
use strict;
use warnings;

# If run outside the normal test suite on an ASCII platform, you can
# just create a latin1_to_native() function that just returns its
# inputs, because that's the only function used from test.pl
require "test.pl";

# Test qr/\X/ and the \p{} regular expression constructs.  This file is
# constructed by mktables from the tables it generates, so if mktables is
# buggy, this won't necessarily catch those bugs.  Tests are generated for all
# feasible properties; a few aren't currently feasible; see
# is_code_point_usable() in mktables for details.

# Standard test packages are not used because this manipulates SIG_WARN.  It
# exits 0 if every non-skipped test succeeded; -1 if any failed.

my $Tests = 0;
my $Fails = 0;

sub Expect($$$$) {
    my $expected = shift;
    my $ord = shift;
    my $regex  = shift;
    my $warning_type = shift;   # Type of warning message, like 'deprecated'
                                # or empty if none
    my $line   = (caller)[2];

    # Convert the code point to hex form
    my $string = sprintf "\"\\x{%04X}\"", $ord;

    my @tests = "";

    # The first time through, use all warnings.  If the input should generate
    # a warning, add another time through with them turned off
    push @tests, "no warnings '$warning_type';" if $warning_type;

    foreach my $no_warnings (@tests) {

        # Store any warning messages instead of outputting them
        local $SIG{__WARN__} = $SIG{__WARN__};
        my $warning_message;
        $SIG{__WARN__} = sub { $warning_message = $_[0] };

        $Tests++;

        # A string eval is needed because of the 'no warnings'.
        # Assumes no parens in the regular expression
        my $result = eval "$no_warnings
                            my \$RegObj = qr($regex);
                            $string =~ \$RegObj ? 1 : 0";
        if (not defined $result) {
            print "not ok $Tests - couldn't compile /$regex/; line $line: $@\n";
            $Fails++;
        }
        elsif ($result ^ $expected) {
            print "not ok $Tests - expected $expected but got $result for $string =~ qr/$regex/; line $line\n";
            $Fails++;
        }
        elsif ($warning_message) {
            if (! $warning_type || ($warning_type && $no_warnings)) {
                print "not ok $Tests - for qr/$regex/ did not expect warning message '$warning_message'; line $line\n";
                $Fails++;
            }
            else {
                print "ok $Tests - expected and got a warning message for qr/$regex/; line $line\n";
            }
        }
        elsif ($warning_type && ! $no_warnings) {
            print "not ok $Tests - for qr/$regex/ expected a $warning_type warning message, but got none; line $line\n";
            $Fails++;
        }
        else {
            print "ok $Tests - got $result for $string =~ qr/$regex/; line $line\n";
        }
    }
    return;
}

sub Error($) {
    my $regex  = shift;
    $Tests++;
    if (eval { 'x' =~ qr/$regex/; 1 }) {
        $Fails++;
        my $line = (caller)[2];
        print "not ok $Tests - re compiled ok, but expected error for qr/$regex/; line $line: $@\n";
    }
    else {
        my $line = (caller)[2];
        print "ok $Tests - got and expected error for qr/$regex/; line $line\n";
    }
    return;
}

# GCBTest.txt character that separates grapheme clusters
my $breakable_utf8 = my $breakable = chr(utf8::unicode_to_native(0xF7));
utf8::upgrade($breakable_utf8);

# GCBTest.txt character that indicates that the adjoining code points are part
# of the same grapheme cluster
my $nobreak_utf8 = my $nobreak = chr(utf8::unicode_to_native(0xD7));
utf8::upgrade($nobreak_utf8);

sub Test_X($) {
    # Test qr/\X/ matches.  The input is a line from auxiliary/GCBTest.txt
    # Each such line is a sequence of code points given by their hex numbers,
    # separated by the two characters defined just before this subroutine that
    # indicate that either there can or cannot be a break between the adjacent
    # code points.  If there isn't a break, that means the sequence forms an
    # extended grapheme cluster, which means that \X should match the whole
    # thing.  If there is a break, \X should stop there.  This is all
    # converted by this routine into a match:
    #   $string =~ /(\X)/,
    # Each \X should match the next cluster; and that is what is checked.

    my $template = shift;

    my $line   = (caller)[2];

    # The line contains characters above the ASCII range, but in Latin1.  It
    # may or may not be in utf8, and if it is, it may or may not know it.  So,
    # convert these characters to 8 bits.  If knows is in utf8, simply
    # downgrade.
    if (utf8::is_utf8($template)) {
        utf8::downgrade($template);
    } else {

        # Otherwise, if it is in utf8, but doesn't know it, the next lines
        # convert the two problematic characters to their 8-bit equivalents.
        # If it isn't in utf8, they don't harm anything.
        use bytes;
        $template =~ s/$nobreak_utf8/$nobreak/g;
        $template =~ s/$breakable_utf8/$breakable/g;
    }

    # Get rid of the leading and trailing breakables
    $template =~ s/^ \s* $breakable \s* //x;
    $template =~ s/ \s* $breakable \s* $ //x;

    # And no-breaks become just a space.
    $template =~ s/ \s* $nobreak \s* / /xg;

    # Split the input into segments that are breakable between them.
    my @segments = split /\s*$breakable\s*/, $template;

    my $string = "";
    my $display_string = "";
    my @should_match;
    my @should_display;

    # Convert the code point sequence in each segment into a Perl string of
    # characters
    foreach my $segment (@segments) {
        my @code_points = split /\s+/, $segment;
        my $this_string = "";
        my $this_display = "";
        foreach my $code_point (@code_points) {
            $this_string .= latin1_to_native(chr(hex $code_point));
            $this_display .= "\\x{$code_point}";
        }

        # The next cluster should match the string in this segment.
        push @should_match, $this_string;
        push @should_display, $this_display;
        $string .= $this_string;
        $display_string .= $this_display;
    }

    # If a string can be represented in both non-ut8 and utf8, test both cases
    UPGRADE:
    for my $to_upgrade (0 .. 1) {

        if ($to_upgrade) {

            # If already in utf8, would just be a repeat
            next UPGRADE if utf8::is_utf8($string);

            utf8::upgrade($string);
        }

        # Finally, do the \X match.
        my @matches = $string =~ /(\X)/g;

        # Look through each matched cluster to verify that it matches what we
        # expect.
        my $min = (@matches < @should_match) ? @matches : @should_match;
        for my $i (0 .. $min - 1) {
            $Tests++;
            if ($matches[$i] eq $should_match[$i]) {
                print "ok $Tests - ";
                if ($i == 0) {
                    print "In \"$display_string\" =~ /(\\X)/g, \\X #1";
                } else {
                    print "And \\X #", $i + 1,
                }
                print " correctly matched $should_display[$i]; line $line\n";
            } else {
                $matches[$i] = join("", map { sprintf "\\x{%04X}", $_ }
                                                    unpack("U*", $matches[$i]));
                print "not ok $Tests - In \"$display_string\" =~ /(\\X)/g, \\X #",
                    $i + 1,
                    " should have matched $should_display[$i]",
                    " but instead matched $matches[$i]",
                    ".  Abandoning rest of line $line\n";
                next UPGRADE;
            }
        }

        # And the number of matches should equal the number of expected matches.
        $Tests++;
        if (@matches == @should_match) {
            print "ok $Tests - Nothing was left over; line $line\n";
        } else {
            print "not ok $Tests - There were ", scalar @should_match, " \\X matches expected, but got ", scalar @matches, " instead; line $line\n";
        }
    }

    return;
}

sub Finished() {
    print "1..$Tests\n";
    exit($Fails ? -1 : 0);
}

Error('\p{Script=InGreek}');    # Bug #69018
Test_X("1100 $nobreak 1161");  # Bug #70940
Expect(0, 0x2028, '\p{Print}', ""); # Bug # 71722
Expect(0, 0x2029, '\p{Print}', ""); # Bug # 71722
Expect(1, 0xFF10, '\p{XDigit}', ""); # Bug # 71726
Error('\p{ASCII_Hex_Digit=:=	No}');
Error('\P{ASCII_Hex_Digit=:=	No}');
Expect(1, 103, '\p{ASCII_Hex_Digit=no}', "");
Expect(0, 103, '\p{^ASCII_Hex_Digit=no}', "");
Expect(0, 103, '\P{ASCII_Hex_Digit=no}', "");
Expect(1, 103, '\P{^ASCII_Hex_Digit=no}', "");
Expect(0, 102, '\p{ASCII_Hex_Digit=no}', "");
Expect(1, 102, '\p{^ASCII_Hex_Digit=no}', "");
Expect(1, 102, '\P{ASCII_Hex_Digit=no}', "");
Expect(0, 102, '\P{^ASCII_Hex_Digit=no}', "");
Expect(1, 103, '\p{ASCII_Hex_Digit=--No}', "");
Expect(0, 103, '\p{^ASCII_Hex_Digit=--No}', "");
Expect(0, 103, '\P{ASCII_Hex_Digit=--No}', "");
Expect(1, 103, '\P{^ASCII_Hex_Digit=--No}', "");
Expect(0, 102, '\p{ASCII_Hex_Digit=--No}', "");
Expect(1, 102, '\p{^ASCII_Hex_Digit=--No}', "");
Expect(1, 102, '\P{ASCII_Hex_Digit=--No}', "");
Expect(0, 102, '\P{^ASCII_Hex_Digit=--No}', "");
Error('\p{AHex=		N:=}');
Error('\P{AHex=		N:=}');
Expect(1, 103, '\p{AHex=n}', "");
Expect(0, 103, '\p{^AHex=n}', "");
Expect(0, 103, '\P{AHex=n}', "");
Expect(1, 103, '\P{^AHex=n}', "");
Expect(0, 102, '\p{AHex=n}', "");
Expect(1, 102, '\p{^AHex=n}', "");
Expect(1, 102, '\P{AHex=n}', "");
Expect(0, 102, '\P{^AHex=n}', "");
Expect(1, 103, '\p{AHex:	N}', "");
Expect(0, 103, '\p{^AHex:	N}', "");
Expect(0, 103, '\P{AHex:	N}', "");
Expect(1, 103, '\P{^AHex:	N}', "");
Expect(0, 102, '\p{AHex:	N}', "");
Expect(1, 102, '\p{^AHex:	N}', "");
Expect(1, 102, '\P{AHex:	N}', "");
Expect(0, 102, '\P{^AHex:	N}', "");
Error('\p{Is_ASCII_Hex_Digit=/a/		F}');
Error('\P{Is_ASCII_Hex_Digit=/a/		F}');
Expect(1, 103, '\p{Is_ASCII_Hex_Digit=f}', "");
Expect(0, 103, '\p{^Is_ASCII_Hex_Digit=f}', "");
Expect(0, 103, '\P{Is_ASCII_Hex_Digit=f}', "");
Expect(1, 103, '\P{^Is_ASCII_Hex_Digit=f}', "");
Expect(0, 102, '\p{Is_ASCII_Hex_Digit=f}', "");
Expect(1, 102, '\p{^Is_ASCII_Hex_Digit=f}', "");
Expect(1, 102, '\P{Is_ASCII_Hex_Digit=f}', "");
Expect(0, 102, '\P{^Is_ASCII_Hex_Digit=f}', "");
Expect(1, 103, '\p{Is_ASCII_Hex_Digit=-F}', "");
Expect(0, 103, '\p{^Is_ASCII_Hex_Digit=-F}', "");
Expect(0, 103, '\P{Is_ASCII_Hex_Digit=-F}', "");
Expect(1, 103, '\P{^Is_ASCII_Hex_Digit=-F}', "");
Expect(0, 102, '\p{Is_ASCII_Hex_Digit=-F}', "");
Expect(1, 102, '\p{^Is_ASCII_Hex_Digit=-F}', "");
Expect(1, 102, '\P{Is_ASCII_Hex_Digit=-F}', "");
Expect(0, 102, '\P{^Is_ASCII_Hex_Digit=-F}', "");
Error('\p{Is_AHex=		False/a/}');
Error('\P{Is_AHex=		False/a/}');
Expect(1, 103, '\p{Is_AHex=false}', "");
Expect(0, 103, '\p{^Is_AHex=false}', "");
Expect(0, 103, '\P{Is_AHex=false}', "");
Expect(1, 103, '\P{^Is_AHex=false}', "");
Expect(0, 102, '\p{Is_AHex=false}', "");
Expect(1, 102, '\p{^Is_AHex=false}', "");
Expect(1, 102, '\P{Is_AHex=false}', "");
Expect(0, 102, '\P{^Is_AHex=false}', "");
Expect(1, 103, '\p{Is_AHex=_-false}', "");
Expect(0, 103, '\p{^Is_AHex=_-false}', "");
Expect(0, 103, '\P{Is_AHex=_-false}', "");
Expect(1, 103, '\P{^Is_AHex=_-false}', "");
Expect(0, 102, '\p{Is_AHex=_-false}', "");
Expect(1, 102, '\p{^Is_AHex=_-false}', "");
Expect(1, 102, '\P{Is_AHex=_-false}', "");
Expect(0, 102, '\P{^Is_AHex=_-false}', "");
Error('\p{ASCII_Hex_Digit=_ YES:=}');
Error('\P{ASCII_Hex_Digit=_ YES:=}');
Expect(1, 102, '\p{ASCII_Hex_Digit=yes}', "");
Expect(0, 102, '\p{^ASCII_Hex_Digit=yes}', "");
Expect(0, 102, '\P{ASCII_Hex_Digit=yes}', "");
Expect(1, 102, '\P{^ASCII_Hex_Digit=yes}', "");
Expect(0, 103, '\p{ASCII_Hex_Digit=yes}', "");
Expect(1, 103, '\p{^ASCII_Hex_Digit=yes}', "");
Expect(1, 103, '\P{ASCII_Hex_Digit=yes}', "");
Expect(0, 103, '\P{^ASCII_Hex_Digit=yes}', "");
Expect(1, 102, '\p{ASCII_Hex_Digit=_	yes}', "");
Expect(0, 102, '\p{^ASCII_Hex_Digit=_	yes}', "");
Expect(0, 102, '\P{ASCII_Hex_Digit=_	yes}', "");
Expect(1, 102, '\P{^ASCII_Hex_Digit=_	yes}', "");
Expect(0, 103, '\p{ASCII_Hex_Digit=_	yes}', "");
Expect(1, 103, '\p{^ASCII_Hex_Digit=_	yes}', "");
Expect(1, 103, '\P{ASCII_Hex_Digit=_	yes}', "");
Expect(0, 103, '\P{^ASCII_Hex_Digit=_	yes}', "");
Error('\p{AHex:   /a/	Y}');
Error('\P{AHex:   /a/	Y}');
Expect(1, 102, '\p{AHex=y}', "");
Expect(0, 102, '\p{^AHex=y}', "");
Expect(0, 102, '\P{AHex=y}', "");
Expect(1, 102, '\P{^AHex=y}', "");
Expect(0, 103, '\p{AHex=y}', "");
Expect(1, 103, '\p{^AHex=y}', "");
Expect(1, 103, '\P{AHex=y}', "");
Expect(0, 103, '\P{^AHex=y}', "");
Expect(1, 102, '\p{AHex= y}', "");
Expect(0, 102, '\p{^AHex= y}', "");
Expect(0, 102, '\P{AHex= y}', "");
Expect(1, 102, '\P{^AHex= y}', "");
Expect(0, 103, '\p{AHex= y}', "");
Expect(1, 103, '\p{^AHex= y}', "");
Expect(1, 103, '\P{AHex= y}', "");
Expect(0, 103, '\P{^AHex= y}', "");
Error('\p{Is_ASCII_Hex_Digit::=-	T}');
Error('\P{Is_ASCII_Hex_Digit::=-	T}');
Expect(1, 102, '\p{Is_ASCII_Hex_Digit=t}', "");
Expect(0, 102, '\p{^Is_ASCII_Hex_Digit=t}', "");
Expect(0, 102, '\P{Is_ASCII_Hex_Digit=t}', "");
Expect(1, 102, '\P{^Is_ASCII_Hex_Digit=t}', "");
Expect(0, 103, '\p{Is_ASCII_Hex_Digit=t}', "");
Expect(1, 103, '\p{^Is_ASCII_Hex_Digit=t}', "");
Expect(1, 103, '\P{Is_ASCII_Hex_Digit=t}', "");
Expect(0, 103, '\P{^Is_ASCII_Hex_Digit=t}', "");
Expect(1, 102, '\p{Is_ASCII_Hex_Digit:  T}', "");
Expect(0, 102, '\p{^Is_ASCII_Hex_Digit:  T}', "");
Expect(0, 102, '\P{Is_ASCII_Hex_Digit:  T}', "");
Expect(1, 102, '\P{^Is_ASCII_Hex_Digit:  T}', "");
Expect(0, 103, '\p{Is_ASCII_Hex_Digit:  T}', "");
Expect(1, 103, '\p{^Is_ASCII_Hex_Digit:  T}', "");
Expect(1, 103, '\P{Is_ASCII_Hex_Digit:  T}', "");
Expect(0, 103, '\P{^Is_ASCII_Hex_Digit:  T}', "");
Error('\p{Is_AHex=	:=True}');
Error('\P{Is_AHex=	:=True}');
Expect(1, 102, '\p{Is_AHex=true}', "");
Expect(0, 102, '\p{^Is_AHex=true}', "");
Expect(0, 102, '\P{Is_AHex=true}', "");
Expect(1, 102, '\P{^Is_AHex=true}', "");
Expect(0, 103, '\p{Is_AHex=true}', "");
Expect(1, 103, '\p{^Is_AHex=true}', "");
Expect(1, 103, '\P{Is_AHex=true}', "");
Expect(0, 103, '\P{^Is_AHex=true}', "");
Expect(1, 102, '\p{Is_AHex=_	True}', "");
Expect(0, 102, '\p{^Is_AHex=_	True}', "");
Expect(0, 102, '\P{Is_AHex=_	True}', "");
Expect(1, 102, '\P{^Is_AHex=_	True}', "");
Expect(0, 103, '\p{Is_AHex=_	True}', "");
Expect(1, 103, '\p{^Is_AHex=_	True}', "");
Expect(1, 103, '\P{Is_AHex=_	True}', "");
Expect(0, 103, '\P{^Is_AHex=_	True}', "");
Error('\p{Alphabetic= No:=}');
Error('\P{Alphabetic= No:=}');
Expect(1, 195102, '\p{Alphabetic=no}', "");
Expect(0, 195102, '\p{^Alphabetic=no}', "");
Expect(0, 195102, '\P{Alphabetic=no}', "");
Expect(1, 195102, '\P{^Alphabetic=no}', "");
Expect(0, 195101, '\p{Alphabetic=no}', "");
Expect(1, 195101, '\p{^Alphabetic=no}', "");
Expect(1, 195101, '\P{Alphabetic=no}', "");
Expect(0, 195101, '\P{^Alphabetic=no}', "");
Expect(1, 195102, '\p{Alphabetic:   -_No}', "");
Expect(0, 195102, '\p{^Alphabetic:   -_No}', "");
Expect(0, 195102, '\P{Alphabetic:   -_No}', "");
Expect(1, 195102, '\P{^Alphabetic:   -_No}', "");
Expect(0, 195101, '\p{Alphabetic:   -_No}', "");
Expect(1, 195101, '\p{^Alphabetic:   -_No}', "");
Expect(1, 195101, '\P{Alphabetic:   -_No}', "");
Expect(0, 195101, '\P{^Alphabetic:   -_No}', "");
Error('\p{Alpha=-_n/a/}');
Error('\P{Alpha=-_n/a/}');
Expect(1, 195102, '\p{Alpha=n}', "");
Expect(0, 195102, '\p{^Alpha=n}', "");
Expect(0, 195102, '\P{Alpha=n}', "");
Expect(1, 195102, '\P{^Alpha=n}', "");
Expect(0, 195101, '\p{Alpha=n}', "");
Expect(1, 195101, '\p{^Alpha=n}', "");
Expect(1, 195101, '\P{Alpha=n}', "");
Expect(0, 195101, '\P{^Alpha=n}', "");
Expect(1, 195102, '\p{Alpha=	 N}', "");
Expect(0, 195102, '\p{^Alpha=	 N}', "");
Expect(0, 195102, '\P{Alpha=	 N}', "");
Expect(1, 195102, '\P{^Alpha=	 N}', "");
Expect(0, 195101, '\p{Alpha=	 N}', "");
Expect(1, 195101, '\p{^Alpha=	 N}', "");
Expect(1, 195101, '\P{Alpha=	 N}', "");
Expect(0, 195101, '\P{^Alpha=	 N}', "");
Error('\p{Is_Alphabetic:	:=_F}');
Error('\P{Is_Alphabetic:	:=_F}');
Expect(1, 195102, '\p{Is_Alphabetic=f}', "");
Expect(0, 195102, '\p{^Is_Alphabetic=f}', "");
Expect(0, 195102, '\P{Is_Alphabetic=f}', "");
Expect(1, 195102, '\P{^Is_Alphabetic=f}', "");
Expect(0, 195101, '\p{Is_Alphabetic=f}', "");
Expect(1, 195101, '\p{^Is_Alphabetic=f}', "");
Expect(1, 195101, '\P{Is_Alphabetic=f}', "");
Expect(0, 195101, '\P{^Is_Alphabetic=f}', "");
Expect(1, 195102, '\p{Is_Alphabetic= F}', "");
Expect(0, 195102, '\p{^Is_Alphabetic= F}', "");
Expect(0, 195102, '\P{Is_Alphabetic= F}', "");
Expect(1, 195102, '\P{^Is_Alphabetic= F}', "");
Expect(0, 195101, '\p{Is_Alphabetic= F}', "");
Expect(1, 195101, '\p{^Is_Alphabetic= F}', "");
Expect(1, 195101, '\P{Is_Alphabetic= F}', "");
Expect(0, 195101, '\P{^Is_Alphabetic= F}', "");
Error('\p{Is_Alpha=/a/--false}');
Error('\P{Is_Alpha=/a/--false}');
Expect(1, 195102, '\p{Is_Alpha=false}', "");
Expect(0, 195102, '\p{^Is_Alpha=false}', "");
Expect(0, 195102, '\P{Is_Alpha=false}', "");
Expect(1, 195102, '\P{^Is_Alpha=false}', "");
Expect(0, 195101, '\p{Is_Alpha=false}', "");
Expect(1, 195101, '\p{^Is_Alpha=false}', "");
Expect(1, 195101, '\P{Is_Alpha=false}', "");
Expect(0, 195101, '\P{^Is_Alpha=false}', "");
Expect(1, 195102, '\p{Is_Alpha: false}', "");
Expect(0, 195102, '\p{^Is_Alpha: false}', "");
Expect(0, 195102, '\P{Is_Alpha: false}', "");
Expect(1, 195102, '\P{^Is_Alpha: false}', "");
Expect(0, 195101, '\p{Is_Alpha: false}', "");
Expect(1, 195101, '\p{^Is_Alpha: false}', "");
Expect(1, 195101, '\P{Is_Alpha: false}', "");
Expect(0, 195101, '\P{^Is_Alpha: false}', "");
Error('\p{Alphabetic= Yes/a/}');
Error('\P{Alphabetic= Yes/a/}');
Expect(1, 195101, '\p{Alphabetic=yes}', "");
Expect(0, 195101, '\p{^Alphabetic=yes}', "");
Expect(0, 195101, '\P{Alphabetic=yes}', "");
Expect(1, 195101, '\P{^Alphabetic=yes}', "");
Expect(0, 195102, '\p{Alphabetic=yes}', "");
Expect(1, 195102, '\p{^Alphabetic=yes}', "");
Expect(1, 195102, '\P{Alphabetic=yes}', "");
Expect(0, 195102, '\P{^Alphabetic=yes}', "");
Expect(1, 195101, '\p{Alphabetic=-	yes}', "");
Expect(0, 195101, '\p{^Alphabetic=-	yes}', "");
Expect(0, 195101, '\P{Alphabetic=-	yes}', "");
Expect(1, 195101, '\P{^Alphabetic=-	yes}', "");
Expect(0, 195102, '\p{Alphabetic=-	yes}', "");
Expect(1, 195102, '\p{^Alphabetic=-	yes}', "");
Expect(1, 195102, '\P{Alphabetic=-	yes}', "");
Expect(0, 195102, '\P{^Alphabetic=-	yes}', "");
Error('\p{Alpha=:=Y}');
Error('\P{Alpha=:=Y}');
Expect(1, 195101, '\p{Alpha=y}', "");
Expect(0, 195101, '\p{^Alpha=y}', "");
Expect(0, 195101, '\P{Alpha=y}', "");
Expect(1, 195101, '\P{^Alpha=y}', "");
Expect(0, 195102, '\p{Alpha=y}', "");
Expect(1, 195102, '\p{^Alpha=y}', "");
Expect(1, 195102, '\P{Alpha=y}', "");
Expect(0, 195102, '\P{^Alpha=y}', "");
Expect(1, 195101, '\p{Alpha=__Y}', "");
Expect(0, 195101, '\p{^Alpha=__Y}', "");
Expect(0, 195101, '\P{Alpha=__Y}', "");
Expect(1, 195101, '\P{^Alpha=__Y}', "");
Expect(0, 195102, '\p{Alpha=__Y}', "");
Expect(1, 195102, '\p{^Alpha=__Y}', "");
Expect(1, 195102, '\P{Alpha=__Y}', "");
Expect(0, 195102, '\P{^Alpha=__Y}', "");
Error('\p{Is_Alphabetic=	T/a/}');
Error('\P{Is_Alphabetic=	T/a/}');
Expect(1, 195101, '\p{Is_Alphabetic:t}', "");
Expect(0, 195101, '\p{^Is_Alphabetic:t}', "");
Expect(0, 195101, '\P{Is_Alphabetic:t}', "");
Expect(1, 195101, '\P{^Is_Alphabetic:t}', "");
Expect(0, 195102, '\p{Is_Alphabetic:t}', "");
Expect(1, 195102, '\p{^Is_Alphabetic:t}', "");
Expect(1, 195102, '\P{Is_Alphabetic:t}', "");
Expect(0, 195102, '\P{^Is_Alphabetic:t}', "");
Expect(1, 195101, '\p{Is_Alphabetic=_-T}', "");
Expect(0, 195101, '\p{^Is_Alphabetic=_-T}', "");
Expect(0, 195101, '\P{Is_Alphabetic=_-T}', "");
Expect(1, 195101, '\P{^Is_Alphabetic=_-T}', "");
Expect(0, 195102, '\p{Is_Alphabetic=_-T}', "");
Expect(1, 195102, '\p{^Is_Alphabetic=_-T}', "");
Expect(1, 195102, '\P{Is_Alphabetic=_-T}', "");
Expect(0, 195102, '\P{^Is_Alphabetic=_-T}', "");
Error('\p{Is_Alpha=/a/		True}');
Error('\P{Is_Alpha=/a/		True}');
Expect(1, 195101, '\p{Is_Alpha=true}', "");
Expect(0, 195101, '\p{^Is_Alpha=true}', "");
Expect(0, 195101, '\P{Is_Alpha=true}', "");
Expect(1, 195101, '\P{^Is_Alpha=true}', "");
Expect(0, 195102, '\p{Is_Alpha=true}', "");
Expect(1, 195102, '\p{^Is_Alpha=true}', "");
Expect(1, 195102, '\P{Is_Alpha=true}', "");
Expect(0, 195102, '\P{^Is_Alpha=true}', "");
Expect(1, 195101, '\p{Is_Alpha=	-TRUE}', "");
Expect(0, 195101, '\p{^Is_Alpha=	-TRUE}', "");
Expect(0, 195101, '\P{Is_Alpha=	-TRUE}', "");
Expect(1, 195101, '\P{^Is_Alpha=	-TRUE}', "");
Expect(0, 195102, '\p{Is_Alpha=	-TRUE}', "");
Expect(1, 195102, '\p{^Is_Alpha=	-TRUE}', "");
Expect(1, 195102, '\P{Is_Alpha=	-TRUE}', "");
Expect(0, 195102, '\P{^Is_Alpha=	-TRUE}', "");
Error('\p{Bidi_Control=-no:=}');
Error('\P{Bidi_Control=-no:=}');
Expect(1, 8298, '\p{Bidi_Control=no}', "");
Expect(0, 8298, '\p{^Bidi_Control=no}', "");
Expect(0, 8298, '\P{Bidi_Control=no}', "");
Expect(1, 8298, '\P{^Bidi_Control=no}', "");
Expect(0, 8297, '\p{Bidi_Control=no}', "");
Expect(1, 8297, '\p{^Bidi_Control=no}', "");
Expect(1, 8297, '\P{Bidi_Control=no}', "");
Expect(0, 8297, '\P{^Bidi_Control=no}', "");
Expect(1, 8298, '\p{Bidi_Control= NO}', "");
Expect(0, 8298, '\p{^Bidi_Control= NO}', "");
Expect(0, 8298, '\P{Bidi_Control= NO}', "");
Expect(1, 8298, '\P{^Bidi_Control= NO}', "");
Expect(0, 8297, '\p{Bidi_Control= NO}', "");
Expect(1, 8297, '\p{^Bidi_Control= NO}', "");
Expect(1, 8297, '\P{Bidi_Control= NO}', "");
Expect(0, 8297, '\P{^Bidi_Control= NO}', "");
Error('\p{Bidi_C=/a/	-N}');
Error('\P{Bidi_C=/a/	-N}');
Expect(1, 8298, '\p{Bidi_C=n}', "");
Expect(0, 8298, '\p{^Bidi_C=n}', "");
Expect(0, 8298, '\P{Bidi_C=n}', "");
Expect(1, 8298, '\P{^Bidi_C=n}', "");
Expect(0, 8297, '\p{Bidi_C=n}', "");
Expect(1, 8297, '\p{^Bidi_C=n}', "");
Expect(1, 8297, '\P{Bidi_C=n}', "");
Expect(0, 8297, '\P{^Bidi_C=n}', "");
Expect(1, 8298, '\p{Bidi_C=-n}', "");
Expect(0, 8298, '\p{^Bidi_C=-n}', "");
Expect(0, 8298, '\P{Bidi_C=-n}', "");
Expect(1, 8298, '\P{^Bidi_C=-n}', "");
Expect(0, 8297, '\p{Bidi_C=-n}', "");
Expect(1, 8297, '\p{^Bidi_C=-n}', "");
Expect(1, 8297, '\P{Bidi_C=-n}', "");
Expect(0, 8297, '\P{^Bidi_C=-n}', "");
Error('\p{Is_Bidi_Control=	 F:=}');
Error('\P{Is_Bidi_Control=	 F:=}');
Expect(1, 8298, '\p{Is_Bidi_Control=f}', "");
Expect(0, 8298, '\p{^Is_Bidi_Control=f}', "");
Expect(0, 8298, '\P{Is_Bidi_Control=f}', "");
Expect(1, 8298, '\P{^Is_Bidi_Control=f}', "");
Expect(0, 8297, '\p{Is_Bidi_Control=f}', "");
Expect(1, 8297, '\p{^Is_Bidi_Control=f}', "");
Expect(1, 8297, '\P{Is_Bidi_Control=f}', "");
Expect(0, 8297, '\P{^Is_Bidi_Control=f}', "");
Expect(1, 8298, '\p{Is_Bidi_Control=  F}', "");
Expect(0, 8298, '\p{^Is_Bidi_Control=  F}', "");
Expect(0, 8298, '\P{Is_Bidi_Control=  F}', "");
Expect(1, 8298, '\P{^Is_Bidi_Control=  F}', "");
Expect(0, 8297, '\p{Is_Bidi_Control=  F}', "");
Expect(1, 8297, '\p{^Is_Bidi_Control=  F}', "");
Expect(1, 8297, '\P{Is_Bidi_Control=  F}', "");
Expect(0, 8297, '\P{^Is_Bidi_Control=  F}', "");
Error('\p{Is_Bidi_C=-False/a/}');
Error('\P{Is_Bidi_C=-False/a/}');
Expect(1, 8298, '\p{Is_Bidi_C=false}', "");
Expect(0, 8298, '\p{^Is_Bidi_C=false}', "");
Expect(0, 8298, '\P{Is_Bidi_C=false}', "");
Expect(1, 8298, '\P{^Is_Bidi_C=false}', "");
Expect(0, 8297, '\p{Is_Bidi_C=false}', "");
Expect(1, 8297, '\p{^Is_Bidi_C=false}', "");
Expect(1, 8297, '\P{Is_Bidi_C=false}', "");
Expect(0, 8297, '\P{^Is_Bidi_C=false}', "");
Expect(1, 8298, '\p{Is_Bidi_C=FALSE}', "");
Expect(0, 8298, '\p{^Is_Bidi_C=FALSE}', "");
Expect(0, 8298, '\P{Is_Bidi_C=FALSE}', "");
Expect(1, 8298, '\P{^Is_Bidi_C=FALSE}', "");
Expect(0, 8297, '\p{Is_Bidi_C=FALSE}', "");
Expect(1, 8297, '\p{^Is_Bidi_C=FALSE}', "");
Expect(1, 8297, '\P{Is_Bidi_C=FALSE}', "");
Expect(0, 8297, '\P{^Is_Bidi_C=FALSE}', "");
Error('\p{Bidi_Control=--Yes/a/}');
Error('\P{Bidi_Control=--Yes/a/}');
Expect(1, 8297, '\p{Bidi_Control=yes}', "");
Expect(0, 8297, '\p{^Bidi_Control=yes}', "");
Expect(0, 8297, '\P{Bidi_Control=yes}', "");
Expect(1, 8297, '\P{^Bidi_Control=yes}', "");
Expect(0, 8298, '\p{Bidi_Control=yes}', "");
Expect(1, 8298, '\p{^Bidi_Control=yes}', "");
Expect(1, 8298, '\P{Bidi_Control=yes}', "");
Expect(0, 8298, '\P{^Bidi_Control=yes}', "");
Expect(1, 8297, '\p{Bidi_Control=	_Yes}', "");
Expect(0, 8297, '\p{^Bidi_Control=	_Yes}', "");
Expect(0, 8297, '\P{Bidi_Control=	_Yes}', "");
Expect(1, 8297, '\P{^Bidi_Control=	_Yes}', "");
Expect(0, 8298, '\p{Bidi_Control=	_Yes}', "");
Expect(1, 8298, '\p{^Bidi_Control=	_Yes}', "");
Expect(1, 8298, '\P{Bidi_Control=	_Yes}', "");
Expect(0, 8298, '\P{^Bidi_Control=	_Yes}', "");
Error('\p{Bidi_C=:= _Y}');
Error('\P{Bidi_C=:= _Y}');
Expect(1, 8297, '\p{Bidi_C=y}', "");
Expect(0, 8297, '\p{^Bidi_C=y}', "");
Expect(0, 8297, '\P{Bidi_C=y}', "");
Expect(1, 8297, '\P{^Bidi_C=y}', "");
Expect(0, 8298, '\p{Bidi_C=y}', "");
Expect(1, 8298, '\p{^Bidi_C=y}', "");
Expect(1, 8298, '\P{Bidi_C=y}', "");
Expect(0, 8298, '\P{^Bidi_C=y}', "");
Expect(1, 8297, '\p{Bidi_C=_Y}', "");
Expect(0, 8297, '\p{^Bidi_C=_Y}', "");
Expect(0, 8297, '\P{Bidi_C=_Y}', "");
Expect(1, 8297, '\P{^Bidi_C=_Y}', "");
Expect(0, 8298, '\p{Bidi_C=_Y}', "");
Expect(1, 8298, '\p{^Bidi_C=_Y}', "");
Expect(1, 8298, '\P{Bidi_C=_Y}', "");
Expect(0, 8298, '\P{^Bidi_C=_Y}', "");
Error('\p{Is_Bidi_Control= -T/a/}');
Error('\P{Is_Bidi_Control= -T/a/}');
Expect(1, 8297, '\p{Is_Bidi_Control=t}', "");
Expect(0, 8297, '\p{^Is_Bidi_Control=t}', "");
Expect(0, 8297, '\P{Is_Bidi_Control=t}', "");
Expect(1, 8297, '\P{^Is_Bidi_Control=t}', "");
Expect(0, 8298, '\p{Is_Bidi_Control=t}', "");
Expect(1, 8298, '\p{^Is_Bidi_Control=t}', "");
Expect(1, 8298, '\P{Is_Bidi_Control=t}', "");
Expect(0, 8298, '\P{^Is_Bidi_Control=t}', "");
Expect(1, 8297, '\p{Is_Bidi_Control= -T}', "");
Expect(0, 8297, '\p{^Is_Bidi_Control= -T}', "");
Expect(0, 8297, '\P{Is_Bidi_Control= -T}', "");
Expect(1, 8297, '\P{^Is_Bidi_Control= -T}', "");
Expect(0, 8298, '\p{Is_Bidi_Control= -T}', "");
Expect(1, 8298, '\p{^Is_Bidi_Control= -T}', "");
Expect(1, 8298, '\P{Is_Bidi_Control= -T}', "");
Expect(0, 8298, '\P{^Is_Bidi_Control= -T}', "");
Error('\p{Is_Bidi_C=		TRUE/a/}');
Error('\P{Is_Bidi_C=		TRUE/a/}');
Expect(1, 8297, '\p{Is_Bidi_C=true}', "");
Expect(0, 8297, '\p{^Is_Bidi_C=true}', "");
Expect(0, 8297, '\P{Is_Bidi_C=true}', "");
Expect(1, 8297, '\P{^Is_Bidi_C=true}', "");
Expect(0, 8298, '\p{Is_Bidi_C=true}', "");
Expect(1, 8298, '\p{^Is_Bidi_C=true}', "");
Expect(1, 8298, '\P{Is_Bidi_C=true}', "");
Expect(0, 8298, '\P{^Is_Bidi_C=true}', "");
Expect(1, 8297, '\p{Is_Bidi_C=  true}', "");
Expect(0, 8297, '\p{^Is_Bidi_C=  true}', "");
Expect(0, 8297, '\P{Is_Bidi_C=  true}', "");
Expect(1, 8297, '\P{^Is_Bidi_C=  true}', "");
Expect(0, 8298, '\p{Is_Bidi_C=  true}', "");
Expect(1, 8298, '\p{^Is_Bidi_C=  true}', "");
Expect(1, 8298, '\P{Is_Bidi_C=  true}', "");
Expect(0, 8298, '\P{^Is_Bidi_C=  true}', "");
Error('\p{Bidi_Mirrored=		No:=}');
Error('\P{Bidi_Mirrored=		No:=}');
Expect(1, 120772, '\p{Bidi_Mirrored=no}', "");
Expect(0, 120772, '\p{^Bidi_Mirrored=no}', "");
Expect(0, 120772, '\P{Bidi_Mirrored=no}', "");
Expect(1, 120772, '\P{^Bidi_Mirrored=no}', "");
Expect(0, 120771, '\p{Bidi_Mirrored=no}', "");
Expect(1, 120771, '\p{^Bidi_Mirrored=no}', "");
Expect(1, 120771, '\P{Bidi_Mirrored=no}', "");
Expect(0, 120771, '\P{^Bidi_Mirrored=no}', "");
Expect(1, 120772, '\p{Bidi_Mirrored=No}', "");
Expect(0, 120772, '\p{^Bidi_Mirrored=No}', "");
Expect(0, 120772, '\P{Bidi_Mirrored=No}', "");
Expect(1, 120772, '\P{^Bidi_Mirrored=No}', "");
Expect(0, 120771, '\p{Bidi_Mirrored=No}', "");
Expect(1, 120771, '\p{^Bidi_Mirrored=No}', "");
Expect(1, 120771, '\P{Bidi_Mirrored=No}', "");
Expect(0, 120771, '\P{^Bidi_Mirrored=No}', "");
Error('\p{Bidi_M= :=N}');
Error('\P{Bidi_M= :=N}');
Expect(1, 120772, '\p{Bidi_M=n}', "");
Expect(0, 120772, '\p{^Bidi_M=n}', "");
Expect(0, 120772, '\P{Bidi_M=n}', "");
Expect(1, 120772, '\P{^Bidi_M=n}', "");
Expect(0, 120771, '\p{Bidi_M=n}', "");
Expect(1, 120771, '\p{^Bidi_M=n}', "");
Expect(1, 120771, '\P{Bidi_M=n}', "");
Expect(0, 120771, '\P{^Bidi_M=n}', "");
Expect(1, 120772, '\p{Bidi_M=  N}', "");
Expect(0, 120772, '\p{^Bidi_M=  N}', "");
Expect(0, 120772, '\P{Bidi_M=  N}', "");
Expect(1, 120772, '\P{^Bidi_M=  N}', "");
Expect(0, 120771, '\p{Bidi_M=  N}', "");
Expect(1, 120771, '\p{^Bidi_M=  N}', "");
Expect(1, 120771, '\P{Bidi_M=  N}', "");
Expect(0, 120771, '\P{^Bidi_M=  N}', "");
Error('\p{Is_Bidi_Mirrored=/a/-F}');
Error('\P{Is_Bidi_Mirrored=/a/-F}');
Expect(1, 120772, '\p{Is_Bidi_Mirrored=f}', "");
Expect(0, 120772, '\p{^Is_Bidi_Mirrored=f}', "");
Expect(0, 120772, '\P{Is_Bidi_Mirrored=f}', "");
Expect(1, 120772, '\P{^Is_Bidi_Mirrored=f}', "");
Expect(0, 120771, '\p{Is_Bidi_Mirrored=f}', "");
Expect(1, 120771, '\p{^Is_Bidi_Mirrored=f}', "");
Expect(1, 120771, '\P{Is_Bidi_Mirrored=f}', "");
Expect(0, 120771, '\P{^Is_Bidi_Mirrored=f}', "");
Expect(1, 120772, '\p{Is_Bidi_Mirrored=	 F}', "");
Expect(0, 120772, '\p{^Is_Bidi_Mirrored=	 F}', "");
Expect(0, 120772, '\P{Is_Bidi_Mirrored=	 F}', "");
Expect(1, 120772, '\P{^Is_Bidi_Mirrored=	 F}', "");
Expect(0, 120771, '\p{Is_Bidi_Mirrored=	 F}', "");
Expect(1, 120771, '\p{^Is_Bidi_Mirrored=	 F}', "");
Expect(1, 120771, '\P{Is_Bidi_Mirrored=	 F}', "");
Expect(0, 120771, '\P{^Is_Bidi_Mirrored=	 F}', "");
Error('\p{Is_Bidi_M: _-false/a/}');
Error('\P{Is_Bidi_M: _-false/a/}');
Expect(1, 120772, '\p{Is_Bidi_M=false}', "");
Expect(0, 120772, '\p{^Is_Bidi_M=false}', "");
Expect(0, 120772, '\P{Is_Bidi_M=false}', "");
Expect(1, 120772, '\P{^Is_Bidi_M=false}', "");
Expect(0, 120771, '\p{Is_Bidi_M=false}', "");
Expect(1, 120771, '\p{^Is_Bidi_M=false}', "");
Expect(1, 120771, '\P{Is_Bidi_M=false}', "");
Expect(0, 120771, '\P{^Is_Bidi_M=false}', "");
Expect(1, 120772, '\p{Is_Bidi_M= 	False}', "");
Expect(0, 120772, '\p{^Is_Bidi_M= 	False}', "");
Expect(0, 120772, '\P{Is_Bidi_M= 	False}', "");
Expect(1, 120772, '\P{^Is_Bidi_M= 	False}', "");
Expect(0, 120771, '\p{Is_Bidi_M= 	False}', "");
Expect(1, 120771, '\p{^Is_Bidi_M= 	False}', "");
Expect(1, 120771, '\P{Is_Bidi_M= 	False}', "");
Expect(0, 120771, '\P{^Is_Bidi_M= 	False}', "");
Error('\p{Bidi_Mirrored:	/a/	-YES}');
Error('\P{Bidi_Mirrored:	/a/	-YES}');
Expect(1, 120771, '\p{Bidi_Mirrored=yes}', "");
Expect(0, 120771, '\p{^Bidi_Mirrored=yes}', "");
Expect(0, 120771, '\P{Bidi_Mirrored=yes}', "");
Expect(1, 120771, '\P{^Bidi_Mirrored=yes}', "");
Expect(0, 120772, '\p{Bidi_Mirrored=yes}', "");
Expect(1, 120772, '\p{^Bidi_Mirrored=yes}', "");
Expect(1, 120772, '\P{Bidi_Mirrored=yes}', "");
Expect(0, 120772, '\P{^Bidi_Mirrored=yes}', "");
Expect(1, 120771, '\p{Bidi_Mirrored=  Yes}', "");
Expect(0, 120771, '\p{^Bidi_Mirrored=  Yes}', "");
Expect(0, 120771, '\P{Bidi_Mirrored=  Yes}', "");
Expect(1, 120771, '\P{^Bidi_Mirrored=  Yes}', "");
Expect(0, 120772, '\p{Bidi_Mirrored=  Yes}', "");
Expect(1, 120772, '\p{^Bidi_Mirrored=  Yes}', "");
Expect(1, 120772, '\P{Bidi_Mirrored=  Yes}', "");
Expect(0, 120772, '\P{^Bidi_Mirrored=  Yes}', "");
Error('\p{Bidi_M=-	y:=}');
Error('\P{Bidi_M=-	y:=}');
Expect(1, 120771, '\p{Bidi_M=y}', "");
Expect(0, 120771, '\p{^Bidi_M=y}', "");
Expect(0, 120771, '\P{Bidi_M=y}', "");
Expect(1, 120771, '\P{^Bidi_M=y}', "");
Expect(0, 120772, '\p{Bidi_M=y}', "");
Expect(1, 120772, '\p{^Bidi_M=y}', "");
Expect(1, 120772, '\P{Bidi_M=y}', "");
Expect(0, 120772, '\P{^Bidi_M=y}', "");
Expect(1, 120771, '\p{Bidi_M=	_y}', "");
Expect(0, 120771, '\p{^Bidi_M=	_y}', "");
Expect(0, 120771, '\P{Bidi_M=	_y}', "");
Expect(1, 120771, '\P{^Bidi_M=	_y}', "");
Expect(0, 120772, '\p{Bidi_M=	_y}', "");
Expect(1, 120772, '\p{^Bidi_M=	_y}', "");
Expect(1, 120772, '\P{Bidi_M=	_y}', "");
Expect(0, 120772, '\P{^Bidi_M=	_y}', "");
Error('\p{Is_Bidi_Mirrored=_	T/a/}');
Error('\P{Is_Bidi_Mirrored=_	T/a/}');
Expect(1, 120771, '\p{Is_Bidi_Mirrored=t}', "");
Expect(0, 120771, '\p{^Is_Bidi_Mirrored=t}', "");
Expect(0, 120771, '\P{Is_Bidi_Mirrored=t}', "");
Expect(1, 120771, '\P{^Is_Bidi_Mirrored=t}', "");
Expect(0, 120772, '\p{Is_Bidi_Mirrored=t}', "");
Expect(1, 120772, '\p{^Is_Bidi_Mirrored=t}', "");
Expect(1, 120772, '\P{Is_Bidi_Mirrored=t}', "");
Expect(0, 120772, '\P{^Is_Bidi_Mirrored=t}', "");
Expect(1, 120771, '\p{Is_Bidi_Mirrored=-t}', "");
Expect(0, 120771, '\p{^Is_Bidi_Mirrored=-t}', "");
Expect(0, 120771, '\P{Is_Bidi_Mirrored=-t}', "");
Expect(1, 120771, '\P{^Is_Bidi_Mirrored=-t}', "");
Expect(0, 120772, '\p{Is_Bidi_Mirrored=-t}', "");
Expect(1, 120772, '\p{^Is_Bidi_Mirrored=-t}', "");
Expect(1, 120772, '\P{Is_Bidi_Mirrored=-t}', "");
Expect(0, 120772, '\P{^Is_Bidi_Mirrored=-t}', "");
Error('\p{Is_Bidi_M=	/a/TRUE}');
Error('\P{Is_Bidi_M=	/a/TRUE}');
Expect(1, 120771, '\p{Is_Bidi_M=true}', "");
Expect(0, 120771, '\p{^Is_Bidi_M=true}', "");
Expect(0, 120771, '\P{Is_Bidi_M=true}', "");
Expect(1, 120771, '\P{^Is_Bidi_M=true}', "");
Expect(0, 120772, '\p{Is_Bidi_M=true}', "");
Expect(1, 120772, '\p{^Is_Bidi_M=true}', "");
Expect(1, 120772, '\P{Is_Bidi_M=true}', "");
Expect(0, 120772, '\P{^Is_Bidi_M=true}', "");
Expect(1, 120771, '\p{Is_Bidi_M:	-_True}', "");
Expect(0, 120771, '\p{^Is_Bidi_M:	-_True}', "");
Expect(0, 120771, '\P{Is_Bidi_M:	-_True}', "");
Expect(1, 120771, '\P{^Is_Bidi_M:	-_True}', "");
Expect(0, 120772, '\p{Is_Bidi_M:	-_True}', "");
Expect(1, 120772, '\p{^Is_Bidi_M:	-_True}', "");
Expect(1, 120772, '\P{Is_Bidi_M:	-_True}', "");
Expect(0, 120772, '\P{^Is_Bidi_M:	-_True}', "");
Error('\p{Composition_Exclusion=:=-_NO}');
Error('\P{Composition_Exclusion=:=-_NO}');
Expect(1, 119233, '\p{Composition_Exclusion:no}', "");
Expect(0, 119233, '\p{^Composition_Exclusion:no}', "");
Expect(0, 119233, '\P{Composition_Exclusion:no}', "");
Expect(1, 119233, '\P{^Composition_Exclusion:no}', "");
Expect(0, 119232, '\p{Composition_Exclusion:no}', "");
Expect(1, 119232, '\p{^Composition_Exclusion:no}', "");
Expect(1, 119232, '\P{Composition_Exclusion:no}', "");
Expect(0, 119232, '\P{^Composition_Exclusion:no}', "");
Expect(1, 119233, '\p{Composition_Exclusion=_	NO}', "");
Expect(0, 119233, '\p{^Composition_Exclusion=_	NO}', "");
Expect(0, 119233, '\P{Composition_Exclusion=_	NO}', "");
Expect(1, 119233, '\P{^Composition_Exclusion=_	NO}', "");
Expect(0, 119232, '\p{Composition_Exclusion=_	NO}', "");
Expect(1, 119232, '\p{^Composition_Exclusion=_	NO}', "");
Expect(1, 119232, '\P{Composition_Exclusion=_	NO}', "");
Expect(0, 119232, '\P{^Composition_Exclusion=_	NO}', "");
Error('\p{CE=_/a/N}');
Error('\P{CE=_/a/N}');
Expect(1, 119233, '\p{CE=n}', "");
Expect(0, 119233, '\p{^CE=n}', "");
Expect(0, 119233, '\P{CE=n}', "");
Expect(1, 119233, '\P{^CE=n}', "");
Expect(0, 119232, '\p{CE=n}', "");
Expect(1, 119232, '\p{^CE=n}', "");
Expect(1, 119232, '\P{CE=n}', "");
Expect(0, 119232, '\P{^CE=n}', "");
Expect(1, 119233, '\p{CE=N}', "");
Expect(0, 119233, '\p{^CE=N}', "");
Expect(0, 119233, '\P{CE=N}', "");
Expect(1, 119233, '\P{^CE=N}', "");
Expect(0, 119232, '\p{CE=N}', "");
Expect(1, 119232, '\p{^CE=N}', "");
Expect(1, 119232, '\P{CE=N}', "");
Expect(0, 119232, '\P{^CE=N}', "");
Error('\p{Is_Composition_Exclusion=__F:=}');
Error('\P{Is_Composition_Exclusion=__F:=}');
Expect(1, 119233, '\p{Is_Composition_Exclusion=f}', "");
Expect(0, 119233, '\p{^Is_Composition_Exclusion=f}', "");
Expect(0, 119233, '\P{Is_Composition_Exclusion=f}', "");
Expect(1, 119233, '\P{^Is_Composition_Exclusion=f}', "");
Expect(0, 119232, '\p{Is_Composition_Exclusion=f}', "");
Expect(1, 119232, '\p{^Is_Composition_Exclusion=f}', "");
Expect(1, 119232, '\P{Is_Composition_Exclusion=f}', "");
Expect(0, 119232, '\P{^Is_Composition_Exclusion=f}', "");
Expect(1, 119233, '\p{Is_Composition_Exclusion=_-F}', "");
Expect(0, 119233, '\p{^Is_Composition_Exclusion=_-F}', "");
Expect(0, 119233, '\P{Is_Composition_Exclusion=_-F}', "");
Expect(1, 119233, '\P{^Is_Composition_Exclusion=_-F}', "");
Expect(0, 119232, '\p{Is_Composition_Exclusion=_-F}', "");
Expect(1, 119232, '\p{^Is_Composition_Exclusion=_-F}', "");
Expect(1, 119232, '\P{Is_Composition_Exclusion=_-F}', "");
Expect(0, 119232, '\P{^Is_Composition_Exclusion=_-F}', "");
Error('\p{Is_CE=--false/a/}');
Error('\P{Is_CE=--false/a/}');
Expect(1, 119233, '\p{Is_CE=false}', "");
Expect(0, 119233, '\p{^Is_CE=false}', "");
Expect(0, 119233, '\P{Is_CE=false}', "");
Expect(1, 119233, '\P{^Is_CE=false}', "");
Expect(0, 119232, '\p{Is_CE=false}', "");
Expect(1, 119232, '\p{^Is_CE=false}', "");
Expect(1, 119232, '\P{Is_CE=false}', "");
Expect(0, 119232, '\P{^Is_CE=false}', "");
Expect(1, 119233, '\p{Is_CE:    false}', "");
Expect(0, 119233, '\p{^Is_CE:    false}', "");
Expect(0, 119233, '\P{Is_CE:    false}', "");
Expect(1, 119233, '\P{^Is_CE:    false}', "");
Expect(0, 119232, '\p{Is_CE:    false}', "");
Expect(1, 119232, '\p{^Is_CE:    false}', "");
Expect(1, 119232, '\P{Is_CE:    false}', "");
Expect(0, 119232, '\P{^Is_CE:    false}', "");
Error('\p{Composition_Exclusion=:=_yes}');
Error('\P{Composition_Exclusion=:=_yes}');
Expect(1, 119232, '\p{Composition_Exclusion:yes}', "");
Expect(0, 119232, '\p{^Composition_Exclusion:yes}', "");
Expect(0, 119232, '\P{Composition_Exclusion:yes}', "");
Expect(1, 119232, '\P{^Composition_Exclusion:yes}', "");
Expect(0, 119233, '\p{Composition_Exclusion:yes}', "");
Expect(1, 119233, '\p{^Composition_Exclusion:yes}', "");
Expect(1, 119233, '\P{Composition_Exclusion:yes}', "");
Expect(0, 119233, '\P{^Composition_Exclusion:yes}', "");
Expect(1, 119232, '\p{Composition_Exclusion=_	Yes}', "");
Expect(0, 119232, '\p{^Composition_Exclusion=_	Yes}', "");
Expect(0, 119232, '\P{Composition_Exclusion=_	Yes}', "");
Expect(1, 119232, '\P{^Composition_Exclusion=_	Yes}', "");
Expect(0, 119233, '\p{Composition_Exclusion=_	Yes}', "");
Expect(1, 119233, '\p{^Composition_Exclusion=_	Yes}', "");
Expect(1, 119233, '\P{Composition_Exclusion=_	Yes}', "");
Expect(0, 119233, '\P{^Composition_Exclusion=_	Yes}', "");
Error('\p{CE=--y:=}');
Error('\P{CE=--y:=}');
Expect(1, 119232, '\p{CE=y}', "");
Expect(0, 119232, '\p{^CE=y}', "");
Expect(0, 119232, '\P{CE=y}', "");
Expect(1, 119232, '\P{^CE=y}', "");
Expect(0, 119233, '\p{CE=y}', "");
Expect(1, 119233, '\p{^CE=y}', "");
Expect(1, 119233, '\P{CE=y}', "");
Expect(0, 119233, '\P{^CE=y}', "");
Expect(1, 119232, '\p{CE=__y}', "");
Expect(0, 119232, '\p{^CE=__y}', "");
Expect(0, 119232, '\P{CE=__y}', "");
Expect(1, 119232, '\P{^CE=__y}', "");
Expect(0, 119233, '\p{CE=__y}', "");
Expect(1, 119233, '\p{^CE=__y}', "");
Expect(1, 119233, '\P{CE=__y}', "");
Expect(0, 119233, '\P{^CE=__y}', "");
Error('\p{Is_Composition_Exclusion=:=		T}');
Error('\P{Is_Composition_Exclusion=:=		T}');
Expect(1, 119232, '\p{Is_Composition_Exclusion=t}', "");
Expect(0, 119232, '\p{^Is_Composition_Exclusion=t}', "");
Expect(0, 119232, '\P{Is_Composition_Exclusion=t}', "");
Expect(1, 119232, '\P{^Is_Composition_Exclusion=t}', "");
Expect(0, 119233, '\p{Is_Composition_Exclusion=t}', "");
Expect(1, 119233, '\p{^Is_Composition_Exclusion=t}', "");
Expect(1, 119233, '\P{Is_Composition_Exclusion=t}', "");
Expect(0, 119233, '\P{^Is_Composition_Exclusion=t}', "");
Expect(1, 119232, '\p{Is_Composition_Exclusion=__t}', "");
Expect(0, 119232, '\p{^Is_Composition_Exclusion=__t}', "");
Expect(0, 119232, '\P{Is_Composition_Exclusion=__t}', "");
Expect(1, 119232, '\P{^Is_Composition_Exclusion=__t}', "");
Expect(0, 119233, '\p{Is_Composition_Exclusion=__t}', "");
Expect(1, 119233, '\p{^Is_Composition_Exclusion=__t}', "");
Expect(1, 119233, '\P{Is_Composition_Exclusion=__t}', "");
Expect(0, 119233, '\P{^Is_Composition_Exclusion=__t}', "");
Error('\p{Is_CE=_:=true}');
Error('\P{Is_CE=_:=true}');
Expect(1, 119232, '\p{Is_CE=true}', "");
Expect(0, 119232, '\p{^Is_CE=true}', "");
Expect(0, 119232, '\P{Is_CE=true}', "");
Expect(1, 119232, '\P{^Is_CE=true}', "");
Expect(0, 119233, '\p{Is_CE=true}', "");
Expect(1, 119233, '\p{^Is_CE=true}', "");
Expect(1, 119233, '\P{Is_CE=true}', "");
Expect(0, 119233, '\P{^Is_CE=true}', "");
Expect(1, 119232, '\p{Is_CE=_true}', "");
Expect(0, 119232, '\p{^Is_CE=_true}', "");
Expect(0, 119232, '\P{Is_CE=_true}', "");
Expect(1, 119232, '\P{^Is_CE=_true}', "");
Expect(0, 119233, '\p{Is_CE=_true}', "");
Expect(1, 119233, '\p{^Is_CE=_true}', "");
Expect(1, 119233, '\P{Is_CE=_true}', "");
Expect(0, 119233, '\P{^Is_CE=_true}', "");
Error('\p{Case_Ignorable=/a/no}');
Error('\P{Case_Ignorable=/a/no}');
Expect(1, 918000, '\p{Case_Ignorable=no}', "");
Expect(0, 918000, '\p{^Case_Ignorable=no}', "");
Expect(0, 918000, '\P{Case_Ignorable=no}', "");
Expect(1, 918000, '\P{^Case_Ignorable=no}', "");
Expect(0, 917999, '\p{Case_Ignorable=no}', "");
Expect(1, 917999, '\p{^Case_Ignorable=no}', "");
Expect(1, 917999, '\P{Case_Ignorable=no}', "");
Expect(0, 917999, '\P{^Case_Ignorable=no}', "");
Expect(1, 918000, '\p{Case_Ignorable=__No}', "");
Expect(0, 918000, '\p{^Case_Ignorable=__No}', "");
Expect(0, 918000, '\P{Case_Ignorable=__No}', "");
Expect(1, 918000, '\P{^Case_Ignorable=__No}', "");
Expect(0, 917999, '\p{Case_Ignorable=__No}', "");
Expect(1, 917999, '\p{^Case_Ignorable=__No}', "");
Expect(1, 917999, '\P{Case_Ignorable=__No}', "");
Expect(0, 917999, '\P{^Case_Ignorable=__No}', "");
Error('\p{CI:/a/		N}');
Error('\P{CI:/a/		N}');
Expect(1, 918000, '\p{CI=n}', "");
Expect(0, 918000, '\p{^CI=n}', "");
Expect(0, 918000, '\P{CI=n}', "");
Expect(1, 918000, '\P{^CI=n}', "");
Expect(0, 917999, '\p{CI=n}', "");
Expect(1, 917999, '\p{^CI=n}', "");
Expect(1, 917999, '\P{CI=n}', "");
Expect(0, 917999, '\P{^CI=n}', "");
Expect(1, 918000, '\p{CI:   _N}', "");
Expect(0, 918000, '\p{^CI:   _N}', "");
Expect(0, 918000, '\P{CI:   _N}', "");
Expect(1, 918000, '\P{^CI:   _N}', "");
Expect(0, 917999, '\p{CI:   _N}', "");
Expect(1, 917999, '\p{^CI:   _N}', "");
Expect(1, 917999, '\P{CI:   _N}', "");
Expect(0, 917999, '\P{^CI:   _N}', "");
Error('\p{Is_Case_Ignorable=-/a/F}');
Error('\P{Is_Case_Ignorable=-/a/F}');
Expect(1, 918000, '\p{Is_Case_Ignorable=f}', "");
Expect(0, 918000, '\p{^Is_Case_Ignorable=f}', "");
Expect(0, 918000, '\P{Is_Case_Ignorable=f}', "");
Expect(1, 918000, '\P{^Is_Case_Ignorable=f}', "");
Expect(0, 917999, '\p{Is_Case_Ignorable=f}', "");
Expect(1, 917999, '\p{^Is_Case_Ignorable=f}', "");
Expect(1, 917999, '\P{Is_Case_Ignorable=f}', "");
Expect(0, 917999, '\P{^Is_Case_Ignorable=f}', "");
Expect(1, 918000, '\p{Is_Case_Ignorable= -F}', "");
Expect(0, 918000, '\p{^Is_Case_Ignorable= -F}', "");
Expect(0, 918000, '\P{Is_Case_Ignorable= -F}', "");
Expect(1, 918000, '\P{^Is_Case_Ignorable= -F}', "");
Expect(0, 917999, '\p{Is_Case_Ignorable= -F}', "");
Expect(1, 917999, '\p{^Is_Case_Ignorable= -F}', "");
Expect(1, 917999, '\P{Is_Case_Ignorable= -F}', "");
Expect(0, 917999, '\P{^Is_Case_Ignorable= -F}', "");
Error('\p{Is_CI=	 False/a/}');
Error('\P{Is_CI=	 False/a/}');
Expect(1, 918000, '\p{Is_CI=false}', "");
Expect(0, 918000, '\p{^Is_CI=false}', "");
Expect(0, 918000, '\P{Is_CI=false}', "");
Expect(1, 918000, '\P{^Is_CI=false}', "");
Expect(0, 917999, '\p{Is_CI=false}', "");
Expect(1, 917999, '\p{^Is_CI=false}', "");
Expect(1, 917999, '\P{Is_CI=false}', "");
Expect(0, 917999, '\P{^Is_CI=false}', "");
Expect(1, 918000, '\p{Is_CI=- FALSE}', "");
Expect(0, 918000, '\p{^Is_CI=- FALSE}', "");
Expect(0, 918000, '\P{Is_CI=- FALSE}', "");
Expect(1, 918000, '\P{^Is_CI=- FALSE}', "");
Expect(0, 917999, '\p{Is_CI=- FALSE}', "");
Expect(1, 917999, '\p{^Is_CI=- FALSE}', "");
Expect(1, 917999, '\P{Is_CI=- FALSE}', "");
Expect(0, 917999, '\P{^Is_CI=- FALSE}', "");
Error('\p{Case_Ignorable=:= Yes}');
Error('\P{Case_Ignorable=:= Yes}');
Expect(1, 917999, '\p{Case_Ignorable:yes}', "");
Expect(0, 917999, '\p{^Case_Ignorable:yes}', "");
Expect(0, 917999, '\P{Case_Ignorable:yes}', "");
Expect(1, 917999, '\P{^Case_Ignorable:yes}', "");
Expect(0, 918000, '\p{Case_Ignorable:yes}', "");
Expect(1, 918000, '\p{^Case_Ignorable:yes}', "");
Expect(1, 918000, '\P{Case_Ignorable:yes}', "");
Expect(0, 918000, '\P{^Case_Ignorable:yes}', "");
Expect(1, 917999, '\p{Case_Ignorable:	_-yes}', "");
Expect(0, 917999, '\p{^Case_Ignorable:	_-yes}', "");
Expect(0, 917999, '\P{Case_Ignorable:	_-yes}', "");
Expect(1, 917999, '\P{^Case_Ignorable:	_-yes}', "");
Expect(0, 918000, '\p{Case_Ignorable:	_-yes}', "");
Expect(1, 918000, '\p{^Case_Ignorable:	_-yes}', "");
Expect(1, 918000, '\P{Case_Ignorable:	_-yes}', "");
Expect(0, 918000, '\P{^Case_Ignorable:	_-yes}', "");
Error('\p{CI:  :=y}');
Error('\P{CI:  :=y}');
Expect(1, 917999, '\p{CI=y}', "");
Expect(0, 917999, '\p{^CI=y}', "");
Expect(0, 917999, '\P{CI=y}', "");
Expect(1, 917999, '\P{^CI=y}', "");
Expect(0, 918000, '\p{CI=y}', "");
Expect(1, 918000, '\p{^CI=y}', "");
Expect(1, 918000, '\P{CI=y}', "");
Expect(0, 918000, '\P{^CI=y}', "");
Expect(1, 917999, '\p{CI=__Y}', "");
Expect(0, 917999, '\p{^CI=__Y}', "");
Expect(0, 917999, '\P{CI=__Y}', "");
Expect(1, 917999, '\P{^CI=__Y}', "");
Expect(0, 918000, '\p{CI=__Y}', "");
Expect(1, 918000, '\p{^CI=__Y}', "");
Expect(1, 918000, '\P{CI=__Y}', "");
Expect(0, 918000, '\P{^CI=__Y}', "");
Error('\p{Is_Case_Ignorable:   -:=T}');
Error('\P{Is_Case_Ignorable:   -:=T}');
Expect(1, 917999, '\p{Is_Case_Ignorable=t}', "");
Expect(0, 917999, '\p{^Is_Case_Ignorable=t}', "");
Expect(0, 917999, '\P{Is_Case_Ignorable=t}', "");
Expect(1, 917999, '\P{^Is_Case_Ignorable=t}', "");
Expect(0, 918000, '\p{Is_Case_Ignorable=t}', "");
Expect(1, 918000, '\p{^Is_Case_Ignorable=t}', "");
Expect(1, 918000, '\P{Is_Case_Ignorable=t}', "");
Expect(0, 918000, '\P{^Is_Case_Ignorable=t}', "");
Expect(1, 917999, '\p{Is_Case_Ignorable= T}', "");
Expect(0, 917999, '\p{^Is_Case_Ignorable= T}', "");
Expect(0, 917999, '\P{Is_Case_Ignorable= T}', "");
Expect(1, 917999, '\P{^Is_Case_Ignorable= T}', "");
Expect(0, 918000, '\p{Is_Case_Ignorable= T}', "");
Expect(1, 918000, '\p{^Is_Case_Ignorable= T}', "");
Expect(1, 918000, '\P{Is_Case_Ignorable= T}', "");
Expect(0, 918000, '\P{^Is_Case_Ignorable= T}', "");
Error('\p{Is_CI=/a/TRUE}');
Error('\P{Is_CI=/a/TRUE}');
Expect(1, 917999, '\p{Is_CI:	true}', "");
Expect(0, 917999, '\p{^Is_CI:	true}', "");
Expect(0, 917999, '\P{Is_CI:	true}', "");
Expect(1, 917999, '\P{^Is_CI:	true}', "");
Expect(0, 918000, '\p{Is_CI:	true}', "");
Expect(1, 918000, '\p{^Is_CI:	true}', "");
Expect(1, 918000, '\P{Is_CI:	true}', "");
Expect(0, 918000, '\P{^Is_CI:	true}', "");
Expect(1, 917999, '\p{Is_CI= -True}', "");
Expect(0, 917999, '\p{^Is_CI= -True}', "");
Expect(0, 917999, '\P{Is_CI= -True}', "");
Expect(1, 917999, '\P{^Is_CI= -True}', "");
Expect(0, 918000, '\p{Is_CI= -True}', "");
Expect(1, 918000, '\p{^Is_CI= -True}', "");
Expect(1, 918000, '\P{Is_CI= -True}', "");
Expect(0, 918000, '\P{^Is_CI= -True}', "");
Error('\p{Changes_When_Casefolded=:=_	no}');
Error('\P{Changes_When_Casefolded=:=_	no}');
Expect(1, 66600, '\p{Changes_When_Casefolded=no}', "");
Expect(0, 66600, '\p{^Changes_When_Casefolded=no}', "");
Expect(0, 66600, '\P{Changes_When_Casefolded=no}', "");
Expect(1, 66600, '\P{^Changes_When_Casefolded=no}', "");
Expect(0, 66599, '\p{Changes_When_Casefolded=no}', "");
Expect(1, 66599, '\p{^Changes_When_Casefolded=no}', "");
Expect(1, 66599, '\P{Changes_When_Casefolded=no}', "");
Expect(0, 66599, '\P{^Changes_When_Casefolded=no}', "");
Expect(1, 66600, '\p{Changes_When_Casefolded:--No}', "");
Expect(0, 66600, '\p{^Changes_When_Casefolded:--No}', "");
Expect(0, 66600, '\P{Changes_When_Casefolded:--No}', "");
Expect(1, 66600, '\P{^Changes_When_Casefolded:--No}', "");
Expect(0, 66599, '\p{Changes_When_Casefolded:--No}', "");
Expect(1, 66599, '\p{^Changes_When_Casefolded:--No}', "");
Expect(1, 66599, '\P{Changes_When_Casefolded:--No}', "");
Expect(0, 66599, '\P{^Changes_When_Casefolded:--No}', "");
Error('\p{CWCF=_/a/N}');
Error('\P{CWCF=_/a/N}');
Expect(1, 66600, '\p{CWCF=n}', "");
Expect(0, 66600, '\p{^CWCF=n}', "");
Expect(0, 66600, '\P{CWCF=n}', "");
Expect(1, 66600, '\P{^CWCF=n}', "");
Expect(0, 66599, '\p{CWCF=n}', "");
Expect(1, 66599, '\p{^CWCF=n}', "");
Expect(1, 66599, '\P{CWCF=n}', "");
Expect(0, 66599, '\P{^CWCF=n}', "");
Expect(1, 66600, '\p{CWCF:   N}', "");
Expect(0, 66600, '\p{^CWCF:   N}', "");
Expect(0, 66600, '\P{CWCF:   N}', "");
Expect(1, 66600, '\P{^CWCF:   N}', "");
Expect(0, 66599, '\p{CWCF:   N}', "");
Expect(1, 66599, '\p{^CWCF:   N}', "");
Expect(1, 66599, '\P{CWCF:   N}', "");
Expect(0, 66599, '\P{^CWCF:   N}', "");
Error('\p{Is_Changes_When_Casefolded=	/a/F}');
Error('\P{Is_Changes_When_Casefolded=	/a/F}');
Expect(1, 66600, '\p{Is_Changes_When_Casefolded=f}', "");
Expect(0, 66600, '\p{^Is_Changes_When_Casefolded=f}', "");
Expect(0, 66600, '\P{Is_Changes_When_Casefolded=f}', "");
Expect(1, 66600, '\P{^Is_Changes_When_Casefolded=f}', "");
Expect(0, 66599, '\p{Is_Changes_When_Casefolded=f}', "");
Expect(1, 66599, '\p{^Is_Changes_When_Casefolded=f}', "");
Expect(1, 66599, '\P{Is_Changes_When_Casefolded=f}', "");
Expect(0, 66599, '\P{^Is_Changes_When_Casefolded=f}', "");
Expect(1, 66600, '\p{Is_Changes_When_Casefolded= -f}', "");
Expect(0, 66600, '\p{^Is_Changes_When_Casefolded= -f}', "");
Expect(0, 66600, '\P{Is_Changes_When_Casefolded= -f}', "");
Expect(1, 66600, '\P{^Is_Changes_When_Casefolded= -f}', "");
Expect(0, 66599, '\p{Is_Changes_When_Casefolded= -f}', "");
Expect(1, 66599, '\p{^Is_Changes_When_Casefolded= -f}', "");
Expect(1, 66599, '\P{Is_Changes_When_Casefolded= -f}', "");
Expect(0, 66599, '\P{^Is_Changes_When_Casefolded= -f}', "");
Error('\p{Is_CWCF= :=False}');
Error('\P{Is_CWCF= :=False}');
Expect(1, 66600, '\p{Is_CWCF=false}', "");
Expect(0, 66600, '\p{^Is_CWCF=false}', "");
Expect(0, 66600, '\P{Is_CWCF=false}', "");
Expect(1, 66600, '\P{^Is_CWCF=false}', "");
Expect(0, 66599, '\p{Is_CWCF=false}', "");
Expect(1, 66599, '\p{^Is_CWCF=false}', "");
Expect(1, 66599, '\P{Is_CWCF=false}', "");
Expect(0, 66599, '\P{^Is_CWCF=false}', "");
Expect(1, 66600, '\p{Is_CWCF=	_false}', "");
Expect(0, 66600, '\p{^Is_CWCF=	_false}', "");
Expect(0, 66600, '\P{Is_CWCF=	_false}', "");
Expect(1, 66600, '\P{^Is_CWCF=	_false}', "");
Expect(0, 66599, '\p{Is_CWCF=	_false}', "");
Expect(1, 66599, '\p{^Is_CWCF=	_false}', "");
Expect(1, 66599, '\P{Is_CWCF=	_false}', "");
Expect(0, 66599, '\P{^Is_CWCF=	_false}', "");
Error('\p{Changes_When_Casefolded= -Yes:=}');
Error('\P{Changes_When_Casefolded= -Yes:=}');
Expect(1, 66599, '\p{Changes_When_Casefolded=yes}', "");
Expect(0, 66599, '\p{^Changes_When_Casefolded=yes}', "");
Expect(0, 66599, '\P{Changes_When_Casefolded=yes}', "");
Expect(1, 66599, '\P{^Changes_When_Casefolded=yes}', "");
Expect(0, 66600, '\p{Changes_When_Casefolded=yes}', "");
Expect(1, 66600, '\p{^Changes_When_Casefolded=yes}', "");
Expect(1, 66600, '\P{Changes_When_Casefolded=yes}', "");
Expect(0, 66600, '\P{^Changes_When_Casefolded=yes}', "");
Expect(1, 66599, '\p{Changes_When_Casefolded=_Yes}', "");
Expect(0, 66599, '\p{^Changes_When_Casefolded=_Yes}', "");
Expect(0, 66599, '\P{Changes_When_Casefolded=_Yes}', "");
Expect(1, 66599, '\P{^Changes_When_Casefolded=_Yes}', "");
Expect(0, 66600, '\p{Changes_When_Casefolded=_Yes}', "");
Expect(1, 66600, '\p{^Changes_When_Casefolded=_Yes}', "");
Expect(1, 66600, '\P{Changes_When_Casefolded=_Yes}', "");
Expect(0, 66600, '\P{^Changes_When_Casefolded=_Yes}', "");
Error('\p{CWCF=/a/ 	Y}');
Error('\P{CWCF=/a/ 	Y}');
Expect(1, 66599, '\p{CWCF:y}', "");
Expect(0, 66599, '\p{^CWCF:y}', "");
Expect(0, 66599, '\P{CWCF:y}', "");
Expect(1, 66599, '\P{^CWCF:y}', "");
Expect(0, 66600, '\p{CWCF:y}', "");
Expect(1, 66600, '\p{^CWCF:y}', "");
Expect(1, 66600, '\P{CWCF:y}', "");
Expect(0, 66600, '\P{^CWCF:y}', "");
Expect(1, 66599, '\p{CWCF=-y}', "");
Expect(0, 66599, '\p{^CWCF=-y}', "");
Expect(0, 66599, '\P{CWCF=-y}', "");
Expect(1, 66599, '\P{^CWCF=-y}', "");
Expect(0, 66600, '\p{CWCF=-y}', "");
Expect(1, 66600, '\p{^CWCF=-y}', "");
Expect(1, 66600, '\P{CWCF=-y}', "");
Expect(0, 66600, '\P{^CWCF=-y}', "");
Error('\p{Is_Changes_When_Casefolded= :=T}');
Error('\P{Is_Changes_When_Casefolded= :=T}');
Expect(1, 66599, '\p{Is_Changes_When_Casefolded:   t}', "");
Expect(0, 66599, '\p{^Is_Changes_When_Casefolded:   t}', "");
Expect(0, 66599, '\P{Is_Changes_When_Casefolded:   t}', "");
Expect(1, 66599, '\P{^Is_Changes_When_Casefolded:   t}', "");
Expect(0, 66600, '\p{Is_Changes_When_Casefolded:   t}', "");
Expect(1, 66600, '\p{^Is_Changes_When_Casefolded:   t}', "");
Expect(1, 66600, '\P{Is_Changes_When_Casefolded:   t}', "");
Expect(0, 66600, '\P{^Is_Changes_When_Casefolded:   t}', "");
Expect(1, 66599, '\p{Is_Changes_When_Casefolded=_-T}', "");
Expect(0, 66599, '\p{^Is_Changes_When_Casefolded=_-T}', "");
Expect(0, 66599, '\P{Is_Changes_When_Casefolded=_-T}', "");
Expect(1, 66599, '\P{^Is_Changes_When_Casefolded=_-T}', "");
Expect(0, 66600, '\p{Is_Changes_When_Casefolded=_-T}', "");
Expect(1, 66600, '\p{^Is_Changes_When_Casefolded=_-T}', "");
Expect(1, 66600, '\P{Is_Changes_When_Casefolded=_-T}', "");
Expect(0, 66600, '\P{^Is_Changes_When_Casefolded=_-T}', "");
Error('\p{Is_CWCF=TRUE/a/}');
Error('\P{Is_CWCF=TRUE/a/}');
Expect(1, 66599, '\p{Is_CWCF=true}', "");
Expect(0, 66599, '\p{^Is_CWCF=true}', "");
Expect(0, 66599, '\P{Is_CWCF=true}', "");
Expect(1, 66599, '\P{^Is_CWCF=true}', "");
Expect(0, 66600, '\p{Is_CWCF=true}', "");
Expect(1, 66600, '\p{^Is_CWCF=true}', "");
Expect(1, 66600, '\P{Is_CWCF=true}', "");
Expect(0, 66600, '\P{^Is_CWCF=true}', "");
Expect(1, 66599, '\p{Is_CWCF=-True}', "");
Expect(0, 66599, '\p{^Is_CWCF=-True}', "");
Expect(0, 66599, '\P{Is_CWCF=-True}', "");
Expect(1, 66599, '\P{^Is_CWCF=-True}', "");
Expect(0, 66600, '\p{Is_CWCF=-True}', "");
Expect(1, 66600, '\p{^Is_CWCF=-True}', "");
Expect(1, 66600, '\P{Is_CWCF=-True}', "");
Expect(0, 66600, '\P{^Is_CWCF=-True}', "");
Error('\p{Changes_When_Casemapped= /a/No}');
Error('\P{Changes_When_Casemapped= /a/No}');
Expect(1, 66640, '\p{Changes_When_Casemapped=no}', "");
Expect(0, 66640, '\p{^Changes_When_Casemapped=no}', "");
Expect(0, 66640, '\P{Changes_When_Casemapped=no}', "");
Expect(1, 66640, '\P{^Changes_When_Casemapped=no}', "");
Expect(0, 66639, '\p{Changes_When_Casemapped=no}', "");
Expect(1, 66639, '\p{^Changes_When_Casemapped=no}', "");
Expect(1, 66639, '\P{Changes_When_Casemapped=no}', "");
Expect(0, 66639, '\P{^Changes_When_Casemapped=no}', "");
Expect(1, 66640, '\p{Changes_When_Casemapped=	-no}', "");
Expect(0, 66640, '\p{^Changes_When_Casemapped=	-no}', "");
Expect(0, 66640, '\P{Changes_When_Casemapped=	-no}', "");
Expect(1, 66640, '\P{^Changes_When_Casemapped=	-no}', "");
Expect(0, 66639, '\p{Changes_When_Casemapped=	-no}', "");
Expect(1, 66639, '\p{^Changes_When_Casemapped=	-no}', "");
Expect(1, 66639, '\P{Changes_When_Casemapped=	-no}', "");
Expect(0, 66639, '\P{^Changes_When_Casemapped=	-no}', "");
Error('\p{CWCM:-N/a/}');
Error('\P{CWCM:-N/a/}');
Expect(1, 66640, '\p{CWCM=n}', "");
Expect(0, 66640, '\p{^CWCM=n}', "");
Expect(0, 66640, '\P{CWCM=n}', "");
Expect(1, 66640, '\P{^CWCM=n}', "");
Expect(0, 66639, '\p{CWCM=n}', "");
Expect(1, 66639, '\p{^CWCM=n}', "");
Expect(1, 66639, '\P{CWCM=n}', "");
Expect(0, 66639, '\P{^CWCM=n}', "");
Expect(1, 66640, '\p{CWCM=_	n}', "");
Expect(0, 66640, '\p{^CWCM=_	n}', "");
Expect(0, 66640, '\P{CWCM=_	n}', "");
Expect(1, 66640, '\P{^CWCM=_	n}', "");
Expect(0, 66639, '\p{CWCM=_	n}', "");
Expect(1, 66639, '\p{^CWCM=_	n}', "");
Expect(1, 66639, '\P{CWCM=_	n}', "");
Expect(0, 66639, '\P{^CWCM=_	n}', "");
Error('\p{Is_Changes_When_Casemapped=/a/-F}');
Error('\P{Is_Changes_When_Casemapped=/a/-F}');
Expect(1, 66640, '\p{Is_Changes_When_Casemapped=f}', "");
Expect(0, 66640, '\p{^Is_Changes_When_Casemapped=f}', "");
Expect(0, 66640, '\P{Is_Changes_When_Casemapped=f}', "");
Expect(1, 66640, '\P{^Is_Changes_When_Casemapped=f}', "");
Expect(0, 66639, '\p{Is_Changes_When_Casemapped=f}', "");
Expect(1, 66639, '\p{^Is_Changes_When_Casemapped=f}', "");
Expect(1, 66639, '\P{Is_Changes_When_Casemapped=f}', "");
Expect(0, 66639, '\P{^Is_Changes_When_Casemapped=f}', "");
Expect(1, 66640, '\p{Is_Changes_When_Casemapped=--F}', "");
Expect(0, 66640, '\p{^Is_Changes_When_Casemapped=--F}', "");
Expect(0, 66640, '\P{Is_Changes_When_Casemapped=--F}', "");
Expect(1, 66640, '\P{^Is_Changes_When_Casemapped=--F}', "");
Expect(0, 66639, '\p{Is_Changes_When_Casemapped=--F}', "");
Expect(1, 66639, '\p{^Is_Changes_When_Casemapped=--F}', "");
Expect(1, 66639, '\P{Is_Changes_When_Casemapped=--F}', "");
Expect(0, 66639, '\P{^Is_Changes_When_Casemapped=--F}', "");
Error('\p{Is_CWCM=	/a/False}');
Error('\P{Is_CWCM=	/a/False}');
Expect(1, 66640, '\p{Is_CWCM=false}', "");
Expect(0, 66640, '\p{^Is_CWCM=false}', "");
Expect(0, 66640, '\P{Is_CWCM=false}', "");
Expect(1, 66640, '\P{^Is_CWCM=false}', "");
Expect(0, 66639, '\p{Is_CWCM=false}', "");
Expect(1, 66639, '\p{^Is_CWCM=false}', "");
Expect(1, 66639, '\P{Is_CWCM=false}', "");
Expect(0, 66639, '\P{^Is_CWCM=false}', "");
Expect(1, 66640, '\p{Is_CWCM=-_false}', "");
Expect(0, 66640, '\p{^Is_CWCM=-_false}', "");
Expect(0, 66640, '\P{Is_CWCM=-_false}', "");
Expect(1, 66640, '\P{^Is_CWCM=-_false}', "");
Expect(0, 66639, '\p{Is_CWCM=-_false}', "");
Expect(1, 66639, '\p{^Is_CWCM=-_false}', "");
Expect(1, 66639, '\P{Is_CWCM=-_false}', "");
Expect(0, 66639, '\P{^Is_CWCM=-_false}', "");
Error('\p{Changes_When_Casemapped=_/a/YES}');
Error('\P{Changes_When_Casemapped=_/a/YES}');
Expect(1, 66639, '\p{Changes_When_Casemapped=yes}', "");
Expect(0, 66639, '\p{^Changes_When_Casemapped=yes}', "");
Expect(0, 66639, '\P{Changes_When_Casemapped=yes}', "");
Expect(1, 66639, '\P{^Changes_When_Casemapped=yes}', "");
Expect(0, 66640, '\p{Changes_When_Casemapped=yes}', "");
Expect(1, 66640, '\p{^Changes_When_Casemapped=yes}', "");
Expect(1, 66640, '\P{Changes_When_Casemapped=yes}', "");
Expect(0, 66640, '\P{^Changes_When_Casemapped=yes}', "");
Expect(1, 66639, '\p{Changes_When_Casemapped=-	yes}', "");
Expect(0, 66639, '\p{^Changes_When_Casemapped=-	yes}', "");
Expect(0, 66639, '\P{Changes_When_Casemapped=-	yes}', "");
Expect(1, 66639, '\P{^Changes_When_Casemapped=-	yes}', "");
Expect(0, 66640, '\p{Changes_When_Casemapped=-	yes}', "");
Expect(1, 66640, '\p{^Changes_When_Casemapped=-	yes}', "");
Expect(1, 66640, '\P{Changes_When_Casemapped=-	yes}', "");
Expect(0, 66640, '\P{^Changes_When_Casemapped=-	yes}', "");
Error('\p{CWCM=-:=Y}');
Error('\P{CWCM=-:=Y}');
Expect(1, 66639, '\p{CWCM=y}', "");
Expect(0, 66639, '\p{^CWCM=y}', "");
Expect(0, 66639, '\P{CWCM=y}', "");
Expect(1, 66639, '\P{^CWCM=y}', "");
Expect(0, 66640, '\p{CWCM=y}', "");
Expect(1, 66640, '\p{^CWCM=y}', "");
Expect(1, 66640, '\P{CWCM=y}', "");
Expect(0, 66640, '\P{^CWCM=y}', "");
Expect(1, 66639, '\p{CWCM=_ Y}', "");
Expect(0, 66639, '\p{^CWCM=_ Y}', "");
Expect(0, 66639, '\P{CWCM=_ Y}', "");
Expect(1, 66639, '\P{^CWCM=_ Y}', "");
Expect(0, 66640, '\p{CWCM=_ Y}', "");
Expect(1, 66640, '\p{^CWCM=_ Y}', "");
Expect(1, 66640, '\P{CWCM=_ Y}', "");
Expect(0, 66640, '\P{^CWCM=_ Y}', "");
Error('\p{Is_Changes_When_Casemapped=	 T/a/}');
Error('\P{Is_Changes_When_Casemapped=	 T/a/}');
Expect(1, 66639, '\p{Is_Changes_When_Casemapped=t}', "");
Expect(0, 66639, '\p{^Is_Changes_When_Casemapped=t}', "");
Expect(0, 66639, '\P{Is_Changes_When_Casemapped=t}', "");
Expect(1, 66639, '\P{^Is_Changes_When_Casemapped=t}', "");
Expect(0, 66640, '\p{Is_Changes_When_Casemapped=t}', "");
Expect(1, 66640, '\p{^Is_Changes_When_Casemapped=t}', "");
Expect(1, 66640, '\P{Is_Changes_When_Casemapped=t}', "");
Expect(0, 66640, '\P{^Is_Changes_When_Casemapped=t}', "");
Expect(1, 66639, '\p{Is_Changes_When_Casemapped:	 t}', "");
Expect(0, 66639, '\p{^Is_Changes_When_Casemapped:	 t}', "");
Expect(0, 66639, '\P{Is_Changes_When_Casemapped:	 t}', "");
Expect(1, 66639, '\P{^Is_Changes_When_Casemapped:	 t}', "");
Expect(0, 66640, '\p{Is_Changes_When_Casemapped:	 t}', "");
Expect(1, 66640, '\p{^Is_Changes_When_Casemapped:	 t}', "");
Expect(1, 66640, '\P{Is_Changes_When_Casemapped:	 t}', "");
Expect(0, 66640, '\P{^Is_Changes_When_Casemapped:	 t}', "");
Error('\p{Is_CWCM=:=True}');
Error('\P{Is_CWCM=:=True}');
Expect(1, 66639, '\p{Is_CWCM=true}', "");
Expect(0, 66639, '\p{^Is_CWCM=true}', "");
Expect(0, 66639, '\P{Is_CWCM=true}', "");
Expect(1, 66639, '\P{^Is_CWCM=true}', "");
Expect(0, 66640, '\p{Is_CWCM=true}', "");
Expect(1, 66640, '\p{^Is_CWCM=true}', "");
Expect(1, 66640, '\P{Is_CWCM=true}', "");
Expect(0, 66640, '\P{^Is_CWCM=true}', "");
Expect(1, 66639, '\p{Is_CWCM=_-TRUE}', "");
Expect(0, 66639, '\p{^Is_CWCM=_-TRUE}', "");
Expect(0, 66639, '\P{Is_CWCM=_-TRUE}', "");
Expect(1, 66639, '\P{^Is_CWCM=_-TRUE}', "");
Expect(0, 66640, '\p{Is_CWCM=_-TRUE}', "");
Expect(1, 66640, '\p{^Is_CWCM=_-TRUE}', "");
Expect(1, 66640, '\P{Is_CWCM=_-TRUE}', "");
Expect(0, 66640, '\P{^Is_CWCM=_-TRUE}', "");
Error('\p{Changes_When_NFKC_Casefolded=-_NO/a/}');
Error('\P{Changes_When_NFKC_Casefolded=-_NO/a/}');
Expect(1, 921600, '\p{Changes_When_NFKC_Casefolded:   no}', "");
Expect(0, 921600, '\p{^Changes_When_NFKC_Casefolded:   no}', "");
Expect(0, 921600, '\P{Changes_When_NFKC_Casefolded:   no}', "");
Expect(1, 921600, '\P{^Changes_When_NFKC_Casefolded:   no}', "");
Expect(0, 921599, '\p{Changes_When_NFKC_Casefolded:   no}', "");
Expect(1, 921599, '\p{^Changes_When_NFKC_Casefolded:   no}', "");
Expect(1, 921599, '\P{Changes_When_NFKC_Casefolded:   no}', "");
Expect(0, 921599, '\P{^Changes_When_NFKC_Casefolded:   no}', "");
Expect(1, 921600, '\p{Changes_When_NFKC_Casefolded=	-no}', "");
Expect(0, 921600, '\p{^Changes_When_NFKC_Casefolded=	-no}', "");
Expect(0, 921600, '\P{Changes_When_NFKC_Casefolded=	-no}', "");
Expect(1, 921600, '\P{^Changes_When_NFKC_Casefolded=	-no}', "");
Expect(0, 921599, '\p{Changes_When_NFKC_Casefolded=	-no}', "");
Expect(1, 921599, '\p{^Changes_When_NFKC_Casefolded=	-no}', "");
Expect(1, 921599, '\P{Changes_When_NFKC_Casefolded=	-no}', "");
Expect(0, 921599, '\P{^Changes_When_NFKC_Casefolded=	-no}', "");
Error('\p{CWKCF=/a/	n}');
Error('\P{CWKCF=/a/	n}');
Expect(1, 921600, '\p{CWKCF=n}', "");
Expect(0, 921600, '\p{^CWKCF=n}', "");
Expect(0, 921600, '\P{CWKCF=n}', "");
Expect(1, 921600, '\P{^CWKCF=n}', "");
Expect(0, 921599, '\p{CWKCF=n}', "");
Expect(1, 921599, '\p{^CWKCF=n}', "");
Expect(1, 921599, '\P{CWKCF=n}', "");
Expect(0, 921599, '\P{^CWKCF=n}', "");
Expect(1, 921600, '\p{CWKCF:   -N}', "");
Expect(0, 921600, '\p{^CWKCF:   -N}', "");
Expect(0, 921600, '\P{CWKCF:   -N}', "");
Expect(1, 921600, '\P{^CWKCF:   -N}', "");
Expect(0, 921599, '\p{CWKCF:   -N}', "");
Expect(1, 921599, '\p{^CWKCF:   -N}', "");
Expect(1, 921599, '\P{CWKCF:   -N}', "");
Expect(0, 921599, '\P{^CWKCF:   -N}', "");
Error('\p{Is_Changes_When_NFKC_Casefolded=/a/  F}');
Error('\P{Is_Changes_When_NFKC_Casefolded=/a/  F}');
Expect(1, 921600, '\p{Is_Changes_When_NFKC_Casefolded=f}', "");
Expect(0, 921600, '\p{^Is_Changes_When_NFKC_Casefolded=f}', "");
Expect(0, 921600, '\P{Is_Changes_When_NFKC_Casefolded=f}', "");
Expect(1, 921600, '\P{^Is_Changes_When_NFKC_Casefolded=f}', "");
Expect(0, 921599, '\p{Is_Changes_When_NFKC_Casefolded=f}', "");
Expect(1, 921599, '\p{^Is_Changes_When_NFKC_Casefolded=f}', "");
Expect(1, 921599, '\P{Is_Changes_When_NFKC_Casefolded=f}', "");
Expect(0, 921599, '\P{^Is_Changes_When_NFKC_Casefolded=f}', "");
Expect(1, 921600, '\p{Is_Changes_When_NFKC_Casefolded:    	f}', "");
Expect(0, 921600, '\p{^Is_Changes_When_NFKC_Casefolded:    	f}', "");
Expect(0, 921600, '\P{Is_Changes_When_NFKC_Casefolded:    	f}', "");
Expect(1, 921600, '\P{^Is_Changes_When_NFKC_Casefolded:    	f}', "");
Expect(0, 921599, '\p{Is_Changes_When_NFKC_Casefolded:    	f}', "");
Expect(1, 921599, '\p{^Is_Changes_When_NFKC_Casefolded:    	f}', "");
Expect(1, 921599, '\P{Is_Changes_When_NFKC_Casefolded:    	f}', "");
Expect(0, 921599, '\P{^Is_Changes_When_NFKC_Casefolded:    	f}', "");
Error('\p{Is_CWKCF=	 False:=}');
Error('\P{Is_CWKCF=	 False:=}');
Expect(1, 921600, '\p{Is_CWKCF=false}', "");
Expect(0, 921600, '\p{^Is_CWKCF=false}', "");
Expect(0, 921600, '\P{Is_CWKCF=false}', "");
Expect(1, 921600, '\P{^Is_CWKCF=false}', "");
Expect(0, 921599, '\p{Is_CWKCF=false}', "");
Expect(1, 921599, '\p{^Is_CWKCF=false}', "");
Expect(1, 921599, '\P{Is_CWKCF=false}', "");
Expect(0, 921599, '\P{^Is_CWKCF=false}', "");
Expect(1, 921600, '\p{Is_CWKCF=_-FALSE}', "");
Expect(0, 921600, '\p{^Is_CWKCF=_-FALSE}', "");
Expect(0, 921600, '\P{Is_CWKCF=_-FALSE}', "");
Expect(1, 921600, '\P{^Is_CWKCF=_-FALSE}', "");
Expect(0, 921599, '\p{Is_CWKCF=_-FALSE}', "");
Expect(1, 921599, '\p{^Is_CWKCF=_-FALSE}', "");
Expect(1, 921599, '\P{Is_CWKCF=_-FALSE}', "");
Expect(0, 921599, '\P{^Is_CWKCF=_-FALSE}', "");
Error('\p{Changes_When_NFKC_Casefolded=/a/		Yes}');
Error('\P{Changes_When_NFKC_Casefolded=/a/		Yes}');
Expect(1, 921599, '\p{Changes_When_NFKC_Casefolded=yes}', "");
Expect(0, 921599, '\p{^Changes_When_NFKC_Casefolded=yes}', "");
Expect(0, 921599, '\P{Changes_When_NFKC_Casefolded=yes}', "");
Expect(1, 921599, '\P{^Changes_When_NFKC_Casefolded=yes}', "");
Expect(0, 921600, '\p{Changes_When_NFKC_Casefolded=yes}', "");
Expect(1, 921600, '\p{^Changes_When_NFKC_Casefolded=yes}', "");
Expect(1, 921600, '\P{Changes_When_NFKC_Casefolded=yes}', "");
Expect(0, 921600, '\P{^Changes_When_NFKC_Casefolded=yes}', "");
Expect(1, 921599, '\p{Changes_When_NFKC_Casefolded=	-yes}', "");
Expect(0, 921599, '\p{^Changes_When_NFKC_Casefolded=	-yes}', "");
Expect(0, 921599, '\P{Changes_When_NFKC_Casefolded=	-yes}', "");
Expect(1, 921599, '\P{^Changes_When_NFKC_Casefolded=	-yes}', "");
Expect(0, 921600, '\p{Changes_When_NFKC_Casefolded=	-yes}', "");
Expect(1, 921600, '\p{^Changes_When_NFKC_Casefolded=	-yes}', "");
Expect(1, 921600, '\P{Changes_When_NFKC_Casefolded=	-yes}', "");
Expect(0, 921600, '\P{^Changes_When_NFKC_Casefolded=	-yes}', "");
Error('\p{CWKCF=		Y:=}');
Error('\P{CWKCF=		Y:=}');
Expect(1, 921599, '\p{CWKCF=y}', "");
Expect(0, 921599, '\p{^CWKCF=y}', "");
Expect(0, 921599, '\P{CWKCF=y}', "");
Expect(1, 921599, '\P{^CWKCF=y}', "");
Expect(0, 921600, '\p{CWKCF=y}', "");
Expect(1, 921600, '\p{^CWKCF=y}', "");
Expect(1, 921600, '\P{CWKCF=y}', "");
Expect(0, 921600, '\P{^CWKCF=y}', "");
Expect(1, 921599, '\p{CWKCF=-Y}', "");
Expect(0, 921599, '\p{^CWKCF=-Y}', "");
Expect(0, 921599, '\P{CWKCF=-Y}', "");
Expect(1, 921599, '\P{^CWKCF=-Y}', "");
Expect(0, 921600, '\p{CWKCF=-Y}', "");
Expect(1, 921600, '\p{^CWKCF=-Y}', "");
Expect(1, 921600, '\P{CWKCF=-Y}', "");
Expect(0, 921600, '\P{^CWKCF=-Y}', "");
Error('\p{Is_Changes_When_NFKC_Casefolded= 	t:=}');
Error('\P{Is_Changes_When_NFKC_Casefolded= 	t:=}');
Expect(1, 921599, '\p{Is_Changes_When_NFKC_Casefolded=t}', "");
Expect(0, 921599, '\p{^Is_Changes_When_NFKC_Casefolded=t}', "");
Expect(0, 921599, '\P{Is_Changes_When_NFKC_Casefolded=t}', "");
Expect(1, 921599, '\P{^Is_Changes_When_NFKC_Casefolded=t}', "");
Expect(0, 921600, '\p{Is_Changes_When_NFKC_Casefolded=t}', "");
Expect(1, 921600, '\p{^Is_Changes_When_NFKC_Casefolded=t}', "");
Expect(1, 921600, '\P{Is_Changes_When_NFKC_Casefolded=t}', "");
Expect(0, 921600, '\P{^Is_Changes_When_NFKC_Casefolded=t}', "");
Expect(1, 921599, '\p{Is_Changes_When_NFKC_Casefolded= _T}', "");
Expect(0, 921599, '\p{^Is_Changes_When_NFKC_Casefolded= _T}', "");
Expect(0, 921599, '\P{Is_Changes_When_NFKC_Casefolded= _T}', "");
Expect(1, 921599, '\P{^Is_Changes_When_NFKC_Casefolded= _T}', "");
Expect(0, 921600, '\p{Is_Changes_When_NFKC_Casefolded= _T}', "");
Expect(1, 921600, '\p{^Is_Changes_When_NFKC_Casefolded= _T}', "");
Expect(1, 921600, '\P{Is_Changes_When_NFKC_Casefolded= _T}', "");
Expect(0, 921600, '\P{^Is_Changes_When_NFKC_Casefolded= _T}', "");
Error('\p{Is_CWKCF=:=	true}');
Error('\P{Is_CWKCF=:=	true}');
Expect(1, 921599, '\p{Is_CWKCF=true}', "");
Expect(0, 921599, '\p{^Is_CWKCF=true}', "");
Expect(0, 921599, '\P{Is_CWKCF=true}', "");
Expect(1, 921599, '\P{^Is_CWKCF=true}', "");
Expect(0, 921600, '\p{Is_CWKCF=true}', "");
Expect(1, 921600, '\p{^Is_CWKCF=true}', "");
Expect(1, 921600, '\P{Is_CWKCF=true}', "");
Expect(0, 921600, '\P{^Is_CWKCF=true}', "");
Expect(1, 921599, '\p{Is_CWKCF=- True}', "");
Expect(0, 921599, '\p{^Is_CWKCF=- True}', "");
Expect(0, 921599, '\P{Is_CWKCF=- True}', "");
Expect(1, 921599, '\P{^Is_CWKCF=- True}', "");
Expect(0, 921600, '\p{Is_CWKCF=- True}', "");
Expect(1, 921600, '\p{^Is_CWKCF=- True}', "");
Expect(1, 921600, '\P{Is_CWKCF=- True}', "");
Expect(0, 921600, '\P{^Is_CWKCF=- True}', "");
Error('\p{Changes_When_Lowercased=_No/a/}');
Error('\P{Changes_When_Lowercased=_No/a/}');
Expect(1, 66600, '\p{Changes_When_Lowercased=no}', "");
Expect(0, 66600, '\p{^Changes_When_Lowercased=no}', "");
Expect(0, 66600, '\P{Changes_When_Lowercased=no}', "");
Expect(1, 66600, '\P{^Changes_When_Lowercased=no}', "");
Expect(0, 66599, '\p{Changes_When_Lowercased=no}', "");
Expect(1, 66599, '\p{^Changes_When_Lowercased=no}', "");
Expect(1, 66599, '\P{Changes_When_Lowercased=no}', "");
Expect(0, 66599, '\P{^Changes_When_Lowercased=no}', "");
Expect(1, 66600, '\p{Changes_When_Lowercased=-	No}', "");
Expect(0, 66600, '\p{^Changes_When_Lowercased=-	No}', "");
Expect(0, 66600, '\P{Changes_When_Lowercased=-	No}', "");
Expect(1, 66600, '\P{^Changes_When_Lowercased=-	No}', "");
Expect(0, 66599, '\p{Changes_When_Lowercased=-	No}', "");
Expect(1, 66599, '\p{^Changes_When_Lowercased=-	No}', "");
Expect(1, 66599, '\P{Changes_When_Lowercased=-	No}', "");
Expect(0, 66599, '\P{^Changes_When_Lowercased=-	No}', "");
Error('\p{CWL=-/a/N}');
Error('\P{CWL=-/a/N}');
Expect(1, 66600, '\p{CWL=n}', "");
Expect(0, 66600, '\p{^CWL=n}', "");
Expect(0, 66600, '\P{CWL=n}', "");
Expect(1, 66600, '\P{^CWL=n}', "");
Expect(0, 66599, '\p{CWL=n}', "");
Expect(1, 66599, '\p{^CWL=n}', "");
Expect(1, 66599, '\P{CWL=n}', "");
Expect(0, 66599, '\P{^CWL=n}', "");
Expect(1, 66600, '\p{CWL:	_N}', "");
Expect(0, 66600, '\p{^CWL:	_N}', "");
Expect(0, 66600, '\P{CWL:	_N}', "");
Expect(1, 66600, '\P{^CWL:	_N}', "");
Expect(0, 66599, '\p{CWL:	_N}', "");
Expect(1, 66599, '\p{^CWL:	_N}', "");
Expect(1, 66599, '\P{CWL:	_N}', "");
Expect(0, 66599, '\P{^CWL:	_N}', "");
Error('\p{Is_Changes_When_Lowercased=/a/f}');
Error('\P{Is_Changes_When_Lowercased=/a/f}');
Expect(1, 66600, '\p{Is_Changes_When_Lowercased:	f}', "");
Expect(0, 66600, '\p{^Is_Changes_When_Lowercased:	f}', "");
Expect(0, 66600, '\P{Is_Changes_When_Lowercased:	f}', "");
Expect(1, 66600, '\P{^Is_Changes_When_Lowercased:	f}', "");
Expect(0, 66599, '\p{Is_Changes_When_Lowercased:	f}', "");
Expect(1, 66599, '\p{^Is_Changes_When_Lowercased:	f}', "");
Expect(1, 66599, '\P{Is_Changes_When_Lowercased:	f}', "");
Expect(0, 66599, '\P{^Is_Changes_When_Lowercased:	f}', "");
Expect(1, 66600, '\p{Is_Changes_When_Lowercased=_-F}', "");
Expect(0, 66600, '\p{^Is_Changes_When_Lowercased=_-F}', "");
Expect(0, 66600, '\P{Is_Changes_When_Lowercased=_-F}', "");
Expect(1, 66600, '\P{^Is_Changes_When_Lowercased=_-F}', "");
Expect(0, 66599, '\p{Is_Changes_When_Lowercased=_-F}', "");
Expect(1, 66599, '\p{^Is_Changes_When_Lowercased=_-F}', "");
Expect(1, 66599, '\P{Is_Changes_When_Lowercased=_-F}', "");
Expect(0, 66599, '\P{^Is_Changes_When_Lowercased=_-F}', "");
Error('\p{Is_CWL=_-False:=}');
Error('\P{Is_CWL=_-False:=}');
Expect(1, 66600, '\p{Is_CWL=false}', "");
Expect(0, 66600, '\p{^Is_CWL=false}', "");
Expect(0, 66600, '\P{Is_CWL=false}', "");
Expect(1, 66600, '\P{^Is_CWL=false}', "");
Expect(0, 66599, '\p{Is_CWL=false}', "");
Expect(1, 66599, '\p{^Is_CWL=false}', "");
Expect(1, 66599, '\P{Is_CWL=false}', "");
Expect(0, 66599, '\P{^Is_CWL=false}', "");
Expect(1, 66600, '\p{Is_CWL=  false}', "");
Expect(0, 66600, '\p{^Is_CWL=  false}', "");
Expect(0, 66600, '\P{Is_CWL=  false}', "");
Expect(1, 66600, '\P{^Is_CWL=  false}', "");
Expect(0, 66599, '\p{Is_CWL=  false}', "");
Expect(1, 66599, '\p{^Is_CWL=  false}', "");
Expect(1, 66599, '\P{Is_CWL=  false}', "");
Expect(0, 66599, '\P{^Is_CWL=  false}', "");
Error('\p{Changes_When_Lowercased=_	Yes:=}');
Error('\P{Changes_When_Lowercased=_	Yes:=}');
Expect(1, 66599, '\p{Changes_When_Lowercased=yes}', "");
Expect(0, 66599, '\p{^Changes_When_Lowercased=yes}', "");
Expect(0, 66599, '\P{Changes_When_Lowercased=yes}', "");
Expect(1, 66599, '\P{^Changes_When_Lowercased=yes}', "");
Expect(0, 66600, '\p{Changes_When_Lowercased=yes}', "");
Expect(1, 66600, '\p{^Changes_When_Lowercased=yes}', "");
Expect(1, 66600, '\P{Changes_When_Lowercased=yes}', "");
Expect(0, 66600, '\P{^Changes_When_Lowercased=yes}', "");
Expect(1, 66599, '\p{Changes_When_Lowercased=	Yes}', "");
Expect(0, 66599, '\p{^Changes_When_Lowercased=	Yes}', "");
Expect(0, 66599, '\P{Changes_When_Lowercased=	Yes}', "");
Expect(1, 66599, '\P{^Changes_When_Lowercased=	Yes}', "");
Expect(0, 66600, '\p{Changes_When_Lowercased=	Yes}', "");
Expect(1, 66600, '\p{^Changes_When_Lowercased=	Yes}', "");
Expect(1, 66600, '\P{Changes_When_Lowercased=	Yes}', "");
Expect(0, 66600, '\P{^Changes_When_Lowercased=	Yes}', "");
Error('\p{CWL=	Y/a/}');
Error('\P{CWL=	Y/a/}');
Expect(1, 66599, '\p{CWL=y}', "");
Expect(0, 66599, '\p{^CWL=y}', "");
Expect(0, 66599, '\P{CWL=y}', "");
Expect(1, 66599, '\P{^CWL=y}', "");
Expect(0, 66600, '\p{CWL=y}', "");
Expect(1, 66600, '\p{^CWL=y}', "");
Expect(1, 66600, '\P{CWL=y}', "");
Expect(0, 66600, '\P{^CWL=y}', "");
Expect(1, 66599, '\p{CWL=_	Y}', "");
Expect(0, 66599, '\p{^CWL=_	Y}', "");
Expect(0, 66599, '\P{CWL=_	Y}', "");
Expect(1, 66599, '\P{^CWL=_	Y}', "");
Expect(0, 66600, '\p{CWL=_	Y}', "");
Expect(1, 66600, '\p{^CWL=_	Y}', "");
Expect(1, 66600, '\P{CWL=_	Y}', "");
Expect(0, 66600, '\P{^CWL=_	Y}', "");
Error('\p{Is_Changes_When_Lowercased= /a/T}');
Error('\P{Is_Changes_When_Lowercased= /a/T}');
Expect(1, 66599, '\p{Is_Changes_When_Lowercased=t}', "");
Expect(0, 66599, '\p{^Is_Changes_When_Lowercased=t}', "");
Expect(0, 66599, '\P{Is_Changes_When_Lowercased=t}', "");
Expect(1, 66599, '\P{^Is_Changes_When_Lowercased=t}', "");
Expect(0, 66600, '\p{Is_Changes_When_Lowercased=t}', "");
Expect(1, 66600, '\p{^Is_Changes_When_Lowercased=t}', "");
Expect(1, 66600, '\P{Is_Changes_When_Lowercased=t}', "");
Expect(0, 66600, '\P{^Is_Changes_When_Lowercased=t}', "");
Expect(1, 66599, '\p{Is_Changes_When_Lowercased=- T}', "");
Expect(0, 66599, '\p{^Is_Changes_When_Lowercased=- T}', "");
Expect(0, 66599, '\P{Is_Changes_When_Lowercased=- T}', "");
Expect(1, 66599, '\P{^Is_Changes_When_Lowercased=- T}', "");
Expect(0, 66600, '\p{Is_Changes_When_Lowercased=- T}', "");
Expect(1, 66600, '\p{^Is_Changes_When_Lowercased=- T}', "");
Expect(1, 66600, '\P{Is_Changes_When_Lowercased=- T}', "");
Expect(0, 66600, '\P{^Is_Changes_When_Lowercased=- T}', "");
Error('\p{Is_CWL:   :=	 True}');
Error('\P{Is_CWL:   :=	 True}');
Expect(1, 66599, '\p{Is_CWL=true}', "");
Expect(0, 66599, '\p{^Is_CWL=true}', "");
Expect(0, 66599, '\P{Is_CWL=true}', "");
Expect(1, 66599, '\P{^Is_CWL=true}', "");
Expect(0, 66600, '\p{Is_CWL=true}', "");
Expect(1, 66600, '\p{^Is_CWL=true}', "");
Expect(1, 66600, '\P{Is_CWL=true}', "");
Expect(0, 66600, '\P{^Is_CWL=true}', "");
Expect(1, 66599, '\p{Is_CWL=-True}', "");
Expect(0, 66599, '\p{^Is_CWL=-True}', "");
Expect(0, 66599, '\P{Is_CWL=-True}', "");
Expect(1, 66599, '\P{^Is_CWL=-True}', "");
Expect(0, 66600, '\p{Is_CWL=-True}', "");
Expect(1, 66600, '\p{^Is_CWL=-True}', "");
Expect(1, 66600, '\P{Is_CWL=-True}', "");
Expect(0, 66600, '\P{^Is_CWL=-True}', "");
Error('\p{Changes_When_Titlecased: -/a/No}');
Error('\P{Changes_When_Titlecased: -/a/No}');
Expect(1, 66640, '\p{Changes_When_Titlecased=no}', "");
Expect(0, 66640, '\p{^Changes_When_Titlecased=no}', "");
Expect(0, 66640, '\P{Changes_When_Titlecased=no}', "");
Expect(1, 66640, '\P{^Changes_When_Titlecased=no}', "");
Expect(0, 66639, '\p{Changes_When_Titlecased=no}', "");
Expect(1, 66639, '\p{^Changes_When_Titlecased=no}', "");
Expect(1, 66639, '\P{Changes_When_Titlecased=no}', "");
Expect(0, 66639, '\P{^Changes_When_Titlecased=no}', "");
Expect(1, 66640, '\p{Changes_When_Titlecased= _No}', "");
Expect(0, 66640, '\p{^Changes_When_Titlecased= _No}', "");
Expect(0, 66640, '\P{Changes_When_Titlecased= _No}', "");
Expect(1, 66640, '\P{^Changes_When_Titlecased= _No}', "");
Expect(0, 66639, '\p{Changes_When_Titlecased= _No}', "");
Expect(1, 66639, '\p{^Changes_When_Titlecased= _No}', "");
Expect(1, 66639, '\P{Changes_When_Titlecased= _No}', "");
Expect(0, 66639, '\P{^Changes_When_Titlecased= _No}', "");
Error('\p{CWT=/a/		N}');
Error('\P{CWT=/a/		N}');
Expect(1, 66640, '\p{CWT=n}', "");
Expect(0, 66640, '\p{^CWT=n}', "");
Expect(0, 66640, '\P{CWT=n}', "");
Expect(1, 66640, '\P{^CWT=n}', "");
Expect(0, 66639, '\p{CWT=n}', "");
Expect(1, 66639, '\p{^CWT=n}', "");
Expect(1, 66639, '\P{CWT=n}', "");
Expect(0, 66639, '\P{^CWT=n}', "");
Expect(1, 66640, '\p{CWT:	_n}', "");
Expect(0, 66640, '\p{^CWT:	_n}', "");
Expect(0, 66640, '\P{CWT:	_n}', "");
Expect(1, 66640, '\P{^CWT:	_n}', "");
Expect(0, 66639, '\p{CWT:	_n}', "");
Expect(1, 66639, '\p{^CWT:	_n}', "");
Expect(1, 66639, '\P{CWT:	_n}', "");
Expect(0, 66639, '\P{^CWT:	_n}', "");
Error('\p{Is_Changes_When_Titlecased=  F/a/}');
Error('\P{Is_Changes_When_Titlecased=  F/a/}');
Expect(1, 66640, '\p{Is_Changes_When_Titlecased=f}', "");
Expect(0, 66640, '\p{^Is_Changes_When_Titlecased=f}', "");
Expect(0, 66640, '\P{Is_Changes_When_Titlecased=f}', "");
Expect(1, 66640, '\P{^Is_Changes_When_Titlecased=f}', "");
Expect(0, 66639, '\p{Is_Changes_When_Titlecased=f}', "");
Expect(1, 66639, '\p{^Is_Changes_When_Titlecased=f}', "");
Expect(1, 66639, '\P{Is_Changes_When_Titlecased=f}', "");
Expect(0, 66639, '\P{^Is_Changes_When_Titlecased=f}', "");
Expect(1, 66640, '\p{Is_Changes_When_Titlecased=	_F}', "");
Expect(0, 66640, '\p{^Is_Changes_When_Titlecased=	_F}', "");
Expect(0, 66640, '\P{Is_Changes_When_Titlecased=	_F}', "");
Expect(1, 66640, '\P{^Is_Changes_When_Titlecased=	_F}', "");
Expect(0, 66639, '\p{Is_Changes_When_Titlecased=	_F}', "");
Expect(1, 66639, '\p{^Is_Changes_When_Titlecased=	_F}', "");
Expect(1, 66639, '\P{Is_Changes_When_Titlecased=	_F}', "");
Expect(0, 66639, '\P{^Is_Changes_When_Titlecased=	_F}', "");
Error('\p{Is_CWT=/a/	 FALSE}');
Error('\P{Is_CWT=/a/	 FALSE}');
Expect(1, 66640, '\p{Is_CWT=false}', "");
Expect(0, 66640, '\p{^Is_CWT=false}', "");
Expect(0, 66640, '\P{Is_CWT=false}', "");
Expect(1, 66640, '\P{^Is_CWT=false}', "");
Expect(0, 66639, '\p{Is_CWT=false}', "");
Expect(1, 66639, '\p{^Is_CWT=false}', "");
Expect(1, 66639, '\P{Is_CWT=false}', "");
Expect(0, 66639, '\P{^Is_CWT=false}', "");
Expect(1, 66640, '\p{Is_CWT=	false}', "");
Expect(0, 66640, '\p{^Is_CWT=	false}', "");
Expect(0, 66640, '\P{Is_CWT=	false}', "");
Expect(1, 66640, '\P{^Is_CWT=	false}', "");
Expect(0, 66639, '\p{Is_CWT=	false}', "");
Expect(1, 66639, '\p{^Is_CWT=	false}', "");
Expect(1, 66639, '\P{Is_CWT=	false}', "");
Expect(0, 66639, '\P{^Is_CWT=	false}', "");
Error('\p{Changes_When_Titlecased=:=	YES}');
Error('\P{Changes_When_Titlecased=:=	YES}');
Expect(1, 66639, '\p{Changes_When_Titlecased=yes}', "");
Expect(0, 66639, '\p{^Changes_When_Titlecased=yes}', "");
Expect(0, 66639, '\P{Changes_When_Titlecased=yes}', "");
Expect(1, 66639, '\P{^Changes_When_Titlecased=yes}', "");
Expect(0, 66640, '\p{Changes_When_Titlecased=yes}', "");
Expect(1, 66640, '\p{^Changes_When_Titlecased=yes}', "");
Expect(1, 66640, '\P{Changes_When_Titlecased=yes}', "");
Expect(0, 66640, '\P{^Changes_When_Titlecased=yes}', "");
Expect(1, 66639, '\p{Changes_When_Titlecased= 	yes}', "");
Expect(0, 66639, '\p{^Changes_When_Titlecased= 	yes}', "");
Expect(0, 66639, '\P{Changes_When_Titlecased= 	yes}', "");
Expect(1, 66639, '\P{^Changes_When_Titlecased= 	yes}', "");
Expect(0, 66640, '\p{Changes_When_Titlecased= 	yes}', "");
Expect(1, 66640, '\p{^Changes_When_Titlecased= 	yes}', "");
Expect(1, 66640, '\P{Changes_When_Titlecased= 	yes}', "");
Expect(0, 66640, '\P{^Changes_When_Titlecased= 	yes}', "");
Error('\p{CWT=:=Y}');
Error('\P{CWT=:=Y}');
Expect(1, 66639, '\p{CWT=y}', "");
Expect(0, 66639, '\p{^CWT=y}', "");
Expect(0, 66639, '\P{CWT=y}', "");
Expect(1, 66639, '\P{^CWT=y}', "");
Expect(0, 66640, '\p{CWT=y}', "");
Expect(1, 66640, '\p{^CWT=y}', "");
Expect(1, 66640, '\P{CWT=y}', "");
Expect(0, 66640, '\P{^CWT=y}', "");
Expect(1, 66639, '\p{CWT=_ Y}', "");
Expect(0, 66639, '\p{^CWT=_ Y}', "");
Expect(0, 66639, '\P{CWT=_ Y}', "");
Expect(1, 66639, '\P{^CWT=_ Y}', "");
Expect(0, 66640, '\p{CWT=_ Y}', "");
Expect(1, 66640, '\p{^CWT=_ Y}', "");
Expect(1, 66640, '\P{CWT=_ Y}', "");
Expect(0, 66640, '\P{^CWT=_ Y}', "");
Error('\p{Is_Changes_When_Titlecased=/a/_T}');
Error('\P{Is_Changes_When_Titlecased=/a/_T}');
Expect(1, 66639, '\p{Is_Changes_When_Titlecased:   t}', "");
Expect(0, 66639, '\p{^Is_Changes_When_Titlecased:   t}', "");
Expect(0, 66639, '\P{Is_Changes_When_Titlecased:   t}', "");
Expect(1, 66639, '\P{^Is_Changes_When_Titlecased:   t}', "");
Expect(0, 66640, '\p{Is_Changes_When_Titlecased:   t}', "");
Expect(1, 66640, '\p{^Is_Changes_When_Titlecased:   t}', "");
Expect(1, 66640, '\P{Is_Changes_When_Titlecased:   t}', "");
Expect(0, 66640, '\P{^Is_Changes_When_Titlecased:   t}', "");
Expect(1, 66639, '\p{Is_Changes_When_Titlecased=- T}', "");
Expect(0, 66639, '\p{^Is_Changes_When_Titlecased=- T}', "");
Expect(0, 66639, '\P{Is_Changes_When_Titlecased=- T}', "");
Expect(1, 66639, '\P{^Is_Changes_When_Titlecased=- T}', "");
Expect(0, 66640, '\p{Is_Changes_When_Titlecased=- T}', "");
Expect(1, 66640, '\p{^Is_Changes_When_Titlecased=- T}', "");
Expect(1, 66640, '\P{Is_Changes_When_Titlecased=- T}', "");
Expect(0, 66640, '\P{^Is_Changes_When_Titlecased=- T}', "");
Error('\p{Is_CWT:   _-True/a/}');
Error('\P{Is_CWT:   _-True/a/}');
Expect(1, 66639, '\p{Is_CWT=true}', "");
Expect(0, 66639, '\p{^Is_CWT=true}', "");
Expect(0, 66639, '\P{Is_CWT=true}', "");
Expect(1, 66639, '\P{^Is_CWT=true}', "");
Expect(0, 66640, '\p{Is_CWT=true}', "");
Expect(1, 66640, '\p{^Is_CWT=true}', "");
Expect(1, 66640, '\P{Is_CWT=true}', "");
Expect(0, 66640, '\P{^Is_CWT=true}', "");
Expect(1, 66639, '\p{Is_CWT=_true}', "");
Expect(0, 66639, '\p{^Is_CWT=_true}', "");
Expect(0, 66639, '\P{Is_CWT=_true}', "");
Expect(1, 66639, '\P{^Is_CWT=_true}', "");
Expect(0, 66640, '\p{Is_CWT=_true}', "");
Expect(1, 66640, '\p{^Is_CWT=_true}', "");
Expect(1, 66640, '\P{Is_CWT=_true}', "");
Expect(0, 66640, '\P{^Is_CWT=_true}', "");
Error('\p{Changes_When_Uppercased=/a/_NO}');
Error('\P{Changes_When_Uppercased=/a/_NO}');
Expect(1, 66640, '\p{Changes_When_Uppercased=no}', "");
Expect(0, 66640, '\p{^Changes_When_Uppercased=no}', "");
Expect(0, 66640, '\P{Changes_When_Uppercased=no}', "");
Expect(1, 66640, '\P{^Changes_When_Uppercased=no}', "");
Expect(0, 66639, '\p{Changes_When_Uppercased=no}', "");
Expect(1, 66639, '\p{^Changes_When_Uppercased=no}', "");
Expect(1, 66639, '\P{Changes_When_Uppercased=no}', "");
Expect(0, 66639, '\P{^Changes_When_Uppercased=no}', "");
Expect(1, 66640, '\p{Changes_When_Uppercased=-No}', "");
Expect(0, 66640, '\p{^Changes_When_Uppercased=-No}', "");
Expect(0, 66640, '\P{Changes_When_Uppercased=-No}', "");
Expect(1, 66640, '\P{^Changes_When_Uppercased=-No}', "");
Expect(0, 66639, '\p{Changes_When_Uppercased=-No}', "");
Expect(1, 66639, '\p{^Changes_When_Uppercased=-No}', "");
Expect(1, 66639, '\P{Changes_When_Uppercased=-No}', "");
Expect(0, 66639, '\P{^Changes_When_Uppercased=-No}', "");
Error('\p{CWU=-N/a/}');
Error('\P{CWU=-N/a/}');
Expect(1, 66640, '\p{CWU=n}', "");
Expect(0, 66640, '\p{^CWU=n}', "");
Expect(0, 66640, '\P{CWU=n}', "");
Expect(1, 66640, '\P{^CWU=n}', "");
Expect(0, 66639, '\p{CWU=n}', "");
Expect(1, 66639, '\p{^CWU=n}', "");
Expect(1, 66639, '\P{CWU=n}', "");
Expect(0, 66639, '\P{^CWU=n}', "");
Expect(1, 66640, '\p{CWU=_-n}', "");
Expect(0, 66640, '\p{^CWU=_-n}', "");
Expect(0, 66640, '\P{CWU=_-n}', "");
Expect(1, 66640, '\P{^CWU=_-n}', "");
Expect(0, 66639, '\p{CWU=_-n}', "");
Expect(1, 66639, '\p{^CWU=_-n}', "");
Expect(1, 66639, '\P{CWU=_-n}', "");
Expect(0, 66639, '\P{^CWU=_-n}', "");
Error('\p{Is_Changes_When_Uppercased= _F/a/}');
Error('\P{Is_Changes_When_Uppercased= _F/a/}');
Expect(1, 66640, '\p{Is_Changes_When_Uppercased=f}', "");
Expect(0, 66640, '\p{^Is_Changes_When_Uppercased=f}', "");
Expect(0, 66640, '\P{Is_Changes_When_Uppercased=f}', "");
Expect(1, 66640, '\P{^Is_Changes_When_Uppercased=f}', "");
Expect(0, 66639, '\p{Is_Changes_When_Uppercased=f}', "");
Expect(1, 66639, '\p{^Is_Changes_When_Uppercased=f}', "");
Expect(1, 66639, '\P{Is_Changes_When_Uppercased=f}', "");
Expect(0, 66639, '\P{^Is_Changes_When_Uppercased=f}', "");
Expect(1, 66640, '\p{Is_Changes_When_Uppercased=  F}', "");
Expect(0, 66640, '\p{^Is_Changes_When_Uppercased=  F}', "");
Expect(0, 66640, '\P{Is_Changes_When_Uppercased=  F}', "");
Expect(1, 66640, '\P{^Is_Changes_When_Uppercased=  F}', "");
Expect(0, 66639, '\p{Is_Changes_When_Uppercased=  F}', "");
Expect(1, 66639, '\p{^Is_Changes_When_Uppercased=  F}', "");
Expect(1, 66639, '\P{Is_Changes_When_Uppercased=  F}', "");
Expect(0, 66639, '\P{^Is_Changes_When_Uppercased=  F}', "");
Error('\p{Is_CWU=	_False:=}');
Error('\P{Is_CWU=	_False:=}');
Expect(1, 66640, '\p{Is_CWU=false}', "");
Expect(0, 66640, '\p{^Is_CWU=false}', "");
Expect(0, 66640, '\P{Is_CWU=false}', "");
Expect(1, 66640, '\P{^Is_CWU=false}', "");
Expect(0, 66639, '\p{Is_CWU=false}', "");
Expect(1, 66639, '\p{^Is_CWU=false}', "");
Expect(1, 66639, '\P{Is_CWU=false}', "");
Expect(0, 66639, '\P{^Is_CWU=false}', "");
Expect(1, 66640, '\p{Is_CWU= -False}', "");
Expect(0, 66640, '\p{^Is_CWU= -False}', "");
Expect(0, 66640, '\P{Is_CWU= -False}', "");
Expect(1, 66640, '\P{^Is_CWU= -False}', "");
Expect(0, 66639, '\p{Is_CWU= -False}', "");
Expect(1, 66639, '\p{^Is_CWU= -False}', "");
Expect(1, 66639, '\P{Is_CWU= -False}', "");
Expect(0, 66639, '\P{^Is_CWU= -False}', "");
Error('\p{Changes_When_Uppercased=:=_Yes}');
Error('\P{Changes_When_Uppercased=:=_Yes}');
Expect(1, 66639, '\p{Changes_When_Uppercased=yes}', "");
Expect(0, 66639, '\p{^Changes_When_Uppercased=yes}', "");
Expect(0, 66639, '\P{Changes_When_Uppercased=yes}', "");
Expect(1, 66639, '\P{^Changes_When_Uppercased=yes}', "");
Expect(0, 66640, '\p{Changes_When_Uppercased=yes}', "");
Expect(1, 66640, '\p{^Changes_When_Uppercased=yes}', "");
Expect(1, 66640, '\P{Changes_When_Uppercased=yes}', "");
Expect(0, 66640, '\P{^Changes_When_Uppercased=yes}', "");
Expect(1, 66639, '\p{Changes_When_Uppercased=_YES}', "");
Expect(0, 66639, '\p{^Changes_When_Uppercased=_YES}', "");
Expect(0, 66639, '\P{Changes_When_Uppercased=_YES}', "");
Expect(1, 66639, '\P{^Changes_When_Uppercased=_YES}', "");
Expect(0, 66640, '\p{Changes_When_Uppercased=_YES}', "");
Expect(1, 66640, '\p{^Changes_When_Uppercased=_YES}', "");
Expect(1, 66640, '\P{Changes_When_Uppercased=_YES}', "");
Expect(0, 66640, '\P{^Changes_When_Uppercased=_YES}', "");
Error('\p{CWU=:= 	Y}');
Error('\P{CWU=:= 	Y}');
Expect(1, 66639, '\p{CWU=y}', "");
Expect(0, 66639, '\p{^CWU=y}', "");
Expect(0, 66639, '\P{CWU=y}', "");
Expect(1, 66639, '\P{^CWU=y}', "");
Expect(0, 66640, '\p{CWU=y}', "");
Expect(1, 66640, '\p{^CWU=y}', "");
Expect(1, 66640, '\P{CWU=y}', "");
Expect(0, 66640, '\P{^CWU=y}', "");
Expect(1, 66639, '\p{CWU=_ Y}', "");
Expect(0, 66639, '\p{^CWU=_ Y}', "");
Expect(0, 66639, '\P{CWU=_ Y}', "");
Expect(1, 66639, '\P{^CWU=_ Y}', "");
Expect(0, 66640, '\p{CWU=_ Y}', "");
Expect(1, 66640, '\p{^CWU=_ Y}', "");
Expect(1, 66640, '\P{CWU=_ Y}', "");
Expect(0, 66640, '\P{^CWU=_ Y}', "");
Error('\p{Is_Changes_When_Uppercased=/a/T}');
Error('\P{Is_Changes_When_Uppercased=/a/T}');
Expect(1, 66639, '\p{Is_Changes_When_Uppercased=t}', "");
Expect(0, 66639, '\p{^Is_Changes_When_Uppercased=t}', "");
Expect(0, 66639, '\P{Is_Changes_When_Uppercased=t}', "");
Expect(1, 66639, '\P{^Is_Changes_When_Uppercased=t}', "");
Expect(0, 66640, '\p{Is_Changes_When_Uppercased=t}', "");
Expect(1, 66640, '\p{^Is_Changes_When_Uppercased=t}', "");
Expect(1, 66640, '\P{Is_Changes_When_Uppercased=t}', "");
Expect(0, 66640, '\P{^Is_Changes_When_Uppercased=t}', "");
Expect(1, 66639, '\p{Is_Changes_When_Uppercased=	t}', "");
Expect(0, 66639, '\p{^Is_Changes_When_Uppercased=	t}', "");
Expect(0, 66639, '\P{Is_Changes_When_Uppercased=	t}', "");
Expect(1, 66639, '\P{^Is_Changes_When_Uppercased=	t}', "");
Expect(0, 66640, '\p{Is_Changes_When_Uppercased=	t}', "");
Expect(1, 66640, '\p{^Is_Changes_When_Uppercased=	t}', "");
Expect(1, 66640, '\P{Is_Changes_When_Uppercased=	t}', "");
Expect(0, 66640, '\P{^Is_Changes_When_Uppercased=	t}', "");
Error('\p{Is_CWU=	:=True}');
Error('\P{Is_CWU=	:=True}');
Expect(1, 66639, '\p{Is_CWU=true}', "");
Expect(0, 66639, '\p{^Is_CWU=true}', "");
Expect(0, 66639, '\P{Is_CWU=true}', "");
Expect(1, 66639, '\P{^Is_CWU=true}', "");
Expect(0, 66640, '\p{Is_CWU=true}', "");
Expect(1, 66640, '\p{^Is_CWU=true}', "");
Expect(1, 66640, '\P{Is_CWU=true}', "");
Expect(0, 66640, '\P{^Is_CWU=true}', "");
Expect(1, 66639, '\p{Is_CWU=_True}', "");
Expect(0, 66639, '\p{^Is_CWU=_True}', "");
Expect(0, 66639, '\P{Is_CWU=_True}', "");
Expect(1, 66639, '\P{^Is_CWU=_True}', "");
Expect(0, 66640, '\p{Is_CWU=_True}', "");
Expect(1, 66640, '\p{^Is_CWU=_True}', "");
Expect(1, 66640, '\P{Is_CWU=_True}', "");
Expect(0, 66640, '\P{^Is_CWU=_True}', "");
Error('\p{Cased=:= _no}');
Error('\P{Cased=:= _no}');
Expect(1, 120780, '\p{Cased=no}', "");
Expect(0, 120780, '\p{^Cased=no}', "");
Expect(0, 120780, '\P{Cased=no}', "");
Expect(1, 120780, '\P{^Cased=no}', "");
Expect(0, 120779, '\p{Cased=no}', "");
Expect(1, 120779, '\p{^Cased=no}', "");
Expect(1, 120779, '\P{Cased=no}', "");
Expect(0, 120779, '\P{^Cased=no}', "");
Expect(1, 120780, '\p{Cased=No}', "");
Expect(0, 120780, '\p{^Cased=No}', "");
Expect(0, 120780, '\P{Cased=No}', "");
Expect(1, 120780, '\P{^Cased=No}', "");
Expect(0, 120779, '\p{Cased=No}', "");
Expect(1, 120779, '\p{^Cased=No}', "");
Expect(1, 120779, '\P{Cased=No}', "");
Expect(0, 120779, '\P{^Cased=No}', "");
Error('\p{Is_Cased=:= -n}');
Error('\P{Is_Cased=:= -n}');
Expect(1, 120780, '\p{Is_Cased=n}', "");
Expect(0, 120780, '\p{^Is_Cased=n}', "");
Expect(0, 120780, '\P{Is_Cased=n}', "");
Expect(1, 120780, '\P{^Is_Cased=n}', "");
Expect(0, 120779, '\p{Is_Cased=n}', "");
Expect(1, 120779, '\p{^Is_Cased=n}', "");
Expect(1, 120779, '\P{Is_Cased=n}', "");
Expect(0, 120779, '\P{^Is_Cased=n}', "");
Expect(1, 120780, '\p{Is_Cased=- n}', "");
Expect(0, 120780, '\p{^Is_Cased=- n}', "");
Expect(0, 120780, '\P{Is_Cased=- n}', "");
Expect(1, 120780, '\P{^Is_Cased=- n}', "");
Expect(0, 120779, '\p{Is_Cased=- n}', "");
Expect(1, 120779, '\p{^Is_Cased=- n}', "");
Expect(1, 120779, '\P{Is_Cased=- n}', "");
Expect(0, 120779, '\P{^Is_Cased=- n}', "");
Error('\p{Cased=__f/a/}');
Error('\P{Cased=__f/a/}');
Expect(1, 120780, '\p{Cased=f}', "");
Expect(0, 120780, '\p{^Cased=f}', "");
Expect(0, 120780, '\P{Cased=f}', "");
Expect(1, 120780, '\P{^Cased=f}', "");
Expect(0, 120779, '\p{Cased=f}', "");
Expect(1, 120779, '\p{^Cased=f}', "");
Expect(1, 120779, '\P{Cased=f}', "");
Expect(0, 120779, '\P{^Cased=f}', "");
Expect(1, 120780, '\p{Cased=F}', "");
Expect(0, 120780, '\p{^Cased=F}', "");
Expect(0, 120780, '\P{Cased=F}', "");
Expect(1, 120780, '\P{^Cased=F}', "");
Expect(0, 120779, '\p{Cased=F}', "");
Expect(1, 120779, '\p{^Cased=F}', "");
Expect(1, 120779, '\P{Cased=F}', "");
Expect(0, 120779, '\P{^Cased=F}', "");
Error('\p{Is_Cased=_ False:=}');
Error('\P{Is_Cased=_ False:=}');
Expect(1, 120780, '\p{Is_Cased=false}', "");
Expect(0, 120780, '\p{^Is_Cased=false}', "");
Expect(0, 120780, '\P{Is_Cased=false}', "");
Expect(1, 120780, '\P{^Is_Cased=false}', "");
Expect(0, 120779, '\p{Is_Cased=false}', "");
Expect(1, 120779, '\p{^Is_Cased=false}', "");
Expect(1, 120779, '\P{Is_Cased=false}', "");
Expect(0, 120779, '\P{^Is_Cased=false}', "");
Expect(1, 120780, '\p{Is_Cased=- false}', "");
Expect(0, 120780, '\p{^Is_Cased=- false}', "");
Expect(0, 120780, '\P{Is_Cased=- false}', "");
Expect(1, 120780, '\P{^Is_Cased=- false}', "");
Expect(0, 120779, '\p{Is_Cased=- false}', "");
Expect(1, 120779, '\p{^Is_Cased=- false}', "");
Expect(1, 120779, '\P{Is_Cased=- false}', "");
Expect(0, 120779, '\P{^Is_Cased=- false}', "");
Error('\p{Cased=_Yes:=}');
Error('\P{Cased=_Yes:=}');
Expect(1, 120779, '\p{Cased=yes}', "");
Expect(0, 120779, '\p{^Cased=yes}', "");
Expect(0, 120779, '\P{Cased=yes}', "");
Expect(1, 120779, '\P{^Cased=yes}', "");
Expect(0, 120780, '\p{Cased=yes}', "");
Expect(1, 120780, '\p{^Cased=yes}', "");
Expect(1, 120780, '\P{Cased=yes}', "");
Expect(0, 120780, '\P{^Cased=yes}', "");
Expect(1, 120779, '\p{Cased=_yes}', "");
Expect(0, 120779, '\p{^Cased=_yes}', "");
Expect(0, 120779, '\P{Cased=_yes}', "");
Expect(1, 120779, '\P{^Cased=_yes}', "");
Expect(0, 120780, '\p{Cased=_yes}', "");
Expect(1, 120780, '\p{^Cased=_yes}', "");
Expect(1, 120780, '\P{Cased=_yes}', "");
Expect(0, 120780, '\P{^Cased=_yes}', "");
Error('\p{Is_Cased=_/a/Y}');
Error('\P{Is_Cased=_/a/Y}');
Expect(1, 120779, '\p{Is_Cased=y}', "");
Expect(0, 120779, '\p{^Is_Cased=y}', "");
Expect(0, 120779, '\P{Is_Cased=y}', "");
Expect(1, 120779, '\P{^Is_Cased=y}', "");
Expect(0, 120780, '\p{Is_Cased=y}', "");
Expect(1, 120780, '\p{^Is_Cased=y}', "");
Expect(1, 120780, '\P{Is_Cased=y}', "");
Expect(0, 120780, '\P{^Is_Cased=y}', "");
Expect(1, 120779, '\p{Is_Cased=_ Y}', "");
Expect(0, 120779, '\p{^Is_Cased=_ Y}', "");
Expect(0, 120779, '\P{Is_Cased=_ Y}', "");
Expect(1, 120779, '\P{^Is_Cased=_ Y}', "");
Expect(0, 120780, '\p{Is_Cased=_ Y}', "");
Expect(1, 120780, '\p{^Is_Cased=_ Y}', "");
Expect(1, 120780, '\P{Is_Cased=_ Y}', "");
Expect(0, 120780, '\P{^Is_Cased=_ Y}', "");
Error('\p{Cased=/a/-_T}');
Error('\P{Cased=/a/-_T}');
Expect(1, 120779, '\p{Cased=t}', "");
Expect(0, 120779, '\p{^Cased=t}', "");
Expect(0, 120779, '\P{Cased=t}', "");
Expect(1, 120779, '\P{^Cased=t}', "");
Expect(0, 120780, '\p{Cased=t}', "");
Expect(1, 120780, '\p{^Cased=t}', "");
Expect(1, 120780, '\P{Cased=t}', "");
Expect(0, 120780, '\P{^Cased=t}', "");
Expect(1, 120779, '\p{Cased=_ T}', "");
Expect(0, 120779, '\p{^Cased=_ T}', "");
Expect(0, 120779, '\P{Cased=_ T}', "");
Expect(1, 120779, '\P{^Cased=_ T}', "");
Expect(0, 120780, '\p{Cased=_ T}', "");
Expect(1, 120780, '\p{^Cased=_ T}', "");
Expect(1, 120780, '\P{Cased=_ T}', "");
Expect(0, 120780, '\P{^Cased=_ T}', "");
Error('\p{Is_Cased=__true:=}');
Error('\P{Is_Cased=__true:=}');
Expect(1, 120779, '\p{Is_Cased=true}', "");
Expect(0, 120779, '\p{^Is_Cased=true}', "");
Expect(0, 120779, '\P{Is_Cased=true}', "");
Expect(1, 120779, '\P{^Is_Cased=true}', "");
Expect(0, 120780, '\p{Is_Cased=true}', "");
Expect(1, 120780, '\p{^Is_Cased=true}', "");
Expect(1, 120780, '\P{Is_Cased=true}', "");
Expect(0, 120780, '\P{^Is_Cased=true}', "");
Expect(1, 120779, '\p{Is_Cased:_true}', "");
Expect(0, 120779, '\p{^Is_Cased:_true}', "");
Expect(0, 120779, '\P{Is_Cased:_true}', "");
Expect(1, 120779, '\P{^Is_Cased:_true}', "");
Expect(0, 120780, '\p{Is_Cased:_true}', "");
Expect(1, 120780, '\p{^Is_Cased:_true}', "");
Expect(1, 120780, '\P{Is_Cased:_true}', "");
Expect(0, 120780, '\P{^Is_Cased:_true}', "");
Error('\p{Full_Composition_Exclusion= :=NO}');
Error('\P{Full_Composition_Exclusion= :=NO}');
Expect(1, 195102, '\p{Full_Composition_Exclusion=no}', "");
Expect(0, 195102, '\p{^Full_Composition_Exclusion=no}', "");
Expect(0, 195102, '\P{Full_Composition_Exclusion=no}', "");
Expect(1, 195102, '\P{^Full_Composition_Exclusion=no}', "");
Expect(0, 195101, '\p{Full_Composition_Exclusion=no}', "");
Expect(1, 195101, '\p{^Full_Composition_Exclusion=no}', "");
Expect(1, 195101, '\P{Full_Composition_Exclusion=no}', "");
Expect(0, 195101, '\P{^Full_Composition_Exclusion=no}', "");
Expect(1, 195102, '\p{Full_Composition_Exclusion:	no}', "");
Expect(0, 195102, '\p{^Full_Composition_Exclusion:	no}', "");
Expect(0, 195102, '\P{Full_Composition_Exclusion:	no}', "");
Expect(1, 195102, '\P{^Full_Composition_Exclusion:	no}', "");
Expect(0, 195101, '\p{Full_Composition_Exclusion:	no}', "");
Expect(1, 195101, '\p{^Full_Composition_Exclusion:	no}', "");
Expect(1, 195101, '\P{Full_Composition_Exclusion:	no}', "");
Expect(0, 195101, '\P{^Full_Composition_Exclusion:	no}', "");
Error('\p{Comp_Ex:- N:=}');
Error('\P{Comp_Ex:- N:=}');
Expect(1, 195102, '\p{Comp_Ex=n}', "");
Expect(0, 195102, '\p{^Comp_Ex=n}', "");
Expect(0, 195102, '\P{Comp_Ex=n}', "");
Expect(1, 195102, '\P{^Comp_Ex=n}', "");
Expect(0, 195101, '\p{Comp_Ex=n}', "");
Expect(1, 195101, '\p{^Comp_Ex=n}', "");
Expect(1, 195101, '\P{Comp_Ex=n}', "");
Expect(0, 195101, '\P{^Comp_Ex=n}', "");
Expect(1, 195102, '\p{Comp_Ex=__n}', "");
Expect(0, 195102, '\p{^Comp_Ex=__n}', "");
Expect(0, 195102, '\P{Comp_Ex=__n}', "");
Expect(1, 195102, '\P{^Comp_Ex=__n}', "");
Expect(0, 195101, '\p{Comp_Ex=__n}', "");
Expect(1, 195101, '\p{^Comp_Ex=__n}', "");
Expect(1, 195101, '\P{Comp_Ex=__n}', "");
Expect(0, 195101, '\P{^Comp_Ex=__n}', "");
Error('\p{Is_Full_Composition_Exclusion:	-	f/a/}');
Error('\P{Is_Full_Composition_Exclusion:	-	f/a/}');
Expect(1, 195102, '\p{Is_Full_Composition_Exclusion=f}', "");
Expect(0, 195102, '\p{^Is_Full_Composition_Exclusion=f}', "");
Expect(0, 195102, '\P{Is_Full_Composition_Exclusion=f}', "");
Expect(1, 195102, '\P{^Is_Full_Composition_Exclusion=f}', "");
Expect(0, 195101, '\p{Is_Full_Composition_Exclusion=f}', "");
Expect(1, 195101, '\p{^Is_Full_Composition_Exclusion=f}', "");
Expect(1, 195101, '\P{Is_Full_Composition_Exclusion=f}', "");
Expect(0, 195101, '\P{^Is_Full_Composition_Exclusion=f}', "");
Expect(1, 195102, '\p{Is_Full_Composition_Exclusion= F}', "");
Expect(0, 195102, '\p{^Is_Full_Composition_Exclusion= F}', "");
Expect(0, 195102, '\P{Is_Full_Composition_Exclusion= F}', "");
Expect(1, 195102, '\P{^Is_Full_Composition_Exclusion= F}', "");
Expect(0, 195101, '\p{Is_Full_Composition_Exclusion= F}', "");
Expect(1, 195101, '\p{^Is_Full_Composition_Exclusion= F}', "");
Expect(1, 195101, '\P{Is_Full_Composition_Exclusion= F}', "");
Expect(0, 195101, '\P{^Is_Full_Composition_Exclusion= F}', "");
Error('\p{Is_Comp_Ex=/a/__FALSE}');
Error('\P{Is_Comp_Ex=/a/__FALSE}');
Expect(1, 195102, '\p{Is_Comp_Ex=false}', "");
Expect(0, 195102, '\p{^Is_Comp_Ex=false}', "");
Expect(0, 195102, '\P{Is_Comp_Ex=false}', "");
Expect(1, 195102, '\P{^Is_Comp_Ex=false}', "");
Expect(0, 195101, '\p{Is_Comp_Ex=false}', "");
Expect(1, 195101, '\p{^Is_Comp_Ex=false}', "");
Expect(1, 195101, '\P{Is_Comp_Ex=false}', "");
Expect(0, 195101, '\P{^Is_Comp_Ex=false}', "");
Expect(1, 195102, '\p{Is_Comp_Ex= FALSE}', "");
Expect(0, 195102, '\p{^Is_Comp_Ex= FALSE}', "");
Expect(0, 195102, '\P{Is_Comp_Ex= FALSE}', "");
Expect(1, 195102, '\P{^Is_Comp_Ex= FALSE}', "");
Expect(0, 195101, '\p{Is_Comp_Ex= FALSE}', "");
Expect(1, 195101, '\p{^Is_Comp_Ex= FALSE}', "");
Expect(1, 195101, '\P{Is_Comp_Ex= FALSE}', "");
Expect(0, 195101, '\P{^Is_Comp_Ex= FALSE}', "");
Error('\p{Full_Composition_Exclusion=	/a/Yes}');
Error('\P{Full_Composition_Exclusion=	/a/Yes}');
Expect(1, 195101, '\p{Full_Composition_Exclusion: yes}', "");
Expect(0, 195101, '\p{^Full_Composition_Exclusion: yes}', "");
Expect(0, 195101, '\P{Full_Composition_Exclusion: yes}', "");
Expect(1, 195101, '\P{^Full_Composition_Exclusion: yes}', "");
Expect(0, 195102, '\p{Full_Composition_Exclusion: yes}', "");
Expect(1, 195102, '\p{^Full_Composition_Exclusion: yes}', "");
Expect(1, 195102, '\P{Full_Composition_Exclusion: yes}', "");
Expect(0, 195102, '\P{^Full_Composition_Exclusion: yes}', "");
Expect(1, 195101, '\p{Full_Composition_Exclusion=_	YES}', "");
Expect(0, 195101, '\p{^Full_Composition_Exclusion=_	YES}', "");
Expect(0, 195101, '\P{Full_Composition_Exclusion=_	YES}', "");
Expect(1, 195101, '\P{^Full_Composition_Exclusion=_	YES}', "");
Expect(0, 195102, '\p{Full_Composition_Exclusion=_	YES}', "");
Expect(1, 195102, '\p{^Full_Composition_Exclusion=_	YES}', "");
Expect(1, 195102, '\P{Full_Composition_Exclusion=_	YES}', "");
Expect(0, 195102, '\P{^Full_Composition_Exclusion=_	YES}', "");
Error('\p{Comp_Ex:		:=Y}');
Error('\P{Comp_Ex:		:=Y}');
Expect(1, 195101, '\p{Comp_Ex=y}', "");
Expect(0, 195101, '\p{^Comp_Ex=y}', "");
Expect(0, 195101, '\P{Comp_Ex=y}', "");
Expect(1, 195101, '\P{^Comp_Ex=y}', "");
Expect(0, 195102, '\p{Comp_Ex=y}', "");
Expect(1, 195102, '\p{^Comp_Ex=y}', "");
Expect(1, 195102, '\P{Comp_Ex=y}', "");
Expect(0, 195102, '\P{^Comp_Ex=y}', "");
Expect(1, 195101, '\p{Comp_Ex=--Y}', "");
Expect(0, 195101, '\p{^Comp_Ex=--Y}', "");
Expect(0, 195101, '\P{Comp_Ex=--Y}', "");
Expect(1, 195101, '\P{^Comp_Ex=--Y}', "");
Expect(0, 195102, '\p{Comp_Ex=--Y}', "");
Expect(1, 195102, '\p{^Comp_Ex=--Y}', "");
Expect(1, 195102, '\P{Comp_Ex=--Y}', "");
Expect(0, 195102, '\P{^Comp_Ex=--Y}', "");
Error('\p{Is_Full_Composition_Exclusion= :=t}');
Error('\P{Is_Full_Composition_Exclusion= :=t}');
Expect(1, 195101, '\p{Is_Full_Composition_Exclusion=t}', "");
Expect(0, 195101, '\p{^Is_Full_Composition_Exclusion=t}', "");
Expect(0, 195101, '\P{Is_Full_Composition_Exclusion=t}', "");
Expect(1, 195101, '\P{^Is_Full_Composition_Exclusion=t}', "");
Expect(0, 195102, '\p{Is_Full_Composition_Exclusion=t}', "");
Expect(1, 195102, '\p{^Is_Full_Composition_Exclusion=t}', "");
Expect(1, 195102, '\P{Is_Full_Composition_Exclusion=t}', "");
Expect(0, 195102, '\P{^Is_Full_Composition_Exclusion=t}', "");
Expect(1, 195101, '\p{Is_Full_Composition_Exclusion= _T}', "");
Expect(0, 195101, '\p{^Is_Full_Composition_Exclusion= _T}', "");
Expect(0, 195101, '\P{Is_Full_Composition_Exclusion= _T}', "");
Expect(1, 195101, '\P{^Is_Full_Composition_Exclusion= _T}', "");
Expect(0, 195102, '\p{Is_Full_Composition_Exclusion= _T}', "");
Expect(1, 195102, '\p{^Is_Full_Composition_Exclusion= _T}', "");
Expect(1, 195102, '\P{Is_Full_Composition_Exclusion= _T}', "");
Expect(0, 195102, '\P{^Is_Full_Composition_Exclusion= _T}', "");
Error('\p{Is_Comp_Ex:	True:=}');
Error('\P{Is_Comp_Ex:	True:=}');
Expect(1, 195101, '\p{Is_Comp_Ex=true}', "");
Expect(0, 195101, '\p{^Is_Comp_Ex=true}', "");
Expect(0, 195101, '\P{Is_Comp_Ex=true}', "");
Expect(1, 195101, '\P{^Is_Comp_Ex=true}', "");
Expect(0, 195102, '\p{Is_Comp_Ex=true}', "");
Expect(1, 195102, '\p{^Is_Comp_Ex=true}', "");
Expect(1, 195102, '\P{Is_Comp_Ex=true}', "");
Expect(0, 195102, '\P{^Is_Comp_Ex=true}', "");
Expect(1, 195101, '\p{Is_Comp_Ex:	True}', "");
Expect(0, 195101, '\p{^Is_Comp_Ex:	True}', "");
Expect(0, 195101, '\P{Is_Comp_Ex:	True}', "");
Expect(1, 195101, '\P{^Is_Comp_Ex:	True}', "");
Expect(0, 195102, '\p{Is_Comp_Ex:	True}', "");
Expect(1, 195102, '\p{^Is_Comp_Ex:	True}', "");
Expect(1, 195102, '\P{Is_Comp_Ex:	True}', "");
Expect(0, 195102, '\P{^Is_Comp_Ex:	True}', "");
Error('\p{Default_Ignorable_Code_Point=	-NO:=}');
Error('\P{Default_Ignorable_Code_Point=	-NO:=}');
Expect(1, 921600, '\p{Default_Ignorable_Code_Point=no}', "");
Expect(0, 921600, '\p{^Default_Ignorable_Code_Point=no}', "");
Expect(0, 921600, '\P{Default_Ignorable_Code_Point=no}', "");
Expect(1, 921600, '\P{^Default_Ignorable_Code_Point=no}', "");
Expect(0, 921599, '\p{Default_Ignorable_Code_Point=no}', "");
Expect(1, 921599, '\p{^Default_Ignorable_Code_Point=no}', "");
Expect(1, 921599, '\P{Default_Ignorable_Code_Point=no}', "");
Expect(0, 921599, '\P{^Default_Ignorable_Code_Point=no}', "");
Expect(1, 921600, '\p{Default_Ignorable_Code_Point=_No}', "");
Expect(0, 921600, '\p{^Default_Ignorable_Code_Point=_No}', "");
Expect(0, 921600, '\P{Default_Ignorable_Code_Point=_No}', "");
Expect(1, 921600, '\P{^Default_Ignorable_Code_Point=_No}', "");
Expect(0, 921599, '\p{Default_Ignorable_Code_Point=_No}', "");
Expect(1, 921599, '\p{^Default_Ignorable_Code_Point=_No}', "");
Expect(1, 921599, '\P{Default_Ignorable_Code_Point=_No}', "");
Expect(0, 921599, '\P{^Default_Ignorable_Code_Point=_No}', "");
Error('\p{DI=	:=N}');
Error('\P{DI=	:=N}');
Expect(1, 921600, '\p{DI=n}', "");
Expect(0, 921600, '\p{^DI=n}', "");
Expect(0, 921600, '\P{DI=n}', "");
Expect(1, 921600, '\P{^DI=n}', "");
Expect(0, 921599, '\p{DI=n}', "");
Expect(1, 921599, '\p{^DI=n}', "");
Expect(1, 921599, '\P{DI=n}', "");
Expect(0, 921599, '\P{^DI=n}', "");
Expect(1, 921600, '\p{DI:_	N}', "");
Expect(0, 921600, '\p{^DI:_	N}', "");
Expect(0, 921600, '\P{DI:_	N}', "");
Expect(1, 921600, '\P{^DI:_	N}', "");
Expect(0, 921599, '\p{DI:_	N}', "");
Expect(1, 921599, '\p{^DI:_	N}', "");
Expect(1, 921599, '\P{DI:_	N}', "");
Expect(0, 921599, '\P{^DI:_	N}', "");
Error('\p{Is_Default_Ignorable_Code_Point=:=  f}');
Error('\P{Is_Default_Ignorable_Code_Point=:=  f}');
Expect(1, 921600, '\p{Is_Default_Ignorable_Code_Point=f}', "");
Expect(0, 921600, '\p{^Is_Default_Ignorable_Code_Point=f}', "");
Expect(0, 921600, '\P{Is_Default_Ignorable_Code_Point=f}', "");
Expect(1, 921600, '\P{^Is_Default_Ignorable_Code_Point=f}', "");
Expect(0, 921599, '\p{Is_Default_Ignorable_Code_Point=f}', "");
Expect(1, 921599, '\p{^Is_Default_Ignorable_Code_Point=f}', "");
Expect(1, 921599, '\P{Is_Default_Ignorable_Code_Point=f}', "");
Expect(0, 921599, '\P{^Is_Default_Ignorable_Code_Point=f}', "");
Expect(1, 921600, '\p{Is_Default_Ignorable_Code_Point= F}', "");
Expect(0, 921600, '\p{^Is_Default_Ignorable_Code_Point= F}', "");
Expect(0, 921600, '\P{Is_Default_Ignorable_Code_Point= F}', "");
Expect(1, 921600, '\P{^Is_Default_Ignorable_Code_Point= F}', "");
Expect(0, 921599, '\p{Is_Default_Ignorable_Code_Point= F}', "");
Expect(1, 921599, '\p{^Is_Default_Ignorable_Code_Point= F}', "");
Expect(1, 921599, '\P{Is_Default_Ignorable_Code_Point= F}', "");
Expect(0, 921599, '\P{^Is_Default_Ignorable_Code_Point= F}', "");
Error('\p{Is_DI= 	False:=}');
Error('\P{Is_DI= 	False:=}');
Expect(1, 921600, '\p{Is_DI=false}', "");
Expect(0, 921600, '\p{^Is_DI=false}', "");
Expect(0, 921600, '\P{Is_DI=false}', "");
Expect(1, 921600, '\P{^Is_DI=false}', "");
Expect(0, 921599, '\p{Is_DI=false}', "");
Expect(1, 921599, '\p{^Is_DI=false}', "");
Expect(1, 921599, '\P{Is_DI=false}', "");
Expect(0, 921599, '\P{^Is_DI=false}', "");
Expect(1, 921600, '\p{Is_DI=_-False}', "");
Expect(0, 921600, '\p{^Is_DI=_-False}', "");
Expect(0, 921600, '\P{Is_DI=_-False}', "");
Expect(1, 921600, '\P{^Is_DI=_-False}', "");
Expect(0, 921599, '\p{Is_DI=_-False}', "");
Expect(1, 921599, '\p{^Is_DI=_-False}', "");
Expect(1, 921599, '\P{Is_DI=_-False}', "");
Expect(0, 921599, '\P{^Is_DI=_-False}', "");
Error('\p{Default_Ignorable_Code_Point:	yes:=}');
Error('\P{Default_Ignorable_Code_Point:	yes:=}');
Expect(1, 921599, '\p{Default_Ignorable_Code_Point=yes}', "");
Expect(0, 921599, '\p{^Default_Ignorable_Code_Point=yes}', "");
Expect(0, 921599, '\P{Default_Ignorable_Code_Point=yes}', "");
Expect(1, 921599, '\P{^Default_Ignorable_Code_Point=yes}', "");
Expect(0, 921600, '\p{Default_Ignorable_Code_Point=yes}', "");
Expect(1, 921600, '\p{^Default_Ignorable_Code_Point=yes}', "");
Expect(1, 921600, '\P{Default_Ignorable_Code_Point=yes}', "");
Expect(0, 921600, '\P{^Default_Ignorable_Code_Point=yes}', "");
Expect(1, 921599, '\p{Default_Ignorable_Code_Point=_	yes}', "");
Expect(0, 921599, '\p{^Default_Ignorable_Code_Point=_	yes}', "");
Expect(0, 921599, '\P{Default_Ignorable_Code_Point=_	yes}', "");
Expect(1, 921599, '\P{^Default_Ignorable_Code_Point=_	yes}', "");
Expect(0, 921600, '\p{Default_Ignorable_Code_Point=_	yes}', "");
Expect(1, 921600, '\p{^Default_Ignorable_Code_Point=_	yes}', "");
Expect(1, 921600, '\P{Default_Ignorable_Code_Point=_	yes}', "");
Expect(0, 921600, '\P{^Default_Ignorable_Code_Point=_	yes}', "");
Error('\p{DI= 	Y/a/}');
Error('\P{DI= 	Y/a/}');
Expect(1, 921599, '\p{DI=y}', "");
Expect(0, 921599, '\p{^DI=y}', "");
Expect(0, 921599, '\P{DI=y}', "");
Expect(1, 921599, '\P{^DI=y}', "");
Expect(0, 921600, '\p{DI=y}', "");
Expect(1, 921600, '\p{^DI=y}', "");
Expect(1, 921600, '\P{DI=y}', "");
Expect(0, 921600, '\P{^DI=y}', "");
Expect(1, 921599, '\p{DI=-Y}', "");
Expect(0, 921599, '\p{^DI=-Y}', "");
Expect(0, 921599, '\P{DI=-Y}', "");
Expect(1, 921599, '\P{^DI=-Y}', "");
Expect(0, 921600, '\p{DI=-Y}', "");
Expect(1, 921600, '\p{^DI=-Y}', "");
Expect(1, 921600, '\P{DI=-Y}', "");
Expect(0, 921600, '\P{^DI=-Y}', "");
Error('\p{Is_Default_Ignorable_Code_Point=	T:=}');
Error('\P{Is_Default_Ignorable_Code_Point=	T:=}');
Expect(1, 921599, '\p{Is_Default_Ignorable_Code_Point=t}', "");
Expect(0, 921599, '\p{^Is_Default_Ignorable_Code_Point=t}', "");
Expect(0, 921599, '\P{Is_Default_Ignorable_Code_Point=t}', "");
Expect(1, 921599, '\P{^Is_Default_Ignorable_Code_Point=t}', "");
Expect(0, 921600, '\p{Is_Default_Ignorable_Code_Point=t}', "");
Expect(1, 921600, '\p{^Is_Default_Ignorable_Code_Point=t}', "");
Expect(1, 921600, '\P{Is_Default_Ignorable_Code_Point=t}', "");
Expect(0, 921600, '\P{^Is_Default_Ignorable_Code_Point=t}', "");
Expect(1, 921599, '\p{Is_Default_Ignorable_Code_Point=	T}', "");
Expect(0, 921599, '\p{^Is_Default_Ignorable_Code_Point=	T}', "");
Expect(0, 921599, '\P{Is_Default_Ignorable_Code_Point=	T}', "");
Expect(1, 921599, '\P{^Is_Default_Ignorable_Code_Point=	T}', "");
Expect(0, 921600, '\p{Is_Default_Ignorable_Code_Point=	T}', "");
Expect(1, 921600, '\p{^Is_Default_Ignorable_Code_Point=	T}', "");
Expect(1, 921600, '\P{Is_Default_Ignorable_Code_Point=	T}', "");
Expect(0, 921600, '\P{^Is_Default_Ignorable_Code_Point=	T}', "");
Error('\p{Is_DI: -_TRUE:=}');
Error('\P{Is_DI: -_TRUE:=}');
Expect(1, 921599, '\p{Is_DI=true}', "");
Expect(0, 921599, '\p{^Is_DI=true}', "");
Expect(0, 921599, '\P{Is_DI=true}', "");
Expect(1, 921599, '\P{^Is_DI=true}', "");
Expect(0, 921600, '\p{Is_DI=true}', "");
Expect(1, 921600, '\p{^Is_DI=true}', "");
Expect(1, 921600, '\P{Is_DI=true}', "");
Expect(0, 921600, '\P{^Is_DI=true}', "");
Expect(1, 921599, '\p{Is_DI: 	_TRUE}', "");
Expect(0, 921599, '\p{^Is_DI: 	_TRUE}', "");
Expect(0, 921599, '\P{Is_DI: 	_TRUE}', "");
Expect(1, 921599, '\P{^Is_DI: 	_TRUE}', "");
Expect(0, 921600, '\p{Is_DI: 	_TRUE}', "");
Expect(1, 921600, '\p{^Is_DI: 	_TRUE}', "");
Expect(1, 921600, '\P{Is_DI: 	_TRUE}', "");
Expect(0, 921600, '\P{^Is_DI: 	_TRUE}', "");
Error('\p{Dash=_-No/a/}');
Error('\P{Dash=_-No/a/}');
Expect(1, 65294, '\p{Dash: no}', "");
Expect(0, 65294, '\p{^Dash: no}', "");
Expect(0, 65294, '\P{Dash: no}', "");
Expect(1, 65294, '\P{^Dash: no}', "");
Expect(0, 65293, '\p{Dash: no}', "");
Expect(1, 65293, '\p{^Dash: no}', "");
Expect(1, 65293, '\P{Dash: no}', "");
Expect(0, 65293, '\P{^Dash: no}', "");
Expect(1, 65294, '\p{Dash= _NO}', "");
Expect(0, 65294, '\p{^Dash= _NO}', "");
Expect(0, 65294, '\P{Dash= _NO}', "");
Expect(1, 65294, '\P{^Dash= _NO}', "");
Expect(0, 65293, '\p{Dash= _NO}', "");
Expect(1, 65293, '\p{^Dash= _NO}', "");
Expect(1, 65293, '\P{Dash= _NO}', "");
Expect(0, 65293, '\P{^Dash= _NO}', "");
Error('\p{Is_Dash=	:=N}');
Error('\P{Is_Dash=	:=N}');
Expect(1, 65294, '\p{Is_Dash=n}', "");
Expect(0, 65294, '\p{^Is_Dash=n}', "");
Expect(0, 65294, '\P{Is_Dash=n}', "");
Expect(1, 65294, '\P{^Is_Dash=n}', "");
Expect(0, 65293, '\p{Is_Dash=n}', "");
Expect(1, 65293, '\p{^Is_Dash=n}', "");
Expect(1, 65293, '\P{Is_Dash=n}', "");
Expect(0, 65293, '\P{^Is_Dash=n}', "");
Expect(1, 65294, '\p{Is_Dash= 	N}', "");
Expect(0, 65294, '\p{^Is_Dash= 	N}', "");
Expect(0, 65294, '\P{Is_Dash= 	N}', "");
Expect(1, 65294, '\P{^Is_Dash= 	N}', "");
Expect(0, 65293, '\p{Is_Dash= 	N}', "");
Expect(1, 65293, '\p{^Is_Dash= 	N}', "");
Expect(1, 65293, '\P{Is_Dash= 	N}', "");
Expect(0, 65293, '\P{^Is_Dash= 	N}', "");
Error('\p{Dash= /a/F}');
Error('\P{Dash= /a/F}');
Expect(1, 65294, '\p{Dash=f}', "");
Expect(0, 65294, '\p{^Dash=f}', "");
Expect(0, 65294, '\P{Dash=f}', "");
Expect(1, 65294, '\P{^Dash=f}', "");
Expect(0, 65293, '\p{Dash=f}', "");
Expect(1, 65293, '\p{^Dash=f}', "");
Expect(1, 65293, '\P{Dash=f}', "");
Expect(0, 65293, '\P{^Dash=f}', "");
Expect(1, 65294, '\p{Dash=	 f}', "");
Expect(0, 65294, '\p{^Dash=	 f}', "");
Expect(0, 65294, '\P{Dash=	 f}', "");
Expect(1, 65294, '\P{^Dash=	 f}', "");
Expect(0, 65293, '\p{Dash=	 f}', "");
Expect(1, 65293, '\p{^Dash=	 f}', "");
Expect(1, 65293, '\P{Dash=	 f}', "");
Expect(0, 65293, '\P{^Dash=	 f}', "");
Error('\p{Is_Dash=:=_-False}');
Error('\P{Is_Dash=:=_-False}');
Expect(1, 65294, '\p{Is_Dash: false}', "");
Expect(0, 65294, '\p{^Is_Dash: false}', "");
Expect(0, 65294, '\P{Is_Dash: false}', "");
Expect(1, 65294, '\P{^Is_Dash: false}', "");
Expect(0, 65293, '\p{Is_Dash: false}', "");
Expect(1, 65293, '\p{^Is_Dash: false}', "");
Expect(1, 65293, '\P{Is_Dash: false}', "");
Expect(0, 65293, '\P{^Is_Dash: false}', "");
Expect(1, 65294, '\p{Is_Dash=-false}', "");
Expect(0, 65294, '\p{^Is_Dash=-false}', "");
Expect(0, 65294, '\P{Is_Dash=-false}', "");
Expect(1, 65294, '\P{^Is_Dash=-false}', "");
Expect(0, 65293, '\p{Is_Dash=-false}', "");
Expect(1, 65293, '\p{^Is_Dash=-false}', "");
Expect(1, 65293, '\P{Is_Dash=-false}', "");
Expect(0, 65293, '\P{^Is_Dash=-false}', "");
Error('\p{Dash:  :=yes}');
Error('\P{Dash:  :=yes}');
Expect(1, 65293, '\p{Dash=yes}', "");
Expect(0, 65293, '\p{^Dash=yes}', "");
Expect(0, 65293, '\P{Dash=yes}', "");
Expect(1, 65293, '\P{^Dash=yes}', "");
Expect(0, 65294, '\p{Dash=yes}', "");
Expect(1, 65294, '\p{^Dash=yes}', "");
Expect(1, 65294, '\P{Dash=yes}', "");
Expect(0, 65294, '\P{^Dash=yes}', "");
Expect(1, 65293, '\p{Dash=--Yes}', "");
Expect(0, 65293, '\p{^Dash=--Yes}', "");
Expect(0, 65293, '\P{Dash=--Yes}', "");
Expect(1, 65293, '\P{^Dash=--Yes}', "");
Expect(0, 65294, '\p{Dash=--Yes}', "");
Expect(1, 65294, '\p{^Dash=--Yes}', "");
Expect(1, 65294, '\P{Dash=--Yes}', "");
Expect(0, 65294, '\P{^Dash=--Yes}', "");
Error('\p{Is_Dash=	/a/Y}');
Error('\P{Is_Dash=	/a/Y}');
Expect(1, 65293, '\p{Is_Dash=y}', "");
Expect(0, 65293, '\p{^Is_Dash=y}', "");
Expect(0, 65293, '\P{Is_Dash=y}', "");
Expect(1, 65293, '\P{^Is_Dash=y}', "");
Expect(0, 65294, '\p{Is_Dash=y}', "");
Expect(1, 65294, '\p{^Is_Dash=y}', "");
Expect(1, 65294, '\P{Is_Dash=y}', "");
Expect(0, 65294, '\P{^Is_Dash=y}', "");
Expect(1, 65293, '\p{Is_Dash=	-y}', "");
Expect(0, 65293, '\p{^Is_Dash=	-y}', "");
Expect(0, 65293, '\P{Is_Dash=	-y}', "");
Expect(1, 65293, '\P{^Is_Dash=	-y}', "");
Expect(0, 65294, '\p{Is_Dash=	-y}', "");
Expect(1, 65294, '\p{^Is_Dash=	-y}', "");
Expect(1, 65294, '\P{Is_Dash=	-y}', "");
Expect(0, 65294, '\P{^Is_Dash=	-y}', "");
Error('\p{Dash= T/a/}');
Error('\P{Dash= T/a/}');
Expect(1, 65293, '\p{Dash=t}', "");
Expect(0, 65293, '\p{^Dash=t}', "");
Expect(0, 65293, '\P{Dash=t}', "");
Expect(1, 65293, '\P{^Dash=t}', "");
Expect(0, 65294, '\p{Dash=t}', "");
Expect(1, 65294, '\p{^Dash=t}', "");
Expect(1, 65294, '\P{Dash=t}', "");
Expect(0, 65294, '\P{^Dash=t}', "");
Expect(1, 65293, '\p{Dash=-T}', "");
Expect(0, 65293, '\p{^Dash=-T}', "");
Expect(0, 65293, '\P{Dash=-T}', "");
Expect(1, 65293, '\P{^Dash=-T}', "");
Expect(0, 65294, '\p{Dash=-T}', "");
Expect(1, 65294, '\p{^Dash=-T}', "");
Expect(1, 65294, '\P{Dash=-T}', "");
Expect(0, 65294, '\P{^Dash=-T}', "");
Error('\p{Is_Dash=-:=TRUE}');
Error('\P{Is_Dash=-:=TRUE}');
Expect(1, 65293, '\p{Is_Dash=true}', "");
Expect(0, 65293, '\p{^Is_Dash=true}', "");
Expect(0, 65293, '\P{Is_Dash=true}', "");
Expect(1, 65293, '\P{^Is_Dash=true}', "");
Expect(0, 65294, '\p{Is_Dash=true}', "");
Expect(1, 65294, '\p{^Is_Dash=true}', "");
Expect(1, 65294, '\P{Is_Dash=true}', "");
Expect(0, 65294, '\P{^Is_Dash=true}', "");
Expect(1, 65293, '\p{Is_Dash= _True}', "");
Expect(0, 65293, '\p{^Is_Dash= _True}', "");
Expect(0, 65293, '\P{Is_Dash= _True}', "");
Expect(1, 65293, '\P{^Is_Dash= _True}', "");
Expect(0, 65294, '\p{Is_Dash= _True}', "");
Expect(1, 65294, '\p{^Is_Dash= _True}', "");
Expect(1, 65294, '\P{Is_Dash= _True}', "");
Expect(0, 65294, '\P{^Is_Dash= _True}', "");
Error('\p{Deprecated=-/a/NO}');
Error('\P{Deprecated=-/a/NO}');
Expect(1, 917632, '\p{Deprecated=no}', "");
Expect(0, 917632, '\p{^Deprecated=no}', "");
Expect(0, 917632, '\P{Deprecated=no}', "");
Expect(1, 917632, '\P{^Deprecated=no}', "");
Expect(0, 917631, '\p{Deprecated=no}', "");
Expect(1, 917631, '\p{^Deprecated=no}', "");
Expect(1, 917631, '\P{Deprecated=no}', "");
Expect(0, 917631, '\P{^Deprecated=no}', "");
Expect(1, 917632, '\p{Deprecated:   - No}', "");
Expect(0, 917632, '\p{^Deprecated:   - No}', "");
Expect(0, 917632, '\P{Deprecated:   - No}', "");
Expect(1, 917632, '\P{^Deprecated:   - No}', "");
Expect(0, 917631, '\p{Deprecated:   - No}', "");
Expect(1, 917631, '\p{^Deprecated:   - No}', "");
Expect(1, 917631, '\P{Deprecated:   - No}', "");
Expect(0, 917631, '\P{^Deprecated:   - No}', "");
Error('\p{Dep=_:=N}');
Error('\P{Dep=_:=N}');
Expect(1, 917632, '\p{Dep=n}', "");
Expect(0, 917632, '\p{^Dep=n}', "");
Expect(0, 917632, '\P{Dep=n}', "");
Expect(1, 917632, '\P{^Dep=n}', "");
Expect(0, 917631, '\p{Dep=n}', "");
Expect(1, 917631, '\p{^Dep=n}', "");
Expect(1, 917631, '\P{Dep=n}', "");
Expect(0, 917631, '\P{^Dep=n}', "");
Expect(1, 917632, '\p{Dep= N}', "");
Expect(0, 917632, '\p{^Dep= N}', "");
Expect(0, 917632, '\P{Dep= N}', "");
Expect(1, 917632, '\P{^Dep= N}', "");
Expect(0, 917631, '\p{Dep= N}', "");
Expect(1, 917631, '\p{^Dep= N}', "");
Expect(1, 917631, '\P{Dep= N}', "");
Expect(0, 917631, '\P{^Dep= N}', "");
Error('\p{Is_Deprecated= /a/F}');
Error('\P{Is_Deprecated= /a/F}');
Expect(1, 917632, '\p{Is_Deprecated=f}', "");
Expect(0, 917632, '\p{^Is_Deprecated=f}', "");
Expect(0, 917632, '\P{Is_Deprecated=f}', "");
Expect(1, 917632, '\P{^Is_Deprecated=f}', "");
Expect(0, 917631, '\p{Is_Deprecated=f}', "");
Expect(1, 917631, '\p{^Is_Deprecated=f}', "");
Expect(1, 917631, '\P{Is_Deprecated=f}', "");
Expect(0, 917631, '\P{^Is_Deprecated=f}', "");
Expect(1, 917632, '\p{Is_Deprecated=-_F}', "");
Expect(0, 917632, '\p{^Is_Deprecated=-_F}', "");
Expect(0, 917632, '\P{Is_Deprecated=-_F}', "");
Expect(1, 917632, '\P{^Is_Deprecated=-_F}', "");
Expect(0, 917631, '\p{Is_Deprecated=-_F}', "");
Expect(1, 917631, '\p{^Is_Deprecated=-_F}', "");
Expect(1, 917631, '\P{Is_Deprecated=-_F}', "");
Expect(0, 917631, '\P{^Is_Deprecated=-_F}', "");
Error('\p{Is_Dep:		:=FALSE}');
Error('\P{Is_Dep:		:=FALSE}');
Expect(1, 917632, '\p{Is_Dep: false}', "");
Expect(0, 917632, '\p{^Is_Dep: false}', "");
Expect(0, 917632, '\P{Is_Dep: false}', "");
Expect(1, 917632, '\P{^Is_Dep: false}', "");
Expect(0, 917631, '\p{Is_Dep: false}', "");
Expect(1, 917631, '\p{^Is_Dep: false}', "");
Expect(1, 917631, '\P{Is_Dep: false}', "");
Expect(0, 917631, '\P{^Is_Dep: false}', "");
Expect(1, 917632, '\p{Is_Dep=		False}', "");
Expect(0, 917632, '\p{^Is_Dep=		False}', "");
Expect(0, 917632, '\P{Is_Dep=		False}', "");
Expect(1, 917632, '\P{^Is_Dep=		False}', "");
Expect(0, 917631, '\p{Is_Dep=		False}', "");
Expect(1, 917631, '\p{^Is_Dep=		False}', "");
Expect(1, 917631, '\P{Is_Dep=		False}', "");
Expect(0, 917631, '\P{^Is_Dep=		False}', "");
Error('\p{Deprecated=/a/	-yes}');
Error('\P{Deprecated=/a/	-yes}');
Expect(1, 917631, '\p{Deprecated=yes}', "");
Expect(0, 917631, '\p{^Deprecated=yes}', "");
Expect(0, 917631, '\P{Deprecated=yes}', "");
Expect(1, 917631, '\P{^Deprecated=yes}', "");
Expect(0, 917632, '\p{Deprecated=yes}', "");
Expect(1, 917632, '\p{^Deprecated=yes}', "");
Expect(1, 917632, '\P{Deprecated=yes}', "");
Expect(0, 917632, '\P{^Deprecated=yes}', "");
Expect(1, 917631, '\p{Deprecated=__Yes}', "");
Expect(0, 917631, '\p{^Deprecated=__Yes}', "");
Expect(0, 917631, '\P{Deprecated=__Yes}', "");
Expect(1, 917631, '\P{^Deprecated=__Yes}', "");
Expect(0, 917632, '\p{Deprecated=__Yes}', "");
Expect(1, 917632, '\p{^Deprecated=__Yes}', "");
Expect(1, 917632, '\P{Deprecated=__Yes}', "");
Expect(0, 917632, '\P{^Deprecated=__Yes}', "");
Error('\p{Dep=_/a/Y}');
Error('\P{Dep=_/a/Y}');
Expect(1, 917631, '\p{Dep=y}', "");
Expect(0, 917631, '\p{^Dep=y}', "");
Expect(0, 917631, '\P{Dep=y}', "");
Expect(1, 917631, '\P{^Dep=y}', "");
Expect(0, 917632, '\p{Dep=y}', "");
Expect(1, 917632, '\p{^Dep=y}', "");
Expect(1, 917632, '\P{Dep=y}', "");
Expect(0, 917632, '\P{^Dep=y}', "");
Expect(1, 917631, '\p{Dep= y}', "");
Expect(0, 917631, '\p{^Dep= y}', "");
Expect(0, 917631, '\P{Dep= y}', "");
Expect(1, 917631, '\P{^Dep= y}', "");
Expect(0, 917632, '\p{Dep= y}', "");
Expect(1, 917632, '\p{^Dep= y}', "");
Expect(1, 917632, '\P{Dep= y}', "");
Expect(0, 917632, '\P{^Dep= y}', "");
Error('\p{Is_Deprecated:   	/a/t}');
Error('\P{Is_Deprecated:   	/a/t}');
Expect(1, 917631, '\p{Is_Deprecated=t}', "");
Expect(0, 917631, '\p{^Is_Deprecated=t}', "");
Expect(0, 917631, '\P{Is_Deprecated=t}', "");
Expect(1, 917631, '\P{^Is_Deprecated=t}', "");
Expect(0, 917632, '\p{Is_Deprecated=t}', "");
Expect(1, 917632, '\p{^Is_Deprecated=t}', "");
Expect(1, 917632, '\P{Is_Deprecated=t}', "");
Expect(0, 917632, '\P{^Is_Deprecated=t}', "");
Expect(1, 917631, '\p{Is_Deprecated=--T}', "");
Expect(0, 917631, '\p{^Is_Deprecated=--T}', "");
Expect(0, 917631, '\P{Is_Deprecated=--T}', "");
Expect(1, 917631, '\P{^Is_Deprecated=--T}', "");
Expect(0, 917632, '\p{Is_Deprecated=--T}', "");
Expect(1, 917632, '\p{^Is_Deprecated=--T}', "");
Expect(1, 917632, '\P{Is_Deprecated=--T}', "");
Expect(0, 917632, '\P{^Is_Deprecated=--T}', "");
Error('\p{Is_Dep=True/a/}');
Error('\P{Is_Dep=True/a/}');
Expect(1, 917631, '\p{Is_Dep=true}', "");
Expect(0, 917631, '\p{^Is_Dep=true}', "");
Expect(0, 917631, '\P{Is_Dep=true}', "");
Expect(1, 917631, '\P{^Is_Dep=true}', "");
Expect(0, 917632, '\p{Is_Dep=true}', "");
Expect(1, 917632, '\p{^Is_Dep=true}', "");
Expect(1, 917632, '\P{Is_Dep=true}', "");
Expect(0, 917632, '\P{^Is_Dep=true}', "");
Expect(1, 917631, '\p{Is_Dep=--True}', "");
Expect(0, 917631, '\p{^Is_Dep=--True}', "");
Expect(0, 917631, '\P{Is_Dep=--True}', "");
Expect(1, 917631, '\P{^Is_Dep=--True}', "");
Expect(0, 917632, '\p{Is_Dep=--True}', "");
Expect(1, 917632, '\p{^Is_Dep=--True}', "");
Expect(1, 917632, '\P{Is_Dep=--True}', "");
Expect(0, 917632, '\P{^Is_Dep=--True}', "");
Error('\p{Diacritic:		/a/NO}');
Error('\P{Diacritic:		/a/NO}');
Expect(1, 119214, '\p{Diacritic=no}', "");
Expect(0, 119214, '\p{^Diacritic=no}', "");
Expect(0, 119214, '\P{Diacritic=no}', "");
Expect(1, 119214, '\P{^Diacritic=no}', "");
Expect(0, 119213, '\p{Diacritic=no}', "");
Expect(1, 119213, '\p{^Diacritic=no}', "");
Expect(1, 119213, '\P{Diacritic=no}', "");
Expect(0, 119213, '\P{^Diacritic=no}', "");
Expect(1, 119214, '\p{Diacritic=- NO}', "");
Expect(0, 119214, '\p{^Diacritic=- NO}', "");
Expect(0, 119214, '\P{Diacritic=- NO}', "");
Expect(1, 119214, '\P{^Diacritic=- NO}', "");
Expect(0, 119213, '\p{Diacritic=- NO}', "");
Expect(1, 119213, '\p{^Diacritic=- NO}', "");
Expect(1, 119213, '\P{Diacritic=- NO}', "");
Expect(0, 119213, '\P{^Diacritic=- NO}', "");
Error('\p{Dia=/a/  N}');
Error('\P{Dia=/a/  N}');
Expect(1, 119214, '\p{Dia=n}', "");
Expect(0, 119214, '\p{^Dia=n}', "");
Expect(0, 119214, '\P{Dia=n}', "");
Expect(1, 119214, '\P{^Dia=n}', "");
Expect(0, 119213, '\p{Dia=n}', "");
Expect(1, 119213, '\p{^Dia=n}', "");
Expect(1, 119213, '\P{Dia=n}', "");
Expect(0, 119213, '\P{^Dia=n}', "");
Expect(1, 119214, '\p{Dia=-_N}', "");
Expect(0, 119214, '\p{^Dia=-_N}', "");
Expect(0, 119214, '\P{Dia=-_N}', "");
Expect(1, 119214, '\P{^Dia=-_N}', "");
Expect(0, 119213, '\p{Dia=-_N}', "");
Expect(1, 119213, '\p{^Dia=-_N}', "");
Expect(1, 119213, '\P{Dia=-_N}', "");
Expect(0, 119213, '\P{^Dia=-_N}', "");
Error('\p{Is_Diacritic=F:=}');
Error('\P{Is_Diacritic=F:=}');
Expect(1, 119214, '\p{Is_Diacritic=f}', "");
Expect(0, 119214, '\p{^Is_Diacritic=f}', "");
Expect(0, 119214, '\P{Is_Diacritic=f}', "");
Expect(1, 119214, '\P{^Is_Diacritic=f}', "");
Expect(0, 119213, '\p{Is_Diacritic=f}', "");
Expect(1, 119213, '\p{^Is_Diacritic=f}', "");
Expect(1, 119213, '\P{Is_Diacritic=f}', "");
Expect(0, 119213, '\P{^Is_Diacritic=f}', "");
Expect(1, 119214, '\p{Is_Diacritic= 	F}', "");
Expect(0, 119214, '\p{^Is_Diacritic= 	F}', "");
Expect(0, 119214, '\P{Is_Diacritic= 	F}', "");
Expect(1, 119214, '\P{^Is_Diacritic= 	F}', "");
Expect(0, 119213, '\p{Is_Diacritic= 	F}', "");
Expect(1, 119213, '\p{^Is_Diacritic= 	F}', "");
Expect(1, 119213, '\P{Is_Diacritic= 	F}', "");
Expect(0, 119213, '\P{^Is_Diacritic= 	F}', "");
Error('\p{Is_Dia= -False:=}');
Error('\P{Is_Dia= -False:=}');
Expect(1, 119214, '\p{Is_Dia=false}', "");
Expect(0, 119214, '\p{^Is_Dia=false}', "");
Expect(0, 119214, '\P{Is_Dia=false}', "");
Expect(1, 119214, '\P{^Is_Dia=false}', "");
Expect(0, 119213, '\p{Is_Dia=false}', "");
Expect(1, 119213, '\p{^Is_Dia=false}', "");
Expect(1, 119213, '\P{Is_Dia=false}', "");
Expect(0, 119213, '\P{^Is_Dia=false}', "");
Expect(1, 119214, '\p{Is_Dia=- False}', "");
Expect(0, 119214, '\p{^Is_Dia=- False}', "");
Expect(0, 119214, '\P{Is_Dia=- False}', "");
Expect(1, 119214, '\P{^Is_Dia=- False}', "");
Expect(0, 119213, '\p{Is_Dia=- False}', "");
Expect(1, 119213, '\p{^Is_Dia=- False}', "");
Expect(1, 119213, '\P{Is_Dia=- False}', "");
Expect(0, 119213, '\P{^Is_Dia=- False}', "");
Error('\p{Diacritic=-:=Yes}');
Error('\P{Diacritic=-:=Yes}');
Expect(1, 119213, '\p{Diacritic:	yes}', "");
Expect(0, 119213, '\p{^Diacritic:	yes}', "");
Expect(0, 119213, '\P{Diacritic:	yes}', "");
Expect(1, 119213, '\P{^Diacritic:	yes}', "");
Expect(0, 119214, '\p{Diacritic:	yes}', "");
Expect(1, 119214, '\p{^Diacritic:	yes}', "");
Expect(1, 119214, '\P{Diacritic:	yes}', "");
Expect(0, 119214, '\P{^Diacritic:	yes}', "");
Expect(1, 119213, '\p{Diacritic= 	yes}', "");
Expect(0, 119213, '\p{^Diacritic= 	yes}', "");
Expect(0, 119213, '\P{Diacritic= 	yes}', "");
Expect(1, 119213, '\P{^Diacritic= 	yes}', "");
Expect(0, 119214, '\p{Diacritic= 	yes}', "");
Expect(1, 119214, '\p{^Diacritic= 	yes}', "");
Expect(1, 119214, '\P{Diacritic= 	yes}', "");
Expect(0, 119214, '\P{^Diacritic= 	yes}', "");
Error('\p{Dia=_:=Y}');
Error('\P{Dia=_:=Y}');
Expect(1, 119213, '\p{Dia=y}', "");
Expect(0, 119213, '\p{^Dia=y}', "");
Expect(0, 119213, '\P{Dia=y}', "");
Expect(1, 119213, '\P{^Dia=y}', "");
Expect(0, 119214, '\p{Dia=y}', "");
Expect(1, 119214, '\p{^Dia=y}', "");
Expect(1, 119214, '\P{Dia=y}', "");
Expect(0, 119214, '\P{^Dia=y}', "");
Expect(1, 119213, '\p{Dia=	Y}', "");
Expect(0, 119213, '\p{^Dia=	Y}', "");
Expect(0, 119213, '\P{Dia=	Y}', "");
Expect(1, 119213, '\P{^Dia=	Y}', "");
Expect(0, 119214, '\p{Dia=	Y}', "");
Expect(1, 119214, '\p{^Dia=	Y}', "");
Expect(1, 119214, '\P{Dia=	Y}', "");
Expect(0, 119214, '\P{^Dia=	Y}', "");
Error('\p{Is_Diacritic:/a/_T}');
Error('\P{Is_Diacritic:/a/_T}');
Expect(1, 119213, '\p{Is_Diacritic=t}', "");
Expect(0, 119213, '\p{^Is_Diacritic=t}', "");
Expect(0, 119213, '\P{Is_Diacritic=t}', "");
Expect(1, 119213, '\P{^Is_Diacritic=t}', "");
Expect(0, 119214, '\p{Is_Diacritic=t}', "");
Expect(1, 119214, '\p{^Is_Diacritic=t}', "");
Expect(1, 119214, '\P{Is_Diacritic=t}', "");
Expect(0, 119214, '\P{^Is_Diacritic=t}', "");
Expect(1, 119213, '\p{Is_Diacritic=_	T}', "");
Expect(0, 119213, '\p{^Is_Diacritic=_	T}', "");
Expect(0, 119213, '\P{Is_Diacritic=_	T}', "");
Expect(1, 119213, '\P{^Is_Diacritic=_	T}', "");
Expect(0, 119214, '\p{Is_Diacritic=_	T}', "");
Expect(1, 119214, '\p{^Is_Diacritic=_	T}', "");
Expect(1, 119214, '\P{Is_Diacritic=_	T}', "");
Expect(0, 119214, '\P{^Is_Diacritic=_	T}', "");
Error('\p{Is_Dia=:=_TRUE}');
Error('\P{Is_Dia=:=_TRUE}');
Expect(1, 119213, '\p{Is_Dia:   true}', "");
Expect(0, 119213, '\p{^Is_Dia:   true}', "");
Expect(0, 119213, '\P{Is_Dia:   true}', "");
Expect(1, 119213, '\P{^Is_Dia:   true}', "");
Expect(0, 119214, '\p{Is_Dia:   true}', "");
Expect(1, 119214, '\p{^Is_Dia:   true}', "");
Expect(1, 119214, '\P{Is_Dia:   true}', "");
Expect(0, 119214, '\P{^Is_Dia:   true}', "");
Expect(1, 119213, '\p{Is_Dia:	-TRUE}', "");
Expect(0, 119213, '\p{^Is_Dia:	-TRUE}', "");
Expect(0, 119213, '\P{Is_Dia:	-TRUE}', "");
Expect(1, 119213, '\P{^Is_Dia:	-TRUE}', "");
Expect(0, 119214, '\p{Is_Dia:	-TRUE}', "");
Expect(1, 119214, '\p{^Is_Dia:	-TRUE}', "");
Expect(1, 119214, '\P{Is_Dia:	-TRUE}', "");
Expect(0, 119214, '\P{^Is_Dia:	-TRUE}', "");
Error('\p{Extender=:= 	no}');
Error('\P{Extender=:= 	no}');
Expect(1, 65393, '\p{Extender=no}', "");
Expect(0, 65393, '\p{^Extender=no}', "");
Expect(0, 65393, '\P{Extender=no}', "");
Expect(1, 65393, '\P{^Extender=no}', "");
Expect(0, 65392, '\p{Extender=no}', "");
Expect(1, 65392, '\p{^Extender=no}', "");
Expect(1, 65392, '\P{Extender=no}', "");
Expect(0, 65392, '\P{^Extender=no}', "");
Expect(1, 65393, '\p{Extender= no}', "");
Expect(0, 65393, '\p{^Extender= no}', "");
Expect(0, 65393, '\P{Extender= no}', "");
Expect(1, 65393, '\P{^Extender= no}', "");
Expect(0, 65392, '\p{Extender= no}', "");
Expect(1, 65392, '\p{^Extender= no}', "");
Expect(1, 65392, '\P{Extender= no}', "");
Expect(0, 65392, '\P{^Extender= no}', "");
Error('\p{Ext= /a/N}');
Error('\P{Ext= /a/N}');
Expect(1, 65393, '\p{Ext=n}', "");
Expect(0, 65393, '\p{^Ext=n}', "");
Expect(0, 65393, '\P{Ext=n}', "");
Expect(1, 65393, '\P{^Ext=n}', "");
Expect(0, 65392, '\p{Ext=n}', "");
Expect(1, 65392, '\p{^Ext=n}', "");
Expect(1, 65392, '\P{Ext=n}', "");
Expect(0, 65392, '\P{^Ext=n}', "");
Expect(1, 65393, '\p{Ext= n}', "");
Expect(0, 65393, '\p{^Ext= n}', "");
Expect(0, 65393, '\P{Ext= n}', "");
Expect(1, 65393, '\P{^Ext= n}', "");
Expect(0, 65392, '\p{Ext= n}', "");
Expect(1, 65392, '\p{^Ext= n}', "");
Expect(1, 65392, '\P{Ext= n}', "");
Expect(0, 65392, '\P{^Ext= n}', "");
Error('\p{Is_Extender=:= _F}');
Error('\P{Is_Extender=:= _F}');
Expect(1, 65393, '\p{Is_Extender=f}', "");
Expect(0, 65393, '\p{^Is_Extender=f}', "");
Expect(0, 65393, '\P{Is_Extender=f}', "");
Expect(1, 65393, '\P{^Is_Extender=f}', "");
Expect(0, 65392, '\p{Is_Extender=f}', "");
Expect(1, 65392, '\p{^Is_Extender=f}', "");
Expect(1, 65392, '\P{Is_Extender=f}', "");
Expect(0, 65392, '\P{^Is_Extender=f}', "");
Expect(1, 65393, '\p{Is_Extender=-F}', "");
Expect(0, 65393, '\p{^Is_Extender=-F}', "");
Expect(0, 65393, '\P{Is_Extender=-F}', "");
Expect(1, 65393, '\P{^Is_Extender=-F}', "");
Expect(0, 65392, '\p{Is_Extender=-F}', "");
Expect(1, 65392, '\p{^Is_Extender=-F}', "");
Expect(1, 65392, '\P{Is_Extender=-F}', "");
Expect(0, 65392, '\P{^Is_Extender=-F}', "");
Error('\p{Is_Ext=/a/-False}');
Error('\P{Is_Ext=/a/-False}');
Expect(1, 65393, '\p{Is_Ext=false}', "");
Expect(0, 65393, '\p{^Is_Ext=false}', "");
Expect(0, 65393, '\P{Is_Ext=false}', "");
Expect(1, 65393, '\P{^Is_Ext=false}', "");
Expect(0, 65392, '\p{Is_Ext=false}', "");
Expect(1, 65392, '\p{^Is_Ext=false}', "");
Expect(1, 65392, '\P{Is_Ext=false}', "");
Expect(0, 65392, '\P{^Is_Ext=false}', "");
Expect(1, 65393, '\p{Is_Ext=		False}', "");
Expect(0, 65393, '\p{^Is_Ext=		False}', "");
Expect(0, 65393, '\P{Is_Ext=		False}', "");
Expect(1, 65393, '\P{^Is_Ext=		False}', "");
Expect(0, 65392, '\p{Is_Ext=		False}', "");
Expect(1, 65392, '\p{^Is_Ext=		False}', "");
Expect(1, 65392, '\P{Is_Ext=		False}', "");
Expect(0, 65392, '\P{^Is_Ext=		False}', "");
Error('\p{Extender=	 Yes:=}');
Error('\P{Extender=	 Yes:=}');
Expect(1, 65392, '\p{Extender=yes}', "");
Expect(0, 65392, '\p{^Extender=yes}', "");
Expect(0, 65392, '\P{Extender=yes}', "");
Expect(1, 65392, '\P{^Extender=yes}', "");
Expect(0, 65393, '\p{Extender=yes}', "");
Expect(1, 65393, '\p{^Extender=yes}', "");
Expect(1, 65393, '\P{Extender=yes}', "");
Expect(0, 65393, '\P{^Extender=yes}', "");
Expect(1, 65392, '\p{Extender= yes}', "");
Expect(0, 65392, '\p{^Extender= yes}', "");
Expect(0, 65392, '\P{Extender= yes}', "");
Expect(1, 65392, '\P{^Extender= yes}', "");
Expect(0, 65393, '\p{Extender= yes}', "");
Expect(1, 65393, '\p{^Extender= yes}', "");
Expect(1, 65393, '\P{Extender= yes}', "");
Expect(0, 65393, '\P{^Extender= yes}', "");
Error('\p{Ext= _Y:=}');
Error('\P{Ext= _Y:=}');
Expect(1, 65392, '\p{Ext:   y}', "");
Expect(0, 65392, '\p{^Ext:   y}', "");
Expect(0, 65392, '\P{Ext:   y}', "");
Expect(1, 65392, '\P{^Ext:   y}', "");
Expect(0, 65393, '\p{Ext:   y}', "");
Expect(1, 65393, '\p{^Ext:   y}', "");
Expect(1, 65393, '\P{Ext:   y}', "");
Expect(0, 65393, '\P{^Ext:   y}', "");
Expect(1, 65392, '\p{Ext=	_y}', "");
Expect(0, 65392, '\p{^Ext=	_y}', "");
Expect(0, 65392, '\P{Ext=	_y}', "");
Expect(1, 65392, '\P{^Ext=	_y}', "");
Expect(0, 65393, '\p{Ext=	_y}', "");
Expect(1, 65393, '\p{^Ext=	_y}', "");
Expect(1, 65393, '\P{Ext=	_y}', "");
Expect(0, 65393, '\P{^Ext=	_y}', "");
Error('\p{Is_Extender=	:=T}');
Error('\P{Is_Extender=	:=T}');
Expect(1, 65392, '\p{Is_Extender=t}', "");
Expect(0, 65392, '\p{^Is_Extender=t}', "");
Expect(0, 65392, '\P{Is_Extender=t}', "");
Expect(1, 65392, '\P{^Is_Extender=t}', "");
Expect(0, 65393, '\p{Is_Extender=t}', "");
Expect(1, 65393, '\p{^Is_Extender=t}', "");
Expect(1, 65393, '\P{Is_Extender=t}', "");
Expect(0, 65393, '\P{^Is_Extender=t}', "");
Expect(1, 65392, '\p{Is_Extender= T}', "");
Expect(0, 65392, '\p{^Is_Extender= T}', "");
Expect(0, 65392, '\P{Is_Extender= T}', "");
Expect(1, 65392, '\P{^Is_Extender= T}', "");
Expect(0, 65393, '\p{Is_Extender= T}', "");
Expect(1, 65393, '\p{^Is_Extender= T}', "");
Expect(1, 65393, '\P{Is_Extender= T}', "");
Expect(0, 65393, '\P{^Is_Extender= T}', "");
Error('\p{Is_Ext=/a/		True}');
Error('\P{Is_Ext=/a/		True}');
Expect(1, 65392, '\p{Is_Ext:	true}', "");
Expect(0, 65392, '\p{^Is_Ext:	true}', "");
Expect(0, 65392, '\P{Is_Ext:	true}', "");
Expect(1, 65392, '\P{^Is_Ext:	true}', "");
Expect(0, 65393, '\p{Is_Ext:	true}', "");
Expect(1, 65393, '\p{^Is_Ext:	true}', "");
Expect(1, 65393, '\P{Is_Ext:	true}', "");
Expect(0, 65393, '\P{^Is_Ext:	true}', "");
Expect(1, 65392, '\p{Is_Ext=		true}', "");
Expect(0, 65392, '\p{^Is_Ext=		true}', "");
Expect(0, 65392, '\P{Is_Ext=		true}', "");
Expect(1, 65392, '\P{^Is_Ext=		true}', "");
Expect(0, 65393, '\p{Is_Ext=		true}', "");
Expect(1, 65393, '\p{^Is_Ext=		true}', "");
Expect(1, 65393, '\P{Is_Ext=		true}', "");
Expect(0, 65393, '\P{^Is_Ext=		true}', "");
Error('\p{Grapheme_Cluster_Break=/a/	-Control}');
Error('\P{Grapheme_Cluster_Break=/a/	-Control}');
Expect(1, 921599, '\p{Grapheme_Cluster_Break=control}', "");
Expect(0, 921599, '\p{^Grapheme_Cluster_Break=control}', "");
Expect(0, 921599, '\P{Grapheme_Cluster_Break=control}', "");
Expect(1, 921599, '\P{^Grapheme_Cluster_Break=control}', "");
Expect(0, 921600, '\p{Grapheme_Cluster_Break=control}', "");
Expect(1, 921600, '\p{^Grapheme_Cluster_Break=control}', "");
Expect(1, 921600, '\P{Grapheme_Cluster_Break=control}', "");
Expect(0, 921600, '\P{^Grapheme_Cluster_Break=control}', "");
Expect(1, 921599, '\p{Grapheme_Cluster_Break=_-CONTROL}', "");
Expect(0, 921599, '\p{^Grapheme_Cluster_Break=_-CONTROL}', "");
Expect(0, 921599, '\P{Grapheme_Cluster_Break=_-CONTROL}', "");
Expect(1, 921599, '\P{^Grapheme_Cluster_Break=_-CONTROL}', "");
Expect(0, 921600, '\p{Grapheme_Cluster_Break=_-CONTROL}', "");
Expect(1, 921600, '\p{^Grapheme_Cluster_Break=_-CONTROL}', "");
Expect(1, 921600, '\P{Grapheme_Cluster_Break=_-CONTROL}', "");
Expect(0, 921600, '\P{^Grapheme_Cluster_Break=_-CONTROL}', "");
Error('\p{GCB=_/a/CN}');
Error('\P{GCB=_/a/CN}');
Expect(1, 921599, '\p{GCB:cn}', "");
Expect(0, 921599, '\p{^GCB:cn}', "");
Expect(0, 921599, '\P{GCB:cn}', "");
Expect(1, 921599, '\P{^GCB:cn}', "");
Expect(0, 921600, '\p{GCB:cn}', "");
Expect(1, 921600, '\p{^GCB:cn}', "");
Expect(1, 921600, '\P{GCB:cn}', "");
Expect(0, 921600, '\P{^GCB:cn}', "");
Expect(1, 921599, '\p{GCB=		CN}', "");
Expect(0, 921599, '\p{^GCB=		CN}', "");
Expect(0, 921599, '\P{GCB=		CN}', "");
Expect(1, 921599, '\P{^GCB=		CN}', "");
Expect(0, 921600, '\p{GCB=		CN}', "");
Expect(1, 921600, '\p{^GCB=		CN}', "");
Expect(1, 921600, '\P{GCB=		CN}', "");
Expect(0, 921600, '\P{^GCB=		CN}', "");
Error('\p{Is_Grapheme_Cluster_Break=-/a/Control}');
Error('\P{Is_Grapheme_Cluster_Break=-/a/Control}');
Expect(1, 921599, '\p{Is_Grapheme_Cluster_Break=control}', "");
Expect(0, 921599, '\p{^Is_Grapheme_Cluster_Break=control}', "");
Expect(0, 921599, '\P{Is_Grapheme_Cluster_Break=control}', "");
Expect(1, 921599, '\P{^Is_Grapheme_Cluster_Break=control}', "");
Expect(0, 921600, '\p{Is_Grapheme_Cluster_Break=control}', "");
Expect(1, 921600, '\p{^Is_Grapheme_Cluster_Break=control}', "");
Expect(1, 921600, '\P{Is_Grapheme_Cluster_Break=control}', "");
Expect(0, 921600, '\P{^Is_Grapheme_Cluster_Break=control}', "");
Expect(1, 921599, '\p{Is_Grapheme_Cluster_Break=	control}', "");
Expect(0, 921599, '\p{^Is_Grapheme_Cluster_Break=	control}', "");
Expect(0, 921599, '\P{Is_Grapheme_Cluster_Break=	control}', "");
Expect(1, 921599, '\P{^Is_Grapheme_Cluster_Break=	control}', "");
Expect(0, 921600, '\p{Is_Grapheme_Cluster_Break=	control}', "");
Expect(1, 921600, '\p{^Is_Grapheme_Cluster_Break=	control}', "");
Expect(1, 921600, '\P{Is_Grapheme_Cluster_Break=	control}', "");
Expect(0, 921600, '\P{^Is_Grapheme_Cluster_Break=	control}', "");
Error('\p{Is_GCB:	- CN/a/}');
Error('\P{Is_GCB:	- CN/a/}');
Expect(1, 921599, '\p{Is_GCB=cn}', "");
Expect(0, 921599, '\p{^Is_GCB=cn}', "");
Expect(0, 921599, '\P{Is_GCB=cn}', "");
Expect(1, 921599, '\P{^Is_GCB=cn}', "");
Expect(0, 921600, '\p{Is_GCB=cn}', "");
Expect(1, 921600, '\p{^Is_GCB=cn}', "");
Expect(1, 921600, '\P{Is_GCB=cn}', "");
Expect(0, 921600, '\P{^Is_GCB=cn}', "");
Expect(1, 921599, '\p{Is_GCB=	cn}', "");
Expect(0, 921599, '\p{^Is_GCB=	cn}', "");
Expect(0, 921599, '\P{Is_GCB=	cn}', "");
Expect(1, 921599, '\P{^Is_GCB=	cn}', "");
Expect(0, 921600, '\p{Is_GCB=	cn}', "");
Expect(1, 921600, '\p{^Is_GCB=	cn}', "");
Expect(1, 921600, '\P{Is_GCB=	cn}', "");
Expect(0, 921600, '\P{^Is_GCB=	cn}', "");
Error('\p{Grapheme_Cluster_Break=/a/ _CR}');
Error('\P{Grapheme_Cluster_Break=/a/ _CR}');
Expect(1, 13, '\p{Grapheme_Cluster_Break=cr}', "");
Expect(0, 13, '\p{^Grapheme_Cluster_Break=cr}', "");
Expect(0, 13, '\P{Grapheme_Cluster_Break=cr}', "");
Expect(1, 13, '\P{^Grapheme_Cluster_Break=cr}', "");
Expect(0, 14, '\p{Grapheme_Cluster_Break=cr}', "");
Expect(1, 14, '\p{^Grapheme_Cluster_Break=cr}', "");
Expect(1, 14, '\P{Grapheme_Cluster_Break=cr}', "");
Expect(0, 14, '\P{^Grapheme_Cluster_Break=cr}', "");
Expect(1, 13, '\p{Grapheme_Cluster_Break= CR}', "");
Expect(0, 13, '\p{^Grapheme_Cluster_Break= CR}', "");
Expect(0, 13, '\P{Grapheme_Cluster_Break= CR}', "");
Expect(1, 13, '\P{^Grapheme_Cluster_Break= CR}', "");
Expect(0, 14, '\p{Grapheme_Cluster_Break= CR}', "");
Expect(1, 14, '\p{^Grapheme_Cluster_Break= CR}', "");
Expect(1, 14, '\P{Grapheme_Cluster_Break= CR}', "");
Expect(0, 14, '\P{^Grapheme_Cluster_Break= CR}', "");
Error('\p{GCB=:=	 CR}');
Error('\P{GCB=:=	 CR}');
Expect(1, 13, '\p{GCB=cr}', "");
Expect(0, 13, '\p{^GCB=cr}', "");
Expect(0, 13, '\P{GCB=cr}', "");
Expect(1, 13, '\P{^GCB=cr}', "");
Expect(0, 14, '\p{GCB=cr}', "");
Expect(1, 14, '\p{^GCB=cr}', "");
Expect(1, 14, '\P{GCB=cr}', "");
Expect(0, 14, '\P{^GCB=cr}', "");
Expect(1, 13, '\p{GCB= 	CR}', "");
Expect(0, 13, '\p{^GCB= 	CR}', "");
Expect(0, 13, '\P{GCB= 	CR}', "");
Expect(1, 13, '\P{^GCB= 	CR}', "");
Expect(0, 14, '\p{GCB= 	CR}', "");
Expect(1, 14, '\p{^GCB= 	CR}', "");
Expect(1, 14, '\P{GCB= 	CR}', "");
Expect(0, 14, '\P{^GCB= 	CR}', "");
Error('\p{Is_Grapheme_Cluster_Break=	-cr/a/}');
Error('\P{Is_Grapheme_Cluster_Break=	-cr/a/}');
Expect(1, 13, '\p{Is_Grapheme_Cluster_Break=cr}', "");
Expect(0, 13, '\p{^Is_Grapheme_Cluster_Break=cr}', "");
Expect(0, 13, '\P{Is_Grapheme_Cluster_Break=cr}', "");
Expect(1, 13, '\P{^Is_Grapheme_Cluster_Break=cr}', "");
Expect(0, 14, '\p{Is_Grapheme_Cluster_Break=cr}', "");
Expect(1, 14, '\p{^Is_Grapheme_Cluster_Break=cr}', "");
Expect(1, 14, '\P{Is_Grapheme_Cluster_Break=cr}', "");
Expect(0, 14, '\P{^Is_Grapheme_Cluster_Break=cr}', "");
Expect(1, 13, '\p{Is_Grapheme_Cluster_Break=-CR}', "");
Expect(0, 13, '\p{^Is_Grapheme_Cluster_Break=-CR}', "");
Expect(0, 13, '\P{Is_Grapheme_Cluster_Break=-CR}', "");
Expect(1, 13, '\P{^Is_Grapheme_Cluster_Break=-CR}', "");
Expect(0, 14, '\p{Is_Grapheme_Cluster_Break=-CR}', "");
Expect(1, 14, '\p{^Is_Grapheme_Cluster_Break=-CR}', "");
Expect(1, 14, '\P{Is_Grapheme_Cluster_Break=-CR}', "");
Expect(0, 14, '\P{^Is_Grapheme_Cluster_Break=-CR}', "");
Error('\p{Is_GCB= -cr/a/}');
Error('\P{Is_GCB= -cr/a/}');
Expect(1, 13, '\p{Is_GCB=cr}', "");
Expect(0, 13, '\p{^Is_GCB=cr}', "");
Expect(0, 13, '\P{Is_GCB=cr}', "");
Expect(1, 13, '\P{^Is_GCB=cr}', "");
Expect(0, 14, '\p{Is_GCB=cr}', "");
Expect(1, 14, '\p{^Is_GCB=cr}', "");
Expect(1, 14, '\P{Is_GCB=cr}', "");
Expect(0, 14, '\P{^Is_GCB=cr}', "");
Expect(1, 13, '\p{Is_GCB= 	cr}', "");
Expect(0, 13, '\p{^Is_GCB= 	cr}', "");
Expect(0, 13, '\P{Is_GCB= 	cr}', "");
Expect(1, 13, '\P{^Is_GCB= 	cr}', "");
Expect(0, 14, '\p{Is_GCB= 	cr}', "");
Expect(1, 14, '\p{^Is_GCB= 	cr}', "");
Expect(1, 14, '\P{Is_GCB= 	cr}', "");
Expect(0, 14, '\P{^Is_GCB= 	cr}', "");
Error('\p{Grapheme_Cluster_Break=_extend:=}');
Error('\P{Grapheme_Cluster_Break=_extend:=}');
Expect(1, 917999, '\p{Grapheme_Cluster_Break:	extend}', "");
Expect(0, 917999, '\p{^Grapheme_Cluster_Break:	extend}', "");
Expect(0, 917999, '\P{Grapheme_Cluster_Break:	extend}', "");
Expect(1, 917999, '\P{^Grapheme_Cluster_Break:	extend}', "");
Expect(0, 918000, '\p{Grapheme_Cluster_Break:	extend}', "");
Expect(1, 918000, '\p{^Grapheme_Cluster_Break:	extend}', "");
Expect(1, 918000, '\P{Grapheme_Cluster_Break:	extend}', "");
Expect(0, 918000, '\P{^Grapheme_Cluster_Break:	extend}', "");
Expect(1, 917999, '\p{Grapheme_Cluster_Break=  EXTEND}', "");
Expect(0, 917999, '\p{^Grapheme_Cluster_Break=  EXTEND}', "");
Expect(0, 917999, '\P{Grapheme_Cluster_Break=  EXTEND}', "");
Expect(1, 917999, '\P{^Grapheme_Cluster_Break=  EXTEND}', "");
Expect(0, 918000, '\p{Grapheme_Cluster_Break=  EXTEND}', "");
Expect(1, 918000, '\p{^Grapheme_Cluster_Break=  EXTEND}', "");
Expect(1, 918000, '\P{Grapheme_Cluster_Break=  EXTEND}', "");
Expect(0, 918000, '\P{^Grapheme_Cluster_Break=  EXTEND}', "");
Error('\p{GCB=:= EX}');
Error('\P{GCB=:= EX}');
Expect(1, 917999, '\p{GCB=ex}', "");
Expect(0, 917999, '\p{^GCB=ex}', "");
Expect(0, 917999, '\P{GCB=ex}', "");
Expect(1, 917999, '\P{^GCB=ex}', "");
Expect(0, 918000, '\p{GCB=ex}', "");
Expect(1, 918000, '\p{^GCB=ex}', "");
Expect(1, 918000, '\P{GCB=ex}', "");
Expect(0, 918000, '\P{^GCB=ex}', "");
Expect(1, 917999, '\p{GCB:	 EX}', "");
Expect(0, 917999, '\p{^GCB:	 EX}', "");
Expect(0, 917999, '\P{GCB:	 EX}', "");
Expect(1, 917999, '\P{^GCB:	 EX}', "");
Expect(0, 918000, '\p{GCB:	 EX}', "");
Expect(1, 918000, '\p{^GCB:	 EX}', "");
Expect(1, 918000, '\P{GCB:	 EX}', "");
Expect(0, 918000, '\P{^GCB:	 EX}', "");
Error('\p{Is_Grapheme_Cluster_Break=:=	_extend}');
Error('\P{Is_Grapheme_Cluster_Break=:=	_extend}');
Expect(1, 917999, '\p{Is_Grapheme_Cluster_Break:	extend}', "");
Expect(0, 917999, '\p{^Is_Grapheme_Cluster_Break:	extend}', "");
Expect(0, 917999, '\P{Is_Grapheme_Cluster_Break:	extend}', "");
Expect(1, 917999, '\P{^Is_Grapheme_Cluster_Break:	extend}', "");
Expect(0, 918000, '\p{Is_Grapheme_Cluster_Break:	extend}', "");
Expect(1, 918000, '\p{^Is_Grapheme_Cluster_Break:	extend}', "");
Expect(1, 918000, '\P{Is_Grapheme_Cluster_Break:	extend}', "");
Expect(0, 918000, '\P{^Is_Grapheme_Cluster_Break:	extend}', "");
Expect(1, 917999, '\p{Is_Grapheme_Cluster_Break=	 EXTEND}', "");
Expect(0, 917999, '\p{^Is_Grapheme_Cluster_Break=	 EXTEND}', "");
Expect(0, 917999, '\P{Is_Grapheme_Cluster_Break=	 EXTEND}', "");
Expect(1, 917999, '\P{^Is_Grapheme_Cluster_Break=	 EXTEND}', "");
Expect(0, 918000, '\p{Is_Grapheme_Cluster_Break=	 EXTEND}', "");
Expect(1, 918000, '\p{^Is_Grapheme_Cluster_Break=	 EXTEND}', "");
Expect(1, 918000, '\P{Is_Grapheme_Cluster_Break=	 EXTEND}', "");
Expect(0, 918000, '\P{^Is_Grapheme_Cluster_Break=	 EXTEND}', "");
Error('\p{Is_GCB=:= 	EX}');
Error('\P{Is_GCB=:= 	EX}');
Expect(1, 917999, '\p{Is_GCB=ex}', "");
Expect(0, 917999, '\p{^Is_GCB=ex}', "");
Expect(0, 917999, '\P{Is_GCB=ex}', "");
Expect(1, 917999, '\P{^Is_GCB=ex}', "");
Expect(0, 918000, '\p{Is_GCB=ex}', "");
Expect(1, 918000, '\p{^Is_GCB=ex}', "");
Expect(1, 918000, '\P{Is_GCB=ex}', "");
Expect(0, 918000, '\P{^Is_GCB=ex}', "");
Expect(1, 917999, '\p{Is_GCB=- EX}', "");
Expect(0, 917999, '\p{^Is_GCB=- EX}', "");
Expect(0, 917999, '\P{Is_GCB=- EX}', "");
Expect(1, 917999, '\P{^Is_GCB=- EX}', "");
Expect(0, 918000, '\p{Is_GCB=- EX}', "");
Expect(1, 918000, '\p{^Is_GCB=- EX}', "");
Expect(1, 918000, '\P{Is_GCB=- EX}', "");
Expect(0, 918000, '\P{^Is_GCB=- EX}', "");
Error('\p{Grapheme_Cluster_Break=	l/a/}');
Error('\P{Grapheme_Cluster_Break=	l/a/}');
Expect(1, 43388, '\p{Grapheme_Cluster_Break=l}', "");
Expect(0, 43388, '\p{^Grapheme_Cluster_Break=l}', "");
Expect(0, 43388, '\P{Grapheme_Cluster_Break=l}', "");
Expect(1, 43388, '\P{^Grapheme_Cluster_Break=l}', "");
Expect(0, 43389, '\p{Grapheme_Cluster_Break=l}', "");
Expect(1, 43389, '\p{^Grapheme_Cluster_Break=l}', "");
Expect(1, 43389, '\P{Grapheme_Cluster_Break=l}', "");
Expect(0, 43389, '\P{^Grapheme_Cluster_Break=l}', "");
Expect(1, 43388, '\p{Grapheme_Cluster_Break=__L}', "");
Expect(0, 43388, '\p{^Grapheme_Cluster_Break=__L}', "");
Expect(0, 43388, '\P{Grapheme_Cluster_Break=__L}', "");
Expect(1, 43388, '\P{^Grapheme_Cluster_Break=__L}', "");
Expect(0, 43389, '\p{Grapheme_Cluster_Break=__L}', "");
Expect(1, 43389, '\p{^Grapheme_Cluster_Break=__L}', "");
Expect(1, 43389, '\P{Grapheme_Cluster_Break=__L}', "");
Expect(0, 43389, '\P{^Grapheme_Cluster_Break=__L}', "");
Error('\p{GCB=  L:=}');
Error('\P{GCB=  L:=}');
Expect(1, 43388, '\p{GCB=l}', "");
Expect(0, 43388, '\p{^GCB=l}', "");
Expect(0, 43388, '\P{GCB=l}', "");
Expect(1, 43388, '\P{^GCB=l}', "");
Expect(0, 43389, '\p{GCB=l}', "");
Expect(1, 43389, '\p{^GCB=l}', "");
Expect(1, 43389, '\P{GCB=l}', "");
Expect(0, 43389, '\P{^GCB=l}', "");
Expect(1, 43388, '\p{GCB= -L}', "");
Expect(0, 43388, '\p{^GCB= -L}', "");
Expect(0, 43388, '\P{GCB= -L}', "");
Expect(1, 43388, '\P{^GCB= -L}', "");
Expect(0, 43389, '\p{GCB= -L}', "");
Expect(1, 43389, '\p{^GCB= -L}', "");
Expect(1, 43389, '\P{GCB= -L}', "");
Expect(0, 43389, '\P{^GCB= -L}', "");
Error('\p{Is_Grapheme_Cluster_Break:	  l:=}');
Error('\P{Is_Grapheme_Cluster_Break:	  l:=}');
Expect(1, 43388, '\p{Is_Grapheme_Cluster_Break=l}', "");
Expect(0, 43388, '\p{^Is_Grapheme_Cluster_Break=l}', "");
Expect(0, 43388, '\P{Is_Grapheme_Cluster_Break=l}', "");
Expect(1, 43388, '\P{^Is_Grapheme_Cluster_Break=l}', "");
Expect(0, 43389, '\p{Is_Grapheme_Cluster_Break=l}', "");
Expect(1, 43389, '\p{^Is_Grapheme_Cluster_Break=l}', "");
Expect(1, 43389, '\P{Is_Grapheme_Cluster_Break=l}', "");
Expect(0, 43389, '\P{^Is_Grapheme_Cluster_Break=l}', "");
Expect(1, 43388, '\p{Is_Grapheme_Cluster_Break=L}', "");
Expect(0, 43388, '\p{^Is_Grapheme_Cluster_Break=L}', "");
Expect(0, 43388, '\P{Is_Grapheme_Cluster_Break=L}', "");
Expect(1, 43388, '\P{^Is_Grapheme_Cluster_Break=L}', "");
Expect(0, 43389, '\p{Is_Grapheme_Cluster_Break=L}', "");
Expect(1, 43389, '\p{^Is_Grapheme_Cluster_Break=L}', "");
Expect(1, 43389, '\P{Is_Grapheme_Cluster_Break=L}', "");
Expect(0, 43389, '\P{^Is_Grapheme_Cluster_Break=L}', "");
Error('\p{Is_GCB=	_L:=}');
Error('\P{Is_GCB=	_L:=}');
Expect(1, 43388, '\p{Is_GCB=l}', "");
Expect(0, 43388, '\p{^Is_GCB=l}', "");
Expect(0, 43388, '\P{Is_GCB=l}', "");
Expect(1, 43388, '\P{^Is_GCB=l}', "");
Expect(0, 43389, '\p{Is_GCB=l}', "");
Expect(1, 43389, '\p{^Is_GCB=l}', "");
Expect(1, 43389, '\P{Is_GCB=l}', "");
Expect(0, 43389, '\P{^Is_GCB=l}', "");
Expect(1, 43388, '\p{Is_GCB=-_L}', "");
Expect(0, 43388, '\p{^Is_GCB=-_L}', "");
Expect(0, 43388, '\P{Is_GCB=-_L}', "");
Expect(1, 43388, '\P{^Is_GCB=-_L}', "");
Expect(0, 43389, '\p{Is_GCB=-_L}', "");
Expect(1, 43389, '\p{^Is_GCB=-_L}', "");
Expect(1, 43389, '\P{Is_GCB=-_L}', "");
Expect(0, 43389, '\P{^Is_GCB=-_L}', "");
Error('\p{Grapheme_Cluster_Break:  LF:=}');
Error('\P{Grapheme_Cluster_Break:  LF:=}');
Expect(1, 10, '\p{Grapheme_Cluster_Break=lf}', "");
Expect(0, 10, '\p{^Grapheme_Cluster_Break=lf}', "");
Expect(0, 10, '\P{Grapheme_Cluster_Break=lf}', "");
Expect(1, 10, '\P{^Grapheme_Cluster_Break=lf}', "");
Expect(0, 11, '\p{Grapheme_Cluster_Break=lf}', "");
Expect(1, 11, '\p{^Grapheme_Cluster_Break=lf}', "");
Expect(1, 11, '\P{Grapheme_Cluster_Break=lf}', "");
Expect(0, 11, '\P{^Grapheme_Cluster_Break=lf}', "");
Expect(1, 10, '\p{Grapheme_Cluster_Break=__LF}', "");
Expect(0, 10, '\p{^Grapheme_Cluster_Break=__LF}', "");
Expect(0, 10, '\P{Grapheme_Cluster_Break=__LF}', "");
Expect(1, 10, '\P{^Grapheme_Cluster_Break=__LF}', "");
Expect(0, 11, '\p{Grapheme_Cluster_Break=__LF}', "");
Expect(1, 11, '\p{^Grapheme_Cluster_Break=__LF}', "");
Expect(1, 11, '\P{Grapheme_Cluster_Break=__LF}', "");
Expect(0, 11, '\P{^Grapheme_Cluster_Break=__LF}', "");
Error('\p{GCB= :=lf}');
Error('\P{GCB= :=lf}');
Expect(1, 10, '\p{GCB:   lf}', "");
Expect(0, 10, '\p{^GCB:   lf}', "");
Expect(0, 10, '\P{GCB:   lf}', "");
Expect(1, 10, '\P{^GCB:   lf}', "");
Expect(0, 11, '\p{GCB:   lf}', "");
Expect(1, 11, '\p{^GCB:   lf}', "");
Expect(1, 11, '\P{GCB:   lf}', "");
Expect(0, 11, '\P{^GCB:   lf}', "");
Expect(1, 10, '\p{GCB=	_LF}', "");
Expect(0, 10, '\p{^GCB=	_LF}', "");
Expect(0, 10, '\P{GCB=	_LF}', "");
Expect(1, 10, '\P{^GCB=	_LF}', "");
Expect(0, 11, '\p{GCB=	_LF}', "");
Expect(1, 11, '\p{^GCB=	_LF}', "");
Expect(1, 11, '\P{GCB=	_LF}', "");
Expect(0, 11, '\P{^GCB=	_LF}', "");
Error('\p{Is_Grapheme_Cluster_Break=	-LF/a/}');
Error('\P{Is_Grapheme_Cluster_Break=	-LF/a/}');
Expect(1, 10, '\p{Is_Grapheme_Cluster_Break=lf}', "");
Expect(0, 10, '\p{^Is_Grapheme_Cluster_Break=lf}', "");
Expect(0, 10, '\P{Is_Grapheme_Cluster_Break=lf}', "");
Expect(1, 10, '\P{^Is_Grapheme_Cluster_Break=lf}', "");
Expect(0, 11, '\p{Is_Grapheme_Cluster_Break=lf}', "");
Expect(1, 11, '\p{^Is_Grapheme_Cluster_Break=lf}', "");
Expect(1, 11, '\P{Is_Grapheme_Cluster_Break=lf}', "");
Expect(0, 11, '\P{^Is_Grapheme_Cluster_Break=lf}', "");
Expect(1, 10, '\p{Is_Grapheme_Cluster_Break=	_LF}', "");
Expect(0, 10, '\p{^Is_Grapheme_Cluster_Break=	_LF}', "");
Expect(0, 10, '\P{Is_Grapheme_Cluster_Break=	_LF}', "");
Expect(1, 10, '\P{^Is_Grapheme_Cluster_Break=	_LF}', "");
Expect(0, 11, '\p{Is_Grapheme_Cluster_Break=	_LF}', "");
Expect(1, 11, '\p{^Is_Grapheme_Cluster_Break=	_LF}', "");
Expect(1, 11, '\P{Is_Grapheme_Cluster_Break=	_LF}', "");
Expect(0, 11, '\P{^Is_Grapheme_Cluster_Break=	_LF}', "");
Error('\p{Is_GCB::=	lf}');
Error('\P{Is_GCB::=	lf}');
Expect(1, 10, '\p{Is_GCB: lf}', "");
Expect(0, 10, '\p{^Is_GCB: lf}', "");
Expect(0, 10, '\P{Is_GCB: lf}', "");
Expect(1, 10, '\P{^Is_GCB: lf}', "");
Expect(0, 11, '\p{Is_GCB: lf}', "");
Expect(1, 11, '\p{^Is_GCB: lf}', "");
Expect(1, 11, '\P{Is_GCB: lf}', "");
Expect(0, 11, '\P{^Is_GCB: lf}', "");
Expect(1, 10, '\p{Is_GCB= LF}', "");
Expect(0, 10, '\p{^Is_GCB= LF}', "");
Expect(0, 10, '\P{Is_GCB= LF}', "");
Expect(1, 10, '\P{^Is_GCB= LF}', "");
Expect(0, 11, '\p{Is_GCB= LF}', "");
Expect(1, 11, '\p{^Is_GCB= LF}', "");
Expect(1, 11, '\P{Is_GCB= LF}', "");
Expect(0, 11, '\P{^Is_GCB= LF}', "");
Error('\p{Grapheme_Cluster_Break=  lv/a/}');
Error('\P{Grapheme_Cluster_Break=  lv/a/}');
Expect(1, 55176, '\p{Grapheme_Cluster_Break=lv}', "");
Expect(0, 55176, '\p{^Grapheme_Cluster_Break=lv}', "");
Expect(0, 55176, '\P{Grapheme_Cluster_Break=lv}', "");
Expect(1, 55176, '\P{^Grapheme_Cluster_Break=lv}', "");
Expect(0, 55177, '\p{Grapheme_Cluster_Break=lv}', "");
Expect(1, 55177, '\p{^Grapheme_Cluster_Break=lv}', "");
Expect(1, 55177, '\P{Grapheme_Cluster_Break=lv}', "");
Expect(0, 55177, '\P{^Grapheme_Cluster_Break=lv}', "");
Expect(1, 55176, '\p{Grapheme_Cluster_Break:	-LV}', "");
Expect(0, 55176, '\p{^Grapheme_Cluster_Break:	-LV}', "");
Expect(0, 55176, '\P{Grapheme_Cluster_Break:	-LV}', "");
Expect(1, 55176, '\P{^Grapheme_Cluster_Break:	-LV}', "");
Expect(0, 55177, '\p{Grapheme_Cluster_Break:	-LV}', "");
Expect(1, 55177, '\p{^Grapheme_Cluster_Break:	-LV}', "");
Expect(1, 55177, '\P{Grapheme_Cluster_Break:	-LV}', "");
Expect(0, 55177, '\P{^Grapheme_Cluster_Break:	-LV}', "");
Error('\p{GCB=	LV:=}');
Error('\P{GCB=	LV:=}');
Expect(1, 55176, '\p{GCB: lv}', "");
Expect(0, 55176, '\p{^GCB: lv}', "");
Expect(0, 55176, '\P{GCB: lv}', "");
Expect(1, 55176, '\P{^GCB: lv}', "");
Expect(0, 55177, '\p{GCB: lv}', "");
Expect(1, 55177, '\p{^GCB: lv}', "");
Expect(1, 55177, '\P{GCB: lv}', "");
Expect(0, 55177, '\P{^GCB: lv}', "");
Expect(1, 55176, '\p{GCB=_ lv}', "");
Expect(0, 55176, '\p{^GCB=_ lv}', "");
Expect(0, 55176, '\P{GCB=_ lv}', "");
Expect(1, 55176, '\P{^GCB=_ lv}', "");
Expect(0, 55177, '\p{GCB=_ lv}', "");
Expect(1, 55177, '\p{^GCB=_ lv}', "");
Expect(1, 55177, '\P{GCB=_ lv}', "");
Expect(0, 55177, '\P{^GCB=_ lv}', "");
Error('\p{Is_Grapheme_Cluster_Break=:=- LV}');
Error('\P{Is_Grapheme_Cluster_Break=:=- LV}');
Expect(1, 55176, '\p{Is_Grapheme_Cluster_Break=lv}', "");
Expect(0, 55176, '\p{^Is_Grapheme_Cluster_Break=lv}', "");
Expect(0, 55176, '\P{Is_Grapheme_Cluster_Break=lv}', "");
Expect(1, 55176, '\P{^Is_Grapheme_Cluster_Break=lv}', "");
Expect(0, 55177, '\p{Is_Grapheme_Cluster_Break=lv}', "");
Expect(1, 55177, '\p{^Is_Grapheme_Cluster_Break=lv}', "");
Expect(1, 55177, '\P{Is_Grapheme_Cluster_Break=lv}', "");
Expect(0, 55177, '\P{^Is_Grapheme_Cluster_Break=lv}', "");
Expect(1, 55176, '\p{Is_Grapheme_Cluster_Break=-LV}', "");
Expect(0, 55176, '\p{^Is_Grapheme_Cluster_Break=-LV}', "");
Expect(0, 55176, '\P{Is_Grapheme_Cluster_Break=-LV}', "");
Expect(1, 55176, '\P{^Is_Grapheme_Cluster_Break=-LV}', "");
Expect(0, 55177, '\p{Is_Grapheme_Cluster_Break=-LV}', "");
Expect(1, 55177, '\p{^Is_Grapheme_Cluster_Break=-LV}', "");
Expect(1, 55177, '\P{Is_Grapheme_Cluster_Break=-LV}', "");
Expect(0, 55177, '\P{^Is_Grapheme_Cluster_Break=-LV}', "");
Error('\p{Is_GCB=_	LV:=}');
Error('\P{Is_GCB=_	LV:=}');
Expect(1, 55176, '\p{Is_GCB=lv}', "");
Expect(0, 55176, '\p{^Is_GCB=lv}', "");
Expect(0, 55176, '\P{Is_GCB=lv}', "");
Expect(1, 55176, '\P{^Is_GCB=lv}', "");
Expect(0, 55177, '\p{Is_GCB=lv}', "");
Expect(1, 55177, '\p{^Is_GCB=lv}', "");
Expect(1, 55177, '\P{Is_GCB=lv}', "");
Expect(0, 55177, '\P{^Is_GCB=lv}', "");
Expect(1, 55176, '\p{Is_GCB=	_lv}', "");
Expect(0, 55176, '\p{^Is_GCB=	_lv}', "");
Expect(0, 55176, '\P{Is_GCB=	_lv}', "");
Expect(1, 55176, '\P{^Is_GCB=	_lv}', "");
Expect(0, 55177, '\p{Is_GCB=	_lv}', "");
Expect(1, 55177, '\p{^Is_GCB=	_lv}', "");
Expect(1, 55177, '\P{Is_GCB=	_lv}', "");
Expect(0, 55177, '\P{^Is_GCB=	_lv}', "");
Error('\p{Grapheme_Cluster_Break=__lvt/a/}');
Error('\P{Grapheme_Cluster_Break=__lvt/a/}');
Expect(1, 55203, '\p{Grapheme_Cluster_Break=lvt}', "");
Expect(0, 55203, '\p{^Grapheme_Cluster_Break=lvt}', "");
Expect(0, 55203, '\P{Grapheme_Cluster_Break=lvt}', "");
Expect(1, 55203, '\P{^Grapheme_Cluster_Break=lvt}', "");
Expect(0, 55204, '\p{Grapheme_Cluster_Break=lvt}', "");
Expect(1, 55204, '\p{^Grapheme_Cluster_Break=lvt}', "");
Expect(1, 55204, '\P{Grapheme_Cluster_Break=lvt}', "");
Expect(0, 55204, '\P{^Grapheme_Cluster_Break=lvt}', "");
Expect(1, 55203, '\p{Grapheme_Cluster_Break=	 lvt}', "");
Expect(0, 55203, '\p{^Grapheme_Cluster_Break=	 lvt}', "");
Expect(0, 55203, '\P{Grapheme_Cluster_Break=	 lvt}', "");
Expect(1, 55203, '\P{^Grapheme_Cluster_Break=	 lvt}', "");
Expect(0, 55204, '\p{Grapheme_Cluster_Break=	 lvt}', "");
Expect(1, 55204, '\p{^Grapheme_Cluster_Break=	 lvt}', "");
Expect(1, 55204, '\P{Grapheme_Cluster_Break=	 lvt}', "");
Expect(0, 55204, '\P{^Grapheme_Cluster_Break=	 lvt}', "");
Error('\p{GCB= LVT/a/}');
Error('\P{GCB= LVT/a/}');
Expect(1, 55203, '\p{GCB=lvt}', "");
Expect(0, 55203, '\p{^GCB=lvt}', "");
Expect(0, 55203, '\P{GCB=lvt}', "");
Expect(1, 55203, '\P{^GCB=lvt}', "");
Expect(0, 55204, '\p{GCB=lvt}', "");
Expect(1, 55204, '\p{^GCB=lvt}', "");
Expect(1, 55204, '\P{GCB=lvt}', "");
Expect(0, 55204, '\P{^GCB=lvt}', "");
Expect(1, 55203, '\p{GCB=_ LVT}', "");
Expect(0, 55203, '\p{^GCB=_ LVT}', "");
Expect(0, 55203, '\P{GCB=_ LVT}', "");
Expect(1, 55203, '\P{^GCB=_ LVT}', "");
Expect(0, 55204, '\p{GCB=_ LVT}', "");
Expect(1, 55204, '\p{^GCB=_ LVT}', "");
Expect(1, 55204, '\P{GCB=_ LVT}', "");
Expect(0, 55204, '\P{^GCB=_ LVT}', "");
Error('\p{Is_Grapheme_Cluster_Break=--LVT/a/}');
Error('\P{Is_Grapheme_Cluster_Break=--LVT/a/}');
Expect(1, 55203, '\p{Is_Grapheme_Cluster_Break: lvt}', "");
Expect(0, 55203, '\p{^Is_Grapheme_Cluster_Break: lvt}', "");
Expect(0, 55203, '\P{Is_Grapheme_Cluster_Break: lvt}', "");
Expect(1, 55203, '\P{^Is_Grapheme_Cluster_Break: lvt}', "");
Expect(0, 55204, '\p{Is_Grapheme_Cluster_Break: lvt}', "");
Expect(1, 55204, '\p{^Is_Grapheme_Cluster_Break: lvt}', "");
Expect(1, 55204, '\P{Is_Grapheme_Cluster_Break: lvt}', "");
Expect(0, 55204, '\P{^Is_Grapheme_Cluster_Break: lvt}', "");
Expect(1, 55203, '\p{Is_Grapheme_Cluster_Break:   - LVT}', "");
Expect(0, 55203, '\p{^Is_Grapheme_Cluster_Break:   - LVT}', "");
Expect(0, 55203, '\P{Is_Grapheme_Cluster_Break:   - LVT}', "");
Expect(1, 55203, '\P{^Is_Grapheme_Cluster_Break:   - LVT}', "");
Expect(0, 55204, '\p{Is_Grapheme_Cluster_Break:   - LVT}', "");
Expect(1, 55204, '\p{^Is_Grapheme_Cluster_Break:   - LVT}', "");
Expect(1, 55204, '\P{Is_Grapheme_Cluster_Break:   - LVT}', "");
Expect(0, 55204, '\P{^Is_Grapheme_Cluster_Break:   - LVT}', "");
Error('\p{Is_GCB=-:=LVT}');
Error('\P{Is_GCB=-:=LVT}');
Expect(1, 55203, '\p{Is_GCB=lvt}', "");
Expect(0, 55203, '\p{^Is_GCB=lvt}', "");
Expect(0, 55203, '\P{Is_GCB=lvt}', "");
Expect(1, 55203, '\P{^Is_GCB=lvt}', "");
Expect(0, 55204, '\p{Is_GCB=lvt}', "");
Expect(1, 55204, '\p{^Is_GCB=lvt}', "");
Expect(1, 55204, '\P{Is_GCB=lvt}', "");
Expect(0, 55204, '\P{^Is_GCB=lvt}', "");
Expect(1, 55203, '\p{Is_GCB=-_lvt}', "");
Expect(0, 55203, '\p{^Is_GCB=-_lvt}', "");
Expect(0, 55203, '\P{Is_GCB=-_lvt}', "");
Expect(1, 55203, '\P{^Is_GCB=-_lvt}', "");
Expect(0, 55204, '\p{Is_GCB=-_lvt}', "");
Expect(1, 55204, '\p{^Is_GCB=-_lvt}', "");
Expect(1, 55204, '\P{Is_GCB=-_lvt}', "");
Expect(0, 55204, '\P{^Is_GCB=-_lvt}', "");
Error('\p{Grapheme_Cluster_Break=:=_ Prepend}');
Error('\P{Grapheme_Cluster_Break=:=_ Prepend}');
Expect(0, 1, '\p{Grapheme_Cluster_Break=prepend}', "");
Expect(1, 1, '\p{^Grapheme_Cluster_Break=prepend}', "");
Expect(1, 1, '\P{Grapheme_Cluster_Break=prepend}', "");
Expect(0, 1, '\P{^Grapheme_Cluster_Break=prepend}', "");
Expect(0, 1, '\p{Grapheme_Cluster_Break= 	PREPEND}', "");
Expect(1, 1, '\p{^Grapheme_Cluster_Break= 	PREPEND}', "");
Expect(1, 1, '\P{Grapheme_Cluster_Break= 	PREPEND}', "");
Expect(0, 1, '\P{^Grapheme_Cluster_Break= 	PREPEND}', "");
Error('\p{GCB:- PP/a/}');
Error('\P{GCB:- PP/a/}');
Expect(0, 1, '\p{GCB=pp}', "");
Expect(1, 1, '\p{^GCB=pp}', "");
Expect(1, 1, '\P{GCB=pp}', "");
Expect(0, 1, '\P{^GCB=pp}', "");
Expect(0, 1, '\p{GCB=_PP}', "");
Expect(1, 1, '\p{^GCB=_PP}', "");
Expect(1, 1, '\P{GCB=_PP}', "");
Expect(0, 1, '\P{^GCB=_PP}', "");
Error('\p{Is_Grapheme_Cluster_Break=:=-_prepend}');
Error('\P{Is_Grapheme_Cluster_Break=:=-_prepend}');
Expect(0, 1, '\p{Is_Grapheme_Cluster_Break=prepend}', "");
Expect(1, 1, '\p{^Is_Grapheme_Cluster_Break=prepend}', "");
Expect(1, 1, '\P{Is_Grapheme_Cluster_Break=prepend}', "");
Expect(0, 1, '\P{^Is_Grapheme_Cluster_Break=prepend}', "");
Expect(0, 1, '\p{Is_Grapheme_Cluster_Break=-_Prepend}', "");
Expect(1, 1, '\p{^Is_Grapheme_Cluster_Break=-_Prepend}', "");
Expect(1, 1, '\P{Is_Grapheme_Cluster_Break=-_Prepend}', "");
Expect(0, 1, '\P{^Is_Grapheme_Cluster_Break=-_Prepend}', "");
Error('\p{Is_GCB=/a/__PP}');
Error('\P{Is_GCB=/a/__PP}');
Expect(0, 1, '\p{Is_GCB=pp}', "");
Expect(1, 1, '\p{^Is_GCB=pp}', "");
Expect(1, 1, '\P{Is_GCB=pp}', "");
Expect(0, 1, '\P{^Is_GCB=pp}', "");
Expect(0, 1, '\p{Is_GCB=_PP}', "");
Expect(1, 1, '\p{^Is_GCB=_PP}', "");
Expect(1, 1, '\P{Is_GCB=_PP}', "");
Expect(0, 1, '\P{^Is_GCB=_PP}', "");
Error('\p{Grapheme_Cluster_Break=:= regional_indicator}');
Error('\P{Grapheme_Cluster_Break=:= regional_indicator}');
Expect(1, 127487, '\p{Grapheme_Cluster_Break=regionalindicator}', "");
Expect(0, 127487, '\p{^Grapheme_Cluster_Break=regionalindicator}', "");
Expect(0, 127487, '\P{Grapheme_Cluster_Break=regionalindicator}', "");
Expect(1, 127487, '\P{^Grapheme_Cluster_Break=regionalindicator}', "");
Expect(0, 127488, '\p{Grapheme_Cluster_Break=regionalindicator}', "");
Expect(1, 127488, '\p{^Grapheme_Cluster_Break=regionalindicator}', "");
Expect(1, 127488, '\P{Grapheme_Cluster_Break=regionalindicator}', "");
Expect(0, 127488, '\P{^Grapheme_Cluster_Break=regionalindicator}', "");
Expect(1, 127487, '\p{Grapheme_Cluster_Break= -Regional_Indicator}', "");
Expect(0, 127487, '\p{^Grapheme_Cluster_Break= -Regional_Indicator}', "");
Expect(0, 127487, '\P{Grapheme_Cluster_Break= -Regional_Indicator}', "");
Expect(1, 127487, '\P{^Grapheme_Cluster_Break= -Regional_Indicator}', "");
Expect(0, 127488, '\p{Grapheme_Cluster_Break= -Regional_Indicator}', "");
Expect(1, 127488, '\p{^Grapheme_Cluster_Break= -Regional_Indicator}', "");
Expect(1, 127488, '\P{Grapheme_Cluster_Break= -Regional_Indicator}', "");
Expect(0, 127488, '\P{^Grapheme_Cluster_Break= -Regional_Indicator}', "");
Error('\p{GCB=__RI/a/}');
Error('\P{GCB=__RI/a/}');
Expect(1, 127487, '\p{GCB=ri}', "");
Expect(0, 127487, '\p{^GCB=ri}', "");
Expect(0, 127487, '\P{GCB=ri}', "");
Expect(1, 127487, '\P{^GCB=ri}', "");
Expect(0, 127488, '\p{GCB=ri}', "");
Expect(1, 127488, '\p{^GCB=ri}', "");
Expect(1, 127488, '\P{GCB=ri}', "");
Expect(0, 127488, '\P{^GCB=ri}', "");
Expect(1, 127487, '\p{GCB:    ri}', "");
Expect(0, 127487, '\p{^GCB:    ri}', "");
Expect(0, 127487, '\P{GCB:    ri}', "");
Expect(1, 127487, '\P{^GCB:    ri}', "");
Expect(0, 127488, '\p{GCB:    ri}', "");
Expect(1, 127488, '\p{^GCB:    ri}', "");
Expect(1, 127488, '\P{GCB:    ri}', "");
Expect(0, 127488, '\P{^GCB:    ri}', "");
Error('\p{Is_Grapheme_Cluster_Break= 	regional_indicator/a/}');
Error('\P{Is_Grapheme_Cluster_Break= 	regional_indicator/a/}');
Expect(1, 127487, '\p{Is_Grapheme_Cluster_Break=regionalindicator}', "");
Expect(0, 127487, '\p{^Is_Grapheme_Cluster_Break=regionalindicator}', "");
Expect(0, 127487, '\P{Is_Grapheme_Cluster_Break=regionalindicator}', "");
Expect(1, 127487, '\P{^Is_Grapheme_Cluster_Break=regionalindicator}', "");
Expect(0, 127488, '\p{Is_Grapheme_Cluster_Break=regionalindicator}', "");
Expect(1, 127488, '\p{^Is_Grapheme_Cluster_Break=regionalindicator}', "");
Expect(1, 127488, '\P{Is_Grapheme_Cluster_Break=regionalindicator}', "");
Expect(0, 127488, '\P{^Is_Grapheme_Cluster_Break=regionalindicator}', "");
Expect(1, 127487, '\p{Is_Grapheme_Cluster_Break=-Regional_Indicator}', "");
Expect(0, 127487, '\p{^Is_Grapheme_Cluster_Break=-Regional_Indicator}', "");
Expect(0, 127487, '\P{Is_Grapheme_Cluster_Break=-Regional_Indicator}', "");
Expect(1, 127487, '\P{^Is_Grapheme_Cluster_Break=-Regional_Indicator}', "");
Expect(0, 127488, '\p{Is_Grapheme_Cluster_Break=-Regional_Indicator}', "");
Expect(1, 127488, '\p{^Is_Grapheme_Cluster_Break=-Regional_Indicator}', "");
Expect(1, 127488, '\P{Is_Grapheme_Cluster_Break=-Regional_Indicator}', "");
Expect(0, 127488, '\P{^Is_Grapheme_Cluster_Break=-Regional_Indicator}', "");
Error('\p{Is_GCB=-:=RI}');
Error('\P{Is_GCB=-:=RI}');
Expect(1, 127487, '\p{Is_GCB=ri}', "");
Expect(0, 127487, '\p{^Is_GCB=ri}', "");
Expect(0, 127487, '\P{Is_GCB=ri}', "");
Expect(1, 127487, '\P{^Is_GCB=ri}', "");
Expect(0, 127488, '\p{Is_GCB=ri}', "");
Expect(1, 127488, '\p{^Is_GCB=ri}', "");
Expect(1, 127488, '\P{Is_GCB=ri}', "");
Expect(0, 127488, '\P{^Is_GCB=ri}', "");
Expect(1, 127487, '\p{Is_GCB= RI}', "");
Expect(0, 127487, '\p{^Is_GCB= RI}', "");
Expect(0, 127487, '\P{Is_GCB= RI}', "");
Expect(1, 127487, '\P{^Is_GCB= RI}', "");
Expect(0, 127488, '\p{Is_GCB= RI}', "");
Expect(1, 127488, '\p{^Is_GCB= RI}', "");
Expect(1, 127488, '\P{Is_GCB= RI}', "");
Expect(0, 127488, '\P{^Is_GCB= RI}', "");
Error('\p{Grapheme_Cluster_Break=:=--SPACINGMARK}');
Error('\P{Grapheme_Cluster_Break=:=--SPACINGMARK}');
Expect(1, 119149, '\p{Grapheme_Cluster_Break=spacingmark}', "");
Expect(0, 119149, '\p{^Grapheme_Cluster_Break=spacingmark}', "");
Expect(0, 119149, '\P{Grapheme_Cluster_Break=spacingmark}', "");
Expect(1, 119149, '\P{^Grapheme_Cluster_Break=spacingmark}', "");
Expect(0, 119150, '\p{Grapheme_Cluster_Break=spacingmark}', "");
Expect(1, 119150, '\p{^Grapheme_Cluster_Break=spacingmark}', "");
Expect(1, 119150, '\P{Grapheme_Cluster_Break=spacingmark}', "");
Expect(0, 119150, '\P{^Grapheme_Cluster_Break=spacingmark}', "");
Expect(1, 119149, '\p{Grapheme_Cluster_Break= SPACINGMARK}', "");
Expect(0, 119149, '\p{^Grapheme_Cluster_Break= SPACINGMARK}', "");
Expect(0, 119149, '\P{Grapheme_Cluster_Break= SPACINGMARK}', "");
Expect(1, 119149, '\P{^Grapheme_Cluster_Break= SPACINGMARK}', "");
Expect(0, 119150, '\p{Grapheme_Cluster_Break= SPACINGMARK}', "");
Expect(1, 119150, '\p{^Grapheme_Cluster_Break= SPACINGMARK}', "");
Expect(1, 119150, '\P{Grapheme_Cluster_Break= SPACINGMARK}', "");
Expect(0, 119150, '\P{^Grapheme_Cluster_Break= SPACINGMARK}', "");
Error('\p{GCB= SM:=}');
Error('\P{GCB= SM:=}');
Expect(1, 119149, '\p{GCB:sm}', "");
Expect(0, 119149, '\p{^GCB:sm}', "");
Expect(0, 119149, '\P{GCB:sm}', "");
Expect(1, 119149, '\P{^GCB:sm}', "");
Expect(0, 119150, '\p{GCB:sm}', "");
Expect(1, 119150, '\p{^GCB:sm}', "");
Expect(1, 119150, '\P{GCB:sm}', "");
Expect(0, 119150, '\P{^GCB:sm}', "");
Expect(1, 119149, '\p{GCB=-_sm}', "");
Expect(0, 119149, '\p{^GCB=-_sm}', "");
Expect(0, 119149, '\P{GCB=-_sm}', "");
Expect(1, 119149, '\P{^GCB=-_sm}', "");
Expect(0, 119150, '\p{GCB=-_sm}', "");
Expect(1, 119150, '\p{^GCB=-_sm}', "");
Expect(1, 119150, '\P{GCB=-_sm}', "");
Expect(0, 119150, '\P{^GCB=-_sm}', "");
Error('\p{Is_Grapheme_Cluster_Break= -SpacingMark/a/}');
Error('\P{Is_Grapheme_Cluster_Break= -SpacingMark/a/}');
Expect(1, 119149, '\p{Is_Grapheme_Cluster_Break=spacingmark}', "");
Expect(0, 119149, '\p{^Is_Grapheme_Cluster_Break=spacingmark}', "");
Expect(0, 119149, '\P{Is_Grapheme_Cluster_Break=spacingmark}', "");
Expect(1, 119149, '\P{^Is_Grapheme_Cluster_Break=spacingmark}', "");
Expect(0, 119150, '\p{Is_Grapheme_Cluster_Break=spacingmark}', "");
Expect(1, 119150, '\p{^Is_Grapheme_Cluster_Break=spacingmark}', "");
Expect(1, 119150, '\P{Is_Grapheme_Cluster_Break=spacingmark}', "");
Expect(0, 119150, '\P{^Is_Grapheme_Cluster_Break=spacingmark}', "");
Expect(1, 119149, '\p{Is_Grapheme_Cluster_Break=__spacingmark}', "");
Expect(0, 119149, '\p{^Is_Grapheme_Cluster_Break=__spacingmark}', "");
Expect(0, 119149, '\P{Is_Grapheme_Cluster_Break=__spacingmark}', "");
Expect(1, 119149, '\P{^Is_Grapheme_Cluster_Break=__spacingmark}', "");
Expect(0, 119150, '\p{Is_Grapheme_Cluster_Break=__spacingmark}', "");
Expect(1, 119150, '\p{^Is_Grapheme_Cluster_Break=__spacingmark}', "");
Expect(1, 119150, '\P{Is_Grapheme_Cluster_Break=__spacingmark}', "");
Expect(0, 119150, '\P{^Is_Grapheme_Cluster_Break=__spacingmark}', "");
Error('\p{Is_GCB=  SM/a/}');
Error('\P{Is_GCB=  SM/a/}');
Expect(1, 119149, '\p{Is_GCB=sm}', "");
Expect(0, 119149, '\p{^Is_GCB=sm}', "");
Expect(0, 119149, '\P{Is_GCB=sm}', "");
Expect(1, 119149, '\P{^Is_GCB=sm}', "");
Expect(0, 119150, '\p{Is_GCB=sm}', "");
Expect(1, 119150, '\p{^Is_GCB=sm}', "");
Expect(1, 119150, '\P{Is_GCB=sm}', "");
Expect(0, 119150, '\P{^Is_GCB=sm}', "");
Expect(1, 119149, '\p{Is_GCB= -SM}', "");
Expect(0, 119149, '\p{^Is_GCB= -SM}', "");
Expect(0, 119149, '\P{Is_GCB= -SM}', "");
Expect(1, 119149, '\P{^Is_GCB= -SM}', "");
Expect(0, 119150, '\p{Is_GCB= -SM}', "");
Expect(1, 119150, '\p{^Is_GCB= -SM}', "");
Expect(1, 119150, '\P{Is_GCB= -SM}', "");
Expect(0, 119150, '\P{^Is_GCB= -SM}', "");
Error('\p{Grapheme_Cluster_Break=/a/_-t}');
Error('\P{Grapheme_Cluster_Break=/a/_-t}');
Expect(1, 55291, '\p{Grapheme_Cluster_Break=t}', "");
Expect(0, 55291, '\p{^Grapheme_Cluster_Break=t}', "");
Expect(0, 55291, '\P{Grapheme_Cluster_Break=t}', "");
Expect(1, 55291, '\P{^Grapheme_Cluster_Break=t}', "");
Expect(0, 55292, '\p{Grapheme_Cluster_Break=t}', "");
Expect(1, 55292, '\p{^Grapheme_Cluster_Break=t}', "");
Expect(1, 55292, '\P{Grapheme_Cluster_Break=t}', "");
Expect(0, 55292, '\P{^Grapheme_Cluster_Break=t}', "");
Expect(1, 55291, '\p{Grapheme_Cluster_Break= T}', "");
Expect(0, 55291, '\p{^Grapheme_Cluster_Break= T}', "");
Expect(0, 55291, '\P{Grapheme_Cluster_Break= T}', "");
Expect(1, 55291, '\P{^Grapheme_Cluster_Break= T}', "");
Expect(0, 55292, '\p{Grapheme_Cluster_Break= T}', "");
Expect(1, 55292, '\p{^Grapheme_Cluster_Break= T}', "");
Expect(1, 55292, '\P{Grapheme_Cluster_Break= T}', "");
Expect(0, 55292, '\P{^Grapheme_Cluster_Break= T}', "");
Error('\p{GCB=:=-T}');
Error('\P{GCB=:=-T}');
Expect(1, 55291, '\p{GCB:   t}', "");
Expect(0, 55291, '\p{^GCB:   t}', "");
Expect(0, 55291, '\P{GCB:   t}', "");
Expect(1, 55291, '\P{^GCB:   t}', "");
Expect(0, 55292, '\p{GCB:   t}', "");
Expect(1, 55292, '\p{^GCB:   t}', "");
Expect(1, 55292, '\P{GCB:   t}', "");
Expect(0, 55292, '\P{^GCB:   t}', "");
Expect(1, 55291, '\p{GCB=_-t}', "");
Expect(0, 55291, '\p{^GCB=_-t}', "");
Expect(0, 55291, '\P{GCB=_-t}', "");
Expect(1, 55291, '\P{^GCB=_-t}', "");
Expect(0, 55292, '\p{GCB=_-t}', "");
Expect(1, 55292, '\p{^GCB=_-t}', "");
Expect(1, 55292, '\P{GCB=_-t}', "");
Expect(0, 55292, '\P{^GCB=_-t}', "");
Error('\p{Is_Grapheme_Cluster_Break=-/a/T}');
Error('\P{Is_Grapheme_Cluster_Break=-/a/T}');
Expect(1, 55291, '\p{Is_Grapheme_Cluster_Break=t}', "");
Expect(0, 55291, '\p{^Is_Grapheme_Cluster_Break=t}', "");
Expect(0, 55291, '\P{Is_Grapheme_Cluster_Break=t}', "");
Expect(1, 55291, '\P{^Is_Grapheme_Cluster_Break=t}', "");
Expect(0, 55292, '\p{Is_Grapheme_Cluster_Break=t}', "");
Expect(1, 55292, '\p{^Is_Grapheme_Cluster_Break=t}', "");
Expect(1, 55292, '\P{Is_Grapheme_Cluster_Break=t}', "");
Expect(0, 55292, '\P{^Is_Grapheme_Cluster_Break=t}', "");
Expect(1, 55291, '\p{Is_Grapheme_Cluster_Break=_T}', "");
Expect(0, 55291, '\p{^Is_Grapheme_Cluster_Break=_T}', "");
Expect(0, 55291, '\P{Is_Grapheme_Cluster_Break=_T}', "");
Expect(1, 55291, '\P{^Is_Grapheme_Cluster_Break=_T}', "");
Expect(0, 55292, '\p{Is_Grapheme_Cluster_Break=_T}', "");
Expect(1, 55292, '\p{^Is_Grapheme_Cluster_Break=_T}', "");
Expect(1, 55292, '\P{Is_Grapheme_Cluster_Break=_T}', "");
Expect(0, 55292, '\P{^Is_Grapheme_Cluster_Break=_T}', "");
Error('\p{Is_GCB=	T/a/}');
Error('\P{Is_GCB=	T/a/}');
Expect(1, 55291, '\p{Is_GCB=t}', "");
Expect(0, 55291, '\p{^Is_GCB=t}', "");
Expect(0, 55291, '\P{Is_GCB=t}', "");
Expect(1, 55291, '\P{^Is_GCB=t}', "");
Expect(0, 55292, '\p{Is_GCB=t}', "");
Expect(1, 55292, '\p{^Is_GCB=t}', "");
Expect(1, 55292, '\P{Is_GCB=t}', "");
Expect(0, 55292, '\P{^Is_GCB=t}', "");
Expect(1, 55291, '\p{Is_GCB=	t}', "");
Expect(0, 55291, '\p{^Is_GCB=	t}', "");
Expect(0, 55291, '\P{Is_GCB=	t}', "");
Expect(1, 55291, '\P{^Is_GCB=	t}', "");
Expect(0, 55292, '\p{Is_GCB=	t}', "");
Expect(1, 55292, '\p{^Is_GCB=	t}', "");
Expect(1, 55292, '\P{Is_GCB=	t}', "");
Expect(0, 55292, '\P{^Is_GCB=	t}', "");
Error('\p{Grapheme_Cluster_Break=--V:=}');
Error('\P{Grapheme_Cluster_Break=--V:=}');
Expect(1, 55238, '\p{Grapheme_Cluster_Break:	v}', "");
Expect(0, 55238, '\p{^Grapheme_Cluster_Break:	v}', "");
Expect(0, 55238, '\P{Grapheme_Cluster_Break:	v}', "");
Expect(1, 55238, '\P{^Grapheme_Cluster_Break:	v}', "");
Expect(0, 55239, '\p{Grapheme_Cluster_Break:	v}', "");
Expect(1, 55239, '\p{^Grapheme_Cluster_Break:	v}', "");
Expect(1, 55239, '\P{Grapheme_Cluster_Break:	v}', "");
Expect(0, 55239, '\P{^Grapheme_Cluster_Break:	v}', "");
Expect(1, 55238, '\p{Grapheme_Cluster_Break=_ V}', "");
Expect(0, 55238, '\p{^Grapheme_Cluster_Break=_ V}', "");
Expect(0, 55238, '\P{Grapheme_Cluster_Break=_ V}', "");
Expect(1, 55238, '\P{^Grapheme_Cluster_Break=_ V}', "");
Expect(0, 55239, '\p{Grapheme_Cluster_Break=_ V}', "");
Expect(1, 55239, '\p{^Grapheme_Cluster_Break=_ V}', "");
Expect(1, 55239, '\P{Grapheme_Cluster_Break=_ V}', "");
Expect(0, 55239, '\P{^Grapheme_Cluster_Break=_ V}', "");
Error('\p{GCB=/a/-_V}');
Error('\P{GCB=/a/-_V}');
Expect(1, 55238, '\p{GCB=v}', "");
Expect(0, 55238, '\p{^GCB=v}', "");
Expect(0, 55238, '\P{GCB=v}', "");
Expect(1, 55238, '\P{^GCB=v}', "");
Expect(0, 55239, '\p{GCB=v}', "");
Expect(1, 55239, '\p{^GCB=v}', "");
Expect(1, 55239, '\P{GCB=v}', "");
Expect(0, 55239, '\P{^GCB=v}', "");
Expect(1, 55238, '\p{GCB=	 V}', "");
Expect(0, 55238, '\p{^GCB=	 V}', "");
Expect(0, 55238, '\P{GCB=	 V}', "");
Expect(1, 55238, '\P{^GCB=	 V}', "");
Expect(0, 55239, '\p{GCB=	 V}', "");
Expect(1, 55239, '\p{^GCB=	 V}', "");
Expect(1, 55239, '\P{GCB=	 V}', "");
Expect(0, 55239, '\P{^GCB=	 V}', "");
Error('\p{Is_Grapheme_Cluster_Break=/a/V}');
Error('\P{Is_Grapheme_Cluster_Break=/a/V}');
Expect(1, 55238, '\p{Is_Grapheme_Cluster_Break=v}', "");
Expect(0, 55238, '\p{^Is_Grapheme_Cluster_Break=v}', "");
Expect(0, 55238, '\P{Is_Grapheme_Cluster_Break=v}', "");
Expect(1, 55238, '\P{^Is_Grapheme_Cluster_Break=v}', "");
Expect(0, 55239, '\p{Is_Grapheme_Cluster_Break=v}', "");
Expect(1, 55239, '\p{^Is_Grapheme_Cluster_Break=v}', "");
Expect(1, 55239, '\P{Is_Grapheme_Cluster_Break=v}', "");
Expect(0, 55239, '\P{^Is_Grapheme_Cluster_Break=v}', "");
Expect(1, 55238, '\p{Is_Grapheme_Cluster_Break=__V}', "");
Expect(0, 55238, '\p{^Is_Grapheme_Cluster_Break=__V}', "");
Expect(0, 55238, '\P{Is_Grapheme_Cluster_Break=__V}', "");
Expect(1, 55238, '\P{^Is_Grapheme_Cluster_Break=__V}', "");
Expect(0, 55239, '\p{Is_Grapheme_Cluster_Break=__V}', "");
Expect(1, 55239, '\p{^Is_Grapheme_Cluster_Break=__V}', "");
Expect(1, 55239, '\P{Is_Grapheme_Cluster_Break=__V}', "");
Expect(0, 55239, '\P{^Is_Grapheme_Cluster_Break=__V}', "");
Error('\p{Is_GCB=:= V}');
Error('\P{Is_GCB=:= V}');
Expect(1, 55238, '\p{Is_GCB:v}', "");
Expect(0, 55238, '\p{^Is_GCB:v}', "");
Expect(0, 55238, '\P{Is_GCB:v}', "");
Expect(1, 55238, '\P{^Is_GCB:v}', "");
Expect(0, 55239, '\p{Is_GCB:v}', "");
Expect(1, 55239, '\p{^Is_GCB:v}', "");
Expect(1, 55239, '\P{Is_GCB:v}', "");
Expect(0, 55239, '\P{^Is_GCB:v}', "");
Expect(1, 55238, '\p{Is_GCB=_v}', "");
Expect(0, 55238, '\p{^Is_GCB=_v}', "");
Expect(0, 55238, '\P{Is_GCB=_v}', "");
Expect(1, 55238, '\P{^Is_GCB=_v}', "");
Expect(0, 55239, '\p{Is_GCB=_v}', "");
Expect(1, 55239, '\p{^Is_GCB=_v}', "");
Expect(1, 55239, '\P{Is_GCB=_v}', "");
Expect(0, 55239, '\P{^Is_GCB=_v}', "");
Error('\p{Grapheme_Cluster_Break=/a/ 	Other}');
Error('\P{Grapheme_Cluster_Break=/a/ 	Other}');
Expect(1, 921600, '\p{Grapheme_Cluster_Break=other}', "");
Expect(0, 921600, '\p{^Grapheme_Cluster_Break=other}', "");
Expect(0, 921600, '\P{Grapheme_Cluster_Break=other}', "");
Expect(1, 921600, '\P{^Grapheme_Cluster_Break=other}', "");
Expect(0, 921599, '\p{Grapheme_Cluster_Break=other}', "");
Expect(1, 921599, '\p{^Grapheme_Cluster_Break=other}', "");
Expect(1, 921599, '\P{Grapheme_Cluster_Break=other}', "");
Expect(0, 921599, '\P{^Grapheme_Cluster_Break=other}', "");
Expect(1, 921600, '\p{Grapheme_Cluster_Break=	Other}', "");
Expect(0, 921600, '\p{^Grapheme_Cluster_Break=	Other}', "");
Expect(0, 921600, '\P{Grapheme_Cluster_Break=	Other}', "");
Expect(1, 921600, '\P{^Grapheme_Cluster_Break=	Other}', "");
Expect(0, 921599, '\p{Grapheme_Cluster_Break=	Other}', "");
Expect(1, 921599, '\p{^Grapheme_Cluster_Break=	Other}', "");
Expect(1, 921599, '\P{Grapheme_Cluster_Break=	Other}', "");
Expect(0, 921599, '\P{^Grapheme_Cluster_Break=	Other}', "");
Error('\p{GCB:	-/a/xx}');
Error('\P{GCB:	-/a/xx}');
Expect(1, 921600, '\p{GCB=xx}', "");
Expect(0, 921600, '\p{^GCB=xx}', "");
Expect(0, 921600, '\P{GCB=xx}', "");
Expect(1, 921600, '\P{^GCB=xx}', "");
Expect(0, 921599, '\p{GCB=xx}', "");
Expect(1, 921599, '\p{^GCB=xx}', "");
Expect(1, 921599, '\P{GCB=xx}', "");
Expect(0, 921599, '\P{^GCB=xx}', "");
Expect(1, 921600, '\p{GCB=XX}', "");
Expect(0, 921600, '\p{^GCB=XX}', "");
Expect(0, 921600, '\P{GCB=XX}', "");
Expect(1, 921600, '\P{^GCB=XX}', "");
Expect(0, 921599, '\p{GCB=XX}', "");
Expect(1, 921599, '\p{^GCB=XX}', "");
Expect(1, 921599, '\P{GCB=XX}', "");
Expect(0, 921599, '\P{^GCB=XX}', "");
Error('\p{Is_Grapheme_Cluster_Break:	-_Other:=}');
Error('\P{Is_Grapheme_Cluster_Break:	-_Other:=}');
Expect(1, 921600, '\p{Is_Grapheme_Cluster_Break=other}', "");
Expect(0, 921600, '\p{^Is_Grapheme_Cluster_Break=other}', "");
Expect(0, 921600, '\P{Is_Grapheme_Cluster_Break=other}', "");
Expect(1, 921600, '\P{^Is_Grapheme_Cluster_Break=other}', "");
Expect(0, 921599, '\p{Is_Grapheme_Cluster_Break=other}', "");
Expect(1, 921599, '\p{^Is_Grapheme_Cluster_Break=other}', "");
Expect(1, 921599, '\P{Is_Grapheme_Cluster_Break=other}', "");
Expect(0, 921599, '\P{^Is_Grapheme_Cluster_Break=other}', "");
Expect(1, 921600, '\p{Is_Grapheme_Cluster_Break=_	Other}', "");
Expect(0, 921600, '\p{^Is_Grapheme_Cluster_Break=_	Other}', "");
Expect(0, 921600, '\P{Is_Grapheme_Cluster_Break=_	Other}', "");
Expect(1, 921600, '\P{^Is_Grapheme_Cluster_Break=_	Other}', "");
Expect(0, 921599, '\p{Is_Grapheme_Cluster_Break=_	Other}', "");
Expect(1, 921599, '\p{^Is_Grapheme_Cluster_Break=_	Other}', "");
Expect(1, 921599, '\P{Is_Grapheme_Cluster_Break=_	Other}', "");
Expect(0, 921599, '\P{^Is_Grapheme_Cluster_Break=_	Other}', "");
Error('\p{Is_GCB=:=		xx}');
Error('\P{Is_GCB=:=		xx}');
Expect(1, 921600, '\p{Is_GCB=xx}', "");
Expect(0, 921600, '\p{^Is_GCB=xx}', "");
Expect(0, 921600, '\P{Is_GCB=xx}', "");
Expect(1, 921600, '\P{^Is_GCB=xx}', "");
Expect(0, 921599, '\p{Is_GCB=xx}', "");
Expect(1, 921599, '\p{^Is_GCB=xx}', "");
Expect(1, 921599, '\P{Is_GCB=xx}', "");
Expect(0, 921599, '\P{^Is_GCB=xx}', "");
Expect(1, 921600, '\p{Is_GCB=_	XX}', "");
Expect(0, 921600, '\p{^Is_GCB=_	XX}', "");
Expect(0, 921600, '\P{Is_GCB=_	XX}', "");
Expect(1, 921600, '\P{^Is_GCB=_	XX}', "");
Expect(0, 921599, '\p{Is_GCB=_	XX}', "");
Expect(1, 921599, '\p{^Is_GCB=_	XX}', "");
Expect(1, 921599, '\P{Is_GCB=_	XX}', "");
Expect(0, 921599, '\P{^Is_GCB=_	XX}', "");
Error('\p{Grapheme_Base:/a/		no}');
Error('\P{Grapheme_Base:/a/		no}');
Expect(1, 195102, '\p{Grapheme_Base:no}', "");
Expect(0, 195102, '\p{^Grapheme_Base:no}', "");
Expect(0, 195102, '\P{Grapheme_Base:no}', "");
Expect(1, 195102, '\P{^Grapheme_Base:no}', "");
Expect(0, 195101, '\p{Grapheme_Base:no}', "");
Expect(1, 195101, '\p{^Grapheme_Base:no}', "");
Expect(1, 195101, '\P{Grapheme_Base:no}', "");
Expect(0, 195101, '\P{^Grapheme_Base:no}', "");
Expect(1, 195102, '\p{Grapheme_Base=__No}', "");
Expect(0, 195102, '\p{^Grapheme_Base=__No}', "");
Expect(0, 195102, '\P{Grapheme_Base=__No}', "");
Expect(1, 195102, '\P{^Grapheme_Base=__No}', "");
Expect(0, 195101, '\p{Grapheme_Base=__No}', "");
Expect(1, 195101, '\p{^Grapheme_Base=__No}', "");
Expect(1, 195101, '\P{Grapheme_Base=__No}', "");
Expect(0, 195101, '\P{^Grapheme_Base=__No}', "");
Error('\p{Gr_Base=:=_ n}');
Error('\P{Gr_Base=:=_ n}');
Expect(1, 195102, '\p{Gr_Base=n}', "");
Expect(0, 195102, '\p{^Gr_Base=n}', "");
Expect(0, 195102, '\P{Gr_Base=n}', "");
Expect(1, 195102, '\P{^Gr_Base=n}', "");
Expect(0, 195101, '\p{Gr_Base=n}', "");
Expect(1, 195101, '\p{^Gr_Base=n}', "");
Expect(1, 195101, '\P{Gr_Base=n}', "");
Expect(0, 195101, '\P{^Gr_Base=n}', "");
Expect(1, 195102, '\p{Gr_Base=	_N}', "");
Expect(0, 195102, '\p{^Gr_Base=	_N}', "");
Expect(0, 195102, '\P{Gr_Base=	_N}', "");
Expect(1, 195102, '\P{^Gr_Base=	_N}', "");
Expect(0, 195101, '\p{Gr_Base=	_N}', "");
Expect(1, 195101, '\p{^Gr_Base=	_N}', "");
Expect(1, 195101, '\P{Gr_Base=	_N}', "");
Expect(0, 195101, '\P{^Gr_Base=	_N}', "");
Error('\p{Is_Grapheme_Base:   -	f/a/}');
Error('\P{Is_Grapheme_Base:   -	f/a/}');
Expect(1, 195102, '\p{Is_Grapheme_Base=f}', "");
Expect(0, 195102, '\p{^Is_Grapheme_Base=f}', "");
Expect(0, 195102, '\P{Is_Grapheme_Base=f}', "");
Expect(1, 195102, '\P{^Is_Grapheme_Base=f}', "");
Expect(0, 195101, '\p{Is_Grapheme_Base=f}', "");
Expect(1, 195101, '\p{^Is_Grapheme_Base=f}', "");
Expect(1, 195101, '\P{Is_Grapheme_Base=f}', "");
Expect(0, 195101, '\P{^Is_Grapheme_Base=f}', "");
Expect(1, 195102, '\p{Is_Grapheme_Base=	f}', "");
Expect(0, 195102, '\p{^Is_Grapheme_Base=	f}', "");
Expect(0, 195102, '\P{Is_Grapheme_Base=	f}', "");
Expect(1, 195102, '\P{^Is_Grapheme_Base=	f}', "");
Expect(0, 195101, '\p{Is_Grapheme_Base=	f}', "");
Expect(1, 195101, '\p{^Is_Grapheme_Base=	f}', "");
Expect(1, 195101, '\P{Is_Grapheme_Base=	f}', "");
Expect(0, 195101, '\P{^Is_Grapheme_Base=	f}', "");
Error('\p{Is_Gr_Base= _False:=}');
Error('\P{Is_Gr_Base= _False:=}');
Expect(1, 195102, '\p{Is_Gr_Base=false}', "");
Expect(0, 195102, '\p{^Is_Gr_Base=false}', "");
Expect(0, 195102, '\P{Is_Gr_Base=false}', "");
Expect(1, 195102, '\P{^Is_Gr_Base=false}', "");
Expect(0, 195101, '\p{Is_Gr_Base=false}', "");
Expect(1, 195101, '\p{^Is_Gr_Base=false}', "");
Expect(1, 195101, '\P{Is_Gr_Base=false}', "");
Expect(0, 195101, '\P{^Is_Gr_Base=false}', "");
Expect(1, 195102, '\p{Is_Gr_Base=_-False}', "");
Expect(0, 195102, '\p{^Is_Gr_Base=_-False}', "");
Expect(0, 195102, '\P{Is_Gr_Base=_-False}', "");
Expect(1, 195102, '\P{^Is_Gr_Base=_-False}', "");
Expect(0, 195101, '\p{Is_Gr_Base=_-False}', "");
Expect(1, 195101, '\p{^Is_Gr_Base=_-False}', "");
Expect(1, 195101, '\P{Is_Gr_Base=_-False}', "");
Expect(0, 195101, '\P{^Is_Gr_Base=_-False}', "");
Error('\p{Grapheme_Base=- YES/a/}');
Error('\P{Grapheme_Base=- YES/a/}');
Expect(1, 195101, '\p{Grapheme_Base=yes}', "");
Expect(0, 195101, '\p{^Grapheme_Base=yes}', "");
Expect(0, 195101, '\P{Grapheme_Base=yes}', "");
Expect(1, 195101, '\P{^Grapheme_Base=yes}', "");
Expect(0, 195102, '\p{Grapheme_Base=yes}', "");
Expect(1, 195102, '\p{^Grapheme_Base=yes}', "");
Expect(1, 195102, '\P{Grapheme_Base=yes}', "");
Expect(0, 195102, '\P{^Grapheme_Base=yes}', "");
Expect(1, 195101, '\p{Grapheme_Base=-Yes}', "");
Expect(0, 195101, '\p{^Grapheme_Base=-Yes}', "");
Expect(0, 195101, '\P{Grapheme_Base=-Yes}', "");
Expect(1, 195101, '\P{^Grapheme_Base=-Yes}', "");
Expect(0, 195102, '\p{Grapheme_Base=-Yes}', "");
Expect(1, 195102, '\p{^Grapheme_Base=-Yes}', "");
Expect(1, 195102, '\P{Grapheme_Base=-Yes}', "");
Expect(0, 195102, '\P{^Grapheme_Base=-Yes}', "");
Error('\p{Gr_Base=-/a/y}');
Error('\P{Gr_Base=-/a/y}');
Expect(1, 195101, '\p{Gr_Base=y}', "");
Expect(0, 195101, '\p{^Gr_Base=y}', "");
Expect(0, 195101, '\P{Gr_Base=y}', "");
Expect(1, 195101, '\P{^Gr_Base=y}', "");
Expect(0, 195102, '\p{Gr_Base=y}', "");
Expect(1, 195102, '\p{^Gr_Base=y}', "");
Expect(1, 195102, '\P{Gr_Base=y}', "");
Expect(0, 195102, '\P{^Gr_Base=y}', "");
Expect(1, 195101, '\p{Gr_Base= _Y}', "");
Expect(0, 195101, '\p{^Gr_Base= _Y}', "");
Expect(0, 195101, '\P{Gr_Base= _Y}', "");
Expect(1, 195101, '\P{^Gr_Base= _Y}', "");
Expect(0, 195102, '\p{Gr_Base= _Y}', "");
Expect(1, 195102, '\p{^Gr_Base= _Y}', "");
Expect(1, 195102, '\P{Gr_Base= _Y}', "");
Expect(0, 195102, '\P{^Gr_Base= _Y}', "");
Error('\p{Is_Grapheme_Base=:=T}');
Error('\P{Is_Grapheme_Base=:=T}');
Expect(1, 195101, '\p{Is_Grapheme_Base=t}', "");
Expect(0, 195101, '\p{^Is_Grapheme_Base=t}', "");
Expect(0, 195101, '\P{Is_Grapheme_Base=t}', "");
Expect(1, 195101, '\P{^Is_Grapheme_Base=t}', "");
Expect(0, 195102, '\p{Is_Grapheme_Base=t}', "");
Expect(1, 195102, '\p{^Is_Grapheme_Base=t}', "");
Expect(1, 195102, '\P{Is_Grapheme_Base=t}', "");
Expect(0, 195102, '\P{^Is_Grapheme_Base=t}', "");
Expect(1, 195101, '\p{Is_Grapheme_Base:   	_T}', "");
Expect(0, 195101, '\p{^Is_Grapheme_Base:   	_T}', "");
Expect(0, 195101, '\P{Is_Grapheme_Base:   	_T}', "");
Expect(1, 195101, '\P{^Is_Grapheme_Base:   	_T}', "");
Expect(0, 195102, '\p{Is_Grapheme_Base:   	_T}', "");
Expect(1, 195102, '\p{^Is_Grapheme_Base:   	_T}', "");
Expect(1, 195102, '\P{Is_Grapheme_Base:   	_T}', "");
Expect(0, 195102, '\P{^Is_Grapheme_Base:   	_T}', "");
Error('\p{Is_Gr_Base=-:=TRUE}');
Error('\P{Is_Gr_Base=-:=TRUE}');
Expect(1, 195101, '\p{Is_Gr_Base=true}', "");
Expect(0, 195101, '\p{^Is_Gr_Base=true}', "");
Expect(0, 195101, '\P{Is_Gr_Base=true}', "");
Expect(1, 195101, '\P{^Is_Gr_Base=true}', "");
Expect(0, 195102, '\p{Is_Gr_Base=true}', "");
Expect(1, 195102, '\p{^Is_Gr_Base=true}', "");
Expect(1, 195102, '\P{Is_Gr_Base=true}', "");
Expect(0, 195102, '\P{^Is_Gr_Base=true}', "");
Expect(1, 195101, '\p{Is_Gr_Base=_TRUE}', "");
Expect(0, 195101, '\p{^Is_Gr_Base=_TRUE}', "");
Expect(0, 195101, '\P{Is_Gr_Base=_TRUE}', "");
Expect(1, 195101, '\P{^Is_Gr_Base=_TRUE}', "");
Expect(0, 195102, '\p{Is_Gr_Base=_TRUE}', "");
Expect(1, 195102, '\p{^Is_Gr_Base=_TRUE}', "");
Expect(1, 195102, '\P{Is_Gr_Base=_TRUE}', "");
Expect(0, 195102, '\P{^Is_Gr_Base=_TRUE}', "");
Error('\p{Grapheme_Extend=-_No/a/}');
Error('\P{Grapheme_Extend=-_No/a/}');
Expect(1, 918000, '\p{Grapheme_Extend=no}', "");
Expect(0, 918000, '\p{^Grapheme_Extend=no}', "");
Expect(0, 918000, '\P{Grapheme_Extend=no}', "");
Expect(1, 918000, '\P{^Grapheme_Extend=no}', "");
Expect(0, 917999, '\p{Grapheme_Extend=no}', "");
Expect(1, 917999, '\p{^Grapheme_Extend=no}', "");
Expect(1, 917999, '\P{Grapheme_Extend=no}', "");
Expect(0, 917999, '\P{^Grapheme_Extend=no}', "");
Expect(1, 918000, '\p{Grapheme_Extend=	 No}', "");
Expect(0, 918000, '\p{^Grapheme_Extend=	 No}', "");
Expect(0, 918000, '\P{Grapheme_Extend=	 No}', "");
Expect(1, 918000, '\P{^Grapheme_Extend=	 No}', "");
Expect(0, 917999, '\p{Grapheme_Extend=	 No}', "");
Expect(1, 917999, '\p{^Grapheme_Extend=	 No}', "");
Expect(1, 917999, '\P{Grapheme_Extend=	 No}', "");
Expect(0, 917999, '\P{^Grapheme_Extend=	 No}', "");
Error('\p{Gr_Ext=_/a/N}');
Error('\P{Gr_Ext=_/a/N}');
Expect(1, 918000, '\p{Gr_Ext=n}', "");
Expect(0, 918000, '\p{^Gr_Ext=n}', "");
Expect(0, 918000, '\P{Gr_Ext=n}', "");
Expect(1, 918000, '\P{^Gr_Ext=n}', "");
Expect(0, 917999, '\p{Gr_Ext=n}', "");
Expect(1, 917999, '\p{^Gr_Ext=n}', "");
Expect(1, 917999, '\P{Gr_Ext=n}', "");
Expect(0, 917999, '\P{^Gr_Ext=n}', "");
Expect(1, 918000, '\p{Gr_Ext=_-N}', "");
Expect(0, 918000, '\p{^Gr_Ext=_-N}', "");
Expect(0, 918000, '\P{Gr_Ext=_-N}', "");
Expect(1, 918000, '\P{^Gr_Ext=_-N}', "");
Expect(0, 917999, '\p{Gr_Ext=_-N}', "");
Expect(1, 917999, '\p{^Gr_Ext=_-N}', "");
Expect(1, 917999, '\P{Gr_Ext=_-N}', "");
Expect(0, 917999, '\P{^Gr_Ext=_-N}', "");
Error('\p{Is_Grapheme_Extend=-:=F}');
Error('\P{Is_Grapheme_Extend=-:=F}');
Expect(1, 918000, '\p{Is_Grapheme_Extend=f}', "");
Expect(0, 918000, '\p{^Is_Grapheme_Extend=f}', "");
Expect(0, 918000, '\P{Is_Grapheme_Extend=f}', "");
Expect(1, 918000, '\P{^Is_Grapheme_Extend=f}', "");
Expect(0, 917999, '\p{Is_Grapheme_Extend=f}', "");
Expect(1, 917999, '\p{^Is_Grapheme_Extend=f}', "");
Expect(1, 917999, '\P{Is_Grapheme_Extend=f}', "");
Expect(0, 917999, '\P{^Is_Grapheme_Extend=f}', "");
Expect(1, 918000, '\p{Is_Grapheme_Extend=-f}', "");
Expect(0, 918000, '\p{^Is_Grapheme_Extend=-f}', "");
Expect(0, 918000, '\P{Is_Grapheme_Extend=-f}', "");
Expect(1, 918000, '\P{^Is_Grapheme_Extend=-f}', "");
Expect(0, 917999, '\p{Is_Grapheme_Extend=-f}', "");
Expect(1, 917999, '\p{^Is_Grapheme_Extend=-f}', "");
Expect(1, 917999, '\P{Is_Grapheme_Extend=-f}', "");
Expect(0, 917999, '\P{^Is_Grapheme_Extend=-f}', "");
Error('\p{Is_Gr_Ext= False/a/}');
Error('\P{Is_Gr_Ext= False/a/}');
Expect(1, 918000, '\p{Is_Gr_Ext=false}', "");
Expect(0, 918000, '\p{^Is_Gr_Ext=false}', "");
Expect(0, 918000, '\P{Is_Gr_Ext=false}', "");
Expect(1, 918000, '\P{^Is_Gr_Ext=false}', "");
Expect(0, 917999, '\p{Is_Gr_Ext=false}', "");
Expect(1, 917999, '\p{^Is_Gr_Ext=false}', "");
Expect(1, 917999, '\P{Is_Gr_Ext=false}', "");
Expect(0, 917999, '\P{^Is_Gr_Ext=false}', "");
Expect(1, 918000, '\p{Is_Gr_Ext=	 False}', "");
Expect(0, 918000, '\p{^Is_Gr_Ext=	 False}', "");
Expect(0, 918000, '\P{Is_Gr_Ext=	 False}', "");
Expect(1, 918000, '\P{^Is_Gr_Ext=	 False}', "");
Expect(0, 917999, '\p{Is_Gr_Ext=	 False}', "");
Expect(1, 917999, '\p{^Is_Gr_Ext=	 False}', "");
Expect(1, 917999, '\P{Is_Gr_Ext=	 False}', "");
Expect(0, 917999, '\P{^Is_Gr_Ext=	 False}', "");
Error('\p{Grapheme_Extend= yes/a/}');
Error('\P{Grapheme_Extend= yes/a/}');
Expect(1, 917999, '\p{Grapheme_Extend=yes}', "");
Expect(0, 917999, '\p{^Grapheme_Extend=yes}', "");
Expect(0, 917999, '\P{Grapheme_Extend=yes}', "");
Expect(1, 917999, '\P{^Grapheme_Extend=yes}', "");
Expect(0, 918000, '\p{Grapheme_Extend=yes}', "");
Expect(1, 918000, '\p{^Grapheme_Extend=yes}', "");
Expect(1, 918000, '\P{Grapheme_Extend=yes}', "");
Expect(0, 918000, '\P{^Grapheme_Extend=yes}', "");
Expect(1, 917999, '\p{Grapheme_Extend=--Yes}', "");
Expect(0, 917999, '\p{^Grapheme_Extend=--Yes}', "");
Expect(0, 917999, '\P{Grapheme_Extend=--Yes}', "");
Expect(1, 917999, '\P{^Grapheme_Extend=--Yes}', "");
Expect(0, 918000, '\p{Grapheme_Extend=--Yes}', "");
Expect(1, 918000, '\p{^Grapheme_Extend=--Yes}', "");
Expect(1, 918000, '\P{Grapheme_Extend=--Yes}', "");
Expect(0, 918000, '\P{^Grapheme_Extend=--Yes}', "");
Error('\p{Gr_Ext=	:=y}');
Error('\P{Gr_Ext=	:=y}');
Expect(1, 917999, '\p{Gr_Ext=y}', "");
Expect(0, 917999, '\p{^Gr_Ext=y}', "");
Expect(0, 917999, '\P{Gr_Ext=y}', "");
Expect(1, 917999, '\P{^Gr_Ext=y}', "");
Expect(0, 918000, '\p{Gr_Ext=y}', "");
Expect(1, 918000, '\p{^Gr_Ext=y}', "");
Expect(1, 918000, '\P{Gr_Ext=y}', "");
Expect(0, 918000, '\P{^Gr_Ext=y}', "");
Expect(1, 917999, '\p{Gr_Ext= 	Y}', "");
Expect(0, 917999, '\p{^Gr_Ext= 	Y}', "");
Expect(0, 917999, '\P{Gr_Ext= 	Y}', "");
Expect(1, 917999, '\P{^Gr_Ext= 	Y}', "");
Expect(0, 918000, '\p{Gr_Ext= 	Y}', "");
Expect(1, 918000, '\p{^Gr_Ext= 	Y}', "");
Expect(1, 918000, '\P{Gr_Ext= 	Y}', "");
Expect(0, 918000, '\P{^Gr_Ext= 	Y}', "");
Error('\p{Is_Grapheme_Extend: - T:=}');
Error('\P{Is_Grapheme_Extend: - T:=}');
Expect(1, 917999, '\p{Is_Grapheme_Extend=t}', "");
Expect(0, 917999, '\p{^Is_Grapheme_Extend=t}', "");
Expect(0, 917999, '\P{Is_Grapheme_Extend=t}', "");
Expect(1, 917999, '\P{^Is_Grapheme_Extend=t}', "");
Expect(0, 918000, '\p{Is_Grapheme_Extend=t}', "");
Expect(1, 918000, '\p{^Is_Grapheme_Extend=t}', "");
Expect(1, 918000, '\P{Is_Grapheme_Extend=t}', "");
Expect(0, 918000, '\P{^Is_Grapheme_Extend=t}', "");
Expect(1, 917999, '\p{Is_Grapheme_Extend=--t}', "");
Expect(0, 917999, '\p{^Is_Grapheme_Extend=--t}', "");
Expect(0, 917999, '\P{Is_Grapheme_Extend=--t}', "");
Expect(1, 917999, '\P{^Is_Grapheme_Extend=--t}', "");
Expect(0, 918000, '\p{Is_Grapheme_Extend=--t}', "");
Expect(1, 918000, '\p{^Is_Grapheme_Extend=--t}', "");
Expect(1, 918000, '\P{Is_Grapheme_Extend=--t}', "");
Expect(0, 918000, '\P{^Is_Grapheme_Extend=--t}', "");
Error('\p{Is_Gr_Ext=/a/ -TRUE}');
Error('\P{Is_Gr_Ext=/a/ -TRUE}');
Expect(1, 917999, '\p{Is_Gr_Ext=true}', "");
Expect(0, 917999, '\p{^Is_Gr_Ext=true}', "");
Expect(0, 917999, '\P{Is_Gr_Ext=true}', "");
Expect(1, 917999, '\P{^Is_Gr_Ext=true}', "");
Expect(0, 918000, '\p{Is_Gr_Ext=true}', "");
Expect(1, 918000, '\p{^Is_Gr_Ext=true}', "");
Expect(1, 918000, '\P{Is_Gr_Ext=true}', "");
Expect(0, 918000, '\P{^Is_Gr_Ext=true}', "");
Expect(1, 917999, '\p{Is_Gr_Ext=_true}', "");
Expect(0, 917999, '\p{^Is_Gr_Ext=_true}', "");
Expect(0, 917999, '\P{Is_Gr_Ext=_true}', "");
Expect(1, 917999, '\P{^Is_Gr_Ext=_true}', "");
Expect(0, 918000, '\p{Is_Gr_Ext=_true}', "");
Expect(1, 918000, '\p{^Is_Gr_Ext=_true}', "");
Expect(1, 918000, '\P{Is_Gr_Ext=_true}', "");
Expect(0, 918000, '\P{^Is_Gr_Ext=_true}', "");
Error('\p{Grapheme_Link=No}');
Error('\P{Grapheme_Link=No}');
Error('\p{Gr_Link=N}');
Error('\P{Gr_Link=N}');
Error('\p{Is_Grapheme_Link=F}');
Error('\P{Is_Grapheme_Link=F}');
Error('\p{Is_Gr_Link=False}');
Error('\P{Is_Gr_Link=False}');
Error('\p{Grapheme_Link:	Yes}');
Error('\P{Grapheme_Link:	Yes}');
Error('\p{Gr_Link=Y}');
Error('\P{Gr_Link=Y}');
Error('\p{Is_Grapheme_Link=T}');
Error('\P{Is_Grapheme_Link=T}');
Error('\p{Is_Gr_Link=True}');
Error('\P{Is_Gr_Link=True}');
Error('\p{Hex_Digit:   := NO}');
Error('\P{Hex_Digit:   := NO}');
Expect(1, 65351, '\p{Hex_Digit=no}', "");
Expect(0, 65351, '\p{^Hex_Digit=no}', "");
Expect(0, 65351, '\P{Hex_Digit=no}', "");
Expect(1, 65351, '\P{^Hex_Digit=no}', "");
Expect(0, 65350, '\p{Hex_Digit=no}', "");
Expect(1, 65350, '\p{^Hex_Digit=no}', "");
Expect(1, 65350, '\P{Hex_Digit=no}', "");
Expect(0, 65350, '\P{^Hex_Digit=no}', "");
Expect(1, 65351, '\p{Hex_Digit=--No}', "");
Expect(0, 65351, '\p{^Hex_Digit=--No}', "");
Expect(0, 65351, '\P{Hex_Digit=--No}', "");
Expect(1, 65351, '\P{^Hex_Digit=--No}', "");
Expect(0, 65350, '\p{Hex_Digit=--No}', "");
Expect(1, 65350, '\p{^Hex_Digit=--No}', "");
Expect(1, 65350, '\P{Hex_Digit=--No}', "");
Expect(0, 65350, '\P{^Hex_Digit=--No}', "");
Error('\p{Hex=- N/a/}');
Error('\P{Hex=- N/a/}');
Expect(1, 65351, '\p{Hex=n}', "");
Expect(0, 65351, '\p{^Hex=n}', "");
Expect(0, 65351, '\P{Hex=n}', "");
Expect(1, 65351, '\P{^Hex=n}', "");
Expect(0, 65350, '\p{Hex=n}', "");
Expect(1, 65350, '\p{^Hex=n}', "");
Expect(1, 65350, '\P{Hex=n}', "");
Expect(0, 65350, '\P{^Hex=n}', "");
Expect(1, 65351, '\p{Hex= -N}', "");
Expect(0, 65351, '\p{^Hex= -N}', "");
Expect(0, 65351, '\P{Hex= -N}', "");
Expect(1, 65351, '\P{^Hex= -N}', "");
Expect(0, 65350, '\p{Hex= -N}', "");
Expect(1, 65350, '\p{^Hex= -N}', "");
Expect(1, 65350, '\P{Hex= -N}', "");
Expect(0, 65350, '\P{^Hex= -N}', "");
Error('\p{Is_Hex_Digit=-F:=}');
Error('\P{Is_Hex_Digit=-F:=}');
Expect(1, 65351, '\p{Is_Hex_Digit=f}', "");
Expect(0, 65351, '\p{^Is_Hex_Digit=f}', "");
Expect(0, 65351, '\P{Is_Hex_Digit=f}', "");
Expect(1, 65351, '\P{^Is_Hex_Digit=f}', "");
Expect(0, 65350, '\p{Is_Hex_Digit=f}', "");
Expect(1, 65350, '\p{^Is_Hex_Digit=f}', "");
Expect(1, 65350, '\P{Is_Hex_Digit=f}', "");
Expect(0, 65350, '\P{^Is_Hex_Digit=f}', "");
Expect(1, 65351, '\p{Is_Hex_Digit=	 f}', "");
Expect(0, 65351, '\p{^Is_Hex_Digit=	 f}', "");
Expect(0, 65351, '\P{Is_Hex_Digit=	 f}', "");
Expect(1, 65351, '\P{^Is_Hex_Digit=	 f}', "");
Expect(0, 65350, '\p{Is_Hex_Digit=	 f}', "");
Expect(1, 65350, '\p{^Is_Hex_Digit=	 f}', "");
Expect(1, 65350, '\P{Is_Hex_Digit=	 f}', "");
Expect(0, 65350, '\P{^Is_Hex_Digit=	 f}', "");
Error('\p{Is_Hex=:= False}');
Error('\P{Is_Hex=:= False}');
Expect(1, 65351, '\p{Is_Hex=false}', "");
Expect(0, 65351, '\p{^Is_Hex=false}', "");
Expect(0, 65351, '\P{Is_Hex=false}', "");
Expect(1, 65351, '\P{^Is_Hex=false}', "");
Expect(0, 65350, '\p{Is_Hex=false}', "");
Expect(1, 65350, '\p{^Is_Hex=false}', "");
Expect(1, 65350, '\P{Is_Hex=false}', "");
Expect(0, 65350, '\P{^Is_Hex=false}', "");
Expect(1, 65351, '\p{Is_Hex=-false}', "");
Expect(0, 65351, '\p{^Is_Hex=-false}', "");
Expect(0, 65351, '\P{Is_Hex=-false}', "");
Expect(1, 65351, '\P{^Is_Hex=-false}', "");
Expect(0, 65350, '\p{Is_Hex=-false}', "");
Expect(1, 65350, '\p{^Is_Hex=-false}', "");
Expect(1, 65350, '\P{Is_Hex=-false}', "");
Expect(0, 65350, '\P{^Is_Hex=-false}', "");
Error('\p{Hex_Digit=:= Yes}');
Error('\P{Hex_Digit=:= Yes}');
Expect(1, 65350, '\p{Hex_Digit=yes}', "");
Expect(0, 65350, '\p{^Hex_Digit=yes}', "");
Expect(0, 65350, '\P{Hex_Digit=yes}', "");
Expect(1, 65350, '\P{^Hex_Digit=yes}', "");
Expect(0, 65351, '\p{Hex_Digit=yes}', "");
Expect(1, 65351, '\p{^Hex_Digit=yes}', "");
Expect(1, 65351, '\P{Hex_Digit=yes}', "");
Expect(0, 65351, '\P{^Hex_Digit=yes}', "");
Expect(1, 65350, '\p{Hex_Digit:	-Yes}', "");
Expect(0, 65350, '\p{^Hex_Digit:	-Yes}', "");
Expect(0, 65350, '\P{Hex_Digit:	-Yes}', "");
Expect(1, 65350, '\P{^Hex_Digit:	-Yes}', "");
Expect(0, 65351, '\p{Hex_Digit:	-Yes}', "");
Expect(1, 65351, '\p{^Hex_Digit:	-Yes}', "");
Expect(1, 65351, '\P{Hex_Digit:	-Yes}', "");
Expect(0, 65351, '\P{^Hex_Digit:	-Yes}', "");
Error('\p{Hex=_/a/Y}');
Error('\P{Hex=_/a/Y}');
Expect(1, 65350, '\p{Hex=y}', "");
Expect(0, 65350, '\p{^Hex=y}', "");
Expect(0, 65350, '\P{Hex=y}', "");
Expect(1, 65350, '\P{^Hex=y}', "");
Expect(0, 65351, '\p{Hex=y}', "");
Expect(1, 65351, '\p{^Hex=y}', "");
Expect(1, 65351, '\P{Hex=y}', "");
Expect(0, 65351, '\P{^Hex=y}', "");
Expect(1, 65350, '\p{Hex=-	y}', "");
Expect(0, 65350, '\p{^Hex=-	y}', "");
Expect(0, 65350, '\P{Hex=-	y}', "");
Expect(1, 65350, '\P{^Hex=-	y}', "");
Expect(0, 65351, '\p{Hex=-	y}', "");
Expect(1, 65351, '\p{^Hex=-	y}', "");
Expect(1, 65351, '\P{Hex=-	y}', "");
Expect(0, 65351, '\P{^Hex=-	y}', "");
Error('\p{Is_Hex_Digit=/a/-T}');
Error('\P{Is_Hex_Digit=/a/-T}');
Expect(1, 65350, '\p{Is_Hex_Digit=t}', "");
Expect(0, 65350, '\p{^Is_Hex_Digit=t}', "");
Expect(0, 65350, '\P{Is_Hex_Digit=t}', "");
Expect(1, 65350, '\P{^Is_Hex_Digit=t}', "");
Expect(0, 65351, '\p{Is_Hex_Digit=t}', "");
Expect(1, 65351, '\p{^Is_Hex_Digit=t}', "");
Expect(1, 65351, '\P{Is_Hex_Digit=t}', "");
Expect(0, 65351, '\P{^Is_Hex_Digit=t}', "");
Expect(1, 65350, '\p{Is_Hex_Digit=_	T}', "");
Expect(0, 65350, '\p{^Is_Hex_Digit=_	T}', "");
Expect(0, 65350, '\P{Is_Hex_Digit=_	T}', "");
Expect(1, 65350, '\P{^Is_Hex_Digit=_	T}', "");
Expect(0, 65351, '\p{Is_Hex_Digit=_	T}', "");
Expect(1, 65351, '\p{^Is_Hex_Digit=_	T}', "");
Expect(1, 65351, '\P{Is_Hex_Digit=_	T}', "");
Expect(0, 65351, '\P{^Is_Hex_Digit=_	T}', "");
Error('\p{Is_Hex=-TRUE:=}');
Error('\P{Is_Hex=-TRUE:=}');
Expect(1, 65350, '\p{Is_Hex=true}', "");
Expect(0, 65350, '\p{^Is_Hex=true}', "");
Expect(0, 65350, '\P{Is_Hex=true}', "");
Expect(1, 65350, '\P{^Is_Hex=true}', "");
Expect(0, 65351, '\p{Is_Hex=true}', "");
Expect(1, 65351, '\p{^Is_Hex=true}', "");
Expect(1, 65351, '\P{Is_Hex=true}', "");
Expect(0, 65351, '\P{^Is_Hex=true}', "");
Expect(1, 65350, '\p{Is_Hex= _True}', "");
Expect(0, 65350, '\p{^Is_Hex= _True}', "");
Expect(0, 65350, '\P{Is_Hex= _True}', "");
Expect(1, 65350, '\P{^Is_Hex= _True}', "");
Expect(0, 65351, '\p{Is_Hex= _True}', "");
Expect(1, 65351, '\p{^Is_Hex= _True}', "");
Expect(1, 65351, '\P{Is_Hex= _True}', "");
Expect(0, 65351, '\P{^Is_Hex= _True}', "");
Error('\p{Hyphen=:=_No}');
Error('\P{Hyphen=:=_No}');
Expect(1, 65382, '\p{Hyphen=no}', 'deprecated');
Expect(0, 65382, '\p{^Hyphen=no}', 'deprecated');
Expect(0, 65382, '\P{Hyphen=no}', 'deprecated');
Expect(1, 65382, '\P{^Hyphen=no}', 'deprecated');
Expect(0, 65381, '\p{Hyphen=no}', 'deprecated');
Expect(1, 65381, '\p{^Hyphen=no}', 'deprecated');
Expect(1, 65381, '\P{Hyphen=no}', 'deprecated');
Expect(0, 65381, '\P{^Hyphen=no}', 'deprecated');
Expect(1, 65382, '\p{Hyphen= No}', 'deprecated');
Expect(0, 65382, '\p{^Hyphen= No}', 'deprecated');
Expect(0, 65382, '\P{Hyphen= No}', 'deprecated');
Expect(1, 65382, '\P{^Hyphen= No}', 'deprecated');
Expect(0, 65381, '\p{Hyphen= No}', 'deprecated');
Expect(1, 65381, '\p{^Hyphen= No}', 'deprecated');
Expect(1, 65381, '\P{Hyphen= No}', 'deprecated');
Expect(0, 65381, '\P{^Hyphen= No}', 'deprecated');
Error('\p{Is_Hyphen=_:=N}');
Error('\P{Is_Hyphen=_:=N}');
Expect(1, 65382, '\p{Is_Hyphen=n}', 'deprecated');
Expect(0, 65382, '\p{^Is_Hyphen=n}', 'deprecated');
Expect(0, 65382, '\P{Is_Hyphen=n}', 'deprecated');
Expect(1, 65382, '\P{^Is_Hyphen=n}', 'deprecated');
Expect(0, 65381, '\p{Is_Hyphen=n}', 'deprecated');
Expect(1, 65381, '\p{^Is_Hyphen=n}', 'deprecated');
Expect(1, 65381, '\P{Is_Hyphen=n}', 'deprecated');
Expect(0, 65381, '\P{^Is_Hyphen=n}', 'deprecated');
Expect(1, 65382, '\p{Is_Hyphen=	-N}', 'deprecated');
Expect(0, 65382, '\p{^Is_Hyphen=	-N}', 'deprecated');
Expect(0, 65382, '\P{Is_Hyphen=	-N}', 'deprecated');
Expect(1, 65382, '\P{^Is_Hyphen=	-N}', 'deprecated');
Expect(0, 65381, '\p{Is_Hyphen=	-N}', 'deprecated');
Expect(1, 65381, '\p{^Is_Hyphen=	-N}', 'deprecated');
Expect(1, 65381, '\P{Is_Hyphen=	-N}', 'deprecated');
Expect(0, 65381, '\P{^Is_Hyphen=	-N}', 'deprecated');
Error('\p{Hyphen=	_F/a/}');
Error('\P{Hyphen=	_F/a/}');
Expect(1, 65382, '\p{Hyphen=f}', 'deprecated');
Expect(0, 65382, '\p{^Hyphen=f}', 'deprecated');
Expect(0, 65382, '\P{Hyphen=f}', 'deprecated');
Expect(1, 65382, '\P{^Hyphen=f}', 'deprecated');
Expect(0, 65381, '\p{Hyphen=f}', 'deprecated');
Expect(1, 65381, '\p{^Hyphen=f}', 'deprecated');
Expect(1, 65381, '\P{Hyphen=f}', 'deprecated');
Expect(0, 65381, '\P{^Hyphen=f}', 'deprecated');
Expect(1, 65382, '\p{Hyphen=		F}', 'deprecated');
Expect(0, 65382, '\p{^Hyphen=		F}', 'deprecated');
Expect(0, 65382, '\P{Hyphen=		F}', 'deprecated');
Expect(1, 65382, '\P{^Hyphen=		F}', 'deprecated');
Expect(0, 65381, '\p{Hyphen=		F}', 'deprecated');
Expect(1, 65381, '\p{^Hyphen=		F}', 'deprecated');
Expect(1, 65381, '\P{Hyphen=		F}', 'deprecated');
Expect(0, 65381, '\P{^Hyphen=		F}', 'deprecated');
Error('\p{Is_Hyphen=-	FALSE/a/}');
Error('\P{Is_Hyphen=-	FALSE/a/}');
Expect(1, 65382, '\p{Is_Hyphen=false}', 'deprecated');
Expect(0, 65382, '\p{^Is_Hyphen=false}', 'deprecated');
Expect(0, 65382, '\P{Is_Hyphen=false}', 'deprecated');
Expect(1, 65382, '\P{^Is_Hyphen=false}', 'deprecated');
Expect(0, 65381, '\p{Is_Hyphen=false}', 'deprecated');
Expect(1, 65381, '\p{^Is_Hyphen=false}', 'deprecated');
Expect(1, 65381, '\P{Is_Hyphen=false}', 'deprecated');
Expect(0, 65381, '\P{^Is_Hyphen=false}', 'deprecated');
Expect(1, 65382, '\p{Is_Hyphen=--False}', 'deprecated');
Expect(0, 65382, '\p{^Is_Hyphen=--False}', 'deprecated');
Expect(0, 65382, '\P{Is_Hyphen=--False}', 'deprecated');
Expect(1, 65382, '\P{^Is_Hyphen=--False}', 'deprecated');
Expect(0, 65381, '\p{Is_Hyphen=--False}', 'deprecated');
Expect(1, 65381, '\p{^Is_Hyphen=--False}', 'deprecated');
Expect(1, 65381, '\P{Is_Hyphen=--False}', 'deprecated');
Expect(0, 65381, '\P{^Is_Hyphen=--False}', 'deprecated');
Error('\p{Hyphen: /a/YES}');
Error('\P{Hyphen: /a/YES}');
Expect(1, 65381, '\p{Hyphen=yes}', 'deprecated');
Expect(0, 65381, '\p{^Hyphen=yes}', 'deprecated');
Expect(0, 65381, '\P{Hyphen=yes}', 'deprecated');
Expect(1, 65381, '\P{^Hyphen=yes}', 'deprecated');
Expect(0, 65382, '\p{Hyphen=yes}', 'deprecated');
Expect(1, 65382, '\p{^Hyphen=yes}', 'deprecated');
Expect(1, 65382, '\P{Hyphen=yes}', 'deprecated');
Expect(0, 65382, '\P{^Hyphen=yes}', 'deprecated');
Expect(1, 65381, '\p{Hyphen=	-yes}', 'deprecated');
Expect(0, 65381, '\p{^Hyphen=	-yes}', 'deprecated');
Expect(0, 65381, '\P{Hyphen=	-yes}', 'deprecated');
Expect(1, 65381, '\P{^Hyphen=	-yes}', 'deprecated');
Expect(0, 65382, '\p{Hyphen=	-yes}', 'deprecated');
Expect(1, 65382, '\p{^Hyphen=	-yes}', 'deprecated');
Expect(1, 65382, '\P{Hyphen=	-yes}', 'deprecated');
Expect(0, 65382, '\P{^Hyphen=	-yes}', 'deprecated');
Error('\p{Is_Hyphen=:=	Y}');
Error('\P{Is_Hyphen=:=	Y}');
Expect(1, 65381, '\p{Is_Hyphen=y}', 'deprecated');
Expect(0, 65381, '\p{^Is_Hyphen=y}', 'deprecated');
Expect(0, 65381, '\P{Is_Hyphen=y}', 'deprecated');
Expect(1, 65381, '\P{^Is_Hyphen=y}', 'deprecated');
Expect(0, 65382, '\p{Is_Hyphen=y}', 'deprecated');
Expect(1, 65382, '\p{^Is_Hyphen=y}', 'deprecated');
Expect(1, 65382, '\P{Is_Hyphen=y}', 'deprecated');
Expect(0, 65382, '\P{^Is_Hyphen=y}', 'deprecated');
Expect(1, 65381, '\p{Is_Hyphen=-y}', 'deprecated');
Expect(0, 65381, '\p{^Is_Hyphen=-y}', 'deprecated');
Expect(0, 65381, '\P{Is_Hyphen=-y}', 'deprecated');
Expect(1, 65381, '\P{^Is_Hyphen=-y}', 'deprecated');
Expect(0, 65382, '\p{Is_Hyphen=-y}', 'deprecated');
Expect(1, 65382, '\p{^Is_Hyphen=-y}', 'deprecated');
Expect(1, 65382, '\P{Is_Hyphen=-y}', 'deprecated');
Expect(0, 65382, '\P{^Is_Hyphen=-y}', 'deprecated');
Error('\p{Hyphen=/a/_T}');
Error('\P{Hyphen=/a/_T}');
Expect(1, 65381, '\p{Hyphen=t}', 'deprecated');
Expect(0, 65381, '\p{^Hyphen=t}', 'deprecated');
Expect(0, 65381, '\P{Hyphen=t}', 'deprecated');
Expect(1, 65381, '\P{^Hyphen=t}', 'deprecated');
Expect(0, 65382, '\p{Hyphen=t}', 'deprecated');
Expect(1, 65382, '\p{^Hyphen=t}', 'deprecated');
Expect(1, 65382, '\P{Hyphen=t}', 'deprecated');
Expect(0, 65382, '\P{^Hyphen=t}', 'deprecated');
Expect(1, 65381, '\p{Hyphen=_	t}', 'deprecated');
Expect(0, 65381, '\p{^Hyphen=_	t}', 'deprecated');
Expect(0, 65381, '\P{Hyphen=_	t}', 'deprecated');
Expect(1, 65381, '\P{^Hyphen=_	t}', 'deprecated');
Expect(0, 65382, '\p{Hyphen=_	t}', 'deprecated');
Expect(1, 65382, '\p{^Hyphen=_	t}', 'deprecated');
Expect(1, 65382, '\P{Hyphen=_	t}', 'deprecated');
Expect(0, 65382, '\P{^Hyphen=_	t}', 'deprecated');
Error('\p{Is_Hyphen=-/a/true}');
Error('\P{Is_Hyphen=-/a/true}');
Expect(1, 65381, '\p{Is_Hyphen=true}', 'deprecated');
Expect(0, 65381, '\p{^Is_Hyphen=true}', 'deprecated');
Expect(0, 65381, '\P{Is_Hyphen=true}', 'deprecated');
Expect(1, 65381, '\P{^Is_Hyphen=true}', 'deprecated');
Expect(0, 65382, '\p{Is_Hyphen=true}', 'deprecated');
Expect(1, 65382, '\p{^Is_Hyphen=true}', 'deprecated');
Expect(1, 65382, '\P{Is_Hyphen=true}', 'deprecated');
Expect(0, 65382, '\P{^Is_Hyphen=true}', 'deprecated');
Expect(1, 65381, '\p{Is_Hyphen=	True}', 'deprecated');
Expect(0, 65381, '\p{^Is_Hyphen=	True}', 'deprecated');
Expect(0, 65381, '\P{Is_Hyphen=	True}', 'deprecated');
Expect(1, 65381, '\P{^Is_Hyphen=	True}', 'deprecated');
Expect(0, 65382, '\p{Is_Hyphen=	True}', 'deprecated');
Expect(1, 65382, '\p{^Is_Hyphen=	True}', 'deprecated');
Expect(1, 65382, '\P{Is_Hyphen=	True}', 'deprecated');
Expect(0, 65382, '\P{^Is_Hyphen=	True}', 'deprecated');
Error('\p{ID_Continue= /a/no}');
Error('\P{ID_Continue= /a/no}');
Expect(1, 918000, '\p{ID_Continue=no}', "");
Expect(0, 918000, '\p{^ID_Continue=no}', "");
Expect(0, 918000, '\P{ID_Continue=no}', "");
Expect(1, 918000, '\P{^ID_Continue=no}', "");
Expect(0, 917999, '\p{ID_Continue=no}', "");
Expect(1, 917999, '\p{^ID_Continue=no}', "");
Expect(1, 917999, '\P{ID_Continue=no}', "");
Expect(0, 917999, '\P{^ID_Continue=no}', "");
Expect(1, 918000, '\p{ID_Continue=-	No}', "");
Expect(0, 918000, '\p{^ID_Continue=-	No}', "");
Expect(0, 918000, '\P{ID_Continue=-	No}', "");
Expect(1, 918000, '\P{^ID_Continue=-	No}', "");
Expect(0, 917999, '\p{ID_Continue=-	No}', "");
Expect(1, 917999, '\p{^ID_Continue=-	No}', "");
Expect(1, 917999, '\P{ID_Continue=-	No}', "");
Expect(0, 917999, '\P{^ID_Continue=-	No}', "");
Error('\p{IDC:  N:=}');
Error('\P{IDC:  N:=}');
Expect(1, 918000, '\p{IDC:	n}', "");
Expect(0, 918000, '\p{^IDC:	n}', "");
Expect(0, 918000, '\P{IDC:	n}', "");
Expect(1, 918000, '\P{^IDC:	n}', "");
Expect(0, 917999, '\p{IDC:	n}', "");
Expect(1, 917999, '\p{^IDC:	n}', "");
Expect(1, 917999, '\P{IDC:	n}', "");
Expect(0, 917999, '\P{^IDC:	n}', "");
Expect(1, 918000, '\p{IDC=_ n}', "");
Expect(0, 918000, '\p{^IDC=_ n}', "");
Expect(0, 918000, '\P{IDC=_ n}', "");
Expect(1, 918000, '\P{^IDC=_ n}', "");
Expect(0, 917999, '\p{IDC=_ n}', "");
Expect(1, 917999, '\p{^IDC=_ n}', "");
Expect(1, 917999, '\P{IDC=_ n}', "");
Expect(0, 917999, '\P{^IDC=_ n}', "");
Error('\p{Is_ID_Continue= F:=}');
Error('\P{Is_ID_Continue= F:=}');
Expect(1, 918000, '\p{Is_ID_Continue=f}', "");
Expect(0, 918000, '\p{^Is_ID_Continue=f}', "");
Expect(0, 918000, '\P{Is_ID_Continue=f}', "");
Expect(1, 918000, '\P{^Is_ID_Continue=f}', "");
Expect(0, 917999, '\p{Is_ID_Continue=f}', "");
Expect(1, 917999, '\p{^Is_ID_Continue=f}', "");
Expect(1, 917999, '\P{Is_ID_Continue=f}', "");
Expect(0, 917999, '\P{^Is_ID_Continue=f}', "");
Expect(1, 918000, '\p{Is_ID_Continue=--F}', "");
Expect(0, 918000, '\p{^Is_ID_Continue=--F}', "");
Expect(0, 918000, '\P{Is_ID_Continue=--F}', "");
Expect(1, 918000, '\P{^Is_ID_Continue=--F}', "");
Expect(0, 917999, '\p{Is_ID_Continue=--F}', "");
Expect(1, 917999, '\p{^Is_ID_Continue=--F}', "");
Expect(1, 917999, '\P{Is_ID_Continue=--F}', "");
Expect(0, 917999, '\P{^Is_ID_Continue=--F}', "");
Error('\p{Is_IDC=_:=false}');
Error('\P{Is_IDC=_:=false}');
Expect(1, 918000, '\p{Is_IDC=false}', "");
Expect(0, 918000, '\p{^Is_IDC=false}', "");
Expect(0, 918000, '\P{Is_IDC=false}', "");
Expect(1, 918000, '\P{^Is_IDC=false}', "");
Expect(0, 917999, '\p{Is_IDC=false}', "");
Expect(1, 917999, '\p{^Is_IDC=false}', "");
Expect(1, 917999, '\P{Is_IDC=false}', "");
Expect(0, 917999, '\P{^Is_IDC=false}', "");
Expect(1, 918000, '\p{Is_IDC= _False}', "");
Expect(0, 918000, '\p{^Is_IDC= _False}', "");
Expect(0, 918000, '\P{Is_IDC= _False}', "");
Expect(1, 918000, '\P{^Is_IDC= _False}', "");
Expect(0, 917999, '\p{Is_IDC= _False}', "");
Expect(1, 917999, '\p{^Is_IDC= _False}', "");
Expect(1, 917999, '\P{Is_IDC= _False}', "");
Expect(0, 917999, '\P{^Is_IDC= _False}', "");
Error('\p{ID_Continue=:=  Yes}');
Error('\P{ID_Continue=:=  Yes}');
Expect(1, 917999, '\p{ID_Continue=yes}', "");
Expect(0, 917999, '\p{^ID_Continue=yes}', "");
Expect(0, 917999, '\P{ID_Continue=yes}', "");
Expect(1, 917999, '\P{^ID_Continue=yes}', "");
Expect(0, 918000, '\p{ID_Continue=yes}', "");
Expect(1, 918000, '\p{^ID_Continue=yes}', "");
Expect(1, 918000, '\P{ID_Continue=yes}', "");
Expect(0, 918000, '\P{^ID_Continue=yes}', "");
Expect(1, 917999, '\p{ID_Continue=__yes}', "");
Expect(0, 917999, '\p{^ID_Continue=__yes}', "");
Expect(0, 917999, '\P{ID_Continue=__yes}', "");
Expect(1, 917999, '\P{^ID_Continue=__yes}', "");
Expect(0, 918000, '\p{ID_Continue=__yes}', "");
Expect(1, 918000, '\p{^ID_Continue=__yes}', "");
Expect(1, 918000, '\P{ID_Continue=__yes}', "");
Expect(0, 918000, '\P{^ID_Continue=__yes}', "");
Error('\p{IDC=:=Y}');
Error('\P{IDC=:=Y}');
Expect(1, 917999, '\p{IDC=y}', "");
Expect(0, 917999, '\p{^IDC=y}', "");
Expect(0, 917999, '\P{IDC=y}', "");
Expect(1, 917999, '\P{^IDC=y}', "");
Expect(0, 918000, '\p{IDC=y}', "");
Expect(1, 918000, '\p{^IDC=y}', "");
Expect(1, 918000, '\P{IDC=y}', "");
Expect(0, 918000, '\P{^IDC=y}', "");
Expect(1, 917999, '\p{IDC=-_Y}', "");
Expect(0, 917999, '\p{^IDC=-_Y}', "");
Expect(0, 917999, '\P{IDC=-_Y}', "");
Expect(1, 917999, '\P{^IDC=-_Y}', "");
Expect(0, 918000, '\p{IDC=-_Y}', "");
Expect(1, 918000, '\p{^IDC=-_Y}', "");
Expect(1, 918000, '\P{IDC=-_Y}', "");
Expect(0, 918000, '\P{^IDC=-_Y}', "");
Error('\p{Is_ID_Continue=	-T/a/}');
Error('\P{Is_ID_Continue=	-T/a/}');
Expect(1, 917999, '\p{Is_ID_Continue=t}', "");
Expect(0, 917999, '\p{^Is_ID_Continue=t}', "");
Expect(0, 917999, '\P{Is_ID_Continue=t}', "");
Expect(1, 917999, '\P{^Is_ID_Continue=t}', "");
Expect(0, 918000, '\p{Is_ID_Continue=t}', "");
Expect(1, 918000, '\p{^Is_ID_Continue=t}', "");
Expect(1, 918000, '\P{Is_ID_Continue=t}', "");
Expect(0, 918000, '\P{^Is_ID_Continue=t}', "");
Expect(1, 917999, '\p{Is_ID_Continue:_T}', "");
Expect(0, 917999, '\p{^Is_ID_Continue:_T}', "");
Expect(0, 917999, '\P{Is_ID_Continue:_T}', "");
Expect(1, 917999, '\P{^Is_ID_Continue:_T}', "");
Expect(0, 918000, '\p{Is_ID_Continue:_T}', "");
Expect(1, 918000, '\p{^Is_ID_Continue:_T}', "");
Expect(1, 918000, '\P{Is_ID_Continue:_T}', "");
Expect(0, 918000, '\P{^Is_ID_Continue:_T}', "");
Error('\p{Is_IDC=_:=true}');
Error('\P{Is_IDC=_:=true}');
Expect(1, 917999, '\p{Is_IDC=true}', "");
Expect(0, 917999, '\p{^Is_IDC=true}', "");
Expect(0, 917999, '\P{Is_IDC=true}', "");
Expect(1, 917999, '\P{^Is_IDC=true}', "");
Expect(0, 918000, '\p{Is_IDC=true}', "");
Expect(1, 918000, '\p{^Is_IDC=true}', "");
Expect(1, 918000, '\P{Is_IDC=true}', "");
Expect(0, 918000, '\P{^Is_IDC=true}', "");
Expect(1, 917999, '\p{Is_IDC=True}', "");
Expect(0, 917999, '\p{^Is_IDC=True}', "");
Expect(0, 917999, '\P{Is_IDC=True}', "");
Expect(1, 917999, '\P{^Is_IDC=True}', "");
Expect(0, 918000, '\p{Is_IDC=True}', "");
Expect(1, 918000, '\p{^Is_IDC=True}', "");
Expect(1, 918000, '\P{Is_IDC=True}', "");
Expect(0, 918000, '\P{^Is_IDC=True}', "");
Error('\p{ID_Start=/a/- No}');
Error('\P{ID_Start=/a/- No}');
Expect(1, 195102, '\p{ID_Start=no}', "");
Expect(0, 195102, '\p{^ID_Start=no}', "");
Expect(0, 195102, '\P{ID_Start=no}', "");
Expect(1, 195102, '\P{^ID_Start=no}', "");
Expect(0, 195101, '\p{ID_Start=no}', "");
Expect(1, 195101, '\p{^ID_Start=no}', "");
Expect(1, 195101, '\P{ID_Start=no}', "");
Expect(0, 195101, '\P{^ID_Start=no}', "");
Expect(1, 195102, '\p{ID_Start=--NO}', "");
Expect(0, 195102, '\p{^ID_Start=--NO}', "");
Expect(0, 195102, '\P{ID_Start=--NO}', "");
Expect(1, 195102, '\P{^ID_Start=--NO}', "");
Expect(0, 195101, '\p{ID_Start=--NO}', "");
Expect(1, 195101, '\p{^ID_Start=--NO}', "");
Expect(1, 195101, '\P{ID_Start=--NO}', "");
Expect(0, 195101, '\P{^ID_Start=--NO}', "");
Error('\p{IDS=	:=N}');
Error('\P{IDS=	:=N}');
Expect(1, 195102, '\p{IDS=n}', "");
Expect(0, 195102, '\p{^IDS=n}', "");
Expect(0, 195102, '\P{IDS=n}', "");
Expect(1, 195102, '\P{^IDS=n}', "");
Expect(0, 195101, '\p{IDS=n}', "");
Expect(1, 195101, '\p{^IDS=n}', "");
Expect(1, 195101, '\P{IDS=n}', "");
Expect(0, 195101, '\P{^IDS=n}', "");
Expect(1, 195102, '\p{IDS=-N}', "");
Expect(0, 195102, '\p{^IDS=-N}', "");
Expect(0, 195102, '\P{IDS=-N}', "");
Expect(1, 195102, '\P{^IDS=-N}', "");
Expect(0, 195101, '\p{IDS=-N}', "");
Expect(1, 195101, '\p{^IDS=-N}', "");
Expect(1, 195101, '\P{IDS=-N}', "");
Expect(0, 195101, '\P{^IDS=-N}', "");
Error('\p{Is_ID_Start= _F/a/}');
Error('\P{Is_ID_Start= _F/a/}');
Expect(1, 195102, '\p{Is_ID_Start=f}', "");
Expect(0, 195102, '\p{^Is_ID_Start=f}', "");
Expect(0, 195102, '\P{Is_ID_Start=f}', "");
Expect(1, 195102, '\P{^Is_ID_Start=f}', "");
Expect(0, 195101, '\p{Is_ID_Start=f}', "");
Expect(1, 195101, '\p{^Is_ID_Start=f}', "");
Expect(1, 195101, '\P{Is_ID_Start=f}', "");
Expect(0, 195101, '\P{^Is_ID_Start=f}', "");
Expect(1, 195102, '\p{Is_ID_Start=-	F}', "");
Expect(0, 195102, '\p{^Is_ID_Start=-	F}', "");
Expect(0, 195102, '\P{Is_ID_Start=-	F}', "");
Expect(1, 195102, '\P{^Is_ID_Start=-	F}', "");
Expect(0, 195101, '\p{Is_ID_Start=-	F}', "");
Expect(1, 195101, '\p{^Is_ID_Start=-	F}', "");
Expect(1, 195101, '\P{Is_ID_Start=-	F}', "");
Expect(0, 195101, '\P{^Is_ID_Start=-	F}', "");
Error('\p{Is_IDS= 	False:=}');
Error('\P{Is_IDS= 	False:=}');
Expect(1, 195102, '\p{Is_IDS=false}', "");
Expect(0, 195102, '\p{^Is_IDS=false}', "");
Expect(0, 195102, '\P{Is_IDS=false}', "");
Expect(1, 195102, '\P{^Is_IDS=false}', "");
Expect(0, 195101, '\p{Is_IDS=false}', "");
Expect(1, 195101, '\p{^Is_IDS=false}', "");
Expect(1, 195101, '\P{Is_IDS=false}', "");
Expect(0, 195101, '\P{^Is_IDS=false}', "");
Expect(1, 195102, '\p{Is_IDS= FALSE}', "");
Expect(0, 195102, '\p{^Is_IDS= FALSE}', "");
Expect(0, 195102, '\P{Is_IDS= FALSE}', "");
Expect(1, 195102, '\P{^Is_IDS= FALSE}', "");
Expect(0, 195101, '\p{Is_IDS= FALSE}', "");
Expect(1, 195101, '\p{^Is_IDS= FALSE}', "");
Expect(1, 195101, '\P{Is_IDS= FALSE}', "");
Expect(0, 195101, '\P{^Is_IDS= FALSE}', "");
Error('\p{ID_Start=:=		YES}');
Error('\P{ID_Start=:=		YES}');
Expect(1, 195101, '\p{ID_Start=yes}', "");
Expect(0, 195101, '\p{^ID_Start=yes}', "");
Expect(0, 195101, '\P{ID_Start=yes}', "");
Expect(1, 195101, '\P{^ID_Start=yes}', "");
Expect(0, 195102, '\p{ID_Start=yes}', "");
Expect(1, 195102, '\p{^ID_Start=yes}', "");
Expect(1, 195102, '\P{ID_Start=yes}', "");
Expect(0, 195102, '\P{^ID_Start=yes}', "");
Expect(1, 195101, '\p{ID_Start= _YES}', "");
Expect(0, 195101, '\p{^ID_Start= _YES}', "");
Expect(0, 195101, '\P{ID_Start= _YES}', "");
Expect(1, 195101, '\P{^ID_Start= _YES}', "");
Expect(0, 195102, '\p{ID_Start= _YES}', "");
Expect(1, 195102, '\p{^ID_Start= _YES}', "");
Expect(1, 195102, '\P{ID_Start= _YES}', "");
Expect(0, 195102, '\P{^ID_Start= _YES}', "");
Error('\p{IDS=-	y:=}');
Error('\P{IDS=-	y:=}');
Expect(1, 195101, '\p{IDS=y}', "");
Expect(0, 195101, '\p{^IDS=y}', "");
Expect(0, 195101, '\P{IDS=y}', "");
Expect(1, 195101, '\P{^IDS=y}', "");
Expect(0, 195102, '\p{IDS=y}', "");
Expect(1, 195102, '\p{^IDS=y}', "");
Expect(1, 195102, '\P{IDS=y}', "");
Expect(0, 195102, '\P{^IDS=y}', "");
Expect(1, 195101, '\p{IDS=_-Y}', "");
Expect(0, 195101, '\p{^IDS=_-Y}', "");
Expect(0, 195101, '\P{IDS=_-Y}', "");
Expect(1, 195101, '\P{^IDS=_-Y}', "");
Expect(0, 195102, '\p{IDS=_-Y}', "");
Expect(1, 195102, '\p{^IDS=_-Y}', "");
Expect(1, 195102, '\P{IDS=_-Y}', "");
Expect(0, 195102, '\P{^IDS=_-Y}', "");
Error('\p{Is_ID_Start=	/a/T}');
Error('\P{Is_ID_Start=	/a/T}');
Expect(1, 195101, '\p{Is_ID_Start:	t}', "");
Expect(0, 195101, '\p{^Is_ID_Start:	t}', "");
Expect(0, 195101, '\P{Is_ID_Start:	t}', "");
Expect(1, 195101, '\P{^Is_ID_Start:	t}', "");
Expect(0, 195102, '\p{Is_ID_Start:	t}', "");
Expect(1, 195102, '\p{^Is_ID_Start:	t}', "");
Expect(1, 195102, '\P{Is_ID_Start:	t}', "");
Expect(0, 195102, '\P{^Is_ID_Start:	t}', "");
Expect(1, 195101, '\p{Is_ID_Start=_ T}', "");
Expect(0, 195101, '\p{^Is_ID_Start=_ T}', "");
Expect(0, 195101, '\P{Is_ID_Start=_ T}', "");
Expect(1, 195101, '\P{^Is_ID_Start=_ T}', "");
Expect(0, 195102, '\p{Is_ID_Start=_ T}', "");
Expect(1, 195102, '\p{^Is_ID_Start=_ T}', "");
Expect(1, 195102, '\P{Is_ID_Start=_ T}', "");
Expect(0, 195102, '\P{^Is_ID_Start=_ T}', "");
Error('\p{Is_IDS:	_True/a/}');
Error('\P{Is_IDS:	_True/a/}');
Expect(1, 195101, '\p{Is_IDS:	true}', "");
Expect(0, 195101, '\p{^Is_IDS:	true}', "");
Expect(0, 195101, '\P{Is_IDS:	true}', "");
Expect(1, 195101, '\P{^Is_IDS:	true}', "");
Expect(0, 195102, '\p{Is_IDS:	true}', "");
Expect(1, 195102, '\p{^Is_IDS:	true}', "");
Expect(1, 195102, '\P{Is_IDS:	true}', "");
Expect(0, 195102, '\P{^Is_IDS:	true}', "");
Expect(1, 195101, '\p{Is_IDS:	_True}', "");
Expect(0, 195101, '\p{^Is_IDS:	_True}', "");
Expect(0, 195101, '\P{Is_IDS:	_True}', "");
Expect(1, 195101, '\P{^Is_IDS:	_True}', "");
Expect(0, 195102, '\p{Is_IDS:	_True}', "");
Expect(1, 195102, '\p{^Is_IDS:	_True}', "");
Expect(1, 195102, '\P{Is_IDS:	_True}', "");
Expect(0, 195102, '\P{^Is_IDS:	_True}', "");
Error('\p{IDS_Binary_Operator=	NO/a/}');
Error('\P{IDS_Binary_Operator=	NO/a/}');
Expect(1, 12284, '\p{IDS_Binary_Operator=no}', "");
Expect(0, 12284, '\p{^IDS_Binary_Operator=no}', "");
Expect(0, 12284, '\P{IDS_Binary_Operator=no}', "");
Expect(1, 12284, '\P{^IDS_Binary_Operator=no}', "");
Expect(0, 12283, '\p{IDS_Binary_Operator=no}', "");
Expect(1, 12283, '\p{^IDS_Binary_Operator=no}', "");
Expect(1, 12283, '\P{IDS_Binary_Operator=no}', "");
Expect(0, 12283, '\P{^IDS_Binary_Operator=no}', "");
Expect(1, 12284, '\p{IDS_Binary_Operator=-NO}', "");
Expect(0, 12284, '\p{^IDS_Binary_Operator=-NO}', "");
Expect(0, 12284, '\P{IDS_Binary_Operator=-NO}', "");
Expect(1, 12284, '\P{^IDS_Binary_Operator=-NO}', "");
Expect(0, 12283, '\p{IDS_Binary_Operator=-NO}', "");
Expect(1, 12283, '\p{^IDS_Binary_Operator=-NO}', "");
Expect(1, 12283, '\P{IDS_Binary_Operator=-NO}', "");
Expect(0, 12283, '\P{^IDS_Binary_Operator=-NO}', "");
Error('\p{IDSB:   --N/a/}');
Error('\P{IDSB:   --N/a/}');
Expect(1, 12284, '\p{IDSB:n}', "");
Expect(0, 12284, '\p{^IDSB:n}', "");
Expect(0, 12284, '\P{IDSB:n}', "");
Expect(1, 12284, '\P{^IDSB:n}', "");
Expect(0, 12283, '\p{IDSB:n}', "");
Expect(1, 12283, '\p{^IDSB:n}', "");
Expect(1, 12283, '\P{IDSB:n}', "");
Expect(0, 12283, '\P{^IDSB:n}', "");
Expect(1, 12284, '\p{IDSB=	-n}', "");
Expect(0, 12284, '\p{^IDSB=	-n}', "");
Expect(0, 12284, '\P{IDSB=	-n}', "");
Expect(1, 12284, '\P{^IDSB=	-n}', "");
Expect(0, 12283, '\p{IDSB=	-n}', "");
Expect(1, 12283, '\p{^IDSB=	-n}', "");
Expect(1, 12283, '\P{IDSB=	-n}', "");
Expect(0, 12283, '\P{^IDSB=	-n}', "");
Error('\p{Is_IDS_Binary_Operator= _F/a/}');
Error('\P{Is_IDS_Binary_Operator= _F/a/}');
Expect(1, 12284, '\p{Is_IDS_Binary_Operator=f}', "");
Expect(0, 12284, '\p{^Is_IDS_Binary_Operator=f}', "");
Expect(0, 12284, '\P{Is_IDS_Binary_Operator=f}', "");
Expect(1, 12284, '\P{^Is_IDS_Binary_Operator=f}', "");
Expect(0, 12283, '\p{Is_IDS_Binary_Operator=f}', "");
Expect(1, 12283, '\p{^Is_IDS_Binary_Operator=f}', "");
Expect(1, 12283, '\P{Is_IDS_Binary_Operator=f}', "");
Expect(0, 12283, '\P{^Is_IDS_Binary_Operator=f}', "");
Expect(1, 12284, '\p{Is_IDS_Binary_Operator:   -	f}', "");
Expect(0, 12284, '\p{^Is_IDS_Binary_Operator:   -	f}', "");
Expect(0, 12284, '\P{Is_IDS_Binary_Operator:   -	f}', "");
Expect(1, 12284, '\P{^Is_IDS_Binary_Operator:   -	f}', "");
Expect(0, 12283, '\p{Is_IDS_Binary_Operator:   -	f}', "");
Expect(1, 12283, '\p{^Is_IDS_Binary_Operator:   -	f}', "");
Expect(1, 12283, '\P{Is_IDS_Binary_Operator:   -	f}', "");
Expect(0, 12283, '\P{^Is_IDS_Binary_Operator:   -	f}', "");
Error('\p{Is_IDSB=	/a/False}');
Error('\P{Is_IDSB=	/a/False}');
Expect(1, 12284, '\p{Is_IDSB=false}', "");
Expect(0, 12284, '\p{^Is_IDSB=false}', "");
Expect(0, 12284, '\P{Is_IDSB=false}', "");
Expect(1, 12284, '\P{^Is_IDSB=false}', "");
Expect(0, 12283, '\p{Is_IDSB=false}', "");
Expect(1, 12283, '\p{^Is_IDSB=false}', "");
Expect(1, 12283, '\P{Is_IDSB=false}', "");
Expect(0, 12283, '\P{^Is_IDSB=false}', "");
Expect(1, 12284, '\p{Is_IDSB=FALSE}', "");
Expect(0, 12284, '\p{^Is_IDSB=FALSE}', "");
Expect(0, 12284, '\P{Is_IDSB=FALSE}', "");
Expect(1, 12284, '\P{^Is_IDSB=FALSE}', "");
Expect(0, 12283, '\p{Is_IDSB=FALSE}', "");
Expect(1, 12283, '\p{^Is_IDSB=FALSE}', "");
Expect(1, 12283, '\P{Is_IDSB=FALSE}', "");
Expect(0, 12283, '\P{^Is_IDSB=FALSE}', "");
Error('\p{IDS_Binary_Operator= _Yes:=}');
Error('\P{IDS_Binary_Operator= _Yes:=}');
Expect(1, 12283, '\p{IDS_Binary_Operator=yes}', "");
Expect(0, 12283, '\p{^IDS_Binary_Operator=yes}', "");
Expect(0, 12283, '\P{IDS_Binary_Operator=yes}', "");
Expect(1, 12283, '\P{^IDS_Binary_Operator=yes}', "");
Expect(0, 12284, '\p{IDS_Binary_Operator=yes}', "");
Expect(1, 12284, '\p{^IDS_Binary_Operator=yes}', "");
Expect(1, 12284, '\P{IDS_Binary_Operator=yes}', "");
Expect(0, 12284, '\P{^IDS_Binary_Operator=yes}', "");
Expect(1, 12283, '\p{IDS_Binary_Operator=Yes}', "");
Expect(0, 12283, '\p{^IDS_Binary_Operator=Yes}', "");
Expect(0, 12283, '\P{IDS_Binary_Operator=Yes}', "");
Expect(1, 12283, '\P{^IDS_Binary_Operator=Yes}', "");
Expect(0, 12284, '\p{IDS_Binary_Operator=Yes}', "");
Expect(1, 12284, '\p{^IDS_Binary_Operator=Yes}', "");
Expect(1, 12284, '\P{IDS_Binary_Operator=Yes}', "");
Expect(0, 12284, '\P{^IDS_Binary_Operator=Yes}', "");
Error('\p{IDSB=- Y:=}');
Error('\P{IDSB=- Y:=}');
Expect(1, 12283, '\p{IDSB=y}', "");
Expect(0, 12283, '\p{^IDSB=y}', "");
Expect(0, 12283, '\P{IDSB=y}', "");
Expect(1, 12283, '\P{^IDSB=y}', "");
Expect(0, 12284, '\p{IDSB=y}', "");
Expect(1, 12284, '\p{^IDSB=y}', "");
Expect(1, 12284, '\P{IDSB=y}', "");
Expect(0, 12284, '\P{^IDSB=y}', "");
Expect(1, 12283, '\p{IDSB=_y}', "");
Expect(0, 12283, '\p{^IDSB=_y}', "");
Expect(0, 12283, '\P{IDSB=_y}', "");
Expect(1, 12283, '\P{^IDSB=_y}', "");
Expect(0, 12284, '\p{IDSB=_y}', "");
Expect(1, 12284, '\p{^IDSB=_y}', "");
Expect(1, 12284, '\P{IDSB=_y}', "");
Expect(0, 12284, '\P{^IDSB=_y}', "");
Error('\p{Is_IDS_Binary_Operator= :=T}');
Error('\P{Is_IDS_Binary_Operator= :=T}');
Expect(1, 12283, '\p{Is_IDS_Binary_Operator:	t}', "");
Expect(0, 12283, '\p{^Is_IDS_Binary_Operator:	t}', "");
Expect(0, 12283, '\P{Is_IDS_Binary_Operator:	t}', "");
Expect(1, 12283, '\P{^Is_IDS_Binary_Operator:	t}', "");
Expect(0, 12284, '\p{Is_IDS_Binary_Operator:	t}', "");
Expect(1, 12284, '\p{^Is_IDS_Binary_Operator:	t}', "");
Expect(1, 12284, '\P{Is_IDS_Binary_Operator:	t}', "");
Expect(0, 12284, '\P{^Is_IDS_Binary_Operator:	t}', "");
Expect(1, 12283, '\p{Is_IDS_Binary_Operator=__T}', "");
Expect(0, 12283, '\p{^Is_IDS_Binary_Operator=__T}', "");
Expect(0, 12283, '\P{Is_IDS_Binary_Operator=__T}', "");
Expect(1, 12283, '\P{^Is_IDS_Binary_Operator=__T}', "");
Expect(0, 12284, '\p{Is_IDS_Binary_Operator=__T}', "");
Expect(1, 12284, '\p{^Is_IDS_Binary_Operator=__T}', "");
Expect(1, 12284, '\P{Is_IDS_Binary_Operator=__T}', "");
Expect(0, 12284, '\P{^Is_IDS_Binary_Operator=__T}', "");
Error('\p{Is_IDSB=- true/a/}');
Error('\P{Is_IDSB=- true/a/}');
Expect(1, 12283, '\p{Is_IDSB=true}', "");
Expect(0, 12283, '\p{^Is_IDSB=true}', "");
Expect(0, 12283, '\P{Is_IDSB=true}', "");
Expect(1, 12283, '\P{^Is_IDSB=true}', "");
Expect(0, 12284, '\p{Is_IDSB=true}', "");
Expect(1, 12284, '\p{^Is_IDSB=true}', "");
Expect(1, 12284, '\P{Is_IDSB=true}', "");
Expect(0, 12284, '\P{^Is_IDSB=true}', "");
Expect(1, 12283, '\p{Is_IDSB: -TRUE}', "");
Expect(0, 12283, '\p{^Is_IDSB: -TRUE}', "");
Expect(0, 12283, '\P{Is_IDSB: -TRUE}', "");
Expect(1, 12283, '\P{^Is_IDSB: -TRUE}', "");
Expect(0, 12284, '\p{Is_IDSB: -TRUE}', "");
Expect(1, 12284, '\p{^Is_IDSB: -TRUE}', "");
Expect(1, 12284, '\P{Is_IDSB: -TRUE}', "");
Expect(0, 12284, '\P{^Is_IDSB: -TRUE}', "");
Error('\p{IDS_Trinary_Operator=	:=No}');
Error('\P{IDS_Trinary_Operator=	:=No}');
Expect(1, 12276, '\p{IDS_Trinary_Operator=no}', "");
Expect(0, 12276, '\p{^IDS_Trinary_Operator=no}', "");
Expect(0, 12276, '\P{IDS_Trinary_Operator=no}', "");
Expect(1, 12276, '\P{^IDS_Trinary_Operator=no}', "");
Expect(0, 12275, '\p{IDS_Trinary_Operator=no}', "");
Expect(1, 12275, '\p{^IDS_Trinary_Operator=no}', "");
Expect(1, 12275, '\P{IDS_Trinary_Operator=no}', "");
Expect(0, 12275, '\P{^IDS_Trinary_Operator=no}', "");
Expect(1, 12276, '\p{IDS_Trinary_Operator=	No}', "");
Expect(0, 12276, '\p{^IDS_Trinary_Operator=	No}', "");
Expect(0, 12276, '\P{IDS_Trinary_Operator=	No}', "");
Expect(1, 12276, '\P{^IDS_Trinary_Operator=	No}', "");
Expect(0, 12275, '\p{IDS_Trinary_Operator=	No}', "");
Expect(1, 12275, '\p{^IDS_Trinary_Operator=	No}', "");
Expect(1, 12275, '\P{IDS_Trinary_Operator=	No}', "");
Expect(0, 12275, '\P{^IDS_Trinary_Operator=	No}', "");
Error('\p{IDST=/a/__N}');
Error('\P{IDST=/a/__N}');
Expect(1, 12276, '\p{IDST=n}', "");
Expect(0, 12276, '\p{^IDST=n}', "");
Expect(0, 12276, '\P{IDST=n}', "");
Expect(1, 12276, '\P{^IDST=n}', "");
Expect(0, 12275, '\p{IDST=n}', "");
Expect(1, 12275, '\p{^IDST=n}', "");
Expect(1, 12275, '\P{IDST=n}', "");
Expect(0, 12275, '\P{^IDST=n}', "");
Expect(1, 12276, '\p{IDST=_	N}', "");
Expect(0, 12276, '\p{^IDST=_	N}', "");
Expect(0, 12276, '\P{IDST=_	N}', "");
Expect(1, 12276, '\P{^IDST=_	N}', "");
Expect(0, 12275, '\p{IDST=_	N}', "");
Expect(1, 12275, '\p{^IDST=_	N}', "");
Expect(1, 12275, '\P{IDST=_	N}', "");
Expect(0, 12275, '\P{^IDST=_	N}', "");
Error('\p{Is_IDS_Trinary_Operator=-:=F}');
Error('\P{Is_IDS_Trinary_Operator=-:=F}');
Expect(1, 12276, '\p{Is_IDS_Trinary_Operator=f}', "");
Expect(0, 12276, '\p{^Is_IDS_Trinary_Operator=f}', "");
Expect(0, 12276, '\P{Is_IDS_Trinary_Operator=f}', "");
Expect(1, 12276, '\P{^Is_IDS_Trinary_Operator=f}', "");
Expect(0, 12275, '\p{Is_IDS_Trinary_Operator=f}', "");
Expect(1, 12275, '\p{^Is_IDS_Trinary_Operator=f}', "");
Expect(1, 12275, '\P{Is_IDS_Trinary_Operator=f}', "");
Expect(0, 12275, '\P{^Is_IDS_Trinary_Operator=f}', "");
Expect(1, 12276, '\p{Is_IDS_Trinary_Operator=_F}', "");
Expect(0, 12276, '\p{^Is_IDS_Trinary_Operator=_F}', "");
Expect(0, 12276, '\P{Is_IDS_Trinary_Operator=_F}', "");
Expect(1, 12276, '\P{^Is_IDS_Trinary_Operator=_F}', "");
Expect(0, 12275, '\p{Is_IDS_Trinary_Operator=_F}', "");
Expect(1, 12275, '\p{^Is_IDS_Trinary_Operator=_F}', "");
Expect(1, 12275, '\P{Is_IDS_Trinary_Operator=_F}', "");
Expect(0, 12275, '\P{^Is_IDS_Trinary_Operator=_F}', "");
Error('\p{Is_IDST=:=--False}');
Error('\P{Is_IDST=:=--False}');
Expect(1, 12276, '\p{Is_IDST=false}', "");
Expect(0, 12276, '\p{^Is_IDST=false}', "");
Expect(0, 12276, '\P{Is_IDST=false}', "");
Expect(1, 12276, '\P{^Is_IDST=false}', "");
Expect(0, 12275, '\p{Is_IDST=false}', "");
Expect(1, 12275, '\p{^Is_IDST=false}', "");
Expect(1, 12275, '\P{Is_IDST=false}', "");
Expect(0, 12275, '\P{^Is_IDST=false}', "");
Expect(1, 12276, '\p{Is_IDST=_-False}', "");
Expect(0, 12276, '\p{^Is_IDST=_-False}', "");
Expect(0, 12276, '\P{Is_IDST=_-False}', "");
Expect(1, 12276, '\P{^Is_IDST=_-False}', "");
Expect(0, 12275, '\p{Is_IDST=_-False}', "");
Expect(1, 12275, '\p{^Is_IDST=_-False}', "");
Expect(1, 12275, '\P{Is_IDST=_-False}', "");
Expect(0, 12275, '\P{^Is_IDST=_-False}', "");
Error('\p{IDS_Trinary_Operator=/a/-Yes}');
Error('\P{IDS_Trinary_Operator=/a/-Yes}');
Expect(1, 12275, '\p{IDS_Trinary_Operator:	yes}', "");
Expect(0, 12275, '\p{^IDS_Trinary_Operator:	yes}', "");
Expect(0, 12275, '\P{IDS_Trinary_Operator:	yes}', "");
Expect(1, 12275, '\P{^IDS_Trinary_Operator:	yes}', "");
Expect(0, 12276, '\p{IDS_Trinary_Operator:	yes}', "");
Expect(1, 12276, '\p{^IDS_Trinary_Operator:	yes}', "");
Expect(1, 12276, '\P{IDS_Trinary_Operator:	yes}', "");
Expect(0, 12276, '\P{^IDS_Trinary_Operator:	yes}', "");
Expect(1, 12275, '\p{IDS_Trinary_Operator=-Yes}', "");
Expect(0, 12275, '\p{^IDS_Trinary_Operator=-Yes}', "");
Expect(0, 12275, '\P{IDS_Trinary_Operator=-Yes}', "");
Expect(1, 12275, '\P{^IDS_Trinary_Operator=-Yes}', "");
Expect(0, 12276, '\p{IDS_Trinary_Operator=-Yes}', "");
Expect(1, 12276, '\p{^IDS_Trinary_Operator=-Yes}', "");
Expect(1, 12276, '\P{IDS_Trinary_Operator=-Yes}', "");
Expect(0, 12276, '\P{^IDS_Trinary_Operator=-Yes}', "");
Error('\p{IDST= /a/Y}');
Error('\P{IDST= /a/Y}');
Expect(1, 12275, '\p{IDST=y}', "");
Expect(0, 12275, '\p{^IDST=y}', "");
Expect(0, 12275, '\P{IDST=y}', "");
Expect(1, 12275, '\P{^IDST=y}', "");
Expect(0, 12276, '\p{IDST=y}', "");
Expect(1, 12276, '\p{^IDST=y}', "");
Expect(1, 12276, '\P{IDST=y}', "");
Expect(0, 12276, '\P{^IDST=y}', "");
Expect(1, 12275, '\p{IDST=-_Y}', "");
Expect(0, 12275, '\p{^IDST=-_Y}', "");
Expect(0, 12275, '\P{IDST=-_Y}', "");
Expect(1, 12275, '\P{^IDST=-_Y}', "");
Expect(0, 12276, '\p{IDST=-_Y}', "");
Expect(1, 12276, '\p{^IDST=-_Y}', "");
Expect(1, 12276, '\P{IDST=-_Y}', "");
Expect(0, 12276, '\P{^IDST=-_Y}', "");
Error('\p{Is_IDS_Trinary_Operator: 	/a/T}');
Error('\P{Is_IDS_Trinary_Operator: 	/a/T}');
Expect(1, 12275, '\p{Is_IDS_Trinary_Operator=t}', "");
Expect(0, 12275, '\p{^Is_IDS_Trinary_Operator=t}', "");
Expect(0, 12275, '\P{Is_IDS_Trinary_Operator=t}', "");
Expect(1, 12275, '\P{^Is_IDS_Trinary_Operator=t}', "");
Expect(0, 12276, '\p{Is_IDS_Trinary_Operator=t}', "");
Expect(1, 12276, '\p{^Is_IDS_Trinary_Operator=t}', "");
Expect(1, 12276, '\P{Is_IDS_Trinary_Operator=t}', "");
Expect(0, 12276, '\P{^Is_IDS_Trinary_Operator=t}', "");
Expect(1, 12275, '\p{Is_IDS_Trinary_Operator=- T}', "");
Expect(0, 12275, '\p{^Is_IDS_Trinary_Operator=- T}', "");
Expect(0, 12275, '\P{Is_IDS_Trinary_Operator=- T}', "");
Expect(1, 12275, '\P{^Is_IDS_Trinary_Operator=- T}', "");
Expect(0, 12276, '\p{Is_IDS_Trinary_Operator=- T}', "");
Expect(1, 12276, '\p{^Is_IDS_Trinary_Operator=- T}', "");
Expect(1, 12276, '\P{Is_IDS_Trinary_Operator=- T}', "");
Expect(0, 12276, '\P{^Is_IDS_Trinary_Operator=- T}', "");
Error('\p{Is_IDST=:=-true}');
Error('\P{Is_IDST=:=-true}');
Expect(1, 12275, '\p{Is_IDST=true}', "");
Expect(0, 12275, '\p{^Is_IDST=true}', "");
Expect(0, 12275, '\P{Is_IDST=true}', "");
Expect(1, 12275, '\P{^Is_IDST=true}', "");
Expect(0, 12276, '\p{Is_IDST=true}', "");
Expect(1, 12276, '\p{^Is_IDST=true}', "");
Expect(1, 12276, '\P{Is_IDST=true}', "");
Expect(0, 12276, '\P{^Is_IDST=true}', "");
Expect(1, 12275, '\p{Is_IDST=	-true}', "");
Expect(0, 12275, '\p{^Is_IDST=	-true}', "");
Expect(0, 12275, '\P{Is_IDST=	-true}', "");
Expect(1, 12275, '\P{^Is_IDST=	-true}', "");
Expect(0, 12276, '\p{Is_IDST=	-true}', "");
Expect(1, 12276, '\p{^Is_IDST=	-true}', "");
Expect(1, 12276, '\P{Is_IDST=	-true}', "");
Expect(0, 12276, '\P{^Is_IDST=	-true}', "");
Error('\p{Ideographic= _No/a/}');
Error('\P{Ideographic= _No/a/}');
Expect(1, 195102, '\p{Ideographic=no}', "");
Expect(0, 195102, '\p{^Ideographic=no}', "");
Expect(0, 195102, '\P{Ideographic=no}', "");
Expect(1, 195102, '\P{^Ideographic=no}', "");
Expect(0, 195101, '\p{Ideographic=no}', "");
Expect(1, 195101, '\p{^Ideographic=no}', "");
Expect(1, 195101, '\P{Ideographic=no}', "");
Expect(0, 195101, '\P{^Ideographic=no}', "");
Expect(1, 195102, '\p{Ideographic=-_no}', "");
Expect(0, 195102, '\p{^Ideographic=-_no}', "");
Expect(0, 195102, '\P{Ideographic=-_no}', "");
Expect(1, 195102, '\P{^Ideographic=-_no}', "");
Expect(0, 195101, '\p{Ideographic=-_no}', "");
Expect(1, 195101, '\p{^Ideographic=-_no}', "");
Expect(1, 195101, '\P{Ideographic=-_no}', "");
Expect(0, 195101, '\P{^Ideographic=-_no}', "");
Error('\p{Ideo= N/a/}');
Error('\P{Ideo= N/a/}');
Expect(1, 195102, '\p{Ideo=n}', "");
Expect(0, 195102, '\p{^Ideo=n}', "");
Expect(0, 195102, '\P{Ideo=n}', "");
Expect(1, 195102, '\P{^Ideo=n}', "");
Expect(0, 195101, '\p{Ideo=n}', "");
Expect(1, 195101, '\p{^Ideo=n}', "");
Expect(1, 195101, '\P{Ideo=n}', "");
Expect(0, 195101, '\P{^Ideo=n}', "");
Expect(1, 195102, '\p{Ideo= 	N}', "");
Expect(0, 195102, '\p{^Ideo= 	N}', "");
Expect(0, 195102, '\P{Ideo= 	N}', "");
Expect(1, 195102, '\P{^Ideo= 	N}', "");
Expect(0, 195101, '\p{Ideo= 	N}', "");
Expect(1, 195101, '\p{^Ideo= 	N}', "");
Expect(1, 195101, '\P{Ideo= 	N}', "");
Expect(0, 195101, '\P{^Ideo= 	N}', "");
Error('\p{Is_Ideographic=/a/f}');
Error('\P{Is_Ideographic=/a/f}');
Expect(1, 195102, '\p{Is_Ideographic=f}', "");
Expect(0, 195102, '\p{^Is_Ideographic=f}', "");
Expect(0, 195102, '\P{Is_Ideographic=f}', "");
Expect(1, 195102, '\P{^Is_Ideographic=f}', "");
Expect(0, 195101, '\p{Is_Ideographic=f}', "");
Expect(1, 195101, '\p{^Is_Ideographic=f}', "");
Expect(1, 195101, '\P{Is_Ideographic=f}', "");
Expect(0, 195101, '\P{^Is_Ideographic=f}', "");
Expect(1, 195102, '\p{Is_Ideographic=- F}', "");
Expect(0, 195102, '\p{^Is_Ideographic=- F}', "");
Expect(0, 195102, '\P{Is_Ideographic=- F}', "");
Expect(1, 195102, '\P{^Is_Ideographic=- F}', "");
Expect(0, 195101, '\p{Is_Ideographic=- F}', "");
Expect(1, 195101, '\p{^Is_Ideographic=- F}', "");
Expect(1, 195101, '\P{Is_Ideographic=- F}', "");
Expect(0, 195101, '\P{^Is_Ideographic=- F}', "");
Error('\p{Is_Ideo=__False/a/}');
Error('\P{Is_Ideo=__False/a/}');
Expect(1, 195102, '\p{Is_Ideo=false}', "");
Expect(0, 195102, '\p{^Is_Ideo=false}', "");
Expect(0, 195102, '\P{Is_Ideo=false}', "");
Expect(1, 195102, '\P{^Is_Ideo=false}', "");
Expect(0, 195101, '\p{Is_Ideo=false}', "");
Expect(1, 195101, '\p{^Is_Ideo=false}', "");
Expect(1, 195101, '\P{Is_Ideo=false}', "");
Expect(0, 195101, '\P{^Is_Ideo=false}', "");
Expect(1, 195102, '\p{Is_Ideo=_	False}', "");
Expect(0, 195102, '\p{^Is_Ideo=_	False}', "");
Expect(0, 195102, '\P{Is_Ideo=_	False}', "");
Expect(1, 195102, '\P{^Is_Ideo=_	False}', "");
Expect(0, 195101, '\p{Is_Ideo=_	False}', "");
Expect(1, 195101, '\p{^Is_Ideo=_	False}', "");
Expect(1, 195101, '\P{Is_Ideo=_	False}', "");
Expect(0, 195101, '\P{^Is_Ideo=_	False}', "");
Error('\p{Ideographic=/a/	-YES}');
Error('\P{Ideographic=/a/	-YES}');
Expect(1, 195101, '\p{Ideographic=yes}', "");
Expect(0, 195101, '\p{^Ideographic=yes}', "");
Expect(0, 195101, '\P{Ideographic=yes}', "");
Expect(1, 195101, '\P{^Ideographic=yes}', "");
Expect(0, 195102, '\p{Ideographic=yes}', "");
Expect(1, 195102, '\p{^Ideographic=yes}', "");
Expect(1, 195102, '\P{Ideographic=yes}', "");
Expect(0, 195102, '\P{^Ideographic=yes}', "");
Expect(1, 195101, '\p{Ideographic=--yes}', "");
Expect(0, 195101, '\p{^Ideographic=--yes}', "");
Expect(0, 195101, '\P{Ideographic=--yes}', "");
Expect(1, 195101, '\P{^Ideographic=--yes}', "");
Expect(0, 195102, '\p{Ideographic=--yes}', "");
Expect(1, 195102, '\p{^Ideographic=--yes}', "");
Expect(1, 195102, '\P{Ideographic=--yes}', "");
Expect(0, 195102, '\P{^Ideographic=--yes}', "");
Error('\p{Ideo=_Y/a/}');
Error('\P{Ideo=_Y/a/}');
Expect(1, 195101, '\p{Ideo:	y}', "");
Expect(0, 195101, '\p{^Ideo:	y}', "");
Expect(0, 195101, '\P{Ideo:	y}', "");
Expect(1, 195101, '\P{^Ideo:	y}', "");
Expect(0, 195102, '\p{Ideo:	y}', "");
Expect(1, 195102, '\p{^Ideo:	y}', "");
Expect(1, 195102, '\P{Ideo:	y}', "");
Expect(0, 195102, '\P{^Ideo:	y}', "");
Expect(1, 195101, '\p{Ideo=_Y}', "");
Expect(0, 195101, '\p{^Ideo=_Y}', "");
Expect(0, 195101, '\P{Ideo=_Y}', "");
Expect(1, 195101, '\P{^Ideo=_Y}', "");
Expect(0, 195102, '\p{Ideo=_Y}', "");
Expect(1, 195102, '\p{^Ideo=_Y}', "");
Expect(1, 195102, '\P{Ideo=_Y}', "");
Expect(0, 195102, '\P{^Ideo=_Y}', "");
Error('\p{Is_Ideographic=_/a/T}');
Error('\P{Is_Ideographic=_/a/T}');
Expect(1, 195101, '\p{Is_Ideographic=t}', "");
Expect(0, 195101, '\p{^Is_Ideographic=t}', "");
Expect(0, 195101, '\P{Is_Ideographic=t}', "");
Expect(1, 195101, '\P{^Is_Ideographic=t}', "");
Expect(0, 195102, '\p{Is_Ideographic=t}', "");
Expect(1, 195102, '\p{^Is_Ideographic=t}', "");
Expect(1, 195102, '\P{Is_Ideographic=t}', "");
Expect(0, 195102, '\P{^Is_Ideographic=t}', "");
Expect(1, 195101, '\p{Is_Ideographic=- t}', "");
Expect(0, 195101, '\p{^Is_Ideographic=- t}', "");
Expect(0, 195101, '\P{Is_Ideographic=- t}', "");
Expect(1, 195101, '\P{^Is_Ideographic=- t}', "");
Expect(0, 195102, '\p{Is_Ideographic=- t}', "");
Expect(1, 195102, '\p{^Is_Ideographic=- t}', "");
Expect(1, 195102, '\P{Is_Ideographic=- t}', "");
Expect(0, 195102, '\P{^Is_Ideographic=- t}', "");
Error('\p{Is_Ideo=:= True}');
Error('\P{Is_Ideo=:= True}');
Expect(1, 195101, '\p{Is_Ideo=true}', "");
Expect(0, 195101, '\p{^Is_Ideo=true}', "");
Expect(0, 195101, '\P{Is_Ideo=true}', "");
Expect(1, 195101, '\P{^Is_Ideo=true}', "");
Expect(0, 195102, '\p{Is_Ideo=true}', "");
Expect(1, 195102, '\p{^Is_Ideo=true}', "");
Expect(1, 195102, '\P{Is_Ideo=true}', "");
Expect(0, 195102, '\P{^Is_Ideo=true}', "");
Expect(1, 195101, '\p{Is_Ideo:  True}', "");
Expect(0, 195101, '\p{^Is_Ideo:  True}', "");
Expect(0, 195101, '\P{Is_Ideo:  True}', "");
Expect(1, 195101, '\P{^Is_Ideo:  True}', "");
Expect(0, 195102, '\p{Is_Ideo:  True}', "");
Expect(1, 195102, '\p{^Is_Ideo:  True}', "");
Expect(1, 195102, '\P{Is_Ideo:  True}', "");
Expect(0, 195102, '\P{^Is_Ideo:  True}', "");
Error('\p{Present_In=	:=00001.1}');
Error('\P{Present_In=	:=00001.1}');
Expect(1, 65533, '\p{Present_In=+00001.1}', "");
Expect(0, 65533, '\p{^Present_In=+00001.1}', "");
Expect(0, 65533, '\P{Present_In=+00001.1}', "");
Expect(1, 65533, '\P{^Present_In=+00001.1}', "");
Expect(0, 65536, '\p{Present_In=+00001.1}', "");
Expect(1, 65536, '\p{^Present_In=+00001.1}', "");
Expect(1, 65536, '\P{Present_In=+00001.1}', "");
Expect(0, 65536, '\P{^Present_In=+00001.1}', "");
Error('\p{In= 1.1/a/}');
Error('\P{In= 1.1/a/}');
Expect(1, 65533, '\p{In=0000_0000_1.1}', "");
Expect(0, 65533, '\p{^In=0000_0000_1.1}', "");
Expect(0, 65533, '\P{In=0000_0000_1.1}', "");
Expect(1, 65533, '\P{^In=0000_0000_1.1}', "");
Expect(0, 65536, '\p{In=0000_0000_1.1}', "");
Expect(1, 65536, '\p{^In=0000_0000_1.1}', "");
Expect(1, 65536, '\P{In=0000_0000_1.1}', "");
Expect(0, 65536, '\P{^In=0000_0000_1.1}', "");
Error('\p{Is_Present_In=- +00_1.1/a/}');
Error('\P{Is_Present_In=- +00_1.1/a/}');
Expect(1, 65533, '\p{Is_Present_In=+000001.1}', "");
Expect(0, 65533, '\p{^Is_Present_In=+000001.1}', "");
Expect(0, 65533, '\P{Is_Present_In=+000001.1}', "");
Expect(1, 65533, '\P{^Is_Present_In=+000001.1}', "");
Expect(0, 65536, '\p{Is_Present_In=+000001.1}', "");
Expect(1, 65536, '\p{^Is_Present_In=+000001.1}', "");
Expect(1, 65536, '\P{Is_Present_In=+000001.1}', "");
Expect(0, 65536, '\P{^Is_Present_In=+000001.1}', "");
Error('\p{Is_In=-/a/+00000001.1}');
Error('\P{Is_In=-/a/+00000001.1}');
Expect(1, 65533, '\p{Is_In=0_1.1}', "");
Expect(0, 65533, '\p{^Is_In=0_1.1}', "");
Expect(0, 65533, '\P{Is_In=0_1.1}', "");
Expect(1, 65533, '\P{^Is_In=0_1.1}', "");
Expect(0, 65536, '\p{Is_In=0_1.1}', "");
Expect(1, 65536, '\p{^Is_In=0_1.1}', "");
Expect(1, 65536, '\P{Is_In=0_1.1}', "");
Expect(0, 65536, '\P{^Is_In=0_1.1}', "");
Error('\p{Present_In=/a/ -2.0}');
Error('\P{Present_In=/a/ -2.0}');
Expect(1, 983040, '\p{Present_In:+00000002.0}', "");
Expect(0, 983040, '\p{^Present_In:+00000002.0}', "");
Expect(0, 983040, '\P{Present_In:+00000002.0}', "");
Expect(1, 983040, '\P{^Present_In:+00000002.0}', "");
Expect(0, 983037, '\p{Present_In:+00000002.0}', "");
Expect(1, 983037, '\p{^Present_In:+00000002.0}', "");
Expect(1, 983037, '\P{Present_In:+00000002.0}', "");
Expect(0, 983037, '\P{^Present_In:+00000002.0}', "");
Error('\p{In: _ 0002.0:=}');
Error('\P{In: _ 0002.0:=}');
Expect(1, 983040, '\p{In=+0000002.0}', "");
Expect(0, 983040, '\p{^In=+0000002.0}', "");
Expect(0, 983040, '\P{In=+0000002.0}', "");
Expect(1, 983040, '\P{^In=+0000002.0}', "");
Expect(0, 983037, '\p{In=+0000002.0}', "");
Expect(1, 983037, '\p{^In=+0000002.0}', "");
Expect(1, 983037, '\P{In=+0000002.0}', "");
Expect(0, 983037, '\P{^In=+0000002.0}', "");
Error('\p{Is_Present_In= -0000000002.0/a/}');
Error('\P{Is_Present_In= -0000000002.0/a/}');
Expect(1, 983040, '\p{Is_Present_In=+000_000_2.0}', "");
Expect(0, 983040, '\p{^Is_Present_In=+000_000_2.0}', "");
Expect(0, 983040, '\P{Is_Present_In=+000_000_2.0}', "");
Expect(1, 983040, '\P{^Is_Present_In=+000_000_2.0}', "");
Expect(0, 983037, '\p{Is_Present_In=+000_000_2.0}', "");
Expect(1, 983037, '\p{^Is_Present_In=+000_000_2.0}', "");
Expect(1, 983037, '\P{Is_Present_In=+000_000_2.0}', "");
Expect(0, 983037, '\P{^Is_Present_In=+000_000_2.0}', "");
Error('\p{Is_In=:= _0_2.0}');
Error('\P{Is_In=:= _0_2.0}');
Expect(1, 983040, '\p{Is_In=000002.0}', "");
Expect(0, 983040, '\p{^Is_In=000002.0}', "");
Expect(0, 983040, '\P{Is_In=000002.0}', "");
Expect(1, 983040, '\P{^Is_In=000002.0}', "");
Expect(0, 983037, '\p{Is_In=000002.0}', "");
Expect(1, 983037, '\p{^Is_In=000002.0}', "");
Expect(1, 983037, '\P{Is_In=000002.0}', "");
Expect(0, 983037, '\P{^Is_In=000002.0}', "");
Error('\p{Present_In=- 000_000_000_2.1/a/}');
Error('\P{Present_In=- 000_000_000_2.1/a/}');
Expect(1, 983040, '\p{Present_In=00_00_2.1}', "");
Expect(0, 983040, '\p{^Present_In=00_00_2.1}', "");
Expect(0, 983040, '\P{Present_In=00_00_2.1}', "");
Expect(1, 983040, '\P{^Present_In=00_00_2.1}', "");
Expect(0, 983037, '\p{Present_In=00_00_2.1}', "");
Expect(1, 983037, '\p{^Present_In=00_00_2.1}', "");
Expect(1, 983037, '\P{Present_In=00_00_2.1}', "");
Expect(0, 983037, '\P{^Present_In=00_00_2.1}', "");
Error('\p{In=:=000002.1}');
Error('\P{In=:=000002.1}');
Expect(1, 983040, '\p{In=+0_0_0_0_0_0_0_0_02.1}', "");
Expect(0, 983040, '\p{^In=+0_0_0_0_0_0_0_0_02.1}', "");
Expect(0, 983040, '\P{In=+0_0_0_0_0_0_0_0_02.1}', "");
Expect(1, 983040, '\P{^In=+0_0_0_0_0_0_0_0_02.1}', "");
Expect(0, 983037, '\p{In=+0_0_0_0_0_0_0_0_02.1}', "");
Expect(1, 983037, '\p{^In=+0_0_0_0_0_0_0_0_02.1}', "");
Expect(1, 983037, '\P{In=+0_0_0_0_0_0_0_0_02.1}', "");
Expect(0, 983037, '\P{^In=+0_0_0_0_0_0_0_0_02.1}', "");
Error('\p{Is_Present_In=-:=0_0_0_0_002.1}');
Error('\P{Is_Present_In=-:=0_0_0_0_002.1}');
Expect(1, 983040, '\p{Is_Present_In=+0000002.1}', "");
Expect(0, 983040, '\p{^Is_Present_In=+0000002.1}', "");
Expect(0, 983040, '\P{Is_Present_In=+0000002.1}', "");
Expect(1, 983040, '\P{^Is_Present_In=+0000002.1}', "");
Expect(0, 983037, '\p{Is_Present_In=+0000002.1}', "");
Expect(1, 983037, '\p{^Is_Present_In=+0000002.1}', "");
Expect(1, 983037, '\P{Is_Present_In=+0000002.1}', "");
Expect(0, 983037, '\P{^Is_Present_In=+0000002.1}', "");
Error('\p{Is_In=_/a/+000_000_000_2.1}');
Error('\P{Is_In=_/a/+000_000_000_2.1}');
Expect(1, 983040, '\p{Is_In=0_0_0_0_0002.1}', "");
Expect(0, 983040, '\p{^Is_In=0_0_0_0_0002.1}', "");
Expect(0, 983040, '\P{Is_In=0_0_0_0_0002.1}', "");
Expect(1, 983040, '\P{^Is_In=0_0_0_0_0002.1}', "");
Expect(0, 983037, '\p{Is_In=0_0_0_0_0002.1}', "");
Expect(1, 983037, '\p{^Is_In=0_0_0_0_0002.1}', "");
Expect(1, 983037, '\P{Is_In=0_0_0_0_0002.1}', "");
Expect(0, 983037, '\P{^Is_In=0_0_0_0_0002.1}', "");
Error('\p{Present_In=	-+0003.0:=}');
Error('\P{Present_In=	-+0003.0:=}');
Expect(1, 983040, '\p{Present_In=000003.0}', "");
Expect(0, 983040, '\p{^Present_In=000003.0}', "");
Expect(0, 983040, '\P{Present_In=000003.0}', "");
Expect(1, 983040, '\P{^Present_In=000003.0}', "");
Expect(0, 983037, '\p{Present_In=000003.0}', "");
Expect(1, 983037, '\p{^Present_In=000003.0}', "");
Expect(1, 983037, '\P{Present_In=000003.0}', "");
Expect(0, 983037, '\P{^Present_In=000003.0}', "");
Error('\p{In=/a/+0_0_0_0_0003.0}');
Error('\P{In=/a/+0_0_0_0_0003.0}');
Expect(1, 983040, '\p{In=000_3.0}', "");
Expect(0, 983040, '\p{^In=000_3.0}', "");
Expect(0, 983040, '\P{In=000_3.0}', "");
Expect(1, 983040, '\P{^In=000_3.0}', "");
Expect(0, 983037, '\p{In=000_3.0}', "");
Expect(1, 983037, '\p{^In=000_3.0}', "");
Expect(1, 983037, '\P{In=000_3.0}', "");
Expect(0, 983037, '\P{^In=000_3.0}', "");
Error('\p{Is_Present_In=:= +0_3.0}');
Error('\P{Is_Present_In=:= +0_3.0}');
Expect(1, 983040, '\p{Is_Present_In:   3.0}', "");
Expect(0, 983040, '\p{^Is_Present_In:   3.0}', "");
Expect(0, 983040, '\P{Is_Present_In:   3.0}', "");
Expect(1, 983040, '\P{^Is_Present_In:   3.0}', "");
Expect(0, 983037, '\p{Is_Present_In:   3.0}', "");
Expect(1, 983037, '\p{^Is_Present_In:   3.0}', "");
Expect(1, 983037, '\P{Is_Present_In:   3.0}', "");
Expect(0, 983037, '\P{^Is_Present_In:   3.0}', "");
Error('\p{Is_In=	:=0000_0000_3.0}');
Error('\P{Is_In=	:=0000_0000_3.0}');
Expect(1, 983040, '\p{Is_In=+03.0}', "");
Expect(0, 983040, '\p{^Is_In=+03.0}', "");
Expect(0, 983040, '\P{Is_In=+03.0}', "");
Expect(1, 983040, '\P{^Is_In=+03.0}', "");
Expect(0, 983037, '\p{Is_In=+03.0}', "");
Expect(1, 983037, '\p{^Is_In=+03.0}', "");
Expect(1, 983037, '\P{Is_In=+03.0}', "");
Expect(0, 983037, '\P{^Is_In=+03.0}', "");
Error('\p{Present_In=/a/	_+0000000003.1}');
Error('\P{Present_In=/a/	_+0000000003.1}');
Expect(1, 983040, '\p{Present_In=003.1}', "");
Expect(0, 983040, '\p{^Present_In=003.1}', "");
Expect(0, 983040, '\P{Present_In=003.1}', "");
Expect(1, 983040, '\P{^Present_In=003.1}', "");
Expect(0, 983037, '\p{Present_In=003.1}', "");
Expect(1, 983037, '\p{^Present_In=003.1}', "");
Expect(1, 983037, '\P{Present_In=003.1}', "");
Expect(0, 983037, '\P{^Present_In=003.1}', "");
Error('\p{In=_ +00_00_3.1/a/}');
Error('\P{In=_ +00_00_3.1/a/}');
Expect(1, 983040, '\p{In=+0000000003.1}', "");
Expect(0, 983040, '\p{^In=+0000000003.1}', "");
Expect(0, 983040, '\P{In=+0000000003.1}', "");
Expect(1, 983040, '\P{^In=+0000000003.1}', "");
Expect(0, 983037, '\p{In=+0000000003.1}', "");
Expect(1, 983037, '\p{^In=+0000000003.1}', "");
Expect(1, 983037, '\P{In=+0000000003.1}', "");
Expect(0, 983037, '\P{^In=+0000000003.1}', "");
Error('\p{Is_Present_In=	_0000000003.1:=}');
Error('\P{Is_Present_In=	_0000000003.1:=}');
Expect(1, 983040, '\p{Is_Present_In=3.1}', "");
Expect(0, 983040, '\p{^Is_Present_In=3.1}', "");
Expect(0, 983040, '\P{Is_Present_In=3.1}', "");
Expect(1, 983040, '\P{^Is_Present_In=3.1}', "");
Expect(0, 983037, '\p{Is_Present_In=3.1}', "");
Expect(1, 983037, '\p{^Is_Present_In=3.1}', "");
Expect(1, 983037, '\P{Is_Present_In=3.1}', "");
Expect(0, 983037, '\P{^Is_Present_In=3.1}', "");
Error('\p{Is_In=:=_+000_000_03.1}');
Error('\P{Is_In=:=_+000_000_03.1}');
Expect(1, 983040, '\p{Is_In:0000003.1}', "");
Expect(0, 983040, '\p{^Is_In:0000003.1}', "");
Expect(0, 983040, '\P{Is_In:0000003.1}', "");
Expect(1, 983040, '\P{^Is_In:0000003.1}', "");
Expect(0, 983037, '\p{Is_In:0000003.1}', "");
Expect(1, 983037, '\p{^Is_In:0000003.1}', "");
Expect(1, 983037, '\P{Is_In:0000003.1}', "");
Expect(0, 983037, '\P{^Is_In:0000003.1}', "");
Error('\p{Present_In=:= 	+03.2}');
Error('\P{Present_In=:= 	+03.2}');
Expect(1, 983040, '\p{Present_In=+0000000_3.2}', "");
Expect(0, 983040, '\p{^Present_In=+0000000_3.2}', "");
Expect(0, 983040, '\P{Present_In=+0000000_3.2}', "");
Expect(1, 983040, '\P{^Present_In=+0000000_3.2}', "");
Expect(0, 983037, '\p{Present_In=+0000000_3.2}', "");
Expect(1, 983037, '\p{^Present_In=+0000000_3.2}', "");
Expect(1, 983037, '\P{Present_In=+0000000_3.2}', "");
Expect(0, 983037, '\P{^Present_In=+0000000_3.2}', "");
Error('\p{In=_/a/00000_3.2}');
Error('\P{In=_/a/00000_3.2}');
Expect(1, 983040, '\p{In=00000000_3.2}', "");
Expect(0, 983040, '\p{^In=00000000_3.2}', "");
Expect(0, 983040, '\P{In=00000000_3.2}', "");
Expect(1, 983040, '\P{^In=00000000_3.2}', "");
Expect(0, 983037, '\p{In=00000000_3.2}', "");
Expect(1, 983037, '\p{^In=00000000_3.2}', "");
Expect(1, 983037, '\P{In=00000000_3.2}', "");
Expect(0, 983037, '\P{^In=00000000_3.2}', "");
Error('\p{Is_Present_In:	:=--000000000_3.2}');
Error('\P{Is_Present_In:	:=--000000000_3.2}');
Expect(1, 983040, '\p{Is_Present_In=0003.2}', "");
Expect(0, 983040, '\p{^Is_Present_In=0003.2}', "");
Expect(0, 983040, '\P{Is_Present_In=0003.2}', "");
Expect(1, 983040, '\P{^Is_Present_In=0003.2}', "");
Expect(0, 983037, '\p{Is_Present_In=0003.2}', "");
Expect(1, 983037, '\p{^Is_Present_In=0003.2}', "");
Expect(1, 983037, '\P{Is_Present_In=0003.2}', "");
Expect(0, 983037, '\P{^Is_Present_In=0003.2}', "");
Error('\p{Is_In=	/a/+3.2}');
Error('\P{Is_In=	/a/+3.2}');
Expect(1, 983040, '\p{Is_In:	+000_000_03.2}', "");
Expect(0, 983040, '\p{^Is_In:	+000_000_03.2}', "");
Expect(0, 983040, '\P{Is_In:	+000_000_03.2}', "");
Expect(1, 983040, '\P{^Is_In:	+000_000_03.2}', "");
Expect(0, 983037, '\p{Is_In:	+000_000_03.2}', "");
Expect(1, 983037, '\p{^Is_In:	+000_000_03.2}', "");
Expect(1, 983037, '\P{Is_In:	+000_000_03.2}', "");
Expect(0, 983037, '\P{^Is_In:	+000_000_03.2}', "");
Error('\p{Present_In=-+0_0_0_004.0:=}');
Error('\P{Present_In=-+0_0_0_004.0:=}');
Expect(1, 983040, '\p{Present_In=0004.0}', "");
Expect(0, 983040, '\p{^Present_In=0004.0}', "");
Expect(0, 983040, '\P{Present_In=0004.0}', "");
Expect(1, 983040, '\P{^Present_In=0004.0}', "");
Expect(0, 983037, '\p{Present_In=0004.0}', "");
Expect(1, 983037, '\p{^Present_In=0004.0}', "");
Expect(1, 983037, '\P{Present_In=0004.0}', "");
Expect(0, 983037, '\P{^Present_In=0004.0}', "");
Error('\p{In=- +0000000004.0:=}');
Error('\P{In=- +0000000004.0:=}');
Expect(1, 983040, '\p{In=+4.0}', "");
Expect(0, 983040, '\p{^In=+4.0}', "");
Expect(0, 983040, '\P{In=+4.0}', "");
Expect(1, 983040, '\P{^In=+4.0}', "");
Expect(0, 983037, '\p{In=+4.0}', "");
Expect(1, 983037, '\p{^In=+4.0}', "");
Expect(1, 983037, '\P{In=+4.0}', "");
Expect(0, 983037, '\P{^In=+4.0}', "");
Error('\p{Is_Present_In=:=000_000_4.0}');
Error('\P{Is_Present_In=:=000_000_4.0}');
Expect(1, 983040, '\p{Is_Present_In=+0004.0}', "");
Expect(0, 983040, '\p{^Is_Present_In=+0004.0}', "");
Expect(0, 983040, '\P{Is_Present_In=+0004.0}', "");
Expect(1, 983040, '\P{^Is_Present_In=+0004.0}', "");
Expect(0, 983037, '\p{Is_Present_In=+0004.0}', "");
Expect(1, 983037, '\p{^Is_Present_In=+0004.0}', "");
Expect(1, 983037, '\P{Is_Present_In=+0004.0}', "");
Expect(0, 983037, '\P{^Is_Present_In=+0004.0}', "");
Error('\p{Is_In=/a/	-004.0}');
Error('\P{Is_In=/a/	-004.0}');
Expect(1, 983040, '\p{Is_In=0004.0}', "");
Expect(0, 983040, '\p{^Is_In=0004.0}', "");
Expect(0, 983040, '\P{Is_In=0004.0}', "");
Expect(1, 983040, '\P{^Is_In=0004.0}', "");
Expect(0, 983037, '\p{Is_In=0004.0}', "");
Expect(1, 983037, '\p{^Is_In=0004.0}', "");
Expect(1, 983037, '\P{Is_In=0004.0}', "");
Expect(0, 983037, '\P{^Is_In=0004.0}', "");
Error('\p{Present_In:	 /a/4.1}');
Error('\P{Present_In:	 /a/4.1}');
Expect(1, 983040, '\p{Present_In=0000004.1}', "");
Expect(0, 983040, '\p{^Present_In=0000004.1}', "");
Expect(0, 983040, '\P{Present_In=0000004.1}', "");
Expect(1, 983040, '\P{^Present_In=0000004.1}', "");
Expect(0, 983037, '\p{Present_In=0000004.1}', "");
Expect(1, 983037, '\p{^Present_In=0000004.1}', "");
Expect(1, 983037, '\P{Present_In=0000004.1}', "");
Expect(0, 983037, '\P{^Present_In=0000004.1}', "");
Error('\p{In=:=4.1}');
Error('\P{In=:=4.1}');
Expect(1, 983040, '\p{In:   +004.1}', "");
Expect(0, 983040, '\p{^In:   +004.1}', "");
Expect(0, 983040, '\P{In:   +004.1}', "");
Expect(1, 983040, '\P{^In:   +004.1}', "");
Expect(0, 983037, '\p{In:   +004.1}', "");
Expect(1, 983037, '\p{^In:   +004.1}', "");
Expect(1, 983037, '\P{In:   +004.1}', "");
Expect(0, 983037, '\P{^In:   +004.1}', "");
Error('\p{Is_Present_In=/a/+00000004.1}');
Error('\P{Is_Present_In=/a/+00000004.1}');
Expect(1, 983040, '\p{Is_Present_In=00000004.1}', "");
Expect(0, 983040, '\p{^Is_Present_In=00000004.1}', "");
Expect(0, 983040, '\P{Is_Present_In=00000004.1}', "");
Expect(1, 983040, '\P{^Is_Present_In=00000004.1}', "");
Expect(0, 983037, '\p{Is_Present_In=00000004.1}', "");
Expect(1, 983037, '\p{^Is_Present_In=00000004.1}', "");
Expect(1, 983037, '\P{Is_Present_In=00000004.1}', "");
Expect(0, 983037, '\P{^Is_Present_In=00000004.1}', "");
Error('\p{Is_In=/a/  +0004.1}');
Error('\P{Is_In=/a/  +0004.1}');
Expect(1, 983040, '\p{Is_In=0004.1}', "");
Expect(0, 983040, '\p{^Is_In=0004.1}', "");
Expect(0, 983040, '\P{Is_In=0004.1}', "");
Expect(1, 983040, '\P{^Is_In=0004.1}', "");
Expect(0, 983037, '\p{Is_In=0004.1}', "");
Expect(1, 983037, '\p{^Is_In=0004.1}', "");
Expect(1, 983037, '\P{Is_In=0004.1}', "");
Expect(0, 983037, '\P{^Is_In=0004.1}', "");
Error('\p{Present_In=:=_0000005.0}');
Error('\P{Present_In=:=_0000005.0}');
Expect(1, 983040, '\p{Present_In=005.0}', "");
Expect(0, 983040, '\p{^Present_In=005.0}', "");
Expect(0, 983040, '\P{Present_In=005.0}', "");
Expect(1, 983040, '\P{^Present_In=005.0}', "");
Expect(0, 983037, '\p{Present_In=005.0}', "");
Expect(1, 983037, '\p{^Present_In=005.0}', "");
Expect(1, 983037, '\P{Present_In=005.0}', "");
Expect(0, 983037, '\P{^Present_In=005.0}', "");
Error('\p{In:	/a/00000000_5.0}');
Error('\P{In:	/a/00000000_5.0}');
Expect(1, 983040, '\p{In=+00_00_5.0}', "");
Expect(0, 983040, '\p{^In=+00_00_5.0}', "");
Expect(0, 983040, '\P{In=+00_00_5.0}', "");
Expect(1, 983040, '\P{^In=+00_00_5.0}', "");
Expect(0, 983037, '\p{In=+00_00_5.0}', "");
Expect(1, 983037, '\p{^In=+00_00_5.0}', "");
Expect(1, 983037, '\P{In=+00_00_5.0}', "");
Expect(0, 983037, '\P{^In=+00_00_5.0}', "");
Error('\p{Is_Present_In=:=	-00000005.0}');
Error('\P{Is_Present_In=:=	-00000005.0}');
Expect(1, 983040, '\p{Is_Present_In=0_0_0_05.0}', "");
Expect(0, 983040, '\p{^Is_Present_In=0_0_0_05.0}', "");
Expect(0, 983040, '\P{Is_Present_In=0_0_0_05.0}', "");
Expect(1, 983040, '\P{^Is_Present_In=0_0_0_05.0}', "");
Expect(0, 983037, '\p{Is_Present_In=0_0_0_05.0}', "");
Expect(1, 983037, '\p{^Is_Present_In=0_0_0_05.0}', "");
Expect(1, 983037, '\P{Is_Present_In=0_0_0_05.0}', "");
Expect(0, 983037, '\P{^Is_Present_In=0_0_0_05.0}', "");
Error('\p{Is_In=/a/	-5.0}');
Error('\P{Is_In=/a/	-5.0}');
Expect(1, 983040, '\p{Is_In=000000005.0}', "");
Expect(0, 983040, '\p{^Is_In=000000005.0}', "");
Expect(0, 983040, '\P{Is_In=000000005.0}', "");
Expect(1, 983040, '\P{^Is_In=000000005.0}', "");
Expect(0, 983037, '\p{Is_In=000000005.0}', "");
Expect(1, 983037, '\p{^Is_In=000000005.0}', "");
Expect(1, 983037, '\P{Is_In=000000005.0}', "");
Expect(0, 983037, '\P{^Is_In=000000005.0}', "");
Error('\p{Present_In=__00000_5.1:=}');
Error('\P{Present_In=__00000_5.1:=}');
Expect(1, 983040, '\p{Present_In=0_0_0_05.1}', "");
Expect(0, 983040, '\p{^Present_In=0_0_0_05.1}', "");
Expect(0, 983040, '\P{Present_In=0_0_0_05.1}', "");
Expect(1, 983040, '\P{^Present_In=0_0_0_05.1}', "");
Expect(0, 983037, '\p{Present_In=0_0_0_05.1}', "");
Expect(1, 983037, '\p{^Present_In=0_0_0_05.1}', "");
Expect(1, 983037, '\P{Present_In=0_0_0_05.1}', "");
Expect(0, 983037, '\P{^Present_In=0_0_0_05.1}', "");
Error('\p{In::=-+0_0_0_0_0_05.1}');
Error('\P{In::=-+0_0_0_0_0_05.1}');
Expect(1, 983040, '\p{In=0000000005.1}', "");
Expect(0, 983040, '\p{^In=0000000005.1}', "");
Expect(0, 983040, '\P{In=0000000005.1}', "");
Expect(1, 983040, '\P{^In=0000000005.1}', "");
Expect(0, 983037, '\p{In=0000000005.1}', "");
Expect(1, 983037, '\p{^In=0000000005.1}', "");
Expect(1, 983037, '\P{In=0000000005.1}', "");
Expect(0, 983037, '\P{^In=0000000005.1}', "");
Error('\p{Is_Present_In=	:=00000_5.1}');
Error('\P{Is_Present_In=	:=00000_5.1}');
Expect(1, 983040, '\p{Is_Present_In=0_0_0_0_05.1}', "");
Expect(0, 983040, '\p{^Is_Present_In=0_0_0_0_05.1}', "");
Expect(0, 983040, '\P{Is_Present_In=0_0_0_0_05.1}', "");
Expect(1, 983040, '\P{^Is_Present_In=0_0_0_0_05.1}', "");
Expect(0, 983037, '\p{Is_Present_In=0_0_0_0_05.1}', "");
Expect(1, 983037, '\p{^Is_Present_In=0_0_0_0_05.1}', "");
Expect(1, 983037, '\P{Is_Present_In=0_0_0_0_05.1}', "");
Expect(0, 983037, '\P{^Is_Present_In=0_0_0_0_05.1}', "");
Error('\p{Is_In: 	-0_5.1:=}');
Error('\P{Is_In: 	-0_5.1:=}');
Expect(1, 983040, '\p{Is_In=0_0_0_0_005.1}', "");
Expect(0, 983040, '\p{^Is_In=0_0_0_0_005.1}', "");
Expect(0, 983040, '\P{Is_In=0_0_0_0_005.1}', "");
Expect(1, 983040, '\P{^Is_In=0_0_0_0_005.1}', "");
Expect(0, 983037, '\p{Is_In=0_0_0_0_005.1}', "");
Expect(1, 983037, '\p{^Is_In=0_0_0_0_005.1}', "");
Expect(1, 983037, '\P{Is_In=0_0_0_0_005.1}', "");
Expect(0, 983037, '\P{^Is_In=0_0_0_0_005.1}', "");
Error('\p{Present_In:		/a/0_0_05.2}');
Error('\P{Present_In:		/a/0_0_05.2}');
Expect(1, 983040, '\p{Present_In=0_0_0_0_0_00005.2}', "");
Expect(0, 983040, '\p{^Present_In=0_0_0_0_0_00005.2}', "");
Expect(0, 983040, '\P{Present_In=0_0_0_0_0_00005.2}', "");
Expect(1, 983040, '\P{^Present_In=0_0_0_0_0_00005.2}', "");
Expect(0, 983037, '\p{Present_In=0_0_0_0_0_00005.2}', "");
Expect(1, 983037, '\p{^Present_In=0_0_0_0_0_00005.2}', "");
Expect(1, 983037, '\P{Present_In=0_0_0_0_0_00005.2}', "");
Expect(0, 983037, '\P{^Present_In=0_0_0_0_0_00005.2}', "");
Error('\p{In=-:=+005.2}');
Error('\P{In=-:=+005.2}');
Expect(1, 983040, '\p{In:	00000005.2}', "");
Expect(0, 983040, '\p{^In:	00000005.2}', "");
Expect(0, 983040, '\P{In:	00000005.2}', "");
Expect(1, 983040, '\P{^In:	00000005.2}', "");
Expect(0, 983037, '\p{In:	00000005.2}', "");
Expect(1, 983037, '\p{^In:	00000005.2}', "");
Expect(1, 983037, '\P{In:	00000005.2}', "");
Expect(0, 983037, '\P{^In:	00000005.2}', "");
Error('\p{Is_Present_In=	:=+0_0_0_0_0_0_0_05.2}');
Error('\P{Is_Present_In=	:=+0_0_0_0_0_0_0_05.2}');
Expect(1, 983040, '\p{Is_Present_In=+00005.2}', "");
Expect(0, 983040, '\p{^Is_Present_In=+00005.2}', "");
Expect(0, 983040, '\P{Is_Present_In=+00005.2}', "");
Expect(1, 983040, '\P{^Is_Present_In=+00005.2}', "");
Expect(0, 983037, '\p{Is_Present_In=+00005.2}', "");
Expect(1, 983037, '\p{^Is_Present_In=+00005.2}', "");
Expect(1, 983037, '\P{Is_Present_In=+00005.2}', "");
Expect(0, 983037, '\P{^Is_Present_In=+00005.2}', "");
Error('\p{Is_In: := 	+00000005.2}');
Error('\P{Is_In: := 	+00000005.2}');
Expect(1, 983040, '\p{Is_In=0_5.2}', "");
Expect(0, 983040, '\p{^Is_In=0_5.2}', "");
Expect(0, 983040, '\P{Is_In=0_5.2}', "");
Expect(1, 983040, '\P{^Is_In=0_5.2}', "");
Expect(0, 983037, '\p{Is_In=0_5.2}', "");
Expect(1, 983037, '\p{^Is_In=0_5.2}', "");
Expect(1, 983037, '\P{Is_In=0_5.2}', "");
Expect(0, 983037, '\P{^Is_In=0_5.2}', "");
Error('\p{Present_In::=_-+00_00_06.0}');
Error('\P{Present_In::=_-+00_00_06.0}');
Expect(1, 983040, '\p{Present_In=06.0}', "");
Expect(0, 983040, '\p{^Present_In=06.0}', "");
Expect(0, 983040, '\P{Present_In=06.0}', "");
Expect(1, 983040, '\P{^Present_In=06.0}', "");
Expect(0, 983037, '\p{Present_In=06.0}', "");
Expect(1, 983037, '\p{^Present_In=06.0}', "");
Expect(1, 983037, '\P{Present_In=06.0}', "");
Expect(0, 983037, '\P{^Present_In=06.0}', "");
Error('\p{In=:=	 006.0}');
Error('\P{In=:=	 006.0}');
Expect(1, 983040, '\p{In=+0006.0}', "");
Expect(0, 983040, '\p{^In=+0006.0}', "");
Expect(0, 983040, '\P{In=+0006.0}', "");
Expect(1, 983040, '\P{^In=+0006.0}', "");
Expect(0, 983037, '\p{In=+0006.0}', "");
Expect(1, 983037, '\p{^In=+0006.0}', "");
Expect(1, 983037, '\P{In=+0006.0}', "");
Expect(0, 983037, '\P{^In=+0006.0}', "");
Error('\p{Is_Present_In=/a/ 0_0_06.0}');
Error('\P{Is_Present_In=/a/ 0_0_06.0}');
Expect(1, 983040, '\p{Is_Present_In=000000_6.0}', "");
Expect(0, 983040, '\p{^Is_Present_In=000000_6.0}', "");
Expect(0, 983040, '\P{Is_Present_In=000000_6.0}', "");
Expect(1, 983040, '\P{^Is_Present_In=000000_6.0}', "");
Expect(0, 983037, '\p{Is_Present_In=000000_6.0}', "");
Expect(1, 983037, '\p{^Is_Present_In=000000_6.0}', "");
Expect(1, 983037, '\P{Is_Present_In=000000_6.0}', "");
Expect(0, 983037, '\P{^Is_Present_In=000000_6.0}', "");
Error('\p{Is_In=__0006.0:=}');
Error('\P{Is_In=__0006.0:=}');
Expect(1, 983040, '\p{Is_In=6.0}', "");
Expect(0, 983040, '\p{^Is_In=6.0}', "");
Expect(0, 983040, '\P{Is_In=6.0}', "");
Expect(1, 983040, '\P{^Is_In=6.0}', "");
Expect(0, 983037, '\p{Is_In=6.0}', "");
Expect(1, 983037, '\p{^Is_In=6.0}', "");
Expect(1, 983037, '\P{Is_In=6.0}', "");
Expect(0, 983037, '\P{^Is_In=6.0}', "");
Error('\p{Present_In=:=00000006.1}');
Error('\P{Present_In=:=00000006.1}');
Expect(1, 983040, '\p{Present_In=+000_000_06.1}', "");
Expect(0, 983040, '\p{^Present_In=+000_000_06.1}', "");
Expect(0, 983040, '\P{Present_In=+000_000_06.1}', "");
Expect(1, 983040, '\P{^Present_In=+000_000_06.1}', "");
Expect(0, 983037, '\p{Present_In=+000_000_06.1}', "");
Expect(1, 983037, '\p{^Present_In=+000_000_06.1}', "");
Expect(1, 983037, '\P{Present_In=+000_000_06.1}', "");
Expect(0, 983037, '\P{^Present_In=+000_000_06.1}', "");
Error('\p{In=	/a/+6.1}');
Error('\P{In=	/a/+6.1}');
Expect(1, 983040, '\p{In=+00_6.1}', "");
Expect(0, 983040, '\p{^In=+00_6.1}', "");
Expect(0, 983040, '\P{In=+00_6.1}', "");
Expect(1, 983040, '\P{^In=+00_6.1}', "");
Expect(0, 983037, '\p{In=+00_6.1}', "");
Expect(1, 983037, '\p{^In=+00_6.1}', "");
Expect(1, 983037, '\P{In=+00_6.1}', "");
Expect(0, 983037, '\P{^In=+00_6.1}', "");
Error('\p{Is_Present_In=/a/	6.1}');
Error('\P{Is_Present_In=/a/	6.1}');
Expect(1, 983040, '\p{Is_Present_In:	+0_0_0_0_0_0006.1}', "");
Expect(0, 983040, '\p{^Is_Present_In:	+0_0_0_0_0_0006.1}', "");
Expect(0, 983040, '\P{Is_Present_In:	+0_0_0_0_0_0006.1}', "");
Expect(1, 983040, '\P{^Is_Present_In:	+0_0_0_0_0_0006.1}', "");
Expect(0, 983037, '\p{Is_Present_In:	+0_0_0_0_0_0006.1}', "");
Expect(1, 983037, '\p{^Is_Present_In:	+0_0_0_0_0_0006.1}', "");
Expect(1, 983037, '\P{Is_Present_In:	+0_0_0_0_0_0006.1}', "");
Expect(0, 983037, '\P{^Is_Present_In:	+0_0_0_0_0_0006.1}', "");
Error('\p{Is_In:	:=-	+0_0_0_0_0_006.1}');
Error('\P{Is_In:	:=-	+0_0_0_0_0_006.1}');
Expect(1, 983040, '\p{Is_In=0000000006.1}', "");
Expect(0, 983040, '\p{^Is_In=0000000006.1}', "");
Expect(0, 983040, '\P{Is_In=0000000006.1}', "");
Expect(1, 983040, '\P{^Is_In=0000000006.1}', "");
Expect(0, 983037, '\p{Is_In=0000000006.1}', "");
Expect(1, 983037, '\p{^Is_In=0000000006.1}', "");
Expect(1, 983037, '\P{Is_In=0000000006.1}', "");
Expect(0, 983037, '\P{^Is_In=0000000006.1}', "");
Error('\p{Present_In=:=		000006.2}');
Error('\P{Present_In=:=		000006.2}');
Expect(1, 983040, '\p{Present_In=+000006.2}', "");
Expect(0, 983040, '\p{^Present_In=+000006.2}', "");
Expect(0, 983040, '\P{Present_In=+000006.2}', "");
Expect(1, 983040, '\P{^Present_In=+000006.2}', "");
Expect(0, 983037, '\p{Present_In=+000006.2}', "");
Expect(1, 983037, '\p{^Present_In=+000006.2}', "");
Expect(1, 983037, '\P{Present_In=+000006.2}', "");
Expect(0, 983037, '\P{^Present_In=+000006.2}', "");
Error('\p{In=_/a/0000_6.2}');
Error('\P{In=_/a/0000_6.2}');
Expect(1, 983040, '\p{In=000000_6.2}', "");
Expect(0, 983040, '\p{^In=000000_6.2}', "");
Expect(0, 983040, '\P{In=000000_6.2}', "");
Expect(1, 983040, '\P{^In=000000_6.2}', "");
Expect(0, 983037, '\p{In=000000_6.2}', "");
Expect(1, 983037, '\p{^In=000000_6.2}', "");
Expect(1, 983037, '\P{In=000000_6.2}', "");
Expect(0, 983037, '\P{^In=000000_6.2}', "");
Error('\p{Is_Present_In=:=	 +00_00_6.2}');
Error('\P{Is_Present_In=:=	 +00_00_6.2}');
Expect(1, 983040, '\p{Is_Present_In=0000006.2}', "");
Expect(0, 983040, '\p{^Is_Present_In=0000006.2}', "");
Expect(0, 983040, '\P{Is_Present_In=0000006.2}', "");
Expect(1, 983040, '\P{^Is_Present_In=0000006.2}', "");
Expect(0, 983037, '\p{Is_Present_In=0000006.2}', "");
Expect(1, 983037, '\p{^Is_Present_In=0000006.2}', "");
Expect(1, 983037, '\P{Is_Present_In=0000006.2}', "");
Expect(0, 983037, '\P{^Is_Present_In=0000006.2}', "");
Error('\p{Is_In=/a/_ 000000006.2}');
Error('\P{Is_In=/a/_ 000000006.2}');
Expect(1, 983040, '\p{Is_In=6.2}', "");
Expect(0, 983040, '\p{^Is_In=6.2}', "");
Expect(0, 983040, '\P{Is_In=6.2}', "");
Expect(1, 983040, '\P{^Is_In=6.2}', "");
Expect(0, 983037, '\p{Is_In=6.2}', "");
Expect(1, 983037, '\p{^Is_In=6.2}', "");
Expect(1, 983037, '\P{Is_In=6.2}', "");
Expect(0, 983037, '\P{^Is_In=6.2}', "");
Error('\p{Present_In= +006.3/a/}');
Error('\P{Present_In= +006.3/a/}');
Expect(1, 983040, '\p{Present_In=000_000_06.3}', "");
Expect(0, 983040, '\p{^Present_In=000_000_06.3}', "");
Expect(0, 983040, '\P{Present_In=000_000_06.3}', "");
Expect(1, 983040, '\P{^Present_In=000_000_06.3}', "");
Expect(0, 983037, '\p{Present_In=000_000_06.3}', "");
Expect(1, 983037, '\p{^Present_In=000_000_06.3}', "");
Expect(1, 983037, '\P{Present_In=000_000_06.3}', "");
Expect(0, 983037, '\P{^Present_In=000_000_06.3}', "");
Error('\p{In=--+00_00_00_006.3/a/}');
Error('\P{In=--+00_00_00_006.3/a/}');
Expect(1, 983040, '\p{In=000006.3}', "");
Expect(0, 983040, '\p{^In=000006.3}', "");
Expect(0, 983040, '\P{In=000006.3}', "");
Expect(1, 983040, '\P{^In=000006.3}', "");
Expect(0, 983037, '\p{In=000006.3}', "");
Expect(1, 983037, '\p{^In=000006.3}', "");
Expect(1, 983037, '\P{In=000006.3}', "");
Expect(0, 983037, '\P{^In=000006.3}', "");
Error('\p{Is_Present_In=-000000006.3/a/}');
Error('\P{Is_Present_In=-000000006.3/a/}');
Expect(1, 983040, '\p{Is_Present_In=000006.3}', "");
Expect(0, 983040, '\p{^Is_Present_In=000006.3}', "");
Expect(0, 983040, '\P{Is_Present_In=000006.3}', "");
Expect(1, 983040, '\P{^Is_Present_In=000006.3}', "");
Expect(0, 983037, '\p{Is_Present_In=000006.3}', "");
Expect(1, 983037, '\p{^Is_Present_In=000006.3}', "");
Expect(1, 983037, '\P{Is_Present_In=000006.3}', "");
Expect(0, 983037, '\P{^Is_Present_In=000006.3}', "");
Error('\p{Is_In=_/a/06.3}');
Error('\P{Is_In=_/a/06.3}');
Expect(1, 983040, '\p{Is_In=+000000006.3}', "");
Expect(0, 983040, '\p{^Is_In=+000000006.3}', "");
Expect(0, 983040, '\P{Is_In=+000000006.3}', "");
Expect(1, 983040, '\P{^Is_In=+000000006.3}', "");
Expect(0, 983037, '\p{Is_In=+000000006.3}', "");
Expect(1, 983037, '\p{^Is_In=+000000006.3}', "");
Expect(1, 983037, '\P{Is_In=+000000006.3}', "");
Expect(0, 983037, '\P{^Is_In=+000000006.3}', "");
Error('\p{Present_In=:=_ unassigned}');
Error('\P{Present_In=:=_ unassigned}');
Expect(1, 983037, '\p{Present_In=unassigned}', "");
Expect(0, 983037, '\p{^Present_In=unassigned}', "");
Expect(0, 983037, '\P{Present_In=unassigned}', "");
Expect(1, 983037, '\P{^Present_In=unassigned}', "");
Expect(0, 983040, '\p{Present_In=unassigned}', "");
Expect(1, 983040, '\p{^Present_In=unassigned}', "");
Expect(1, 983040, '\P{Present_In=unassigned}', "");
Expect(0, 983040, '\P{^Present_In=unassigned}', "");
Expect(1, 983037, '\p{Present_In=-_Unassigned}', "");
Expect(0, 983037, '\p{^Present_In=-_Unassigned}', "");
Expect(0, 983037, '\P{Present_In=-_Unassigned}', "");
Expect(1, 983037, '\P{^Present_In=-_Unassigned}', "");
Expect(0, 983040, '\p{Present_In=-_Unassigned}', "");
Expect(1, 983040, '\p{^Present_In=-_Unassigned}', "");
Expect(1, 983040, '\P{Present_In=-_Unassigned}', "");
Expect(0, 983040, '\P{^Present_In=-_Unassigned}', "");
Error('\p{In=:=Unassigned}');
Error('\P{In=:=Unassigned}');
Expect(1, 983037, '\p{In=unassigned}', "");
Expect(0, 983037, '\p{^In=unassigned}', "");
Expect(0, 983037, '\P{In=unassigned}', "");
Expect(1, 983037, '\P{^In=unassigned}', "");
Expect(0, 983040, '\p{In=unassigned}', "");
Expect(1, 983040, '\p{^In=unassigned}', "");
Expect(1, 983040, '\P{In=unassigned}', "");
Expect(0, 983040, '\P{^In=unassigned}', "");
Expect(1, 983037, '\p{In: unassigned}', "");
Expect(0, 983037, '\p{^In: unassigned}', "");
Expect(0, 983037, '\P{In: unassigned}', "");
Expect(1, 983037, '\P{^In: unassigned}', "");
Expect(0, 983040, '\p{In: unassigned}', "");
Expect(1, 983040, '\p{^In: unassigned}', "");
Expect(1, 983040, '\P{In: unassigned}', "");
Expect(0, 983040, '\P{^In: unassigned}', "");
Error('\p{Is_Present_In=/a/	Unassigned}');
Error('\P{Is_Present_In=/a/	Unassigned}');
Expect(1, 983037, '\p{Is_Present_In=unassigned}', "");
Expect(0, 983037, '\p{^Is_Present_In=unassigned}', "");
Expect(0, 983037, '\P{Is_Present_In=unassigned}', "");
Expect(1, 983037, '\P{^Is_Present_In=unassigned}', "");
Expect(0, 983040, '\p{Is_Present_In=unassigned}', "");
Expect(1, 983040, '\p{^Is_Present_In=unassigned}', "");
Expect(1, 983040, '\P{Is_Present_In=unassigned}', "");
Expect(0, 983040, '\P{^Is_Present_In=unassigned}', "");
Expect(1, 983037, '\p{Is_Present_In:   	 Unassigned}', "");
Expect(0, 983037, '\p{^Is_Present_In:   	 Unassigned}', "");
Expect(0, 983037, '\P{Is_Present_In:   	 Unassigned}', "");
Expect(1, 983037, '\P{^Is_Present_In:   	 Unassigned}', "");
Expect(0, 983040, '\p{Is_Present_In:   	 Unassigned}', "");
Expect(1, 983040, '\p{^Is_Present_In:   	 Unassigned}', "");
Expect(1, 983040, '\P{Is_Present_In:   	 Unassigned}', "");
Expect(0, 983040, '\P{^Is_Present_In:   	 Unassigned}', "");
Error('\p{Is_In= Unassigned:=}');
Error('\P{Is_In= Unassigned:=}');
Expect(1, 983037, '\p{Is_In=unassigned}', "");
Expect(0, 983037, '\p{^Is_In=unassigned}', "");
Expect(0, 983037, '\P{Is_In=unassigned}', "");
Expect(1, 983037, '\P{^Is_In=unassigned}', "");
Expect(0, 983040, '\p{Is_In=unassigned}', "");
Expect(1, 983040, '\p{^Is_In=unassigned}', "");
Expect(1, 983040, '\P{Is_In=unassigned}', "");
Expect(0, 983040, '\P{^Is_In=unassigned}', "");
Expect(1, 983037, '\p{Is_In=	-Unassigned}', "");
Expect(0, 983037, '\p{^Is_In=	-Unassigned}', "");
Expect(0, 983037, '\P{Is_In=	-Unassigned}', "");
Expect(1, 983037, '\P{^Is_In=	-Unassigned}', "");
Expect(0, 983040, '\p{Is_In=	-Unassigned}', "");
Expect(1, 983040, '\p{^Is_In=	-Unassigned}', "");
Expect(1, 983040, '\P{Is_In=	-Unassigned}', "");
Expect(0, 983040, '\P{^Is_In=	-Unassigned}', "");
Error('\p{Indic_Matra_Category=Bottom}');
Error('\P{Indic_Matra_Category=Bottom}');
Error('\p{InMC=Bottom}');
Error('\P{InMC=Bottom}');
Error('\p{Is_Indic_Matra_Category=Bottom}');
Error('\P{Is_Indic_Matra_Category=Bottom}');
Error('\p{Is_InMC=Bottom}');
Error('\P{Is_InMC=Bottom}');
Error('\p{Indic_Matra_Category=Bottom_And_Right}');
Error('\P{Indic_Matra_Category=Bottom_And_Right}');
Error('\p{InMC:   Bottom_And_Right}');
Error('\P{InMC:   Bottom_And_Right}');
Error('\p{Is_Indic_Matra_Category=Bottom_And_Right}');
Error('\P{Is_Indic_Matra_Category=Bottom_And_Right}');
Error('\p{Is_InMC=Bottom_And_Right}');
Error('\P{Is_InMC=Bottom_And_Right}');
Error('\p{Indic_Matra_Category=Invisible}');
Error('\P{Indic_Matra_Category=Invisible}');
Error('\p{InMC=Invisible}');
Error('\P{InMC=Invisible}');
Error('\p{Is_Indic_Matra_Category=Invisible}');
Error('\P{Is_Indic_Matra_Category=Invisible}');
Error('\p{Is_InMC=Invisible}');
Error('\P{Is_InMC=Invisible}');
Error('\p{Indic_Matra_Category=Left}');
Error('\P{Indic_Matra_Category=Left}');
Error('\p{InMC=Left}');
Error('\P{InMC=Left}');
Error('\p{Is_Indic_Matra_Category=Left}');
Error('\P{Is_Indic_Matra_Category=Left}');
Error('\p{Is_InMC=Left}');
Error('\P{Is_InMC=Left}');
Error('\p{Indic_Matra_Category=Left_And_Right}');
Error('\P{Indic_Matra_Category=Left_And_Right}');
Error('\p{InMC=Left_And_Right}');
Error('\P{InMC=Left_And_Right}');
Error('\p{Is_Indic_Matra_Category=Left_And_Right}');
Error('\P{Is_Indic_Matra_Category=Left_And_Right}');
Error('\p{Is_InMC=Left_And_Right}');
Error('\P{Is_InMC=Left_And_Right}');
Error('\p{Indic_Matra_Category: NA}');
Error('\P{Indic_Matra_Category: NA}');
Error('\p{InMC=NA}');
Error('\P{InMC=NA}');
Error('\p{Is_Indic_Matra_Category=NA}');
Error('\P{Is_Indic_Matra_Category=NA}');
Error('\p{Is_InMC=NA}');
Error('\P{Is_InMC=NA}');
Error('\p{Indic_Matra_Category=Overstruck}');
Error('\P{Indic_Matra_Category=Overstruck}');
Error('\p{InMC:Overstruck}');
Error('\P{InMC:Overstruck}');
Error('\p{Is_Indic_Matra_Category=Overstruck}');
Error('\P{Is_Indic_Matra_Category=Overstruck}');
Error('\p{Is_InMC=Overstruck}');
Error('\P{Is_InMC=Overstruck}');
Error('\p{Indic_Matra_Category=Right}');
Error('\P{Indic_Matra_Category=Right}');
Error('\p{InMC=Right}');
Error('\P{InMC=Right}');
Error('\p{Is_Indic_Matra_Category: Right}');
Error('\P{Is_Indic_Matra_Category: Right}');
Error('\p{Is_InMC=Right}');
Error('\P{Is_InMC=Right}');
Error('\p{Indic_Matra_Category=Top}');
Error('\P{Indic_Matra_Category=Top}');
Error('\p{InMC=Top}');
Error('\P{InMC=Top}');
Error('\p{Is_Indic_Matra_Category=Top}');
Error('\P{Is_Indic_Matra_Category=Top}');
Error('\p{Is_InMC=Top}');
Error('\P{Is_InMC=Top}');
Error('\p{Indic_Matra_Category=Top_And_Bottom}');
Error('\P{Indic_Matra_Category=Top_And_Bottom}');
Error('\p{InMC=Top_And_Bottom}');
Error('\P{InMC=Top_And_Bottom}');
Error('\p{Is_Indic_Matra_Category=Top_And_Bottom}');
Error('\P{Is_Indic_Matra_Category=Top_And_Bottom}');
Error('\p{Is_InMC=Top_And_Bottom}');
Error('\P{Is_InMC=Top_And_Bottom}');
Error('\p{Indic_Matra_Category=Top_And_Bottom_And_Right}');
Error('\P{Indic_Matra_Category=Top_And_Bottom_And_Right}');
Error('\p{InMC:Top_And_Bottom_And_Right}');
Error('\P{InMC:Top_And_Bottom_And_Right}');
Error('\p{Is_Indic_Matra_Category=Top_And_Bottom_And_Right}');
Error('\P{Is_Indic_Matra_Category=Top_And_Bottom_And_Right}');
Error('\p{Is_InMC=Top_And_Bottom_And_Right}');
Error('\P{Is_InMC=Top_And_Bottom_And_Right}');
Error('\p{Indic_Matra_Category=Top_And_Left}');
Error('\P{Indic_Matra_Category=Top_And_Left}');
Error('\p{InMC:Top_And_Left}');
Error('\P{InMC:Top_And_Left}');
Error('\p{Is_Indic_Matra_Category=Top_And_Left}');
Error('\P{Is_Indic_Matra_Category=Top_And_Left}');
Error('\p{Is_InMC=Top_And_Left}');
Error('\P{Is_InMC=Top_And_Left}');
Error('\p{Indic_Matra_Category=Top_And_Left_And_Right}');
Error('\P{Indic_Matra_Category=Top_And_Left_And_Right}');
Error('\p{InMC=Top_And_Left_And_Right}');
Error('\P{InMC=Top_And_Left_And_Right}');
Error('\p{Is_Indic_Matra_Category=Top_And_Left_And_Right}');
Error('\P{Is_Indic_Matra_Category=Top_And_Left_And_Right}');
Error('\p{Is_InMC=Top_And_Left_And_Right}');
Error('\P{Is_InMC=Top_And_Left_And_Right}');
Error('\p{Indic_Matra_Category=Top_And_Right}');
Error('\P{Indic_Matra_Category=Top_And_Right}');
Error('\p{InMC=Top_And_Right}');
Error('\P{InMC=Top_And_Right}');
Error('\p{Is_Indic_Matra_Category=Top_And_Right}');
Error('\P{Is_Indic_Matra_Category=Top_And_Right}');
Error('\p{Is_InMC=Top_And_Right}');
Error('\P{Is_InMC=Top_And_Right}');
Error('\p{Indic_Matra_Category:	Visual_Order_Left}');
Error('\P{Indic_Matra_Category:	Visual_Order_Left}');
Error('\p{InMC=Visual_Order_Left}');
Error('\P{InMC=Visual_Order_Left}');
Error('\p{Is_Indic_Matra_Category=Visual_Order_Left}');
Error('\P{Is_Indic_Matra_Category=Visual_Order_Left}');
Error('\p{Is_InMC=Visual_Order_Left}');
Error('\P{Is_InMC=Visual_Order_Left}');
Error('\p{Indic_Syllabic_Category=Avagraha}');
Error('\P{Indic_Syllabic_Category=Avagraha}');
Error('\p{InSC=Avagraha}');
Error('\P{InSC=Avagraha}');
Error('\p{Is_Indic_Syllabic_Category=Avagraha}');
Error('\P{Is_Indic_Syllabic_Category=Avagraha}');
Error('\p{Is_InSC=Avagraha}');
Error('\P{Is_InSC=Avagraha}');
Error('\p{Indic_Syllabic_Category=Bindu}');
Error('\P{Indic_Syllabic_Category=Bindu}');
Error('\p{InSC=Bindu}');
Error('\P{InSC=Bindu}');
Error('\p{Is_Indic_Syllabic_Category=Bindu}');
Error('\P{Is_Indic_Syllabic_Category=Bindu}');
Error('\p{Is_InSC=Bindu}');
Error('\P{Is_InSC=Bindu}');
Error('\p{Indic_Syllabic_Category=Consonant}');
Error('\P{Indic_Syllabic_Category=Consonant}');
Error('\p{InSC=Consonant}');
Error('\P{InSC=Consonant}');
Error('\p{Is_Indic_Syllabic_Category=Consonant}');
Error('\P{Is_Indic_Syllabic_Category=Consonant}');
Error('\p{Is_InSC: Consonant}');
Error('\P{Is_InSC: Consonant}');
Error('\p{Indic_Syllabic_Category=Consonant_Dead}');
Error('\P{Indic_Syllabic_Category=Consonant_Dead}');
Error('\p{InSC:	Consonant_Dead}');
Error('\P{InSC:	Consonant_Dead}');
Error('\p{Is_Indic_Syllabic_Category=Consonant_Dead}');
Error('\P{Is_Indic_Syllabic_Category=Consonant_Dead}');
Error('\p{Is_InSC=Consonant_Dead}');
Error('\P{Is_InSC=Consonant_Dead}');
Error('\p{Indic_Syllabic_Category=Consonant_Final}');
Error('\P{Indic_Syllabic_Category=Consonant_Final}');
Error('\p{InSC=Consonant_Final}');
Error('\P{InSC=Consonant_Final}');
Error('\p{Is_Indic_Syllabic_Category=Consonant_Final}');
Error('\P{Is_Indic_Syllabic_Category=Consonant_Final}');
Error('\p{Is_InSC:   Consonant_Final}');
Error('\P{Is_InSC:   Consonant_Final}');
Error('\p{Indic_Syllabic_Category=Consonant_Head_Letter}');
Error('\P{Indic_Syllabic_Category=Consonant_Head_Letter}');
Error('\p{InSC=Consonant_Head_Letter}');
Error('\P{InSC=Consonant_Head_Letter}');
Error('\p{Is_Indic_Syllabic_Category:   Consonant_Head_Letter}');
Error('\P{Is_Indic_Syllabic_Category:   Consonant_Head_Letter}');
Error('\p{Is_InSC=Consonant_Head_Letter}');
Error('\P{Is_InSC=Consonant_Head_Letter}');
Error('\p{Indic_Syllabic_Category=Consonant_Medial}');
Error('\P{Indic_Syllabic_Category=Consonant_Medial}');
Error('\p{InSC=Consonant_Medial}');
Error('\P{InSC=Consonant_Medial}');
Error('\p{Is_Indic_Syllabic_Category=Consonant_Medial}');
Error('\P{Is_Indic_Syllabic_Category=Consonant_Medial}');
Error('\p{Is_InSC=Consonant_Medial}');
Error('\P{Is_InSC=Consonant_Medial}');
Error('\p{Indic_Syllabic_Category=Consonant_Placeholder}');
Error('\P{Indic_Syllabic_Category=Consonant_Placeholder}');
Error('\p{InSC: Consonant_Placeholder}');
Error('\P{InSC: Consonant_Placeholder}');
Error('\p{Is_Indic_Syllabic_Category=Consonant_Placeholder}');
Error('\P{Is_Indic_Syllabic_Category=Consonant_Placeholder}');
Error('\p{Is_InSC:	Consonant_Placeholder}');
Error('\P{Is_InSC:	Consonant_Placeholder}');
Error('\p{Indic_Syllabic_Category=Consonant_Repha}');
Error('\P{Indic_Syllabic_Category=Consonant_Repha}');
Error('\p{InSC=Consonant_Repha}');
Error('\P{InSC=Consonant_Repha}');
Error('\p{Is_Indic_Syllabic_Category=Consonant_Repha}');
Error('\P{Is_Indic_Syllabic_Category=Consonant_Repha}');
Error('\p{Is_InSC=Consonant_Repha}');
Error('\P{Is_InSC=Consonant_Repha}');
Error('\p{Indic_Syllabic_Category=Consonant_Subjoined}');
Error('\P{Indic_Syllabic_Category=Consonant_Subjoined}');
Error('\p{InSC=Consonant_Subjoined}');
Error('\P{InSC=Consonant_Subjoined}');
Error('\p{Is_Indic_Syllabic_Category=Consonant_Subjoined}');
Error('\P{Is_Indic_Syllabic_Category=Consonant_Subjoined}');
Error('\p{Is_InSC=Consonant_Subjoined}');
Error('\P{Is_InSC=Consonant_Subjoined}');
Error('\p{Indic_Syllabic_Category=Modifying_Letter}');
Error('\P{Indic_Syllabic_Category=Modifying_Letter}');
Error('\p{InSC=Modifying_Letter}');
Error('\P{InSC=Modifying_Letter}');
Error('\p{Is_Indic_Syllabic_Category=Modifying_Letter}');
Error('\P{Is_Indic_Syllabic_Category=Modifying_Letter}');
Error('\p{Is_InSC=Modifying_Letter}');
Error('\P{Is_InSC=Modifying_Letter}');
Error('\p{Indic_Syllabic_Category=Nukta}');
Error('\P{Indic_Syllabic_Category=Nukta}');
Error('\p{InSC=Nukta}');
Error('\P{InSC=Nukta}');
Error('\p{Is_Indic_Syllabic_Category=Nukta}');
Error('\P{Is_Indic_Syllabic_Category=Nukta}');
Error('\p{Is_InSC=Nukta}');
Error('\P{Is_InSC=Nukta}');
Error('\p{Indic_Syllabic_Category=Other}');
Error('\P{Indic_Syllabic_Category=Other}');
Error('\p{InSC=Other}');
Error('\P{InSC=Other}');
Error('\p{Is_Indic_Syllabic_Category=Other}');
Error('\P{Is_Indic_Syllabic_Category=Other}');
Error('\p{Is_InSC=Other}');
Error('\P{Is_InSC=Other}');
Error('\p{Indic_Syllabic_Category=Register_Shifter}');
Error('\P{Indic_Syllabic_Category=Register_Shifter}');
Error('\p{InSC=Register_Shifter}');
Error('\P{InSC=Register_Shifter}');
Error('\p{Is_Indic_Syllabic_Category=Register_Shifter}');
Error('\P{Is_Indic_Syllabic_Category=Register_Shifter}');
Error('\p{Is_InSC:	Register_Shifter}');
Error('\P{Is_InSC:	Register_Shifter}');
Error('\p{Indic_Syllabic_Category=Tone_Letter}');
Error('\P{Indic_Syllabic_Category=Tone_Letter}');
Error('\p{InSC=Tone_Letter}');
Error('\P{InSC=Tone_Letter}');
Error('\p{Is_Indic_Syllabic_Category=Tone_Letter}');
Error('\P{Is_Indic_Syllabic_Category=Tone_Letter}');
Error('\p{Is_InSC=Tone_Letter}');
Error('\P{Is_InSC=Tone_Letter}');
Error('\p{Indic_Syllabic_Category=Tone_Mark}');
Error('\P{Indic_Syllabic_Category=Tone_Mark}');
Error('\p{InSC=Tone_Mark}');
Error('\P{InSC=Tone_Mark}');
Error('\p{Is_Indic_Syllabic_Category=Tone_Mark}');
Error('\P{Is_Indic_Syllabic_Category=Tone_Mark}');
Error('\p{Is_InSC=Tone_Mark}');
Error('\P{Is_InSC=Tone_Mark}');
Error('\p{Indic_Syllabic_Category=Virama}');
Error('\P{Indic_Syllabic_Category=Virama}');
Error('\p{InSC:Virama}');
Error('\P{InSC:Virama}');
Error('\p{Is_Indic_Syllabic_Category=Virama}');
Error('\P{Is_Indic_Syllabic_Category=Virama}');
Error('\p{Is_InSC=Virama}');
Error('\P{Is_InSC=Virama}');
Error('\p{Indic_Syllabic_Category=Visarga}');
Error('\P{Indic_Syllabic_Category=Visarga}');
Error('\p{InSC=Visarga}');
Error('\P{InSC=Visarga}');
Error('\p{Is_Indic_Syllabic_Category=Visarga}');
Error('\P{Is_Indic_Syllabic_Category=Visarga}');
Error('\p{Is_InSC=Visarga}');
Error('\P{Is_InSC=Visarga}');
Error('\p{Indic_Syllabic_Category=Vowel}');
Error('\P{Indic_Syllabic_Category=Vowel}');
Error('\p{InSC: Vowel}');
Error('\P{InSC: Vowel}');
Error('\p{Is_Indic_Syllabic_Category:   Vowel}');
Error('\P{Is_Indic_Syllabic_Category:   Vowel}');
Error('\p{Is_InSC=Vowel}');
Error('\P{Is_InSC=Vowel}');
Error('\p{Indic_Syllabic_Category=Vowel_Dependent}');
Error('\P{Indic_Syllabic_Category=Vowel_Dependent}');
Error('\p{InSC=Vowel_Dependent}');
Error('\P{InSC=Vowel_Dependent}');
Error('\p{Is_Indic_Syllabic_Category=Vowel_Dependent}');
Error('\P{Is_Indic_Syllabic_Category=Vowel_Dependent}');
Error('\p{Is_InSC=Vowel_Dependent}');
Error('\P{Is_InSC=Vowel_Dependent}');
Error('\p{Indic_Syllabic_Category=Vowel_Independent}');
Error('\P{Indic_Syllabic_Category=Vowel_Independent}');
Error('\p{InSC=Vowel_Independent}');
Error('\P{InSC=Vowel_Independent}');
Error('\p{Is_Indic_Syllabic_Category=Vowel_Independent}');
Error('\P{Is_Indic_Syllabic_Category=Vowel_Independent}');
Error('\p{Is_InSC=Vowel_Independent}');
Error('\P{Is_InSC=Vowel_Independent}');
Error('\p{Jamo_Short_Name=A}');
Error('\P{Jamo_Short_Name=A}');
Error('\p{JSN=A}');
Error('\P{JSN=A}');
Error('\p{Is_Jamo_Short_Name=A}');
Error('\P{Is_Jamo_Short_Name=A}');
Error('\p{Is_JSN=A}');
Error('\P{Is_JSN=A}');
Error('\p{Jamo_Short_Name=AE}');
Error('\P{Jamo_Short_Name=AE}');
Error('\p{JSN=AE}');
Error('\P{JSN=AE}');
Error('\p{Is_Jamo_Short_Name=AE}');
Error('\P{Is_Jamo_Short_Name=AE}');
Error('\p{Is_JSN=AE}');
Error('\P{Is_JSN=AE}');
Error('\p{Jamo_Short_Name=B}');
Error('\P{Jamo_Short_Name=B}');
Error('\p{JSN=B}');
Error('\P{JSN=B}');
Error('\p{Is_Jamo_Short_Name=B}');
Error('\P{Is_Jamo_Short_Name=B}');
Error('\p{Is_JSN=B}');
Error('\P{Is_JSN=B}');
Error('\p{Jamo_Short_Name=BB}');
Error('\P{Jamo_Short_Name=BB}');
Error('\p{JSN=BB}');
Error('\P{JSN=BB}');
Error('\p{Is_Jamo_Short_Name=BB}');
Error('\P{Is_Jamo_Short_Name=BB}');
Error('\p{Is_JSN=BB}');
Error('\P{Is_JSN=BB}');
Error('\p{Jamo_Short_Name=BS}');
Error('\P{Jamo_Short_Name=BS}');
Error('\p{JSN=BS}');
Error('\P{JSN=BS}');
Error('\p{Is_Jamo_Short_Name=BS}');
Error('\P{Is_Jamo_Short_Name=BS}');
Error('\p{Is_JSN=BS}');
Error('\P{Is_JSN=BS}');
Error('\p{Jamo_Short_Name=C}');
Error('\P{Jamo_Short_Name=C}');
Error('\p{JSN=C}');
Error('\P{JSN=C}');
Error('\p{Is_Jamo_Short_Name:C}');
Error('\P{Is_Jamo_Short_Name:C}');
Error('\p{Is_JSN=C}');
Error('\P{Is_JSN=C}');
Error('\p{Jamo_Short_Name=D}');
Error('\P{Jamo_Short_Name=D}');
Error('\p{JSN=D}');
Error('\P{JSN=D}');
Error('\p{Is_Jamo_Short_Name=D}');
Error('\P{Is_Jamo_Short_Name=D}');
Error('\p{Is_JSN:D}');
Error('\P{Is_JSN:D}');
Error('\p{Jamo_Short_Name=DD}');
Error('\P{Jamo_Short_Name=DD}');
Error('\p{JSN=DD}');
Error('\P{JSN=DD}');
Error('\p{Is_Jamo_Short_Name=DD}');
Error('\P{Is_Jamo_Short_Name=DD}');
Error('\p{Is_JSN=DD}');
Error('\P{Is_JSN=DD}');
Error('\p{Jamo_Short_Name=E}');
Error('\P{Jamo_Short_Name=E}');
Error('\p{JSN:   E}');
Error('\P{JSN:   E}');
Error('\p{Is_Jamo_Short_Name=E}');
Error('\P{Is_Jamo_Short_Name=E}');
Error('\p{Is_JSN=E}');
Error('\P{Is_JSN=E}');
Error('\p{Jamo_Short_Name:   EO}');
Error('\P{Jamo_Short_Name:   EO}');
Error('\p{JSN=EO}');
Error('\P{JSN=EO}');
Error('\p{Is_Jamo_Short_Name=EO}');
Error('\P{Is_Jamo_Short_Name=EO}');
Error('\p{Is_JSN=EO}');
Error('\P{Is_JSN=EO}');
Error('\p{Jamo_Short_Name=EU}');
Error('\P{Jamo_Short_Name=EU}');
Error('\p{JSN=EU}');
Error('\P{JSN=EU}');
Error('\p{Is_Jamo_Short_Name=EU}');
Error('\P{Is_Jamo_Short_Name=EU}');
Error('\p{Is_JSN=EU}');
Error('\P{Is_JSN=EU}');
Error('\p{Jamo_Short_Name: G}');
Error('\P{Jamo_Short_Name: G}');
Error('\p{JSN=G}');
Error('\P{JSN=G}');
Error('\p{Is_Jamo_Short_Name=G}');
Error('\P{Is_Jamo_Short_Name=G}');
Error('\p{Is_JSN=G}');
Error('\P{Is_JSN=G}');
Error('\p{Jamo_Short_Name=GG}');
Error('\P{Jamo_Short_Name=GG}');
Error('\p{JSN=GG}');
Error('\P{JSN=GG}');
Error('\p{Is_Jamo_Short_Name:   GG}');
Error('\P{Is_Jamo_Short_Name:   GG}');
Error('\p{Is_JSN=GG}');
Error('\P{Is_JSN=GG}');
Error('\p{Jamo_Short_Name=GS}');
Error('\P{Jamo_Short_Name=GS}');
Error('\p{JSN=GS}');
Error('\P{JSN=GS}');
Error('\p{Is_Jamo_Short_Name=GS}');
Error('\P{Is_Jamo_Short_Name=GS}');
Error('\p{Is_JSN=GS}');
Error('\P{Is_JSN=GS}');
Error('\p{Jamo_Short_Name=H}');
Error('\P{Jamo_Short_Name=H}');
Error('\p{JSN=H}');
Error('\P{JSN=H}');
Error('\p{Is_Jamo_Short_Name: H}');
Error('\P{Is_Jamo_Short_Name: H}');
Error('\p{Is_JSN=H}');
Error('\P{Is_JSN=H}');
Error('\p{Jamo_Short_Name=I}');
Error('\P{Jamo_Short_Name=I}');
Error('\p{JSN=I}');
Error('\P{JSN=I}');
Error('\p{Is_Jamo_Short_Name=I}');
Error('\P{Is_Jamo_Short_Name=I}');
Error('\p{Is_JSN=I}');
Error('\P{Is_JSN=I}');
Error('\p{Jamo_Short_Name=J}');
Error('\P{Jamo_Short_Name=J}');
Error('\p{JSN=J}');
Error('\P{JSN=J}');
Error('\p{Is_Jamo_Short_Name=J}');
Error('\P{Is_Jamo_Short_Name=J}');
Error('\p{Is_JSN=J}');
Error('\P{Is_JSN=J}');
Error('\p{Jamo_Short_Name=JJ}');
Error('\P{Jamo_Short_Name=JJ}');
Error('\p{JSN=JJ}');
Error('\P{JSN=JJ}');
Error('\p{Is_Jamo_Short_Name=JJ}');
Error('\P{Is_Jamo_Short_Name=JJ}');
Error('\p{Is_JSN:JJ}');
Error('\P{Is_JSN:JJ}');
Error('\p{Jamo_Short_Name=K}');
Error('\P{Jamo_Short_Name=K}');
Error('\p{JSN=K}');
Error('\P{JSN=K}');
Error('\p{Is_Jamo_Short_Name=K}');
Error('\P{Is_Jamo_Short_Name=K}');
Error('\p{Is_JSN=K}');
Error('\P{Is_JSN=K}');
Error('\p{Jamo_Short_Name=L}');
Error('\P{Jamo_Short_Name=L}');
Error('\p{JSN=L}');
Error('\P{JSN=L}');
Error('\p{Is_Jamo_Short_Name=L}');
Error('\P{Is_Jamo_Short_Name=L}');
Error('\p{Is_JSN=L}');
Error('\P{Is_JSN=L}');
Error('\p{Jamo_Short_Name=LB}');
Error('\P{Jamo_Short_Name=LB}');
Error('\p{JSN=LB}');
Error('\P{JSN=LB}');
Error('\p{Is_Jamo_Short_Name=LB}');
Error('\P{Is_Jamo_Short_Name=LB}');
Error('\p{Is_JSN=LB}');
Error('\P{Is_JSN=LB}');
Error('\p{Jamo_Short_Name=LG}');
Error('\P{Jamo_Short_Name=LG}');
Error('\p{JSN:LG}');
Error('\P{JSN:LG}');
Error('\p{Is_Jamo_Short_Name:   LG}');
Error('\P{Is_Jamo_Short_Name:   LG}');
Error('\p{Is_JSN:LG}');
Error('\P{Is_JSN:LG}');
Error('\p{Jamo_Short_Name=LH}');
Error('\P{Jamo_Short_Name=LH}');
Error('\p{JSN:	LH}');
Error('\P{JSN:	LH}');
Error('\p{Is_Jamo_Short_Name:	LH}');
Error('\P{Is_Jamo_Short_Name:	LH}');
Error('\p{Is_JSN=LH}');
Error('\P{Is_JSN=LH}');
Error('\p{Jamo_Short_Name: LM}');
Error('\P{Jamo_Short_Name: LM}');
Error('\p{JSN=LM}');
Error('\P{JSN=LM}');
Error('\p{Is_Jamo_Short_Name=LM}');
Error('\P{Is_Jamo_Short_Name=LM}');
Error('\p{Is_JSN=LM}');
Error('\P{Is_JSN=LM}');
Error('\p{Jamo_Short_Name=LP}');
Error('\P{Jamo_Short_Name=LP}');
Error('\p{JSN=LP}');
Error('\P{JSN=LP}');
Error('\p{Is_Jamo_Short_Name=LP}');
Error('\P{Is_Jamo_Short_Name=LP}');
Error('\p{Is_JSN=LP}');
Error('\P{Is_JSN=LP}');
Error('\p{Jamo_Short_Name=LS}');
Error('\P{Jamo_Short_Name=LS}');
Error('\p{JSN=LS}');
Error('\P{JSN=LS}');
Error('\p{Is_Jamo_Short_Name:LS}');
Error('\P{Is_Jamo_Short_Name:LS}');
Error('\p{Is_JSN=LS}');
Error('\P{Is_JSN=LS}');
Error('\p{Jamo_Short_Name:LT}');
Error('\P{Jamo_Short_Name:LT}');
Error('\p{JSN=LT}');
Error('\P{JSN=LT}');
Error('\p{Is_Jamo_Short_Name:LT}');
Error('\P{Is_Jamo_Short_Name:LT}');
Error('\p{Is_JSN=LT}');
Error('\P{Is_JSN=LT}');
Error('\p{Jamo_Short_Name=M}');
Error('\P{Jamo_Short_Name=M}');
Error('\p{JSN=M}');
Error('\P{JSN=M}');
Error('\p{Is_Jamo_Short_Name=M}');
Error('\P{Is_Jamo_Short_Name=M}');
Error('\p{Is_JSN=M}');
Error('\P{Is_JSN=M}');
Error('\p{Jamo_Short_Name=N}');
Error('\P{Jamo_Short_Name=N}');
Error('\p{JSN=N}');
Error('\P{JSN=N}');
Error('\p{Is_Jamo_Short_Name=N}');
Error('\P{Is_Jamo_Short_Name=N}');
Error('\p{Is_JSN=N}');
Error('\P{Is_JSN=N}');
Error('\p{Jamo_Short_Name=NG}');
Error('\P{Jamo_Short_Name=NG}');
Error('\p{JSN=NG}');
Error('\P{JSN=NG}');
Error('\p{Is_Jamo_Short_Name=NG}');
Error('\P{Is_Jamo_Short_Name=NG}');
Error('\p{Is_JSN=NG}');
Error('\P{Is_JSN=NG}');
Error('\p{Jamo_Short_Name=NH}');
Error('\P{Jamo_Short_Name=NH}');
Error('\p{JSN=NH}');
Error('\P{JSN=NH}');
Error('\p{Is_Jamo_Short_Name=NH}');
Error('\P{Is_Jamo_Short_Name=NH}');
Error('\p{Is_JSN=NH}');
Error('\P{Is_JSN=NH}');
Error('\p{Jamo_Short_Name=NJ}');
Error('\P{Jamo_Short_Name=NJ}');
Error('\p{JSN=NJ}');
Error('\P{JSN=NJ}');
Error('\p{Is_Jamo_Short_Name=NJ}');
Error('\P{Is_Jamo_Short_Name=NJ}');
Error('\p{Is_JSN=NJ}');
Error('\P{Is_JSN=NJ}');
Error('\p{Jamo_Short_Name=O}');
Error('\P{Jamo_Short_Name=O}');
Error('\p{JSN:O}');
Error('\P{JSN:O}');
Error('\p{Is_Jamo_Short_Name=O}');
Error('\P{Is_Jamo_Short_Name=O}');
Error('\p{Is_JSN=O}');
Error('\P{Is_JSN=O}');
Error('\p{Jamo_Short_Name=OE}');
Error('\P{Jamo_Short_Name=OE}');
Error('\p{JSN=OE}');
Error('\P{JSN=OE}');
Error('\p{Is_Jamo_Short_Name=OE}');
Error('\P{Is_Jamo_Short_Name=OE}');
Error('\p{Is_JSN:OE}');
Error('\P{Is_JSN:OE}');
Error('\p{Jamo_Short_Name=P}');
Error('\P{Jamo_Short_Name=P}');
Error('\p{JSN:   P}');
Error('\P{JSN:   P}');
Error('\p{Is_Jamo_Short_Name=P}');
Error('\P{Is_Jamo_Short_Name=P}');
Error('\p{Is_JSN=P}');
Error('\P{Is_JSN=P}');
Error('\p{Jamo_Short_Name:	R}');
Error('\P{Jamo_Short_Name:	R}');
Error('\p{JSN=R}');
Error('\P{JSN=R}');
Error('\p{Is_Jamo_Short_Name=R}');
Error('\P{Is_Jamo_Short_Name=R}');
Error('\p{Is_JSN=R}');
Error('\P{Is_JSN=R}');
Error('\p{Jamo_Short_Name=S}');
Error('\P{Jamo_Short_Name=S}');
Error('\p{JSN=S}');
Error('\P{JSN=S}');
Error('\p{Is_Jamo_Short_Name=S}');
Error('\P{Is_Jamo_Short_Name=S}');
Error('\p{Is_JSN=S}');
Error('\P{Is_JSN=S}');
Error('\p{Jamo_Short_Name:SS}');
Error('\P{Jamo_Short_Name:SS}');
Error('\p{JSN:SS}');
Error('\P{JSN:SS}');
Error('\p{Is_Jamo_Short_Name=SS}');
Error('\P{Is_Jamo_Short_Name=SS}');
Error('\p{Is_JSN=SS}');
Error('\P{Is_JSN=SS}');
Error('\p{Jamo_Short_Name=T}');
Error('\P{Jamo_Short_Name=T}');
Error('\p{JSN=T}');
Error('\P{JSN=T}');
Error('\p{Is_Jamo_Short_Name=T}');
Error('\P{Is_Jamo_Short_Name=T}');
Error('\p{Is_JSN=T}');
Error('\P{Is_JSN=T}');
Error('\p{Jamo_Short_Name=U}');
Error('\P{Jamo_Short_Name=U}');
Error('\p{JSN=U}');
Error('\P{JSN=U}');
Error('\p{Is_Jamo_Short_Name=U}');
Error('\P{Is_Jamo_Short_Name=U}');
Error('\p{Is_JSN=U}');
Error('\P{Is_JSN=U}');
Error('\p{Jamo_Short_Name=WA}');
Error('\P{Jamo_Short_Name=WA}');
Error('\p{JSN=WA}');
Error('\P{JSN=WA}');
Error('\p{Is_Jamo_Short_Name=WA}');
Error('\P{Is_Jamo_Short_Name=WA}');
Error('\p{Is_JSN=WA}');
Error('\P{Is_JSN=WA}');
Error('\p{Jamo_Short_Name:WAE}');
Error('\P{Jamo_Short_Name:WAE}');
Error('\p{JSN=WAE}');
Error('\P{JSN=WAE}');
Error('\p{Is_Jamo_Short_Name=WAE}');
Error('\P{Is_Jamo_Short_Name=WAE}');
Error('\p{Is_JSN=WAE}');
Error('\P{Is_JSN=WAE}');
Error('\p{Jamo_Short_Name=WE}');
Error('\P{Jamo_Short_Name=WE}');
Error('\p{JSN=WE}');
Error('\P{JSN=WE}');
Error('\p{Is_Jamo_Short_Name=WE}');
Error('\P{Is_Jamo_Short_Name=WE}');
Error('\p{Is_JSN=WE}');
Error('\P{Is_JSN=WE}');
Error('\p{Jamo_Short_Name=WEO}');
Error('\P{Jamo_Short_Name=WEO}');
Error('\p{JSN=WEO}');
Error('\P{JSN=WEO}');
Error('\p{Is_Jamo_Short_Name=WEO}');
Error('\P{Is_Jamo_Short_Name=WEO}');
Error('\p{Is_JSN=WEO}');
Error('\P{Is_JSN=WEO}');
Error('\p{Jamo_Short_Name=WI}');
Error('\P{Jamo_Short_Name=WI}');
Error('\p{JSN=WI}');
Error('\P{JSN=WI}');
Error('\p{Is_Jamo_Short_Name=WI}');
Error('\P{Is_Jamo_Short_Name=WI}');
Error('\p{Is_JSN:	WI}');
Error('\P{Is_JSN:	WI}');
Error('\p{Jamo_Short_Name=YA}');
Error('\P{Jamo_Short_Name=YA}');
Error('\p{JSN=YA}');
Error('\P{JSN=YA}');
Error('\p{Is_Jamo_Short_Name=YA}');
Error('\P{Is_Jamo_Short_Name=YA}');
Error('\p{Is_JSN=YA}');
Error('\P{Is_JSN=YA}');
Error('\p{Jamo_Short_Name=YAE}');
Error('\P{Jamo_Short_Name=YAE}');
Error('\p{JSN=YAE}');
Error('\P{JSN=YAE}');
Error('\p{Is_Jamo_Short_Name=YAE}');
Error('\P{Is_Jamo_Short_Name=YAE}');
Error('\p{Is_JSN=YAE}');
Error('\P{Is_JSN=YAE}');
Error('\p{Jamo_Short_Name=YE}');
Error('\P{Jamo_Short_Name=YE}');
Error('\p{JSN=YE}');
Error('\P{JSN=YE}');
Error('\p{Is_Jamo_Short_Name=YE}');
Error('\P{Is_Jamo_Short_Name=YE}');
Error('\p{Is_JSN=YE}');
Error('\P{Is_JSN=YE}');
Error('\p{Jamo_Short_Name:	YEO}');
Error('\P{Jamo_Short_Name:	YEO}');
Error('\p{JSN=YEO}');
Error('\P{JSN=YEO}');
Error('\p{Is_Jamo_Short_Name:   YEO}');
Error('\P{Is_Jamo_Short_Name:   YEO}');
Error('\p{Is_JSN=YEO}');
Error('\P{Is_JSN=YEO}');
Error('\p{Jamo_Short_Name=YI}');
Error('\P{Jamo_Short_Name=YI}');
Error('\p{JSN=YI}');
Error('\P{JSN=YI}');
Error('\p{Is_Jamo_Short_Name=YI}');
Error('\P{Is_Jamo_Short_Name=YI}');
Error('\p{Is_JSN=YI}');
Error('\P{Is_JSN=YI}');
Error('\p{Jamo_Short_Name=YO}');
Error('\P{Jamo_Short_Name=YO}');
Error('\p{JSN=YO}');
Error('\P{JSN=YO}');
Error('\p{Is_Jamo_Short_Name:   YO}');
Error('\P{Is_Jamo_Short_Name:   YO}');
Error('\p{Is_JSN=YO}');
Error('\P{Is_JSN=YO}');
Error('\p{Jamo_Short_Name=YU}');
Error('\P{Jamo_Short_Name=YU}');
Error('\p{JSN=YU}');
Error('\P{JSN=YU}');
Error('\p{Is_Jamo_Short_Name=YU}');
Error('\P{Is_Jamo_Short_Name=YU}');
Error('\p{Is_JSN=YU}');
Error('\P{Is_JSN=YU}');
Error('\p{Join_Control=	-NO:=}');
Error('\P{Join_Control=	-NO:=}');
Expect(1, 8206, '\p{Join_Control=no}', "");
Expect(0, 8206, '\p{^Join_Control=no}', "");
Expect(0, 8206, '\P{Join_Control=no}', "");
Expect(1, 8206, '\P{^Join_Control=no}', "");
Expect(0, 8205, '\p{Join_Control=no}', "");
Expect(1, 8205, '\p{^Join_Control=no}', "");
Expect(1, 8205, '\P{Join_Control=no}', "");
Expect(0, 8205, '\P{^Join_Control=no}', "");
Expect(1, 8206, '\p{Join_Control=-NO}', "");
Expect(0, 8206, '\p{^Join_Control=-NO}', "");
Expect(0, 8206, '\P{Join_Control=-NO}', "");
Expect(1, 8206, '\P{^Join_Control=-NO}', "");
Expect(0, 8205, '\p{Join_Control=-NO}', "");
Expect(1, 8205, '\p{^Join_Control=-NO}', "");
Expect(1, 8205, '\P{Join_Control=-NO}', "");
Expect(0, 8205, '\P{^Join_Control=-NO}', "");
Error('\p{Join_C=-N:=}');
Error('\P{Join_C=-N:=}');
Expect(1, 8206, '\p{Join_C=n}', "");
Expect(0, 8206, '\p{^Join_C=n}', "");
Expect(0, 8206, '\P{Join_C=n}', "");
Expect(1, 8206, '\P{^Join_C=n}', "");
Expect(0, 8205, '\p{Join_C=n}', "");
Expect(1, 8205, '\p{^Join_C=n}', "");
Expect(1, 8205, '\P{Join_C=n}', "");
Expect(0, 8205, '\P{^Join_C=n}', "");
Expect(1, 8206, '\p{Join_C=	 N}', "");
Expect(0, 8206, '\p{^Join_C=	 N}', "");
Expect(0, 8206, '\P{Join_C=	 N}', "");
Expect(1, 8206, '\P{^Join_C=	 N}', "");
Expect(0, 8205, '\p{Join_C=	 N}', "");
Expect(1, 8205, '\p{^Join_C=	 N}', "");
Expect(1, 8205, '\P{Join_C=	 N}', "");
Expect(0, 8205, '\P{^Join_C=	 N}', "");
Error('\p{Is_Join_Control=:=		F}');
Error('\P{Is_Join_Control=:=		F}');
Expect(1, 8206, '\p{Is_Join_Control=f}', "");
Expect(0, 8206, '\p{^Is_Join_Control=f}', "");
Expect(0, 8206, '\P{Is_Join_Control=f}', "");
Expect(1, 8206, '\P{^Is_Join_Control=f}', "");
Expect(0, 8205, '\p{Is_Join_Control=f}', "");
Expect(1, 8205, '\p{^Is_Join_Control=f}', "");
Expect(1, 8205, '\P{Is_Join_Control=f}', "");
Expect(0, 8205, '\P{^Is_Join_Control=f}', "");
Expect(1, 8206, '\p{Is_Join_Control= f}', "");
Expect(0, 8206, '\p{^Is_Join_Control= f}', "");
Expect(0, 8206, '\P{Is_Join_Control= f}', "");
Expect(1, 8206, '\P{^Is_Join_Control= f}', "");
Expect(0, 8205, '\p{Is_Join_Control= f}', "");
Expect(1, 8205, '\p{^Is_Join_Control= f}', "");
Expect(1, 8205, '\P{Is_Join_Control= f}', "");
Expect(0, 8205, '\P{^Is_Join_Control= f}', "");
Error('\p{Is_Join_C=:=	False}');
Error('\P{Is_Join_C=:=	False}');
Expect(1, 8206, '\p{Is_Join_C=false}', "");
Expect(0, 8206, '\p{^Is_Join_C=false}', "");
Expect(0, 8206, '\P{Is_Join_C=false}', "");
Expect(1, 8206, '\P{^Is_Join_C=false}', "");
Expect(0, 8205, '\p{Is_Join_C=false}', "");
Expect(1, 8205, '\p{^Is_Join_C=false}', "");
Expect(1, 8205, '\P{Is_Join_C=false}', "");
Expect(0, 8205, '\P{^Is_Join_C=false}', "");
Expect(1, 8206, '\p{Is_Join_C=--FALSE}', "");
Expect(0, 8206, '\p{^Is_Join_C=--FALSE}', "");
Expect(0, 8206, '\P{Is_Join_C=--FALSE}', "");
Expect(1, 8206, '\P{^Is_Join_C=--FALSE}', "");
Expect(0, 8205, '\p{Is_Join_C=--FALSE}', "");
Expect(1, 8205, '\p{^Is_Join_C=--FALSE}', "");
Expect(1, 8205, '\P{Is_Join_C=--FALSE}', "");
Expect(0, 8205, '\P{^Is_Join_C=--FALSE}', "");
Error('\p{Join_Control:	_/a/Yes}');
Error('\P{Join_Control:	_/a/Yes}');
Expect(1, 8205, '\p{Join_Control=yes}', "");
Expect(0, 8205, '\p{^Join_Control=yes}', "");
Expect(0, 8205, '\P{Join_Control=yes}', "");
Expect(1, 8205, '\P{^Join_Control=yes}', "");
Expect(0, 8206, '\p{Join_Control=yes}', "");
Expect(1, 8206, '\p{^Join_Control=yes}', "");
Expect(1, 8206, '\P{Join_Control=yes}', "");
Expect(0, 8206, '\P{^Join_Control=yes}', "");
Expect(1, 8205, '\p{Join_Control=	-Yes}', "");
Expect(0, 8205, '\p{^Join_Control=	-Yes}', "");
Expect(0, 8205, '\P{Join_Control=	-Yes}', "");
Expect(1, 8205, '\P{^Join_Control=	-Yes}', "");
Expect(0, 8206, '\p{Join_Control=	-Yes}', "");
Expect(1, 8206, '\p{^Join_Control=	-Yes}', "");
Expect(1, 8206, '\P{Join_Control=	-Yes}', "");
Expect(0, 8206, '\P{^Join_Control=	-Yes}', "");
Error('\p{Join_C=-_Y:=}');
Error('\P{Join_C=-_Y:=}');
Expect(1, 8205, '\p{Join_C:y}', "");
Expect(0, 8205, '\p{^Join_C:y}', "");
Expect(0, 8205, '\P{Join_C:y}', "");
Expect(1, 8205, '\P{^Join_C:y}', "");
Expect(0, 8206, '\p{Join_C:y}', "");
Expect(1, 8206, '\p{^Join_C:y}', "");
Expect(1, 8206, '\P{Join_C:y}', "");
Expect(0, 8206, '\P{^Join_C:y}', "");
Expect(1, 8205, '\p{Join_C=_Y}', "");
Expect(0, 8205, '\p{^Join_C=_Y}', "");
Expect(0, 8205, '\P{Join_C=_Y}', "");
Expect(1, 8205, '\P{^Join_C=_Y}', "");
Expect(0, 8206, '\p{Join_C=_Y}', "");
Expect(1, 8206, '\p{^Join_C=_Y}', "");
Expect(1, 8206, '\P{Join_C=_Y}', "");
Expect(0, 8206, '\P{^Join_C=_Y}', "");
Error('\p{Is_Join_Control=- t/a/}');
Error('\P{Is_Join_Control=- t/a/}');
Expect(1, 8205, '\p{Is_Join_Control: t}', "");
Expect(0, 8205, '\p{^Is_Join_Control: t}', "");
Expect(0, 8205, '\P{Is_Join_Control: t}', "");
Expect(1, 8205, '\P{^Is_Join_Control: t}', "");
Expect(0, 8206, '\p{Is_Join_Control: t}', "");
Expect(1, 8206, '\p{^Is_Join_Control: t}', "");
Expect(1, 8206, '\P{Is_Join_Control: t}', "");
Expect(0, 8206, '\P{^Is_Join_Control: t}', "");
Expect(1, 8205, '\p{Is_Join_Control=-T}', "");
Expect(0, 8205, '\p{^Is_Join_Control=-T}', "");
Expect(0, 8205, '\P{Is_Join_Control=-T}', "");
Expect(1, 8205, '\P{^Is_Join_Control=-T}', "");
Expect(0, 8206, '\p{Is_Join_Control=-T}', "");
Expect(1, 8206, '\p{^Is_Join_Control=-T}', "");
Expect(1, 8206, '\P{Is_Join_Control=-T}', "");
Expect(0, 8206, '\P{^Is_Join_Control=-T}', "");
Error('\p{Is_Join_C=/a/	_True}');
Error('\P{Is_Join_C=/a/	_True}');
Expect(1, 8205, '\p{Is_Join_C=true}', "");
Expect(0, 8205, '\p{^Is_Join_C=true}', "");
Expect(0, 8205, '\P{Is_Join_C=true}', "");
Expect(1, 8205, '\P{^Is_Join_C=true}', "");
Expect(0, 8206, '\p{Is_Join_C=true}', "");
Expect(1, 8206, '\p{^Is_Join_C=true}', "");
Expect(1, 8206, '\P{Is_Join_C=true}', "");
Expect(0, 8206, '\P{^Is_Join_C=true}', "");
Expect(1, 8205, '\p{Is_Join_C= -True}', "");
Expect(0, 8205, '\p{^Is_Join_C= -True}', "");
Expect(0, 8205, '\P{Is_Join_C= -True}', "");
Expect(1, 8205, '\P{^Is_Join_C= -True}', "");
Expect(0, 8206, '\p{Is_Join_C= -True}', "");
Expect(1, 8206, '\p{^Is_Join_C= -True}', "");
Expect(1, 8206, '\P{Is_Join_C= -True}', "");
Expect(0, 8206, '\P{^Is_Join_C= -True}', "");
Error('\p{Logical_Order_Exception=	:=NO}');
Error('\P{Logical_Order_Exception=	:=NO}');
Expect(1, 43709, '\p{Logical_Order_Exception=no}', "");
Expect(0, 43709, '\p{^Logical_Order_Exception=no}', "");
Expect(0, 43709, '\P{Logical_Order_Exception=no}', "");
Expect(1, 43709, '\P{^Logical_Order_Exception=no}', "");
Expect(0, 43708, '\p{Logical_Order_Exception=no}', "");
Expect(1, 43708, '\p{^Logical_Order_Exception=no}', "");
Expect(1, 43708, '\P{Logical_Order_Exception=no}', "");
Expect(0, 43708, '\P{^Logical_Order_Exception=no}', "");
Expect(1, 43709, '\p{Logical_Order_Exception=--no}', "");
Expect(0, 43709, '\p{^Logical_Order_Exception=--no}', "");
Expect(0, 43709, '\P{Logical_Order_Exception=--no}', "");
Expect(1, 43709, '\P{^Logical_Order_Exception=--no}', "");
Expect(0, 43708, '\p{Logical_Order_Exception=--no}', "");
Expect(1, 43708, '\p{^Logical_Order_Exception=--no}', "");
Expect(1, 43708, '\P{Logical_Order_Exception=--no}', "");
Expect(0, 43708, '\P{^Logical_Order_Exception=--no}', "");
Error('\p{LOE=-:=n}');
Error('\P{LOE=-:=n}');
Expect(1, 43709, '\p{LOE=n}', "");
Expect(0, 43709, '\p{^LOE=n}', "");
Expect(0, 43709, '\P{LOE=n}', "");
Expect(1, 43709, '\P{^LOE=n}', "");
Expect(0, 43708, '\p{LOE=n}', "");
Expect(1, 43708, '\p{^LOE=n}', "");
Expect(1, 43708, '\P{LOE=n}', "");
Expect(0, 43708, '\P{^LOE=n}', "");
Expect(1, 43709, '\p{LOE: -N}', "");
Expect(0, 43709, '\p{^LOE: -N}', "");
Expect(0, 43709, '\P{LOE: -N}', "");
Expect(1, 43709, '\P{^LOE: -N}', "");
Expect(0, 43708, '\p{LOE: -N}', "");
Expect(1, 43708, '\p{^LOE: -N}', "");
Expect(1, 43708, '\P{LOE: -N}', "");
Expect(0, 43708, '\P{^LOE: -N}', "");
Error('\p{Is_Logical_Order_Exception=:=F}');
Error('\P{Is_Logical_Order_Exception=:=F}');
Expect(1, 43709, '\p{Is_Logical_Order_Exception:	f}', "");
Expect(0, 43709, '\p{^Is_Logical_Order_Exception:	f}', "");
Expect(0, 43709, '\P{Is_Logical_Order_Exception:	f}', "");
Expect(1, 43709, '\P{^Is_Logical_Order_Exception:	f}', "");
Expect(0, 43708, '\p{Is_Logical_Order_Exception:	f}', "");
Expect(1, 43708, '\p{^Is_Logical_Order_Exception:	f}', "");
Expect(1, 43708, '\P{Is_Logical_Order_Exception:	f}', "");
Expect(0, 43708, '\P{^Is_Logical_Order_Exception:	f}', "");
Expect(1, 43709, '\p{Is_Logical_Order_Exception=- F}', "");
Expect(0, 43709, '\p{^Is_Logical_Order_Exception=- F}', "");
Expect(0, 43709, '\P{Is_Logical_Order_Exception=- F}', "");
Expect(1, 43709, '\P{^Is_Logical_Order_Exception=- F}', "");
Expect(0, 43708, '\p{Is_Logical_Order_Exception=- F}', "");
Expect(1, 43708, '\p{^Is_Logical_Order_Exception=- F}', "");
Expect(1, 43708, '\P{Is_Logical_Order_Exception=- F}', "");
Expect(0, 43708, '\P{^Is_Logical_Order_Exception=- F}', "");
Error('\p{Is_LOE=-/a/False}');
Error('\P{Is_LOE=-/a/False}');
Expect(1, 43709, '\p{Is_LOE=false}', "");
Expect(0, 43709, '\p{^Is_LOE=false}', "");
Expect(0, 43709, '\P{Is_LOE=false}', "");
Expect(1, 43709, '\P{^Is_LOE=false}', "");
Expect(0, 43708, '\p{Is_LOE=false}', "");
Expect(1, 43708, '\p{^Is_LOE=false}', "");
Expect(1, 43708, '\P{Is_LOE=false}', "");
Expect(0, 43708, '\P{^Is_LOE=false}', "");
Expect(1, 43709, '\p{Is_LOE=_ false}', "");
Expect(0, 43709, '\p{^Is_LOE=_ false}', "");
Expect(0, 43709, '\P{Is_LOE=_ false}', "");
Expect(1, 43709, '\P{^Is_LOE=_ false}', "");
Expect(0, 43708, '\p{Is_LOE=_ false}', "");
Expect(1, 43708, '\p{^Is_LOE=_ false}', "");
Expect(1, 43708, '\P{Is_LOE=_ false}', "");
Expect(0, 43708, '\P{^Is_LOE=_ false}', "");
Error('\p{Logical_Order_Exception=/a/YES}');
Error('\P{Logical_Order_Exception=/a/YES}');
Expect(1, 43708, '\p{Logical_Order_Exception=yes}', "");
Expect(0, 43708, '\p{^Logical_Order_Exception=yes}', "");
Expect(0, 43708, '\P{Logical_Order_Exception=yes}', "");
Expect(1, 43708, '\P{^Logical_Order_Exception=yes}', "");
Expect(0, 43709, '\p{Logical_Order_Exception=yes}', "");
Expect(1, 43709, '\p{^Logical_Order_Exception=yes}', "");
Expect(1, 43709, '\P{Logical_Order_Exception=yes}', "");
Expect(0, 43709, '\P{^Logical_Order_Exception=yes}', "");
Expect(1, 43708, '\p{Logical_Order_Exception:	Yes}', "");
Expect(0, 43708, '\p{^Logical_Order_Exception:	Yes}', "");
Expect(0, 43708, '\P{Logical_Order_Exception:	Yes}', "");
Expect(1, 43708, '\P{^Logical_Order_Exception:	Yes}', "");
Expect(0, 43709, '\p{Logical_Order_Exception:	Yes}', "");
Expect(1, 43709, '\p{^Logical_Order_Exception:	Yes}', "");
Expect(1, 43709, '\P{Logical_Order_Exception:	Yes}', "");
Expect(0, 43709, '\P{^Logical_Order_Exception:	Yes}', "");
Error('\p{LOE=-y/a/}');
Error('\P{LOE=-y/a/}');
Expect(1, 43708, '\p{LOE=y}', "");
Expect(0, 43708, '\p{^LOE=y}', "");
Expect(0, 43708, '\P{LOE=y}', "");
Expect(1, 43708, '\P{^LOE=y}', "");
Expect(0, 43709, '\p{LOE=y}', "");
Expect(1, 43709, '\p{^LOE=y}', "");
Expect(1, 43709, '\P{LOE=y}', "");
Expect(0, 43709, '\P{^LOE=y}', "");
Expect(1, 43708, '\p{LOE:	_	y}', "");
Expect(0, 43708, '\p{^LOE:	_	y}', "");
Expect(0, 43708, '\P{LOE:	_	y}', "");
Expect(1, 43708, '\P{^LOE:	_	y}', "");
Expect(0, 43709, '\p{LOE:	_	y}', "");
Expect(1, 43709, '\p{^LOE:	_	y}', "");
Expect(1, 43709, '\P{LOE:	_	y}', "");
Expect(0, 43709, '\P{^LOE:	_	y}', "");
Error('\p{Is_Logical_Order_Exception:   	/a/T}');
Error('\P{Is_Logical_Order_Exception:   	/a/T}');
Expect(1, 43708, '\p{Is_Logical_Order_Exception:t}', "");
Expect(0, 43708, '\p{^Is_Logical_Order_Exception:t}', "");
Expect(0, 43708, '\P{Is_Logical_Order_Exception:t}', "");
Expect(1, 43708, '\P{^Is_Logical_Order_Exception:t}', "");
Expect(0, 43709, '\p{Is_Logical_Order_Exception:t}', "");
Expect(1, 43709, '\p{^Is_Logical_Order_Exception:t}', "");
Expect(1, 43709, '\P{Is_Logical_Order_Exception:t}', "");
Expect(0, 43709, '\P{^Is_Logical_Order_Exception:t}', "");
Expect(1, 43708, '\p{Is_Logical_Order_Exception=-_T}', "");
Expect(0, 43708, '\p{^Is_Logical_Order_Exception=-_T}', "");
Expect(0, 43708, '\P{Is_Logical_Order_Exception=-_T}', "");
Expect(1, 43708, '\P{^Is_Logical_Order_Exception=-_T}', "");
Expect(0, 43709, '\p{Is_Logical_Order_Exception=-_T}', "");
Expect(1, 43709, '\p{^Is_Logical_Order_Exception=-_T}', "");
Expect(1, 43709, '\P{Is_Logical_Order_Exception=-_T}', "");
Expect(0, 43709, '\P{^Is_Logical_Order_Exception=-_T}', "");
Error('\p{Is_LOE=/a/_True}');
Error('\P{Is_LOE=/a/_True}');
Expect(1, 43708, '\p{Is_LOE:   true}', "");
Expect(0, 43708, '\p{^Is_LOE:   true}', "");
Expect(0, 43708, '\P{Is_LOE:   true}', "");
Expect(1, 43708, '\P{^Is_LOE:   true}', "");
Expect(0, 43709, '\p{Is_LOE:   true}', "");
Expect(1, 43709, '\p{^Is_LOE:   true}', "");
Expect(1, 43709, '\P{Is_LOE:   true}', "");
Expect(0, 43709, '\P{^Is_LOE:   true}', "");
Expect(1, 43708, '\p{Is_LOE=- true}', "");
Expect(0, 43708, '\p{^Is_LOE=- true}', "");
Expect(0, 43708, '\P{Is_LOE=- true}', "");
Expect(1, 43708, '\P{^Is_LOE=- true}', "");
Expect(0, 43709, '\p{Is_LOE=- true}', "");
Expect(1, 43709, '\p{^Is_LOE=- true}', "");
Expect(1, 43709, '\P{Is_LOE=- true}', "");
Expect(0, 43709, '\P{^Is_LOE=- true}', "");
Error('\p{Lowercase:	-NO/a/}');
Error('\P{Lowercase:	-NO/a/}');
Expect(1, 120780, '\p{Lowercase:no}', "");
Expect(0, 120780, '\p{^Lowercase:no}', "");
Expect(0, 120780, '\P{Lowercase:no}', "");
Expect(1, 120780, '\P{^Lowercase:no}', "");
Expect(0, 120779, '\p{Lowercase:no}', "");
Expect(1, 120779, '\p{^Lowercase:no}', "");
Expect(1, 120779, '\P{Lowercase:no}', "");
Expect(0, 120779, '\P{^Lowercase:no}', "");
Expect(1, 120780, '\p{Lowercase=- No}', "");
Expect(0, 120780, '\p{^Lowercase=- No}', "");
Expect(0, 120780, '\P{Lowercase=- No}', "");
Expect(1, 120780, '\P{^Lowercase=- No}', "");
Expect(0, 120779, '\p{Lowercase=- No}', "");
Expect(1, 120779, '\p{^Lowercase=- No}', "");
Expect(1, 120779, '\P{Lowercase=- No}', "");
Expect(0, 120779, '\P{^Lowercase=- No}', "");
Error('\p{Lower=/a/ N}');
Error('\P{Lower=/a/ N}');
Expect(1, 120780, '\p{Lower=n}', "");
Expect(0, 120780, '\p{^Lower=n}', "");
Expect(0, 120780, '\P{Lower=n}', "");
Expect(1, 120780, '\P{^Lower=n}', "");
Expect(0, 120779, '\p{Lower=n}', "");
Expect(1, 120779, '\p{^Lower=n}', "");
Expect(1, 120779, '\P{Lower=n}', "");
Expect(0, 120779, '\P{^Lower=n}', "");
Expect(1, 120780, '\p{Lower=--N}', "");
Expect(0, 120780, '\p{^Lower=--N}', "");
Expect(0, 120780, '\P{Lower=--N}', "");
Expect(1, 120780, '\P{^Lower=--N}', "");
Expect(0, 120779, '\p{Lower=--N}', "");
Expect(1, 120779, '\p{^Lower=--N}', "");
Expect(1, 120779, '\P{Lower=--N}', "");
Expect(0, 120779, '\P{^Lower=--N}', "");
Error('\p{Is_Lowercase: /a/  F}');
Error('\P{Is_Lowercase: /a/  F}');
Expect(1, 120780, '\p{Is_Lowercase=f}', "");
Expect(0, 120780, '\p{^Is_Lowercase=f}', "");
Expect(0, 120780, '\P{Is_Lowercase=f}', "");
Expect(1, 120780, '\P{^Is_Lowercase=f}', "");
Expect(0, 120779, '\p{Is_Lowercase=f}', "");
Expect(1, 120779, '\p{^Is_Lowercase=f}', "");
Expect(1, 120779, '\P{Is_Lowercase=f}', "");
Expect(0, 120779, '\P{^Is_Lowercase=f}', "");
Expect(1, 120780, '\p{Is_Lowercase=_ F}', "");
Expect(0, 120780, '\p{^Is_Lowercase=_ F}', "");
Expect(0, 120780, '\P{Is_Lowercase=_ F}', "");
Expect(1, 120780, '\P{^Is_Lowercase=_ F}', "");
Expect(0, 120779, '\p{Is_Lowercase=_ F}', "");
Expect(1, 120779, '\p{^Is_Lowercase=_ F}', "");
Expect(1, 120779, '\P{Is_Lowercase=_ F}', "");
Expect(0, 120779, '\P{^Is_Lowercase=_ F}', "");
Error('\p{Is_Lower=:= False}');
Error('\P{Is_Lower=:= False}');
Expect(1, 120780, '\p{Is_Lower=false}', "");
Expect(0, 120780, '\p{^Is_Lower=false}', "");
Expect(0, 120780, '\P{Is_Lower=false}', "");
Expect(1, 120780, '\P{^Is_Lower=false}', "");
Expect(0, 120779, '\p{Is_Lower=false}', "");
Expect(1, 120779, '\p{^Is_Lower=false}', "");
Expect(1, 120779, '\P{Is_Lower=false}', "");
Expect(0, 120779, '\P{^Is_Lower=false}', "");
Expect(1, 120780, '\p{Is_Lower=	-FALSE}', "");
Expect(0, 120780, '\p{^Is_Lower=	-FALSE}', "");
Expect(0, 120780, '\P{Is_Lower=	-FALSE}', "");
Expect(1, 120780, '\P{^Is_Lower=	-FALSE}', "");
Expect(0, 120779, '\p{Is_Lower=	-FALSE}', "");
Expect(1, 120779, '\p{^Is_Lower=	-FALSE}', "");
Expect(1, 120779, '\P{Is_Lower=	-FALSE}', "");
Expect(0, 120779, '\P{^Is_Lower=	-FALSE}', "");
Error('\p{Lowercase=_	Yes:=}');
Error('\P{Lowercase=_	Yes:=}');
Expect(1, 120779, '\p{Lowercase=yes}', "");
Expect(0, 120779, '\p{^Lowercase=yes}', "");
Expect(0, 120779, '\P{Lowercase=yes}', "");
Expect(1, 120779, '\P{^Lowercase=yes}', "");
Expect(0, 120780, '\p{Lowercase=yes}', "");
Expect(1, 120780, '\p{^Lowercase=yes}', "");
Expect(1, 120780, '\P{Lowercase=yes}', "");
Expect(0, 120780, '\P{^Lowercase=yes}', "");
Expect(1, 120779, '\p{Lowercase=__Yes}', "");
Expect(0, 120779, '\p{^Lowercase=__Yes}', "");
Expect(0, 120779, '\P{Lowercase=__Yes}', "");
Expect(1, 120779, '\P{^Lowercase=__Yes}', "");
Expect(0, 120780, '\p{Lowercase=__Yes}', "");
Expect(1, 120780, '\p{^Lowercase=__Yes}', "");
Expect(1, 120780, '\P{Lowercase=__Yes}', "");
Expect(0, 120780, '\P{^Lowercase=__Yes}', "");
Error('\p{Lower=_/a/Y}');
Error('\P{Lower=_/a/Y}');
Expect(1, 120779, '\p{Lower=y}', "");
Expect(0, 120779, '\p{^Lower=y}', "");
Expect(0, 120779, '\P{Lower=y}', "");
Expect(1, 120779, '\P{^Lower=y}', "");
Expect(0, 120780, '\p{Lower=y}', "");
Expect(1, 120780, '\p{^Lower=y}', "");
Expect(1, 120780, '\P{Lower=y}', "");
Expect(0, 120780, '\P{^Lower=y}', "");
Expect(1, 120779, '\p{Lower=-Y}', "");
Expect(0, 120779, '\p{^Lower=-Y}', "");
Expect(0, 120779, '\P{Lower=-Y}', "");
Expect(1, 120779, '\P{^Lower=-Y}', "");
Expect(0, 120780, '\p{Lower=-Y}', "");
Expect(1, 120780, '\p{^Lower=-Y}', "");
Expect(1, 120780, '\P{Lower=-Y}', "");
Expect(0, 120780, '\P{^Lower=-Y}', "");
Error('\p{Is_Lowercase=:=_	T}');
Error('\P{Is_Lowercase=:=_	T}');
Expect(1, 120779, '\p{Is_Lowercase=t}', "");
Expect(0, 120779, '\p{^Is_Lowercase=t}', "");
Expect(0, 120779, '\P{Is_Lowercase=t}', "");
Expect(1, 120779, '\P{^Is_Lowercase=t}', "");
Expect(0, 120780, '\p{Is_Lowercase=t}', "");
Expect(1, 120780, '\p{^Is_Lowercase=t}', "");
Expect(1, 120780, '\P{Is_Lowercase=t}', "");
Expect(0, 120780, '\P{^Is_Lowercase=t}', "");
Expect(1, 120779, '\p{Is_Lowercase=--t}', "");
Expect(0, 120779, '\p{^Is_Lowercase=--t}', "");
Expect(0, 120779, '\P{Is_Lowercase=--t}', "");
Expect(1, 120779, '\P{^Is_Lowercase=--t}', "");
Expect(0, 120780, '\p{Is_Lowercase=--t}', "");
Expect(1, 120780, '\p{^Is_Lowercase=--t}', "");
Expect(1, 120780, '\P{Is_Lowercase=--t}', "");
Expect(0, 120780, '\P{^Is_Lowercase=--t}', "");
Error('\p{Is_Lower=:=		true}');
Error('\P{Is_Lower=:=		true}');
Expect(1, 120779, '\p{Is_Lower=true}', "");
Expect(0, 120779, '\p{^Is_Lower=true}', "");
Expect(0, 120779, '\P{Is_Lower=true}', "");
Expect(1, 120779, '\P{^Is_Lower=true}', "");
Expect(0, 120780, '\p{Is_Lower=true}', "");
Expect(1, 120780, '\p{^Is_Lower=true}', "");
Expect(1, 120780, '\P{Is_Lower=true}', "");
Expect(0, 120780, '\P{^Is_Lower=true}', "");
Expect(1, 120779, '\p{Is_Lower=		TRUE}', "");
Expect(0, 120779, '\p{^Is_Lower=		TRUE}', "");
Expect(0, 120779, '\P{Is_Lower=		TRUE}', "");
Expect(1, 120779, '\P{^Is_Lower=		TRUE}', "");
Expect(0, 120780, '\p{Is_Lower=		TRUE}', "");
Expect(1, 120780, '\p{^Is_Lower=		TRUE}', "");
Expect(1, 120780, '\P{Is_Lower=		TRUE}', "");
Expect(0, 120780, '\P{^Is_Lower=		TRUE}', "");
Error('\p{Math=/a/	No}');
Error('\P{Math=/a/	No}');
Expect(1, 126706, '\p{Math=no}', "");
Expect(0, 126706, '\p{^Math=no}', "");
Expect(0, 126706, '\P{Math=no}', "");
Expect(1, 126706, '\P{^Math=no}', "");
Expect(0, 126705, '\p{Math=no}', "");
Expect(1, 126705, '\p{^Math=no}', "");
Expect(1, 126705, '\P{Math=no}', "");
Expect(0, 126705, '\P{^Math=no}', "");
Expect(1, 126706, '\p{Math= No}', "");
Expect(0, 126706, '\p{^Math= No}', "");
Expect(0, 126706, '\P{Math= No}', "");
Expect(1, 126706, '\P{^Math= No}', "");
Expect(0, 126705, '\p{Math= No}', "");
Expect(1, 126705, '\p{^Math= No}', "");
Expect(1, 126705, '\P{Math= No}', "");
Expect(0, 126705, '\P{^Math= No}', "");
Error('\p{Is_Math=	N:=}');
Error('\P{Is_Math=	N:=}');
Expect(1, 126706, '\p{Is_Math=n}', "");
Expect(0, 126706, '\p{^Is_Math=n}', "");
Expect(0, 126706, '\P{Is_Math=n}', "");
Expect(1, 126706, '\P{^Is_Math=n}', "");
Expect(0, 126705, '\p{Is_Math=n}', "");
Expect(1, 126705, '\p{^Is_Math=n}', "");
Expect(1, 126705, '\P{Is_Math=n}', "");
Expect(0, 126705, '\P{^Is_Math=n}', "");
Expect(1, 126706, '\p{Is_Math=- N}', "");
Expect(0, 126706, '\p{^Is_Math=- N}', "");
Expect(0, 126706, '\P{Is_Math=- N}', "");
Expect(1, 126706, '\P{^Is_Math=- N}', "");
Expect(0, 126705, '\p{Is_Math=- N}', "");
Expect(1, 126705, '\p{^Is_Math=- N}', "");
Expect(1, 126705, '\P{Is_Math=- N}', "");
Expect(0, 126705, '\P{^Is_Math=- N}', "");
Error('\p{Math=	/a/F}');
Error('\P{Math=	/a/F}');
Expect(1, 126706, '\p{Math=f}', "");
Expect(0, 126706, '\p{^Math=f}', "");
Expect(0, 126706, '\P{Math=f}', "");
Expect(1, 126706, '\P{^Math=f}', "");
Expect(0, 126705, '\p{Math=f}', "");
Expect(1, 126705, '\p{^Math=f}', "");
Expect(1, 126705, '\P{Math=f}', "");
Expect(0, 126705, '\P{^Math=f}', "");
Expect(1, 126706, '\p{Math=_ F}', "");
Expect(0, 126706, '\p{^Math=_ F}', "");
Expect(0, 126706, '\P{Math=_ F}', "");
Expect(1, 126706, '\P{^Math=_ F}', "");
Expect(0, 126705, '\p{Math=_ F}', "");
Expect(1, 126705, '\p{^Math=_ F}', "");
Expect(1, 126705, '\P{Math=_ F}', "");
Expect(0, 126705, '\P{^Math=_ F}', "");
Error('\p{Is_Math=_ false/a/}');
Error('\P{Is_Math=_ false/a/}');
Expect(1, 126706, '\p{Is_Math=false}', "");
Expect(0, 126706, '\p{^Is_Math=false}', "");
Expect(0, 126706, '\P{Is_Math=false}', "");
Expect(1, 126706, '\P{^Is_Math=false}', "");
Expect(0, 126705, '\p{Is_Math=false}', "");
Expect(1, 126705, '\p{^Is_Math=false}', "");
Expect(1, 126705, '\P{Is_Math=false}', "");
Expect(0, 126705, '\P{^Is_Math=false}', "");
Expect(1, 126706, '\p{Is_Math=-_False}', "");
Expect(0, 126706, '\p{^Is_Math=-_False}', "");
Expect(0, 126706, '\P{Is_Math=-_False}', "");
Expect(1, 126706, '\P{^Is_Math=-_False}', "");
Expect(0, 126705, '\p{Is_Math=-_False}', "");
Expect(1, 126705, '\p{^Is_Math=-_False}', "");
Expect(1, 126705, '\P{Is_Math=-_False}', "");
Expect(0, 126705, '\P{^Is_Math=-_False}', "");
Error('\p{Math=/a/ _Yes}');
Error('\P{Math=/a/ _Yes}');
Expect(1, 126705, '\p{Math=yes}', "");
Expect(0, 126705, '\p{^Math=yes}', "");
Expect(0, 126705, '\P{Math=yes}', "");
Expect(1, 126705, '\P{^Math=yes}', "");
Expect(0, 126706, '\p{Math=yes}', "");
Expect(1, 126706, '\p{^Math=yes}', "");
Expect(1, 126706, '\P{Math=yes}', "");
Expect(0, 126706, '\P{^Math=yes}', "");
Expect(1, 126705, '\p{Math=	Yes}', "");
Expect(0, 126705, '\p{^Math=	Yes}', "");
Expect(0, 126705, '\P{Math=	Yes}', "");
Expect(1, 126705, '\P{^Math=	Yes}', "");
Expect(0, 126706, '\p{Math=	Yes}', "");
Expect(1, 126706, '\p{^Math=	Yes}', "");
Expect(1, 126706, '\P{Math=	Yes}', "");
Expect(0, 126706, '\P{^Math=	Yes}', "");
Error('\p{Is_Math=:=--Y}');
Error('\P{Is_Math=:=--Y}');
Expect(1, 126705, '\p{Is_Math:   y}', "");
Expect(0, 126705, '\p{^Is_Math:   y}', "");
Expect(0, 126705, '\P{Is_Math:   y}', "");
Expect(1, 126705, '\P{^Is_Math:   y}', "");
Expect(0, 126706, '\p{Is_Math:   y}', "");
Expect(1, 126706, '\p{^Is_Math:   y}', "");
Expect(1, 126706, '\P{Is_Math:   y}', "");
Expect(0, 126706, '\P{^Is_Math:   y}', "");
Expect(1, 126705, '\p{Is_Math=	 Y}', "");
Expect(0, 126705, '\p{^Is_Math=	 Y}', "");
Expect(0, 126705, '\P{Is_Math=	 Y}', "");
Expect(1, 126705, '\P{^Is_Math=	 Y}', "");
Expect(0, 126706, '\p{Is_Math=	 Y}', "");
Expect(1, 126706, '\p{^Is_Math=	 Y}', "");
Expect(1, 126706, '\P{Is_Math=	 Y}', "");
Expect(0, 126706, '\P{^Is_Math=	 Y}', "");
Error('\p{Math=:= 	T}');
Error('\P{Math=:= 	T}');
Expect(1, 126705, '\p{Math=t}', "");
Expect(0, 126705, '\p{^Math=t}', "");
Expect(0, 126705, '\P{Math=t}', "");
Expect(1, 126705, '\P{^Math=t}', "");
Expect(0, 126706, '\p{Math=t}', "");
Expect(1, 126706, '\p{^Math=t}', "");
Expect(1, 126706, '\P{Math=t}', "");
Expect(0, 126706, '\P{^Math=t}', "");
Expect(1, 126705, '\p{Math=  T}', "");
Expect(0, 126705, '\p{^Math=  T}', "");
Expect(0, 126705, '\P{Math=  T}', "");
Expect(1, 126705, '\P{^Math=  T}', "");
Expect(0, 126706, '\p{Math=  T}', "");
Expect(1, 126706, '\p{^Math=  T}', "");
Expect(1, 126706, '\P{Math=  T}', "");
Expect(0, 126706, '\P{^Math=  T}', "");
Error('\p{Is_Math=	_True:=}');
Error('\P{Is_Math=	_True:=}');
Expect(1, 126705, '\p{Is_Math=true}', "");
Expect(0, 126705, '\p{^Is_Math=true}', "");
Expect(0, 126705, '\P{Is_Math=true}', "");
Expect(1, 126705, '\P{^Is_Math=true}', "");
Expect(0, 126706, '\p{Is_Math=true}', "");
Expect(1, 126706, '\p{^Is_Math=true}', "");
Expect(1, 126706, '\P{Is_Math=true}', "");
Expect(0, 126706, '\P{^Is_Math=true}', "");
Expect(1, 126705, '\p{Is_Math:	  True}', "");
Expect(0, 126705, '\p{^Is_Math:	  True}', "");
Expect(0, 126705, '\P{Is_Math:	  True}', "");
Expect(1, 126705, '\P{^Is_Math:	  True}', "");
Expect(0, 126706, '\p{Is_Math:	  True}', "");
Expect(1, 126706, '\p{^Is_Math:	  True}', "");
Expect(1, 126706, '\P{Is_Math:	  True}', "");
Expect(0, 126706, '\P{^Is_Math:	  True}', "");
Error('\p{Noncharacter_Code_Point=:=--No}');
Error('\P{Noncharacter_Code_Point=:=--No}');
Expect(1, 1114109, '\p{Noncharacter_Code_Point=no}', "");
Expect(0, 1114109, '\p{^Noncharacter_Code_Point=no}', "");
Expect(0, 1114109, '\P{Noncharacter_Code_Point=no}', "");
Expect(1, 1114109, '\P{^Noncharacter_Code_Point=no}', "");
Expect(0, 1114111, '\p{Noncharacter_Code_Point=no}', "");
Expect(1, 1114111, '\p{^Noncharacter_Code_Point=no}', "");
Expect(1, 1114111, '\P{Noncharacter_Code_Point=no}', "");
Expect(0, 1114111, '\P{^Noncharacter_Code_Point=no}', "");
Expect(1, 1114109, '\p{Noncharacter_Code_Point=_No}', "");
Expect(0, 1114109, '\p{^Noncharacter_Code_Point=_No}', "");
Expect(0, 1114109, '\P{Noncharacter_Code_Point=_No}', "");
Expect(1, 1114109, '\P{^Noncharacter_Code_Point=_No}', "");
Expect(0, 1114111, '\p{Noncharacter_Code_Point=_No}', "");
Expect(1, 1114111, '\p{^Noncharacter_Code_Point=_No}', "");
Expect(1, 1114111, '\P{Noncharacter_Code_Point=_No}', "");
Expect(0, 1114111, '\P{^Noncharacter_Code_Point=_No}', "");
Error('\p{NChar=_:=N}');
Error('\P{NChar=_:=N}');
Expect(1, 1114109, '\p{NChar=n}', "");
Expect(0, 1114109, '\p{^NChar=n}', "");
Expect(0, 1114109, '\P{NChar=n}', "");
Expect(1, 1114109, '\P{^NChar=n}', "");
Expect(0, 1114111, '\p{NChar=n}', "");
Expect(1, 1114111, '\p{^NChar=n}', "");
Expect(1, 1114111, '\P{NChar=n}', "");
Expect(0, 1114111, '\P{^NChar=n}', "");
Expect(1, 1114109, '\p{NChar=_ N}', "");
Expect(0, 1114109, '\p{^NChar=_ N}', "");
Expect(0, 1114109, '\P{NChar=_ N}', "");
Expect(1, 1114109, '\P{^NChar=_ N}', "");
Expect(0, 1114111, '\p{NChar=_ N}', "");
Expect(1, 1114111, '\p{^NChar=_ N}', "");
Expect(1, 1114111, '\P{NChar=_ N}', "");
Expect(0, 1114111, '\P{^NChar=_ N}', "");
Error('\p{Is_Noncharacter_Code_Point= /a/F}');
Error('\P{Is_Noncharacter_Code_Point= /a/F}');
Expect(1, 1114109, '\p{Is_Noncharacter_Code_Point=f}', "");
Expect(0, 1114109, '\p{^Is_Noncharacter_Code_Point=f}', "");
Expect(0, 1114109, '\P{Is_Noncharacter_Code_Point=f}', "");
Expect(1, 1114109, '\P{^Is_Noncharacter_Code_Point=f}', "");
Expect(0, 1114111, '\p{Is_Noncharacter_Code_Point=f}', "");
Expect(1, 1114111, '\p{^Is_Noncharacter_Code_Point=f}', "");
Expect(1, 1114111, '\P{Is_Noncharacter_Code_Point=f}', "");
Expect(0, 1114111, '\P{^Is_Noncharacter_Code_Point=f}', "");
Expect(1, 1114109, '\p{Is_Noncharacter_Code_Point=-_F}', "");
Expect(0, 1114109, '\p{^Is_Noncharacter_Code_Point=-_F}', "");
Expect(0, 1114109, '\P{Is_Noncharacter_Code_Point=-_F}', "");
Expect(1, 1114109, '\P{^Is_Noncharacter_Code_Point=-_F}', "");
Expect(0, 1114111, '\p{Is_Noncharacter_Code_Point=-_F}', "");
Expect(1, 1114111, '\p{^Is_Noncharacter_Code_Point=-_F}', "");
Expect(1, 1114111, '\P{Is_Noncharacter_Code_Point=-_F}', "");
Expect(0, 1114111, '\P{^Is_Noncharacter_Code_Point=-_F}', "");
Error('\p{Is_NChar=/a/-	False}');
Error('\P{Is_NChar=/a/-	False}');
Expect(1, 1114109, '\p{Is_NChar=false}', "");
Expect(0, 1114109, '\p{^Is_NChar=false}', "");
Expect(0, 1114109, '\P{Is_NChar=false}', "");
Expect(1, 1114109, '\P{^Is_NChar=false}', "");
Expect(0, 1114111, '\p{Is_NChar=false}', "");
Expect(1, 1114111, '\p{^Is_NChar=false}', "");
Expect(1, 1114111, '\P{Is_NChar=false}', "");
Expect(0, 1114111, '\P{^Is_NChar=false}', "");
Expect(1, 1114109, '\p{Is_NChar=__False}', "");
Expect(0, 1114109, '\p{^Is_NChar=__False}', "");
Expect(0, 1114109, '\P{Is_NChar=__False}', "");
Expect(1, 1114109, '\P{^Is_NChar=__False}', "");
Expect(0, 1114111, '\p{Is_NChar=__False}', "");
Expect(1, 1114111, '\p{^Is_NChar=__False}', "");
Expect(1, 1114111, '\P{Is_NChar=__False}', "");
Expect(0, 1114111, '\P{^Is_NChar=__False}', "");
Error('\p{Noncharacter_Code_Point=_yes:=}');
Error('\P{Noncharacter_Code_Point=_yes:=}');
Expect(1, 1114111, '\p{Noncharacter_Code_Point=yes}', "");
Expect(0, 1114111, '\p{^Noncharacter_Code_Point=yes}', "");
Expect(0, 1114111, '\P{Noncharacter_Code_Point=yes}', "");
Expect(1, 1114111, '\P{^Noncharacter_Code_Point=yes}', "");
Expect(0, 1114109, '\p{Noncharacter_Code_Point=yes}', "");
Expect(1, 1114109, '\p{^Noncharacter_Code_Point=yes}', "");
Expect(1, 1114109, '\P{Noncharacter_Code_Point=yes}', "");
Expect(0, 1114109, '\P{^Noncharacter_Code_Point=yes}', "");
Expect(1, 1114111, '\p{Noncharacter_Code_Point=  Yes}', "");
Expect(0, 1114111, '\p{^Noncharacter_Code_Point=  Yes}', "");
Expect(0, 1114111, '\P{Noncharacter_Code_Point=  Yes}', "");
Expect(1, 1114111, '\P{^Noncharacter_Code_Point=  Yes}', "");
Expect(0, 1114109, '\p{Noncharacter_Code_Point=  Yes}', "");
Expect(1, 1114109, '\p{^Noncharacter_Code_Point=  Yes}', "");
Expect(1, 1114109, '\P{Noncharacter_Code_Point=  Yes}', "");
Expect(0, 1114109, '\P{^Noncharacter_Code_Point=  Yes}', "");
Error('\p{NChar=-	Y:=}');
Error('\P{NChar=-	Y:=}');
Expect(1, 1114111, '\p{NChar=y}', "");
Expect(0, 1114111, '\p{^NChar=y}', "");
Expect(0, 1114111, '\P{NChar=y}', "");
Expect(1, 1114111, '\P{^NChar=y}', "");
Expect(0, 1114109, '\p{NChar=y}', "");
Expect(1, 1114109, '\p{^NChar=y}', "");
Expect(1, 1114109, '\P{NChar=y}', "");
Expect(0, 1114109, '\P{^NChar=y}', "");
Expect(1, 1114111, '\p{NChar=- y}', "");
Expect(0, 1114111, '\p{^NChar=- y}', "");
Expect(0, 1114111, '\P{NChar=- y}', "");
Expect(1, 1114111, '\P{^NChar=- y}', "");
Expect(0, 1114109, '\p{NChar=- y}', "");
Expect(1, 1114109, '\p{^NChar=- y}', "");
Expect(1, 1114109, '\P{NChar=- y}', "");
Expect(0, 1114109, '\P{^NChar=- y}', "");
Error('\p{Is_Noncharacter_Code_Point=_ t/a/}');
Error('\P{Is_Noncharacter_Code_Point=_ t/a/}');
Expect(1, 1114111, '\p{Is_Noncharacter_Code_Point=t}', "");
Expect(0, 1114111, '\p{^Is_Noncharacter_Code_Point=t}', "");
Expect(0, 1114111, '\P{Is_Noncharacter_Code_Point=t}', "");
Expect(1, 1114111, '\P{^Is_Noncharacter_Code_Point=t}', "");
Expect(0, 1114109, '\p{Is_Noncharacter_Code_Point=t}', "");
Expect(1, 1114109, '\p{^Is_Noncharacter_Code_Point=t}', "");
Expect(1, 1114109, '\P{Is_Noncharacter_Code_Point=t}', "");
Expect(0, 1114109, '\P{^Is_Noncharacter_Code_Point=t}', "");
Expect(1, 1114111, '\p{Is_Noncharacter_Code_Point:   		T}', "");
Expect(0, 1114111, '\p{^Is_Noncharacter_Code_Point:   		T}', "");
Expect(0, 1114111, '\P{Is_Noncharacter_Code_Point:   		T}', "");
Expect(1, 1114111, '\P{^Is_Noncharacter_Code_Point:   		T}', "");
Expect(0, 1114109, '\p{Is_Noncharacter_Code_Point:   		T}', "");
Expect(1, 1114109, '\p{^Is_Noncharacter_Code_Point:   		T}', "");
Expect(1, 1114109, '\P{Is_Noncharacter_Code_Point:   		T}', "");
Expect(0, 1114109, '\P{^Is_Noncharacter_Code_Point:   		T}', "");
Error('\p{Is_NChar:/a/-_TRUE}');
Error('\P{Is_NChar:/a/-_TRUE}');
Expect(1, 1114111, '\p{Is_NChar=true}', "");
Expect(0, 1114111, '\p{^Is_NChar=true}', "");
Expect(0, 1114111, '\P{Is_NChar=true}', "");
Expect(1, 1114111, '\P{^Is_NChar=true}', "");
Expect(0, 1114109, '\p{Is_NChar=true}', "");
Expect(1, 1114109, '\p{^Is_NChar=true}', "");
Expect(1, 1114109, '\P{Is_NChar=true}', "");
Expect(0, 1114109, '\P{^Is_NChar=true}', "");
Expect(1, 1114111, '\p{Is_NChar=_ True}', "");
Expect(0, 1114111, '\p{^Is_NChar=_ True}', "");
Expect(0, 1114111, '\P{Is_NChar=_ True}', "");
Expect(1, 1114111, '\P{^Is_NChar=_ True}', "");
Expect(0, 1114109, '\p{Is_NChar=_ True}', "");
Expect(1, 1114109, '\p{^Is_NChar=_ True}', "");
Expect(1, 1114109, '\P{Is_NChar=_ True}', "");
Expect(0, 1114109, '\P{^Is_NChar=_ True}', "");
Error('\p{NFC_Quick_Check= /a/Maybe}');
Error('\P{NFC_Quick_Check= /a/Maybe}');
Expect(1, 69927, '\p{NFC_Quick_Check=maybe}', "");
Expect(0, 69927, '\p{^NFC_Quick_Check=maybe}', "");
Expect(0, 69927, '\P{NFC_Quick_Check=maybe}', "");
Expect(1, 69927, '\P{^NFC_Quick_Check=maybe}', "");
Expect(0, 69928, '\p{NFC_Quick_Check=maybe}', "");
Expect(1, 69928, '\p{^NFC_Quick_Check=maybe}', "");
Expect(1, 69928, '\P{NFC_Quick_Check=maybe}', "");
Expect(0, 69928, '\P{^NFC_Quick_Check=maybe}', "");
Expect(1, 69927, '\p{NFC_Quick_Check=  MAYBE}', "");
Expect(0, 69927, '\p{^NFC_Quick_Check=  MAYBE}', "");
Expect(0, 69927, '\P{NFC_Quick_Check=  MAYBE}', "");
Expect(1, 69927, '\P{^NFC_Quick_Check=  MAYBE}', "");
Expect(0, 69928, '\p{NFC_Quick_Check=  MAYBE}', "");
Expect(1, 69928, '\p{^NFC_Quick_Check=  MAYBE}', "");
Expect(1, 69928, '\P{NFC_Quick_Check=  MAYBE}', "");
Expect(0, 69928, '\P{^NFC_Quick_Check=  MAYBE}', "");
Error('\p{NFC_QC=/a/ M}');
Error('\P{NFC_QC=/a/ M}');
Expect(1, 69927, '\p{NFC_QC=m}', "");
Expect(0, 69927, '\p{^NFC_QC=m}', "");
Expect(0, 69927, '\P{NFC_QC=m}', "");
Expect(1, 69927, '\P{^NFC_QC=m}', "");
Expect(0, 69928, '\p{NFC_QC=m}', "");
Expect(1, 69928, '\p{^NFC_QC=m}', "");
Expect(1, 69928, '\P{NFC_QC=m}', "");
Expect(0, 69928, '\P{^NFC_QC=m}', "");
Expect(1, 69927, '\p{NFC_QC=		M}', "");
Expect(0, 69927, '\p{^NFC_QC=		M}', "");
Expect(0, 69927, '\P{NFC_QC=		M}', "");
Expect(1, 69927, '\P{^NFC_QC=		M}', "");
Expect(0, 69928, '\p{NFC_QC=		M}', "");
Expect(1, 69928, '\p{^NFC_QC=		M}', "");
Expect(1, 69928, '\P{NFC_QC=		M}', "");
Expect(0, 69928, '\P{^NFC_QC=		M}', "");
Error('\p{Is_NFC_Quick_Check=	Maybe/a/}');
Error('\P{Is_NFC_Quick_Check=	Maybe/a/}');
Expect(1, 69927, '\p{Is_NFC_Quick_Check=maybe}', "");
Expect(0, 69927, '\p{^Is_NFC_Quick_Check=maybe}', "");
Expect(0, 69927, '\P{Is_NFC_Quick_Check=maybe}', "");
Expect(1, 69927, '\P{^Is_NFC_Quick_Check=maybe}', "");
Expect(0, 69928, '\p{Is_NFC_Quick_Check=maybe}', "");
Expect(1, 69928, '\p{^Is_NFC_Quick_Check=maybe}', "");
Expect(1, 69928, '\P{Is_NFC_Quick_Check=maybe}', "");
Expect(0, 69928, '\P{^Is_NFC_Quick_Check=maybe}', "");
Expect(1, 69927, '\p{Is_NFC_Quick_Check= maybe}', "");
Expect(0, 69927, '\p{^Is_NFC_Quick_Check= maybe}', "");
Expect(0, 69927, '\P{Is_NFC_Quick_Check= maybe}', "");
Expect(1, 69927, '\P{^Is_NFC_Quick_Check= maybe}', "");
Expect(0, 69928, '\p{Is_NFC_Quick_Check= maybe}', "");
Expect(1, 69928, '\p{^Is_NFC_Quick_Check= maybe}', "");
Expect(1, 69928, '\P{Is_NFC_Quick_Check= maybe}', "");
Expect(0, 69928, '\P{^Is_NFC_Quick_Check= maybe}', "");
Error('\p{Is_NFC_QC= /a/M}');
Error('\P{Is_NFC_QC= /a/M}');
Expect(1, 69927, '\p{Is_NFC_QC=m}', "");
Expect(0, 69927, '\p{^Is_NFC_QC=m}', "");
Expect(0, 69927, '\P{Is_NFC_QC=m}', "");
Expect(1, 69927, '\P{^Is_NFC_QC=m}', "");
Expect(0, 69928, '\p{Is_NFC_QC=m}', "");
Expect(1, 69928, '\p{^Is_NFC_QC=m}', "");
Expect(1, 69928, '\P{Is_NFC_QC=m}', "");
Expect(0, 69928, '\P{^Is_NFC_QC=m}', "");
Expect(1, 69927, '\p{Is_NFC_QC=M}', "");
Expect(0, 69927, '\p{^Is_NFC_QC=M}', "");
Expect(0, 69927, '\P{Is_NFC_QC=M}', "");
Expect(1, 69927, '\P{^Is_NFC_QC=M}', "");
Expect(0, 69928, '\p{Is_NFC_QC=M}', "");
Expect(1, 69928, '\p{^Is_NFC_QC=M}', "");
Expect(1, 69928, '\P{Is_NFC_QC=M}', "");
Expect(0, 69928, '\P{^Is_NFC_QC=M}', "");
Error('\p{NFC_Quick_Check=:=No}');
Error('\P{NFC_Quick_Check=:=No}');
Expect(1, 195101, '\p{NFC_Quick_Check=no}', "");
Expect(0, 195101, '\p{^NFC_Quick_Check=no}', "");
Expect(0, 195101, '\P{NFC_Quick_Check=no}', "");
Expect(1, 195101, '\P{^NFC_Quick_Check=no}', "");
Expect(0, 195102, '\p{NFC_Quick_Check=no}', "");
Expect(1, 195102, '\p{^NFC_Quick_Check=no}', "");
Expect(1, 195102, '\P{NFC_Quick_Check=no}', "");
Expect(0, 195102, '\P{^NFC_Quick_Check=no}', "");
Expect(1, 195101, '\p{NFC_Quick_Check=	_NO}', "");
Expect(0, 195101, '\p{^NFC_Quick_Check=	_NO}', "");
Expect(0, 195101, '\P{NFC_Quick_Check=	_NO}', "");
Expect(1, 195101, '\P{^NFC_Quick_Check=	_NO}', "");
Expect(0, 195102, '\p{NFC_Quick_Check=	_NO}', "");
Expect(1, 195102, '\p{^NFC_Quick_Check=	_NO}', "");
Expect(1, 195102, '\P{NFC_Quick_Check=	_NO}', "");
Expect(0, 195102, '\P{^NFC_Quick_Check=	_NO}', "");
Error('\p{NFC_QC=/a/  N}');
Error('\P{NFC_QC=/a/  N}');
Expect(1, 195101, '\p{NFC_QC:n}', "");
Expect(0, 195101, '\p{^NFC_QC:n}', "");
Expect(0, 195101, '\P{NFC_QC:n}', "");
Expect(1, 195101, '\P{^NFC_QC:n}', "");
Expect(0, 195102, '\p{NFC_QC:n}', "");
Expect(1, 195102, '\p{^NFC_QC:n}', "");
Expect(1, 195102, '\P{NFC_QC:n}', "");
Expect(0, 195102, '\P{^NFC_QC:n}', "");
Expect(1, 195101, '\p{NFC_QC=_N}', "");
Expect(0, 195101, '\p{^NFC_QC=_N}', "");
Expect(0, 195101, '\P{NFC_QC=_N}', "");
Expect(1, 195101, '\P{^NFC_QC=_N}', "");
Expect(0, 195102, '\p{NFC_QC=_N}', "");
Expect(1, 195102, '\p{^NFC_QC=_N}', "");
Expect(1, 195102, '\P{NFC_QC=_N}', "");
Expect(0, 195102, '\P{^NFC_QC=_N}', "");
Error('\p{Is_NFC_Quick_Check= :=No}');
Error('\P{Is_NFC_Quick_Check= :=No}');
Expect(1, 195101, '\p{Is_NFC_Quick_Check=no}', "");
Expect(0, 195101, '\p{^Is_NFC_Quick_Check=no}', "");
Expect(0, 195101, '\P{Is_NFC_Quick_Check=no}', "");
Expect(1, 195101, '\P{^Is_NFC_Quick_Check=no}', "");
Expect(0, 195102, '\p{Is_NFC_Quick_Check=no}', "");
Expect(1, 195102, '\p{^Is_NFC_Quick_Check=no}', "");
Expect(1, 195102, '\P{Is_NFC_Quick_Check=no}', "");
Expect(0, 195102, '\P{^Is_NFC_Quick_Check=no}', "");
Expect(1, 195101, '\p{Is_NFC_Quick_Check: _ NO}', "");
Expect(0, 195101, '\p{^Is_NFC_Quick_Check: _ NO}', "");
Expect(0, 195101, '\P{Is_NFC_Quick_Check: _ NO}', "");
Expect(1, 195101, '\P{^Is_NFC_Quick_Check: _ NO}', "");
Expect(0, 195102, '\p{Is_NFC_Quick_Check: _ NO}', "");
Expect(1, 195102, '\p{^Is_NFC_Quick_Check: _ NO}', "");
Expect(1, 195102, '\P{Is_NFC_Quick_Check: _ NO}', "");
Expect(0, 195102, '\P{^Is_NFC_Quick_Check: _ NO}', "");
Error('\p{Is_NFC_QC= N:=}');
Error('\P{Is_NFC_QC= N:=}');
Expect(1, 195101, '\p{Is_NFC_QC=n}', "");
Expect(0, 195101, '\p{^Is_NFC_QC=n}', "");
Expect(0, 195101, '\P{Is_NFC_QC=n}', "");
Expect(1, 195101, '\P{^Is_NFC_QC=n}', "");
Expect(0, 195102, '\p{Is_NFC_QC=n}', "");
Expect(1, 195102, '\p{^Is_NFC_QC=n}', "");
Expect(1, 195102, '\P{Is_NFC_QC=n}', "");
Expect(0, 195102, '\P{^Is_NFC_QC=n}', "");
Expect(1, 195101, '\p{Is_NFC_QC=-N}', "");
Expect(0, 195101, '\p{^Is_NFC_QC=-N}', "");
Expect(0, 195101, '\P{Is_NFC_QC=-N}', "");
Expect(1, 195101, '\P{^Is_NFC_QC=-N}', "");
Expect(0, 195102, '\p{Is_NFC_QC=-N}', "");
Expect(1, 195102, '\p{^Is_NFC_QC=-N}', "");
Expect(1, 195102, '\P{Is_NFC_QC=-N}', "");
Expect(0, 195102, '\P{^Is_NFC_QC=-N}', "");
Error('\p{NFC_Quick_Check=/a/-	yes}');
Error('\P{NFC_Quick_Check=/a/-	yes}');
Expect(1, 195102, '\p{NFC_Quick_Check=yes}', "");
Expect(0, 195102, '\p{^NFC_Quick_Check=yes}', "");
Expect(0, 195102, '\P{NFC_Quick_Check=yes}', "");
Expect(1, 195102, '\P{^NFC_Quick_Check=yes}', "");
Expect(0, 195101, '\p{NFC_Quick_Check=yes}', "");
Expect(1, 195101, '\p{^NFC_Quick_Check=yes}', "");
Expect(1, 195101, '\P{NFC_Quick_Check=yes}', "");
Expect(0, 195101, '\P{^NFC_Quick_Check=yes}', "");
Expect(1, 195102, '\p{NFC_Quick_Check=--yes}', "");
Expect(0, 195102, '\p{^NFC_Quick_Check=--yes}', "");
Expect(0, 195102, '\P{NFC_Quick_Check=--yes}', "");
Expect(1, 195102, '\P{^NFC_Quick_Check=--yes}', "");
Expect(0, 195101, '\p{NFC_Quick_Check=--yes}', "");
Expect(1, 195101, '\p{^NFC_Quick_Check=--yes}', "");
Expect(1, 195101, '\P{NFC_Quick_Check=--yes}', "");
Expect(0, 195101, '\P{^NFC_Quick_Check=--yes}', "");
Error('\p{NFC_QC=- y/a/}');
Error('\P{NFC_QC=- y/a/}');
Expect(1, 195102, '\p{NFC_QC: y}', "");
Expect(0, 195102, '\p{^NFC_QC: y}', "");
Expect(0, 195102, '\P{NFC_QC: y}', "");
Expect(1, 195102, '\P{^NFC_QC: y}', "");
Expect(0, 195101, '\p{NFC_QC: y}', "");
Expect(1, 195101, '\p{^NFC_QC: y}', "");
Expect(1, 195101, '\P{NFC_QC: y}', "");
Expect(0, 195101, '\P{^NFC_QC: y}', "");
Expect(1, 195102, '\p{NFC_QC=_Y}', "");
Expect(0, 195102, '\p{^NFC_QC=_Y}', "");
Expect(0, 195102, '\P{NFC_QC=_Y}', "");
Expect(1, 195102, '\P{^NFC_QC=_Y}', "");
Expect(0, 195101, '\p{NFC_QC=_Y}', "");
Expect(1, 195101, '\p{^NFC_QC=_Y}', "");
Expect(1, 195101, '\P{NFC_QC=_Y}', "");
Expect(0, 195101, '\P{^NFC_QC=_Y}', "");
Error('\p{Is_NFC_Quick_Check=	-Yes/a/}');
Error('\P{Is_NFC_Quick_Check=	-Yes/a/}');
Expect(1, 195102, '\p{Is_NFC_Quick_Check=yes}', "");
Expect(0, 195102, '\p{^Is_NFC_Quick_Check=yes}', "");
Expect(0, 195102, '\P{Is_NFC_Quick_Check=yes}', "");
Expect(1, 195102, '\P{^Is_NFC_Quick_Check=yes}', "");
Expect(0, 195101, '\p{Is_NFC_Quick_Check=yes}', "");
Expect(1, 195101, '\p{^Is_NFC_Quick_Check=yes}', "");
Expect(1, 195101, '\P{Is_NFC_Quick_Check=yes}', "");
Expect(0, 195101, '\P{^Is_NFC_Quick_Check=yes}', "");
Expect(1, 195102, '\p{Is_NFC_Quick_Check= -Yes}', "");
Expect(0, 195102, '\p{^Is_NFC_Quick_Check= -Yes}', "");
Expect(0, 195102, '\P{Is_NFC_Quick_Check= -Yes}', "");
Expect(1, 195102, '\P{^Is_NFC_Quick_Check= -Yes}', "");
Expect(0, 195101, '\p{Is_NFC_Quick_Check= -Yes}', "");
Expect(1, 195101, '\p{^Is_NFC_Quick_Check= -Yes}', "");
Expect(1, 195101, '\P{Is_NFC_Quick_Check= -Yes}', "");
Expect(0, 195101, '\P{^Is_NFC_Quick_Check= -Yes}', "");
Error('\p{Is_NFC_QC=	/a/Y}');
Error('\P{Is_NFC_QC=	/a/Y}');
Expect(1, 195102, '\p{Is_NFC_QC=y}', "");
Expect(0, 195102, '\p{^Is_NFC_QC=y}', "");
Expect(0, 195102, '\P{Is_NFC_QC=y}', "");
Expect(1, 195102, '\P{^Is_NFC_QC=y}', "");
Expect(0, 195101, '\p{Is_NFC_QC=y}', "");
Expect(1, 195101, '\p{^Is_NFC_QC=y}', "");
Expect(1, 195101, '\P{Is_NFC_QC=y}', "");
Expect(0, 195101, '\P{^Is_NFC_QC=y}', "");
Expect(1, 195102, '\p{Is_NFC_QC=-Y}', "");
Expect(0, 195102, '\p{^Is_NFC_QC=-Y}', "");
Expect(0, 195102, '\P{Is_NFC_QC=-Y}', "");
Expect(1, 195102, '\P{^Is_NFC_QC=-Y}', "");
Expect(0, 195101, '\p{Is_NFC_QC=-Y}', "");
Expect(1, 195101, '\p{^Is_NFC_QC=-Y}', "");
Expect(1, 195101, '\P{Is_NFC_QC=-Y}', "");
Expect(0, 195101, '\P{^Is_NFC_QC=-Y}', "");
Error('\p{NFD_Quick_Check=_ NO/a/}');
Error('\P{NFD_Quick_Check=_ NO/a/}');
Expect(1, 195101, '\p{NFD_Quick_Check=no}', "");
Expect(0, 195101, '\p{^NFD_Quick_Check=no}', "");
Expect(0, 195101, '\P{NFD_Quick_Check=no}', "");
Expect(1, 195101, '\P{^NFD_Quick_Check=no}', "");
Expect(0, 195102, '\p{NFD_Quick_Check=no}', "");
Expect(1, 195102, '\p{^NFD_Quick_Check=no}', "");
Expect(1, 195102, '\P{NFD_Quick_Check=no}', "");
Expect(0, 195102, '\P{^NFD_Quick_Check=no}', "");
Expect(1, 195101, '\p{NFD_Quick_Check= No}', "");
Expect(0, 195101, '\p{^NFD_Quick_Check= No}', "");
Expect(0, 195101, '\P{NFD_Quick_Check= No}', "");
Expect(1, 195101, '\P{^NFD_Quick_Check= No}', "");
Expect(0, 195102, '\p{NFD_Quick_Check= No}', "");
Expect(1, 195102, '\p{^NFD_Quick_Check= No}', "");
Expect(1, 195102, '\P{NFD_Quick_Check= No}', "");
Expect(0, 195102, '\P{^NFD_Quick_Check= No}', "");
Error('\p{NFD_QC:   	-N/a/}');
Error('\P{NFD_QC:   	-N/a/}');
Expect(1, 195101, '\p{NFD_QC=n}', "");
Expect(0, 195101, '\p{^NFD_QC=n}', "");
Expect(0, 195101, '\P{NFD_QC=n}', "");
Expect(1, 195101, '\P{^NFD_QC=n}', "");
Expect(0, 195102, '\p{NFD_QC=n}', "");
Expect(1, 195102, '\p{^NFD_QC=n}', "");
Expect(1, 195102, '\P{NFD_QC=n}', "");
Expect(0, 195102, '\P{^NFD_QC=n}', "");
Expect(1, 195101, '\p{NFD_QC=_	N}', "");
Expect(0, 195101, '\p{^NFD_QC=_	N}', "");
Expect(0, 195101, '\P{NFD_QC=_	N}', "");
Expect(1, 195101, '\P{^NFD_QC=_	N}', "");
Expect(0, 195102, '\p{NFD_QC=_	N}', "");
Expect(1, 195102, '\p{^NFD_QC=_	N}', "");
Expect(1, 195102, '\P{NFD_QC=_	N}', "");
Expect(0, 195102, '\P{^NFD_QC=_	N}', "");
Error('\p{Is_NFD_Quick_Check=:=- No}');
Error('\P{Is_NFD_Quick_Check=:=- No}');
Expect(1, 195101, '\p{Is_NFD_Quick_Check:no}', "");
Expect(0, 195101, '\p{^Is_NFD_Quick_Check:no}', "");
Expect(0, 195101, '\P{Is_NFD_Quick_Check:no}', "");
Expect(1, 195101, '\P{^Is_NFD_Quick_Check:no}', "");
Expect(0, 195102, '\p{Is_NFD_Quick_Check:no}', "");
Expect(1, 195102, '\p{^Is_NFD_Quick_Check:no}', "");
Expect(1, 195102, '\P{Is_NFD_Quick_Check:no}', "");
Expect(0, 195102, '\P{^Is_NFD_Quick_Check:no}', "");
Expect(1, 195101, '\p{Is_NFD_Quick_Check= -no}', "");
Expect(0, 195101, '\p{^Is_NFD_Quick_Check= -no}', "");
Expect(0, 195101, '\P{Is_NFD_Quick_Check= -no}', "");
Expect(1, 195101, '\P{^Is_NFD_Quick_Check= -no}', "");
Expect(0, 195102, '\p{Is_NFD_Quick_Check= -no}', "");
Expect(1, 195102, '\p{^Is_NFD_Quick_Check= -no}', "");
Expect(1, 195102, '\P{Is_NFD_Quick_Check= -no}', "");
Expect(0, 195102, '\P{^Is_NFD_Quick_Check= -no}', "");
Error('\p{Is_NFD_QC=		n:=}');
Error('\P{Is_NFD_QC=		n:=}');
Expect(1, 195101, '\p{Is_NFD_QC=n}', "");
Expect(0, 195101, '\p{^Is_NFD_QC=n}', "");
Expect(0, 195101, '\P{Is_NFD_QC=n}', "");
Expect(1, 195101, '\P{^Is_NFD_QC=n}', "");
Expect(0, 195102, '\p{Is_NFD_QC=n}', "");
Expect(1, 195102, '\p{^Is_NFD_QC=n}', "");
Expect(1, 195102, '\P{Is_NFD_QC=n}', "");
Expect(0, 195102, '\P{^Is_NFD_QC=n}', "");
Expect(1, 195101, '\p{Is_NFD_QC=-N}', "");
Expect(0, 195101, '\p{^Is_NFD_QC=-N}', "");
Expect(0, 195101, '\P{Is_NFD_QC=-N}', "");
Expect(1, 195101, '\P{^Is_NFD_QC=-N}', "");
Expect(0, 195102, '\p{Is_NFD_QC=-N}', "");
Expect(1, 195102, '\p{^Is_NFD_QC=-N}', "");
Expect(1, 195102, '\P{Is_NFD_QC=-N}', "");
Expect(0, 195102, '\P{^Is_NFD_QC=-N}', "");
Error('\p{NFD_Quick_Check= YES:=}');
Error('\P{NFD_Quick_Check= YES:=}');
Expect(1, 195102, '\p{NFD_Quick_Check:   yes}', "");
Expect(0, 195102, '\p{^NFD_Quick_Check:   yes}', "");
Expect(0, 195102, '\P{NFD_Quick_Check:   yes}', "");
Expect(1, 195102, '\P{^NFD_Quick_Check:   yes}', "");
Expect(0, 195101, '\p{NFD_Quick_Check:   yes}', "");
Expect(1, 195101, '\p{^NFD_Quick_Check:   yes}', "");
Expect(1, 195101, '\P{NFD_Quick_Check:   yes}', "");
Expect(0, 195101, '\P{^NFD_Quick_Check:   yes}', "");
Expect(1, 195102, '\p{NFD_Quick_Check=--yes}', "");
Expect(0, 195102, '\p{^NFD_Quick_Check=--yes}', "");
Expect(0, 195102, '\P{NFD_Quick_Check=--yes}', "");
Expect(1, 195102, '\P{^NFD_Quick_Check=--yes}', "");
Expect(0, 195101, '\p{NFD_Quick_Check=--yes}', "");
Expect(1, 195101, '\p{^NFD_Quick_Check=--yes}', "");
Expect(1, 195101, '\P{NFD_Quick_Check=--yes}', "");
Expect(0, 195101, '\P{^NFD_Quick_Check=--yes}', "");
Error('\p{NFD_QC=	_y:=}');
Error('\P{NFD_QC=	_y:=}');
Expect(1, 195102, '\p{NFD_QC=y}', "");
Expect(0, 195102, '\p{^NFD_QC=y}', "");
Expect(0, 195102, '\P{NFD_QC=y}', "");
Expect(1, 195102, '\P{^NFD_QC=y}', "");
Expect(0, 195101, '\p{NFD_QC=y}', "");
Expect(1, 195101, '\p{^NFD_QC=y}', "");
Expect(1, 195101, '\P{NFD_QC=y}', "");
Expect(0, 195101, '\P{^NFD_QC=y}', "");
Expect(1, 195102, '\p{NFD_QC=--y}', "");
Expect(0, 195102, '\p{^NFD_QC=--y}', "");
Expect(0, 195102, '\P{NFD_QC=--y}', "");
Expect(1, 195102, '\P{^NFD_QC=--y}', "");
Expect(0, 195101, '\p{NFD_QC=--y}', "");
Expect(1, 195101, '\p{^NFD_QC=--y}', "");
Expect(1, 195101, '\P{NFD_QC=--y}', "");
Expect(0, 195101, '\P{^NFD_QC=--y}', "");
Error('\p{Is_NFD_Quick_Check=:=Yes}');
Error('\P{Is_NFD_Quick_Check=:=Yes}');
Expect(1, 195102, '\p{Is_NFD_Quick_Check=yes}', "");
Expect(0, 195102, '\p{^Is_NFD_Quick_Check=yes}', "");
Expect(0, 195102, '\P{Is_NFD_Quick_Check=yes}', "");
Expect(1, 195102, '\P{^Is_NFD_Quick_Check=yes}', "");
Expect(0, 195101, '\p{Is_NFD_Quick_Check=yes}', "");
Expect(1, 195101, '\p{^Is_NFD_Quick_Check=yes}', "");
Expect(1, 195101, '\P{Is_NFD_Quick_Check=yes}', "");
Expect(0, 195101, '\P{^Is_NFD_Quick_Check=yes}', "");
Expect(1, 195102, '\p{Is_NFD_Quick_Check: 	YES}', "");
Expect(0, 195102, '\p{^Is_NFD_Quick_Check: 	YES}', "");
Expect(0, 195102, '\P{Is_NFD_Quick_Check: 	YES}', "");
Expect(1, 195102, '\P{^Is_NFD_Quick_Check: 	YES}', "");
Expect(0, 195101, '\p{Is_NFD_Quick_Check: 	YES}', "");
Expect(1, 195101, '\p{^Is_NFD_Quick_Check: 	YES}', "");
Expect(1, 195101, '\P{Is_NFD_Quick_Check: 	YES}', "");
Expect(0, 195101, '\P{^Is_NFD_Quick_Check: 	YES}', "");
Error('\p{Is_NFD_QC=:=-Y}');
Error('\P{Is_NFD_QC=:=-Y}');
Expect(1, 195102, '\p{Is_NFD_QC=y}', "");
Expect(0, 195102, '\p{^Is_NFD_QC=y}', "");
Expect(0, 195102, '\P{Is_NFD_QC=y}', "");
Expect(1, 195102, '\P{^Is_NFD_QC=y}', "");
Expect(0, 195101, '\p{Is_NFD_QC=y}', "");
Expect(1, 195101, '\p{^Is_NFD_QC=y}', "");
Expect(1, 195101, '\P{Is_NFD_QC=y}', "");
Expect(0, 195101, '\P{^Is_NFD_QC=y}', "");
Expect(1, 195102, '\p{Is_NFD_QC=_Y}', "");
Expect(0, 195102, '\p{^Is_NFD_QC=_Y}', "");
Expect(0, 195102, '\P{Is_NFD_QC=_Y}', "");
Expect(1, 195102, '\P{^Is_NFD_QC=_Y}', "");
Expect(0, 195101, '\p{Is_NFD_QC=_Y}', "");
Expect(1, 195101, '\p{^Is_NFD_QC=_Y}', "");
Expect(1, 195101, '\P{Is_NFD_QC=_Y}', "");
Expect(0, 195101, '\P{^Is_NFD_QC=_Y}', "");
Error('\p{NFKC_Quick_Check=_MAYBE/a/}');
Error('\P{NFKC_Quick_Check=_MAYBE/a/}');
Expect(1, 69927, '\p{NFKC_Quick_Check=maybe}', "");
Expect(0, 69927, '\p{^NFKC_Quick_Check=maybe}', "");
Expect(0, 69927, '\P{NFKC_Quick_Check=maybe}', "");
Expect(1, 69927, '\P{^NFKC_Quick_Check=maybe}', "");
Expect(0, 69928, '\p{NFKC_Quick_Check=maybe}', "");
Expect(1, 69928, '\p{^NFKC_Quick_Check=maybe}', "");
Expect(1, 69928, '\P{NFKC_Quick_Check=maybe}', "");
Expect(0, 69928, '\P{^NFKC_Quick_Check=maybe}', "");
Expect(1, 69927, '\p{NFKC_Quick_Check=	Maybe}', "");
Expect(0, 69927, '\p{^NFKC_Quick_Check=	Maybe}', "");
Expect(0, 69927, '\P{NFKC_Quick_Check=	Maybe}', "");
Expect(1, 69927, '\P{^NFKC_Quick_Check=	Maybe}', "");
Expect(0, 69928, '\p{NFKC_Quick_Check=	Maybe}', "");
Expect(1, 69928, '\p{^NFKC_Quick_Check=	Maybe}', "");
Expect(1, 69928, '\P{NFKC_Quick_Check=	Maybe}', "");
Expect(0, 69928, '\P{^NFKC_Quick_Check=	Maybe}', "");
Error('\p{NFKC_QC=	/a/M}');
Error('\P{NFKC_QC=	/a/M}');
Expect(1, 69927, '\p{NFKC_QC: m}', "");
Expect(0, 69927, '\p{^NFKC_QC: m}', "");
Expect(0, 69927, '\P{NFKC_QC: m}', "");
Expect(1, 69927, '\P{^NFKC_QC: m}', "");
Expect(0, 69928, '\p{NFKC_QC: m}', "");
Expect(1, 69928, '\p{^NFKC_QC: m}', "");
Expect(1, 69928, '\P{NFKC_QC: m}', "");
Expect(0, 69928, '\P{^NFKC_QC: m}', "");
Expect(1, 69927, '\p{NFKC_QC:	 _M}', "");
Expect(0, 69927, '\p{^NFKC_QC:	 _M}', "");
Expect(0, 69927, '\P{NFKC_QC:	 _M}', "");
Expect(1, 69927, '\P{^NFKC_QC:	 _M}', "");
Expect(0, 69928, '\p{NFKC_QC:	 _M}', "");
Expect(1, 69928, '\p{^NFKC_QC:	 _M}', "");
Expect(1, 69928, '\P{NFKC_QC:	 _M}', "");
Expect(0, 69928, '\P{^NFKC_QC:	 _M}', "");
Error('\p{Is_NFKC_Quick_Check= 	MAYBE/a/}');
Error('\P{Is_NFKC_Quick_Check= 	MAYBE/a/}');
Expect(1, 69927, '\p{Is_NFKC_Quick_Check=maybe}', "");
Expect(0, 69927, '\p{^Is_NFKC_Quick_Check=maybe}', "");
Expect(0, 69927, '\P{Is_NFKC_Quick_Check=maybe}', "");
Expect(1, 69927, '\P{^Is_NFKC_Quick_Check=maybe}', "");
Expect(0, 69928, '\p{Is_NFKC_Quick_Check=maybe}', "");
Expect(1, 69928, '\p{^Is_NFKC_Quick_Check=maybe}', "");
Expect(1, 69928, '\P{Is_NFKC_Quick_Check=maybe}', "");
Expect(0, 69928, '\P{^Is_NFKC_Quick_Check=maybe}', "");
Expect(1, 69927, '\p{Is_NFKC_Quick_Check=	_Maybe}', "");
Expect(0, 69927, '\p{^Is_NFKC_Quick_Check=	_Maybe}', "");
Expect(0, 69927, '\P{Is_NFKC_Quick_Check=	_Maybe}', "");
Expect(1, 69927, '\P{^Is_NFKC_Quick_Check=	_Maybe}', "");
Expect(0, 69928, '\p{Is_NFKC_Quick_Check=	_Maybe}', "");
Expect(1, 69928, '\p{^Is_NFKC_Quick_Check=	_Maybe}', "");
Expect(1, 69928, '\P{Is_NFKC_Quick_Check=	_Maybe}', "");
Expect(0, 69928, '\P{^Is_NFKC_Quick_Check=	_Maybe}', "");
Error('\p{Is_NFKC_QC=:=-M}');
Error('\P{Is_NFKC_QC=:=-M}');
Expect(1, 69927, '\p{Is_NFKC_QC=m}', "");
Expect(0, 69927, '\p{^Is_NFKC_QC=m}', "");
Expect(0, 69927, '\P{Is_NFKC_QC=m}', "");
Expect(1, 69927, '\P{^Is_NFKC_QC=m}', "");
Expect(0, 69928, '\p{Is_NFKC_QC=m}', "");
Expect(1, 69928, '\p{^Is_NFKC_QC=m}', "");
Expect(1, 69928, '\P{Is_NFKC_QC=m}', "");
Expect(0, 69928, '\P{^Is_NFKC_QC=m}', "");
Expect(1, 69927, '\p{Is_NFKC_QC=__M}', "");
Expect(0, 69927, '\p{^Is_NFKC_QC=__M}', "");
Expect(0, 69927, '\P{Is_NFKC_QC=__M}', "");
Expect(1, 69927, '\P{^Is_NFKC_QC=__M}', "");
Expect(0, 69928, '\p{Is_NFKC_QC=__M}', "");
Expect(1, 69928, '\p{^Is_NFKC_QC=__M}', "");
Expect(1, 69928, '\P{Is_NFKC_QC=__M}', "");
Expect(0, 69928, '\P{^Is_NFKC_QC=__M}', "");
Error('\p{NFKC_Quick_Check:	 No:=}');
Error('\P{NFKC_Quick_Check:	 No:=}');
Expect(1, 195101, '\p{NFKC_Quick_Check=no}', "");
Expect(0, 195101, '\p{^NFKC_Quick_Check=no}', "");
Expect(0, 195101, '\P{NFKC_Quick_Check=no}', "");
Expect(1, 195101, '\P{^NFKC_Quick_Check=no}', "");
Expect(0, 195102, '\p{NFKC_Quick_Check=no}', "");
Expect(1, 195102, '\p{^NFKC_Quick_Check=no}', "");
Expect(1, 195102, '\P{NFKC_Quick_Check=no}', "");
Expect(0, 195102, '\P{^NFKC_Quick_Check=no}', "");
Expect(1, 195101, '\p{NFKC_Quick_Check=-	No}', "");
Expect(0, 195101, '\p{^NFKC_Quick_Check=-	No}', "");
Expect(0, 195101, '\P{NFKC_Quick_Check=-	No}', "");
Expect(1, 195101, '\P{^NFKC_Quick_Check=-	No}', "");
Expect(0, 195102, '\p{NFKC_Quick_Check=-	No}', "");
Expect(1, 195102, '\p{^NFKC_Quick_Check=-	No}', "");
Expect(1, 195102, '\P{NFKC_Quick_Check=-	No}', "");
Expect(0, 195102, '\P{^NFKC_Quick_Check=-	No}', "");
Error('\p{NFKC_QC:    :=N}');
Error('\P{NFKC_QC:    :=N}');
Expect(1, 195101, '\p{NFKC_QC=n}', "");
Expect(0, 195101, '\p{^NFKC_QC=n}', "");
Expect(0, 195101, '\P{NFKC_QC=n}', "");
Expect(1, 195101, '\P{^NFKC_QC=n}', "");
Expect(0, 195102, '\p{NFKC_QC=n}', "");
Expect(1, 195102, '\p{^NFKC_QC=n}', "");
Expect(1, 195102, '\P{NFKC_QC=n}', "");
Expect(0, 195102, '\P{^NFKC_QC=n}', "");
Expect(1, 195101, '\p{NFKC_QC=N}', "");
Expect(0, 195101, '\p{^NFKC_QC=N}', "");
Expect(0, 195101, '\P{NFKC_QC=N}', "");
Expect(1, 195101, '\P{^NFKC_QC=N}', "");
Expect(0, 195102, '\p{NFKC_QC=N}', "");
Expect(1, 195102, '\p{^NFKC_QC=N}', "");
Expect(1, 195102, '\P{NFKC_QC=N}', "");
Expect(0, 195102, '\P{^NFKC_QC=N}', "");
Error('\p{Is_NFKC_Quick_Check=:=	NO}');
Error('\P{Is_NFKC_Quick_Check=:=	NO}');
Expect(1, 195101, '\p{Is_NFKC_Quick_Check=no}', "");
Expect(0, 195101, '\p{^Is_NFKC_Quick_Check=no}', "");
Expect(0, 195101, '\P{Is_NFKC_Quick_Check=no}', "");
Expect(1, 195101, '\P{^Is_NFKC_Quick_Check=no}', "");
Expect(0, 195102, '\p{Is_NFKC_Quick_Check=no}', "");
Expect(1, 195102, '\p{^Is_NFKC_Quick_Check=no}', "");
Expect(1, 195102, '\P{Is_NFKC_Quick_Check=no}', "");
Expect(0, 195102, '\P{^Is_NFKC_Quick_Check=no}', "");
Expect(1, 195101, '\p{Is_NFKC_Quick_Check=	_NO}', "");
Expect(0, 195101, '\p{^Is_NFKC_Quick_Check=	_NO}', "");
Expect(0, 195101, '\P{Is_NFKC_Quick_Check=	_NO}', "");
Expect(1, 195101, '\P{^Is_NFKC_Quick_Check=	_NO}', "");
Expect(0, 195102, '\p{Is_NFKC_Quick_Check=	_NO}', "");
Expect(1, 195102, '\p{^Is_NFKC_Quick_Check=	_NO}', "");
Expect(1, 195102, '\P{Is_NFKC_Quick_Check=	_NO}', "");
Expect(0, 195102, '\P{^Is_NFKC_Quick_Check=	_NO}', "");
Error('\p{Is_NFKC_QC=/a/	_N}');
Error('\P{Is_NFKC_QC=/a/	_N}');
Expect(1, 195101, '\p{Is_NFKC_QC=n}', "");
Expect(0, 195101, '\p{^Is_NFKC_QC=n}', "");
Expect(0, 195101, '\P{Is_NFKC_QC=n}', "");
Expect(1, 195101, '\P{^Is_NFKC_QC=n}', "");
Expect(0, 195102, '\p{Is_NFKC_QC=n}', "");
Expect(1, 195102, '\p{^Is_NFKC_QC=n}', "");
Expect(1, 195102, '\P{Is_NFKC_QC=n}', "");
Expect(0, 195102, '\P{^Is_NFKC_QC=n}', "");
Expect(1, 195101, '\p{Is_NFKC_QC=	N}', "");
Expect(0, 195101, '\p{^Is_NFKC_QC=	N}', "");
Expect(0, 195101, '\P{Is_NFKC_QC=	N}', "");
Expect(1, 195101, '\P{^Is_NFKC_QC=	N}', "");
Expect(0, 195102, '\p{Is_NFKC_QC=	N}', "");
Expect(1, 195102, '\p{^Is_NFKC_QC=	N}', "");
Expect(1, 195102, '\P{Is_NFKC_QC=	N}', "");
Expect(0, 195102, '\P{^Is_NFKC_QC=	N}', "");
Error('\p{NFKC_Quick_Check=:=-Yes}');
Error('\P{NFKC_Quick_Check=:=-Yes}');
Expect(1, 195102, '\p{NFKC_Quick_Check=yes}', "");
Expect(0, 195102, '\p{^NFKC_Quick_Check=yes}', "");
Expect(0, 195102, '\P{NFKC_Quick_Check=yes}', "");
Expect(1, 195102, '\P{^NFKC_Quick_Check=yes}', "");
Expect(0, 195101, '\p{NFKC_Quick_Check=yes}', "");
Expect(1, 195101, '\p{^NFKC_Quick_Check=yes}', "");
Expect(1, 195101, '\P{NFKC_Quick_Check=yes}', "");
Expect(0, 195101, '\P{^NFKC_Quick_Check=yes}', "");
Expect(1, 195102, '\p{NFKC_Quick_Check: _	yes}', "");
Expect(0, 195102, '\p{^NFKC_Quick_Check: _	yes}', "");
Expect(0, 195102, '\P{NFKC_Quick_Check: _	yes}', "");
Expect(1, 195102, '\P{^NFKC_Quick_Check: _	yes}', "");
Expect(0, 195101, '\p{NFKC_Quick_Check: _	yes}', "");
Expect(1, 195101, '\p{^NFKC_Quick_Check: _	yes}', "");
Expect(1, 195101, '\P{NFKC_Quick_Check: _	yes}', "");
Expect(0, 195101, '\P{^NFKC_Quick_Check: _	yes}', "");
Error('\p{NFKC_QC=	/a/Y}');
Error('\P{NFKC_QC=	/a/Y}');
Expect(1, 195102, '\p{NFKC_QC=y}', "");
Expect(0, 195102, '\p{^NFKC_QC=y}', "");
Expect(0, 195102, '\P{NFKC_QC=y}', "");
Expect(1, 195102, '\P{^NFKC_QC=y}', "");
Expect(0, 195101, '\p{NFKC_QC=y}', "");
Expect(1, 195101, '\p{^NFKC_QC=y}', "");
Expect(1, 195101, '\P{NFKC_QC=y}', "");
Expect(0, 195101, '\P{^NFKC_QC=y}', "");
Expect(1, 195102, '\p{NFKC_QC=__Y}', "");
Expect(0, 195102, '\p{^NFKC_QC=__Y}', "");
Expect(0, 195102, '\P{NFKC_QC=__Y}', "");
Expect(1, 195102, '\P{^NFKC_QC=__Y}', "");
Expect(0, 195101, '\p{NFKC_QC=__Y}', "");
Expect(1, 195101, '\p{^NFKC_QC=__Y}', "");
Expect(1, 195101, '\P{NFKC_QC=__Y}', "");
Expect(0, 195101, '\P{^NFKC_QC=__Y}', "");
Error('\p{Is_NFKC_Quick_Check=	Yes/a/}');
Error('\P{Is_NFKC_Quick_Check=	Yes/a/}');
Expect(1, 195102, '\p{Is_NFKC_Quick_Check=yes}', "");
Expect(0, 195102, '\p{^Is_NFKC_Quick_Check=yes}', "");
Expect(0, 195102, '\P{Is_NFKC_Quick_Check=yes}', "");
Expect(1, 195102, '\P{^Is_NFKC_Quick_Check=yes}', "");
Expect(0, 195101, '\p{Is_NFKC_Quick_Check=yes}', "");
Expect(1, 195101, '\p{^Is_NFKC_Quick_Check=yes}', "");
Expect(1, 195101, '\P{Is_NFKC_Quick_Check=yes}', "");
Expect(0, 195101, '\P{^Is_NFKC_Quick_Check=yes}', "");
Expect(1, 195102, '\p{Is_NFKC_Quick_Check=-_yes}', "");
Expect(0, 195102, '\p{^Is_NFKC_Quick_Check=-_yes}', "");
Expect(0, 195102, '\P{Is_NFKC_Quick_Check=-_yes}', "");
Expect(1, 195102, '\P{^Is_NFKC_Quick_Check=-_yes}', "");
Expect(0, 195101, '\p{Is_NFKC_Quick_Check=-_yes}', "");
Expect(1, 195101, '\p{^Is_NFKC_Quick_Check=-_yes}', "");
Expect(1, 195101, '\P{Is_NFKC_Quick_Check=-_yes}', "");
Expect(0, 195101, '\P{^Is_NFKC_Quick_Check=-_yes}', "");
Error('\p{Is_NFKC_QC=/a/- y}');
Error('\P{Is_NFKC_QC=/a/- y}');
Expect(1, 195102, '\p{Is_NFKC_QC=y}', "");
Expect(0, 195102, '\p{^Is_NFKC_QC=y}', "");
Expect(0, 195102, '\P{Is_NFKC_QC=y}', "");
Expect(1, 195102, '\P{^Is_NFKC_QC=y}', "");
Expect(0, 195101, '\p{Is_NFKC_QC=y}', "");
Expect(1, 195101, '\p{^Is_NFKC_QC=y}', "");
Expect(1, 195101, '\P{Is_NFKC_QC=y}', "");
Expect(0, 195101, '\P{^Is_NFKC_QC=y}', "");
Expect(1, 195102, '\p{Is_NFKC_QC=-	Y}', "");
Expect(0, 195102, '\p{^Is_NFKC_QC=-	Y}', "");
Expect(0, 195102, '\P{Is_NFKC_QC=-	Y}', "");
Expect(1, 195102, '\P{^Is_NFKC_QC=-	Y}', "");
Expect(0, 195101, '\p{Is_NFKC_QC=-	Y}', "");
Expect(1, 195101, '\p{^Is_NFKC_QC=-	Y}', "");
Expect(1, 195101, '\P{Is_NFKC_QC=-	Y}', "");
Expect(0, 195101, '\P{^Is_NFKC_QC=-	Y}', "");
Error('\p{NFKD_Quick_Check=/a/	-no}');
Error('\P{NFKD_Quick_Check=/a/	-no}');
Expect(1, 195101, '\p{NFKD_Quick_Check=no}', "");
Expect(0, 195101, '\p{^NFKD_Quick_Check=no}', "");
Expect(0, 195101, '\P{NFKD_Quick_Check=no}', "");
Expect(1, 195101, '\P{^NFKD_Quick_Check=no}', "");
Expect(0, 195102, '\p{NFKD_Quick_Check=no}', "");
Expect(1, 195102, '\p{^NFKD_Quick_Check=no}', "");
Expect(1, 195102, '\P{NFKD_Quick_Check=no}', "");
Expect(0, 195102, '\P{^NFKD_Quick_Check=no}', "");
Expect(1, 195101, '\p{NFKD_Quick_Check=-no}', "");
Expect(0, 195101, '\p{^NFKD_Quick_Check=-no}', "");
Expect(0, 195101, '\P{NFKD_Quick_Check=-no}', "");
Expect(1, 195101, '\P{^NFKD_Quick_Check=-no}', "");
Expect(0, 195102, '\p{NFKD_Quick_Check=-no}', "");
Expect(1, 195102, '\p{^NFKD_Quick_Check=-no}', "");
Expect(1, 195102, '\P{NFKD_Quick_Check=-no}', "");
Expect(0, 195102, '\P{^NFKD_Quick_Check=-no}', "");
Error('\p{NFKD_QC=	:=n}');
Error('\P{NFKD_QC=	:=n}');
Expect(1, 195101, '\p{NFKD_QC=n}', "");
Expect(0, 195101, '\p{^NFKD_QC=n}', "");
Expect(0, 195101, '\P{NFKD_QC=n}', "");
Expect(1, 195101, '\P{^NFKD_QC=n}', "");
Expect(0, 195102, '\p{NFKD_QC=n}', "");
Expect(1, 195102, '\p{^NFKD_QC=n}', "");
Expect(1, 195102, '\P{NFKD_QC=n}', "");
Expect(0, 195102, '\P{^NFKD_QC=n}', "");
Expect(1, 195101, '\p{NFKD_QC= 	N}', "");
Expect(0, 195101, '\p{^NFKD_QC= 	N}', "");
Expect(0, 195101, '\P{NFKD_QC= 	N}', "");
Expect(1, 195101, '\P{^NFKD_QC= 	N}', "");
Expect(0, 195102, '\p{NFKD_QC= 	N}', "");
Expect(1, 195102, '\p{^NFKD_QC= 	N}', "");
Expect(1, 195102, '\P{NFKD_QC= 	N}', "");
Expect(0, 195102, '\P{^NFKD_QC= 	N}', "");
Error('\p{Is_NFKD_Quick_Check=/a/- No}');
Error('\P{Is_NFKD_Quick_Check=/a/- No}');
Expect(1, 195101, '\p{Is_NFKD_Quick_Check=no}', "");
Expect(0, 195101, '\p{^Is_NFKD_Quick_Check=no}', "");
Expect(0, 195101, '\P{Is_NFKD_Quick_Check=no}', "");
Expect(1, 195101, '\P{^Is_NFKD_Quick_Check=no}', "");
Expect(0, 195102, '\p{Is_NFKD_Quick_Check=no}', "");
Expect(1, 195102, '\p{^Is_NFKD_Quick_Check=no}', "");
Expect(1, 195102, '\P{Is_NFKD_Quick_Check=no}', "");
Expect(0, 195102, '\P{^Is_NFKD_Quick_Check=no}', "");
Expect(1, 195101, '\p{Is_NFKD_Quick_Check=	No}', "");
Expect(0, 195101, '\p{^Is_NFKD_Quick_Check=	No}', "");
Expect(0, 195101, '\P{Is_NFKD_Quick_Check=	No}', "");
Expect(1, 195101, '\P{^Is_NFKD_Quick_Check=	No}', "");
Expect(0, 195102, '\p{Is_NFKD_Quick_Check=	No}', "");
Expect(1, 195102, '\p{^Is_NFKD_Quick_Check=	No}', "");
Expect(1, 195102, '\P{Is_NFKD_Quick_Check=	No}', "");
Expect(0, 195102, '\P{^Is_NFKD_Quick_Check=	No}', "");
Error('\p{Is_NFKD_QC=_-N:=}');
Error('\P{Is_NFKD_QC=_-N:=}');
Expect(1, 195101, '\p{Is_NFKD_QC: n}', "");
Expect(0, 195101, '\p{^Is_NFKD_QC: n}', "");
Expect(0, 195101, '\P{Is_NFKD_QC: n}', "");
Expect(1, 195101, '\P{^Is_NFKD_QC: n}', "");
Expect(0, 195102, '\p{Is_NFKD_QC: n}', "");
Expect(1, 195102, '\p{^Is_NFKD_QC: n}', "");
Expect(1, 195102, '\P{Is_NFKD_QC: n}', "");
Expect(0, 195102, '\P{^Is_NFKD_QC: n}', "");
Expect(1, 195101, '\p{Is_NFKD_QC=	-N}', "");
Expect(0, 195101, '\p{^Is_NFKD_QC=	-N}', "");
Expect(0, 195101, '\P{Is_NFKD_QC=	-N}', "");
Expect(1, 195101, '\P{^Is_NFKD_QC=	-N}', "");
Expect(0, 195102, '\p{Is_NFKD_QC=	-N}', "");
Expect(1, 195102, '\p{^Is_NFKD_QC=	-N}', "");
Expect(1, 195102, '\P{Is_NFKD_QC=	-N}', "");
Expect(0, 195102, '\P{^Is_NFKD_QC=	-N}', "");
Error('\p{NFKD_Quick_Check=:=__YES}');
Error('\P{NFKD_Quick_Check=:=__YES}');
Expect(1, 195102, '\p{NFKD_Quick_Check:yes}', "");
Expect(0, 195102, '\p{^NFKD_Quick_Check:yes}', "");
Expect(0, 195102, '\P{NFKD_Quick_Check:yes}', "");
Expect(1, 195102, '\P{^NFKD_Quick_Check:yes}', "");
Expect(0, 195101, '\p{NFKD_Quick_Check:yes}', "");
Expect(1, 195101, '\p{^NFKD_Quick_Check:yes}', "");
Expect(1, 195101, '\P{NFKD_Quick_Check:yes}', "");
Expect(0, 195101, '\P{^NFKD_Quick_Check:yes}', "");
Expect(1, 195102, '\p{NFKD_Quick_Check=-	Yes}', "");
Expect(0, 195102, '\p{^NFKD_Quick_Check=-	Yes}', "");
Expect(0, 195102, '\P{NFKD_Quick_Check=-	Yes}', "");
Expect(1, 195102, '\P{^NFKD_Quick_Check=-	Yes}', "");
Expect(0, 195101, '\p{NFKD_Quick_Check=-	Yes}', "");
Expect(1, 195101, '\p{^NFKD_Quick_Check=-	Yes}', "");
Expect(1, 195101, '\P{NFKD_Quick_Check=-	Yes}', "");
Expect(0, 195101, '\P{^NFKD_Quick_Check=-	Yes}', "");
Error('\p{NFKD_QC=/a/-Y}');
Error('\P{NFKD_QC=/a/-Y}');
Expect(1, 195102, '\p{NFKD_QC=y}', "");
Expect(0, 195102, '\p{^NFKD_QC=y}', "");
Expect(0, 195102, '\P{NFKD_QC=y}', "");
Expect(1, 195102, '\P{^NFKD_QC=y}', "");
Expect(0, 195101, '\p{NFKD_QC=y}', "");
Expect(1, 195101, '\p{^NFKD_QC=y}', "");
Expect(1, 195101, '\P{NFKD_QC=y}', "");
Expect(0, 195101, '\P{^NFKD_QC=y}', "");
Expect(1, 195102, '\p{NFKD_QC=		Y}', "");
Expect(0, 195102, '\p{^NFKD_QC=		Y}', "");
Expect(0, 195102, '\P{NFKD_QC=		Y}', "");
Expect(1, 195102, '\P{^NFKD_QC=		Y}', "");
Expect(0, 195101, '\p{NFKD_QC=		Y}', "");
Expect(1, 195101, '\p{^NFKD_QC=		Y}', "");
Expect(1, 195101, '\P{NFKD_QC=		Y}', "");
Expect(0, 195101, '\P{^NFKD_QC=		Y}', "");
Error('\p{Is_NFKD_Quick_Check=	_Yes:=}');
Error('\P{Is_NFKD_Quick_Check=	_Yes:=}');
Expect(1, 195102, '\p{Is_NFKD_Quick_Check=yes}', "");
Expect(0, 195102, '\p{^Is_NFKD_Quick_Check=yes}', "");
Expect(0, 195102, '\P{Is_NFKD_Quick_Check=yes}', "");
Expect(1, 195102, '\P{^Is_NFKD_Quick_Check=yes}', "");
Expect(0, 195101, '\p{Is_NFKD_Quick_Check=yes}', "");
Expect(1, 195101, '\p{^Is_NFKD_Quick_Check=yes}', "");
Expect(1, 195101, '\P{Is_NFKD_Quick_Check=yes}', "");
Expect(0, 195101, '\P{^Is_NFKD_Quick_Check=yes}', "");
Expect(1, 195102, '\p{Is_NFKD_Quick_Check=_ Yes}', "");
Expect(0, 195102, '\p{^Is_NFKD_Quick_Check=_ Yes}', "");
Expect(0, 195102, '\P{Is_NFKD_Quick_Check=_ Yes}', "");
Expect(1, 195102, '\P{^Is_NFKD_Quick_Check=_ Yes}', "");
Expect(0, 195101, '\p{Is_NFKD_Quick_Check=_ Yes}', "");
Expect(1, 195101, '\p{^Is_NFKD_Quick_Check=_ Yes}', "");
Expect(1, 195101, '\P{Is_NFKD_Quick_Check=_ Yes}', "");
Expect(0, 195101, '\P{^Is_NFKD_Quick_Check=_ Yes}', "");
Error('\p{Is_NFKD_QC=	_y:=}');
Error('\P{Is_NFKD_QC=	_y:=}');
Expect(1, 195102, '\p{Is_NFKD_QC=y}', "");
Expect(0, 195102, '\p{^Is_NFKD_QC=y}', "");
Expect(0, 195102, '\P{Is_NFKD_QC=y}', "");
Expect(1, 195102, '\P{^Is_NFKD_QC=y}', "");
Expect(0, 195101, '\p{Is_NFKD_QC=y}', "");
Expect(1, 195101, '\p{^Is_NFKD_QC=y}', "");
Expect(1, 195101, '\P{Is_NFKD_QC=y}', "");
Expect(0, 195101, '\P{^Is_NFKD_QC=y}', "");
Expect(1, 195102, '\p{Is_NFKD_QC= Y}', "");
Expect(0, 195102, '\p{^Is_NFKD_QC= Y}', "");
Expect(0, 195102, '\P{Is_NFKD_QC= Y}', "");
Expect(1, 195102, '\P{^Is_NFKD_QC= Y}', "");
Expect(0, 195101, '\p{Is_NFKD_QC= Y}', "");
Expect(1, 195101, '\p{^Is_NFKD_QC= Y}', "");
Expect(1, 195101, '\P{Is_NFKD_QC= Y}', "");
Expect(0, 195101, '\P{^Is_NFKD_QC= Y}', "");
Error('\p{Other_Alphabetic=No}');
Error('\P{Other_Alphabetic=No}');
Error('\p{OAlpha=N}');
Error('\P{OAlpha=N}');
Error('\p{Is_Other_Alphabetic=F}');
Error('\P{Is_Other_Alphabetic=F}');
Error('\p{Is_OAlpha=False}');
Error('\P{Is_OAlpha=False}');
Error('\p{Other_Alphabetic=Yes}');
Error('\P{Other_Alphabetic=Yes}');
Error('\p{OAlpha=Y}');
Error('\P{OAlpha=Y}');
Error('\p{Is_Other_Alphabetic=T}');
Error('\P{Is_Other_Alphabetic=T}');
Error('\p{Is_OAlpha=True}');
Error('\P{Is_OAlpha=True}');
Error('\p{Other_Default_Ignorable_Code_Point=No}');
Error('\P{Other_Default_Ignorable_Code_Point=No}');
Error('\p{ODI=N}');
Error('\P{ODI=N}');
Error('\p{Is_Other_Default_Ignorable_Code_Point=F}');
Error('\P{Is_Other_Default_Ignorable_Code_Point=F}');
Error('\p{Is_ODI=False}');
Error('\P{Is_ODI=False}');
Error('\p{Other_Default_Ignorable_Code_Point=Yes}');
Error('\P{Other_Default_Ignorable_Code_Point=Yes}');
Error('\p{ODI: Y}');
Error('\P{ODI: Y}');
Error('\p{Is_Other_Default_Ignorable_Code_Point=T}');
Error('\P{Is_Other_Default_Ignorable_Code_Point=T}');
Error('\p{Is_ODI=True}');
Error('\P{Is_ODI=True}');
Error('\p{Other_Grapheme_Extend=No}');
Error('\P{Other_Grapheme_Extend=No}');
Error('\p{OGr_Ext=N}');
Error('\P{OGr_Ext=N}');
Error('\p{Is_Other_Grapheme_Extend=F}');
Error('\P{Is_Other_Grapheme_Extend=F}');
Error('\p{Is_OGr_Ext=False}');
Error('\P{Is_OGr_Ext=False}');
Error('\p{Other_Grapheme_Extend:   Yes}');
Error('\P{Other_Grapheme_Extend:   Yes}');
Error('\p{OGr_Ext=Y}');
Error('\P{OGr_Ext=Y}');
Error('\p{Is_Other_Grapheme_Extend: T}');
Error('\P{Is_Other_Grapheme_Extend: T}');
Error('\p{Is_OGr_Ext=True}');
Error('\P{Is_OGr_Ext=True}');
Error('\p{Other_ID_Continue=No}');
Error('\P{Other_ID_Continue=No}');
Error('\p{OIDC=N}');
Error('\P{OIDC=N}');
Error('\p{Is_Other_ID_Continue:   F}');
Error('\P{Is_Other_ID_Continue:   F}');
Error('\p{Is_OIDC=False}');
Error('\P{Is_OIDC=False}');
Error('\p{Other_ID_Continue=Yes}');
Error('\P{Other_ID_Continue=Yes}');
Error('\p{OIDC=Y}');
Error('\P{OIDC=Y}');
Error('\p{Is_Other_ID_Continue=T}');
Error('\P{Is_Other_ID_Continue=T}');
Error('\p{Is_OIDC=True}');
Error('\P{Is_OIDC=True}');
Error('\p{Other_ID_Start=No}');
Error('\P{Other_ID_Start=No}');
Error('\p{OIDS=N}');
Error('\P{OIDS=N}');
Error('\p{Is_Other_ID_Start=F}');
Error('\P{Is_Other_ID_Start=F}');
Error('\p{Is_OIDS=False}');
Error('\P{Is_OIDS=False}');
Error('\p{Other_ID_Start=Yes}');
Error('\P{Other_ID_Start=Yes}');
Error('\p{OIDS=Y}');
Error('\P{OIDS=Y}');
Error('\p{Is_Other_ID_Start=T}');
Error('\P{Is_Other_ID_Start=T}');
Error('\p{Is_OIDS=True}');
Error('\P{Is_OIDS=True}');
Error('\p{Other_Lowercase=No}');
Error('\P{Other_Lowercase=No}');
Error('\p{OLower=N}');
Error('\P{OLower=N}');
Error('\p{Is_Other_Lowercase=F}');
Error('\P{Is_Other_Lowercase=F}');
Error('\p{Is_OLower=False}');
Error('\P{Is_OLower=False}');
Error('\p{Other_Lowercase=Yes}');
Error('\P{Other_Lowercase=Yes}');
Error('\p{OLower=Y}');
Error('\P{OLower=Y}');
Error('\p{Is_Other_Lowercase=T}');
Error('\P{Is_Other_Lowercase=T}');
Error('\p{Is_OLower=True}');
Error('\P{Is_OLower=True}');
Error('\p{Other_Math=No}');
Error('\P{Other_Math=No}');
Error('\p{OMath=N}');
Error('\P{OMath=N}');
Error('\p{Is_Other_Math=F}');
Error('\P{Is_Other_Math=F}');
Error('\p{Is_OMath=False}');
Error('\P{Is_OMath=False}');
Error('\p{Other_Math=Yes}');
Error('\P{Other_Math=Yes}');
Error('\p{OMath=Y}');
Error('\P{OMath=Y}');
Error('\p{Is_Other_Math=T}');
Error('\P{Is_Other_Math=T}');
Error('\p{Is_OMath=True}');
Error('\P{Is_OMath=True}');
Error('\p{Other_Uppercase:	No}');
Error('\P{Other_Uppercase:	No}');
Error('\p{OUpper=N}');
Error('\P{OUpper=N}');
Error('\p{Is_Other_Uppercase=F}');
Error('\P{Is_Other_Uppercase=F}');
Error('\p{Is_OUpper=False}');
Error('\P{Is_OUpper=False}');
Error('\p{Other_Uppercase=Yes}');
Error('\P{Other_Uppercase=Yes}');
Error('\p{OUpper=Y}');
Error('\P{OUpper=Y}');
Error('\p{Is_Other_Uppercase=T}');
Error('\P{Is_Other_Uppercase=T}');
Error('\p{Is_OUpper=True}');
Error('\P{Is_OUpper=True}');
Error('\p{Pattern_Syntax=/a/--NO}');
Error('\P{Pattern_Syntax=/a/--NO}');
Expect(1, 65095, '\p{Pattern_Syntax:	no}', "");
Expect(0, 65095, '\p{^Pattern_Syntax:	no}', "");
Expect(0, 65095, '\P{Pattern_Syntax:	no}', "");
Expect(1, 65095, '\P{^Pattern_Syntax:	no}', "");
Expect(0, 65094, '\p{Pattern_Syntax:	no}', "");
Expect(1, 65094, '\p{^Pattern_Syntax:	no}', "");
Expect(1, 65094, '\P{Pattern_Syntax:	no}', "");
Expect(0, 65094, '\P{^Pattern_Syntax:	no}', "");
Expect(1, 65095, '\p{Pattern_Syntax=	NO}', "");
Expect(0, 65095, '\p{^Pattern_Syntax=	NO}', "");
Expect(0, 65095, '\P{Pattern_Syntax=	NO}', "");
Expect(1, 65095, '\P{^Pattern_Syntax=	NO}', "");
Expect(0, 65094, '\p{Pattern_Syntax=	NO}', "");
Expect(1, 65094, '\p{^Pattern_Syntax=	NO}', "");
Expect(1, 65094, '\P{Pattern_Syntax=	NO}', "");
Expect(0, 65094, '\P{^Pattern_Syntax=	NO}', "");
Error('\p{Pat_Syn=-/a/N}');
Error('\P{Pat_Syn=-/a/N}');
Expect(1, 65095, '\p{Pat_Syn=n}', "");
Expect(0, 65095, '\p{^Pat_Syn=n}', "");
Expect(0, 65095, '\P{Pat_Syn=n}', "");
Expect(1, 65095, '\P{^Pat_Syn=n}', "");
Expect(0, 65094, '\p{Pat_Syn=n}', "");
Expect(1, 65094, '\p{^Pat_Syn=n}', "");
Expect(1, 65094, '\P{Pat_Syn=n}', "");
Expect(0, 65094, '\P{^Pat_Syn=n}', "");
Expect(1, 65095, '\p{Pat_Syn=-	N}', "");
Expect(0, 65095, '\p{^Pat_Syn=-	N}', "");
Expect(0, 65095, '\P{Pat_Syn=-	N}', "");
Expect(1, 65095, '\P{^Pat_Syn=-	N}', "");
Expect(0, 65094, '\p{Pat_Syn=-	N}', "");
Expect(1, 65094, '\p{^Pat_Syn=-	N}', "");
Expect(1, 65094, '\P{Pat_Syn=-	N}', "");
Expect(0, 65094, '\P{^Pat_Syn=-	N}', "");
Error('\p{Is_Pattern_Syntax=_F:=}');
Error('\P{Is_Pattern_Syntax=_F:=}');
Expect(1, 65095, '\p{Is_Pattern_Syntax=f}', "");
Expect(0, 65095, '\p{^Is_Pattern_Syntax=f}', "");
Expect(0, 65095, '\P{Is_Pattern_Syntax=f}', "");
Expect(1, 65095, '\P{^Is_Pattern_Syntax=f}', "");
Expect(0, 65094, '\p{Is_Pattern_Syntax=f}', "");
Expect(1, 65094, '\p{^Is_Pattern_Syntax=f}', "");
Expect(1, 65094, '\P{Is_Pattern_Syntax=f}', "");
Expect(0, 65094, '\P{^Is_Pattern_Syntax=f}', "");
Expect(1, 65095, '\p{Is_Pattern_Syntax=- F}', "");
Expect(0, 65095, '\p{^Is_Pattern_Syntax=- F}', "");
Expect(0, 65095, '\P{Is_Pattern_Syntax=- F}', "");
Expect(1, 65095, '\P{^Is_Pattern_Syntax=- F}', "");
Expect(0, 65094, '\p{Is_Pattern_Syntax=- F}', "");
Expect(1, 65094, '\p{^Is_Pattern_Syntax=- F}', "");
Expect(1, 65094, '\P{Is_Pattern_Syntax=- F}', "");
Expect(0, 65094, '\P{^Is_Pattern_Syntax=- F}', "");
Error('\p{Is_Pat_Syn=/a/_	FALSE}');
Error('\P{Is_Pat_Syn=/a/_	FALSE}');
Expect(1, 65095, '\p{Is_Pat_Syn=false}', "");
Expect(0, 65095, '\p{^Is_Pat_Syn=false}', "");
Expect(0, 65095, '\P{Is_Pat_Syn=false}', "");
Expect(1, 65095, '\P{^Is_Pat_Syn=false}', "");
Expect(0, 65094, '\p{Is_Pat_Syn=false}', "");
Expect(1, 65094, '\p{^Is_Pat_Syn=false}', "");
Expect(1, 65094, '\P{Is_Pat_Syn=false}', "");
Expect(0, 65094, '\P{^Is_Pat_Syn=false}', "");
Expect(1, 65095, '\p{Is_Pat_Syn: _ False}', "");
Expect(0, 65095, '\p{^Is_Pat_Syn: _ False}', "");
Expect(0, 65095, '\P{Is_Pat_Syn: _ False}', "");
Expect(1, 65095, '\P{^Is_Pat_Syn: _ False}', "");
Expect(0, 65094, '\p{Is_Pat_Syn: _ False}', "");
Expect(1, 65094, '\p{^Is_Pat_Syn: _ False}', "");
Expect(1, 65094, '\P{Is_Pat_Syn: _ False}', "");
Expect(0, 65094, '\P{^Is_Pat_Syn: _ False}', "");
Error('\p{Pattern_Syntax=/a/ 	yes}');
Error('\P{Pattern_Syntax=/a/ 	yes}');
Expect(1, 65094, '\p{Pattern_Syntax=yes}', "");
Expect(0, 65094, '\p{^Pattern_Syntax=yes}', "");
Expect(0, 65094, '\P{Pattern_Syntax=yes}', "");
Expect(1, 65094, '\P{^Pattern_Syntax=yes}', "");
Expect(0, 65095, '\p{Pattern_Syntax=yes}', "");
Expect(1, 65095, '\p{^Pattern_Syntax=yes}', "");
Expect(1, 65095, '\P{Pattern_Syntax=yes}', "");
Expect(0, 65095, '\P{^Pattern_Syntax=yes}', "");
Expect(1, 65094, '\p{Pattern_Syntax:   _Yes}', "");
Expect(0, 65094, '\p{^Pattern_Syntax:   _Yes}', "");
Expect(0, 65094, '\P{Pattern_Syntax:   _Yes}', "");
Expect(1, 65094, '\P{^Pattern_Syntax:   _Yes}', "");
Expect(0, 65095, '\p{Pattern_Syntax:   _Yes}', "");
Expect(1, 65095, '\p{^Pattern_Syntax:   _Yes}', "");
Expect(1, 65095, '\P{Pattern_Syntax:   _Yes}', "");
Expect(0, 65095, '\P{^Pattern_Syntax:   _Yes}', "");
Error('\p{Pat_Syn=	/a/Y}');
Error('\P{Pat_Syn=	/a/Y}');
Expect(1, 65094, '\p{Pat_Syn=y}', "");
Expect(0, 65094, '\p{^Pat_Syn=y}', "");
Expect(0, 65094, '\P{Pat_Syn=y}', "");
Expect(1, 65094, '\P{^Pat_Syn=y}', "");
Expect(0, 65095, '\p{Pat_Syn=y}', "");
Expect(1, 65095, '\p{^Pat_Syn=y}', "");
Expect(1, 65095, '\P{Pat_Syn=y}', "");
Expect(0, 65095, '\P{^Pat_Syn=y}', "");
Expect(1, 65094, '\p{Pat_Syn= -Y}', "");
Expect(0, 65094, '\p{^Pat_Syn= -Y}', "");
Expect(0, 65094, '\P{Pat_Syn= -Y}', "");
Expect(1, 65094, '\P{^Pat_Syn= -Y}', "");
Expect(0, 65095, '\p{Pat_Syn= -Y}', "");
Expect(1, 65095, '\p{^Pat_Syn= -Y}', "");
Expect(1, 65095, '\P{Pat_Syn= -Y}', "");
Expect(0, 65095, '\P{^Pat_Syn= -Y}', "");
Error('\p{Is_Pattern_Syntax= T/a/}');
Error('\P{Is_Pattern_Syntax= T/a/}');
Expect(1, 65094, '\p{Is_Pattern_Syntax:t}', "");
Expect(0, 65094, '\p{^Is_Pattern_Syntax:t}', "");
Expect(0, 65094, '\P{Is_Pattern_Syntax:t}', "");
Expect(1, 65094, '\P{^Is_Pattern_Syntax:t}', "");
Expect(0, 65095, '\p{Is_Pattern_Syntax:t}', "");
Expect(1, 65095, '\p{^Is_Pattern_Syntax:t}', "");
Expect(1, 65095, '\P{Is_Pattern_Syntax:t}', "");
Expect(0, 65095, '\P{^Is_Pattern_Syntax:t}', "");
Expect(1, 65094, '\p{Is_Pattern_Syntax=	-T}', "");
Expect(0, 65094, '\p{^Is_Pattern_Syntax=	-T}', "");
Expect(0, 65094, '\P{Is_Pattern_Syntax=	-T}', "");
Expect(1, 65094, '\P{^Is_Pattern_Syntax=	-T}', "");
Expect(0, 65095, '\p{Is_Pattern_Syntax=	-T}', "");
Expect(1, 65095, '\p{^Is_Pattern_Syntax=	-T}', "");
Expect(1, 65095, '\P{Is_Pattern_Syntax=	-T}', "");
Expect(0, 65095, '\P{^Is_Pattern_Syntax=	-T}', "");
Error('\p{Is_Pat_Syn: :=_-true}');
Error('\P{Is_Pat_Syn: :=_-true}');
Expect(1, 65094, '\p{Is_Pat_Syn=true}', "");
Expect(0, 65094, '\p{^Is_Pat_Syn=true}', "");
Expect(0, 65094, '\P{Is_Pat_Syn=true}', "");
Expect(1, 65094, '\P{^Is_Pat_Syn=true}', "");
Expect(0, 65095, '\p{Is_Pat_Syn=true}', "");
Expect(1, 65095, '\p{^Is_Pat_Syn=true}', "");
Expect(1, 65095, '\P{Is_Pat_Syn=true}', "");
Expect(0, 65095, '\P{^Is_Pat_Syn=true}', "");
Expect(1, 65094, '\p{Is_Pat_Syn=-True}', "");
Expect(0, 65094, '\p{^Is_Pat_Syn=-True}', "");
Expect(0, 65094, '\P{Is_Pat_Syn=-True}', "");
Expect(1, 65094, '\P{^Is_Pat_Syn=-True}', "");
Expect(0, 65095, '\p{Is_Pat_Syn=-True}', "");
Expect(1, 65095, '\p{^Is_Pat_Syn=-True}', "");
Expect(1, 65095, '\P{Is_Pat_Syn=-True}', "");
Expect(0, 65095, '\P{^Is_Pat_Syn=-True}', "");
Error('\p{Pattern_White_Space:   	no:=}');
Error('\P{Pattern_White_Space:   	no:=}');
Expect(1, 8234, '\p{Pattern_White_Space=no}', "");
Expect(0, 8234, '\p{^Pattern_White_Space=no}', "");
Expect(0, 8234, '\P{Pattern_White_Space=no}', "");
Expect(1, 8234, '\P{^Pattern_White_Space=no}', "");
Expect(0, 8233, '\p{Pattern_White_Space=no}', "");
Expect(1, 8233, '\p{^Pattern_White_Space=no}', "");
Expect(1, 8233, '\P{Pattern_White_Space=no}', "");
Expect(0, 8233, '\P{^Pattern_White_Space=no}', "");
Expect(1, 8234, '\p{Pattern_White_Space=NO}', "");
Expect(0, 8234, '\p{^Pattern_White_Space=NO}', "");
Expect(0, 8234, '\P{Pattern_White_Space=NO}', "");
Expect(1, 8234, '\P{^Pattern_White_Space=NO}', "");
Expect(0, 8233, '\p{Pattern_White_Space=NO}', "");
Expect(1, 8233, '\p{^Pattern_White_Space=NO}', "");
Expect(1, 8233, '\P{Pattern_White_Space=NO}', "");
Expect(0, 8233, '\P{^Pattern_White_Space=NO}', "");
Error('\p{Pat_WS=:=	n}');
Error('\P{Pat_WS=:=	n}');
Expect(1, 8234, '\p{Pat_WS=n}', "");
Expect(0, 8234, '\p{^Pat_WS=n}', "");
Expect(0, 8234, '\P{Pat_WS=n}', "");
Expect(1, 8234, '\P{^Pat_WS=n}', "");
Expect(0, 8233, '\p{Pat_WS=n}', "");
Expect(1, 8233, '\p{^Pat_WS=n}', "");
Expect(1, 8233, '\P{Pat_WS=n}', "");
Expect(0, 8233, '\P{^Pat_WS=n}', "");
Expect(1, 8234, '\p{Pat_WS=N}', "");
Expect(0, 8234, '\p{^Pat_WS=N}', "");
Expect(0, 8234, '\P{Pat_WS=N}', "");
Expect(1, 8234, '\P{^Pat_WS=N}', "");
Expect(0, 8233, '\p{Pat_WS=N}', "");
Expect(1, 8233, '\p{^Pat_WS=N}', "");
Expect(1, 8233, '\P{Pat_WS=N}', "");
Expect(0, 8233, '\P{^Pat_WS=N}', "");
Error('\p{Is_Pattern_White_Space=-:=f}');
Error('\P{Is_Pattern_White_Space=-:=f}');
Expect(1, 8234, '\p{Is_Pattern_White_Space=f}', "");
Expect(0, 8234, '\p{^Is_Pattern_White_Space=f}', "");
Expect(0, 8234, '\P{Is_Pattern_White_Space=f}', "");
Expect(1, 8234, '\P{^Is_Pattern_White_Space=f}', "");
Expect(0, 8233, '\p{Is_Pattern_White_Space=f}', "");
Expect(1, 8233, '\p{^Is_Pattern_White_Space=f}', "");
Expect(1, 8233, '\P{Is_Pattern_White_Space=f}', "");
Expect(0, 8233, '\P{^Is_Pattern_White_Space=f}', "");
Expect(1, 8234, '\p{Is_Pattern_White_Space:	 	F}', "");
Expect(0, 8234, '\p{^Is_Pattern_White_Space:	 	F}', "");
Expect(0, 8234, '\P{Is_Pattern_White_Space:	 	F}', "");
Expect(1, 8234, '\P{^Is_Pattern_White_Space:	 	F}', "");
Expect(0, 8233, '\p{Is_Pattern_White_Space:	 	F}', "");
Expect(1, 8233, '\p{^Is_Pattern_White_Space:	 	F}', "");
Expect(1, 8233, '\P{Is_Pattern_White_Space:	 	F}', "");
Expect(0, 8233, '\P{^Is_Pattern_White_Space:	 	F}', "");
Error('\p{Is_Pat_WS:/a/-_False}');
Error('\P{Is_Pat_WS:/a/-_False}');
Expect(1, 8234, '\p{Is_Pat_WS=false}', "");
Expect(0, 8234, '\p{^Is_Pat_WS=false}', "");
Expect(0, 8234, '\P{Is_Pat_WS=false}', "");
Expect(1, 8234, '\P{^Is_Pat_WS=false}', "");
Expect(0, 8233, '\p{Is_Pat_WS=false}', "");
Expect(1, 8233, '\p{^Is_Pat_WS=false}', "");
Expect(1, 8233, '\P{Is_Pat_WS=false}', "");
Expect(0, 8233, '\P{^Is_Pat_WS=false}', "");
Expect(1, 8234, '\p{Is_Pat_WS=_	false}', "");
Expect(0, 8234, '\p{^Is_Pat_WS=_	false}', "");
Expect(0, 8234, '\P{Is_Pat_WS=_	false}', "");
Expect(1, 8234, '\P{^Is_Pat_WS=_	false}', "");
Expect(0, 8233, '\p{Is_Pat_WS=_	false}', "");
Expect(1, 8233, '\p{^Is_Pat_WS=_	false}', "");
Expect(1, 8233, '\P{Is_Pat_WS=_	false}', "");
Expect(0, 8233, '\P{^Is_Pat_WS=_	false}', "");
Error('\p{Pattern_White_Space=_:=yes}');
Error('\P{Pattern_White_Space=_:=yes}');
Expect(1, 8233, '\p{Pattern_White_Space=yes}', "");
Expect(0, 8233, '\p{^Pattern_White_Space=yes}', "");
Expect(0, 8233, '\P{Pattern_White_Space=yes}', "");
Expect(1, 8233, '\P{^Pattern_White_Space=yes}', "");
Expect(0, 8234, '\p{Pattern_White_Space=yes}', "");
Expect(1, 8234, '\p{^Pattern_White_Space=yes}', "");
Expect(1, 8234, '\P{Pattern_White_Space=yes}', "");
Expect(0, 8234, '\P{^Pattern_White_Space=yes}', "");
Expect(1, 8233, '\p{Pattern_White_Space=_-Yes}', "");
Expect(0, 8233, '\p{^Pattern_White_Space=_-Yes}', "");
Expect(0, 8233, '\P{Pattern_White_Space=_-Yes}', "");
Expect(1, 8233, '\P{^Pattern_White_Space=_-Yes}', "");
Expect(0, 8234, '\p{Pattern_White_Space=_-Yes}', "");
Expect(1, 8234, '\p{^Pattern_White_Space=_-Yes}', "");
Expect(1, 8234, '\P{Pattern_White_Space=_-Yes}', "");
Expect(0, 8234, '\P{^Pattern_White_Space=_-Yes}', "");
Error('\p{Pat_WS=/a/_y}');
Error('\P{Pat_WS=/a/_y}');
Expect(1, 8233, '\p{Pat_WS=y}', "");
Expect(0, 8233, '\p{^Pat_WS=y}', "");
Expect(0, 8233, '\P{Pat_WS=y}', "");
Expect(1, 8233, '\P{^Pat_WS=y}', "");
Expect(0, 8234, '\p{Pat_WS=y}', "");
Expect(1, 8234, '\p{^Pat_WS=y}', "");
Expect(1, 8234, '\P{Pat_WS=y}', "");
Expect(0, 8234, '\P{^Pat_WS=y}', "");
Expect(1, 8233, '\p{Pat_WS=_-Y}', "");
Expect(0, 8233, '\p{^Pat_WS=_-Y}', "");
Expect(0, 8233, '\P{Pat_WS=_-Y}', "");
Expect(1, 8233, '\P{^Pat_WS=_-Y}', "");
Expect(0, 8234, '\p{Pat_WS=_-Y}', "");
Expect(1, 8234, '\p{^Pat_WS=_-Y}', "");
Expect(1, 8234, '\P{Pat_WS=_-Y}', "");
Expect(0, 8234, '\P{^Pat_WS=_-Y}', "");
Error('\p{Is_Pattern_White_Space=	/a/T}');
Error('\P{Is_Pattern_White_Space=	/a/T}');
Expect(1, 8233, '\p{Is_Pattern_White_Space=t}', "");
Expect(0, 8233, '\p{^Is_Pattern_White_Space=t}', "");
Expect(0, 8233, '\P{Is_Pattern_White_Space=t}', "");
Expect(1, 8233, '\P{^Is_Pattern_White_Space=t}', "");
Expect(0, 8234, '\p{Is_Pattern_White_Space=t}', "");
Expect(1, 8234, '\p{^Is_Pattern_White_Space=t}', "");
Expect(1, 8234, '\P{Is_Pattern_White_Space=t}', "");
Expect(0, 8234, '\P{^Is_Pattern_White_Space=t}', "");
Expect(1, 8233, '\p{Is_Pattern_White_Space=	_T}', "");
Expect(0, 8233, '\p{^Is_Pattern_White_Space=	_T}', "");
Expect(0, 8233, '\P{Is_Pattern_White_Space=	_T}', "");
Expect(1, 8233, '\P{^Is_Pattern_White_Space=	_T}', "");
Expect(0, 8234, '\p{Is_Pattern_White_Space=	_T}', "");
Expect(1, 8234, '\p{^Is_Pattern_White_Space=	_T}', "");
Expect(1, 8234, '\P{Is_Pattern_White_Space=	_T}', "");
Expect(0, 8234, '\P{^Is_Pattern_White_Space=	_T}', "");
Error('\p{Is_Pat_WS=:= true}');
Error('\P{Is_Pat_WS=:= true}');
Expect(1, 8233, '\p{Is_Pat_WS=true}', "");
Expect(0, 8233, '\p{^Is_Pat_WS=true}', "");
Expect(0, 8233, '\P{Is_Pat_WS=true}', "");
Expect(1, 8233, '\P{^Is_Pat_WS=true}', "");
Expect(0, 8234, '\p{Is_Pat_WS=true}', "");
Expect(1, 8234, '\p{^Is_Pat_WS=true}', "");
Expect(1, 8234, '\P{Is_Pat_WS=true}', "");
Expect(0, 8234, '\P{^Is_Pat_WS=true}', "");
Expect(1, 8233, '\p{Is_Pat_WS=  TRUE}', "");
Expect(0, 8233, '\p{^Is_Pat_WS=  TRUE}', "");
Expect(0, 8233, '\P{Is_Pat_WS=  TRUE}', "");
Expect(1, 8233, '\P{^Is_Pat_WS=  TRUE}', "");
Expect(0, 8234, '\p{Is_Pat_WS=  TRUE}', "");
Expect(1, 8234, '\p{^Is_Pat_WS=  TRUE}', "");
Expect(1, 8234, '\P{Is_Pat_WS=  TRUE}', "");
Expect(0, 8234, '\P{^Is_Pat_WS=  TRUE}', "");
Error('\p{Quotation_Mark=--No/a/}');
Error('\P{Quotation_Mark=--No/a/}');
Expect(1, 65380, '\p{Quotation_Mark=no}', "");
Expect(0, 65380, '\p{^Quotation_Mark=no}', "");
Expect(0, 65380, '\P{Quotation_Mark=no}', "");
Expect(1, 65380, '\P{^Quotation_Mark=no}', "");
Expect(0, 65379, '\p{Quotation_Mark=no}', "");
Expect(1, 65379, '\p{^Quotation_Mark=no}', "");
Expect(1, 65379, '\P{Quotation_Mark=no}', "");
Expect(0, 65379, '\P{^Quotation_Mark=no}', "");
Expect(1, 65380, '\p{Quotation_Mark= _No}', "");
Expect(0, 65380, '\p{^Quotation_Mark= _No}', "");
Expect(0, 65380, '\P{Quotation_Mark= _No}', "");
Expect(1, 65380, '\P{^Quotation_Mark= _No}', "");
Expect(0, 65379, '\p{Quotation_Mark= _No}', "");
Expect(1, 65379, '\p{^Quotation_Mark= _No}', "");
Expect(1, 65379, '\P{Quotation_Mark= _No}', "");
Expect(0, 65379, '\P{^Quotation_Mark= _No}', "");
Error('\p{QMark=:= 	n}');
Error('\P{QMark=:= 	n}');
Expect(1, 65380, '\p{QMark=n}', "");
Expect(0, 65380, '\p{^QMark=n}', "");
Expect(0, 65380, '\P{QMark=n}', "");
Expect(1, 65380, '\P{^QMark=n}', "");
Expect(0, 65379, '\p{QMark=n}', "");
Expect(1, 65379, '\p{^QMark=n}', "");
Expect(1, 65379, '\P{QMark=n}', "");
Expect(0, 65379, '\P{^QMark=n}', "");
Expect(1, 65380, '\p{QMark=_	n}', "");
Expect(0, 65380, '\p{^QMark=_	n}', "");
Expect(0, 65380, '\P{QMark=_	n}', "");
Expect(1, 65380, '\P{^QMark=_	n}', "");
Expect(0, 65379, '\p{QMark=_	n}', "");
Expect(1, 65379, '\p{^QMark=_	n}', "");
Expect(1, 65379, '\P{QMark=_	n}', "");
Expect(0, 65379, '\P{^QMark=_	n}', "");
Error('\p{Is_Quotation_Mark:   :=-_F}');
Error('\P{Is_Quotation_Mark:   :=-_F}');
Expect(1, 65380, '\p{Is_Quotation_Mark=f}', "");
Expect(0, 65380, '\p{^Is_Quotation_Mark=f}', "");
Expect(0, 65380, '\P{Is_Quotation_Mark=f}', "");
Expect(1, 65380, '\P{^Is_Quotation_Mark=f}', "");
Expect(0, 65379, '\p{Is_Quotation_Mark=f}', "");
Expect(1, 65379, '\p{^Is_Quotation_Mark=f}', "");
Expect(1, 65379, '\P{Is_Quotation_Mark=f}', "");
Expect(0, 65379, '\P{^Is_Quotation_Mark=f}', "");
Expect(1, 65380, '\p{Is_Quotation_Mark= 	F}', "");
Expect(0, 65380, '\p{^Is_Quotation_Mark= 	F}', "");
Expect(0, 65380, '\P{Is_Quotation_Mark= 	F}', "");
Expect(1, 65380, '\P{^Is_Quotation_Mark= 	F}', "");
Expect(0, 65379, '\p{Is_Quotation_Mark= 	F}', "");
Expect(1, 65379, '\p{^Is_Quotation_Mark= 	F}', "");
Expect(1, 65379, '\P{Is_Quotation_Mark= 	F}', "");
Expect(0, 65379, '\P{^Is_Quotation_Mark= 	F}', "");
Error('\p{Is_QMark=_/a/False}');
Error('\P{Is_QMark=_/a/False}');
Expect(1, 65380, '\p{Is_QMark=false}', "");
Expect(0, 65380, '\p{^Is_QMark=false}', "");
Expect(0, 65380, '\P{Is_QMark=false}', "");
Expect(1, 65380, '\P{^Is_QMark=false}', "");
Expect(0, 65379, '\p{Is_QMark=false}', "");
Expect(1, 65379, '\p{^Is_QMark=false}', "");
Expect(1, 65379, '\P{Is_QMark=false}', "");
Expect(0, 65379, '\P{^Is_QMark=false}', "");
Expect(1, 65380, '\p{Is_QMark=--false}', "");
Expect(0, 65380, '\p{^Is_QMark=--false}', "");
Expect(0, 65380, '\P{Is_QMark=--false}', "");
Expect(1, 65380, '\P{^Is_QMark=--false}', "");
Expect(0, 65379, '\p{Is_QMark=--false}', "");
Expect(1, 65379, '\p{^Is_QMark=--false}', "");
Expect(1, 65379, '\P{Is_QMark=--false}', "");
Expect(0, 65379, '\P{^Is_QMark=--false}', "");
Error('\p{Quotation_Mark=:=	 yes}');
Error('\P{Quotation_Mark=:=	 yes}');
Expect(1, 65379, '\p{Quotation_Mark=yes}', "");
Expect(0, 65379, '\p{^Quotation_Mark=yes}', "");
Expect(0, 65379, '\P{Quotation_Mark=yes}', "");
Expect(1, 65379, '\P{^Quotation_Mark=yes}', "");
Expect(0, 65380, '\p{Quotation_Mark=yes}', "");
Expect(1, 65380, '\p{^Quotation_Mark=yes}', "");
Expect(1, 65380, '\P{Quotation_Mark=yes}', "");
Expect(0, 65380, '\P{^Quotation_Mark=yes}', "");
Expect(1, 65379, '\p{Quotation_Mark:-	Yes}', "");
Expect(0, 65379, '\p{^Quotation_Mark:-	Yes}', "");
Expect(0, 65379, '\P{Quotation_Mark:-	Yes}', "");
Expect(1, 65379, '\P{^Quotation_Mark:-	Yes}', "");
Expect(0, 65380, '\p{Quotation_Mark:-	Yes}', "");
Expect(1, 65380, '\p{^Quotation_Mark:-	Yes}', "");
Expect(1, 65380, '\P{Quotation_Mark:-	Yes}', "");
Expect(0, 65380, '\P{^Quotation_Mark:-	Yes}', "");
Error('\p{QMark=/a/__Y}');
Error('\P{QMark=/a/__Y}');
Expect(1, 65379, '\p{QMark=y}', "");
Expect(0, 65379, '\p{^QMark=y}', "");
Expect(0, 65379, '\P{QMark=y}', "");
Expect(1, 65379, '\P{^QMark=y}', "");
Expect(0, 65380, '\p{QMark=y}', "");
Expect(1, 65380, '\p{^QMark=y}', "");
Expect(1, 65380, '\P{QMark=y}', "");
Expect(0, 65380, '\P{^QMark=y}', "");
Expect(1, 65379, '\p{QMark=	y}', "");
Expect(0, 65379, '\p{^QMark=	y}', "");
Expect(0, 65379, '\P{QMark=	y}', "");
Expect(1, 65379, '\P{^QMark=	y}', "");
Expect(0, 65380, '\p{QMark=	y}', "");
Expect(1, 65380, '\p{^QMark=	y}', "");
Expect(1, 65380, '\P{QMark=	y}', "");
Expect(0, 65380, '\P{^QMark=	y}', "");
Error('\p{Is_Quotation_Mark=/a/_-T}');
Error('\P{Is_Quotation_Mark=/a/_-T}');
Expect(1, 65379, '\p{Is_Quotation_Mark=t}', "");
Expect(0, 65379, '\p{^Is_Quotation_Mark=t}', "");
Expect(0, 65379, '\P{Is_Quotation_Mark=t}', "");
Expect(1, 65379, '\P{^Is_Quotation_Mark=t}', "");
Expect(0, 65380, '\p{Is_Quotation_Mark=t}', "");
Expect(1, 65380, '\p{^Is_Quotation_Mark=t}', "");
Expect(1, 65380, '\P{Is_Quotation_Mark=t}', "");
Expect(0, 65380, '\P{^Is_Quotation_Mark=t}', "");
Expect(1, 65379, '\p{Is_Quotation_Mark=_ t}', "");
Expect(0, 65379, '\p{^Is_Quotation_Mark=_ t}', "");
Expect(0, 65379, '\P{Is_Quotation_Mark=_ t}', "");
Expect(1, 65379, '\P{^Is_Quotation_Mark=_ t}', "");
Expect(0, 65380, '\p{Is_Quotation_Mark=_ t}', "");
Expect(1, 65380, '\p{^Is_Quotation_Mark=_ t}', "");
Expect(1, 65380, '\P{Is_Quotation_Mark=_ t}', "");
Expect(0, 65380, '\P{^Is_Quotation_Mark=_ t}', "");
Error('\p{Is_QMark:	:=TRUE}');
Error('\P{Is_QMark:	:=TRUE}');
Expect(1, 65379, '\p{Is_QMark=true}', "");
Expect(0, 65379, '\p{^Is_QMark=true}', "");
Expect(0, 65379, '\P{Is_QMark=true}', "");
Expect(1, 65379, '\P{^Is_QMark=true}', "");
Expect(0, 65380, '\p{Is_QMark=true}', "");
Expect(1, 65380, '\p{^Is_QMark=true}', "");
Expect(1, 65380, '\P{Is_QMark=true}', "");
Expect(0, 65380, '\P{^Is_QMark=true}', "");
Expect(1, 65379, '\p{Is_QMark=-TRUE}', "");
Expect(0, 65379, '\p{^Is_QMark=-TRUE}', "");
Expect(0, 65379, '\P{Is_QMark=-TRUE}', "");
Expect(1, 65379, '\P{^Is_QMark=-TRUE}', "");
Expect(0, 65380, '\p{Is_QMark=-TRUE}', "");
Expect(1, 65380, '\p{^Is_QMark=-TRUE}', "");
Expect(1, 65380, '\P{Is_QMark=-TRUE}', "");
Expect(0, 65380, '\P{^Is_QMark=-TRUE}', "");
Error('\p{Radical=-:=No}');
Error('\P{Radical=-:=No}');
Expect(1, 12246, '\p{Radical=no}', "");
Expect(0, 12246, '\p{^Radical=no}', "");
Expect(0, 12246, '\P{Radical=no}', "");
Expect(1, 12246, '\P{^Radical=no}', "");
Expect(0, 12245, '\p{Radical=no}', "");
Expect(1, 12245, '\p{^Radical=no}', "");
Expect(1, 12245, '\P{Radical=no}', "");
Expect(0, 12245, '\P{^Radical=no}', "");
Expect(1, 12246, '\p{Radical=_-No}', "");
Expect(0, 12246, '\p{^Radical=_-No}', "");
Expect(0, 12246, '\P{Radical=_-No}', "");
Expect(1, 12246, '\P{^Radical=_-No}', "");
Expect(0, 12245, '\p{Radical=_-No}', "");
Expect(1, 12245, '\p{^Radical=_-No}', "");
Expect(1, 12245, '\P{Radical=_-No}', "");
Expect(0, 12245, '\P{^Radical=_-No}', "");
Error('\p{Is_Radical=/a/ N}');
Error('\P{Is_Radical=/a/ N}');
Expect(1, 12246, '\p{Is_Radical=n}', "");
Expect(0, 12246, '\p{^Is_Radical=n}', "");
Expect(0, 12246, '\P{Is_Radical=n}', "");
Expect(1, 12246, '\P{^Is_Radical=n}', "");
Expect(0, 12245, '\p{Is_Radical=n}', "");
Expect(1, 12245, '\p{^Is_Radical=n}', "");
Expect(1, 12245, '\P{Is_Radical=n}', "");
Expect(0, 12245, '\P{^Is_Radical=n}', "");
Expect(1, 12246, '\p{Is_Radical=__N}', "");
Expect(0, 12246, '\p{^Is_Radical=__N}', "");
Expect(0, 12246, '\P{Is_Radical=__N}', "");
Expect(1, 12246, '\P{^Is_Radical=__N}', "");
Expect(0, 12245, '\p{Is_Radical=__N}', "");
Expect(1, 12245, '\p{^Is_Radical=__N}', "");
Expect(1, 12245, '\P{Is_Radical=__N}', "");
Expect(0, 12245, '\P{^Is_Radical=__N}', "");
Error('\p{Radical=_-f/a/}');
Error('\P{Radical=_-f/a/}');
Expect(1, 12246, '\p{Radical=f}', "");
Expect(0, 12246, '\p{^Radical=f}', "");
Expect(0, 12246, '\P{Radical=f}', "");
Expect(1, 12246, '\P{^Radical=f}', "");
Expect(0, 12245, '\p{Radical=f}', "");
Expect(1, 12245, '\p{^Radical=f}', "");
Expect(1, 12245, '\P{Radical=f}', "");
Expect(0, 12245, '\P{^Radical=f}', "");
Expect(1, 12246, '\p{Radical=-	f}', "");
Expect(0, 12246, '\p{^Radical=-	f}', "");
Expect(0, 12246, '\P{Radical=-	f}', "");
Expect(1, 12246, '\P{^Radical=-	f}', "");
Expect(0, 12245, '\p{Radical=-	f}', "");
Expect(1, 12245, '\p{^Radical=-	f}', "");
Expect(1, 12245, '\P{Radical=-	f}', "");
Expect(0, 12245, '\P{^Radical=-	f}', "");
Error('\p{Is_Radical=-:=False}');
Error('\P{Is_Radical=-:=False}');
Expect(1, 12246, '\p{Is_Radical=false}', "");
Expect(0, 12246, '\p{^Is_Radical=false}', "");
Expect(0, 12246, '\P{Is_Radical=false}', "");
Expect(1, 12246, '\P{^Is_Radical=false}', "");
Expect(0, 12245, '\p{Is_Radical=false}', "");
Expect(1, 12245, '\p{^Is_Radical=false}', "");
Expect(1, 12245, '\P{Is_Radical=false}', "");
Expect(0, 12245, '\P{^Is_Radical=false}', "");
Expect(1, 12246, '\p{Is_Radical:   FALSE}', "");
Expect(0, 12246, '\p{^Is_Radical:   FALSE}', "");
Expect(0, 12246, '\P{Is_Radical:   FALSE}', "");
Expect(1, 12246, '\P{^Is_Radical:   FALSE}', "");
Expect(0, 12245, '\p{Is_Radical:   FALSE}', "");
Expect(1, 12245, '\p{^Is_Radical:   FALSE}', "");
Expect(1, 12245, '\P{Is_Radical:   FALSE}', "");
Expect(0, 12245, '\P{^Is_Radical:   FALSE}', "");
Error('\p{Radical=/a/_	YES}');
Error('\P{Radical=/a/_	YES}');
Expect(1, 12245, '\p{Radical=yes}', "");
Expect(0, 12245, '\p{^Radical=yes}', "");
Expect(0, 12245, '\P{Radical=yes}', "");
Expect(1, 12245, '\P{^Radical=yes}', "");
Expect(0, 12246, '\p{Radical=yes}', "");
Expect(1, 12246, '\p{^Radical=yes}', "");
Expect(1, 12246, '\P{Radical=yes}', "");
Expect(0, 12246, '\P{^Radical=yes}', "");
Expect(1, 12245, '\p{Radical:   - Yes}', "");
Expect(0, 12245, '\p{^Radical:   - Yes}', "");
Expect(0, 12245, '\P{Radical:   - Yes}', "");
Expect(1, 12245, '\P{^Radical:   - Yes}', "");
Expect(0, 12246, '\p{Radical:   - Yes}', "");
Expect(1, 12246, '\p{^Radical:   - Yes}', "");
Expect(1, 12246, '\P{Radical:   - Yes}', "");
Expect(0, 12246, '\P{^Radical:   - Yes}', "");
Error('\p{Is_Radical=--Y:=}');
Error('\P{Is_Radical=--Y:=}');
Expect(1, 12245, '\p{Is_Radical=y}', "");
Expect(0, 12245, '\p{^Is_Radical=y}', "");
Expect(0, 12245, '\P{Is_Radical=y}', "");
Expect(1, 12245, '\P{^Is_Radical=y}', "");
Expect(0, 12246, '\p{Is_Radical=y}', "");
Expect(1, 12246, '\p{^Is_Radical=y}', "");
Expect(1, 12246, '\P{Is_Radical=y}', "");
Expect(0, 12246, '\P{^Is_Radical=y}', "");
Expect(1, 12245, '\p{Is_Radical=_	Y}', "");
Expect(0, 12245, '\p{^Is_Radical=_	Y}', "");
Expect(0, 12245, '\P{Is_Radical=_	Y}', "");
Expect(1, 12245, '\P{^Is_Radical=_	Y}', "");
Expect(0, 12246, '\p{Is_Radical=_	Y}', "");
Expect(1, 12246, '\p{^Is_Radical=_	Y}', "");
Expect(1, 12246, '\P{Is_Radical=_	Y}', "");
Expect(0, 12246, '\P{^Is_Radical=_	Y}', "");
Error('\p{Radical=-:=t}');
Error('\P{Radical=-:=t}');
Expect(1, 12245, '\p{Radical=t}', "");
Expect(0, 12245, '\p{^Radical=t}', "");
Expect(0, 12245, '\P{Radical=t}', "");
Expect(1, 12245, '\P{^Radical=t}', "");
Expect(0, 12246, '\p{Radical=t}', "");
Expect(1, 12246, '\p{^Radical=t}', "");
Expect(1, 12246, '\P{Radical=t}', "");
Expect(0, 12246, '\P{^Radical=t}', "");
Expect(1, 12245, '\p{Radical=_T}', "");
Expect(0, 12245, '\p{^Radical=_T}', "");
Expect(0, 12245, '\P{Radical=_T}', "");
Expect(1, 12245, '\P{^Radical=_T}', "");
Expect(0, 12246, '\p{Radical=_T}', "");
Expect(1, 12246, '\p{^Radical=_T}', "");
Expect(1, 12246, '\P{Radical=_T}', "");
Expect(0, 12246, '\P{^Radical=_T}', "");
Error('\p{Is_Radical=/a/	-TRUE}');
Error('\P{Is_Radical=/a/	-TRUE}');
Expect(1, 12245, '\p{Is_Radical=true}', "");
Expect(0, 12245, '\p{^Is_Radical=true}', "");
Expect(0, 12245, '\P{Is_Radical=true}', "");
Expect(1, 12245, '\P{^Is_Radical=true}', "");
Expect(0, 12246, '\p{Is_Radical=true}', "");
Expect(1, 12246, '\p{^Is_Radical=true}', "");
Expect(1, 12246, '\P{Is_Radical=true}', "");
Expect(0, 12246, '\P{^Is_Radical=true}', "");
Expect(1, 12245, '\p{Is_Radical=-_True}', "");
Expect(0, 12245, '\p{^Is_Radical=-_True}', "");
Expect(0, 12245, '\P{Is_Radical=-_True}', "");
Expect(1, 12245, '\P{^Is_Radical=-_True}', "");
Expect(0, 12246, '\p{Is_Radical=-_True}', "");
Expect(1, 12246, '\p{^Is_Radical=-_True}', "");
Expect(1, 12246, '\P{Is_Radical=-_True}', "");
Expect(0, 12246, '\P{^Is_Radical=-_True}', "");
Error('\p{Sentence_Break=aterm/a/}');
Error('\P{Sentence_Break=aterm/a/}');
Expect(1, 65294, '\p{Sentence_Break=aterm}', "");
Expect(0, 65294, '\p{^Sentence_Break=aterm}', "");
Expect(0, 65294, '\P{Sentence_Break=aterm}', "");
Expect(1, 65294, '\P{^Sentence_Break=aterm}', "");
Expect(0, 65295, '\p{Sentence_Break=aterm}', "");
Expect(1, 65295, '\p{^Sentence_Break=aterm}', "");
Expect(1, 65295, '\P{Sentence_Break=aterm}', "");
Expect(0, 65295, '\P{^Sentence_Break=aterm}', "");
Expect(1, 65294, '\p{Sentence_Break:	ATERM}', "");
Expect(0, 65294, '\p{^Sentence_Break:	ATERM}', "");
Expect(0, 65294, '\P{Sentence_Break:	ATERM}', "");
Expect(1, 65294, '\P{^Sentence_Break:	ATERM}', "");
Expect(0, 65295, '\p{Sentence_Break:	ATERM}', "");
Expect(1, 65295, '\p{^Sentence_Break:	ATERM}', "");
Expect(1, 65295, '\P{Sentence_Break:	ATERM}', "");
Expect(0, 65295, '\P{^Sentence_Break:	ATERM}', "");
Error('\p{SB=:=	_AT}');
Error('\P{SB=:=	_AT}');
Expect(1, 65294, '\p{SB=at}', "");
Expect(0, 65294, '\p{^SB=at}', "");
Expect(0, 65294, '\P{SB=at}', "");
Expect(1, 65294, '\P{^SB=at}', "");
Expect(0, 65295, '\p{SB=at}', "");
Expect(1, 65295, '\p{^SB=at}', "");
Expect(1, 65295, '\P{SB=at}', "");
Expect(0, 65295, '\P{^SB=at}', "");
Expect(1, 65294, '\p{SB= AT}', "");
Expect(0, 65294, '\p{^SB= AT}', "");
Expect(0, 65294, '\P{SB= AT}', "");
Expect(1, 65294, '\P{^SB= AT}', "");
Expect(0, 65295, '\p{SB= AT}', "");
Expect(1, 65295, '\p{^SB= AT}', "");
Expect(1, 65295, '\P{SB= AT}', "");
Expect(0, 65295, '\P{^SB= AT}', "");
Error('\p{Is_Sentence_Break=_/a/ATerm}');
Error('\P{Is_Sentence_Break=_/a/ATerm}');
Expect(1, 65294, '\p{Is_Sentence_Break=aterm}', "");
Expect(0, 65294, '\p{^Is_Sentence_Break=aterm}', "");
Expect(0, 65294, '\P{Is_Sentence_Break=aterm}', "");
Expect(1, 65294, '\P{^Is_Sentence_Break=aterm}', "");
Expect(0, 65295, '\p{Is_Sentence_Break=aterm}', "");
Expect(1, 65295, '\p{^Is_Sentence_Break=aterm}', "");
Expect(1, 65295, '\P{Is_Sentence_Break=aterm}', "");
Expect(0, 65295, '\P{^Is_Sentence_Break=aterm}', "");
Expect(1, 65294, '\p{Is_Sentence_Break=	 ATerm}', "");
Expect(0, 65294, '\p{^Is_Sentence_Break=	 ATerm}', "");
Expect(0, 65294, '\P{Is_Sentence_Break=	 ATerm}', "");
Expect(1, 65294, '\P{^Is_Sentence_Break=	 ATerm}', "");
Expect(0, 65295, '\p{Is_Sentence_Break=	 ATerm}', "");
Expect(1, 65295, '\p{^Is_Sentence_Break=	 ATerm}', "");
Expect(1, 65295, '\P{Is_Sentence_Break=	 ATerm}', "");
Expect(0, 65295, '\P{^Is_Sentence_Break=	 ATerm}', "");
Error('\p{Is_SB:   :=AT}');
Error('\P{Is_SB:   :=AT}');
Expect(1, 65294, '\p{Is_SB=at}', "");
Expect(0, 65294, '\p{^Is_SB=at}', "");
Expect(0, 65294, '\P{Is_SB=at}', "");
Expect(1, 65294, '\P{^Is_SB=at}', "");
Expect(0, 65295, '\p{Is_SB=at}', "");
Expect(1, 65295, '\p{^Is_SB=at}', "");
Expect(1, 65295, '\P{Is_SB=at}', "");
Expect(0, 65295, '\P{^Is_SB=at}', "");
Expect(1, 65294, '\p{Is_SB= AT}', "");
Expect(0, 65294, '\p{^Is_SB= AT}', "");
Expect(0, 65294, '\P{Is_SB= AT}', "");
Expect(1, 65294, '\P{^Is_SB= AT}', "");
Expect(0, 65295, '\p{Is_SB= AT}', "");
Expect(1, 65295, '\p{^Is_SB= AT}', "");
Expect(1, 65295, '\P{Is_SB= AT}', "");
Expect(0, 65295, '\P{^Is_SB= AT}', "");
Error('\p{Sentence_Break=:=_	close}');
Error('\P{Sentence_Break=:=_	close}');
Expect(1, 65379, '\p{Sentence_Break=close}', "");
Expect(0, 65379, '\p{^Sentence_Break=close}', "");
Expect(0, 65379, '\P{Sentence_Break=close}', "");
Expect(1, 65379, '\P{^Sentence_Break=close}', "");
Expect(0, 65380, '\p{Sentence_Break=close}', "");
Expect(1, 65380, '\p{^Sentence_Break=close}', "");
Expect(1, 65380, '\P{Sentence_Break=close}', "");
Expect(0, 65380, '\P{^Sentence_Break=close}', "");
Expect(1, 65379, '\p{Sentence_Break=	-Close}', "");
Expect(0, 65379, '\p{^Sentence_Break=	-Close}', "");
Expect(0, 65379, '\P{Sentence_Break=	-Close}', "");
Expect(1, 65379, '\P{^Sentence_Break=	-Close}', "");
Expect(0, 65380, '\p{Sentence_Break=	-Close}', "");
Expect(1, 65380, '\p{^Sentence_Break=	-Close}', "");
Expect(1, 65380, '\P{Sentence_Break=	-Close}', "");
Expect(0, 65380, '\P{^Sentence_Break=	-Close}', "");
Error('\p{SB= _CL/a/}');
Error('\P{SB= _CL/a/}');
Expect(1, 65379, '\p{SB=cl}', "");
Expect(0, 65379, '\p{^SB=cl}', "");
Expect(0, 65379, '\P{SB=cl}', "");
Expect(1, 65379, '\P{^SB=cl}', "");
Expect(0, 65380, '\p{SB=cl}', "");
Expect(1, 65380, '\p{^SB=cl}', "");
Expect(1, 65380, '\P{SB=cl}', "");
Expect(0, 65380, '\P{^SB=cl}', "");
Expect(1, 65379, '\p{SB=		cl}', "");
Expect(0, 65379, '\p{^SB=		cl}', "");
Expect(0, 65379, '\P{SB=		cl}', "");
Expect(1, 65379, '\P{^SB=		cl}', "");
Expect(0, 65380, '\p{SB=		cl}', "");
Expect(1, 65380, '\p{^SB=		cl}', "");
Expect(1, 65380, '\P{SB=		cl}', "");
Expect(0, 65380, '\P{^SB=		cl}', "");
Error('\p{Is_Sentence_Break= /a/Close}');
Error('\P{Is_Sentence_Break= /a/Close}');
Expect(1, 65379, '\p{Is_Sentence_Break=close}', "");
Expect(0, 65379, '\p{^Is_Sentence_Break=close}', "");
Expect(0, 65379, '\P{Is_Sentence_Break=close}', "");
Expect(1, 65379, '\P{^Is_Sentence_Break=close}', "");
Expect(0, 65380, '\p{Is_Sentence_Break=close}', "");
Expect(1, 65380, '\p{^Is_Sentence_Break=close}', "");
Expect(1, 65380, '\P{Is_Sentence_Break=close}', "");
Expect(0, 65380, '\P{^Is_Sentence_Break=close}', "");
Expect(1, 65379, '\p{Is_Sentence_Break=_	Close}', "");
Expect(0, 65379, '\p{^Is_Sentence_Break=_	Close}', "");
Expect(0, 65379, '\P{Is_Sentence_Break=_	Close}', "");
Expect(1, 65379, '\P{^Is_Sentence_Break=_	Close}', "");
Expect(0, 65380, '\p{Is_Sentence_Break=_	Close}', "");
Expect(1, 65380, '\p{^Is_Sentence_Break=_	Close}', "");
Expect(1, 65380, '\P{Is_Sentence_Break=_	Close}', "");
Expect(0, 65380, '\P{^Is_Sentence_Break=_	Close}', "");
Error('\p{Is_SB=:=CL}');
Error('\P{Is_SB=:=CL}');
Expect(1, 65379, '\p{Is_SB=cl}', "");
Expect(0, 65379, '\p{^Is_SB=cl}', "");
Expect(0, 65379, '\P{Is_SB=cl}', "");
Expect(1, 65379, '\P{^Is_SB=cl}', "");
Expect(0, 65380, '\p{Is_SB=cl}', "");
Expect(1, 65380, '\p{^Is_SB=cl}', "");
Expect(1, 65380, '\P{Is_SB=cl}', "");
Expect(0, 65380, '\P{^Is_SB=cl}', "");
Expect(1, 65379, '\p{Is_SB=_	CL}', "");
Expect(0, 65379, '\p{^Is_SB=_	CL}', "");
Expect(0, 65379, '\P{Is_SB=_	CL}', "");
Expect(1, 65379, '\P{^Is_SB=_	CL}', "");
Expect(0, 65380, '\p{Is_SB=_	CL}', "");
Expect(1, 65380, '\p{^Is_SB=_	CL}', "");
Expect(1, 65380, '\P{Is_SB=_	CL}', "");
Expect(0, 65380, '\P{^Is_SB=_	CL}', "");
Error('\p{Sentence_Break=/a/_ CR}');
Error('\P{Sentence_Break=/a/_ CR}');
Expect(1, 13, '\p{Sentence_Break=cr}', "");
Expect(0, 13, '\p{^Sentence_Break=cr}', "");
Expect(0, 13, '\P{Sentence_Break=cr}', "");
Expect(1, 13, '\P{^Sentence_Break=cr}', "");
Expect(0, 14, '\p{Sentence_Break=cr}', "");
Expect(1, 14, '\p{^Sentence_Break=cr}', "");
Expect(1, 14, '\P{Sentence_Break=cr}', "");
Expect(0, 14, '\P{^Sentence_Break=cr}', "");
Expect(1, 13, '\p{Sentence_Break=__CR}', "");
Expect(0, 13, '\p{^Sentence_Break=__CR}', "");
Expect(0, 13, '\P{Sentence_Break=__CR}', "");
Expect(1, 13, '\P{^Sentence_Break=__CR}', "");
Expect(0, 14, '\p{Sentence_Break=__CR}', "");
Expect(1, 14, '\p{^Sentence_Break=__CR}', "");
Expect(1, 14, '\P{Sentence_Break=__CR}', "");
Expect(0, 14, '\P{^Sentence_Break=__CR}', "");
Error('\p{SB=/a/_CR}');
Error('\P{SB=/a/_CR}');
Expect(1, 13, '\p{SB:cr}', "");
Expect(0, 13, '\p{^SB:cr}', "");
Expect(0, 13, '\P{SB:cr}', "");
Expect(1, 13, '\P{^SB:cr}', "");
Expect(0, 14, '\p{SB:cr}', "");
Expect(1, 14, '\p{^SB:cr}', "");
Expect(1, 14, '\P{SB:cr}', "");
Expect(0, 14, '\P{^SB:cr}', "");
Expect(1, 13, '\p{SB=_CR}', "");
Expect(0, 13, '\p{^SB=_CR}', "");
Expect(0, 13, '\P{SB=_CR}', "");
Expect(1, 13, '\P{^SB=_CR}', "");
Expect(0, 14, '\p{SB=_CR}', "");
Expect(1, 14, '\p{^SB=_CR}', "");
Expect(1, 14, '\P{SB=_CR}', "");
Expect(0, 14, '\P{^SB=_CR}', "");
Error('\p{Is_Sentence_Break=:=cr}');
Error('\P{Is_Sentence_Break=:=cr}');
Expect(1, 13, '\p{Is_Sentence_Break=cr}', "");
Expect(0, 13, '\p{^Is_Sentence_Break=cr}', "");
Expect(0, 13, '\P{Is_Sentence_Break=cr}', "");
Expect(1, 13, '\P{^Is_Sentence_Break=cr}', "");
Expect(0, 14, '\p{Is_Sentence_Break=cr}', "");
Expect(1, 14, '\p{^Is_Sentence_Break=cr}', "");
Expect(1, 14, '\P{Is_Sentence_Break=cr}', "");
Expect(0, 14, '\P{^Is_Sentence_Break=cr}', "");
Expect(1, 13, '\p{Is_Sentence_Break=CR}', "");
Expect(0, 13, '\p{^Is_Sentence_Break=CR}', "");
Expect(0, 13, '\P{Is_Sentence_Break=CR}', "");
Expect(1, 13, '\P{^Is_Sentence_Break=CR}', "");
Expect(0, 14, '\p{Is_Sentence_Break=CR}', "");
Expect(1, 14, '\p{^Is_Sentence_Break=CR}', "");
Expect(1, 14, '\P{Is_Sentence_Break=CR}', "");
Expect(0, 14, '\P{^Is_Sentence_Break=CR}', "");
Error('\p{Is_SB=_	CR:=}');
Error('\P{Is_SB=_	CR:=}');
Expect(1, 13, '\p{Is_SB=cr}', "");
Expect(0, 13, '\p{^Is_SB=cr}', "");
Expect(0, 13, '\P{Is_SB=cr}', "");
Expect(1, 13, '\P{^Is_SB=cr}', "");
Expect(0, 14, '\p{Is_SB=cr}', "");
Expect(1, 14, '\p{^Is_SB=cr}', "");
Expect(1, 14, '\P{Is_SB=cr}', "");
Expect(0, 14, '\P{^Is_SB=cr}', "");
Expect(1, 13, '\p{Is_SB=	 CR}', "");
Expect(0, 13, '\p{^Is_SB=	 CR}', "");
Expect(0, 13, '\P{Is_SB=	 CR}', "");
Expect(1, 13, '\P{^Is_SB=	 CR}', "");
Expect(0, 14, '\p{Is_SB=	 CR}', "");
Expect(1, 14, '\p{^Is_SB=	 CR}', "");
Expect(1, 14, '\P{Is_SB=	 CR}', "");
Expect(0, 14, '\P{^Is_SB=	 CR}', "");
Error('\p{Sentence_Break: :=Extend}');
Error('\P{Sentence_Break: :=Extend}');
Expect(1, 917999, '\p{Sentence_Break=extend}', "");
Expect(0, 917999, '\p{^Sentence_Break=extend}', "");
Expect(0, 917999, '\P{Sentence_Break=extend}', "");
Expect(1, 917999, '\P{^Sentence_Break=extend}', "");
Expect(0, 918000, '\p{Sentence_Break=extend}', "");
Expect(1, 918000, '\p{^Sentence_Break=extend}', "");
Expect(1, 918000, '\P{Sentence_Break=extend}', "");
Expect(0, 918000, '\P{^Sentence_Break=extend}', "");
Expect(1, 917999, '\p{Sentence_Break:	Extend}', "");
Expect(0, 917999, '\p{^Sentence_Break:	Extend}', "");
Expect(0, 917999, '\P{Sentence_Break:	Extend}', "");
Expect(1, 917999, '\P{^Sentence_Break:	Extend}', "");
Expect(0, 918000, '\p{Sentence_Break:	Extend}', "");
Expect(1, 918000, '\p{^Sentence_Break:	Extend}', "");
Expect(1, 918000, '\P{Sentence_Break:	Extend}', "");
Expect(0, 918000, '\P{^Sentence_Break:	Extend}', "");
Error('\p{SB=:=- EX}');
Error('\P{SB=:=- EX}');
Expect(1, 917999, '\p{SB:   ex}', "");
Expect(0, 917999, '\p{^SB:   ex}', "");
Expect(0, 917999, '\P{SB:   ex}', "");
Expect(1, 917999, '\P{^SB:   ex}', "");
Expect(0, 918000, '\p{SB:   ex}', "");
Expect(1, 918000, '\p{^SB:   ex}', "");
Expect(1, 918000, '\P{SB:   ex}', "");
Expect(0, 918000, '\P{^SB:   ex}', "");
Expect(1, 917999, '\p{SB=		ex}', "");
Expect(0, 917999, '\p{^SB=		ex}', "");
Expect(0, 917999, '\P{SB=		ex}', "");
Expect(1, 917999, '\P{^SB=		ex}', "");
Expect(0, 918000, '\p{SB=		ex}', "");
Expect(1, 918000, '\p{^SB=		ex}', "");
Expect(1, 918000, '\P{SB=		ex}', "");
Expect(0, 918000, '\P{^SB=		ex}', "");
Error('\p{Is_Sentence_Break=/a/ -EXTEND}');
Error('\P{Is_Sentence_Break=/a/ -EXTEND}');
Expect(1, 917999, '\p{Is_Sentence_Break=extend}', "");
Expect(0, 917999, '\p{^Is_Sentence_Break=extend}', "");
Expect(0, 917999, '\P{Is_Sentence_Break=extend}', "");
Expect(1, 917999, '\P{^Is_Sentence_Break=extend}', "");
Expect(0, 918000, '\p{Is_Sentence_Break=extend}', "");
Expect(1, 918000, '\p{^Is_Sentence_Break=extend}', "");
Expect(1, 918000, '\P{Is_Sentence_Break=extend}', "");
Expect(0, 918000, '\P{^Is_Sentence_Break=extend}', "");
Expect(1, 917999, '\p{Is_Sentence_Break=-	Extend}', "");
Expect(0, 917999, '\p{^Is_Sentence_Break=-	Extend}', "");
Expect(0, 917999, '\P{Is_Sentence_Break=-	Extend}', "");
Expect(1, 917999, '\P{^Is_Sentence_Break=-	Extend}', "");
Expect(0, 918000, '\p{Is_Sentence_Break=-	Extend}', "");
Expect(1, 918000, '\p{^Is_Sentence_Break=-	Extend}', "");
Expect(1, 918000, '\P{Is_Sentence_Break=-	Extend}', "");
Expect(0, 918000, '\P{^Is_Sentence_Break=-	Extend}', "");
Error('\p{Is_SB=-:=EX}');
Error('\P{Is_SB=-:=EX}');
Expect(1, 917999, '\p{Is_SB=ex}', "");
Expect(0, 917999, '\p{^Is_SB=ex}', "");
Expect(0, 917999, '\P{Is_SB=ex}', "");
Expect(1, 917999, '\P{^Is_SB=ex}', "");
Expect(0, 918000, '\p{Is_SB=ex}', "");
Expect(1, 918000, '\p{^Is_SB=ex}', "");
Expect(1, 918000, '\P{Is_SB=ex}', "");
Expect(0, 918000, '\P{^Is_SB=ex}', "");
Expect(1, 917999, '\p{Is_SB=_-EX}', "");
Expect(0, 917999, '\p{^Is_SB=_-EX}', "");
Expect(0, 917999, '\P{Is_SB=_-EX}', "");
Expect(1, 917999, '\P{^Is_SB=_-EX}', "");
Expect(0, 918000, '\p{Is_SB=_-EX}', "");
Expect(1, 918000, '\p{^Is_SB=_-EX}', "");
Expect(1, 918000, '\P{Is_SB=_-EX}', "");
Expect(0, 918000, '\P{^Is_SB=_-EX}', "");
Error('\p{Sentence_Break=:=	 FORMAT}');
Error('\P{Sentence_Break=:=	 FORMAT}');
Expect(1, 917631, '\p{Sentence_Break=format}', "");
Expect(0, 917631, '\p{^Sentence_Break=format}', "");
Expect(0, 917631, '\P{Sentence_Break=format}', "");
Expect(1, 917631, '\P{^Sentence_Break=format}', "");
Expect(0, 917632, '\p{Sentence_Break=format}', "");
Expect(1, 917632, '\p{^Sentence_Break=format}', "");
Expect(1, 917632, '\P{Sentence_Break=format}', "");
Expect(0, 917632, '\P{^Sentence_Break=format}', "");
Expect(1, 917631, '\p{Sentence_Break=-_format}', "");
Expect(0, 917631, '\p{^Sentence_Break=-_format}', "");
Expect(0, 917631, '\P{Sentence_Break=-_format}', "");
Expect(1, 917631, '\P{^Sentence_Break=-_format}', "");
Expect(0, 917632, '\p{Sentence_Break=-_format}', "");
Expect(1, 917632, '\p{^Sentence_Break=-_format}', "");
Expect(1, 917632, '\P{Sentence_Break=-_format}', "");
Expect(0, 917632, '\P{^Sentence_Break=-_format}', "");
Error('\p{SB=  FO/a/}');
Error('\P{SB=  FO/a/}');
Expect(1, 917631, '\p{SB=fo}', "");
Expect(0, 917631, '\p{^SB=fo}', "");
Expect(0, 917631, '\P{SB=fo}', "");
Expect(1, 917631, '\P{^SB=fo}', "");
Expect(0, 917632, '\p{SB=fo}', "");
Expect(1, 917632, '\p{^SB=fo}', "");
Expect(1, 917632, '\P{SB=fo}', "");
Expect(0, 917632, '\P{^SB=fo}', "");
Expect(1, 917631, '\p{SB=	-fo}', "");
Expect(0, 917631, '\p{^SB=	-fo}', "");
Expect(0, 917631, '\P{SB=	-fo}', "");
Expect(1, 917631, '\P{^SB=	-fo}', "");
Expect(0, 917632, '\p{SB=	-fo}', "");
Expect(1, 917632, '\p{^SB=	-fo}', "");
Expect(1, 917632, '\P{SB=	-fo}', "");
Expect(0, 917632, '\P{^SB=	-fo}', "");
Error('\p{Is_Sentence_Break=	FORMAT:=}');
Error('\P{Is_Sentence_Break=	FORMAT:=}');
Expect(1, 917631, '\p{Is_Sentence_Break=format}', "");
Expect(0, 917631, '\p{^Is_Sentence_Break=format}', "");
Expect(0, 917631, '\P{Is_Sentence_Break=format}', "");
Expect(1, 917631, '\P{^Is_Sentence_Break=format}', "");
Expect(0, 917632, '\p{Is_Sentence_Break=format}', "");
Expect(1, 917632, '\p{^Is_Sentence_Break=format}', "");
Expect(1, 917632, '\P{Is_Sentence_Break=format}', "");
Expect(0, 917632, '\P{^Is_Sentence_Break=format}', "");
Expect(1, 917631, '\p{Is_Sentence_Break= -Format}', "");
Expect(0, 917631, '\p{^Is_Sentence_Break= -Format}', "");
Expect(0, 917631, '\P{Is_Sentence_Break= -Format}', "");
Expect(1, 917631, '\P{^Is_Sentence_Break= -Format}', "");
Expect(0, 917632, '\p{Is_Sentence_Break= -Format}', "");
Expect(1, 917632, '\p{^Is_Sentence_Break= -Format}', "");
Expect(1, 917632, '\P{Is_Sentence_Break= -Format}', "");
Expect(0, 917632, '\P{^Is_Sentence_Break= -Format}', "");
Error('\p{Is_SB=	FO/a/}');
Error('\P{Is_SB=	FO/a/}');
Expect(1, 917631, '\p{Is_SB=fo}', "");
Expect(0, 917631, '\p{^Is_SB=fo}', "");
Expect(0, 917631, '\P{Is_SB=fo}', "");
Expect(1, 917631, '\P{^Is_SB=fo}', "");
Expect(0, 917632, '\p{Is_SB=fo}', "");
Expect(1, 917632, '\p{^Is_SB=fo}', "");
Expect(1, 917632, '\P{Is_SB=fo}', "");
Expect(0, 917632, '\P{^Is_SB=fo}', "");
Expect(1, 917631, '\p{Is_SB:_-fo}', "");
Expect(0, 917631, '\p{^Is_SB:_-fo}', "");
Expect(0, 917631, '\P{Is_SB:_-fo}', "");
Expect(1, 917631, '\P{^Is_SB:_-fo}', "");
Expect(0, 917632, '\p{Is_SB:_-fo}', "");
Expect(1, 917632, '\p{^Is_SB:_-fo}', "");
Expect(1, 917632, '\P{Is_SB:_-fo}', "");
Expect(0, 917632, '\P{^Is_SB:_-fo}', "");
Error('\p{Sentence_Break:   /a/ 	oletter}');
Error('\P{Sentence_Break:   /a/ 	oletter}');
Expect(1, 195101, '\p{Sentence_Break=oletter}', "");
Expect(0, 195101, '\p{^Sentence_Break=oletter}', "");
Expect(0, 195101, '\P{Sentence_Break=oletter}', "");
Expect(1, 195101, '\P{^Sentence_Break=oletter}', "");
Expect(0, 195102, '\p{Sentence_Break=oletter}', "");
Expect(1, 195102, '\p{^Sentence_Break=oletter}', "");
Expect(1, 195102, '\P{Sentence_Break=oletter}', "");
Expect(0, 195102, '\P{^Sentence_Break=oletter}', "");
Expect(1, 195101, '\p{Sentence_Break=_OLetter}', "");
Expect(0, 195101, '\p{^Sentence_Break=_OLetter}', "");
Expect(0, 195101, '\P{Sentence_Break=_OLetter}', "");
Expect(1, 195101, '\P{^Sentence_Break=_OLetter}', "");
Expect(0, 195102, '\p{Sentence_Break=_OLetter}', "");
Expect(1, 195102, '\p{^Sentence_Break=_OLetter}', "");
Expect(1, 195102, '\P{Sentence_Break=_OLetter}', "");
Expect(0, 195102, '\P{^Sentence_Break=_OLetter}', "");
Error('\p{SB=/a/ LE}');
Error('\P{SB=/a/ LE}');
Expect(1, 195101, '\p{SB=le}', "");
Expect(0, 195101, '\p{^SB=le}', "");
Expect(0, 195101, '\P{SB=le}', "");
Expect(1, 195101, '\P{^SB=le}', "");
Expect(0, 195102, '\p{SB=le}', "");
Expect(1, 195102, '\p{^SB=le}', "");
Expect(1, 195102, '\P{SB=le}', "");
Expect(0, 195102, '\P{^SB=le}', "");
Expect(1, 195101, '\p{SB=-LE}', "");
Expect(0, 195101, '\p{^SB=-LE}', "");
Expect(0, 195101, '\P{SB=-LE}', "");
Expect(1, 195101, '\P{^SB=-LE}', "");
Expect(0, 195102, '\p{SB=-LE}', "");
Expect(1, 195102, '\p{^SB=-LE}', "");
Expect(1, 195102, '\P{SB=-LE}', "");
Expect(0, 195102, '\P{^SB=-LE}', "");
Error('\p{Is_Sentence_Break=/a/	OLetter}');
Error('\P{Is_Sentence_Break=/a/	OLetter}');
Expect(1, 195101, '\p{Is_Sentence_Break=oletter}', "");
Expect(0, 195101, '\p{^Is_Sentence_Break=oletter}', "");
Expect(0, 195101, '\P{Is_Sentence_Break=oletter}', "");
Expect(1, 195101, '\P{^Is_Sentence_Break=oletter}', "");
Expect(0, 195102, '\p{Is_Sentence_Break=oletter}', "");
Expect(1, 195102, '\p{^Is_Sentence_Break=oletter}', "");
Expect(1, 195102, '\P{Is_Sentence_Break=oletter}', "");
Expect(0, 195102, '\P{^Is_Sentence_Break=oletter}', "");
Expect(1, 195101, '\p{Is_Sentence_Break=__OLetter}', "");
Expect(0, 195101, '\p{^Is_Sentence_Break=__OLetter}', "");
Expect(0, 195101, '\P{Is_Sentence_Break=__OLetter}', "");
Expect(1, 195101, '\P{^Is_Sentence_Break=__OLetter}', "");
Expect(0, 195102, '\p{Is_Sentence_Break=__OLetter}', "");
Expect(1, 195102, '\p{^Is_Sentence_Break=__OLetter}', "");
Expect(1, 195102, '\P{Is_Sentence_Break=__OLetter}', "");
Expect(0, 195102, '\P{^Is_Sentence_Break=__OLetter}', "");
Error('\p{Is_SB= LE/a/}');
Error('\P{Is_SB= LE/a/}');
Expect(1, 195101, '\p{Is_SB=le}', "");
Expect(0, 195101, '\p{^Is_SB=le}', "");
Expect(0, 195101, '\P{Is_SB=le}', "");
Expect(1, 195101, '\P{^Is_SB=le}', "");
Expect(0, 195102, '\p{Is_SB=le}', "");
Expect(1, 195102, '\p{^Is_SB=le}', "");
Expect(1, 195102, '\P{Is_SB=le}', "");
Expect(0, 195102, '\P{^Is_SB=le}', "");
Expect(1, 195101, '\p{Is_SB=--LE}', "");
Expect(0, 195101, '\p{^Is_SB=--LE}', "");
Expect(0, 195101, '\P{Is_SB=--LE}', "");
Expect(1, 195101, '\P{^Is_SB=--LE}', "");
Expect(0, 195102, '\p{Is_SB=--LE}', "");
Expect(1, 195102, '\p{^Is_SB=--LE}', "");
Expect(1, 195102, '\P{Is_SB=--LE}', "");
Expect(0, 195102, '\P{^Is_SB=--LE}', "");
Error('\p{Sentence_Break: :=	LF}');
Error('\P{Sentence_Break: :=	LF}');
Expect(1, 10, '\p{Sentence_Break=lf}', "");
Expect(0, 10, '\p{^Sentence_Break=lf}', "");
Expect(0, 10, '\P{Sentence_Break=lf}', "");
Expect(1, 10, '\P{^Sentence_Break=lf}', "");
Expect(0, 11, '\p{Sentence_Break=lf}', "");
Expect(1, 11, '\p{^Sentence_Break=lf}', "");
Expect(1, 11, '\P{Sentence_Break=lf}', "");
Expect(0, 11, '\P{^Sentence_Break=lf}', "");
Expect(1, 10, '\p{Sentence_Break=_lf}', "");
Expect(0, 10, '\p{^Sentence_Break=_lf}', "");
Expect(0, 10, '\P{Sentence_Break=_lf}', "");
Expect(1, 10, '\P{^Sentence_Break=_lf}', "");
Expect(0, 11, '\p{Sentence_Break=_lf}', "");
Expect(1, 11, '\p{^Sentence_Break=_lf}', "");
Expect(1, 11, '\P{Sentence_Break=_lf}', "");
Expect(0, 11, '\P{^Sentence_Break=_lf}', "");
Error('\p{SB=_LF:=}');
Error('\P{SB=_LF:=}');
Expect(1, 10, '\p{SB=lf}', "");
Expect(0, 10, '\p{^SB=lf}', "");
Expect(0, 10, '\P{SB=lf}', "");
Expect(1, 10, '\P{^SB=lf}', "");
Expect(0, 11, '\p{SB=lf}', "");
Expect(1, 11, '\p{^SB=lf}', "");
Expect(1, 11, '\P{SB=lf}', "");
Expect(0, 11, '\P{^SB=lf}', "");
Expect(1, 10, '\p{SB= _LF}', "");
Expect(0, 10, '\p{^SB= _LF}', "");
Expect(0, 10, '\P{SB= _LF}', "");
Expect(1, 10, '\P{^SB= _LF}', "");
Expect(0, 11, '\p{SB= _LF}', "");
Expect(1, 11, '\p{^SB= _LF}', "");
Expect(1, 11, '\P{SB= _LF}', "");
Expect(0, 11, '\P{^SB= _LF}', "");
Error('\p{Is_Sentence_Break=	_lf/a/}');
Error('\P{Is_Sentence_Break=	_lf/a/}');
Expect(1, 10, '\p{Is_Sentence_Break=lf}', "");
Expect(0, 10, '\p{^Is_Sentence_Break=lf}', "");
Expect(0, 10, '\P{Is_Sentence_Break=lf}', "");
Expect(1, 10, '\P{^Is_Sentence_Break=lf}', "");
Expect(0, 11, '\p{Is_Sentence_Break=lf}', "");
Expect(1, 11, '\p{^Is_Sentence_Break=lf}', "");
Expect(1, 11, '\P{Is_Sentence_Break=lf}', "");
Expect(0, 11, '\P{^Is_Sentence_Break=lf}', "");
Expect(1, 10, '\p{Is_Sentence_Break=-	LF}', "");
Expect(0, 10, '\p{^Is_Sentence_Break=-	LF}', "");
Expect(0, 10, '\P{Is_Sentence_Break=-	LF}', "");
Expect(1, 10, '\P{^Is_Sentence_Break=-	LF}', "");
Expect(0, 11, '\p{Is_Sentence_Break=-	LF}', "");
Expect(1, 11, '\p{^Is_Sentence_Break=-	LF}', "");
Expect(1, 11, '\P{Is_Sentence_Break=-	LF}', "");
Expect(0, 11, '\P{^Is_Sentence_Break=-	LF}', "");
Error('\p{Is_SB=:=- LF}');
Error('\P{Is_SB=:=- LF}');
Expect(1, 10, '\p{Is_SB=lf}', "");
Expect(0, 10, '\p{^Is_SB=lf}', "");
Expect(0, 10, '\P{Is_SB=lf}', "");
Expect(1, 10, '\P{^Is_SB=lf}', "");
Expect(0, 11, '\p{Is_SB=lf}', "");
Expect(1, 11, '\p{^Is_SB=lf}', "");
Expect(1, 11, '\P{Is_SB=lf}', "");
Expect(0, 11, '\P{^Is_SB=lf}', "");
Expect(1, 10, '\p{Is_SB=	_lf}', "");
Expect(0, 10, '\p{^Is_SB=	_lf}', "");
Expect(0, 10, '\P{Is_SB=	_lf}', "");
Expect(1, 10, '\P{^Is_SB=	_lf}', "");
Expect(0, 11, '\p{Is_SB=	_lf}', "");
Expect(1, 11, '\p{^Is_SB=	_lf}', "");
Expect(1, 11, '\P{Is_SB=	_lf}', "");
Expect(0, 11, '\P{^Is_SB=	_lf}', "");
Error('\p{Sentence_Break:_/a/LOWER}');
Error('\P{Sentence_Break:_/a/LOWER}');
Expect(1, 120779, '\p{Sentence_Break=lower}', "");
Expect(0, 120779, '\p{^Sentence_Break=lower}', "");
Expect(0, 120779, '\P{Sentence_Break=lower}', "");
Expect(1, 120779, '\P{^Sentence_Break=lower}', "");
Expect(0, 120780, '\p{Sentence_Break=lower}', "");
Expect(1, 120780, '\p{^Sentence_Break=lower}', "");
Expect(1, 120780, '\P{Sentence_Break=lower}', "");
Expect(0, 120780, '\P{^Sentence_Break=lower}', "");
Expect(1, 120779, '\p{Sentence_Break=_-lower}', "");
Expect(0, 120779, '\p{^Sentence_Break=_-lower}', "");
Expect(0, 120779, '\P{Sentence_Break=_-lower}', "");
Expect(1, 120779, '\P{^Sentence_Break=_-lower}', "");
Expect(0, 120780, '\p{Sentence_Break=_-lower}', "");
Expect(1, 120780, '\p{^Sentence_Break=_-lower}', "");
Expect(1, 120780, '\P{Sentence_Break=_-lower}', "");
Expect(0, 120780, '\P{^Sentence_Break=_-lower}', "");
Error('\p{SB=_:=LO}');
Error('\P{SB=_:=LO}');
Expect(1, 120779, '\p{SB=lo}', "");
Expect(0, 120779, '\p{^SB=lo}', "");
Expect(0, 120779, '\P{SB=lo}', "");
Expect(1, 120779, '\P{^SB=lo}', "");
Expect(0, 120780, '\p{SB=lo}', "");
Expect(1, 120780, '\p{^SB=lo}', "");
Expect(1, 120780, '\P{SB=lo}', "");
Expect(0, 120780, '\P{^SB=lo}', "");
Expect(1, 120779, '\p{SB=_-lo}', "");
Expect(0, 120779, '\p{^SB=_-lo}', "");
Expect(0, 120779, '\P{SB=_-lo}', "");
Expect(1, 120779, '\P{^SB=_-lo}', "");
Expect(0, 120780, '\p{SB=_-lo}', "");
Expect(1, 120780, '\p{^SB=_-lo}', "");
Expect(1, 120780, '\P{SB=_-lo}', "");
Expect(0, 120780, '\P{^SB=_-lo}', "");
Error('\p{Is_Sentence_Break=  lower/a/}');
Error('\P{Is_Sentence_Break=  lower/a/}');
Expect(1, 120779, '\p{Is_Sentence_Break=lower}', "");
Expect(0, 120779, '\p{^Is_Sentence_Break=lower}', "");
Expect(0, 120779, '\P{Is_Sentence_Break=lower}', "");
Expect(1, 120779, '\P{^Is_Sentence_Break=lower}', "");
Expect(0, 120780, '\p{Is_Sentence_Break=lower}', "");
Expect(1, 120780, '\p{^Is_Sentence_Break=lower}', "");
Expect(1, 120780, '\P{Is_Sentence_Break=lower}', "");
Expect(0, 120780, '\P{^Is_Sentence_Break=lower}', "");
Expect(1, 120779, '\p{Is_Sentence_Break=-Lower}', "");
Expect(0, 120779, '\p{^Is_Sentence_Break=-Lower}', "");
Expect(0, 120779, '\P{Is_Sentence_Break=-Lower}', "");
Expect(1, 120779, '\P{^Is_Sentence_Break=-Lower}', "");
Expect(0, 120780, '\p{Is_Sentence_Break=-Lower}', "");
Expect(1, 120780, '\p{^Is_Sentence_Break=-Lower}', "");
Expect(1, 120780, '\P{Is_Sentence_Break=-Lower}', "");
Expect(0, 120780, '\P{^Is_Sentence_Break=-Lower}', "");
Error('\p{Is_SB=:=__LO}');
Error('\P{Is_SB=:=__LO}');
Expect(1, 120779, '\p{Is_SB=lo}', "");
Expect(0, 120779, '\p{^Is_SB=lo}', "");
Expect(0, 120779, '\P{Is_SB=lo}', "");
Expect(1, 120779, '\P{^Is_SB=lo}', "");
Expect(0, 120780, '\p{Is_SB=lo}', "");
Expect(1, 120780, '\p{^Is_SB=lo}', "");
Expect(1, 120780, '\P{Is_SB=lo}', "");
Expect(0, 120780, '\P{^Is_SB=lo}', "");
Expect(1, 120779, '\p{Is_SB=-lo}', "");
Expect(0, 120779, '\p{^Is_SB=-lo}', "");
Expect(0, 120779, '\P{Is_SB=-lo}', "");
Expect(1, 120779, '\P{^Is_SB=-lo}', "");
Expect(0, 120780, '\p{Is_SB=-lo}', "");
Expect(1, 120780, '\p{^Is_SB=-lo}', "");
Expect(1, 120780, '\P{Is_SB=-lo}', "");
Expect(0, 120780, '\P{^Is_SB=-lo}', "");
Error('\p{Sentence_Break= numeric:=}');
Error('\P{Sentence_Break= numeric:=}');
Expect(1, 120831, '\p{Sentence_Break=numeric}', "");
Expect(0, 120831, '\p{^Sentence_Break=numeric}', "");
Expect(0, 120831, '\P{Sentence_Break=numeric}', "");
Expect(1, 120831, '\P{^Sentence_Break=numeric}', "");
Expect(0, 120832, '\p{Sentence_Break=numeric}', "");
Expect(1, 120832, '\p{^Sentence_Break=numeric}', "");
Expect(1, 120832, '\P{Sentence_Break=numeric}', "");
Expect(0, 120832, '\P{^Sentence_Break=numeric}', "");
Expect(1, 120831, '\p{Sentence_Break=	NUMERIC}', "");
Expect(0, 120831, '\p{^Sentence_Break=	NUMERIC}', "");
Expect(0, 120831, '\P{Sentence_Break=	NUMERIC}', "");
Expect(1, 120831, '\P{^Sentence_Break=	NUMERIC}', "");
Expect(0, 120832, '\p{Sentence_Break=	NUMERIC}', "");
Expect(1, 120832, '\p{^Sentence_Break=	NUMERIC}', "");
Expect(1, 120832, '\P{Sentence_Break=	NUMERIC}', "");
Expect(0, 120832, '\P{^Sentence_Break=	NUMERIC}', "");
Error('\p{SB=-:=NU}');
Error('\P{SB=-:=NU}');
Expect(1, 120831, '\p{SB=nu}', "");
Expect(0, 120831, '\p{^SB=nu}', "");
Expect(0, 120831, '\P{SB=nu}', "");
Expect(1, 120831, '\P{^SB=nu}', "");
Expect(0, 120832, '\p{SB=nu}', "");
Expect(1, 120832, '\p{^SB=nu}', "");
Expect(1, 120832, '\P{SB=nu}', "");
Expect(0, 120832, '\P{^SB=nu}', "");
Expect(1, 120831, '\p{SB:   -NU}', "");
Expect(0, 120831, '\p{^SB:   -NU}', "");
Expect(0, 120831, '\P{SB:   -NU}', "");
Expect(1, 120831, '\P{^SB:   -NU}', "");
Expect(0, 120832, '\p{SB:   -NU}', "");
Expect(1, 120832, '\p{^SB:   -NU}', "");
Expect(1, 120832, '\P{SB:   -NU}', "");
Expect(0, 120832, '\P{^SB:   -NU}', "");
Error('\p{Is_Sentence_Break=_Numeric:=}');
Error('\P{Is_Sentence_Break=_Numeric:=}');
Expect(1, 120831, '\p{Is_Sentence_Break=numeric}', "");
Expect(0, 120831, '\p{^Is_Sentence_Break=numeric}', "");
Expect(0, 120831, '\P{Is_Sentence_Break=numeric}', "");
Expect(1, 120831, '\P{^Is_Sentence_Break=numeric}', "");
Expect(0, 120832, '\p{Is_Sentence_Break=numeric}', "");
Expect(1, 120832, '\p{^Is_Sentence_Break=numeric}', "");
Expect(1, 120832, '\P{Is_Sentence_Break=numeric}', "");
Expect(0, 120832, '\P{^Is_Sentence_Break=numeric}', "");
Expect(1, 120831, '\p{Is_Sentence_Break=		numeric}', "");
Expect(0, 120831, '\p{^Is_Sentence_Break=		numeric}', "");
Expect(0, 120831, '\P{Is_Sentence_Break=		numeric}', "");
Expect(1, 120831, '\P{^Is_Sentence_Break=		numeric}', "");
Expect(0, 120832, '\p{Is_Sentence_Break=		numeric}', "");
Expect(1, 120832, '\p{^Is_Sentence_Break=		numeric}', "");
Expect(1, 120832, '\P{Is_Sentence_Break=		numeric}', "");
Expect(0, 120832, '\P{^Is_Sentence_Break=		numeric}', "");
Error('\p{Is_SB=	:=NU}');
Error('\P{Is_SB=	:=NU}');
Expect(1, 120831, '\p{Is_SB=nu}', "");
Expect(0, 120831, '\p{^Is_SB=nu}', "");
Expect(0, 120831, '\P{Is_SB=nu}', "");
Expect(1, 120831, '\P{^Is_SB=nu}', "");
Expect(0, 120832, '\p{Is_SB=nu}', "");
Expect(1, 120832, '\p{^Is_SB=nu}', "");
Expect(1, 120832, '\P{Is_SB=nu}', "");
Expect(0, 120832, '\P{^Is_SB=nu}', "");
Expect(1, 120831, '\p{Is_SB= NU}', "");
Expect(0, 120831, '\p{^Is_SB= NU}', "");
Expect(0, 120831, '\P{Is_SB= NU}', "");
Expect(1, 120831, '\P{^Is_SB= NU}', "");
Expect(0, 120832, '\p{Is_SB= NU}', "");
Expect(1, 120832, '\p{^Is_SB= NU}', "");
Expect(1, 120832, '\P{Is_SB= NU}', "");
Expect(0, 120832, '\P{^Is_SB= NU}', "");
Error('\p{Sentence_Break=	/a/SContinue}');
Error('\P{Sentence_Break=	/a/SContinue}');
Expect(1, 65380, '\p{Sentence_Break=scontinue}', "");
Expect(0, 65380, '\p{^Sentence_Break=scontinue}', "");
Expect(0, 65380, '\P{Sentence_Break=scontinue}', "");
Expect(1, 65380, '\P{^Sentence_Break=scontinue}', "");
Expect(0, 65381, '\p{Sentence_Break=scontinue}', "");
Expect(1, 65381, '\p{^Sentence_Break=scontinue}', "");
Expect(1, 65381, '\P{Sentence_Break=scontinue}', "");
Expect(0, 65381, '\P{^Sentence_Break=scontinue}', "");
Expect(1, 65380, '\p{Sentence_Break=__SCONTINUE}', "");
Expect(0, 65380, '\p{^Sentence_Break=__SCONTINUE}', "");
Expect(0, 65380, '\P{Sentence_Break=__SCONTINUE}', "");
Expect(1, 65380, '\P{^Sentence_Break=__SCONTINUE}', "");
Expect(0, 65381, '\p{Sentence_Break=__SCONTINUE}', "");
Expect(1, 65381, '\p{^Sentence_Break=__SCONTINUE}', "");
Expect(1, 65381, '\P{Sentence_Break=__SCONTINUE}', "");
Expect(0, 65381, '\P{^Sentence_Break=__SCONTINUE}', "");
Error('\p{SB=	 sc:=}');
Error('\P{SB=	 sc:=}');
Expect(1, 65380, '\p{SB=sc}', "");
Expect(0, 65380, '\p{^SB=sc}', "");
Expect(0, 65380, '\P{SB=sc}', "");
Expect(1, 65380, '\P{^SB=sc}', "");
Expect(0, 65381, '\p{SB=sc}', "");
Expect(1, 65381, '\p{^SB=sc}', "");
Expect(1, 65381, '\P{SB=sc}', "");
Expect(0, 65381, '\P{^SB=sc}', "");
Expect(1, 65380, '\p{SB: _ SC}', "");
Expect(0, 65380, '\p{^SB: _ SC}', "");
Expect(0, 65380, '\P{SB: _ SC}', "");
Expect(1, 65380, '\P{^SB: _ SC}', "");
Expect(0, 65381, '\p{SB: _ SC}', "");
Expect(1, 65381, '\p{^SB: _ SC}', "");
Expect(1, 65381, '\P{SB: _ SC}', "");
Expect(0, 65381, '\P{^SB: _ SC}', "");
Error('\p{Is_Sentence_Break=:=	SCONTINUE}');
Error('\P{Is_Sentence_Break=:=	SCONTINUE}');
Expect(1, 65380, '\p{Is_Sentence_Break=scontinue}', "");
Expect(0, 65380, '\p{^Is_Sentence_Break=scontinue}', "");
Expect(0, 65380, '\P{Is_Sentence_Break=scontinue}', "");
Expect(1, 65380, '\P{^Is_Sentence_Break=scontinue}', "");
Expect(0, 65381, '\p{Is_Sentence_Break=scontinue}', "");
Expect(1, 65381, '\p{^Is_Sentence_Break=scontinue}', "");
Expect(1, 65381, '\P{Is_Sentence_Break=scontinue}', "");
Expect(0, 65381, '\P{^Is_Sentence_Break=scontinue}', "");
Expect(1, 65380, '\p{Is_Sentence_Break=_ SContinue}', "");
Expect(0, 65380, '\p{^Is_Sentence_Break=_ SContinue}', "");
Expect(0, 65380, '\P{Is_Sentence_Break=_ SContinue}', "");
Expect(1, 65380, '\P{^Is_Sentence_Break=_ SContinue}', "");
Expect(0, 65381, '\p{Is_Sentence_Break=_ SContinue}', "");
Expect(1, 65381, '\p{^Is_Sentence_Break=_ SContinue}', "");
Expect(1, 65381, '\P{Is_Sentence_Break=_ SContinue}', "");
Expect(0, 65381, '\P{^Is_Sentence_Break=_ SContinue}', "");
Error('\p{Is_SB=	/a/sc}');
Error('\P{Is_SB=	/a/sc}');
Expect(1, 65380, '\p{Is_SB=sc}', "");
Expect(0, 65380, '\p{^Is_SB=sc}', "");
Expect(0, 65380, '\P{Is_SB=sc}', "");
Expect(1, 65380, '\P{^Is_SB=sc}', "");
Expect(0, 65381, '\p{Is_SB=sc}', "");
Expect(1, 65381, '\p{^Is_SB=sc}', "");
Expect(1, 65381, '\P{Is_SB=sc}', "");
Expect(0, 65381, '\P{^Is_SB=sc}', "");
Expect(1, 65380, '\p{Is_SB=-SC}', "");
Expect(0, 65380, '\p{^Is_SB=-SC}', "");
Expect(0, 65380, '\P{Is_SB=-SC}', "");
Expect(1, 65380, '\P{^Is_SB=-SC}', "");
Expect(0, 65381, '\p{Is_SB=-SC}', "");
Expect(1, 65381, '\p{^Is_SB=-SC}', "");
Expect(1, 65381, '\P{Is_SB=-SC}', "");
Expect(0, 65381, '\P{^Is_SB=-SC}', "");
Error('\p{Sentence_Break:	:= Sep}');
Error('\P{Sentence_Break:	:= Sep}');
Expect(1, 8233, '\p{Sentence_Break:sep}', "");
Expect(0, 8233, '\p{^Sentence_Break:sep}', "");
Expect(0, 8233, '\P{Sentence_Break:sep}', "");
Expect(1, 8233, '\P{^Sentence_Break:sep}', "");
Expect(0, 8234, '\p{Sentence_Break:sep}', "");
Expect(1, 8234, '\p{^Sentence_Break:sep}', "");
Expect(1, 8234, '\P{Sentence_Break:sep}', "");
Expect(0, 8234, '\P{^Sentence_Break:sep}', "");
Expect(1, 8233, '\p{Sentence_Break=	 sep}', "");
Expect(0, 8233, '\p{^Sentence_Break=	 sep}', "");
Expect(0, 8233, '\P{Sentence_Break=	 sep}', "");
Expect(1, 8233, '\P{^Sentence_Break=	 sep}', "");
Expect(0, 8234, '\p{Sentence_Break=	 sep}', "");
Expect(1, 8234, '\p{^Sentence_Break=	 sep}', "");
Expect(1, 8234, '\P{Sentence_Break=	 sep}', "");
Expect(0, 8234, '\P{^Sentence_Break=	 sep}', "");
Error('\p{SB=/a/	SE}');
Error('\P{SB=/a/	SE}');
Expect(1, 8233, '\p{SB=se}', "");
Expect(0, 8233, '\p{^SB=se}', "");
Expect(0, 8233, '\P{SB=se}', "");
Expect(1, 8233, '\P{^SB=se}', "");
Expect(0, 8234, '\p{SB=se}', "");
Expect(1, 8234, '\p{^SB=se}', "");
Expect(1, 8234, '\P{SB=se}', "");
Expect(0, 8234, '\P{^SB=se}', "");
Expect(1, 8233, '\p{SB= 	SE}', "");
Expect(0, 8233, '\p{^SB= 	SE}', "");
Expect(0, 8233, '\P{SB= 	SE}', "");
Expect(1, 8233, '\P{^SB= 	SE}', "");
Expect(0, 8234, '\p{SB= 	SE}', "");
Expect(1, 8234, '\p{^SB= 	SE}', "");
Expect(1, 8234, '\P{SB= 	SE}', "");
Expect(0, 8234, '\P{^SB= 	SE}', "");
Error('\p{Is_Sentence_Break:_sep/a/}');
Error('\P{Is_Sentence_Break:_sep/a/}');
Expect(1, 8233, '\p{Is_Sentence_Break=sep}', "");
Expect(0, 8233, '\p{^Is_Sentence_Break=sep}', "");
Expect(0, 8233, '\P{Is_Sentence_Break=sep}', "");
Expect(1, 8233, '\P{^Is_Sentence_Break=sep}', "");
Expect(0, 8234, '\p{Is_Sentence_Break=sep}', "");
Expect(1, 8234, '\p{^Is_Sentence_Break=sep}', "");
Expect(1, 8234, '\P{Is_Sentence_Break=sep}', "");
Expect(0, 8234, '\P{^Is_Sentence_Break=sep}', "");
Expect(1, 8233, '\p{Is_Sentence_Break=	-Sep}', "");
Expect(0, 8233, '\p{^Is_Sentence_Break=	-Sep}', "");
Expect(0, 8233, '\P{Is_Sentence_Break=	-Sep}', "");
Expect(1, 8233, '\P{^Is_Sentence_Break=	-Sep}', "");
Expect(0, 8234, '\p{Is_Sentence_Break=	-Sep}', "");
Expect(1, 8234, '\p{^Is_Sentence_Break=	-Sep}', "");
Expect(1, 8234, '\P{Is_Sentence_Break=	-Sep}', "");
Expect(0, 8234, '\P{^Is_Sentence_Break=	-Sep}', "");
Error('\p{Is_SB=/a/	 SE}');
Error('\P{Is_SB=/a/	 SE}');
Expect(1, 8233, '\p{Is_SB=se}', "");
Expect(0, 8233, '\p{^Is_SB=se}', "");
Expect(0, 8233, '\P{Is_SB=se}', "");
Expect(1, 8233, '\P{^Is_SB=se}', "");
Expect(0, 8234, '\p{Is_SB=se}', "");
Expect(1, 8234, '\p{^Is_SB=se}', "");
Expect(1, 8234, '\P{Is_SB=se}', "");
Expect(0, 8234, '\P{^Is_SB=se}', "");
Expect(1, 8233, '\p{Is_SB=  se}', "");
Expect(0, 8233, '\p{^Is_SB=  se}', "");
Expect(0, 8233, '\P{Is_SB=  se}', "");
Expect(1, 8233, '\P{^Is_SB=  se}', "");
Expect(0, 8234, '\p{Is_SB=  se}', "");
Expect(1, 8234, '\p{^Is_SB=  se}', "");
Expect(1, 8234, '\P{Is_SB=  se}', "");
Expect(0, 8234, '\P{^Is_SB=  se}', "");
Error('\p{Sentence_Break: :=SP}');
Error('\P{Sentence_Break: :=SP}');
Expect(1, 12288, '\p{Sentence_Break=sp}', "");
Expect(0, 12288, '\p{^Sentence_Break=sp}', "");
Expect(0, 12288, '\P{Sentence_Break=sp}', "");
Expect(1, 12288, '\P{^Sentence_Break=sp}', "");
Expect(0, 12289, '\p{Sentence_Break=sp}', "");
Expect(1, 12289, '\p{^Sentence_Break=sp}', "");
Expect(1, 12289, '\P{Sentence_Break=sp}', "");
Expect(0, 12289, '\P{^Sentence_Break=sp}', "");
Expect(1, 12288, '\p{Sentence_Break=	_Sp}', "");
Expect(0, 12288, '\p{^Sentence_Break=	_Sp}', "");
Expect(0, 12288, '\P{Sentence_Break=	_Sp}', "");
Expect(1, 12288, '\P{^Sentence_Break=	_Sp}', "");
Expect(0, 12289, '\p{Sentence_Break=	_Sp}', "");
Expect(1, 12289, '\p{^Sentence_Break=	_Sp}', "");
Expect(1, 12289, '\P{Sentence_Break=	_Sp}', "");
Expect(0, 12289, '\P{^Sentence_Break=	_Sp}', "");
Error('\p{SB=	SP/a/}');
Error('\P{SB=	SP/a/}');
Expect(1, 12288, '\p{SB=sp}', "");
Expect(0, 12288, '\p{^SB=sp}', "");
Expect(0, 12288, '\P{SB=sp}', "");
Expect(1, 12288, '\P{^SB=sp}', "");
Expect(0, 12289, '\p{SB=sp}', "");
Expect(1, 12289, '\p{^SB=sp}', "");
Expect(1, 12289, '\P{SB=sp}', "");
Expect(0, 12289, '\P{^SB=sp}', "");
Expect(1, 12288, '\p{SB=  Sp}', "");
Expect(0, 12288, '\p{^SB=  Sp}', "");
Expect(0, 12288, '\P{SB=  Sp}', "");
Expect(1, 12288, '\P{^SB=  Sp}', "");
Expect(0, 12289, '\p{SB=  Sp}', "");
Expect(1, 12289, '\p{^SB=  Sp}', "");
Expect(1, 12289, '\P{SB=  Sp}', "");
Expect(0, 12289, '\P{^SB=  Sp}', "");
Error('\p{Is_Sentence_Break=-/a/Sp}');
Error('\P{Is_Sentence_Break=-/a/Sp}');
Expect(1, 12288, '\p{Is_Sentence_Break:sp}', "");
Expect(0, 12288, '\p{^Is_Sentence_Break:sp}', "");
Expect(0, 12288, '\P{Is_Sentence_Break:sp}', "");
Expect(1, 12288, '\P{^Is_Sentence_Break:sp}', "");
Expect(0, 12289, '\p{Is_Sentence_Break:sp}', "");
Expect(1, 12289, '\p{^Is_Sentence_Break:sp}', "");
Expect(1, 12289, '\P{Is_Sentence_Break:sp}', "");
Expect(0, 12289, '\P{^Is_Sentence_Break:sp}', "");
Expect(1, 12288, '\p{Is_Sentence_Break=	-Sp}', "");
Expect(0, 12288, '\p{^Is_Sentence_Break=	-Sp}', "");
Expect(0, 12288, '\P{Is_Sentence_Break=	-Sp}', "");
Expect(1, 12288, '\P{^Is_Sentence_Break=	-Sp}', "");
Expect(0, 12289, '\p{Is_Sentence_Break=	-Sp}', "");
Expect(1, 12289, '\p{^Is_Sentence_Break=	-Sp}', "");
Expect(1, 12289, '\P{Is_Sentence_Break=	-Sp}', "");
Expect(0, 12289, '\P{^Is_Sentence_Break=	-Sp}', "");
Error('\p{Is_SB:_:=sp}');
Error('\P{Is_SB:_:=sp}');
Expect(1, 12288, '\p{Is_SB=sp}', "");
Expect(0, 12288, '\p{^Is_SB=sp}', "");
Expect(0, 12288, '\P{Is_SB=sp}', "");
Expect(1, 12288, '\P{^Is_SB=sp}', "");
Expect(0, 12289, '\p{Is_SB=sp}', "");
Expect(1, 12289, '\p{^Is_SB=sp}', "");
Expect(1, 12289, '\P{Is_SB=sp}', "");
Expect(0, 12289, '\P{^Is_SB=sp}', "");
Expect(1, 12288, '\p{Is_SB:   	-SP}', "");
Expect(0, 12288, '\p{^Is_SB:   	-SP}', "");
Expect(0, 12288, '\P{Is_SB:   	-SP}', "");
Expect(1, 12288, '\P{^Is_SB:   	-SP}', "");
Expect(0, 12289, '\p{Is_SB:   	-SP}', "");
Expect(1, 12289, '\p{^Is_SB:   	-SP}', "");
Expect(1, 12289, '\P{Is_SB:   	-SP}', "");
Expect(0, 12289, '\P{^Is_SB:   	-SP}', "");
Error('\p{Sentence_Break:   _-STerm/a/}');
Error('\P{Sentence_Break:   _-STerm/a/}');
Expect(1, 70086, '\p{Sentence_Break=sterm}', "");
Expect(0, 70086, '\p{^Sentence_Break=sterm}', "");
Expect(0, 70086, '\P{Sentence_Break=sterm}', "");
Expect(1, 70086, '\P{^Sentence_Break=sterm}', "");
Expect(0, 70087, '\p{Sentence_Break=sterm}', "");
Expect(1, 70087, '\p{^Sentence_Break=sterm}', "");
Expect(1, 70087, '\P{Sentence_Break=sterm}', "");
Expect(0, 70087, '\P{^Sentence_Break=sterm}', "");
Expect(1, 70086, '\p{Sentence_Break:	sterm}', "");
Expect(0, 70086, '\p{^Sentence_Break:	sterm}', "");
Expect(0, 70086, '\P{Sentence_Break:	sterm}', "");
Expect(1, 70086, '\P{^Sentence_Break:	sterm}', "");
Expect(0, 70087, '\p{Sentence_Break:	sterm}', "");
Expect(1, 70087, '\p{^Sentence_Break:	sterm}', "");
Expect(1, 70087, '\P{Sentence_Break:	sterm}', "");
Expect(0, 70087, '\P{^Sentence_Break:	sterm}', "");
Error('\p{SB=/a/ 	ST}');
Error('\P{SB=/a/ 	ST}');
Expect(1, 70086, '\p{SB=st}', "");
Expect(0, 70086, '\p{^SB=st}', "");
Expect(0, 70086, '\P{SB=st}', "");
Expect(1, 70086, '\P{^SB=st}', "");
Expect(0, 70087, '\p{SB=st}', "");
Expect(1, 70087, '\p{^SB=st}', "");
Expect(1, 70087, '\P{SB=st}', "");
Expect(0, 70087, '\P{^SB=st}', "");
Expect(1, 70086, '\p{SB=_st}', "");
Expect(0, 70086, '\p{^SB=_st}', "");
Expect(0, 70086, '\P{SB=_st}', "");
Expect(1, 70086, '\P{^SB=_st}', "");
Expect(0, 70087, '\p{SB=_st}', "");
Expect(1, 70087, '\p{^SB=_st}', "");
Expect(1, 70087, '\P{SB=_st}', "");
Expect(0, 70087, '\P{^SB=_st}', "");
Error('\p{Is_Sentence_Break= /a/STerm}');
Error('\P{Is_Sentence_Break= /a/STerm}');
Expect(1, 70086, '\p{Is_Sentence_Break=sterm}', "");
Expect(0, 70086, '\p{^Is_Sentence_Break=sterm}', "");
Expect(0, 70086, '\P{Is_Sentence_Break=sterm}', "");
Expect(1, 70086, '\P{^Is_Sentence_Break=sterm}', "");
Expect(0, 70087, '\p{Is_Sentence_Break=sterm}', "");
Expect(1, 70087, '\p{^Is_Sentence_Break=sterm}', "");
Expect(1, 70087, '\P{Is_Sentence_Break=sterm}', "");
Expect(0, 70087, '\P{^Is_Sentence_Break=sterm}', "");
Expect(1, 70086, '\p{Is_Sentence_Break=-STerm}', "");
Expect(0, 70086, '\p{^Is_Sentence_Break=-STerm}', "");
Expect(0, 70086, '\P{Is_Sentence_Break=-STerm}', "");
Expect(1, 70086, '\P{^Is_Sentence_Break=-STerm}', "");
Expect(0, 70087, '\p{Is_Sentence_Break=-STerm}', "");
Expect(1, 70087, '\p{^Is_Sentence_Break=-STerm}', "");
Expect(1, 70087, '\P{Is_Sentence_Break=-STerm}', "");
Expect(0, 70087, '\P{^Is_Sentence_Break=-STerm}', "");
Error('\p{Is_SB=/a/_	ST}');
Error('\P{Is_SB=/a/_	ST}');
Expect(1, 70086, '\p{Is_SB=st}', "");
Expect(0, 70086, '\p{^Is_SB=st}', "");
Expect(0, 70086, '\P{Is_SB=st}', "");
Expect(1, 70086, '\P{^Is_SB=st}', "");
Expect(0, 70087, '\p{Is_SB=st}', "");
Expect(1, 70087, '\p{^Is_SB=st}', "");
Expect(1, 70087, '\P{Is_SB=st}', "");
Expect(0, 70087, '\P{^Is_SB=st}', "");
Expect(1, 70086, '\p{Is_SB=--st}', "");
Expect(0, 70086, '\p{^Is_SB=--st}', "");
Expect(0, 70086, '\P{Is_SB=--st}', "");
Expect(1, 70086, '\P{^Is_SB=--st}', "");
Expect(0, 70087, '\p{Is_SB=--st}', "");
Expect(1, 70087, '\p{^Is_SB=--st}', "");
Expect(1, 70087, '\P{Is_SB=--st}', "");
Expect(0, 70087, '\P{^Is_SB=--st}', "");
Error('\p{Sentence_Break=	/a/Upper}');
Error('\P{Sentence_Break=	/a/Upper}');
Expect(1, 120778, '\p{Sentence_Break=upper}', "");
Expect(0, 120778, '\p{^Sentence_Break=upper}', "");
Expect(0, 120778, '\P{Sentence_Break=upper}', "");
Expect(1, 120778, '\P{^Sentence_Break=upper}', "");
Expect(0, 120779, '\p{Sentence_Break=upper}', "");
Expect(1, 120779, '\p{^Sentence_Break=upper}', "");
Expect(1, 120779, '\P{Sentence_Break=upper}', "");
Expect(0, 120779, '\P{^Sentence_Break=upper}', "");
Expect(1, 120778, '\p{Sentence_Break=_Upper}', "");
Expect(0, 120778, '\p{^Sentence_Break=_Upper}', "");
Expect(0, 120778, '\P{Sentence_Break=_Upper}', "");
Expect(1, 120778, '\P{^Sentence_Break=_Upper}', "");
Expect(0, 120779, '\p{Sentence_Break=_Upper}', "");
Expect(1, 120779, '\p{^Sentence_Break=_Upper}', "");
Expect(1, 120779, '\P{Sentence_Break=_Upper}', "");
Expect(0, 120779, '\P{^Sentence_Break=_Upper}', "");
Error('\p{SB=	up:=}');
Error('\P{SB=	up:=}');
Expect(1, 120778, '\p{SB=up}', "");
Expect(0, 120778, '\p{^SB=up}', "");
Expect(0, 120778, '\P{SB=up}', "");
Expect(1, 120778, '\P{^SB=up}', "");
Expect(0, 120779, '\p{SB=up}', "");
Expect(1, 120779, '\p{^SB=up}', "");
Expect(1, 120779, '\P{SB=up}', "");
Expect(0, 120779, '\P{^SB=up}', "");
Expect(1, 120778, '\p{SB= _UP}', "");
Expect(0, 120778, '\p{^SB= _UP}', "");
Expect(0, 120778, '\P{SB= _UP}', "");
Expect(1, 120778, '\P{^SB= _UP}', "");
Expect(0, 120779, '\p{SB= _UP}', "");
Expect(1, 120779, '\p{^SB= _UP}', "");
Expect(1, 120779, '\P{SB= _UP}', "");
Expect(0, 120779, '\P{^SB= _UP}', "");
Error('\p{Is_Sentence_Break=:=	 upper}');
Error('\P{Is_Sentence_Break=:=	 upper}');
Expect(1, 120778, '\p{Is_Sentence_Break=upper}', "");
Expect(0, 120778, '\p{^Is_Sentence_Break=upper}', "");
Expect(0, 120778, '\P{Is_Sentence_Break=upper}', "");
Expect(1, 120778, '\P{^Is_Sentence_Break=upper}', "");
Expect(0, 120779, '\p{Is_Sentence_Break=upper}', "");
Expect(1, 120779, '\p{^Is_Sentence_Break=upper}', "");
Expect(1, 120779, '\P{Is_Sentence_Break=upper}', "");
Expect(0, 120779, '\P{^Is_Sentence_Break=upper}', "");
Expect(1, 120778, '\p{Is_Sentence_Break=- Upper}', "");
Expect(0, 120778, '\p{^Is_Sentence_Break=- Upper}', "");
Expect(0, 120778, '\P{Is_Sentence_Break=- Upper}', "");
Expect(1, 120778, '\P{^Is_Sentence_Break=- Upper}', "");
Expect(0, 120779, '\p{Is_Sentence_Break=- Upper}', "");
Expect(1, 120779, '\p{^Is_Sentence_Break=- Upper}', "");
Expect(1, 120779, '\P{Is_Sentence_Break=- Upper}', "");
Expect(0, 120779, '\P{^Is_Sentence_Break=- Upper}', "");
Error('\p{Is_SB: 	up:=}');
Error('\P{Is_SB: 	up:=}');
Expect(1, 120778, '\p{Is_SB=up}', "");
Expect(0, 120778, '\p{^Is_SB=up}', "");
Expect(0, 120778, '\P{Is_SB=up}', "");
Expect(1, 120778, '\P{^Is_SB=up}', "");
Expect(0, 120779, '\p{Is_SB=up}', "");
Expect(1, 120779, '\p{^Is_SB=up}', "");
Expect(1, 120779, '\P{Is_SB=up}', "");
Expect(0, 120779, '\P{^Is_SB=up}', "");
Expect(1, 120778, '\p{Is_SB=	up}', "");
Expect(0, 120778, '\p{^Is_SB=	up}', "");
Expect(0, 120778, '\P{Is_SB=	up}', "");
Expect(1, 120778, '\P{^Is_SB=	up}', "");
Expect(0, 120779, '\p{Is_SB=	up}', "");
Expect(1, 120779, '\p{^Is_SB=	up}', "");
Expect(1, 120779, '\P{Is_SB=	up}', "");
Expect(0, 120779, '\P{^Is_SB=	up}', "");
Error('\p{Sentence_Break=	:=Other}');
Error('\P{Sentence_Break=	:=Other}');
Expect(1, 918000, '\p{Sentence_Break=other}', "");
Expect(0, 918000, '\p{^Sentence_Break=other}', "");
Expect(0, 918000, '\P{Sentence_Break=other}', "");
Expect(1, 918000, '\P{^Sentence_Break=other}', "");
Expect(0, 917999, '\p{Sentence_Break=other}', "");
Expect(1, 917999, '\p{^Sentence_Break=other}', "");
Expect(1, 917999, '\P{Sentence_Break=other}', "");
Expect(0, 917999, '\P{^Sentence_Break=other}', "");
Expect(1, 918000, '\p{Sentence_Break=	Other}', "");
Expect(0, 918000, '\p{^Sentence_Break=	Other}', "");
Expect(0, 918000, '\P{Sentence_Break=	Other}', "");
Expect(1, 918000, '\P{^Sentence_Break=	Other}', "");
Expect(0, 917999, '\p{Sentence_Break=	Other}', "");
Expect(1, 917999, '\p{^Sentence_Break=	Other}', "");
Expect(1, 917999, '\P{Sentence_Break=	Other}', "");
Expect(0, 917999, '\P{^Sentence_Break=	Other}', "");
Error('\p{SB=:=	XX}');
Error('\P{SB=:=	XX}');
Expect(1, 918000, '\p{SB=xx}', "");
Expect(0, 918000, '\p{^SB=xx}', "");
Expect(0, 918000, '\P{SB=xx}', "");
Expect(1, 918000, '\P{^SB=xx}', "");
Expect(0, 917999, '\p{SB=xx}', "");
Expect(1, 917999, '\p{^SB=xx}', "");
Expect(1, 917999, '\P{SB=xx}', "");
Expect(0, 917999, '\P{^SB=xx}', "");
Expect(1, 918000, '\p{SB=	 XX}', "");
Expect(0, 918000, '\p{^SB=	 XX}', "");
Expect(0, 918000, '\P{SB=	 XX}', "");
Expect(1, 918000, '\P{^SB=	 XX}', "");
Expect(0, 917999, '\p{SB=	 XX}', "");
Expect(1, 917999, '\p{^SB=	 XX}', "");
Expect(1, 917999, '\P{SB=	 XX}', "");
Expect(0, 917999, '\P{^SB=	 XX}', "");
Error('\p{Is_Sentence_Break=:=	 Other}');
Error('\P{Is_Sentence_Break=:=	 Other}');
Expect(1, 918000, '\p{Is_Sentence_Break=other}', "");
Expect(0, 918000, '\p{^Is_Sentence_Break=other}', "");
Expect(0, 918000, '\P{Is_Sentence_Break=other}', "");
Expect(1, 918000, '\P{^Is_Sentence_Break=other}', "");
Expect(0, 917999, '\p{Is_Sentence_Break=other}', "");
Expect(1, 917999, '\p{^Is_Sentence_Break=other}', "");
Expect(1, 917999, '\P{Is_Sentence_Break=other}', "");
Expect(0, 917999, '\P{^Is_Sentence_Break=other}', "");
Expect(1, 918000, '\p{Is_Sentence_Break=	Other}', "");
Expect(0, 918000, '\p{^Is_Sentence_Break=	Other}', "");
Expect(0, 918000, '\P{Is_Sentence_Break=	Other}', "");
Expect(1, 918000, '\P{^Is_Sentence_Break=	Other}', "");
Expect(0, 917999, '\p{Is_Sentence_Break=	Other}', "");
Expect(1, 917999, '\p{^Is_Sentence_Break=	Other}', "");
Expect(1, 917999, '\P{Is_Sentence_Break=	Other}', "");
Expect(0, 917999, '\P{^Is_Sentence_Break=	Other}', "");
Error('\p{Is_SB=	-XX/a/}');
Error('\P{Is_SB=	-XX/a/}');
Expect(1, 918000, '\p{Is_SB=xx}', "");
Expect(0, 918000, '\p{^Is_SB=xx}', "");
Expect(0, 918000, '\P{Is_SB=xx}', "");
Expect(1, 918000, '\P{^Is_SB=xx}', "");
Expect(0, 917999, '\p{Is_SB=xx}', "");
Expect(1, 917999, '\p{^Is_SB=xx}', "");
Expect(1, 917999, '\P{Is_SB=xx}', "");
Expect(0, 917999, '\P{^Is_SB=xx}', "");
Expect(1, 918000, '\p{Is_SB=_-XX}', "");
Expect(0, 918000, '\p{^Is_SB=_-XX}', "");
Expect(0, 918000, '\P{Is_SB=_-XX}', "");
Expect(1, 918000, '\P{^Is_SB=_-XX}', "");
Expect(0, 917999, '\p{Is_SB=_-XX}', "");
Expect(1, 917999, '\p{^Is_SB=_-XX}', "");
Expect(1, 917999, '\P{Is_SB=_-XX}', "");
Expect(0, 917999, '\P{^Is_SB=_-XX}', "");
Error('\p{Soft_Dotted=:=_NO}');
Error('\P{Soft_Dotted=:=_NO}');
Expect(1, 120468, '\p{Soft_Dotted=no}', "");
Expect(0, 120468, '\p{^Soft_Dotted=no}', "");
Expect(0, 120468, '\P{Soft_Dotted=no}', "");
Expect(1, 120468, '\P{^Soft_Dotted=no}', "");
Expect(0, 120467, '\p{Soft_Dotted=no}', "");
Expect(1, 120467, '\p{^Soft_Dotted=no}', "");
Expect(1, 120467, '\P{Soft_Dotted=no}', "");
Expect(0, 120467, '\P{^Soft_Dotted=no}', "");
Expect(1, 120468, '\p{Soft_Dotted=	-No}', "");
Expect(0, 120468, '\p{^Soft_Dotted=	-No}', "");
Expect(0, 120468, '\P{Soft_Dotted=	-No}', "");
Expect(1, 120468, '\P{^Soft_Dotted=	-No}', "");
Expect(0, 120467, '\p{Soft_Dotted=	-No}', "");
Expect(1, 120467, '\p{^Soft_Dotted=	-No}', "");
Expect(1, 120467, '\P{Soft_Dotted=	-No}', "");
Expect(0, 120467, '\P{^Soft_Dotted=	-No}', "");
Error('\p{SD= /a/N}');
Error('\P{SD= /a/N}');
Expect(1, 120468, '\p{SD=n}', "");
Expect(0, 120468, '\p{^SD=n}', "");
Expect(0, 120468, '\P{SD=n}', "");
Expect(1, 120468, '\P{^SD=n}', "");
Expect(0, 120467, '\p{SD=n}', "");
Expect(1, 120467, '\p{^SD=n}', "");
Expect(1, 120467, '\P{SD=n}', "");
Expect(0, 120467, '\P{^SD=n}', "");
Expect(1, 120468, '\p{SD=--N}', "");
Expect(0, 120468, '\p{^SD=--N}', "");
Expect(0, 120468, '\P{SD=--N}', "");
Expect(1, 120468, '\P{^SD=--N}', "");
Expect(0, 120467, '\p{SD=--N}', "");
Expect(1, 120467, '\p{^SD=--N}', "");
Expect(1, 120467, '\P{SD=--N}', "");
Expect(0, 120467, '\P{^SD=--N}', "");
Error('\p{Is_Soft_Dotted=	 F:=}');
Error('\P{Is_Soft_Dotted=	 F:=}');
Expect(1, 120468, '\p{Is_Soft_Dotted=f}', "");
Expect(0, 120468, '\p{^Is_Soft_Dotted=f}', "");
Expect(0, 120468, '\P{Is_Soft_Dotted=f}', "");
Expect(1, 120468, '\P{^Is_Soft_Dotted=f}', "");
Expect(0, 120467, '\p{Is_Soft_Dotted=f}', "");
Expect(1, 120467, '\p{^Is_Soft_Dotted=f}', "");
Expect(1, 120467, '\P{Is_Soft_Dotted=f}', "");
Expect(0, 120467, '\P{^Is_Soft_Dotted=f}', "");
Expect(1, 120468, '\p{Is_Soft_Dotted=	F}', "");
Expect(0, 120468, '\p{^Is_Soft_Dotted=	F}', "");
Expect(0, 120468, '\P{Is_Soft_Dotted=	F}', "");
Expect(1, 120468, '\P{^Is_Soft_Dotted=	F}', "");
Expect(0, 120467, '\p{Is_Soft_Dotted=	F}', "");
Expect(1, 120467, '\p{^Is_Soft_Dotted=	F}', "");
Expect(1, 120467, '\P{Is_Soft_Dotted=	F}', "");
Expect(0, 120467, '\P{^Is_Soft_Dotted=	F}', "");
Error('\p{Is_SD=	/a/False}');
Error('\P{Is_SD=	/a/False}');
Expect(1, 120468, '\p{Is_SD=false}', "");
Expect(0, 120468, '\p{^Is_SD=false}', "");
Expect(0, 120468, '\P{Is_SD=false}', "");
Expect(1, 120468, '\P{^Is_SD=false}', "");
Expect(0, 120467, '\p{Is_SD=false}', "");
Expect(1, 120467, '\p{^Is_SD=false}', "");
Expect(1, 120467, '\P{Is_SD=false}', "");
Expect(0, 120467, '\P{^Is_SD=false}', "");
Expect(1, 120468, '\p{Is_SD=_FALSE}', "");
Expect(0, 120468, '\p{^Is_SD=_FALSE}', "");
Expect(0, 120468, '\P{Is_SD=_FALSE}', "");
Expect(1, 120468, '\P{^Is_SD=_FALSE}', "");
Expect(0, 120467, '\p{Is_SD=_FALSE}', "");
Expect(1, 120467, '\p{^Is_SD=_FALSE}', "");
Expect(1, 120467, '\P{Is_SD=_FALSE}', "");
Expect(0, 120467, '\P{^Is_SD=_FALSE}', "");
Error('\p{Soft_Dotted=/a/Yes}');
Error('\P{Soft_Dotted=/a/Yes}');
Expect(1, 120467, '\p{Soft_Dotted=yes}', "");
Expect(0, 120467, '\p{^Soft_Dotted=yes}', "");
Expect(0, 120467, '\P{Soft_Dotted=yes}', "");
Expect(1, 120467, '\P{^Soft_Dotted=yes}', "");
Expect(0, 120468, '\p{Soft_Dotted=yes}', "");
Expect(1, 120468, '\p{^Soft_Dotted=yes}', "");
Expect(1, 120468, '\P{Soft_Dotted=yes}', "");
Expect(0, 120468, '\P{^Soft_Dotted=yes}', "");
Expect(1, 120467, '\p{Soft_Dotted=	-YES}', "");
Expect(0, 120467, '\p{^Soft_Dotted=	-YES}', "");
Expect(0, 120467, '\P{Soft_Dotted=	-YES}', "");
Expect(1, 120467, '\P{^Soft_Dotted=	-YES}', "");
Expect(0, 120468, '\p{Soft_Dotted=	-YES}', "");
Expect(1, 120468, '\p{^Soft_Dotted=	-YES}', "");
Expect(1, 120468, '\P{Soft_Dotted=	-YES}', "");
Expect(0, 120468, '\P{^Soft_Dotted=	-YES}', "");
Error('\p{SD=_/a/Y}');
Error('\P{SD=_/a/Y}');
Expect(1, 120467, '\p{SD=y}', "");
Expect(0, 120467, '\p{^SD=y}', "");
Expect(0, 120467, '\P{SD=y}', "");
Expect(1, 120467, '\P{^SD=y}', "");
Expect(0, 120468, '\p{SD=y}', "");
Expect(1, 120468, '\p{^SD=y}', "");
Expect(1, 120468, '\P{SD=y}', "");
Expect(0, 120468, '\P{^SD=y}', "");
Expect(1, 120467, '\p{SD=__Y}', "");
Expect(0, 120467, '\p{^SD=__Y}', "");
Expect(0, 120467, '\P{SD=__Y}', "");
Expect(1, 120467, '\P{^SD=__Y}', "");
Expect(0, 120468, '\p{SD=__Y}', "");
Expect(1, 120468, '\p{^SD=__Y}', "");
Expect(1, 120468, '\P{SD=__Y}', "");
Expect(0, 120468, '\P{^SD=__Y}', "");
Error('\p{Is_Soft_Dotted:/a/--t}');
Error('\P{Is_Soft_Dotted:/a/--t}');
Expect(1, 120467, '\p{Is_Soft_Dotted=t}', "");
Expect(0, 120467, '\p{^Is_Soft_Dotted=t}', "");
Expect(0, 120467, '\P{Is_Soft_Dotted=t}', "");
Expect(1, 120467, '\P{^Is_Soft_Dotted=t}', "");
Expect(0, 120468, '\p{Is_Soft_Dotted=t}', "");
Expect(1, 120468, '\p{^Is_Soft_Dotted=t}', "");
Expect(1, 120468, '\P{Is_Soft_Dotted=t}', "");
Expect(0, 120468, '\P{^Is_Soft_Dotted=t}', "");
Expect(1, 120467, '\p{Is_Soft_Dotted=	-T}', "");
Expect(0, 120467, '\p{^Is_Soft_Dotted=	-T}', "");
Expect(0, 120467, '\P{Is_Soft_Dotted=	-T}', "");
Expect(1, 120467, '\P{^Is_Soft_Dotted=	-T}', "");
Expect(0, 120468, '\p{Is_Soft_Dotted=	-T}', "");
Expect(1, 120468, '\p{^Is_Soft_Dotted=	-T}', "");
Expect(1, 120468, '\P{Is_Soft_Dotted=	-T}', "");
Expect(0, 120468, '\P{^Is_Soft_Dotted=	-T}', "");
Error('\p{Is_SD=/a/_-true}');
Error('\P{Is_SD=/a/_-true}');
Expect(1, 120467, '\p{Is_SD=true}', "");
Expect(0, 120467, '\p{^Is_SD=true}', "");
Expect(0, 120467, '\P{Is_SD=true}', "");
Expect(1, 120467, '\P{^Is_SD=true}', "");
Expect(0, 120468, '\p{Is_SD=true}', "");
Expect(1, 120468, '\p{^Is_SD=true}', "");
Expect(1, 120468, '\P{Is_SD=true}', "");
Expect(0, 120468, '\P{^Is_SD=true}', "");
Expect(1, 120467, '\p{Is_SD=_True}', "");
Expect(0, 120467, '\p{^Is_SD=_True}', "");
Expect(0, 120467, '\P{Is_SD=_True}', "");
Expect(1, 120467, '\P{^Is_SD=_True}', "");
Expect(0, 120468, '\p{Is_SD=_True}', "");
Expect(1, 120468, '\p{^Is_SD=_True}', "");
Expect(1, 120468, '\P{Is_SD=_True}', "");
Expect(0, 120468, '\P{^Is_SD=_True}', "");
Error('\p{STerm=	/a/NO}');
Error('\P{STerm=	/a/NO}');
Expect(1, 70087, '\p{STerm=no}', "");
Expect(0, 70087, '\p{^STerm=no}', "");
Expect(0, 70087, '\P{STerm=no}', "");
Expect(1, 70087, '\P{^STerm=no}', "");
Expect(0, 70086, '\p{STerm=no}', "");
Expect(1, 70086, '\p{^STerm=no}', "");
Expect(1, 70086, '\P{STerm=no}', "");
Expect(0, 70086, '\P{^STerm=no}', "");
Expect(1, 70087, '\p{STerm=	-No}', "");
Expect(0, 70087, '\p{^STerm=	-No}', "");
Expect(0, 70087, '\P{STerm=	-No}', "");
Expect(1, 70087, '\P{^STerm=	-No}', "");
Expect(0, 70086, '\p{STerm=	-No}', "");
Expect(1, 70086, '\p{^STerm=	-No}', "");
Expect(1, 70086, '\P{STerm=	-No}', "");
Expect(0, 70086, '\P{^STerm=	-No}', "");
Error('\p{Is_STerm= :=N}');
Error('\P{Is_STerm= :=N}');
Expect(1, 70087, '\p{Is_STerm=n}', "");
Expect(0, 70087, '\p{^Is_STerm=n}', "");
Expect(0, 70087, '\P{Is_STerm=n}', "");
Expect(1, 70087, '\P{^Is_STerm=n}', "");
Expect(0, 70086, '\p{Is_STerm=n}', "");
Expect(1, 70086, '\p{^Is_STerm=n}', "");
Expect(1, 70086, '\P{Is_STerm=n}', "");
Expect(0, 70086, '\P{^Is_STerm=n}', "");
Expect(1, 70087, '\p{Is_STerm=_N}', "");
Expect(0, 70087, '\p{^Is_STerm=_N}', "");
Expect(0, 70087, '\P{Is_STerm=_N}', "");
Expect(1, 70087, '\P{^Is_STerm=_N}', "");
Expect(0, 70086, '\p{Is_STerm=_N}', "");
Expect(1, 70086, '\p{^Is_STerm=_N}', "");
Expect(1, 70086, '\P{Is_STerm=_N}', "");
Expect(0, 70086, '\P{^Is_STerm=_N}', "");
Error('\p{STerm=/a/_-F}');
Error('\P{STerm=/a/_-F}');
Expect(1, 70087, '\p{STerm=f}', "");
Expect(0, 70087, '\p{^STerm=f}', "");
Expect(0, 70087, '\P{STerm=f}', "");
Expect(1, 70087, '\P{^STerm=f}', "");
Expect(0, 70086, '\p{STerm=f}', "");
Expect(1, 70086, '\p{^STerm=f}', "");
Expect(1, 70086, '\P{STerm=f}', "");
Expect(0, 70086, '\P{^STerm=f}', "");
Expect(1, 70087, '\p{STerm= 	F}', "");
Expect(0, 70087, '\p{^STerm= 	F}', "");
Expect(0, 70087, '\P{STerm= 	F}', "");
Expect(1, 70087, '\P{^STerm= 	F}', "");
Expect(0, 70086, '\p{STerm= 	F}', "");
Expect(1, 70086, '\p{^STerm= 	F}', "");
Expect(1, 70086, '\P{STerm= 	F}', "");
Expect(0, 70086, '\P{^STerm= 	F}', "");
Error('\p{Is_STerm=-_FALSE/a/}');
Error('\P{Is_STerm=-_FALSE/a/}');
Expect(1, 70087, '\p{Is_STerm=false}', "");
Expect(0, 70087, '\p{^Is_STerm=false}', "");
Expect(0, 70087, '\P{Is_STerm=false}', "");
Expect(1, 70087, '\P{^Is_STerm=false}', "");
Expect(0, 70086, '\p{Is_STerm=false}', "");
Expect(1, 70086, '\p{^Is_STerm=false}', "");
Expect(1, 70086, '\P{Is_STerm=false}', "");
Expect(0, 70086, '\P{^Is_STerm=false}', "");
Expect(1, 70087, '\p{Is_STerm=-false}', "");
Expect(0, 70087, '\p{^Is_STerm=-false}', "");
Expect(0, 70087, '\P{Is_STerm=-false}', "");
Expect(1, 70087, '\P{^Is_STerm=-false}', "");
Expect(0, 70086, '\p{Is_STerm=-false}', "");
Expect(1, 70086, '\p{^Is_STerm=-false}', "");
Expect(1, 70086, '\P{Is_STerm=-false}', "");
Expect(0, 70086, '\P{^Is_STerm=-false}', "");
Error('\p{STerm=_/a/yes}');
Error('\P{STerm=_/a/yes}');
Expect(1, 70086, '\p{STerm=yes}', "");
Expect(0, 70086, '\p{^STerm=yes}', "");
Expect(0, 70086, '\P{STerm=yes}', "");
Expect(1, 70086, '\P{^STerm=yes}', "");
Expect(0, 70087, '\p{STerm=yes}', "");
Expect(1, 70087, '\p{^STerm=yes}', "");
Expect(1, 70087, '\P{STerm=yes}', "");
Expect(0, 70087, '\P{^STerm=yes}', "");
Expect(1, 70086, '\p{STerm:	_Yes}', "");
Expect(0, 70086, '\p{^STerm:	_Yes}', "");
Expect(0, 70086, '\P{STerm:	_Yes}', "");
Expect(1, 70086, '\P{^STerm:	_Yes}', "");
Expect(0, 70087, '\p{STerm:	_Yes}', "");
Expect(1, 70087, '\p{^STerm:	_Yes}', "");
Expect(1, 70087, '\P{STerm:	_Yes}', "");
Expect(0, 70087, '\P{^STerm:	_Yes}', "");
Error('\p{Is_STerm=:=Y}');
Error('\P{Is_STerm=:=Y}');
Expect(1, 70086, '\p{Is_STerm=y}', "");
Expect(0, 70086, '\p{^Is_STerm=y}', "");
Expect(0, 70086, '\P{Is_STerm=y}', "");
Expect(1, 70086, '\P{^Is_STerm=y}', "");
Expect(0, 70087, '\p{Is_STerm=y}', "");
Expect(1, 70087, '\p{^Is_STerm=y}', "");
Expect(1, 70087, '\P{Is_STerm=y}', "");
Expect(0, 70087, '\P{^Is_STerm=y}', "");
Expect(1, 70086, '\p{Is_STerm=_	y}', "");
Expect(0, 70086, '\p{^Is_STerm=_	y}', "");
Expect(0, 70086, '\P{Is_STerm=_	y}', "");
Expect(1, 70086, '\P{^Is_STerm=_	y}', "");
Expect(0, 70087, '\p{Is_STerm=_	y}', "");
Expect(1, 70087, '\p{^Is_STerm=_	y}', "");
Expect(1, 70087, '\P{Is_STerm=_	y}', "");
Expect(0, 70087, '\P{^Is_STerm=_	y}', "");
Error('\p{STerm= /a/T}');
Error('\P{STerm= /a/T}');
Expect(1, 70086, '\p{STerm=t}', "");
Expect(0, 70086, '\p{^STerm=t}', "");
Expect(0, 70086, '\P{STerm=t}', "");
Expect(1, 70086, '\P{^STerm=t}', "");
Expect(0, 70087, '\p{STerm=t}', "");
Expect(1, 70087, '\p{^STerm=t}', "");
Expect(1, 70087, '\P{STerm=t}', "");
Expect(0, 70087, '\P{^STerm=t}', "");
Expect(1, 70086, '\p{STerm=	_T}', "");
Expect(0, 70086, '\p{^STerm=	_T}', "");
Expect(0, 70086, '\P{STerm=	_T}', "");
Expect(1, 70086, '\P{^STerm=	_T}', "");
Expect(0, 70087, '\p{STerm=	_T}', "");
Expect(1, 70087, '\p{^STerm=	_T}', "");
Expect(1, 70087, '\P{STerm=	_T}', "");
Expect(0, 70087, '\P{^STerm=	_T}', "");
Error('\p{Is_STerm=:= true}');
Error('\P{Is_STerm=:= true}');
Expect(1, 70086, '\p{Is_STerm:true}', "");
Expect(0, 70086, '\p{^Is_STerm:true}', "");
Expect(0, 70086, '\P{Is_STerm:true}', "");
Expect(1, 70086, '\P{^Is_STerm:true}', "");
Expect(0, 70087, '\p{Is_STerm:true}', "");
Expect(1, 70087, '\p{^Is_STerm:true}', "");
Expect(1, 70087, '\P{Is_STerm:true}', "");
Expect(0, 70087, '\P{^Is_STerm:true}', "");
Expect(1, 70086, '\p{Is_STerm=		true}', "");
Expect(0, 70086, '\p{^Is_STerm=		true}', "");
Expect(0, 70086, '\P{Is_STerm=		true}', "");
Expect(1, 70086, '\P{^Is_STerm=		true}', "");
Expect(0, 70087, '\p{Is_STerm=		true}', "");
Expect(1, 70087, '\p{^Is_STerm=		true}', "");
Expect(1, 70087, '\P{Is_STerm=		true}', "");
Expect(0, 70087, '\P{^Is_STerm=		true}', "");
Error('\p{Terminal_Punctuation:_ no/a/}');
Error('\P{Terminal_Punctuation:_ no/a/}');
Expect(1, 74868, '\p{Terminal_Punctuation: no}', "");
Expect(0, 74868, '\p{^Terminal_Punctuation: no}', "");
Expect(0, 74868, '\P{Terminal_Punctuation: no}', "");
Expect(1, 74868, '\P{^Terminal_Punctuation: no}', "");
Expect(0, 74867, '\p{Terminal_Punctuation: no}', "");
Expect(1, 74867, '\p{^Terminal_Punctuation: no}', "");
Expect(1, 74867, '\P{Terminal_Punctuation: no}', "");
Expect(0, 74867, '\P{^Terminal_Punctuation: no}', "");
Expect(1, 74868, '\p{Terminal_Punctuation=-NO}', "");
Expect(0, 74868, '\p{^Terminal_Punctuation=-NO}', "");
Expect(0, 74868, '\P{Terminal_Punctuation=-NO}', "");
Expect(1, 74868, '\P{^Terminal_Punctuation=-NO}', "");
Expect(0, 74867, '\p{Terminal_Punctuation=-NO}', "");
Expect(1, 74867, '\p{^Terminal_Punctuation=-NO}', "");
Expect(1, 74867, '\P{Terminal_Punctuation=-NO}', "");
Expect(0, 74867, '\P{^Terminal_Punctuation=-NO}', "");
Error('\p{Term=:=	n}');
Error('\P{Term=:=	n}');
Expect(1, 74868, '\p{Term=n}', "");
Expect(0, 74868, '\p{^Term=n}', "");
Expect(0, 74868, '\P{Term=n}', "");
Expect(1, 74868, '\P{^Term=n}', "");
Expect(0, 74867, '\p{Term=n}', "");
Expect(1, 74867, '\p{^Term=n}', "");
Expect(1, 74867, '\P{Term=n}', "");
Expect(0, 74867, '\P{^Term=n}', "");
Expect(1, 74868, '\p{Term: 	 N}', "");
Expect(0, 74868, '\p{^Term: 	 N}', "");
Expect(0, 74868, '\P{Term: 	 N}', "");
Expect(1, 74868, '\P{^Term: 	 N}', "");
Expect(0, 74867, '\p{Term: 	 N}', "");
Expect(1, 74867, '\p{^Term: 	 N}', "");
Expect(1, 74867, '\P{Term: 	 N}', "");
Expect(0, 74867, '\P{^Term: 	 N}', "");
Error('\p{Is_Terminal_Punctuation= 	f:=}');
Error('\P{Is_Terminal_Punctuation= 	f:=}');
Expect(1, 74868, '\p{Is_Terminal_Punctuation=f}', "");
Expect(0, 74868, '\p{^Is_Terminal_Punctuation=f}', "");
Expect(0, 74868, '\P{Is_Terminal_Punctuation=f}', "");
Expect(1, 74868, '\P{^Is_Terminal_Punctuation=f}', "");
Expect(0, 74867, '\p{Is_Terminal_Punctuation=f}', "");
Expect(1, 74867, '\p{^Is_Terminal_Punctuation=f}', "");
Expect(1, 74867, '\P{Is_Terminal_Punctuation=f}', "");
Expect(0, 74867, '\P{^Is_Terminal_Punctuation=f}', "");
Expect(1, 74868, '\p{Is_Terminal_Punctuation=	-f}', "");
Expect(0, 74868, '\p{^Is_Terminal_Punctuation=	-f}', "");
Expect(0, 74868, '\P{Is_Terminal_Punctuation=	-f}', "");
Expect(1, 74868, '\P{^Is_Terminal_Punctuation=	-f}', "");
Expect(0, 74867, '\p{Is_Terminal_Punctuation=	-f}', "");
Expect(1, 74867, '\p{^Is_Terminal_Punctuation=	-f}', "");
Expect(1, 74867, '\P{Is_Terminal_Punctuation=	-f}', "");
Expect(0, 74867, '\P{^Is_Terminal_Punctuation=	-f}', "");
Error('\p{Is_Term=_:=False}');
Error('\P{Is_Term=_:=False}');
Expect(1, 74868, '\p{Is_Term=false}', "");
Expect(0, 74868, '\p{^Is_Term=false}', "");
Expect(0, 74868, '\P{Is_Term=false}', "");
Expect(1, 74868, '\P{^Is_Term=false}', "");
Expect(0, 74867, '\p{Is_Term=false}', "");
Expect(1, 74867, '\p{^Is_Term=false}', "");
Expect(1, 74867, '\P{Is_Term=false}', "");
Expect(0, 74867, '\P{^Is_Term=false}', "");
Expect(1, 74868, '\p{Is_Term= _False}', "");
Expect(0, 74868, '\p{^Is_Term= _False}', "");
Expect(0, 74868, '\P{Is_Term= _False}', "");
Expect(1, 74868, '\P{^Is_Term= _False}', "");
Expect(0, 74867, '\p{Is_Term= _False}', "");
Expect(1, 74867, '\p{^Is_Term= _False}', "");
Expect(1, 74867, '\P{Is_Term= _False}', "");
Expect(0, 74867, '\P{^Is_Term= _False}', "");
Error('\p{Terminal_Punctuation:		_Yes/a/}');
Error('\P{Terminal_Punctuation:		_Yes/a/}');
Expect(1, 74867, '\p{Terminal_Punctuation=yes}', "");
Expect(0, 74867, '\p{^Terminal_Punctuation=yes}', "");
Expect(0, 74867, '\P{Terminal_Punctuation=yes}', "");
Expect(1, 74867, '\P{^Terminal_Punctuation=yes}', "");
Expect(0, 74868, '\p{Terminal_Punctuation=yes}', "");
Expect(1, 74868, '\p{^Terminal_Punctuation=yes}', "");
Expect(1, 74868, '\P{Terminal_Punctuation=yes}', "");
Expect(0, 74868, '\P{^Terminal_Punctuation=yes}', "");
Expect(1, 74867, '\p{Terminal_Punctuation=	_Yes}', "");
Expect(0, 74867, '\p{^Terminal_Punctuation=	_Yes}', "");
Expect(0, 74867, '\P{Terminal_Punctuation=	_Yes}', "");
Expect(1, 74867, '\P{^Terminal_Punctuation=	_Yes}', "");
Expect(0, 74868, '\p{Terminal_Punctuation=	_Yes}', "");
Expect(1, 74868, '\p{^Terminal_Punctuation=	_Yes}', "");
Expect(1, 74868, '\P{Terminal_Punctuation=	_Yes}', "");
Expect(0, 74868, '\P{^Terminal_Punctuation=	_Yes}', "");
Error('\p{Term=:=	_Y}');
Error('\P{Term=:=	_Y}');
Expect(1, 74867, '\p{Term=y}', "");
Expect(0, 74867, '\p{^Term=y}', "");
Expect(0, 74867, '\P{Term=y}', "");
Expect(1, 74867, '\P{^Term=y}', "");
Expect(0, 74868, '\p{Term=y}', "");
Expect(1, 74868, '\p{^Term=y}', "");
Expect(1, 74868, '\P{Term=y}', "");
Expect(0, 74868, '\P{^Term=y}', "");
Expect(1, 74867, '\p{Term=	_Y}', "");
Expect(0, 74867, '\p{^Term=	_Y}', "");
Expect(0, 74867, '\P{Term=	_Y}', "");
Expect(1, 74867, '\P{^Term=	_Y}', "");
Expect(0, 74868, '\p{Term=	_Y}', "");
Expect(1, 74868, '\p{^Term=	_Y}', "");
Expect(1, 74868, '\P{Term=	_Y}', "");
Expect(0, 74868, '\P{^Term=	_Y}', "");
Error('\p{Is_Terminal_Punctuation=__t:=}');
Error('\P{Is_Terminal_Punctuation=__t:=}');
Expect(1, 74867, '\p{Is_Terminal_Punctuation=t}', "");
Expect(0, 74867, '\p{^Is_Terminal_Punctuation=t}', "");
Expect(0, 74867, '\P{Is_Terminal_Punctuation=t}', "");
Expect(1, 74867, '\P{^Is_Terminal_Punctuation=t}', "");
Expect(0, 74868, '\p{Is_Terminal_Punctuation=t}', "");
Expect(1, 74868, '\p{^Is_Terminal_Punctuation=t}', "");
Expect(1, 74868, '\P{Is_Terminal_Punctuation=t}', "");
Expect(0, 74868, '\P{^Is_Terminal_Punctuation=t}', "");
Expect(1, 74867, '\p{Is_Terminal_Punctuation=  T}', "");
Expect(0, 74867, '\p{^Is_Terminal_Punctuation=  T}', "");
Expect(0, 74867, '\P{Is_Terminal_Punctuation=  T}', "");
Expect(1, 74867, '\P{^Is_Terminal_Punctuation=  T}', "");
Expect(0, 74868, '\p{Is_Terminal_Punctuation=  T}', "");
Expect(1, 74868, '\p{^Is_Terminal_Punctuation=  T}', "");
Expect(1, 74868, '\P{Is_Terminal_Punctuation=  T}', "");
Expect(0, 74868, '\P{^Is_Terminal_Punctuation=  T}', "");
Error('\p{Is_Term=:=	_True}');
Error('\P{Is_Term=:=	_True}');
Expect(1, 74867, '\p{Is_Term=true}', "");
Expect(0, 74867, '\p{^Is_Term=true}', "");
Expect(0, 74867, '\P{Is_Term=true}', "");
Expect(1, 74867, '\P{^Is_Term=true}', "");
Expect(0, 74868, '\p{Is_Term=true}', "");
Expect(1, 74868, '\p{^Is_Term=true}', "");
Expect(1, 74868, '\P{Is_Term=true}', "");
Expect(0, 74868, '\P{^Is_Term=true}', "");
Expect(1, 74867, '\p{Is_Term=_-True}', "");
Expect(0, 74867, '\p{^Is_Term=_-True}', "");
Expect(0, 74867, '\P{Is_Term=_-True}', "");
Expect(1, 74867, '\P{^Is_Term=_-True}', "");
Expect(0, 74868, '\p{Is_Term=_-True}', "");
Expect(1, 74868, '\p{^Is_Term=_-True}', "");
Expect(1, 74868, '\P{Is_Term=_-True}', "");
Expect(0, 74868, '\P{^Is_Term=_-True}', "");
Error('\p{Unified_Ideograph=/a/_No}');
Error('\P{Unified_Ideograph=/a/_No}');
Expect(1, 178206, '\p{Unified_Ideograph=no}', "");
Expect(0, 178206, '\p{^Unified_Ideograph=no}', "");
Expect(0, 178206, '\P{Unified_Ideograph=no}', "");
Expect(1, 178206, '\P{^Unified_Ideograph=no}', "");
Expect(0, 178205, '\p{Unified_Ideograph=no}', "");
Expect(1, 178205, '\p{^Unified_Ideograph=no}', "");
Expect(1, 178205, '\P{Unified_Ideograph=no}', "");
Expect(0, 178205, '\P{^Unified_Ideograph=no}', "");
Expect(1, 178206, '\p{Unified_Ideograph=	 no}', "");
Expect(0, 178206, '\p{^Unified_Ideograph=	 no}', "");
Expect(0, 178206, '\P{Unified_Ideograph=	 no}', "");
Expect(1, 178206, '\P{^Unified_Ideograph=	 no}', "");
Expect(0, 178205, '\p{Unified_Ideograph=	 no}', "");
Expect(1, 178205, '\p{^Unified_Ideograph=	 no}', "");
Expect(1, 178205, '\P{Unified_Ideograph=	 no}', "");
Expect(0, 178205, '\P{^Unified_Ideograph=	 no}', "");
Error('\p{UIdeo=:=	-N}');
Error('\P{UIdeo=:=	-N}');
Expect(1, 178206, '\p{UIdeo=n}', "");
Expect(0, 178206, '\p{^UIdeo=n}', "");
Expect(0, 178206, '\P{UIdeo=n}', "");
Expect(1, 178206, '\P{^UIdeo=n}', "");
Expect(0, 178205, '\p{UIdeo=n}', "");
Expect(1, 178205, '\p{^UIdeo=n}', "");
Expect(1, 178205, '\P{UIdeo=n}', "");
Expect(0, 178205, '\P{^UIdeo=n}', "");
Expect(1, 178206, '\p{UIdeo=N}', "");
Expect(0, 178206, '\p{^UIdeo=N}', "");
Expect(0, 178206, '\P{UIdeo=N}', "");
Expect(1, 178206, '\P{^UIdeo=N}', "");
Expect(0, 178205, '\p{UIdeo=N}', "");
Expect(1, 178205, '\p{^UIdeo=N}', "");
Expect(1, 178205, '\P{UIdeo=N}', "");
Expect(0, 178205, '\P{^UIdeo=N}', "");
Error('\p{Is_Unified_Ideograph=-F:=}');
Error('\P{Is_Unified_Ideograph=-F:=}');
Expect(1, 178206, '\p{Is_Unified_Ideograph=f}', "");
Expect(0, 178206, '\p{^Is_Unified_Ideograph=f}', "");
Expect(0, 178206, '\P{Is_Unified_Ideograph=f}', "");
Expect(1, 178206, '\P{^Is_Unified_Ideograph=f}', "");
Expect(0, 178205, '\p{Is_Unified_Ideograph=f}', "");
Expect(1, 178205, '\p{^Is_Unified_Ideograph=f}', "");
Expect(1, 178205, '\P{Is_Unified_Ideograph=f}', "");
Expect(0, 178205, '\P{^Is_Unified_Ideograph=f}', "");
Expect(1, 178206, '\p{Is_Unified_Ideograph=	 f}', "");
Expect(0, 178206, '\p{^Is_Unified_Ideograph=	 f}', "");
Expect(0, 178206, '\P{Is_Unified_Ideograph=	 f}', "");
Expect(1, 178206, '\P{^Is_Unified_Ideograph=	 f}', "");
Expect(0, 178205, '\p{Is_Unified_Ideograph=	 f}', "");
Expect(1, 178205, '\p{^Is_Unified_Ideograph=	 f}', "");
Expect(1, 178205, '\P{Is_Unified_Ideograph=	 f}', "");
Expect(0, 178205, '\P{^Is_Unified_Ideograph=	 f}', "");
Error('\p{Is_UIdeo= :=False}');
Error('\P{Is_UIdeo= :=False}');
Expect(1, 178206, '\p{Is_UIdeo=false}', "");
Expect(0, 178206, '\p{^Is_UIdeo=false}', "");
Expect(0, 178206, '\P{Is_UIdeo=false}', "");
Expect(1, 178206, '\P{^Is_UIdeo=false}', "");
Expect(0, 178205, '\p{Is_UIdeo=false}', "");
Expect(1, 178205, '\p{^Is_UIdeo=false}', "");
Expect(1, 178205, '\P{Is_UIdeo=false}', "");
Expect(0, 178205, '\P{^Is_UIdeo=false}', "");
Expect(1, 178206, '\p{Is_UIdeo= 	False}', "");
Expect(0, 178206, '\p{^Is_UIdeo= 	False}', "");
Expect(0, 178206, '\P{Is_UIdeo= 	False}', "");
Expect(1, 178206, '\P{^Is_UIdeo= 	False}', "");
Expect(0, 178205, '\p{Is_UIdeo= 	False}', "");
Expect(1, 178205, '\p{^Is_UIdeo= 	False}', "");
Expect(1, 178205, '\P{Is_UIdeo= 	False}', "");
Expect(0, 178205, '\P{^Is_UIdeo= 	False}', "");
Error('\p{Unified_Ideograph= Yes/a/}');
Error('\P{Unified_Ideograph= Yes/a/}');
Expect(1, 178205, '\p{Unified_Ideograph=yes}', "");
Expect(0, 178205, '\p{^Unified_Ideograph=yes}', "");
Expect(0, 178205, '\P{Unified_Ideograph=yes}', "");
Expect(1, 178205, '\P{^Unified_Ideograph=yes}', "");
Expect(0, 178206, '\p{Unified_Ideograph=yes}', "");
Expect(1, 178206, '\p{^Unified_Ideograph=yes}', "");
Expect(1, 178206, '\P{Unified_Ideograph=yes}', "");
Expect(0, 178206, '\P{^Unified_Ideograph=yes}', "");
Expect(1, 178205, '\p{Unified_Ideograph=  Yes}', "");
Expect(0, 178205, '\p{^Unified_Ideograph=  Yes}', "");
Expect(0, 178205, '\P{Unified_Ideograph=  Yes}', "");
Expect(1, 178205, '\P{^Unified_Ideograph=  Yes}', "");
Expect(0, 178206, '\p{Unified_Ideograph=  Yes}', "");
Expect(1, 178206, '\p{^Unified_Ideograph=  Yes}', "");
Expect(1, 178206, '\P{Unified_Ideograph=  Yes}', "");
Expect(0, 178206, '\P{^Unified_Ideograph=  Yes}', "");
Error('\p{UIdeo=:=-_Y}');
Error('\P{UIdeo=:=-_Y}');
Expect(1, 178205, '\p{UIdeo=y}', "");
Expect(0, 178205, '\p{^UIdeo=y}', "");
Expect(0, 178205, '\P{UIdeo=y}', "");
Expect(1, 178205, '\P{^UIdeo=y}', "");
Expect(0, 178206, '\p{UIdeo=y}', "");
Expect(1, 178206, '\p{^UIdeo=y}', "");
Expect(1, 178206, '\P{UIdeo=y}', "");
Expect(0, 178206, '\P{^UIdeo=y}', "");
Expect(1, 178205, '\p{UIdeo= Y}', "");
Expect(0, 178205, '\p{^UIdeo= Y}', "");
Expect(0, 178205, '\P{UIdeo= Y}', "");
Expect(1, 178205, '\P{^UIdeo= Y}', "");
Expect(0, 178206, '\p{UIdeo= Y}', "");
Expect(1, 178206, '\p{^UIdeo= Y}', "");
Expect(1, 178206, '\P{UIdeo= Y}', "");
Expect(0, 178206, '\P{^UIdeo= Y}', "");
Error('\p{Is_Unified_Ideograph=-	T/a/}');
Error('\P{Is_Unified_Ideograph=-	T/a/}');
Expect(1, 178205, '\p{Is_Unified_Ideograph=t}', "");
Expect(0, 178205, '\p{^Is_Unified_Ideograph=t}', "");
Expect(0, 178205, '\P{Is_Unified_Ideograph=t}', "");
Expect(1, 178205, '\P{^Is_Unified_Ideograph=t}', "");
Expect(0, 178206, '\p{Is_Unified_Ideograph=t}', "");
Expect(1, 178206, '\p{^Is_Unified_Ideograph=t}', "");
Expect(1, 178206, '\P{Is_Unified_Ideograph=t}', "");
Expect(0, 178206, '\P{^Is_Unified_Ideograph=t}', "");
Expect(1, 178205, '\p{Is_Unified_Ideograph:	- T}', "");
Expect(0, 178205, '\p{^Is_Unified_Ideograph:	- T}', "");
Expect(0, 178205, '\P{Is_Unified_Ideograph:	- T}', "");
Expect(1, 178205, '\P{^Is_Unified_Ideograph:	- T}', "");
Expect(0, 178206, '\p{Is_Unified_Ideograph:	- T}', "");
Expect(1, 178206, '\p{^Is_Unified_Ideograph:	- T}', "");
Expect(1, 178206, '\P{Is_Unified_Ideograph:	- T}', "");
Expect(0, 178206, '\P{^Is_Unified_Ideograph:	- T}', "");
Error('\p{Is_UIdeo=/a/ -true}');
Error('\P{Is_UIdeo=/a/ -true}');
Expect(1, 178205, '\p{Is_UIdeo=true}', "");
Expect(0, 178205, '\p{^Is_UIdeo=true}', "");
Expect(0, 178205, '\P{Is_UIdeo=true}', "");
Expect(1, 178205, '\P{^Is_UIdeo=true}', "");
Expect(0, 178206, '\p{Is_UIdeo=true}', "");
Expect(1, 178206, '\p{^Is_UIdeo=true}', "");
Expect(1, 178206, '\P{Is_UIdeo=true}', "");
Expect(0, 178206, '\P{^Is_UIdeo=true}', "");
Expect(1, 178205, '\p{Is_UIdeo= True}', "");
Expect(0, 178205, '\p{^Is_UIdeo= True}', "");
Expect(0, 178205, '\P{Is_UIdeo= True}', "");
Expect(1, 178205, '\P{^Is_UIdeo= True}', "");
Expect(0, 178206, '\p{Is_UIdeo= True}', "");
Expect(1, 178206, '\p{^Is_UIdeo= True}', "");
Expect(1, 178206, '\P{Is_UIdeo= True}', "");
Expect(0, 178206, '\P{^Is_UIdeo= True}', "");
Error('\p{Uppercase:	  NO/a/}');
Error('\P{Uppercase:	  NO/a/}');
Expect(1, 120779, '\p{Uppercase=no}', "");
Expect(0, 120779, '\p{^Uppercase=no}', "");
Expect(0, 120779, '\P{Uppercase=no}', "");
Expect(1, 120779, '\P{^Uppercase=no}', "");
Expect(0, 120778, '\p{Uppercase=no}', "");
Expect(1, 120778, '\p{^Uppercase=no}', "");
Expect(1, 120778, '\P{Uppercase=no}', "");
Expect(0, 120778, '\P{^Uppercase=no}', "");
Expect(1, 120779, '\p{Uppercase= no}', "");
Expect(0, 120779, '\p{^Uppercase= no}', "");
Expect(0, 120779, '\P{Uppercase= no}', "");
Expect(1, 120779, '\P{^Uppercase= no}', "");
Expect(0, 120778, '\p{Uppercase= no}', "");
Expect(1, 120778, '\p{^Uppercase= no}', "");
Expect(1, 120778, '\P{Uppercase= no}', "");
Expect(0, 120778, '\P{^Uppercase= no}', "");
Error('\p{Upper:	_:=n}');
Error('\P{Upper:	_:=n}');
Expect(1, 120779, '\p{Upper=n}', "");
Expect(0, 120779, '\p{^Upper=n}', "");
Expect(0, 120779, '\P{Upper=n}', "");
Expect(1, 120779, '\P{^Upper=n}', "");
Expect(0, 120778, '\p{Upper=n}', "");
Expect(1, 120778, '\p{^Upper=n}', "");
Expect(1, 120778, '\P{Upper=n}', "");
Expect(0, 120778, '\P{^Upper=n}', "");
Expect(1, 120779, '\p{Upper=-N}', "");
Expect(0, 120779, '\p{^Upper=-N}', "");
Expect(0, 120779, '\P{Upper=-N}', "");
Expect(1, 120779, '\P{^Upper=-N}', "");
Expect(0, 120778, '\p{Upper=-N}', "");
Expect(1, 120778, '\p{^Upper=-N}', "");
Expect(1, 120778, '\P{Upper=-N}', "");
Expect(0, 120778, '\P{^Upper=-N}', "");
Error('\p{Is_Uppercase=_F:=}');
Error('\P{Is_Uppercase=_F:=}');
Expect(1, 120779, '\p{Is_Uppercase=f}', "");
Expect(0, 120779, '\p{^Is_Uppercase=f}', "");
Expect(0, 120779, '\P{Is_Uppercase=f}', "");
Expect(1, 120779, '\P{^Is_Uppercase=f}', "");
Expect(0, 120778, '\p{Is_Uppercase=f}', "");
Expect(1, 120778, '\p{^Is_Uppercase=f}', "");
Expect(1, 120778, '\P{Is_Uppercase=f}', "");
Expect(0, 120778, '\P{^Is_Uppercase=f}', "");
Expect(1, 120779, '\p{Is_Uppercase=	F}', "");
Expect(0, 120779, '\p{^Is_Uppercase=	F}', "");
Expect(0, 120779, '\P{Is_Uppercase=	F}', "");
Expect(1, 120779, '\P{^Is_Uppercase=	F}', "");
Expect(0, 120778, '\p{Is_Uppercase=	F}', "");
Expect(1, 120778, '\p{^Is_Uppercase=	F}', "");
Expect(1, 120778, '\P{Is_Uppercase=	F}', "");
Expect(0, 120778, '\P{^Is_Uppercase=	F}', "");
Error('\p{Is_Upper=/a/ 	False}');
Error('\P{Is_Upper=/a/ 	False}');
Expect(1, 120779, '\p{Is_Upper=false}', "");
Expect(0, 120779, '\p{^Is_Upper=false}', "");
Expect(0, 120779, '\P{Is_Upper=false}', "");
Expect(1, 120779, '\P{^Is_Upper=false}', "");
Expect(0, 120778, '\p{Is_Upper=false}', "");
Expect(1, 120778, '\p{^Is_Upper=false}', "");
Expect(1, 120778, '\P{Is_Upper=false}', "");
Expect(0, 120778, '\P{^Is_Upper=false}', "");
Expect(1, 120779, '\p{Is_Upper=_ False}', "");
Expect(0, 120779, '\p{^Is_Upper=_ False}', "");
Expect(0, 120779, '\P{Is_Upper=_ False}', "");
Expect(1, 120779, '\P{^Is_Upper=_ False}', "");
Expect(0, 120778, '\p{Is_Upper=_ False}', "");
Expect(1, 120778, '\p{^Is_Upper=_ False}', "");
Expect(1, 120778, '\P{Is_Upper=_ False}', "");
Expect(0, 120778, '\P{^Is_Upper=_ False}', "");
Error('\p{Uppercase=/a/Yes}');
Error('\P{Uppercase=/a/Yes}');
Expect(1, 120778, '\p{Uppercase=yes}', "");
Expect(0, 120778, '\p{^Uppercase=yes}', "");
Expect(0, 120778, '\P{Uppercase=yes}', "");
Expect(1, 120778, '\P{^Uppercase=yes}', "");
Expect(0, 120779, '\p{Uppercase=yes}', "");
Expect(1, 120779, '\p{^Uppercase=yes}', "");
Expect(1, 120779, '\P{Uppercase=yes}', "");
Expect(0, 120779, '\P{^Uppercase=yes}', "");
Expect(1, 120778, '\p{Uppercase=	 YES}', "");
Expect(0, 120778, '\p{^Uppercase=	 YES}', "");
Expect(0, 120778, '\P{Uppercase=	 YES}', "");
Expect(1, 120778, '\P{^Uppercase=	 YES}', "");
Expect(0, 120779, '\p{Uppercase=	 YES}', "");
Expect(1, 120779, '\p{^Uppercase=	 YES}', "");
Expect(1, 120779, '\P{Uppercase=	 YES}', "");
Expect(0, 120779, '\P{^Uppercase=	 YES}', "");
Error('\p{Upper: /a/- y}');
Error('\P{Upper: /a/- y}');
Expect(1, 120778, '\p{Upper=y}', "");
Expect(0, 120778, '\p{^Upper=y}', "");
Expect(0, 120778, '\P{Upper=y}', "");
Expect(1, 120778, '\P{^Upper=y}', "");
Expect(0, 120779, '\p{Upper=y}', "");
Expect(1, 120779, '\p{^Upper=y}', "");
Expect(1, 120779, '\P{Upper=y}', "");
Expect(0, 120779, '\P{^Upper=y}', "");
Expect(1, 120778, '\p{Upper=	y}', "");
Expect(0, 120778, '\p{^Upper=	y}', "");
Expect(0, 120778, '\P{Upper=	y}', "");
Expect(1, 120778, '\P{^Upper=	y}', "");
Expect(0, 120779, '\p{Upper=	y}', "");
Expect(1, 120779, '\p{^Upper=	y}', "");
Expect(1, 120779, '\P{Upper=	y}', "");
Expect(0, 120779, '\P{^Upper=	y}', "");
Error('\p{Is_Uppercase:	_T/a/}');
Error('\P{Is_Uppercase:	_T/a/}');
Expect(1, 120778, '\p{Is_Uppercase=t}', "");
Expect(0, 120778, '\p{^Is_Uppercase=t}', "");
Expect(0, 120778, '\P{Is_Uppercase=t}', "");
Expect(1, 120778, '\P{^Is_Uppercase=t}', "");
Expect(0, 120779, '\p{Is_Uppercase=t}', "");
Expect(1, 120779, '\p{^Is_Uppercase=t}', "");
Expect(1, 120779, '\P{Is_Uppercase=t}', "");
Expect(0, 120779, '\P{^Is_Uppercase=t}', "");
Expect(1, 120778, '\p{Is_Uppercase=-_T}', "");
Expect(0, 120778, '\p{^Is_Uppercase=-_T}', "");
Expect(0, 120778, '\P{Is_Uppercase=-_T}', "");
Expect(1, 120778, '\P{^Is_Uppercase=-_T}', "");
Expect(0, 120779, '\p{Is_Uppercase=-_T}', "");
Expect(1, 120779, '\p{^Is_Uppercase=-_T}', "");
Expect(1, 120779, '\P{Is_Uppercase=-_T}', "");
Expect(0, 120779, '\P{^Is_Uppercase=-_T}', "");
Error('\p{Is_Upper:    True:=}');
Error('\P{Is_Upper:    True:=}');
Expect(1, 120778, '\p{Is_Upper=true}', "");
Expect(0, 120778, '\p{^Is_Upper=true}', "");
Expect(0, 120778, '\P{Is_Upper=true}', "");
Expect(1, 120778, '\P{^Is_Upper=true}', "");
Expect(0, 120779, '\p{Is_Upper=true}', "");
Expect(1, 120779, '\p{^Is_Upper=true}', "");
Expect(1, 120779, '\P{Is_Upper=true}', "");
Expect(0, 120779, '\P{^Is_Upper=true}', "");
Expect(1, 120778, '\p{Is_Upper=	 true}', "");
Expect(0, 120778, '\p{^Is_Upper=	 true}', "");
Expect(0, 120778, '\P{Is_Upper=	 true}', "");
Expect(1, 120778, '\P{^Is_Upper=	 true}', "");
Expect(0, 120779, '\p{Is_Upper=	 true}', "");
Expect(1, 120779, '\p{^Is_Upper=	 true}', "");
Expect(1, 120779, '\P{Is_Upper=	 true}', "");
Expect(0, 120779, '\P{^Is_Upper=	 true}', "");
Error('\p{Variation_Selector=	-no:=}');
Error('\P{Variation_Selector=	-no:=}');
Expect(1, 918000, '\p{Variation_Selector=no}', "");
Expect(0, 918000, '\p{^Variation_Selector=no}', "");
Expect(0, 918000, '\P{Variation_Selector=no}', "");
Expect(1, 918000, '\P{^Variation_Selector=no}', "");
Expect(0, 917999, '\p{Variation_Selector=no}', "");
Expect(1, 917999, '\p{^Variation_Selector=no}', "");
Expect(1, 917999, '\P{Variation_Selector=no}', "");
Expect(0, 917999, '\P{^Variation_Selector=no}', "");
Expect(1, 918000, '\p{Variation_Selector=	No}', "");
Expect(0, 918000, '\p{^Variation_Selector=	No}', "");
Expect(0, 918000, '\P{Variation_Selector=	No}', "");
Expect(1, 918000, '\P{^Variation_Selector=	No}', "");
Expect(0, 917999, '\p{Variation_Selector=	No}', "");
Expect(1, 917999, '\p{^Variation_Selector=	No}', "");
Expect(1, 917999, '\P{Variation_Selector=	No}', "");
Expect(0, 917999, '\P{^Variation_Selector=	No}', "");
Error('\p{VS= 	N:=}');
Error('\P{VS= 	N:=}');
Expect(1, 918000, '\p{VS=n}', "");
Expect(0, 918000, '\p{^VS=n}', "");
Expect(0, 918000, '\P{VS=n}', "");
Expect(1, 918000, '\P{^VS=n}', "");
Expect(0, 917999, '\p{VS=n}', "");
Expect(1, 917999, '\p{^VS=n}', "");
Expect(1, 917999, '\P{VS=n}', "");
Expect(0, 917999, '\P{^VS=n}', "");
Expect(1, 918000, '\p{VS=__N}', "");
Expect(0, 918000, '\p{^VS=__N}', "");
Expect(0, 918000, '\P{VS=__N}', "");
Expect(1, 918000, '\P{^VS=__N}', "");
Expect(0, 917999, '\p{VS=__N}', "");
Expect(1, 917999, '\p{^VS=__N}', "");
Expect(1, 917999, '\P{VS=__N}', "");
Expect(0, 917999, '\P{^VS=__N}', "");
Error('\p{Is_Variation_Selector=-f/a/}');
Error('\P{Is_Variation_Selector=-f/a/}');
Expect(1, 918000, '\p{Is_Variation_Selector=f}', "");
Expect(0, 918000, '\p{^Is_Variation_Selector=f}', "");
Expect(0, 918000, '\P{Is_Variation_Selector=f}', "");
Expect(1, 918000, '\P{^Is_Variation_Selector=f}', "");
Expect(0, 917999, '\p{Is_Variation_Selector=f}', "");
Expect(1, 917999, '\p{^Is_Variation_Selector=f}', "");
Expect(1, 917999, '\P{Is_Variation_Selector=f}', "");
Expect(0, 917999, '\P{^Is_Variation_Selector=f}', "");
Expect(1, 918000, '\p{Is_Variation_Selector=	F}', "");
Expect(0, 918000, '\p{^Is_Variation_Selector=	F}', "");
Expect(0, 918000, '\P{Is_Variation_Selector=	F}', "");
Expect(1, 918000, '\P{^Is_Variation_Selector=	F}', "");
Expect(0, 917999, '\p{Is_Variation_Selector=	F}', "");
Expect(1, 917999, '\p{^Is_Variation_Selector=	F}', "");
Expect(1, 917999, '\P{Is_Variation_Selector=	F}', "");
Expect(0, 917999, '\P{^Is_Variation_Selector=	F}', "");
Error('\p{Is_VS=_:=False}');
Error('\P{Is_VS=_:=False}');
Expect(1, 918000, '\p{Is_VS=false}', "");
Expect(0, 918000, '\p{^Is_VS=false}', "");
Expect(0, 918000, '\P{Is_VS=false}', "");
Expect(1, 918000, '\P{^Is_VS=false}', "");
Expect(0, 917999, '\p{Is_VS=false}', "");
Expect(1, 917999, '\p{^Is_VS=false}', "");
Expect(1, 917999, '\P{Is_VS=false}', "");
Expect(0, 917999, '\P{^Is_VS=false}', "");
Expect(1, 918000, '\p{Is_VS=FALSE}', "");
Expect(0, 918000, '\p{^Is_VS=FALSE}', "");
Expect(0, 918000, '\P{Is_VS=FALSE}', "");
Expect(1, 918000, '\P{^Is_VS=FALSE}', "");
Expect(0, 917999, '\p{Is_VS=FALSE}', "");
Expect(1, 917999, '\p{^Is_VS=FALSE}', "");
Expect(1, 917999, '\P{Is_VS=FALSE}', "");
Expect(0, 917999, '\P{^Is_VS=FALSE}', "");
Error('\p{Variation_Selector=/a/-_Yes}');
Error('\P{Variation_Selector=/a/-_Yes}');
Expect(1, 917999, '\p{Variation_Selector=yes}', "");
Expect(0, 917999, '\p{^Variation_Selector=yes}', "");
Expect(0, 917999, '\P{Variation_Selector=yes}', "");
Expect(1, 917999, '\P{^Variation_Selector=yes}', "");
Expect(0, 918000, '\p{Variation_Selector=yes}', "");
Expect(1, 918000, '\p{^Variation_Selector=yes}', "");
Expect(1, 918000, '\P{Variation_Selector=yes}', "");
Expect(0, 918000, '\P{^Variation_Selector=yes}', "");
Expect(1, 917999, '\p{Variation_Selector= _Yes}', "");
Expect(0, 917999, '\p{^Variation_Selector= _Yes}', "");
Expect(0, 917999, '\P{Variation_Selector= _Yes}', "");
Expect(1, 917999, '\P{^Variation_Selector= _Yes}', "");
Expect(0, 918000, '\p{Variation_Selector= _Yes}', "");
Expect(1, 918000, '\p{^Variation_Selector= _Yes}', "");
Expect(1, 918000, '\P{Variation_Selector= _Yes}', "");
Expect(0, 918000, '\P{^Variation_Selector= _Yes}', "");
Error('\p{VS=:=	_Y}');
Error('\P{VS=:=	_Y}');
Expect(1, 917999, '\p{VS=y}', "");
Expect(0, 917999, '\p{^VS=y}', "");
Expect(0, 917999, '\P{VS=y}', "");
Expect(1, 917999, '\P{^VS=y}', "");
Expect(0, 918000, '\p{VS=y}', "");
Expect(1, 918000, '\p{^VS=y}', "");
Expect(1, 918000, '\P{VS=y}', "");
Expect(0, 918000, '\P{^VS=y}', "");
Expect(1, 917999, '\p{VS=_-y}', "");
Expect(0, 917999, '\p{^VS=_-y}', "");
Expect(0, 917999, '\P{VS=_-y}', "");
Expect(1, 917999, '\P{^VS=_-y}', "");
Expect(0, 918000, '\p{VS=_-y}', "");
Expect(1, 918000, '\p{^VS=_-y}', "");
Expect(1, 918000, '\P{VS=_-y}', "");
Expect(0, 918000, '\P{^VS=_-y}', "");
Error('\p{Is_Variation_Selector=_/a/T}');
Error('\P{Is_Variation_Selector=_/a/T}');
Expect(1, 917999, '\p{Is_Variation_Selector=t}', "");
Expect(0, 917999, '\p{^Is_Variation_Selector=t}', "");
Expect(0, 917999, '\P{Is_Variation_Selector=t}', "");
Expect(1, 917999, '\P{^Is_Variation_Selector=t}', "");
Expect(0, 918000, '\p{Is_Variation_Selector=t}', "");
Expect(1, 918000, '\p{^Is_Variation_Selector=t}', "");
Expect(1, 918000, '\P{Is_Variation_Selector=t}', "");
Expect(0, 918000, '\P{^Is_Variation_Selector=t}', "");
Expect(1, 917999, '\p{Is_Variation_Selector= 	T}', "");
Expect(0, 917999, '\p{^Is_Variation_Selector= 	T}', "");
Expect(0, 917999, '\P{Is_Variation_Selector= 	T}', "");
Expect(1, 917999, '\P{^Is_Variation_Selector= 	T}', "");
Expect(0, 918000, '\p{Is_Variation_Selector= 	T}', "");
Expect(1, 918000, '\p{^Is_Variation_Selector= 	T}', "");
Expect(1, 918000, '\P{Is_Variation_Selector= 	T}', "");
Expect(0, 918000, '\P{^Is_Variation_Selector= 	T}', "");
Error('\p{Is_VS=/a/True}');
Error('\P{Is_VS=/a/True}');
Expect(1, 917999, '\p{Is_VS=true}', "");
Expect(0, 917999, '\p{^Is_VS=true}', "");
Expect(0, 917999, '\P{Is_VS=true}', "");
Expect(1, 917999, '\P{^Is_VS=true}', "");
Expect(0, 918000, '\p{Is_VS=true}', "");
Expect(1, 918000, '\p{^Is_VS=true}', "");
Expect(1, 918000, '\P{Is_VS=true}', "");
Expect(0, 918000, '\P{^Is_VS=true}', "");
Expect(1, 917999, '\p{Is_VS= TRUE}', "");
Expect(0, 917999, '\p{^Is_VS= TRUE}', "");
Expect(0, 917999, '\P{Is_VS= TRUE}', "");
Expect(1, 917999, '\P{^Is_VS= TRUE}', "");
Expect(0, 918000, '\p{Is_VS= TRUE}', "");
Expect(1, 918000, '\p{^Is_VS= TRUE}', "");
Expect(1, 918000, '\P{Is_VS= TRUE}', "");
Expect(0, 918000, '\P{^Is_VS= TRUE}', "");
Error('\p{Word_Break=/a/	CR}');
Error('\P{Word_Break=/a/	CR}');
Expect(1, 13, '\p{Word_Break=cr}', "");
Expect(0, 13, '\p{^Word_Break=cr}', "");
Expect(0, 13, '\P{Word_Break=cr}', "");
Expect(1, 13, '\P{^Word_Break=cr}', "");
Expect(0, 14, '\p{Word_Break=cr}', "");
Expect(1, 14, '\p{^Word_Break=cr}', "");
Expect(1, 14, '\P{Word_Break=cr}', "");
Expect(0, 14, '\P{^Word_Break=cr}', "");
Expect(1, 13, '\p{Word_Break=--cr}', "");
Expect(0, 13, '\p{^Word_Break=--cr}', "");
Expect(0, 13, '\P{Word_Break=--cr}', "");
Expect(1, 13, '\P{^Word_Break=--cr}', "");
Expect(0, 14, '\p{Word_Break=--cr}', "");
Expect(1, 14, '\p{^Word_Break=--cr}', "");
Expect(1, 14, '\P{Word_Break=--cr}', "");
Expect(0, 14, '\P{^Word_Break=--cr}', "");
Error('\p{WB=/a/_-cr}');
Error('\P{WB=/a/_-cr}');
Expect(1, 13, '\p{WB=cr}', "");
Expect(0, 13, '\p{^WB=cr}', "");
Expect(0, 13, '\P{WB=cr}', "");
Expect(1, 13, '\P{^WB=cr}', "");
Expect(0, 14, '\p{WB=cr}', "");
Expect(1, 14, '\p{^WB=cr}', "");
Expect(1, 14, '\P{WB=cr}', "");
Expect(0, 14, '\P{^WB=cr}', "");
Expect(1, 13, '\p{WB=_ CR}', "");
Expect(0, 13, '\p{^WB=_ CR}', "");
Expect(0, 13, '\P{WB=_ CR}', "");
Expect(1, 13, '\P{^WB=_ CR}', "");
Expect(0, 14, '\p{WB=_ CR}', "");
Expect(1, 14, '\p{^WB=_ CR}', "");
Expect(1, 14, '\P{WB=_ CR}', "");
Expect(0, 14, '\P{^WB=_ CR}', "");
Error('\p{Is_Word_Break=-cr:=}');
Error('\P{Is_Word_Break=-cr:=}');
Expect(1, 13, '\p{Is_Word_Break=cr}', "");
Expect(0, 13, '\p{^Is_Word_Break=cr}', "");
Expect(0, 13, '\P{Is_Word_Break=cr}', "");
Expect(1, 13, '\P{^Is_Word_Break=cr}', "");
Expect(0, 14, '\p{Is_Word_Break=cr}', "");
Expect(1, 14, '\p{^Is_Word_Break=cr}', "");
Expect(1, 14, '\P{Is_Word_Break=cr}', "");
Expect(0, 14, '\P{^Is_Word_Break=cr}', "");
Expect(1, 13, '\p{Is_Word_Break: CR}', "");
Expect(0, 13, '\p{^Is_Word_Break: CR}', "");
Expect(0, 13, '\P{Is_Word_Break: CR}', "");
Expect(1, 13, '\P{^Is_Word_Break: CR}', "");
Expect(0, 14, '\p{Is_Word_Break: CR}', "");
Expect(1, 14, '\p{^Is_Word_Break: CR}', "");
Expect(1, 14, '\P{Is_Word_Break: CR}', "");
Expect(0, 14, '\P{^Is_Word_Break: CR}', "");
Error('\p{Is_WB=	 CR:=}');
Error('\P{Is_WB=	 CR:=}');
Expect(1, 13, '\p{Is_WB=cr}', "");
Expect(0, 13, '\p{^Is_WB=cr}', "");
Expect(0, 13, '\P{Is_WB=cr}', "");
Expect(1, 13, '\P{^Is_WB=cr}', "");
Expect(0, 14, '\p{Is_WB=cr}', "");
Expect(1, 14, '\p{^Is_WB=cr}', "");
Expect(1, 14, '\P{Is_WB=cr}', "");
Expect(0, 14, '\P{^Is_WB=cr}', "");
Expect(1, 13, '\p{Is_WB=CR}', "");
Expect(0, 13, '\p{^Is_WB=CR}', "");
Expect(0, 13, '\P{Is_WB=CR}', "");
Expect(1, 13, '\P{^Is_WB=CR}', "");
Expect(0, 14, '\p{Is_WB=CR}', "");
Expect(1, 14, '\p{^Is_WB=CR}', "");
Expect(1, 14, '\P{Is_WB=CR}', "");
Expect(0, 14, '\P{^Is_WB=CR}', "");
Error('\p{Word_Break=-Double_Quote:=}');
Error('\P{Word_Break=-Double_Quote:=}');
Expect(1, 34, '\p{Word_Break=doublequote}', "");
Expect(0, 34, '\p{^Word_Break=doublequote}', "");
Expect(0, 34, '\P{Word_Break=doublequote}', "");
Expect(1, 34, '\P{^Word_Break=doublequote}', "");
Expect(0, 35, '\p{Word_Break=doublequote}', "");
Expect(1, 35, '\p{^Word_Break=doublequote}', "");
Expect(1, 35, '\P{Word_Break=doublequote}', "");
Expect(0, 35, '\P{^Word_Break=doublequote}', "");
Expect(1, 34, '\p{Word_Break=__double_QUOTE}', "");
Expect(0, 34, '\p{^Word_Break=__double_QUOTE}', "");
Expect(0, 34, '\P{Word_Break=__double_QUOTE}', "");
Expect(1, 34, '\P{^Word_Break=__double_QUOTE}', "");
Expect(0, 35, '\p{Word_Break=__double_QUOTE}', "");
Expect(1, 35, '\p{^Word_Break=__double_QUOTE}', "");
Expect(1, 35, '\P{Word_Break=__double_QUOTE}', "");
Expect(0, 35, '\P{^Word_Break=__double_QUOTE}', "");
Error('\p{WB=:=_ dq}');
Error('\P{WB=:=_ dq}');
Expect(1, 34, '\p{WB=dq}', "");
Expect(0, 34, '\p{^WB=dq}', "");
Expect(0, 34, '\P{WB=dq}', "");
Expect(1, 34, '\P{^WB=dq}', "");
Expect(0, 35, '\p{WB=dq}', "");
Expect(1, 35, '\p{^WB=dq}', "");
Expect(1, 35, '\P{WB=dq}', "");
Expect(0, 35, '\P{^WB=dq}', "");
Expect(1, 34, '\p{WB=_ DQ}', "");
Expect(0, 34, '\p{^WB=_ DQ}', "");
Expect(0, 34, '\P{WB=_ DQ}', "");
Expect(1, 34, '\P{^WB=_ DQ}', "");
Expect(0, 35, '\p{WB=_ DQ}', "");
Expect(1, 35, '\p{^WB=_ DQ}', "");
Expect(1, 35, '\P{WB=_ DQ}', "");
Expect(0, 35, '\P{^WB=_ DQ}', "");
Error('\p{Is_Word_Break=/a/Double_quote}');
Error('\P{Is_Word_Break=/a/Double_quote}');
Expect(1, 34, '\p{Is_Word_Break=doublequote}', "");
Expect(0, 34, '\p{^Is_Word_Break=doublequote}', "");
Expect(0, 34, '\P{Is_Word_Break=doublequote}', "");
Expect(1, 34, '\P{^Is_Word_Break=doublequote}', "");
Expect(0, 35, '\p{Is_Word_Break=doublequote}', "");
Expect(1, 35, '\p{^Is_Word_Break=doublequote}', "");
Expect(1, 35, '\P{Is_Word_Break=doublequote}', "");
Expect(0, 35, '\P{^Is_Word_Break=doublequote}', "");
Expect(1, 34, '\p{Is_Word_Break=	double_quote}', "");
Expect(0, 34, '\p{^Is_Word_Break=	double_quote}', "");
Expect(0, 34, '\P{Is_Word_Break=	double_quote}', "");
Expect(1, 34, '\P{^Is_Word_Break=	double_quote}', "");
Expect(0, 35, '\p{Is_Word_Break=	double_quote}', "");
Expect(1, 35, '\p{^Is_Word_Break=	double_quote}', "");
Expect(1, 35, '\P{Is_Word_Break=	double_quote}', "");
Expect(0, 35, '\P{^Is_Word_Break=	double_quote}', "");
Error('\p{Is_WB=:=-	dq}');
Error('\P{Is_WB=:=-	dq}');
Expect(1, 34, '\p{Is_WB=dq}', "");
Expect(0, 34, '\p{^Is_WB=dq}', "");
Expect(0, 34, '\P{Is_WB=dq}', "");
Expect(1, 34, '\P{^Is_WB=dq}', "");
Expect(0, 35, '\p{Is_WB=dq}', "");
Expect(1, 35, '\p{^Is_WB=dq}', "");
Expect(1, 35, '\P{Is_WB=dq}', "");
Expect(0, 35, '\P{^Is_WB=dq}', "");
Expect(1, 34, '\p{Is_WB=_	DQ}', "");
Expect(0, 34, '\p{^Is_WB=_	DQ}', "");
Expect(0, 34, '\P{Is_WB=_	DQ}', "");
Expect(1, 34, '\P{^Is_WB=_	DQ}', "");
Expect(0, 35, '\p{Is_WB=_	DQ}', "");
Expect(1, 35, '\p{^Is_WB=_	DQ}', "");
Expect(1, 35, '\P{Is_WB=_	DQ}', "");
Expect(0, 35, '\P{^Is_WB=_	DQ}', "");
Error('\p{Word_Break=/a/-_EXTENDNUMLET}');
Error('\P{Word_Break=/a/-_EXTENDNUMLET}');
Expect(1, 65343, '\p{Word_Break=extendnumlet}', "");
Expect(0, 65343, '\p{^Word_Break=extendnumlet}', "");
Expect(0, 65343, '\P{Word_Break=extendnumlet}', "");
Expect(1, 65343, '\P{^Word_Break=extendnumlet}', "");
Expect(0, 65344, '\p{Word_Break=extendnumlet}', "");
Expect(1, 65344, '\p{^Word_Break=extendnumlet}', "");
Expect(1, 65344, '\P{Word_Break=extendnumlet}', "");
Expect(0, 65344, '\P{^Word_Break=extendnumlet}', "");
Expect(1, 65343, '\p{Word_Break= extendnumlet}', "");
Expect(0, 65343, '\p{^Word_Break= extendnumlet}', "");
Expect(0, 65343, '\P{Word_Break= extendnumlet}', "");
Expect(1, 65343, '\P{^Word_Break= extendnumlet}', "");
Expect(0, 65344, '\p{Word_Break= extendnumlet}', "");
Expect(1, 65344, '\p{^Word_Break= extendnumlet}', "");
Expect(1, 65344, '\P{Word_Break= extendnumlet}', "");
Expect(0, 65344, '\P{^Word_Break= extendnumlet}', "");
Error('\p{WB=_/a/EX}');
Error('\P{WB=_/a/EX}');
Expect(1, 65343, '\p{WB=ex}', "");
Expect(0, 65343, '\p{^WB=ex}', "");
Expect(0, 65343, '\P{WB=ex}', "");
Expect(1, 65343, '\P{^WB=ex}', "");
Expect(0, 65344, '\p{WB=ex}', "");
Expect(1, 65344, '\p{^WB=ex}', "");
Expect(1, 65344, '\P{WB=ex}', "");
Expect(0, 65344, '\P{^WB=ex}', "");
Expect(1, 65343, '\p{WB=- ex}', "");
Expect(0, 65343, '\p{^WB=- ex}', "");
Expect(0, 65343, '\P{WB=- ex}', "");
Expect(1, 65343, '\P{^WB=- ex}', "");
Expect(0, 65344, '\p{WB=- ex}', "");
Expect(1, 65344, '\p{^WB=- ex}', "");
Expect(1, 65344, '\P{WB=- ex}', "");
Expect(0, 65344, '\P{^WB=- ex}', "");
Error('\p{Is_Word_Break=_/a/ExtendNumLet}');
Error('\P{Is_Word_Break=_/a/ExtendNumLet}');
Expect(1, 65343, '\p{Is_Word_Break=extendnumlet}', "");
Expect(0, 65343, '\p{^Is_Word_Break=extendnumlet}', "");
Expect(0, 65343, '\P{Is_Word_Break=extendnumlet}', "");
Expect(1, 65343, '\P{^Is_Word_Break=extendnumlet}', "");
Expect(0, 65344, '\p{Is_Word_Break=extendnumlet}', "");
Expect(1, 65344, '\p{^Is_Word_Break=extendnumlet}', "");
Expect(1, 65344, '\P{Is_Word_Break=extendnumlet}', "");
Expect(0, 65344, '\P{^Is_Word_Break=extendnumlet}', "");
Expect(1, 65343, '\p{Is_Word_Break=_ extendnumlet}', "");
Expect(0, 65343, '\p{^Is_Word_Break=_ extendnumlet}', "");
Expect(0, 65343, '\P{Is_Word_Break=_ extendnumlet}', "");
Expect(1, 65343, '\P{^Is_Word_Break=_ extendnumlet}', "");
Expect(0, 65344, '\p{Is_Word_Break=_ extendnumlet}', "");
Expect(1, 65344, '\p{^Is_Word_Break=_ extendnumlet}', "");
Expect(1, 65344, '\P{Is_Word_Break=_ extendnumlet}', "");
Expect(0, 65344, '\P{^Is_Word_Break=_ extendnumlet}', "");
Error('\p{Is_WB=-/a/EX}');
Error('\P{Is_WB=-/a/EX}');
Expect(1, 65343, '\p{Is_WB=ex}', "");
Expect(0, 65343, '\p{^Is_WB=ex}', "");
Expect(0, 65343, '\P{Is_WB=ex}', "");
Expect(1, 65343, '\P{^Is_WB=ex}', "");
Expect(0, 65344, '\p{Is_WB=ex}', "");
Expect(1, 65344, '\p{^Is_WB=ex}', "");
Expect(1, 65344, '\P{Is_WB=ex}', "");
Expect(0, 65344, '\P{^Is_WB=ex}', "");
Expect(1, 65343, '\p{Is_WB= ex}', "");
Expect(0, 65343, '\p{^Is_WB= ex}', "");
Expect(0, 65343, '\P{Is_WB= ex}', "");
Expect(1, 65343, '\P{^Is_WB= ex}', "");
Expect(0, 65344, '\p{Is_WB= ex}', "");
Expect(1, 65344, '\p{^Is_WB= ex}', "");
Expect(1, 65344, '\P{Is_WB= ex}', "");
Expect(0, 65344, '\P{^Is_WB= ex}', "");
Error('\p{Word_Break= 	extend:=}');
Error('\P{Word_Break= 	extend:=}');
Expect(1, 917999, '\p{Word_Break=extend}', "");
Expect(0, 917999, '\p{^Word_Break=extend}', "");
Expect(0, 917999, '\P{Word_Break=extend}', "");
Expect(1, 917999, '\P{^Word_Break=extend}', "");
Expect(0, 918000, '\p{Word_Break=extend}', "");
Expect(1, 918000, '\p{^Word_Break=extend}', "");
Expect(1, 918000, '\P{Word_Break=extend}', "");
Expect(0, 918000, '\P{^Word_Break=extend}', "");
Expect(1, 917999, '\p{Word_Break:	 Extend}', "");
Expect(0, 917999, '\p{^Word_Break:	 Extend}', "");
Expect(0, 917999, '\P{Word_Break:	 Extend}', "");
Expect(1, 917999, '\P{^Word_Break:	 Extend}', "");
Expect(0, 918000, '\p{Word_Break:	 Extend}', "");
Expect(1, 918000, '\p{^Word_Break:	 Extend}', "");
Expect(1, 918000, '\P{Word_Break:	 Extend}', "");
Expect(0, 918000, '\P{^Word_Break:	 Extend}', "");
Error('\p{WB= Extend/a/}');
Error('\P{WB= Extend/a/}');
Expect(1, 917999, '\p{WB=extend}', "");
Expect(0, 917999, '\p{^WB=extend}', "");
Expect(0, 917999, '\P{WB=extend}', "");
Expect(1, 917999, '\P{^WB=extend}', "");
Expect(0, 918000, '\p{WB=extend}', "");
Expect(1, 918000, '\p{^WB=extend}', "");
Expect(1, 918000, '\P{WB=extend}', "");
Expect(0, 918000, '\P{^WB=extend}', "");
Expect(1, 917999, '\p{WB=_Extend}', "");
Expect(0, 917999, '\p{^WB=_Extend}', "");
Expect(0, 917999, '\P{WB=_Extend}', "");
Expect(1, 917999, '\P{^WB=_Extend}', "");
Expect(0, 918000, '\p{WB=_Extend}', "");
Expect(1, 918000, '\p{^WB=_Extend}', "");
Expect(1, 918000, '\P{WB=_Extend}', "");
Expect(0, 918000, '\P{^WB=_Extend}', "");
Error('\p{Is_Word_Break=/a/_	extend}');
Error('\P{Is_Word_Break=/a/_	extend}');
Expect(1, 917999, '\p{Is_Word_Break=extend}', "");
Expect(0, 917999, '\p{^Is_Word_Break=extend}', "");
Expect(0, 917999, '\P{Is_Word_Break=extend}', "");
Expect(1, 917999, '\P{^Is_Word_Break=extend}', "");
Expect(0, 918000, '\p{Is_Word_Break=extend}', "");
Expect(1, 918000, '\p{^Is_Word_Break=extend}', "");
Expect(1, 918000, '\P{Is_Word_Break=extend}', "");
Expect(0, 918000, '\P{^Is_Word_Break=extend}', "");
Expect(1, 917999, '\p{Is_Word_Break=_extend}', "");
Expect(0, 917999, '\p{^Is_Word_Break=_extend}', "");
Expect(0, 917999, '\P{Is_Word_Break=_extend}', "");
Expect(1, 917999, '\P{^Is_Word_Break=_extend}', "");
Expect(0, 918000, '\p{Is_Word_Break=_extend}', "");
Expect(1, 918000, '\p{^Is_Word_Break=_extend}', "");
Expect(1, 918000, '\P{Is_Word_Break=_extend}', "");
Expect(0, 918000, '\P{^Is_Word_Break=_extend}', "");
Error('\p{Is_WB=-/a/Extend}');
Error('\P{Is_WB=-/a/Extend}');
Expect(1, 917999, '\p{Is_WB=extend}', "");
Expect(0, 917999, '\p{^Is_WB=extend}', "");
Expect(0, 917999, '\P{Is_WB=extend}', "");
Expect(1, 917999, '\P{^Is_WB=extend}', "");
Expect(0, 918000, '\p{Is_WB=extend}', "");
Expect(1, 918000, '\p{^Is_WB=extend}', "");
Expect(1, 918000, '\P{Is_WB=extend}', "");
Expect(0, 918000, '\P{^Is_WB=extend}', "");
Expect(1, 917999, '\p{Is_WB:    	Extend}', "");
Expect(0, 917999, '\p{^Is_WB:    	Extend}', "");
Expect(0, 917999, '\P{Is_WB:    	Extend}', "");
Expect(1, 917999, '\P{^Is_WB:    	Extend}', "");
Expect(0, 918000, '\p{Is_WB:    	Extend}', "");
Expect(1, 918000, '\p{^Is_WB:    	Extend}', "");
Expect(1, 918000, '\P{Is_WB:    	Extend}', "");
Expect(0, 918000, '\P{^Is_WB:    	Extend}', "");
Error('\p{Word_Break=		Format/a/}');
Error('\P{Word_Break=		Format/a/}');
Expect(1, 917631, '\p{Word_Break=format}', "");
Expect(0, 917631, '\p{^Word_Break=format}', "");
Expect(0, 917631, '\P{Word_Break=format}', "");
Expect(1, 917631, '\P{^Word_Break=format}', "");
Expect(0, 917632, '\p{Word_Break=format}', "");
Expect(1, 917632, '\p{^Word_Break=format}', "");
Expect(1, 917632, '\P{Word_Break=format}', "");
Expect(0, 917632, '\P{^Word_Break=format}', "");
Expect(1, 917631, '\p{Word_Break=	Format}', "");
Expect(0, 917631, '\p{^Word_Break=	Format}', "");
Expect(0, 917631, '\P{Word_Break=	Format}', "");
Expect(1, 917631, '\P{^Word_Break=	Format}', "");
Expect(0, 917632, '\p{Word_Break=	Format}', "");
Expect(1, 917632, '\p{^Word_Break=	Format}', "");
Expect(1, 917632, '\P{Word_Break=	Format}', "");
Expect(0, 917632, '\P{^Word_Break=	Format}', "");
Error('\p{WB= /a/fo}');
Error('\P{WB= /a/fo}');
Expect(1, 917631, '\p{WB=fo}', "");
Expect(0, 917631, '\p{^WB=fo}', "");
Expect(0, 917631, '\P{WB=fo}', "");
Expect(1, 917631, '\P{^WB=fo}', "");
Expect(0, 917632, '\p{WB=fo}', "");
Expect(1, 917632, '\p{^WB=fo}', "");
Expect(1, 917632, '\P{WB=fo}', "");
Expect(0, 917632, '\P{^WB=fo}', "");
Expect(1, 917631, '\p{WB=		FO}', "");
Expect(0, 917631, '\p{^WB=		FO}', "");
Expect(0, 917631, '\P{WB=		FO}', "");
Expect(1, 917631, '\P{^WB=		FO}', "");
Expect(0, 917632, '\p{WB=		FO}', "");
Expect(1, 917632, '\p{^WB=		FO}', "");
Expect(1, 917632, '\P{WB=		FO}', "");
Expect(0, 917632, '\P{^WB=		FO}', "");
Error('\p{Is_Word_Break=-_FORMAT/a/}');
Error('\P{Is_Word_Break=-_FORMAT/a/}');
Expect(1, 917631, '\p{Is_Word_Break=format}', "");
Expect(0, 917631, '\p{^Is_Word_Break=format}', "");
Expect(0, 917631, '\P{Is_Word_Break=format}', "");
Expect(1, 917631, '\P{^Is_Word_Break=format}', "");
Expect(0, 917632, '\p{Is_Word_Break=format}', "");
Expect(1, 917632, '\p{^Is_Word_Break=format}', "");
Expect(1, 917632, '\P{Is_Word_Break=format}', "");
Expect(0, 917632, '\P{^Is_Word_Break=format}', "");
Expect(1, 917631, '\p{Is_Word_Break:   _ FORMAT}', "");
Expect(0, 917631, '\p{^Is_Word_Break:   _ FORMAT}', "");
Expect(0, 917631, '\P{Is_Word_Break:   _ FORMAT}', "");
Expect(1, 917631, '\P{^Is_Word_Break:   _ FORMAT}', "");
Expect(0, 917632, '\p{Is_Word_Break:   _ FORMAT}', "");
Expect(1, 917632, '\p{^Is_Word_Break:   _ FORMAT}', "");
Expect(1, 917632, '\P{Is_Word_Break:   _ FORMAT}', "");
Expect(0, 917632, '\P{^Is_Word_Break:   _ FORMAT}', "");
Error('\p{Is_WB=/a/_ fo}');
Error('\P{Is_WB=/a/_ fo}');
Expect(1, 917631, '\p{Is_WB=fo}', "");
Expect(0, 917631, '\p{^Is_WB=fo}', "");
Expect(0, 917631, '\P{Is_WB=fo}', "");
Expect(1, 917631, '\P{^Is_WB=fo}', "");
Expect(0, 917632, '\p{Is_WB=fo}', "");
Expect(1, 917632, '\p{^Is_WB=fo}', "");
Expect(1, 917632, '\P{Is_WB=fo}', "");
Expect(0, 917632, '\P{^Is_WB=fo}', "");
Expect(1, 917631, '\p{Is_WB=-	fo}', "");
Expect(0, 917631, '\p{^Is_WB=-	fo}', "");
Expect(0, 917631, '\P{Is_WB=-	fo}', "");
Expect(1, 917631, '\P{^Is_WB=-	fo}', "");
Expect(0, 917632, '\p{Is_WB=-	fo}', "");
Expect(1, 917632, '\p{^Is_WB=-	fo}', "");
Expect(1, 917632, '\P{Is_WB=-	fo}', "");
Expect(0, 917632, '\P{^Is_WB=-	fo}', "");
Error('\p{Word_Break=_:=Hebrew_letter}');
Error('\P{Word_Break=_:=Hebrew_letter}');
Expect(1, 64335, '\p{Word_Break=hebrewletter}', "");
Expect(0, 64335, '\p{^Word_Break=hebrewletter}', "");
Expect(0, 64335, '\P{Word_Break=hebrewletter}', "");
Expect(1, 64335, '\P{^Word_Break=hebrewletter}', "");
Expect(0, 64336, '\p{Word_Break=hebrewletter}', "");
Expect(1, 64336, '\p{^Word_Break=hebrewletter}', "");
Expect(1, 64336, '\P{Word_Break=hebrewletter}', "");
Expect(0, 64336, '\P{^Word_Break=hebrewletter}', "");
Expect(1, 64335, '\p{Word_Break=	_HEBREW_Letter}', "");
Expect(0, 64335, '\p{^Word_Break=	_HEBREW_Letter}', "");
Expect(0, 64335, '\P{Word_Break=	_HEBREW_Letter}', "");
Expect(1, 64335, '\P{^Word_Break=	_HEBREW_Letter}', "");
Expect(0, 64336, '\p{Word_Break=	_HEBREW_Letter}', "");
Expect(1, 64336, '\p{^Word_Break=	_HEBREW_Letter}', "");
Expect(1, 64336, '\P{Word_Break=	_HEBREW_Letter}', "");
Expect(0, 64336, '\P{^Word_Break=	_HEBREW_Letter}', "");
Error('\p{WB=:=_	hl}');
Error('\P{WB=:=_	hl}');
Expect(1, 64335, '\p{WB=hl}', "");
Expect(0, 64335, '\p{^WB=hl}', "");
Expect(0, 64335, '\P{WB=hl}', "");
Expect(1, 64335, '\P{^WB=hl}', "");
Expect(0, 64336, '\p{WB=hl}', "");
Expect(1, 64336, '\p{^WB=hl}', "");
Expect(1, 64336, '\P{WB=hl}', "");
Expect(0, 64336, '\P{^WB=hl}', "");
Expect(1, 64335, '\p{WB=-hl}', "");
Expect(0, 64335, '\p{^WB=-hl}', "");
Expect(0, 64335, '\P{WB=-hl}', "");
Expect(1, 64335, '\P{^WB=-hl}', "");
Expect(0, 64336, '\p{WB=-hl}', "");
Expect(1, 64336, '\p{^WB=-hl}', "");
Expect(1, 64336, '\P{WB=-hl}', "");
Expect(0, 64336, '\P{^WB=-hl}', "");
Error('\p{Is_Word_Break=-:=Hebrew_Letter}');
Error('\P{Is_Word_Break=-:=Hebrew_Letter}');
Expect(1, 64335, '\p{Is_Word_Break=hebrewletter}', "");
Expect(0, 64335, '\p{^Is_Word_Break=hebrewletter}', "");
Expect(0, 64335, '\P{Is_Word_Break=hebrewletter}', "");
Expect(1, 64335, '\P{^Is_Word_Break=hebrewletter}', "");
Expect(0, 64336, '\p{Is_Word_Break=hebrewletter}', "");
Expect(1, 64336, '\p{^Is_Word_Break=hebrewletter}', "");
Expect(1, 64336, '\P{Is_Word_Break=hebrewletter}', "");
Expect(0, 64336, '\P{^Is_Word_Break=hebrewletter}', "");
Expect(1, 64335, '\p{Is_Word_Break=__HEBREW_letter}', "");
Expect(0, 64335, '\p{^Is_Word_Break=__HEBREW_letter}', "");
Expect(0, 64335, '\P{Is_Word_Break=__HEBREW_letter}', "");
Expect(1, 64335, '\P{^Is_Word_Break=__HEBREW_letter}', "");
Expect(0, 64336, '\p{Is_Word_Break=__HEBREW_letter}', "");
Expect(1, 64336, '\p{^Is_Word_Break=__HEBREW_letter}', "");
Expect(1, 64336, '\P{Is_Word_Break=__HEBREW_letter}', "");
Expect(0, 64336, '\P{^Is_Word_Break=__HEBREW_letter}', "");
Error('\p{Is_WB=-/a/HL}');
Error('\P{Is_WB=-/a/HL}');
Expect(1, 64335, '\p{Is_WB:hl}', "");
Expect(0, 64335, '\p{^Is_WB:hl}', "");
Expect(0, 64335, '\P{Is_WB:hl}', "");
Expect(1, 64335, '\P{^Is_WB:hl}', "");
Expect(0, 64336, '\p{Is_WB:hl}', "");
Expect(1, 64336, '\p{^Is_WB:hl}', "");
Expect(1, 64336, '\P{Is_WB:hl}', "");
Expect(0, 64336, '\P{^Is_WB:hl}', "");
Expect(1, 64335, '\p{Is_WB= hl}', "");
Expect(0, 64335, '\p{^Is_WB= hl}', "");
Expect(0, 64335, '\P{Is_WB= hl}', "");
Expect(1, 64335, '\P{^Is_WB= hl}', "");
Expect(0, 64336, '\p{Is_WB= hl}', "");
Expect(1, 64336, '\p{^Is_WB= hl}', "");
Expect(1, 64336, '\P{Is_WB= hl}', "");
Expect(0, 64336, '\P{^Is_WB= hl}', "");
Error('\p{Word_Break=/a/ KATAKANA}');
Error('\P{Word_Break=/a/ KATAKANA}');
Expect(1, 110592, '\p{Word_Break=katakana}', "");
Expect(0, 110592, '\p{^Word_Break=katakana}', "");
Expect(0, 110592, '\P{Word_Break=katakana}', "");
Expect(1, 110592, '\P{^Word_Break=katakana}', "");
Expect(0, 110593, '\p{Word_Break=katakana}', "");
Expect(1, 110593, '\p{^Word_Break=katakana}', "");
Expect(1, 110593, '\P{Word_Break=katakana}', "");
Expect(0, 110593, '\P{^Word_Break=katakana}', "");
Expect(1, 110592, '\p{Word_Break=_-Katakana}', "");
Expect(0, 110592, '\p{^Word_Break=_-Katakana}', "");
Expect(0, 110592, '\P{Word_Break=_-Katakana}', "");
Expect(1, 110592, '\P{^Word_Break=_-Katakana}', "");
Expect(0, 110593, '\p{Word_Break=_-Katakana}', "");
Expect(1, 110593, '\p{^Word_Break=_-Katakana}', "");
Expect(1, 110593, '\P{Word_Break=_-Katakana}', "");
Expect(0, 110593, '\P{^Word_Break=_-Katakana}', "");
Error('\p{WB=_-ka/a/}');
Error('\P{WB=_-ka/a/}');
Expect(1, 110592, '\p{WB=ka}', "");
Expect(0, 110592, '\p{^WB=ka}', "");
Expect(0, 110592, '\P{WB=ka}', "");
Expect(1, 110592, '\P{^WB=ka}', "");
Expect(0, 110593, '\p{WB=ka}', "");
Expect(1, 110593, '\p{^WB=ka}', "");
Expect(1, 110593, '\P{WB=ka}', "");
Expect(0, 110593, '\P{^WB=ka}', "");
Expect(1, 110592, '\p{WB= -KA}', "");
Expect(0, 110592, '\p{^WB= -KA}', "");
Expect(0, 110592, '\P{WB= -KA}', "");
Expect(1, 110592, '\P{^WB= -KA}', "");
Expect(0, 110593, '\p{WB= -KA}', "");
Expect(1, 110593, '\p{^WB= -KA}', "");
Expect(1, 110593, '\P{WB= -KA}', "");
Expect(0, 110593, '\P{^WB= -KA}', "");
Error('\p{Is_Word_Break:   /a/KATAKANA}');
Error('\P{Is_Word_Break:   /a/KATAKANA}');
Expect(1, 110592, '\p{Is_Word_Break=katakana}', "");
Expect(0, 110592, '\p{^Is_Word_Break=katakana}', "");
Expect(0, 110592, '\P{Is_Word_Break=katakana}', "");
Expect(1, 110592, '\P{^Is_Word_Break=katakana}', "");
Expect(0, 110593, '\p{Is_Word_Break=katakana}', "");
Expect(1, 110593, '\p{^Is_Word_Break=katakana}', "");
Expect(1, 110593, '\P{Is_Word_Break=katakana}', "");
Expect(0, 110593, '\P{^Is_Word_Break=katakana}', "");
Expect(1, 110592, '\p{Is_Word_Break:    Katakana}', "");
Expect(0, 110592, '\p{^Is_Word_Break:    Katakana}', "");
Expect(0, 110592, '\P{Is_Word_Break:    Katakana}', "");
Expect(1, 110592, '\P{^Is_Word_Break:    Katakana}', "");
Expect(0, 110593, '\p{Is_Word_Break:    Katakana}', "");
Expect(1, 110593, '\p{^Is_Word_Break:    Katakana}', "");
Expect(1, 110593, '\P{Is_Word_Break:    Katakana}', "");
Expect(0, 110593, '\P{^Is_Word_Break:    Katakana}', "");
Error('\p{Is_WB=--KA/a/}');
Error('\P{Is_WB=--KA/a/}');
Expect(1, 110592, '\p{Is_WB=ka}', "");
Expect(0, 110592, '\p{^Is_WB=ka}', "");
Expect(0, 110592, '\P{Is_WB=ka}', "");
Expect(1, 110592, '\P{^Is_WB=ka}', "");
Expect(0, 110593, '\p{Is_WB=ka}', "");
Expect(1, 110593, '\p{^Is_WB=ka}', "");
Expect(1, 110593, '\P{Is_WB=ka}', "");
Expect(0, 110593, '\P{^Is_WB=ka}', "");
Expect(1, 110592, '\p{Is_WB:	KA}', "");
Expect(0, 110592, '\p{^Is_WB:	KA}', "");
Expect(0, 110592, '\P{Is_WB:	KA}', "");
Expect(1, 110592, '\P{^Is_WB:	KA}', "");
Expect(0, 110593, '\p{Is_WB:	KA}', "");
Expect(1, 110593, '\p{^Is_WB:	KA}', "");
Expect(1, 110593, '\P{Is_WB:	KA}', "");
Expect(0, 110593, '\P{^Is_WB:	KA}', "");
Error('\p{Word_Break=/a/	_ALetter}');
Error('\P{Word_Break=/a/	_ALetter}');
Expect(1, 126651, '\p{Word_Break=aletter}', "");
Expect(0, 126651, '\p{^Word_Break=aletter}', "");
Expect(0, 126651, '\P{Word_Break=aletter}', "");
Expect(1, 126651, '\P{^Word_Break=aletter}', "");
Expect(0, 126652, '\p{Word_Break=aletter}', "");
Expect(1, 126652, '\p{^Word_Break=aletter}', "");
Expect(1, 126652, '\P{Word_Break=aletter}', "");
Expect(0, 126652, '\P{^Word_Break=aletter}', "");
Expect(1, 126651, '\p{Word_Break:	_ALetter}', "");
Expect(0, 126651, '\p{^Word_Break:	_ALetter}', "");
Expect(0, 126651, '\P{Word_Break:	_ALetter}', "");
Expect(1, 126651, '\P{^Word_Break:	_ALetter}', "");
Expect(0, 126652, '\p{Word_Break:	_ALetter}', "");
Expect(1, 126652, '\p{^Word_Break:	_ALetter}', "");
Expect(1, 126652, '\P{Word_Break:	_ALetter}', "");
Expect(0, 126652, '\P{^Word_Break:	_ALetter}', "");
Error('\p{WB:/a/-LE}');
Error('\P{WB:/a/-LE}');
Expect(1, 126651, '\p{WB=le}', "");
Expect(0, 126651, '\p{^WB=le}', "");
Expect(0, 126651, '\P{WB=le}', "");
Expect(1, 126651, '\P{^WB=le}', "");
Expect(0, 126652, '\p{WB=le}', "");
Expect(1, 126652, '\p{^WB=le}', "");
Expect(1, 126652, '\P{WB=le}', "");
Expect(0, 126652, '\P{^WB=le}', "");
Expect(1, 126651, '\p{WB= LE}', "");
Expect(0, 126651, '\p{^WB= LE}', "");
Expect(0, 126651, '\P{WB= LE}', "");
Expect(1, 126651, '\P{^WB= LE}', "");
Expect(0, 126652, '\p{WB= LE}', "");
Expect(1, 126652, '\p{^WB= LE}', "");
Expect(1, 126652, '\P{WB= LE}', "");
Expect(0, 126652, '\P{^WB= LE}', "");
Error('\p{Is_Word_Break=	_aletter:=}');
Error('\P{Is_Word_Break=	_aletter:=}');
Expect(1, 126651, '\p{Is_Word_Break:aletter}', "");
Expect(0, 126651, '\p{^Is_Word_Break:aletter}', "");
Expect(0, 126651, '\P{Is_Word_Break:aletter}', "");
Expect(1, 126651, '\P{^Is_Word_Break:aletter}', "");
Expect(0, 126652, '\p{Is_Word_Break:aletter}', "");
Expect(1, 126652, '\p{^Is_Word_Break:aletter}', "");
Expect(1, 126652, '\P{Is_Word_Break:aletter}', "");
Expect(0, 126652, '\P{^Is_Word_Break:aletter}', "");
Expect(1, 126651, '\p{Is_Word_Break=_ ALetter}', "");
Expect(0, 126651, '\p{^Is_Word_Break=_ ALetter}', "");
Expect(0, 126651, '\P{Is_Word_Break=_ ALetter}', "");
Expect(1, 126651, '\P{^Is_Word_Break=_ ALetter}', "");
Expect(0, 126652, '\p{Is_Word_Break=_ ALetter}', "");
Expect(1, 126652, '\p{^Is_Word_Break=_ ALetter}', "");
Expect(1, 126652, '\P{Is_Word_Break=_ ALetter}', "");
Expect(0, 126652, '\P{^Is_Word_Break=_ ALetter}', "");
Error('\p{Is_WB=_:=LE}');
Error('\P{Is_WB=_:=LE}');
Expect(1, 126651, '\p{Is_WB=le}', "");
Expect(0, 126651, '\p{^Is_WB=le}', "");
Expect(0, 126651, '\P{Is_WB=le}', "");
Expect(1, 126651, '\P{^Is_WB=le}', "");
Expect(0, 126652, '\p{Is_WB=le}', "");
Expect(1, 126652, '\p{^Is_WB=le}', "");
Expect(1, 126652, '\P{Is_WB=le}', "");
Expect(0, 126652, '\P{^Is_WB=le}', "");
Expect(1, 126651, '\p{Is_WB:_le}', "");
Expect(0, 126651, '\p{^Is_WB:_le}', "");
Expect(0, 126651, '\P{Is_WB:_le}', "");
Expect(1, 126651, '\P{^Is_WB:_le}', "");
Expect(0, 126652, '\p{Is_WB:_le}', "");
Expect(1, 126652, '\p{^Is_WB:_le}', "");
Expect(1, 126652, '\P{Is_WB:_le}', "");
Expect(0, 126652, '\P{^Is_WB:_le}', "");
Error('\p{Word_Break::=-lf}');
Error('\P{Word_Break::=-lf}');
Expect(1, 10, '\p{Word_Break=lf}', "");
Expect(0, 10, '\p{^Word_Break=lf}', "");
Expect(0, 10, '\P{Word_Break=lf}', "");
Expect(1, 10, '\P{^Word_Break=lf}', "");
Expect(0, 11, '\p{Word_Break=lf}', "");
Expect(1, 11, '\p{^Word_Break=lf}', "");
Expect(1, 11, '\P{Word_Break=lf}', "");
Expect(0, 11, '\P{^Word_Break=lf}', "");
Expect(1, 10, '\p{Word_Break=- LF}', "");
Expect(0, 10, '\p{^Word_Break=- LF}', "");
Expect(0, 10, '\P{Word_Break=- LF}', "");
Expect(1, 10, '\P{^Word_Break=- LF}', "");
Expect(0, 11, '\p{Word_Break=- LF}', "");
Expect(1, 11, '\p{^Word_Break=- LF}', "");
Expect(1, 11, '\P{Word_Break=- LF}', "");
Expect(0, 11, '\P{^Word_Break=- LF}', "");
Error('\p{WB=	LF:=}');
Error('\P{WB=	LF:=}');
Expect(1, 10, '\p{WB=lf}', "");
Expect(0, 10, '\p{^WB=lf}', "");
Expect(0, 10, '\P{WB=lf}', "");
Expect(1, 10, '\P{^WB=lf}', "");
Expect(0, 11, '\p{WB=lf}', "");
Expect(1, 11, '\p{^WB=lf}', "");
Expect(1, 11, '\P{WB=lf}', "");
Expect(0, 11, '\P{^WB=lf}', "");
Expect(1, 10, '\p{WB=_lf}', "");
Expect(0, 10, '\p{^WB=_lf}', "");
Expect(0, 10, '\P{WB=_lf}', "");
Expect(1, 10, '\P{^WB=_lf}', "");
Expect(0, 11, '\p{WB=_lf}', "");
Expect(1, 11, '\p{^WB=_lf}', "");
Expect(1, 11, '\P{WB=_lf}', "");
Expect(0, 11, '\P{^WB=_lf}', "");
Error('\p{Is_Word_Break=_/a/LF}');
Error('\P{Is_Word_Break=_/a/LF}');
Expect(1, 10, '\p{Is_Word_Break=lf}', "");
Expect(0, 10, '\p{^Is_Word_Break=lf}', "");
Expect(0, 10, '\P{Is_Word_Break=lf}', "");
Expect(1, 10, '\P{^Is_Word_Break=lf}', "");
Expect(0, 11, '\p{Is_Word_Break=lf}', "");
Expect(1, 11, '\p{^Is_Word_Break=lf}', "");
Expect(1, 11, '\P{Is_Word_Break=lf}', "");
Expect(0, 11, '\P{^Is_Word_Break=lf}', "");
Expect(1, 10, '\p{Is_Word_Break=_LF}', "");
Expect(0, 10, '\p{^Is_Word_Break=_LF}', "");
Expect(0, 10, '\P{Is_Word_Break=_LF}', "");
Expect(1, 10, '\P{^Is_Word_Break=_LF}', "");
Expect(0, 11, '\p{Is_Word_Break=_LF}', "");
Expect(1, 11, '\p{^Is_Word_Break=_LF}', "");
Expect(1, 11, '\P{Is_Word_Break=_LF}', "");
Expect(0, 11, '\P{^Is_Word_Break=_LF}', "");
Error('\p{Is_WB=/a/--LF}');
Error('\P{Is_WB=/a/--LF}');
Expect(1, 10, '\p{Is_WB=lf}', "");
Expect(0, 10, '\p{^Is_WB=lf}', "");
Expect(0, 10, '\P{Is_WB=lf}', "");
Expect(1, 10, '\P{^Is_WB=lf}', "");
Expect(0, 11, '\p{Is_WB=lf}', "");
Expect(1, 11, '\p{^Is_WB=lf}', "");
Expect(1, 11, '\P{Is_WB=lf}', "");
Expect(0, 11, '\P{^Is_WB=lf}', "");
Expect(1, 10, '\p{Is_WB: lf}', "");
Expect(0, 10, '\p{^Is_WB: lf}', "");
Expect(0, 10, '\P{Is_WB: lf}', "");
Expect(1, 10, '\P{^Is_WB: lf}', "");
Expect(0, 11, '\p{Is_WB: lf}', "");
Expect(1, 11, '\p{^Is_WB: lf}', "");
Expect(1, 11, '\P{Is_WB: lf}', "");
Expect(0, 11, '\P{^Is_WB: lf}', "");
Error('\p{Word_Break=/a/MidNumLet}');
Error('\P{Word_Break=/a/MidNumLet}');
Expect(1, 65294, '\p{Word_Break=midnumlet}', "");
Expect(0, 65294, '\p{^Word_Break=midnumlet}', "");
Expect(0, 65294, '\P{Word_Break=midnumlet}', "");
Expect(1, 65294, '\P{^Word_Break=midnumlet}', "");
Expect(0, 65295, '\p{Word_Break=midnumlet}', "");
Expect(1, 65295, '\p{^Word_Break=midnumlet}', "");
Expect(1, 65295, '\P{Word_Break=midnumlet}', "");
Expect(0, 65295, '\P{^Word_Break=midnumlet}', "");
Expect(1, 65294, '\p{Word_Break=_-MidNumLet}', "");
Expect(0, 65294, '\p{^Word_Break=_-MidNumLet}', "");
Expect(0, 65294, '\P{Word_Break=_-MidNumLet}', "");
Expect(1, 65294, '\P{^Word_Break=_-MidNumLet}', "");
Expect(0, 65295, '\p{Word_Break=_-MidNumLet}', "");
Expect(1, 65295, '\p{^Word_Break=_-MidNumLet}', "");
Expect(1, 65295, '\P{Word_Break=_-MidNumLet}', "");
Expect(0, 65295, '\P{^Word_Break=_-MidNumLet}', "");
Error('\p{WB=/a/MB}');
Error('\P{WB=/a/MB}');
Expect(1, 65294, '\p{WB=mb}', "");
Expect(0, 65294, '\p{^WB=mb}', "");
Expect(0, 65294, '\P{WB=mb}', "");
Expect(1, 65294, '\P{^WB=mb}', "");
Expect(0, 65295, '\p{WB=mb}', "");
Expect(1, 65295, '\p{^WB=mb}', "");
Expect(1, 65295, '\P{WB=mb}', "");
Expect(0, 65295, '\P{^WB=mb}', "");
Expect(1, 65294, '\p{WB= MB}', "");
Expect(0, 65294, '\p{^WB= MB}', "");
Expect(0, 65294, '\P{WB= MB}', "");
Expect(1, 65294, '\P{^WB= MB}', "");
Expect(0, 65295, '\p{WB= MB}', "");
Expect(1, 65295, '\p{^WB= MB}', "");
Expect(1, 65295, '\P{WB= MB}', "");
Expect(0, 65295, '\P{^WB= MB}', "");
Error('\p{Is_Word_Break=:=--MIDNUMLET}');
Error('\P{Is_Word_Break=:=--MIDNUMLET}');
Expect(1, 65294, '\p{Is_Word_Break=midnumlet}', "");
Expect(0, 65294, '\p{^Is_Word_Break=midnumlet}', "");
Expect(0, 65294, '\P{Is_Word_Break=midnumlet}', "");
Expect(1, 65294, '\P{^Is_Word_Break=midnumlet}', "");
Expect(0, 65295, '\p{Is_Word_Break=midnumlet}', "");
Expect(1, 65295, '\p{^Is_Word_Break=midnumlet}', "");
Expect(1, 65295, '\P{Is_Word_Break=midnumlet}', "");
Expect(0, 65295, '\P{^Is_Word_Break=midnumlet}', "");
Expect(1, 65294, '\p{Is_Word_Break=		MidNumLet}', "");
Expect(0, 65294, '\p{^Is_Word_Break=		MidNumLet}', "");
Expect(0, 65294, '\P{Is_Word_Break=		MidNumLet}', "");
Expect(1, 65294, '\P{^Is_Word_Break=		MidNumLet}', "");
Expect(0, 65295, '\p{Is_Word_Break=		MidNumLet}', "");
Expect(1, 65295, '\p{^Is_Word_Break=		MidNumLet}', "");
Expect(1, 65295, '\P{Is_Word_Break=		MidNumLet}', "");
Expect(0, 65295, '\P{^Is_Word_Break=		MidNumLet}', "");
Error('\p{Is_WB=-_MB:=}');
Error('\P{Is_WB=-_MB:=}');
Expect(1, 65294, '\p{Is_WB=mb}', "");
Expect(0, 65294, '\p{^Is_WB=mb}', "");
Expect(0, 65294, '\P{Is_WB=mb}', "");
Expect(1, 65294, '\P{^Is_WB=mb}', "");
Expect(0, 65295, '\p{Is_WB=mb}', "");
Expect(1, 65295, '\p{^Is_WB=mb}', "");
Expect(1, 65295, '\P{Is_WB=mb}', "");
Expect(0, 65295, '\P{^Is_WB=mb}', "");
Expect(1, 65294, '\p{Is_WB=	MB}', "");
Expect(0, 65294, '\p{^Is_WB=	MB}', "");
Expect(0, 65294, '\P{Is_WB=	MB}', "");
Expect(1, 65294, '\P{^Is_WB=	MB}', "");
Expect(0, 65295, '\p{Is_WB=	MB}', "");
Expect(1, 65295, '\p{^Is_WB=	MB}', "");
Expect(1, 65295, '\P{Is_WB=	MB}', "");
Expect(0, 65295, '\P{^Is_WB=	MB}', "");
Error('\p{Word_Break=  MidLetter/a/}');
Error('\P{Word_Break=  MidLetter/a/}');
Expect(1, 65306, '\p{Word_Break:midletter}', "");
Expect(0, 65306, '\p{^Word_Break:midletter}', "");
Expect(0, 65306, '\P{Word_Break:midletter}', "");
Expect(1, 65306, '\P{^Word_Break:midletter}', "");
Expect(0, 65307, '\p{Word_Break:midletter}', "");
Expect(1, 65307, '\p{^Word_Break:midletter}', "");
Expect(1, 65307, '\P{Word_Break:midletter}', "");
Expect(0, 65307, '\P{^Word_Break:midletter}', "");
Expect(1, 65306, '\p{Word_Break=_MidLetter}', "");
Expect(0, 65306, '\p{^Word_Break=_MidLetter}', "");
Expect(0, 65306, '\P{Word_Break=_MidLetter}', "");
Expect(1, 65306, '\P{^Word_Break=_MidLetter}', "");
Expect(0, 65307, '\p{Word_Break=_MidLetter}', "");
Expect(1, 65307, '\p{^Word_Break=_MidLetter}', "");
Expect(1, 65307, '\P{Word_Break=_MidLetter}', "");
Expect(0, 65307, '\P{^Word_Break=_MidLetter}', "");
Error('\p{WB: :=-ML}');
Error('\P{WB: :=-ML}');
Expect(1, 65306, '\p{WB=ml}', "");
Expect(0, 65306, '\p{^WB=ml}', "");
Expect(0, 65306, '\P{WB=ml}', "");
Expect(1, 65306, '\P{^WB=ml}', "");
Expect(0, 65307, '\p{WB=ml}', "");
Expect(1, 65307, '\p{^WB=ml}', "");
Expect(1, 65307, '\P{WB=ml}', "");
Expect(0, 65307, '\P{^WB=ml}', "");
Expect(1, 65306, '\p{WB=	-ML}', "");
Expect(0, 65306, '\p{^WB=	-ML}', "");
Expect(0, 65306, '\P{WB=	-ML}', "");
Expect(1, 65306, '\P{^WB=	-ML}', "");
Expect(0, 65307, '\p{WB=	-ML}', "");
Expect(1, 65307, '\p{^WB=	-ML}', "");
Expect(1, 65307, '\P{WB=	-ML}', "");
Expect(0, 65307, '\P{^WB=	-ML}', "");
Error('\p{Is_Word_Break= MIDLETTER/a/}');
Error('\P{Is_Word_Break= MIDLETTER/a/}');
Expect(1, 65306, '\p{Is_Word_Break=midletter}', "");
Expect(0, 65306, '\p{^Is_Word_Break=midletter}', "");
Expect(0, 65306, '\P{Is_Word_Break=midletter}', "");
Expect(1, 65306, '\P{^Is_Word_Break=midletter}', "");
Expect(0, 65307, '\p{Is_Word_Break=midletter}', "");
Expect(1, 65307, '\p{^Is_Word_Break=midletter}', "");
Expect(1, 65307, '\P{Is_Word_Break=midletter}', "");
Expect(0, 65307, '\P{^Is_Word_Break=midletter}', "");
Expect(1, 65306, '\p{Is_Word_Break=	-MidLetter}', "");
Expect(0, 65306, '\p{^Is_Word_Break=	-MidLetter}', "");
Expect(0, 65306, '\P{Is_Word_Break=	-MidLetter}', "");
Expect(1, 65306, '\P{^Is_Word_Break=	-MidLetter}', "");
Expect(0, 65307, '\p{Is_Word_Break=	-MidLetter}', "");
Expect(1, 65307, '\p{^Is_Word_Break=	-MidLetter}', "");
Expect(1, 65307, '\P{Is_Word_Break=	-MidLetter}', "");
Expect(0, 65307, '\P{^Is_Word_Break=	-MidLetter}', "");
Error('\p{Is_WB=:= ml}');
Error('\P{Is_WB=:= ml}');
Expect(1, 65306, '\p{Is_WB:ml}', "");
Expect(0, 65306, '\p{^Is_WB:ml}', "");
Expect(0, 65306, '\P{Is_WB:ml}', "");
Expect(1, 65306, '\P{^Is_WB:ml}', "");
Expect(0, 65307, '\p{Is_WB:ml}', "");
Expect(1, 65307, '\p{^Is_WB:ml}', "");
Expect(1, 65307, '\P{Is_WB:ml}', "");
Expect(0, 65307, '\P{^Is_WB:ml}', "");
Expect(1, 65306, '\p{Is_WB= ML}', "");
Expect(0, 65306, '\p{^Is_WB= ML}', "");
Expect(0, 65306, '\P{Is_WB= ML}', "");
Expect(1, 65306, '\P{^Is_WB= ML}', "");
Expect(0, 65307, '\p{Is_WB= ML}', "");
Expect(1, 65307, '\p{^Is_WB= ML}', "");
Expect(1, 65307, '\P{Is_WB= ML}', "");
Expect(0, 65307, '\P{^Is_WB= ML}', "");
Error('\p{Word_Break: 	MIDNUM:=}');
Error('\P{Word_Break: 	MIDNUM:=}');
Expect(1, 65307, '\p{Word_Break=midnum}', "");
Expect(0, 65307, '\p{^Word_Break=midnum}', "");
Expect(0, 65307, '\P{Word_Break=midnum}', "");
Expect(1, 65307, '\P{^Word_Break=midnum}', "");
Expect(0, 65308, '\p{Word_Break=midnum}', "");
Expect(1, 65308, '\p{^Word_Break=midnum}', "");
Expect(1, 65308, '\P{Word_Break=midnum}', "");
Expect(0, 65308, '\P{^Word_Break=midnum}', "");
Expect(1, 65307, '\p{Word_Break=__MidNum}', "");
Expect(0, 65307, '\p{^Word_Break=__MidNum}', "");
Expect(0, 65307, '\P{Word_Break=__MidNum}', "");
Expect(1, 65307, '\P{^Word_Break=__MidNum}', "");
Expect(0, 65308, '\p{Word_Break=__MidNum}', "");
Expect(1, 65308, '\p{^Word_Break=__MidNum}', "");
Expect(1, 65308, '\P{Word_Break=__MidNum}', "");
Expect(0, 65308, '\P{^Word_Break=__MidNum}', "");
Error('\p{WB=_:=MN}');
Error('\P{WB=_:=MN}');
Expect(1, 65307, '\p{WB=mn}', "");
Expect(0, 65307, '\p{^WB=mn}', "");
Expect(0, 65307, '\P{WB=mn}', "");
Expect(1, 65307, '\P{^WB=mn}', "");
Expect(0, 65308, '\p{WB=mn}', "");
Expect(1, 65308, '\p{^WB=mn}', "");
Expect(1, 65308, '\P{WB=mn}', "");
Expect(0, 65308, '\P{^WB=mn}', "");
Expect(1, 65307, '\p{WB=_MN}', "");
Expect(0, 65307, '\p{^WB=_MN}', "");
Expect(0, 65307, '\P{WB=_MN}', "");
Expect(1, 65307, '\P{^WB=_MN}', "");
Expect(0, 65308, '\p{WB=_MN}', "");
Expect(1, 65308, '\p{^WB=_MN}', "");
Expect(1, 65308, '\P{WB=_MN}', "");
Expect(0, 65308, '\P{^WB=_MN}', "");
Error('\p{Is_Word_Break=	MIDNUM:=}');
Error('\P{Is_Word_Break=	MIDNUM:=}');
Expect(1, 65307, '\p{Is_Word_Break:   midnum}', "");
Expect(0, 65307, '\p{^Is_Word_Break:   midnum}', "");
Expect(0, 65307, '\P{Is_Word_Break:   midnum}', "");
Expect(1, 65307, '\P{^Is_Word_Break:   midnum}', "");
Expect(0, 65308, '\p{Is_Word_Break:   midnum}', "");
Expect(1, 65308, '\p{^Is_Word_Break:   midnum}', "");
Expect(1, 65308, '\P{Is_Word_Break:   midnum}', "");
Expect(0, 65308, '\P{^Is_Word_Break:   midnum}', "");
Expect(1, 65307, '\p{Is_Word_Break=_ MidNum}', "");
Expect(0, 65307, '\p{^Is_Word_Break=_ MidNum}', "");
Expect(0, 65307, '\P{Is_Word_Break=_ MidNum}', "");
Expect(1, 65307, '\P{^Is_Word_Break=_ MidNum}', "");
Expect(0, 65308, '\p{Is_Word_Break=_ MidNum}', "");
Expect(1, 65308, '\p{^Is_Word_Break=_ MidNum}', "");
Expect(1, 65308, '\P{Is_Word_Break=_ MidNum}', "");
Expect(0, 65308, '\P{^Is_Word_Break=_ MidNum}', "");
Error('\p{Is_WB=:=	MN}');
Error('\P{Is_WB=:=	MN}');
Expect(1, 65307, '\p{Is_WB=mn}', "");
Expect(0, 65307, '\p{^Is_WB=mn}', "");
Expect(0, 65307, '\P{Is_WB=mn}', "");
Expect(1, 65307, '\P{^Is_WB=mn}', "");
Expect(0, 65308, '\p{Is_WB=mn}', "");
Expect(1, 65308, '\p{^Is_WB=mn}', "");
Expect(1, 65308, '\P{Is_WB=mn}', "");
Expect(0, 65308, '\P{^Is_WB=mn}', "");
Expect(1, 65307, '\p{Is_WB=- mn}', "");
Expect(0, 65307, '\p{^Is_WB=- mn}', "");
Expect(0, 65307, '\P{Is_WB=- mn}', "");
Expect(1, 65307, '\P{^Is_WB=- mn}', "");
Expect(0, 65308, '\p{Is_WB=- mn}', "");
Expect(1, 65308, '\p{^Is_WB=- mn}', "");
Expect(1, 65308, '\P{Is_WB=- mn}', "");
Expect(0, 65308, '\P{^Is_WB=- mn}', "");
Error('\p{Word_Break::= Newline}');
Error('\P{Word_Break::= Newline}');
Expect(1, 8233, '\p{Word_Break: newline}', "");
Expect(0, 8233, '\p{^Word_Break: newline}', "");
Expect(0, 8233, '\P{Word_Break: newline}', "");
Expect(1, 8233, '\P{^Word_Break: newline}', "");
Expect(0, 8234, '\p{Word_Break: newline}', "");
Expect(1, 8234, '\p{^Word_Break: newline}', "");
Expect(1, 8234, '\P{Word_Break: newline}', "");
Expect(0, 8234, '\P{^Word_Break: newline}', "");
Expect(1, 8233, '\p{Word_Break= newline}', "");
Expect(0, 8233, '\p{^Word_Break= newline}', "");
Expect(0, 8233, '\P{Word_Break= newline}', "");
Expect(1, 8233, '\P{^Word_Break= newline}', "");
Expect(0, 8234, '\p{Word_Break= newline}', "");
Expect(1, 8234, '\p{^Word_Break= newline}', "");
Expect(1, 8234, '\P{Word_Break= newline}', "");
Expect(0, 8234, '\P{^Word_Break= newline}', "");
Error('\p{WB=	 NL/a/}');
Error('\P{WB=	 NL/a/}');
Expect(1, 8233, '\p{WB=nl}', "");
Expect(0, 8233, '\p{^WB=nl}', "");
Expect(0, 8233, '\P{WB=nl}', "");
Expect(1, 8233, '\P{^WB=nl}', "");
Expect(0, 8234, '\p{WB=nl}', "");
Expect(1, 8234, '\p{^WB=nl}', "");
Expect(1, 8234, '\P{WB=nl}', "");
Expect(0, 8234, '\P{^WB=nl}', "");
Expect(1, 8233, '\p{WB=_NL}', "");
Expect(0, 8233, '\p{^WB=_NL}', "");
Expect(0, 8233, '\P{WB=_NL}', "");
Expect(1, 8233, '\P{^WB=_NL}', "");
Expect(0, 8234, '\p{WB=_NL}', "");
Expect(1, 8234, '\p{^WB=_NL}', "");
Expect(1, 8234, '\P{WB=_NL}', "");
Expect(0, 8234, '\P{^WB=_NL}', "");
Error('\p{Is_Word_Break=:=Newline}');
Error('\P{Is_Word_Break=:=Newline}');
Expect(1, 8233, '\p{Is_Word_Break=newline}', "");
Expect(0, 8233, '\p{^Is_Word_Break=newline}', "");
Expect(0, 8233, '\P{Is_Word_Break=newline}', "");
Expect(1, 8233, '\P{^Is_Word_Break=newline}', "");
Expect(0, 8234, '\p{Is_Word_Break=newline}', "");
Expect(1, 8234, '\p{^Is_Word_Break=newline}', "");
Expect(1, 8234, '\P{Is_Word_Break=newline}', "");
Expect(0, 8234, '\P{^Is_Word_Break=newline}', "");
Expect(1, 8233, '\p{Is_Word_Break: __Newline}', "");
Expect(0, 8233, '\p{^Is_Word_Break: __Newline}', "");
Expect(0, 8233, '\P{Is_Word_Break: __Newline}', "");
Expect(1, 8233, '\P{^Is_Word_Break: __Newline}', "");
Expect(0, 8234, '\p{Is_Word_Break: __Newline}', "");
Expect(1, 8234, '\p{^Is_Word_Break: __Newline}', "");
Expect(1, 8234, '\P{Is_Word_Break: __Newline}', "");
Expect(0, 8234, '\P{^Is_Word_Break: __Newline}', "");
Error('\p{Is_WB=:=		NL}');
Error('\P{Is_WB=:=		NL}');
Expect(1, 8233, '\p{Is_WB=nl}', "");
Expect(0, 8233, '\p{^Is_WB=nl}', "");
Expect(0, 8233, '\P{Is_WB=nl}', "");
Expect(1, 8233, '\P{^Is_WB=nl}', "");
Expect(0, 8234, '\p{Is_WB=nl}', "");
Expect(1, 8234, '\p{^Is_WB=nl}', "");
Expect(1, 8234, '\P{Is_WB=nl}', "");
Expect(0, 8234, '\P{^Is_WB=nl}', "");
Expect(1, 8233, '\p{Is_WB=	NL}', "");
Expect(0, 8233, '\p{^Is_WB=	NL}', "");
Expect(0, 8233, '\P{Is_WB=	NL}', "");
Expect(1, 8233, '\P{^Is_WB=	NL}', "");
Expect(0, 8234, '\p{Is_WB=	NL}', "");
Expect(1, 8234, '\p{^Is_WB=	NL}', "");
Expect(1, 8234, '\P{Is_WB=	NL}', "");
Expect(0, 8234, '\P{^Is_WB=	NL}', "");
Error('\p{Word_Break: := numeric}');
Error('\P{Word_Break: := numeric}');
Expect(1, 120831, '\p{Word_Break=numeric}', "");
Expect(0, 120831, '\p{^Word_Break=numeric}', "");
Expect(0, 120831, '\P{Word_Break=numeric}', "");
Expect(1, 120831, '\P{^Word_Break=numeric}', "");
Expect(0, 120832, '\p{Word_Break=numeric}', "");
Expect(1, 120832, '\p{^Word_Break=numeric}', "");
Expect(1, 120832, '\P{Word_Break=numeric}', "");
Expect(0, 120832, '\P{^Word_Break=numeric}', "");
Expect(1, 120831, '\p{Word_Break=_	Numeric}', "");
Expect(0, 120831, '\p{^Word_Break=_	Numeric}', "");
Expect(0, 120831, '\P{Word_Break=_	Numeric}', "");
Expect(1, 120831, '\P{^Word_Break=_	Numeric}', "");
Expect(0, 120832, '\p{Word_Break=_	Numeric}', "");
Expect(1, 120832, '\p{^Word_Break=_	Numeric}', "");
Expect(1, 120832, '\P{Word_Break=_	Numeric}', "");
Expect(0, 120832, '\P{^Word_Break=_	Numeric}', "");
Error('\p{WB=_NU:=}');
Error('\P{WB=_NU:=}');
Expect(1, 120831, '\p{WB=nu}', "");
Expect(0, 120831, '\p{^WB=nu}', "");
Expect(0, 120831, '\P{WB=nu}', "");
Expect(1, 120831, '\P{^WB=nu}', "");
Expect(0, 120832, '\p{WB=nu}', "");
Expect(1, 120832, '\p{^WB=nu}', "");
Expect(1, 120832, '\P{WB=nu}', "");
Expect(0, 120832, '\P{^WB=nu}', "");
Expect(1, 120831, '\p{WB=_NU}', "");
Expect(0, 120831, '\p{^WB=_NU}', "");
Expect(0, 120831, '\P{WB=_NU}', "");
Expect(1, 120831, '\P{^WB=_NU}', "");
Expect(0, 120832, '\p{WB=_NU}', "");
Expect(1, 120832, '\p{^WB=_NU}', "");
Expect(1, 120832, '\P{WB=_NU}', "");
Expect(0, 120832, '\P{^WB=_NU}', "");
Error('\p{Is_Word_Break=	-numeric:=}');
Error('\P{Is_Word_Break=	-numeric:=}');
Expect(1, 120831, '\p{Is_Word_Break=numeric}', "");
Expect(0, 120831, '\p{^Is_Word_Break=numeric}', "");
Expect(0, 120831, '\P{Is_Word_Break=numeric}', "");
Expect(1, 120831, '\P{^Is_Word_Break=numeric}', "");
Expect(0, 120832, '\p{Is_Word_Break=numeric}', "");
Expect(1, 120832, '\p{^Is_Word_Break=numeric}', "");
Expect(1, 120832, '\P{Is_Word_Break=numeric}', "");
Expect(0, 120832, '\P{^Is_Word_Break=numeric}', "");
Expect(1, 120831, '\p{Is_Word_Break=_	numeric}', "");
Expect(0, 120831, '\p{^Is_Word_Break=_	numeric}', "");
Expect(0, 120831, '\P{Is_Word_Break=_	numeric}', "");
Expect(1, 120831, '\P{^Is_Word_Break=_	numeric}', "");
Expect(0, 120832, '\p{Is_Word_Break=_	numeric}', "");
Expect(1, 120832, '\p{^Is_Word_Break=_	numeric}', "");
Expect(1, 120832, '\P{Is_Word_Break=_	numeric}', "");
Expect(0, 120832, '\P{^Is_Word_Break=_	numeric}', "");
Error('\p{Is_WB=_NU/a/}');
Error('\P{Is_WB=_NU/a/}');
Expect(1, 120831, '\p{Is_WB=nu}', "");
Expect(0, 120831, '\p{^Is_WB=nu}', "");
Expect(0, 120831, '\P{Is_WB=nu}', "");
Expect(1, 120831, '\P{^Is_WB=nu}', "");
Expect(0, 120832, '\p{Is_WB=nu}', "");
Expect(1, 120832, '\p{^Is_WB=nu}', "");
Expect(1, 120832, '\P{Is_WB=nu}', "");
Expect(0, 120832, '\P{^Is_WB=nu}', "");
Expect(1, 120831, '\p{Is_WB=	NU}', "");
Expect(0, 120831, '\p{^Is_WB=	NU}', "");
Expect(0, 120831, '\P{Is_WB=	NU}', "");
Expect(1, 120831, '\P{^Is_WB=	NU}', "");
Expect(0, 120832, '\p{Is_WB=	NU}', "");
Expect(1, 120832, '\p{^Is_WB=	NU}', "");
Expect(1, 120832, '\P{Is_WB=	NU}', "");
Expect(0, 120832, '\P{^Is_WB=	NU}', "");
Error('\p{Word_Break=	_REGIONAL_Indicator/a/}');
Error('\P{Word_Break=	_REGIONAL_Indicator/a/}');
Expect(1, 127487, '\p{Word_Break=regionalindicator}', "");
Expect(0, 127487, '\p{^Word_Break=regionalindicator}', "");
Expect(0, 127487, '\P{Word_Break=regionalindicator}', "");
Expect(1, 127487, '\P{^Word_Break=regionalindicator}', "");
Expect(0, 127488, '\p{Word_Break=regionalindicator}', "");
Expect(1, 127488, '\p{^Word_Break=regionalindicator}', "");
Expect(1, 127488, '\P{Word_Break=regionalindicator}', "");
Expect(0, 127488, '\P{^Word_Break=regionalindicator}', "");
Expect(1, 127487, '\p{Word_Break: 	 Regional_Indicator}', "");
Expect(0, 127487, '\p{^Word_Break: 	 Regional_Indicator}', "");
Expect(0, 127487, '\P{Word_Break: 	 Regional_Indicator}', "");
Expect(1, 127487, '\P{^Word_Break: 	 Regional_Indicator}', "");
Expect(0, 127488, '\p{Word_Break: 	 Regional_Indicator}', "");
Expect(1, 127488, '\p{^Word_Break: 	 Regional_Indicator}', "");
Expect(1, 127488, '\P{Word_Break: 	 Regional_Indicator}', "");
Expect(0, 127488, '\P{^Word_Break: 	 Regional_Indicator}', "");
Error('\p{WB=:=	ri}');
Error('\P{WB=:=	ri}');
Expect(1, 127487, '\p{WB=ri}', "");
Expect(0, 127487, '\p{^WB=ri}', "");
Expect(0, 127487, '\P{WB=ri}', "");
Expect(1, 127487, '\P{^WB=ri}', "");
Expect(0, 127488, '\p{WB=ri}', "");
Expect(1, 127488, '\p{^WB=ri}', "");
Expect(1, 127488, '\P{WB=ri}', "");
Expect(0, 127488, '\P{^WB=ri}', "");
Expect(1, 127487, '\p{WB= RI}', "");
Expect(0, 127487, '\p{^WB= RI}', "");
Expect(0, 127487, '\P{WB= RI}', "");
Expect(1, 127487, '\P{^WB= RI}', "");
Expect(0, 127488, '\p{WB= RI}', "");
Expect(1, 127488, '\p{^WB= RI}', "");
Expect(1, 127488, '\P{WB= RI}', "");
Expect(0, 127488, '\P{^WB= RI}', "");
Error('\p{Is_Word_Break=	:=regional_Indicator}');
Error('\P{Is_Word_Break=	:=regional_Indicator}');
Expect(1, 127487, '\p{Is_Word_Break:   regionalindicator}', "");
Expect(0, 127487, '\p{^Is_Word_Break:   regionalindicator}', "");
Expect(0, 127487, '\P{Is_Word_Break:   regionalindicator}', "");
Expect(1, 127487, '\P{^Is_Word_Break:   regionalindicator}', "");
Expect(0, 127488, '\p{Is_Word_Break:   regionalindicator}', "");
Expect(1, 127488, '\p{^Is_Word_Break:   regionalindicator}', "");
Expect(1, 127488, '\P{Is_Word_Break:   regionalindicator}', "");
Expect(0, 127488, '\P{^Is_Word_Break:   regionalindicator}', "");
Expect(1, 127487, '\p{Is_Word_Break=_Regional_indicator}', "");
Expect(0, 127487, '\p{^Is_Word_Break=_Regional_indicator}', "");
Expect(0, 127487, '\P{Is_Word_Break=_Regional_indicator}', "");
Expect(1, 127487, '\P{^Is_Word_Break=_Regional_indicator}', "");
Expect(0, 127488, '\p{Is_Word_Break=_Regional_indicator}', "");
Expect(1, 127488, '\p{^Is_Word_Break=_Regional_indicator}', "");
Expect(1, 127488, '\P{Is_Word_Break=_Regional_indicator}', "");
Expect(0, 127488, '\P{^Is_Word_Break=_Regional_indicator}', "");
Error('\p{Is_WB=:=RI}');
Error('\P{Is_WB=:=RI}');
Expect(1, 127487, '\p{Is_WB=ri}', "");
Expect(0, 127487, '\p{^Is_WB=ri}', "");
Expect(0, 127487, '\P{Is_WB=ri}', "");
Expect(1, 127487, '\P{^Is_WB=ri}', "");
Expect(0, 127488, '\p{Is_WB=ri}', "");
Expect(1, 127488, '\p{^Is_WB=ri}', "");
Expect(1, 127488, '\P{Is_WB=ri}', "");
Expect(0, 127488, '\P{^Is_WB=ri}', "");
Expect(1, 127487, '\p{Is_WB: _	ri}', "");
Expect(0, 127487, '\p{^Is_WB: _	ri}', "");
Expect(0, 127487, '\P{Is_WB: _	ri}', "");
Expect(1, 127487, '\P{^Is_WB: _	ri}', "");
Expect(0, 127488, '\p{Is_WB: _	ri}', "");
Expect(1, 127488, '\p{^Is_WB: _	ri}', "");
Expect(1, 127488, '\P{Is_WB: _	ri}', "");
Expect(0, 127488, '\P{^Is_WB: _	ri}', "");
Error('\p{Word_Break= _single_QUOTE/a/}');
Error('\P{Word_Break= _single_QUOTE/a/}');
Expect(1, 39, '\p{Word_Break=singlequote}', "");
Expect(0, 39, '\p{^Word_Break=singlequote}', "");
Expect(0, 39, '\P{Word_Break=singlequote}', "");
Expect(1, 39, '\P{^Word_Break=singlequote}', "");
Expect(0, 40, '\p{Word_Break=singlequote}', "");
Expect(1, 40, '\p{^Word_Break=singlequote}', "");
Expect(1, 40, '\P{Word_Break=singlequote}', "");
Expect(0, 40, '\P{^Word_Break=singlequote}', "");
Expect(1, 39, '\p{Word_Break=single_Quote}', "");
Expect(0, 39, '\p{^Word_Break=single_Quote}', "");
Expect(0, 39, '\P{Word_Break=single_Quote}', "");
Expect(1, 39, '\P{^Word_Break=single_Quote}', "");
Expect(0, 40, '\p{Word_Break=single_Quote}', "");
Expect(1, 40, '\p{^Word_Break=single_Quote}', "");
Expect(1, 40, '\P{Word_Break=single_Quote}', "");
Expect(0, 40, '\P{^Word_Break=single_Quote}', "");
Error('\p{WB=/a/  SQ}');
Error('\P{WB=/a/  SQ}');
Expect(1, 39, '\p{WB=sq}', "");
Expect(0, 39, '\p{^WB=sq}', "");
Expect(0, 39, '\P{WB=sq}', "");
Expect(1, 39, '\P{^WB=sq}', "");
Expect(0, 40, '\p{WB=sq}', "");
Expect(1, 40, '\p{^WB=sq}', "");
Expect(1, 40, '\P{WB=sq}', "");
Expect(0, 40, '\P{^WB=sq}', "");
Expect(1, 39, '\p{WB=_ SQ}', "");
Expect(0, 39, '\p{^WB=_ SQ}', "");
Expect(0, 39, '\P{WB=_ SQ}', "");
Expect(1, 39, '\P{^WB=_ SQ}', "");
Expect(0, 40, '\p{WB=_ SQ}', "");
Expect(1, 40, '\p{^WB=_ SQ}', "");
Expect(1, 40, '\P{WB=_ SQ}', "");
Expect(0, 40, '\P{^WB=_ SQ}', "");
Error('\p{Is_Word_Break:   :=	SINGLE_QUOTE}');
Error('\P{Is_Word_Break:   :=	SINGLE_QUOTE}');
Expect(1, 39, '\p{Is_Word_Break=singlequote}', "");
Expect(0, 39, '\p{^Is_Word_Break=singlequote}', "");
Expect(0, 39, '\P{Is_Word_Break=singlequote}', "");
Expect(1, 39, '\P{^Is_Word_Break=singlequote}', "");
Expect(0, 40, '\p{Is_Word_Break=singlequote}', "");
Expect(1, 40, '\p{^Is_Word_Break=singlequote}', "");
Expect(1, 40, '\P{Is_Word_Break=singlequote}', "");
Expect(0, 40, '\P{^Is_Word_Break=singlequote}', "");
Expect(1, 39, '\p{Is_Word_Break=-	Single_Quote}', "");
Expect(0, 39, '\p{^Is_Word_Break=-	Single_Quote}', "");
Expect(0, 39, '\P{Is_Word_Break=-	Single_Quote}', "");
Expect(1, 39, '\P{^Is_Word_Break=-	Single_Quote}', "");
Expect(0, 40, '\p{Is_Word_Break=-	Single_Quote}', "");
Expect(1, 40, '\p{^Is_Word_Break=-	Single_Quote}', "");
Expect(1, 40, '\P{Is_Word_Break=-	Single_Quote}', "");
Expect(0, 40, '\P{^Is_Word_Break=-	Single_Quote}', "");
Error('\p{Is_WB=-/a/SQ}');
Error('\P{Is_WB=-/a/SQ}');
Expect(1, 39, '\p{Is_WB: sq}', "");
Expect(0, 39, '\p{^Is_WB: sq}', "");
Expect(0, 39, '\P{Is_WB: sq}', "");
Expect(1, 39, '\P{^Is_WB: sq}', "");
Expect(0, 40, '\p{Is_WB: sq}', "");
Expect(1, 40, '\p{^Is_WB: sq}', "");
Expect(1, 40, '\P{Is_WB: sq}', "");
Expect(0, 40, '\P{^Is_WB: sq}', "");
Expect(1, 39, '\p{Is_WB= sq}', "");
Expect(0, 39, '\p{^Is_WB= sq}', "");
Expect(0, 39, '\P{Is_WB= sq}', "");
Expect(1, 39, '\P{^Is_WB= sq}', "");
Expect(0, 40, '\p{Is_WB= sq}', "");
Expect(1, 40, '\p{^Is_WB= sq}', "");
Expect(1, 40, '\P{Is_WB= sq}', "");
Expect(0, 40, '\P{^Is_WB= sq}', "");
Error('\p{Word_Break=_:=OTHER}');
Error('\P{Word_Break=_:=OTHER}');
Expect(1, 918000, '\p{Word_Break=other}', "");
Expect(0, 918000, '\p{^Word_Break=other}', "");
Expect(0, 918000, '\P{Word_Break=other}', "");
Expect(1, 918000, '\P{^Word_Break=other}', "");
Expect(0, 917999, '\p{Word_Break=other}', "");
Expect(1, 917999, '\p{^Word_Break=other}', "");
Expect(1, 917999, '\P{Word_Break=other}', "");
Expect(0, 917999, '\P{^Word_Break=other}', "");
Expect(1, 918000, '\p{Word_Break=-_Other}', "");
Expect(0, 918000, '\p{^Word_Break=-_Other}', "");
Expect(0, 918000, '\P{Word_Break=-_Other}', "");
Expect(1, 918000, '\P{^Word_Break=-_Other}', "");
Expect(0, 917999, '\p{Word_Break=-_Other}', "");
Expect(1, 917999, '\p{^Word_Break=-_Other}', "");
Expect(1, 917999, '\P{Word_Break=-_Other}', "");
Expect(0, 917999, '\P{^Word_Break=-_Other}', "");
Error('\p{WB=_/a/XX}');
Error('\P{WB=_/a/XX}');
Expect(1, 918000, '\p{WB=xx}', "");
Expect(0, 918000, '\p{^WB=xx}', "");
Expect(0, 918000, '\P{WB=xx}', "");
Expect(1, 918000, '\P{^WB=xx}', "");
Expect(0, 917999, '\p{WB=xx}', "");
Expect(1, 917999, '\p{^WB=xx}', "");
Expect(1, 917999, '\P{WB=xx}', "");
Expect(0, 917999, '\P{^WB=xx}', "");
Expect(1, 918000, '\p{WB=-	XX}', "");
Expect(0, 918000, '\p{^WB=-	XX}', "");
Expect(0, 918000, '\P{WB=-	XX}', "");
Expect(1, 918000, '\P{^WB=-	XX}', "");
Expect(0, 917999, '\p{WB=-	XX}', "");
Expect(1, 917999, '\p{^WB=-	XX}', "");
Expect(1, 917999, '\P{WB=-	XX}', "");
Expect(0, 917999, '\P{^WB=-	XX}', "");
Error('\p{Is_Word_Break:		other/a/}');
Error('\P{Is_Word_Break:		other/a/}');
Expect(1, 918000, '\p{Is_Word_Break: other}', "");
Expect(0, 918000, '\p{^Is_Word_Break: other}', "");
Expect(0, 918000, '\P{Is_Word_Break: other}', "");
Expect(1, 918000, '\P{^Is_Word_Break: other}', "");
Expect(0, 917999, '\p{Is_Word_Break: other}', "");
Expect(1, 917999, '\p{^Is_Word_Break: other}', "");
Expect(1, 917999, '\P{Is_Word_Break: other}', "");
Expect(0, 917999, '\P{^Is_Word_Break: other}', "");
Expect(1, 918000, '\p{Is_Word_Break=  Other}', "");
Expect(0, 918000, '\p{^Is_Word_Break=  Other}', "");
Expect(0, 918000, '\P{Is_Word_Break=  Other}', "");
Expect(1, 918000, '\P{^Is_Word_Break=  Other}', "");
Expect(0, 917999, '\p{Is_Word_Break=  Other}', "");
Expect(1, 917999, '\p{^Is_Word_Break=  Other}', "");
Expect(1, 917999, '\P{Is_Word_Break=  Other}', "");
Expect(0, 917999, '\P{^Is_Word_Break=  Other}', "");
Error('\p{Is_WB=	/a/XX}');
Error('\P{Is_WB=	/a/XX}');
Expect(1, 918000, '\p{Is_WB:	xx}', "");
Expect(0, 918000, '\p{^Is_WB:	xx}', "");
Expect(0, 918000, '\P{Is_WB:	xx}', "");
Expect(1, 918000, '\P{^Is_WB:	xx}', "");
Expect(0, 917999, '\p{Is_WB:	xx}', "");
Expect(1, 917999, '\p{^Is_WB:	xx}', "");
Expect(1, 917999, '\P{Is_WB:	xx}', "");
Expect(0, 917999, '\P{^Is_WB:	xx}', "");
Expect(1, 918000, '\p{Is_WB= -XX}', "");
Expect(0, 918000, '\p{^Is_WB= -XX}', "");
Expect(0, 918000, '\P{Is_WB= -XX}', "");
Expect(1, 918000, '\P{^Is_WB= -XX}', "");
Expect(0, 917999, '\p{Is_WB= -XX}', "");
Expect(1, 917999, '\p{^Is_WB= -XX}', "");
Expect(1, 917999, '\P{Is_WB= -XX}', "");
Expect(0, 917999, '\P{^Is_WB= -XX}', "");
Error('\p{White_Space=_/a/No}');
Error('\P{White_Space=_/a/No}');
Expect(1, 12289, '\p{White_Space=no}', "");
Expect(0, 12289, '\p{^White_Space=no}', "");
Expect(0, 12289, '\P{White_Space=no}', "");
Expect(1, 12289, '\P{^White_Space=no}', "");
Expect(0, 12288, '\p{White_Space=no}', "");
Expect(1, 12288, '\p{^White_Space=no}', "");
Expect(1, 12288, '\P{White_Space=no}', "");
Expect(0, 12288, '\P{^White_Space=no}', "");
Expect(1, 12289, '\p{White_Space=-NO}', "");
Expect(0, 12289, '\p{^White_Space=-NO}', "");
Expect(0, 12289, '\P{White_Space=-NO}', "");
Expect(1, 12289, '\P{^White_Space=-NO}', "");
Expect(0, 12288, '\p{White_Space=-NO}', "");
Expect(1, 12288, '\p{^White_Space=-NO}', "");
Expect(1, 12288, '\P{White_Space=-NO}', "");
Expect(0, 12288, '\P{^White_Space=-NO}', "");
Error('\p{WSpace=-:=n}');
Error('\P{WSpace=-:=n}');
Expect(1, 12289, '\p{WSpace=n}', "");
Expect(0, 12289, '\p{^WSpace=n}', "");
Expect(0, 12289, '\P{WSpace=n}', "");
Expect(1, 12289, '\P{^WSpace=n}', "");
Expect(0, 12288, '\p{WSpace=n}', "");
Expect(1, 12288, '\p{^WSpace=n}', "");
Expect(1, 12288, '\P{WSpace=n}', "");
Expect(0, 12288, '\P{^WSpace=n}', "");
Expect(1, 12289, '\p{WSpace=_ N}', "");
Expect(0, 12289, '\p{^WSpace=_ N}', "");
Expect(0, 12289, '\P{WSpace=_ N}', "");
Expect(1, 12289, '\P{^WSpace=_ N}', "");
Expect(0, 12288, '\p{WSpace=_ N}', "");
Expect(1, 12288, '\p{^WSpace=_ N}', "");
Expect(1, 12288, '\P{WSpace=_ N}', "");
Expect(0, 12288, '\P{^WSpace=_ N}', "");
Error('\p{Space: 	F:=}');
Error('\P{Space: 	F:=}');
Expect(1, 12289, '\p{Space: f}', "");
Expect(0, 12289, '\p{^Space: f}', "");
Expect(0, 12289, '\P{Space: f}', "");
Expect(1, 12289, '\P{^Space: f}', "");
Expect(0, 12288, '\p{Space: f}', "");
Expect(1, 12288, '\p{^Space: f}', "");
Expect(1, 12288, '\P{Space: f}', "");
Expect(0, 12288, '\P{^Space: f}', "");
Expect(1, 12289, '\p{Space=_F}', "");
Expect(0, 12289, '\p{^Space=_F}', "");
Expect(0, 12289, '\P{Space=_F}', "");
Expect(1, 12289, '\P{^Space=_F}', "");
Expect(0, 12288, '\p{Space=_F}', "");
Expect(1, 12288, '\p{^Space=_F}', "");
Expect(1, 12288, '\P{Space=_F}', "");
Expect(0, 12288, '\P{^Space=_F}', "");
Error('\p{Is_White_Space=/a/False}');
Error('\P{Is_White_Space=/a/False}');
Expect(1, 12289, '\p{Is_White_Space=false}', "");
Expect(0, 12289, '\p{^Is_White_Space=false}', "");
Expect(0, 12289, '\P{Is_White_Space=false}', "");
Expect(1, 12289, '\P{^Is_White_Space=false}', "");
Expect(0, 12288, '\p{Is_White_Space=false}', "");
Expect(1, 12288, '\p{^Is_White_Space=false}', "");
Expect(1, 12288, '\P{Is_White_Space=false}', "");
Expect(0, 12288, '\P{^Is_White_Space=false}', "");
Expect(1, 12289, '\p{Is_White_Space=_-FALSE}', "");
Expect(0, 12289, '\p{^Is_White_Space=_-FALSE}', "");
Expect(0, 12289, '\P{Is_White_Space=_-FALSE}', "");
Expect(1, 12289, '\P{^Is_White_Space=_-FALSE}', "");
Expect(0, 12288, '\p{Is_White_Space=_-FALSE}', "");
Expect(1, 12288, '\p{^Is_White_Space=_-FALSE}', "");
Expect(1, 12288, '\P{Is_White_Space=_-FALSE}', "");
Expect(0, 12288, '\P{^Is_White_Space=_-FALSE}', "");
Error('\p{Is_WSpace=:=_	No}');
Error('\P{Is_WSpace=:=_	No}');
Expect(1, 12289, '\p{Is_WSpace=no}', "");
Expect(0, 12289, '\p{^Is_WSpace=no}', "");
Expect(0, 12289, '\P{Is_WSpace=no}', "");
Expect(1, 12289, '\P{^Is_WSpace=no}', "");
Expect(0, 12288, '\p{Is_WSpace=no}', "");
Expect(1, 12288, '\p{^Is_WSpace=no}', "");
Expect(1, 12288, '\P{Is_WSpace=no}', "");
Expect(0, 12288, '\P{^Is_WSpace=no}', "");
Expect(1, 12289, '\p{Is_WSpace=--NO}', "");
Expect(0, 12289, '\p{^Is_WSpace=--NO}', "");
Expect(0, 12289, '\P{Is_WSpace=--NO}', "");
Expect(1, 12289, '\P{^Is_WSpace=--NO}', "");
Expect(0, 12288, '\p{Is_WSpace=--NO}', "");
Expect(1, 12288, '\p{^Is_WSpace=--NO}', "");
Expect(1, 12288, '\P{Is_WSpace=--NO}', "");
Expect(0, 12288, '\P{^Is_WSpace=--NO}', "");
Error('\p{Is_Space=_/a/n}');
Error('\P{Is_Space=_/a/n}');
Expect(1, 12289, '\p{Is_Space=n}', "");
Expect(0, 12289, '\p{^Is_Space=n}', "");
Expect(0, 12289, '\P{Is_Space=n}', "");
Expect(1, 12289, '\P{^Is_Space=n}', "");
Expect(0, 12288, '\p{Is_Space=n}', "");
Expect(1, 12288, '\p{^Is_Space=n}', "");
Expect(1, 12288, '\P{Is_Space=n}', "");
Expect(0, 12288, '\P{^Is_Space=n}', "");
Expect(1, 12289, '\p{Is_Space=	_n}', "");
Expect(0, 12289, '\p{^Is_Space=	_n}', "");
Expect(0, 12289, '\P{Is_Space=	_n}', "");
Expect(1, 12289, '\P{^Is_Space=	_n}', "");
Expect(0, 12288, '\p{Is_Space=	_n}', "");
Expect(1, 12288, '\p{^Is_Space=	_n}', "");
Expect(1, 12288, '\P{Is_Space=	_n}', "");
Expect(0, 12288, '\P{^Is_Space=	_n}', "");
Error('\p{White_Space=-:=Yes}');
Error('\P{White_Space=-:=Yes}');
Expect(1, 12288, '\p{White_Space=yes}', "");
Expect(0, 12288, '\p{^White_Space=yes}', "");
Expect(0, 12288, '\P{White_Space=yes}', "");
Expect(1, 12288, '\P{^White_Space=yes}', "");
Expect(0, 12289, '\p{White_Space=yes}', "");
Expect(1, 12289, '\p{^White_Space=yes}', "");
Expect(1, 12289, '\P{White_Space=yes}', "");
Expect(0, 12289, '\P{^White_Space=yes}', "");
Expect(1, 12288, '\p{White_Space= Yes}', "");
Expect(0, 12288, '\p{^White_Space= Yes}', "");
Expect(0, 12288, '\P{White_Space= Yes}', "");
Expect(1, 12288, '\P{^White_Space= Yes}', "");
Expect(0, 12289, '\p{White_Space= Yes}', "");
Expect(1, 12289, '\p{^White_Space= Yes}', "");
Expect(1, 12289, '\P{White_Space= Yes}', "");
Expect(0, 12289, '\P{^White_Space= Yes}', "");
Error('\p{WSpace=	/a/Y}');
Error('\P{WSpace=	/a/Y}');
Expect(1, 12288, '\p{WSpace=y}', "");
Expect(0, 12288, '\p{^WSpace=y}', "");
Expect(0, 12288, '\P{WSpace=y}', "");
Expect(1, 12288, '\P{^WSpace=y}', "");
Expect(0, 12289, '\p{WSpace=y}', "");
Expect(1, 12289, '\p{^WSpace=y}', "");
Expect(1, 12289, '\P{WSpace=y}', "");
Expect(0, 12289, '\P{^WSpace=y}', "");
Expect(1, 12288, '\p{WSpace=	y}', "");
Expect(0, 12288, '\p{^WSpace=	y}', "");
Expect(0, 12288, '\P{WSpace=	y}', "");
Expect(1, 12288, '\P{^WSpace=	y}', "");
Expect(0, 12289, '\p{WSpace=	y}', "");
Expect(1, 12289, '\p{^WSpace=	y}', "");
Expect(1, 12289, '\P{WSpace=	y}', "");
Expect(0, 12289, '\P{^WSpace=	y}', "");
Error('\p{Space=:=	T}');
Error('\P{Space=:=	T}');
Expect(1, 12288, '\p{Space=t}', "");
Expect(0, 12288, '\p{^Space=t}', "");
Expect(0, 12288, '\P{Space=t}', "");
Expect(1, 12288, '\P{^Space=t}', "");
Expect(0, 12289, '\p{Space=t}', "");
Expect(1, 12289, '\p{^Space=t}', "");
Expect(1, 12289, '\P{Space=t}', "");
Expect(0, 12289, '\P{^Space=t}', "");
Expect(1, 12288, '\p{Space= -t}', "");
Expect(0, 12288, '\p{^Space= -t}', "");
Expect(0, 12288, '\P{Space= -t}', "");
Expect(1, 12288, '\P{^Space= -t}', "");
Expect(0, 12289, '\p{Space= -t}', "");
Expect(1, 12289, '\p{^Space= -t}', "");
Expect(1, 12289, '\P{Space= -t}', "");
Expect(0, 12289, '\P{^Space= -t}', "");
Error('\p{Is_White_Space=/a/True}');
Error('\P{Is_White_Space=/a/True}');
Expect(1, 12288, '\p{Is_White_Space=true}', "");
Expect(0, 12288, '\p{^Is_White_Space=true}', "");
Expect(0, 12288, '\P{Is_White_Space=true}', "");
Expect(1, 12288, '\P{^Is_White_Space=true}', "");
Expect(0, 12289, '\p{Is_White_Space=true}', "");
Expect(1, 12289, '\p{^Is_White_Space=true}', "");
Expect(1, 12289, '\P{Is_White_Space=true}', "");
Expect(0, 12289, '\P{^Is_White_Space=true}', "");
Expect(1, 12288, '\p{Is_White_Space=_true}', "");
Expect(0, 12288, '\p{^Is_White_Space=_true}', "");
Expect(0, 12288, '\P{Is_White_Space=_true}', "");
Expect(1, 12288, '\P{^Is_White_Space=_true}', "");
Expect(0, 12289, '\p{Is_White_Space=_true}', "");
Expect(1, 12289, '\p{^Is_White_Space=_true}', "");
Expect(1, 12289, '\P{Is_White_Space=_true}', "");
Expect(0, 12289, '\P{^Is_White_Space=_true}', "");
Error('\p{Is_WSpace=/a/	yes}');
Error('\P{Is_WSpace=/a/	yes}');
Expect(1, 12288, '\p{Is_WSpace=yes}', "");
Expect(0, 12288, '\p{^Is_WSpace=yes}', "");
Expect(0, 12288, '\P{Is_WSpace=yes}', "");
Expect(1, 12288, '\P{^Is_WSpace=yes}', "");
Expect(0, 12289, '\p{Is_WSpace=yes}', "");
Expect(1, 12289, '\p{^Is_WSpace=yes}', "");
Expect(1, 12289, '\P{Is_WSpace=yes}', "");
Expect(0, 12289, '\P{^Is_WSpace=yes}', "");
Expect(1, 12288, '\p{Is_WSpace=		yes}', "");
Expect(0, 12288, '\p{^Is_WSpace=		yes}', "");
Expect(0, 12288, '\P{Is_WSpace=		yes}', "");
Expect(1, 12288, '\P{^Is_WSpace=		yes}', "");
Expect(0, 12289, '\p{Is_WSpace=		yes}', "");
Expect(1, 12289, '\p{^Is_WSpace=		yes}', "");
Expect(1, 12289, '\P{Is_WSpace=		yes}', "");
Expect(0, 12289, '\P{^Is_WSpace=		yes}', "");
Error('\p{Is_Space=/a/Y}');
Error('\P{Is_Space=/a/Y}');
Expect(1, 12288, '\p{Is_Space:	y}', "");
Expect(0, 12288, '\p{^Is_Space:	y}', "");
Expect(0, 12288, '\P{Is_Space:	y}', "");
Expect(1, 12288, '\P{^Is_Space:	y}', "");
Expect(0, 12289, '\p{Is_Space:	y}', "");
Expect(1, 12289, '\p{^Is_Space:	y}', "");
Expect(1, 12289, '\P{Is_Space:	y}', "");
Expect(0, 12289, '\P{^Is_Space:	y}', "");
Expect(1, 12288, '\p{Is_Space=-Y}', "");
Expect(0, 12288, '\p{^Is_Space=-Y}', "");
Expect(0, 12288, '\P{Is_Space=-Y}', "");
Expect(1, 12288, '\P{^Is_Space=-Y}', "");
Expect(0, 12289, '\p{Is_Space=-Y}', "");
Expect(1, 12289, '\p{^Is_Space=-Y}', "");
Expect(1, 12289, '\P{Is_Space=-Y}', "");
Expect(0, 12289, '\P{^Is_Space=-Y}', "");
Error('\p{XID_Continue=	_NO/a/}');
Error('\P{XID_Continue=	_NO/a/}');
Expect(1, 918000, '\p{XID_Continue=no}', "");
Expect(0, 918000, '\p{^XID_Continue=no}', "");
Expect(0, 918000, '\P{XID_Continue=no}', "");
Expect(1, 918000, '\P{^XID_Continue=no}', "");
Expect(0, 917999, '\p{XID_Continue=no}', "");
Expect(1, 917999, '\p{^XID_Continue=no}', "");
Expect(1, 917999, '\P{XID_Continue=no}', "");
Expect(0, 917999, '\P{^XID_Continue=no}', "");
Expect(1, 918000, '\p{XID_Continue:	-NO}', "");
Expect(0, 918000, '\p{^XID_Continue:	-NO}', "");
Expect(0, 918000, '\P{XID_Continue:	-NO}', "");
Expect(1, 918000, '\P{^XID_Continue:	-NO}', "");
Expect(0, 917999, '\p{XID_Continue:	-NO}', "");
Expect(1, 917999, '\p{^XID_Continue:	-NO}', "");
Expect(1, 917999, '\P{XID_Continue:	-NO}', "");
Expect(0, 917999, '\P{^XID_Continue:	-NO}', "");
Error('\p{XIDC=_/a/N}');
Error('\P{XIDC=_/a/N}');
Expect(1, 918000, '\p{XIDC=n}', "");
Expect(0, 918000, '\p{^XIDC=n}', "");
Expect(0, 918000, '\P{XIDC=n}', "");
Expect(1, 918000, '\P{^XIDC=n}', "");
Expect(0, 917999, '\p{XIDC=n}', "");
Expect(1, 917999, '\p{^XIDC=n}', "");
Expect(1, 917999, '\P{XIDC=n}', "");
Expect(0, 917999, '\P{^XIDC=n}', "");
Expect(1, 918000, '\p{XIDC=	n}', "");
Expect(0, 918000, '\p{^XIDC=	n}', "");
Expect(0, 918000, '\P{XIDC=	n}', "");
Expect(1, 918000, '\P{^XIDC=	n}', "");
Expect(0, 917999, '\p{XIDC=	n}', "");
Expect(1, 917999, '\p{^XIDC=	n}', "");
Expect(1, 917999, '\P{XIDC=	n}', "");
Expect(0, 917999, '\P{^XIDC=	n}', "");
Error('\p{Is_XID_Continue=:=	F}');
Error('\P{Is_XID_Continue=:=	F}');
Expect(1, 918000, '\p{Is_XID_Continue=f}', "");
Expect(0, 918000, '\p{^Is_XID_Continue=f}', "");
Expect(0, 918000, '\P{Is_XID_Continue=f}', "");
Expect(1, 918000, '\P{^Is_XID_Continue=f}', "");
Expect(0, 917999, '\p{Is_XID_Continue=f}', "");
Expect(1, 917999, '\p{^Is_XID_Continue=f}', "");
Expect(1, 917999, '\P{Is_XID_Continue=f}', "");
Expect(0, 917999, '\P{^Is_XID_Continue=f}', "");
Expect(1, 918000, '\p{Is_XID_Continue= -f}', "");
Expect(0, 918000, '\p{^Is_XID_Continue= -f}', "");
Expect(0, 918000, '\P{Is_XID_Continue= -f}', "");
Expect(1, 918000, '\P{^Is_XID_Continue= -f}', "");
Expect(0, 917999, '\p{Is_XID_Continue= -f}', "");
Expect(1, 917999, '\p{^Is_XID_Continue= -f}', "");
Expect(1, 917999, '\P{Is_XID_Continue= -f}', "");
Expect(0, 917999, '\P{^Is_XID_Continue= -f}', "");
Error('\p{Is_XIDC=/a/ -False}');
Error('\P{Is_XIDC=/a/ -False}');
Expect(1, 918000, '\p{Is_XIDC=false}', "");
Expect(0, 918000, '\p{^Is_XIDC=false}', "");
Expect(0, 918000, '\P{Is_XIDC=false}', "");
Expect(1, 918000, '\P{^Is_XIDC=false}', "");
Expect(0, 917999, '\p{Is_XIDC=false}', "");
Expect(1, 917999, '\p{^Is_XIDC=false}', "");
Expect(1, 917999, '\P{Is_XIDC=false}', "");
Expect(0, 917999, '\P{^Is_XIDC=false}', "");
Expect(1, 918000, '\p{Is_XIDC=_FALSE}', "");
Expect(0, 918000, '\p{^Is_XIDC=_FALSE}', "");
Expect(0, 918000, '\P{Is_XIDC=_FALSE}', "");
Expect(1, 918000, '\P{^Is_XIDC=_FALSE}', "");
Expect(0, 917999, '\p{Is_XIDC=_FALSE}', "");
Expect(1, 917999, '\p{^Is_XIDC=_FALSE}', "");
Expect(1, 917999, '\P{Is_XIDC=_FALSE}', "");
Expect(0, 917999, '\P{^Is_XIDC=_FALSE}', "");
Error('\p{XID_Continue=/a/-Yes}');
Error('\P{XID_Continue=/a/-Yes}');
Expect(1, 917999, '\p{XID_Continue=yes}', "");
Expect(0, 917999, '\p{^XID_Continue=yes}', "");
Expect(0, 917999, '\P{XID_Continue=yes}', "");
Expect(1, 917999, '\P{^XID_Continue=yes}', "");
Expect(0, 918000, '\p{XID_Continue=yes}', "");
Expect(1, 918000, '\p{^XID_Continue=yes}', "");
Expect(1, 918000, '\P{XID_Continue=yes}', "");
Expect(0, 918000, '\P{^XID_Continue=yes}', "");
Expect(1, 917999, '\p{XID_Continue=_ yes}', "");
Expect(0, 917999, '\p{^XID_Continue=_ yes}', "");
Expect(0, 917999, '\P{XID_Continue=_ yes}', "");
Expect(1, 917999, '\P{^XID_Continue=_ yes}', "");
Expect(0, 918000, '\p{XID_Continue=_ yes}', "");
Expect(1, 918000, '\p{^XID_Continue=_ yes}', "");
Expect(1, 918000, '\P{XID_Continue=_ yes}', "");
Expect(0, 918000, '\P{^XID_Continue=_ yes}', "");
Error('\p{XIDC=:=Y}');
Error('\P{XIDC=:=Y}');
Expect(1, 917999, '\p{XIDC:	y}', "");
Expect(0, 917999, '\p{^XIDC:	y}', "");
Expect(0, 917999, '\P{XIDC:	y}', "");
Expect(1, 917999, '\P{^XIDC:	y}', "");
Expect(0, 918000, '\p{XIDC:	y}', "");
Expect(1, 918000, '\p{^XIDC:	y}', "");
Expect(1, 918000, '\P{XIDC:	y}', "");
Expect(0, 918000, '\P{^XIDC:	y}', "");
Expect(1, 917999, '\p{XIDC= Y}', "");
Expect(0, 917999, '\p{^XIDC= Y}', "");
Expect(0, 917999, '\P{XIDC= Y}', "");
Expect(1, 917999, '\P{^XIDC= Y}', "");
Expect(0, 918000, '\p{XIDC= Y}', "");
Expect(1, 918000, '\p{^XIDC= Y}', "");
Expect(1, 918000, '\P{XIDC= Y}', "");
Expect(0, 918000, '\P{^XIDC= Y}', "");
Error('\p{Is_XID_Continue=	t:=}');
Error('\P{Is_XID_Continue=	t:=}');
Expect(1, 917999, '\p{Is_XID_Continue=t}', "");
Expect(0, 917999, '\p{^Is_XID_Continue=t}', "");
Expect(0, 917999, '\P{Is_XID_Continue=t}', "");
Expect(1, 917999, '\P{^Is_XID_Continue=t}', "");
Expect(0, 918000, '\p{Is_XID_Continue=t}', "");
Expect(1, 918000, '\p{^Is_XID_Continue=t}', "");
Expect(1, 918000, '\P{Is_XID_Continue=t}', "");
Expect(0, 918000, '\P{^Is_XID_Continue=t}', "");
Expect(1, 917999, '\p{Is_XID_Continue=_	t}', "");
Expect(0, 917999, '\p{^Is_XID_Continue=_	t}', "");
Expect(0, 917999, '\P{Is_XID_Continue=_	t}', "");
Expect(1, 917999, '\P{^Is_XID_Continue=_	t}', "");
Expect(0, 918000, '\p{Is_XID_Continue=_	t}', "");
Expect(1, 918000, '\p{^Is_XID_Continue=_	t}', "");
Expect(1, 918000, '\P{Is_XID_Continue=_	t}', "");
Expect(0, 918000, '\P{^Is_XID_Continue=_	t}', "");
Error('\p{Is_XIDC=_:=True}');
Error('\P{Is_XIDC=_:=True}');
Expect(1, 917999, '\p{Is_XIDC=true}', "");
Expect(0, 917999, '\p{^Is_XIDC=true}', "");
Expect(0, 917999, '\P{Is_XIDC=true}', "");
Expect(1, 917999, '\P{^Is_XIDC=true}', "");
Expect(0, 918000, '\p{Is_XIDC=true}', "");
Expect(1, 918000, '\p{^Is_XIDC=true}', "");
Expect(1, 918000, '\P{Is_XIDC=true}', "");
Expect(0, 918000, '\P{^Is_XIDC=true}', "");
Expect(1, 917999, '\p{Is_XIDC=-	TRUE}', "");
Expect(0, 917999, '\p{^Is_XIDC=-	TRUE}', "");
Expect(0, 917999, '\P{Is_XIDC=-	TRUE}', "");
Expect(1, 917999, '\P{^Is_XIDC=-	TRUE}', "");
Expect(0, 918000, '\p{Is_XIDC=-	TRUE}', "");
Expect(1, 918000, '\p{^Is_XIDC=-	TRUE}', "");
Expect(1, 918000, '\P{Is_XIDC=-	TRUE}', "");
Expect(0, 918000, '\P{^Is_XIDC=-	TRUE}', "");
Error('\p{XID_Start=/a/no}');
Error('\P{XID_Start=/a/no}');
Expect(1, 195102, '\p{XID_Start=no}', "");
Expect(0, 195102, '\p{^XID_Start=no}', "");
Expect(0, 195102, '\P{XID_Start=no}', "");
Expect(1, 195102, '\P{^XID_Start=no}', "");
Expect(0, 195101, '\p{XID_Start=no}', "");
Expect(1, 195101, '\p{^XID_Start=no}', "");
Expect(1, 195101, '\P{XID_Start=no}', "");
Expect(0, 195101, '\P{^XID_Start=no}', "");
Expect(1, 195102, '\p{XID_Start:_NO}', "");
Expect(0, 195102, '\p{^XID_Start:_NO}', "");
Expect(0, 195102, '\P{XID_Start:_NO}', "");
Expect(1, 195102, '\P{^XID_Start:_NO}', "");
Expect(0, 195101, '\p{XID_Start:_NO}', "");
Expect(1, 195101, '\p{^XID_Start:_NO}', "");
Expect(1, 195101, '\P{XID_Start:_NO}', "");
Expect(0, 195101, '\P{^XID_Start:_NO}', "");
Error('\p{XIDS:	:=N}');
Error('\P{XIDS:	:=N}');
Expect(1, 195102, '\p{XIDS=n}', "");
Expect(0, 195102, '\p{^XIDS=n}', "");
Expect(0, 195102, '\P{XIDS=n}', "");
Expect(1, 195102, '\P{^XIDS=n}', "");
Expect(0, 195101, '\p{XIDS=n}', "");
Expect(1, 195101, '\p{^XIDS=n}', "");
Expect(1, 195101, '\P{XIDS=n}', "");
Expect(0, 195101, '\P{^XIDS=n}', "");
Expect(1, 195102, '\p{XIDS:   	-n}', "");
Expect(0, 195102, '\p{^XIDS:   	-n}', "");
Expect(0, 195102, '\P{XIDS:   	-n}', "");
Expect(1, 195102, '\P{^XIDS:   	-n}', "");
Expect(0, 195101, '\p{XIDS:   	-n}', "");
Expect(1, 195101, '\p{^XIDS:   	-n}', "");
Expect(1, 195101, '\P{XIDS:   	-n}', "");
Expect(0, 195101, '\P{^XIDS:   	-n}', "");
Error('\p{Is_XID_Start=-/a/F}');
Error('\P{Is_XID_Start=-/a/F}');
Expect(1, 195102, '\p{Is_XID_Start:   f}', "");
Expect(0, 195102, '\p{^Is_XID_Start:   f}', "");
Expect(0, 195102, '\P{Is_XID_Start:   f}', "");
Expect(1, 195102, '\P{^Is_XID_Start:   f}', "");
Expect(0, 195101, '\p{Is_XID_Start:   f}', "");
Expect(1, 195101, '\p{^Is_XID_Start:   f}', "");
Expect(1, 195101, '\P{Is_XID_Start:   f}', "");
Expect(0, 195101, '\P{^Is_XID_Start:   f}', "");
Expect(1, 195102, '\p{Is_XID_Start= -F}', "");
Expect(0, 195102, '\p{^Is_XID_Start= -F}', "");
Expect(0, 195102, '\P{Is_XID_Start= -F}', "");
Expect(1, 195102, '\P{^Is_XID_Start= -F}', "");
Expect(0, 195101, '\p{Is_XID_Start= -F}', "");
Expect(1, 195101, '\p{^Is_XID_Start= -F}', "");
Expect(1, 195101, '\P{Is_XID_Start= -F}', "");
Expect(0, 195101, '\P{^Is_XID_Start= -F}', "");
Error('\p{Is_XIDS=-:=FALSE}');
Error('\P{Is_XIDS=-:=FALSE}');
Expect(1, 195102, '\p{Is_XIDS=false}', "");
Expect(0, 195102, '\p{^Is_XIDS=false}', "");
Expect(0, 195102, '\P{Is_XIDS=false}', "");
Expect(1, 195102, '\P{^Is_XIDS=false}', "");
Expect(0, 195101, '\p{Is_XIDS=false}', "");
Expect(1, 195101, '\p{^Is_XIDS=false}', "");
Expect(1, 195101, '\P{Is_XIDS=false}', "");
Expect(0, 195101, '\P{^Is_XIDS=false}', "");
Expect(1, 195102, '\p{Is_XIDS=	 False}', "");
Expect(0, 195102, '\p{^Is_XIDS=	 False}', "");
Expect(0, 195102, '\P{Is_XIDS=	 False}', "");
Expect(1, 195102, '\P{^Is_XIDS=	 False}', "");
Expect(0, 195101, '\p{Is_XIDS=	 False}', "");
Expect(1, 195101, '\p{^Is_XIDS=	 False}', "");
Expect(1, 195101, '\P{Is_XIDS=	 False}', "");
Expect(0, 195101, '\P{^Is_XIDS=	 False}', "");
Error('\p{XID_Start=/a/_-Yes}');
Error('\P{XID_Start=/a/_-Yes}');
Expect(1, 195101, '\p{XID_Start=yes}', "");
Expect(0, 195101, '\p{^XID_Start=yes}', "");
Expect(0, 195101, '\P{XID_Start=yes}', "");
Expect(1, 195101, '\P{^XID_Start=yes}', "");
Expect(0, 195102, '\p{XID_Start=yes}', "");
Expect(1, 195102, '\p{^XID_Start=yes}', "");
Expect(1, 195102, '\P{XID_Start=yes}', "");
Expect(0, 195102, '\P{^XID_Start=yes}', "");
Expect(1, 195101, '\p{XID_Start=-	Yes}', "");
Expect(0, 195101, '\p{^XID_Start=-	Yes}', "");
Expect(0, 195101, '\P{XID_Start=-	Yes}', "");
Expect(1, 195101, '\P{^XID_Start=-	Yes}', "");
Expect(0, 195102, '\p{XID_Start=-	Yes}', "");
Expect(1, 195102, '\p{^XID_Start=-	Yes}', "");
Expect(1, 195102, '\P{XID_Start=-	Yes}', "");
Expect(0, 195102, '\P{^XID_Start=-	Yes}', "");
Error('\p{XIDS=	 Y/a/}');
Error('\P{XIDS=	 Y/a/}');
Expect(1, 195101, '\p{XIDS:	y}', "");
Expect(0, 195101, '\p{^XIDS:	y}', "");
Expect(0, 195101, '\P{XIDS:	y}', "");
Expect(1, 195101, '\P{^XIDS:	y}', "");
Expect(0, 195102, '\p{XIDS:	y}', "");
Expect(1, 195102, '\p{^XIDS:	y}', "");
Expect(1, 195102, '\P{XIDS:	y}', "");
Expect(0, 195102, '\P{^XIDS:	y}', "");
Expect(1, 195101, '\p{XIDS=-Y}', "");
Expect(0, 195101, '\p{^XIDS=-Y}', "");
Expect(0, 195101, '\P{XIDS=-Y}', "");
Expect(1, 195101, '\P{^XIDS=-Y}', "");
Expect(0, 195102, '\p{XIDS=-Y}', "");
Expect(1, 195102, '\p{^XIDS=-Y}', "");
Expect(1, 195102, '\P{XIDS=-Y}', "");
Expect(0, 195102, '\P{^XIDS=-Y}', "");
Error('\p{Is_XID_Start=:=- T}');
Error('\P{Is_XID_Start=:=- T}');
Expect(1, 195101, '\p{Is_XID_Start=t}', "");
Expect(0, 195101, '\p{^Is_XID_Start=t}', "");
Expect(0, 195101, '\P{Is_XID_Start=t}', "");
Expect(1, 195101, '\P{^Is_XID_Start=t}', "");
Expect(0, 195102, '\p{Is_XID_Start=t}', "");
Expect(1, 195102, '\p{^Is_XID_Start=t}', "");
Expect(1, 195102, '\P{Is_XID_Start=t}', "");
Expect(0, 195102, '\P{^Is_XID_Start=t}', "");
Error('\p{Is_XIDS: /a/ true}');
Error('\P{Is_XIDS: /a/ true}');
Expect(1, 195101, '\p{Is_XIDS:true}', "");
Expect(0, 195101, '\p{^Is_XIDS:true}', "");
Expect(0, 195101, '\P{Is_XIDS:true}', "");
Expect(1, 195101, '\P{^Is_XIDS:true}', "");
Expect(0, 195102, '\p{Is_XIDS:true}', "");
Expect(1, 195102, '\p{^Is_XIDS:true}', "");
Expect(1, 195102, '\P{Is_XIDS:true}', "");
Expect(0, 195102, '\P{^Is_XIDS:true}', "");
Expect(1, 195101, '\p{Is_XIDS:  TRUE}', "");
Expect(0, 195101, '\p{^Is_XIDS:  TRUE}', "");
Expect(0, 195101, '\P{Is_XIDS:  TRUE}', "");
Expect(1, 195101, '\P{^Is_XIDS:  TRUE}', "");
Expect(0, 195102, '\p{Is_XIDS:  TRUE}', "");
Expect(1, 195102, '\p{^Is_XIDS:  TRUE}', "");
Expect(1, 195102, '\P{Is_XIDS:  TRUE}', "");
Expect(0, 195102, '\P{^Is_XIDS:  TRUE}', "");
Error('\p{Expands_On_NFC=No}');
Error('\P{Expands_On_NFC=No}');
Error('\p{XO_NFC=N}');
Error('\P{XO_NFC=N}');
Error('\p{Is_Expands_On_NFC:	F}');
Error('\P{Is_Expands_On_NFC:	F}');
Error('\p{Is_XO_NFC=False}');
Error('\P{Is_XO_NFC=False}');
Error('\p{Expands_On_NFC=Yes}');
Error('\P{Expands_On_NFC=Yes}');
Error('\p{XO_NFC=Y}');
Error('\P{XO_NFC=Y}');
Error('\p{Is_Expands_On_NFC=T}');
Error('\P{Is_Expands_On_NFC=T}');
Error('\p{Is_XO_NFC=True}');
Error('\P{Is_XO_NFC=True}');
Error('\p{Expands_On_NFD: No}');
Error('\P{Expands_On_NFD: No}');
Error('\p{XO_NFD=N}');
Error('\P{XO_NFD=N}');
Error('\p{Is_Expands_On_NFD=F}');
Error('\P{Is_Expands_On_NFD=F}');
Error('\p{Is_XO_NFD=False}');
Error('\P{Is_XO_NFD=False}');
Error('\p{Expands_On_NFD:Yes}');
Error('\P{Expands_On_NFD:Yes}');
Error('\p{XO_NFD:	Y}');
Error('\P{XO_NFD:	Y}');
Error('\p{Is_Expands_On_NFD=T}');
Error('\P{Is_Expands_On_NFD=T}');
Error('\p{Is_XO_NFD=True}');
Error('\P{Is_XO_NFD=True}');
Error('\p{Expands_On_NFKC=No}');
Error('\P{Expands_On_NFKC=No}');
Error('\p{XO_NFKC=N}');
Error('\P{XO_NFKC=N}');
Error('\p{Is_Expands_On_NFKC=F}');
Error('\P{Is_Expands_On_NFKC=F}');
Error('\p{Is_XO_NFKC=False}');
Error('\P{Is_XO_NFKC=False}');
Error('\p{Expands_On_NFKC=Yes}');
Error('\P{Expands_On_NFKC=Yes}');
Error('\p{XO_NFKC=Y}');
Error('\P{XO_NFKC=Y}');
Error('\p{Is_Expands_On_NFKC=T}');
Error('\P{Is_Expands_On_NFKC=T}');
Error('\p{Is_XO_NFKC=True}');
Error('\P{Is_XO_NFKC=True}');
Error('\p{Expands_On_NFKD=No}');
Error('\P{Expands_On_NFKD=No}');
Error('\p{XO_NFKD: N}');
Error('\P{XO_NFKD: N}');
Error('\p{Is_Expands_On_NFKD=F}');
Error('\P{Is_Expands_On_NFKD=F}');
Error('\p{Is_XO_NFKD:	False}');
Error('\P{Is_XO_NFKD:	False}');
Error('\p{Expands_On_NFKD=Yes}');
Error('\P{Expands_On_NFKD=Yes}');
Error('\p{XO_NFKD=Y}');
Error('\P{XO_NFKD=Y}');
Error('\p{Is_Expands_On_NFKD:	T}');
Error('\P{Is_Expands_On_NFKD:	T}');
Error('\p{Is_XO_NFKD=True}');
Error('\P{Is_XO_NFKD=True}');
Error('\p{Age=:= -V1_1}');
Error('\P{Age=:= -V1_1}');
Expect(1, 65533, '\p{Age:v11}', "");
Expect(0, 65533, '\p{^Age:v11}', "");
Expect(0, 65533, '\P{Age:v11}', "");
Expect(1, 65533, '\P{^Age:v11}', "");
Expect(0, 65536, '\p{Age:v11}', "");
Expect(1, 65536, '\p{^Age:v11}', "");
Expect(1, 65536, '\P{Age:v11}', "");
Expect(0, 65536, '\P{^Age:v11}', "");
Expect(1, 65533, '\p{Age=_-V1_1}', "");
Expect(0, 65533, '\p{^Age=_-V1_1}', "");
Expect(0, 65533, '\P{Age=_-V1_1}', "");
Expect(1, 65533, '\P{^Age=_-V1_1}', "");
Expect(0, 65536, '\p{Age=_-V1_1}', "");
Expect(1, 65536, '\p{^Age=_-V1_1}', "");
Expect(1, 65536, '\P{Age=_-V1_1}', "");
Expect(0, 65536, '\P{^Age=_-V1_1}', "");
Error('\p{Is_Age=:=-00_00_00_01.1}');
Error('\P{Is_Age=:=-00_00_00_01.1}');
Expect(1, 65533, '\p{Is_Age=0000000001.1}', "");
Expect(0, 65533, '\p{^Is_Age=0000000001.1}', "");
Expect(0, 65533, '\P{Is_Age=0000000001.1}', "");
Expect(1, 65533, '\P{^Is_Age=0000000001.1}', "");
Expect(0, 65536, '\p{Is_Age=0000000001.1}', "");
Expect(1, 65536, '\p{^Is_Age=0000000001.1}', "");
Expect(1, 65536, '\P{Is_Age=0000000001.1}', "");
Expect(0, 65536, '\P{^Is_Age=0000000001.1}', "");
Error('\p{Age=-/a/V2_0}');
Error('\P{Age=-/a/V2_0}');
Expect(1, 983040, '\p{Age=v20}', "");
Expect(0, 983040, '\p{^Age=v20}', "");
Expect(0, 983040, '\P{Age=v20}', "");
Expect(1, 983040, '\P{^Age=v20}', "");
Expect(0, 983037, '\p{Age=v20}', "");
Expect(1, 983037, '\p{^Age=v20}', "");
Expect(1, 983037, '\P{Age=v20}', "");
Expect(0, 983037, '\P{^Age=v20}', "");
Expect(1, 983040, '\p{Age=	_v2_0}', "");
Expect(0, 983040, '\p{^Age=	_v2_0}', "");
Expect(0, 983040, '\P{Age=	_v2_0}', "");
Expect(1, 983040, '\P{^Age=	_v2_0}', "");
Expect(0, 983037, '\p{Age=	_v2_0}', "");
Expect(1, 983037, '\p{^Age=	_v2_0}', "");
Expect(1, 983037, '\P{Age=	_v2_0}', "");
Expect(0, 983037, '\P{^Age=	_v2_0}', "");
Error('\p{Is_Age: _	0000000002.0/a/}');
Error('\P{Is_Age: _	0000000002.0/a/}');
Expect(1, 983040, '\p{Is_Age=2.0}', "");
Expect(0, 983040, '\p{^Is_Age=2.0}', "");
Expect(0, 983040, '\P{Is_Age=2.0}', "");
Expect(1, 983040, '\P{^Is_Age=2.0}', "");
Expect(0, 983037, '\p{Is_Age=2.0}', "");
Expect(1, 983037, '\p{^Is_Age=2.0}', "");
Expect(1, 983037, '\P{Is_Age=2.0}', "");
Expect(0, 983037, '\P{^Is_Age=2.0}', "");
Error('\p{Age=_/a/V2_1}');
Error('\P{Age=_/a/V2_1}');
Expect(1, 65532, '\p{Age=v21}', "");
Expect(0, 65532, '\p{^Age=v21}', "");
Expect(0, 65532, '\P{Age=v21}', "");
Expect(1, 65532, '\P{^Age=v21}', "");
Expect(0, 65533, '\p{Age=v21}', "");
Expect(1, 65533, '\p{^Age=v21}', "");
Expect(1, 65533, '\P{Age=v21}', "");
Expect(0, 65533, '\P{^Age=v21}', "");
Expect(1, 65532, '\p{Age=-V2_1}', "");
Expect(0, 65532, '\p{^Age=-V2_1}', "");
Expect(0, 65532, '\P{Age=-V2_1}', "");
Expect(1, 65532, '\P{^Age=-V2_1}', "");
Expect(0, 65533, '\p{Age=-V2_1}', "");
Expect(1, 65533, '\p{^Age=-V2_1}', "");
Expect(1, 65533, '\P{Age=-V2_1}', "");
Expect(0, 65533, '\P{^Age=-V2_1}', "");
Error('\p{Is_Age= 	0002.1/a/}');
Error('\P{Is_Age= 	0002.1/a/}');
Expect(1, 65532, '\p{Is_Age=00_2.1}', "");
Expect(0, 65532, '\p{^Is_Age=00_2.1}', "");
Expect(0, 65532, '\P{Is_Age=00_2.1}', "");
Expect(1, 65532, '\P{^Is_Age=00_2.1}', "");
Expect(0, 65533, '\p{Is_Age=00_2.1}', "");
Expect(1, 65533, '\p{^Is_Age=00_2.1}', "");
Expect(1, 65533, '\P{Is_Age=00_2.1}', "");
Expect(0, 65533, '\P{^Is_Age=00_2.1}', "");
Error('\p{Age=	:=V3_0}');
Error('\P{Age=	:=V3_0}');
Expect(1, 65531, '\p{Age=v30}', "");
Expect(0, 65531, '\p{^Age=v30}', "");
Expect(0, 65531, '\P{Age=v30}', "");
Expect(1, 65531, '\P{^Age=v30}', "");
Expect(0, 65532, '\p{Age=v30}', "");
Expect(1, 65532, '\p{^Age=v30}', "");
Expect(1, 65532, '\P{Age=v30}', "");
Expect(0, 65532, '\P{^Age=v30}', "");
Expect(1, 65531, '\p{Age=		V3_0}', "");
Expect(0, 65531, '\p{^Age=		V3_0}', "");
Expect(0, 65531, '\P{Age=		V3_0}', "");
Expect(1, 65531, '\P{^Age=		V3_0}', "");
Expect(0, 65532, '\p{Age=		V3_0}', "");
Expect(1, 65532, '\p{^Age=		V3_0}', "");
Expect(1, 65532, '\P{Age=		V3_0}', "");
Expect(0, 65532, '\P{^Age=		V3_0}', "");
Error('\p{Is_Age=__0_3.0/a/}');
Error('\P{Is_Age=__0_3.0/a/}');
Expect(1, 65531, '\p{Is_Age=+0_3.0}', "");
Expect(0, 65531, '\p{^Is_Age=+0_3.0}', "");
Expect(0, 65531, '\P{Is_Age=+0_3.0}', "");
Expect(1, 65531, '\P{^Is_Age=+0_3.0}', "");
Expect(0, 65532, '\p{Is_Age=+0_3.0}', "");
Expect(1, 65532, '\p{^Is_Age=+0_3.0}', "");
Expect(1, 65532, '\P{Is_Age=+0_3.0}', "");
Expect(0, 65532, '\P{^Is_Age=+0_3.0}', "");
Error('\p{Age=_/a/V3_1}');
Error('\P{Age=_/a/V3_1}');
Expect(1, 917631, '\p{Age=v31}', "");
Expect(0, 917631, '\p{^Age=v31}', "");
Expect(0, 917631, '\P{Age=v31}', "");
Expect(1, 917631, '\P{^Age=v31}', "");
Expect(0, 917632, '\p{Age=v31}', "");
Expect(1, 917632, '\p{^Age=v31}', "");
Expect(1, 917632, '\P{Age=v31}', "");
Expect(0, 917632, '\P{^Age=v31}', "");
Expect(1, 917631, '\p{Age= V3_1}', "");
Expect(0, 917631, '\p{^Age= V3_1}', "");
Expect(0, 917631, '\P{Age= V3_1}', "");
Expect(1, 917631, '\P{^Age= V3_1}', "");
Expect(0, 917632, '\p{Age= V3_1}', "");
Expect(1, 917632, '\p{^Age= V3_1}', "");
Expect(1, 917632, '\P{Age= V3_1}', "");
Expect(0, 917632, '\P{^Age= V3_1}', "");
Error('\p{Is_Age=_-00_3.1/a/}');
Error('\P{Is_Age=_-00_3.1/a/}');
Expect(1, 917631, '\p{Is_Age=+00_00_00_03.1}', "");
Expect(0, 917631, '\p{^Is_Age=+00_00_00_03.1}', "");
Expect(0, 917631, '\P{Is_Age=+00_00_00_03.1}', "");
Expect(1, 917631, '\P{^Is_Age=+00_00_00_03.1}', "");
Expect(0, 917632, '\p{Is_Age=+00_00_00_03.1}', "");
Expect(1, 917632, '\p{^Is_Age=+00_00_00_03.1}', "");
Expect(1, 917632, '\P{Is_Age=+00_00_00_03.1}', "");
Expect(0, 917632, '\P{^Is_Age=+00_00_00_03.1}', "");
Error('\p{Age=:=	V3_2}');
Error('\P{Age=:=	V3_2}');
Expect(1, 65376, '\p{Age=v32}', "");
Expect(0, 65376, '\p{^Age=v32}', "");
Expect(0, 65376, '\P{Age=v32}', "");
Expect(1, 65376, '\P{^Age=v32}', "");
Expect(0, 65377, '\p{Age=v32}', "");
Expect(1, 65377, '\p{^Age=v32}', "");
Expect(1, 65377, '\P{Age=v32}', "");
Expect(0, 65377, '\P{^Age=v32}', "");
Expect(1, 65376, '\p{Age= -v3_2}', "");
Expect(0, 65376, '\p{^Age= -v3_2}', "");
Expect(0, 65376, '\P{Age= -v3_2}', "");
Expect(1, 65376, '\P{^Age= -v3_2}', "");
Expect(0, 65377, '\p{Age= -v3_2}', "");
Expect(1, 65377, '\p{^Age= -v3_2}', "");
Expect(1, 65377, '\P{Age= -v3_2}', "");
Expect(0, 65377, '\P{^Age= -v3_2}', "");
Error('\p{Is_Age: 		+0003.2/a/}');
Error('\P{Is_Age: 		+0003.2/a/}');
Expect(1, 65376, '\p{Is_Age=+0_0_0_0_0_0_03.2}', "");
Expect(0, 65376, '\p{^Is_Age=+0_0_0_0_0_0_03.2}', "");
Expect(0, 65376, '\P{Is_Age=+0_0_0_0_0_0_03.2}', "");
Expect(1, 65376, '\P{^Is_Age=+0_0_0_0_0_0_03.2}', "");
Expect(0, 65377, '\p{Is_Age=+0_0_0_0_0_0_03.2}', "");
Expect(1, 65377, '\p{^Is_Age=+0_0_0_0_0_0_03.2}', "");
Expect(1, 65377, '\P{Is_Age=+0_0_0_0_0_0_03.2}', "");
Expect(0, 65377, '\P{^Is_Age=+0_0_0_0_0_0_03.2}', "");
Error('\p{Age=-:=V4_0}');
Error('\P{Age=-:=V4_0}');
Expect(1, 917999, '\p{Age=v40}', "");
Expect(0, 917999, '\p{^Age=v40}', "");
Expect(0, 917999, '\P{Age=v40}', "");
Expect(1, 917999, '\P{^Age=v40}', "");
Expect(0, 918000, '\p{Age=v40}', "");
Expect(1, 918000, '\p{^Age=v40}', "");
Expect(1, 918000, '\P{Age=v40}', "");
Expect(0, 918000, '\P{^Age=v40}', "");
Expect(1, 917999, '\p{Age:  	V4_0}', "");
Expect(0, 917999, '\p{^Age:  	V4_0}', "");
Expect(0, 917999, '\P{Age:  	V4_0}', "");
Expect(1, 917999, '\P{^Age:  	V4_0}', "");
Expect(0, 918000, '\p{Age:  	V4_0}', "");
Expect(1, 918000, '\p{^Age:  	V4_0}', "");
Expect(1, 918000, '\P{Age:  	V4_0}', "");
Expect(0, 918000, '\P{^Age:  	V4_0}', "");
Error('\p{Is_Age=/a/ 000_4.0}');
Error('\P{Is_Age=/a/ 000_4.0}');
Expect(1, 917999, '\p{Is_Age=0004.0}', "");
Expect(0, 917999, '\p{^Is_Age=0004.0}', "");
Expect(0, 917999, '\P{Is_Age=0004.0}', "");
Expect(1, 917999, '\P{^Is_Age=0004.0}', "");
Expect(0, 918000, '\p{Is_Age=0004.0}', "");
Expect(1, 918000, '\p{^Is_Age=0004.0}', "");
Expect(1, 918000, '\P{Is_Age=0004.0}', "");
Expect(0, 918000, '\P{^Is_Age=0004.0}', "");
Error('\p{Age=:=-V4_1}');
Error('\P{Age=:=-V4_1}');
Expect(1, 120485, '\p{Age=v41}', "");
Expect(0, 120485, '\p{^Age=v41}', "");
Expect(0, 120485, '\P{Age=v41}', "");
Expect(1, 120485, '\P{^Age=v41}', "");
Expect(0, 120486, '\p{Age=v41}', "");
Expect(1, 120486, '\p{^Age=v41}', "");
Expect(1, 120486, '\P{Age=v41}', "");
Expect(0, 120486, '\P{^Age=v41}', "");
Expect(1, 120485, '\p{Age=__v4_1}', "");
Expect(0, 120485, '\p{^Age=__v4_1}', "");
Expect(0, 120485, '\P{Age=__v4_1}', "");
Expect(1, 120485, '\P{^Age=__v4_1}', "");
Expect(0, 120486, '\p{Age=__v4_1}', "");
Expect(1, 120486, '\p{^Age=__v4_1}', "");
Expect(1, 120486, '\P{Age=__v4_1}', "");
Expect(0, 120486, '\P{^Age=__v4_1}', "");
Error('\p{Is_Age:-/a/0_0_0_0_0_0_0_0_04.1}');
Error('\P{Is_Age:-/a/0_0_0_0_0_0_0_0_04.1}');
Expect(1, 120485, '\p{Is_Age: 4.1}', "");
Expect(0, 120485, '\p{^Is_Age: 4.1}', "");
Expect(0, 120485, '\P{Is_Age: 4.1}', "");
Expect(1, 120485, '\P{^Is_Age: 4.1}', "");
Expect(0, 120486, '\p{Is_Age: 4.1}', "");
Expect(1, 120486, '\p{^Is_Age: 4.1}', "");
Expect(1, 120486, '\P{Is_Age: 4.1}', "");
Expect(0, 120486, '\P{^Is_Age: 4.1}', "");
Error('\p{Age=_	V5_0/a/}');
Error('\P{Age=_	V5_0/a/}');
Expect(1, 120779, '\p{Age=v50}', "");
Expect(0, 120779, '\p{^Age=v50}', "");
Expect(0, 120779, '\P{Age=v50}', "");
Expect(1, 120779, '\P{^Age=v50}', "");
Expect(0, 120780, '\p{Age=v50}', "");
Expect(1, 120780, '\p{^Age=v50}', "");
Expect(1, 120780, '\P{Age=v50}', "");
Expect(0, 120780, '\P{^Age=v50}', "");
Expect(1, 120779, '\p{Age=	V5_0}', "");
Expect(0, 120779, '\p{^Age=	V5_0}', "");
Expect(0, 120779, '\P{Age=	V5_0}', "");
Expect(1, 120779, '\P{^Age=	V5_0}', "");
Expect(0, 120780, '\p{Age=	V5_0}', "");
Expect(1, 120780, '\p{^Age=	V5_0}', "");
Expect(1, 120780, '\P{Age=	V5_0}', "");
Expect(0, 120780, '\P{^Age=	V5_0}', "");
Error('\p{Is_Age=:=-	+00005.0}');
Error('\P{Is_Age=:=-	+00005.0}');
Expect(1, 120779, '\p{Is_Age=5.0}', "");
Expect(0, 120779, '\p{^Is_Age=5.0}', "");
Expect(0, 120779, '\P{Is_Age=5.0}', "");
Expect(1, 120779, '\P{^Is_Age=5.0}', "");
Expect(0, 120780, '\p{Is_Age=5.0}', "");
Expect(1, 120780, '\p{^Is_Age=5.0}', "");
Expect(1, 120780, '\P{Is_Age=5.0}', "");
Expect(0, 120780, '\P{^Is_Age=5.0}', "");
Error('\p{Age=  V5_1:=}');
Error('\P{Age=  V5_1:=}');
Expect(1, 127123, '\p{Age=v51}', "");
Expect(0, 127123, '\p{^Age=v51}', "");
Expect(0, 127123, '\P{Age=v51}', "");
Expect(1, 127123, '\P{^Age=v51}', "");
Expect(0, 127124, '\p{Age=v51}', "");
Expect(1, 127124, '\p{^Age=v51}', "");
Expect(1, 127124, '\P{Age=v51}', "");
Expect(0, 127124, '\P{^Age=v51}', "");
Expect(1, 127123, '\p{Age=- v5_1}', "");
Expect(0, 127123, '\p{^Age=- v5_1}', "");
Expect(0, 127123, '\P{Age=- v5_1}', "");
Expect(1, 127123, '\P{^Age=- v5_1}', "");
Expect(0, 127124, '\p{Age=- v5_1}', "");
Expect(1, 127124, '\p{^Age=- v5_1}', "");
Expect(1, 127124, '\P{Age=- v5_1}', "");
Expect(0, 127124, '\P{^Age=- v5_1}', "");
Error('\p{Is_Age= /a/+005.1}');
Error('\P{Is_Age= /a/+005.1}');
Expect(1, 127123, '\p{Is_Age=+000000_5.1}', "");
Expect(0, 127123, '\p{^Is_Age=+000000_5.1}', "");
Expect(0, 127123, '\P{Is_Age=+000000_5.1}', "");
Expect(1, 127123, '\P{^Is_Age=+000000_5.1}', "");
Expect(0, 127124, '\p{Is_Age=+000000_5.1}', "");
Expect(1, 127124, '\p{^Is_Age=+000000_5.1}', "");
Expect(1, 127124, '\P{Is_Age=+000000_5.1}', "");
Expect(0, 127124, '\P{^Is_Age=+000000_5.1}', "");
Error('\p{Age=/a/  V5_2}');
Error('\P{Age=/a/  V5_2}');
Expect(1, 177972, '\p{Age=v52}', "");
Expect(0, 177972, '\p{^Age=v52}', "");
Expect(0, 177972, '\P{Age=v52}', "");
Expect(1, 177972, '\P{^Age=v52}', "");
Expect(0, 177973, '\p{Age=v52}', "");
Expect(1, 177973, '\p{^Age=v52}', "");
Expect(1, 177973, '\P{Age=v52}', "");
Expect(0, 177973, '\P{^Age=v52}', "");
Expect(1, 177972, '\p{Age=		v5_2}', "");
Expect(0, 177972, '\p{^Age=		v5_2}', "");
Expect(0, 177972, '\P{Age=		v5_2}', "");
Expect(1, 177972, '\P{^Age=		v5_2}', "");
Expect(0, 177973, '\p{Age=		v5_2}', "");
Expect(1, 177973, '\p{^Age=		v5_2}', "");
Expect(1, 177973, '\P{Age=		v5_2}', "");
Expect(0, 177973, '\P{^Age=		v5_2}', "");
Error('\p{Is_Age=:=		0_0_0_0_05.2}');
Error('\P{Is_Age=:=		0_0_0_0_05.2}');
Expect(1, 177972, '\p{Is_Age=00_00_00_5.2}', "");
Expect(0, 177972, '\p{^Is_Age=00_00_00_5.2}', "");
Expect(0, 177972, '\P{Is_Age=00_00_00_5.2}', "");
Expect(1, 177972, '\P{^Is_Age=00_00_00_5.2}', "");
Expect(0, 177973, '\p{Is_Age=00_00_00_5.2}', "");
Expect(1, 177973, '\p{^Is_Age=00_00_00_5.2}', "");
Expect(1, 177973, '\P{Is_Age=00_00_00_5.2}', "");
Expect(0, 177973, '\P{^Is_Age=00_00_00_5.2}', "");
Error('\p{Age=_/a/V6_0}');
Error('\P{Age=_/a/V6_0}');
Expect(1, 178205, '\p{Age=v60}', "");
Expect(0, 178205, '\p{^Age=v60}', "");
Expect(0, 178205, '\P{Age=v60}', "");
Expect(1, 178205, '\P{^Age=v60}', "");
Expect(0, 178206, '\p{Age=v60}', "");
Expect(1, 178206, '\p{^Age=v60}', "");
Expect(1, 178206, '\P{Age=v60}', "");
Expect(0, 178206, '\P{^Age=v60}', "");
Expect(1, 178205, '\p{Age=_-V6_0}', "");
Expect(0, 178205, '\p{^Age=_-V6_0}', "");
Expect(0, 178205, '\P{Age=_-V6_0}', "");
Expect(1, 178205, '\P{^Age=_-V6_0}', "");
Expect(0, 178206, '\p{Age=_-V6_0}', "");
Expect(1, 178206, '\p{^Age=_-V6_0}', "");
Expect(1, 178206, '\P{Age=_-V6_0}', "");
Expect(0, 178206, '\P{^Age=_-V6_0}', "");
Error('\p{Is_Age=_:=006.0}');
Error('\P{Is_Age=_:=006.0}');
Expect(1, 178205, '\p{Is_Age=006.0}', "");
Expect(0, 178205, '\p{^Is_Age=006.0}', "");
Expect(0, 178205, '\P{Is_Age=006.0}', "");
Expect(1, 178205, '\P{^Is_Age=006.0}', "");
Expect(0, 178206, '\p{Is_Age=006.0}', "");
Expect(1, 178206, '\p{^Is_Age=006.0}', "");
Expect(1, 178206, '\P{Is_Age=006.0}', "");
Expect(0, 178206, '\P{^Is_Age=006.0}', "");
Error('\p{Age:		/a/v6_1}');
Error('\P{Age:		/a/v6_1}');
Expect(1, 128564, '\p{Age=v61}', "");
Expect(0, 128564, '\p{^Age=v61}', "");
Expect(0, 128564, '\P{Age=v61}', "");
Expect(1, 128564, '\P{^Age=v61}', "");
Expect(0, 128565, '\p{Age=v61}', "");
Expect(1, 128565, '\p{^Age=v61}', "");
Expect(1, 128565, '\P{Age=v61}', "");
Expect(0, 128565, '\P{^Age=v61}', "");
Expect(1, 128564, '\p{Age:--V6_1}', "");
Expect(0, 128564, '\p{^Age:--V6_1}', "");
Expect(0, 128564, '\P{Age:--V6_1}', "");
Expect(1, 128564, '\P{^Age:--V6_1}', "");
Expect(0, 128565, '\p{Age:--V6_1}', "");
Expect(1, 128565, '\p{^Age:--V6_1}', "");
Expect(1, 128565, '\P{Age:--V6_1}', "");
Expect(0, 128565, '\P{^Age:--V6_1}', "");
Error('\p{Is_Age=:=+0_0_0_0_0_00006.1}');
Error('\P{Is_Age=:=+0_0_0_0_0_00006.1}');
Expect(1, 128564, '\p{Is_Age=+0000006.1}', "");
Expect(0, 128564, '\p{^Is_Age=+0000006.1}', "");
Expect(0, 128564, '\P{Is_Age=+0000006.1}', "");
Expect(1, 128564, '\P{^Is_Age=+0000006.1}', "");
Expect(0, 128565, '\p{Is_Age=+0000006.1}', "");
Expect(1, 128565, '\p{^Is_Age=+0000006.1}', "");
Expect(1, 128565, '\P{Is_Age=+0000006.1}', "");
Expect(0, 128565, '\P{^Is_Age=+0000006.1}', "");
Error('\p{Age= /a/V6_2}');
Error('\P{Age= /a/V6_2}');
Expect(1, 8378, '\p{Age: v62}', "");
Expect(0, 8378, '\p{^Age: v62}', "");
Expect(0, 8378, '\P{Age: v62}', "");
Expect(1, 8378, '\P{^Age: v62}', "");
Expect(0, 8379, '\p{Age: v62}', "");
Expect(1, 8379, '\p{^Age: v62}', "");
Expect(1, 8379, '\P{Age: v62}', "");
Expect(0, 8379, '\P{^Age: v62}', "");
Expect(1, 8378, '\p{Age=_V6_2}', "");
Expect(0, 8378, '\p{^Age=_V6_2}', "");
Expect(0, 8378, '\P{Age=_V6_2}', "");
Expect(1, 8378, '\P{^Age=_V6_2}', "");
Expect(0, 8379, '\p{Age=_V6_2}', "");
Expect(1, 8379, '\p{^Age=_V6_2}', "");
Expect(1, 8379, '\P{Age=_V6_2}', "");
Expect(0, 8379, '\P{^Age=_V6_2}', "");
Error('\p{Is_Age: /a/0_0_0_0_0_06.2}');
Error('\P{Is_Age: /a/0_0_0_0_0_06.2}');
Expect(1, 8378, '\p{Is_Age=0_0_0_0_0_00006.2}', "");
Expect(0, 8378, '\p{^Is_Age=0_0_0_0_0_00006.2}', "");
Expect(0, 8378, '\P{Is_Age=0_0_0_0_0_00006.2}', "");
Expect(1, 8378, '\P{^Is_Age=0_0_0_0_0_00006.2}', "");
Expect(0, 8379, '\p{Is_Age=0_0_0_0_0_00006.2}', "");
Expect(1, 8379, '\p{^Is_Age=0_0_0_0_0_00006.2}', "");
Expect(1, 8379, '\P{Is_Age=0_0_0_0_0_00006.2}', "");
Expect(0, 8379, '\P{^Is_Age=0_0_0_0_0_00006.2}', "");
Error('\p{Age=-:=V6_3}');
Error('\P{Age=-:=V6_3}');
Expect(1, 8297, '\p{Age=v63}', "");
Expect(0, 8297, '\p{^Age=v63}', "");
Expect(0, 8297, '\P{Age=v63}', "");
Expect(1, 8297, '\P{^Age=v63}', "");
Expect(0, 8298, '\p{Age=v63}', "");
Expect(1, 8298, '\p{^Age=v63}', "");
Expect(1, 8298, '\P{Age=v63}', "");
Expect(0, 8298, '\P{^Age=v63}', "");
Expect(1, 8297, '\p{Age=	 V6_3}', "");
Expect(0, 8297, '\p{^Age=	 V6_3}', "");
Expect(0, 8297, '\P{Age=	 V6_3}', "");
Expect(1, 8297, '\P{^Age=	 V6_3}', "");
Expect(0, 8298, '\p{Age=	 V6_3}', "");
Expect(1, 8298, '\p{^Age=	 V6_3}', "");
Expect(1, 8298, '\P{Age=	 V6_3}', "");
Expect(0, 8298, '\P{^Age=	 V6_3}', "");
Error('\p{Is_Age=_-00_6.3:=}');
Error('\P{Is_Age=_-00_6.3:=}');
Expect(1, 8297, '\p{Is_Age=00_00_00_00_6.3}', "");
Expect(0, 8297, '\p{^Is_Age=00_00_00_00_6.3}', "");
Expect(0, 8297, '\P{Is_Age=00_00_00_00_6.3}', "");
Expect(1, 8297, '\P{^Is_Age=00_00_00_00_6.3}', "");
Expect(0, 8298, '\p{Is_Age=00_00_00_00_6.3}', "");
Expect(1, 8298, '\p{^Is_Age=00_00_00_00_6.3}', "");
Expect(1, 8298, '\P{Is_Age=00_00_00_00_6.3}', "");
Expect(0, 8298, '\P{^Is_Age=00_00_00_00_6.3}', "");
Error('\p{Age=/a/_	Unassigned}');
Error('\P{Age=/a/_	Unassigned}');
Expect(1, 983037, '\p{Age=unassigned}', "");
Expect(0, 983037, '\p{^Age=unassigned}', "");
Expect(0, 983037, '\P{Age=unassigned}', "");
Expect(1, 983037, '\P{^Age=unassigned}', "");
Expect(0, 983040, '\p{Age=unassigned}', "");
Expect(1, 983040, '\p{^Age=unassigned}', "");
Expect(1, 983040, '\P{Age=unassigned}', "");
Expect(0, 983040, '\P{^Age=unassigned}', "");
Expect(1, 983037, '\p{Age= unassigned}', "");
Expect(0, 983037, '\p{^Age= unassigned}', "");
Expect(0, 983037, '\P{Age= unassigned}', "");
Expect(1, 983037, '\P{^Age= unassigned}', "");
Expect(0, 983040, '\p{Age= unassigned}', "");
Expect(1, 983040, '\p{^Age= unassigned}', "");
Expect(1, 983040, '\P{Age= unassigned}', "");
Expect(0, 983040, '\P{^Age= unassigned}', "");
Error('\p{Is_Age=		NA/a/}');
Error('\P{Is_Age=		NA/a/}');
Expect(1, 983037, '\p{Is_Age=na}', "");
Expect(0, 983037, '\p{^Is_Age=na}', "");
Expect(0, 983037, '\P{Is_Age=na}', "");
Expect(1, 983037, '\P{^Is_Age=na}', "");
Expect(0, 983040, '\p{Is_Age=na}', "");
Expect(1, 983040, '\p{^Is_Age=na}', "");
Expect(1, 983040, '\P{Is_Age=na}', "");
Expect(0, 983040, '\P{^Is_Age=na}', "");
Expect(1, 983037, '\p{Is_Age=		NA}', "");
Expect(0, 983037, '\p{^Is_Age=		NA}', "");
Expect(0, 983037, '\P{Is_Age=		NA}', "");
Expect(1, 983037, '\P{^Is_Age=		NA}', "");
Expect(0, 983040, '\p{Is_Age=		NA}', "");
Expect(1, 983040, '\p{^Is_Age=		NA}', "");
Expect(1, 983040, '\P{Is_Age=		NA}', "");
Expect(0, 983040, '\P{^Is_Age=		NA}', "");
Error('\p{Bidi_Class=-:=ARABIC_Letter}');
Error('\P{Bidi_Class=-:=ARABIC_Letter}');
Expect(1, 126719, '\p{Bidi_Class:   arabicletter}', "");
Expect(0, 126719, '\p{^Bidi_Class:   arabicletter}', "");
Expect(0, 126719, '\P{Bidi_Class:   arabicletter}', "");
Expect(1, 126719, '\P{^Bidi_Class:   arabicletter}', "");
Expect(0, 126720, '\p{Bidi_Class:   arabicletter}', "");
Expect(1, 126720, '\p{^Bidi_Class:   arabicletter}', "");
Expect(1, 126720, '\P{Bidi_Class:   arabicletter}', "");
Expect(0, 126720, '\P{^Bidi_Class:   arabicletter}', "");
Expect(1, 126719, '\p{Bidi_Class=_ARABIC_Letter}', "");
Expect(0, 126719, '\p{^Bidi_Class=_ARABIC_Letter}', "");
Expect(0, 126719, '\P{Bidi_Class=_ARABIC_Letter}', "");
Expect(1, 126719, '\P{^Bidi_Class=_ARABIC_Letter}', "");
Expect(0, 126720, '\p{Bidi_Class=_ARABIC_Letter}', "");
Expect(1, 126720, '\p{^Bidi_Class=_ARABIC_Letter}', "");
Expect(1, 126720, '\P{Bidi_Class=_ARABIC_Letter}', "");
Expect(0, 126720, '\P{^Bidi_Class=_ARABIC_Letter}', "");
Error('\p{Bc=	:=AL}');
Error('\P{Bc=	:=AL}');
Expect(1, 126719, '\p{Bc=al}', "");
Expect(0, 126719, '\p{^Bc=al}', "");
Expect(0, 126719, '\P{Bc=al}', "");
Expect(1, 126719, '\P{^Bc=al}', "");
Expect(0, 126720, '\p{Bc=al}', "");
Expect(1, 126720, '\p{^Bc=al}', "");
Expect(1, 126720, '\P{Bc=al}', "");
Expect(0, 126720, '\P{^Bc=al}', "");
Expect(1, 126719, '\p{Bc=	AL}', "");
Expect(0, 126719, '\p{^Bc=	AL}', "");
Expect(0, 126719, '\P{Bc=	AL}', "");
Expect(1, 126719, '\P{^Bc=	AL}', "");
Expect(0, 126720, '\p{Bc=	AL}', "");
Expect(1, 126720, '\p{^Bc=	AL}', "");
Expect(1, 126720, '\P{Bc=	AL}', "");
Expect(0, 126720, '\P{^Bc=	AL}', "");
Error('\p{Is_Bidi_Class=/a/	-Arabic_Letter}');
Error('\P{Is_Bidi_Class=/a/	-Arabic_Letter}');
Expect(1, 126719, '\p{Is_Bidi_Class=arabicletter}', "");
Expect(0, 126719, '\p{^Is_Bidi_Class=arabicletter}', "");
Expect(0, 126719, '\P{Is_Bidi_Class=arabicletter}', "");
Expect(1, 126719, '\P{^Is_Bidi_Class=arabicletter}', "");
Expect(0, 126720, '\p{Is_Bidi_Class=arabicletter}', "");
Expect(1, 126720, '\p{^Is_Bidi_Class=arabicletter}', "");
Expect(1, 126720, '\P{Is_Bidi_Class=arabicletter}', "");
Expect(0, 126720, '\P{^Is_Bidi_Class=arabicletter}', "");
Expect(1, 126719, '\p{Is_Bidi_Class=--arabic_Letter}', "");
Expect(0, 126719, '\p{^Is_Bidi_Class=--arabic_Letter}', "");
Expect(0, 126719, '\P{Is_Bidi_Class=--arabic_Letter}', "");
Expect(1, 126719, '\P{^Is_Bidi_Class=--arabic_Letter}', "");
Expect(0, 126720, '\p{Is_Bidi_Class=--arabic_Letter}', "");
Expect(1, 126720, '\p{^Is_Bidi_Class=--arabic_Letter}', "");
Expect(1, 126720, '\P{Is_Bidi_Class=--arabic_Letter}', "");
Expect(0, 126720, '\P{^Is_Bidi_Class=--arabic_Letter}', "");
Error('\p{Is_Bc:/a/AL}');
Error('\P{Is_Bc:/a/AL}');
Expect(1, 126719, '\p{Is_Bc=al}', "");
Expect(0, 126719, '\p{^Is_Bc=al}', "");
Expect(0, 126719, '\P{Is_Bc=al}', "");
Expect(1, 126719, '\P{^Is_Bc=al}', "");
Expect(0, 126720, '\p{Is_Bc=al}', "");
Expect(1, 126720, '\p{^Is_Bc=al}', "");
Expect(1, 126720, '\P{Is_Bc=al}', "");
Expect(0, 126720, '\P{^Is_Bc=al}', "");
Expect(1, 126719, '\p{Is_Bc=_-AL}', "");
Expect(0, 126719, '\p{^Is_Bc=_-AL}', "");
Expect(0, 126719, '\P{Is_Bc=_-AL}', "");
Expect(1, 126719, '\P{^Is_Bc=_-AL}', "");
Expect(0, 126720, '\p{Is_Bc=_-AL}', "");
Expect(1, 126720, '\p{^Is_Bc=_-AL}', "");
Expect(1, 126720, '\P{Is_Bc=_-AL}', "");
Expect(0, 126720, '\P{^Is_Bc=_-AL}', "");
Error('\p{Bidi_Class= /a/arabic_Number}');
Error('\P{Bidi_Class= /a/arabic_Number}');
Expect(1, 69246, '\p{Bidi_Class=arabicnumber}', "");
Expect(0, 69246, '\p{^Bidi_Class=arabicnumber}', "");
Expect(0, 69246, '\P{Bidi_Class=arabicnumber}', "");
Expect(1, 69246, '\P{^Bidi_Class=arabicnumber}', "");
Expect(0, 69247, '\p{Bidi_Class=arabicnumber}', "");
Expect(1, 69247, '\p{^Bidi_Class=arabicnumber}', "");
Expect(1, 69247, '\P{Bidi_Class=arabicnumber}', "");
Expect(0, 69247, '\P{^Bidi_Class=arabicnumber}', "");
Expect(1, 69246, '\p{Bidi_Class: 	arabic_Number}', "");
Expect(0, 69246, '\p{^Bidi_Class: 	arabic_Number}', "");
Expect(0, 69246, '\P{Bidi_Class: 	arabic_Number}', "");
Expect(1, 69246, '\P{^Bidi_Class: 	arabic_Number}', "");
Expect(0, 69247, '\p{Bidi_Class: 	arabic_Number}', "");
Expect(1, 69247, '\p{^Bidi_Class: 	arabic_Number}', "");
Expect(1, 69247, '\P{Bidi_Class: 	arabic_Number}', "");
Expect(0, 69247, '\P{^Bidi_Class: 	arabic_Number}', "");
Error('\p{Bc= 	an/a/}');
Error('\P{Bc= 	an/a/}');
Expect(1, 69246, '\p{Bc=an}', "");
Expect(0, 69246, '\p{^Bc=an}', "");
Expect(0, 69246, '\P{Bc=an}', "");
Expect(1, 69246, '\P{^Bc=an}', "");
Expect(0, 69247, '\p{Bc=an}', "");
Expect(1, 69247, '\p{^Bc=an}', "");
Expect(1, 69247, '\P{Bc=an}', "");
Expect(0, 69247, '\P{^Bc=an}', "");
Expect(1, 69246, '\p{Bc=AN}', "");
Expect(0, 69246, '\p{^Bc=AN}', "");
Expect(0, 69246, '\P{Bc=AN}', "");
Expect(1, 69246, '\P{^Bc=AN}', "");
Expect(0, 69247, '\p{Bc=AN}', "");
Expect(1, 69247, '\p{^Bc=AN}', "");
Expect(1, 69247, '\P{Bc=AN}', "");
Expect(0, 69247, '\P{^Bc=AN}', "");
Error('\p{Is_Bidi_Class=-/a/Arabic_NUMBER}');
Error('\P{Is_Bidi_Class=-/a/Arabic_NUMBER}');
Expect(1, 69246, '\p{Is_Bidi_Class=arabicnumber}', "");
Expect(0, 69246, '\p{^Is_Bidi_Class=arabicnumber}', "");
Expect(0, 69246, '\P{Is_Bidi_Class=arabicnumber}', "");
Expect(1, 69246, '\P{^Is_Bidi_Class=arabicnumber}', "");
Expect(0, 69247, '\p{Is_Bidi_Class=arabicnumber}', "");
Expect(1, 69247, '\p{^Is_Bidi_Class=arabicnumber}', "");
Expect(1, 69247, '\P{Is_Bidi_Class=arabicnumber}', "");
Expect(0, 69247, '\P{^Is_Bidi_Class=arabicnumber}', "");
Expect(1, 69246, '\p{Is_Bidi_Class=		Arabic_Number}', "");
Expect(0, 69246, '\p{^Is_Bidi_Class=		Arabic_Number}', "");
Expect(0, 69246, '\P{Is_Bidi_Class=		Arabic_Number}', "");
Expect(1, 69246, '\P{^Is_Bidi_Class=		Arabic_Number}', "");
Expect(0, 69247, '\p{Is_Bidi_Class=		Arabic_Number}', "");
Expect(1, 69247, '\p{^Is_Bidi_Class=		Arabic_Number}', "");
Expect(1, 69247, '\P{Is_Bidi_Class=		Arabic_Number}', "");
Expect(0, 69247, '\P{^Is_Bidi_Class=		Arabic_Number}', "");
Error('\p{Is_Bc=_:=AN}');
Error('\P{Is_Bc=_:=AN}');
Expect(1, 69246, '\p{Is_Bc=an}', "");
Expect(0, 69246, '\p{^Is_Bc=an}', "");
Expect(0, 69246, '\P{Is_Bc=an}', "");
Expect(1, 69246, '\P{^Is_Bc=an}', "");
Expect(0, 69247, '\p{Is_Bc=an}', "");
Expect(1, 69247, '\p{^Is_Bc=an}', "");
Expect(1, 69247, '\P{Is_Bc=an}', "");
Expect(0, 69247, '\P{^Is_Bc=an}', "");
Expect(1, 69246, '\p{Is_Bc=	 AN}', "");
Expect(0, 69246, '\p{^Is_Bc=	 AN}', "");
Expect(0, 69246, '\P{Is_Bc=	 AN}', "");
Expect(1, 69246, '\P{^Is_Bc=	 AN}', "");
Expect(0, 69247, '\p{Is_Bc=	 AN}', "");
Expect(1, 69247, '\p{^Is_Bc=	 AN}', "");
Expect(1, 69247, '\P{Is_Bc=	 AN}', "");
Expect(0, 69247, '\P{^Is_Bc=	 AN}', "");
Error('\p{Bidi_Class:	_Paragraph_Separator/a/}');
Error('\P{Bidi_Class:	_Paragraph_Separator/a/}');
Expect(1, 8233, '\p{Bidi_Class=paragraphseparator}', "");
Expect(0, 8233, '\p{^Bidi_Class=paragraphseparator}', "");
Expect(0, 8233, '\P{Bidi_Class=paragraphseparator}', "");
Expect(1, 8233, '\P{^Bidi_Class=paragraphseparator}', "");
Expect(0, 8234, '\p{Bidi_Class=paragraphseparator}', "");
Expect(1, 8234, '\p{^Bidi_Class=paragraphseparator}', "");
Expect(1, 8234, '\P{Bidi_Class=paragraphseparator}', "");
Expect(0, 8234, '\P{^Bidi_Class=paragraphseparator}', "");
Expect(1, 8233, '\p{Bidi_Class= PARAGRAPH_separator}', "");
Expect(0, 8233, '\p{^Bidi_Class= PARAGRAPH_separator}', "");
Expect(0, 8233, '\P{Bidi_Class= PARAGRAPH_separator}', "");
Expect(1, 8233, '\P{^Bidi_Class= PARAGRAPH_separator}', "");
Expect(0, 8234, '\p{Bidi_Class= PARAGRAPH_separator}', "");
Expect(1, 8234, '\p{^Bidi_Class= PARAGRAPH_separator}', "");
Expect(1, 8234, '\P{Bidi_Class= PARAGRAPH_separator}', "");
Expect(0, 8234, '\P{^Bidi_Class= PARAGRAPH_separator}', "");
Error('\p{Bc=/a/ 	b}');
Error('\P{Bc=/a/ 	b}');
Expect(1, 8233, '\p{Bc=b}', "");
Expect(0, 8233, '\p{^Bc=b}', "");
Expect(0, 8233, '\P{Bc=b}', "");
Expect(1, 8233, '\P{^Bc=b}', "");
Expect(0, 8234, '\p{Bc=b}', "");
Expect(1, 8234, '\p{^Bc=b}', "");
Expect(1, 8234, '\P{Bc=b}', "");
Expect(0, 8234, '\P{^Bc=b}', "");
Expect(1, 8233, '\p{Bc=	_B}', "");
Expect(0, 8233, '\p{^Bc=	_B}', "");
Expect(0, 8233, '\P{Bc=	_B}', "");
Expect(1, 8233, '\P{^Bc=	_B}', "");
Expect(0, 8234, '\p{Bc=	_B}', "");
Expect(1, 8234, '\p{^Bc=	_B}', "");
Expect(1, 8234, '\P{Bc=	_B}', "");
Expect(0, 8234, '\P{^Bc=	_B}', "");
Error('\p{Is_Bidi_Class=_-Paragraph_SEPARATOR/a/}');
Error('\P{Is_Bidi_Class=_-Paragraph_SEPARATOR/a/}');
Expect(1, 8233, '\p{Is_Bidi_Class=paragraphseparator}', "");
Expect(0, 8233, '\p{^Is_Bidi_Class=paragraphseparator}', "");
Expect(0, 8233, '\P{Is_Bidi_Class=paragraphseparator}', "");
Expect(1, 8233, '\P{^Is_Bidi_Class=paragraphseparator}', "");
Expect(0, 8234, '\p{Is_Bidi_Class=paragraphseparator}', "");
Expect(1, 8234, '\p{^Is_Bidi_Class=paragraphseparator}', "");
Expect(1, 8234, '\P{Is_Bidi_Class=paragraphseparator}', "");
Expect(0, 8234, '\P{^Is_Bidi_Class=paragraphseparator}', "");
Expect(1, 8233, '\p{Is_Bidi_Class=		paragraph_SEPARATOR}', "");
Expect(0, 8233, '\p{^Is_Bidi_Class=		paragraph_SEPARATOR}', "");
Expect(0, 8233, '\P{Is_Bidi_Class=		paragraph_SEPARATOR}', "");
Expect(1, 8233, '\P{^Is_Bidi_Class=		paragraph_SEPARATOR}', "");
Expect(0, 8234, '\p{Is_Bidi_Class=		paragraph_SEPARATOR}', "");
Expect(1, 8234, '\p{^Is_Bidi_Class=		paragraph_SEPARATOR}', "");
Expect(1, 8234, '\P{Is_Bidi_Class=		paragraph_SEPARATOR}', "");
Expect(0, 8234, '\P{^Is_Bidi_Class=		paragraph_SEPARATOR}', "");
Error('\p{Is_Bc=/a/	B}');
Error('\P{Is_Bc=/a/	B}');
Expect(1, 8233, '\p{Is_Bc=b}', "");
Expect(0, 8233, '\p{^Is_Bc=b}', "");
Expect(0, 8233, '\P{Is_Bc=b}', "");
Expect(1, 8233, '\P{^Is_Bc=b}', "");
Expect(0, 8234, '\p{Is_Bc=b}', "");
Expect(1, 8234, '\p{^Is_Bc=b}', "");
Expect(1, 8234, '\P{Is_Bc=b}', "");
Expect(0, 8234, '\P{^Is_Bc=b}', "");
Expect(1, 8233, '\p{Is_Bc=	B}', "");
Expect(0, 8233, '\p{^Is_Bc=	B}', "");
Expect(0, 8233, '\P{Is_Bc=	B}', "");
Expect(1, 8233, '\P{^Is_Bc=	B}', "");
Expect(0, 8234, '\p{Is_Bc=	B}', "");
Expect(1, 8234, '\p{^Is_Bc=	B}', "");
Expect(1, 8234, '\P{Is_Bc=	B}', "");
Expect(0, 8234, '\P{^Is_Bc=	B}', "");
Error('\p{Bidi_Class=-/a/boundary_Neutral}');
Error('\P{Bidi_Class=-/a/boundary_Neutral}');
Expect(1, 921599, '\p{Bidi_Class=boundaryneutral}', "");
Expect(0, 921599, '\p{^Bidi_Class=boundaryneutral}', "");
Expect(0, 921599, '\P{Bidi_Class=boundaryneutral}', "");
Expect(1, 921599, '\P{^Bidi_Class=boundaryneutral}', "");
Expect(0, 1114109, '\p{Bidi_Class=boundaryneutral}', "");
Expect(1, 1114109, '\p{^Bidi_Class=boundaryneutral}', "");
Expect(1, 1114109, '\P{Bidi_Class=boundaryneutral}', "");
Expect(0, 1114109, '\P{^Bidi_Class=boundaryneutral}', "");
Expect(1, 921599, '\p{Bidi_Class=_	Boundary_NEUTRAL}', "");
Expect(0, 921599, '\p{^Bidi_Class=_	Boundary_NEUTRAL}', "");
Expect(0, 921599, '\P{Bidi_Class=_	Boundary_NEUTRAL}', "");
Expect(1, 921599, '\P{^Bidi_Class=_	Boundary_NEUTRAL}', "");
Expect(0, 1114109, '\p{Bidi_Class=_	Boundary_NEUTRAL}', "");
Expect(1, 1114109, '\p{^Bidi_Class=_	Boundary_NEUTRAL}', "");
Expect(1, 1114109, '\P{Bidi_Class=_	Boundary_NEUTRAL}', "");
Expect(0, 1114109, '\P{^Bidi_Class=_	Boundary_NEUTRAL}', "");
Error('\p{Bc=/a/-_BN}');
Error('\P{Bc=/a/-_BN}');
Expect(1, 921599, '\p{Bc=bn}', "");
Expect(0, 921599, '\p{^Bc=bn}', "");
Expect(0, 921599, '\P{Bc=bn}', "");
Expect(1, 921599, '\P{^Bc=bn}', "");
Expect(0, 1114109, '\p{Bc=bn}', "");
Expect(1, 1114109, '\p{^Bc=bn}', "");
Expect(1, 1114109, '\P{Bc=bn}', "");
Expect(0, 1114109, '\P{^Bc=bn}', "");
Expect(1, 921599, '\p{Bc: __BN}', "");
Expect(0, 921599, '\p{^Bc: __BN}', "");
Expect(0, 921599, '\P{Bc: __BN}', "");
Expect(1, 921599, '\P{^Bc: __BN}', "");
Expect(0, 1114109, '\p{Bc: __BN}', "");
Expect(1, 1114109, '\p{^Bc: __BN}', "");
Expect(1, 1114109, '\P{Bc: __BN}', "");
Expect(0, 1114109, '\P{^Bc: __BN}', "");
Error('\p{Is_Bidi_Class=-	Boundary_Neutral/a/}');
Error('\P{Is_Bidi_Class=-	Boundary_Neutral/a/}');
Expect(1, 921599, '\p{Is_Bidi_Class=boundaryneutral}', "");
Expect(0, 921599, '\p{^Is_Bidi_Class=boundaryneutral}', "");
Expect(0, 921599, '\P{Is_Bidi_Class=boundaryneutral}', "");
Expect(1, 921599, '\P{^Is_Bidi_Class=boundaryneutral}', "");
Expect(0, 1114109, '\p{Is_Bidi_Class=boundaryneutral}', "");
Expect(1, 1114109, '\p{^Is_Bidi_Class=boundaryneutral}', "");
Expect(1, 1114109, '\P{Is_Bidi_Class=boundaryneutral}', "");
Expect(0, 1114109, '\P{^Is_Bidi_Class=boundaryneutral}', "");
Expect(1, 921599, '\p{Is_Bidi_Class: _boundary_NEUTRAL}', "");
Expect(0, 921599, '\p{^Is_Bidi_Class: _boundary_NEUTRAL}', "");
Expect(0, 921599, '\P{Is_Bidi_Class: _boundary_NEUTRAL}', "");
Expect(1, 921599, '\P{^Is_Bidi_Class: _boundary_NEUTRAL}', "");
Expect(0, 1114109, '\p{Is_Bidi_Class: _boundary_NEUTRAL}', "");
Expect(1, 1114109, '\p{^Is_Bidi_Class: _boundary_NEUTRAL}', "");
Expect(1, 1114109, '\P{Is_Bidi_Class: _boundary_NEUTRAL}', "");
Expect(0, 1114109, '\P{^Is_Bidi_Class: _boundary_NEUTRAL}', "");
Error('\p{Is_Bc=:= BN}');
Error('\P{Is_Bc=:= BN}');
Expect(1, 921599, '\p{Is_Bc=bn}', "");
Expect(0, 921599, '\p{^Is_Bc=bn}', "");
Expect(0, 921599, '\P{Is_Bc=bn}', "");
Expect(1, 921599, '\P{^Is_Bc=bn}', "");
Expect(0, 1114109, '\p{Is_Bc=bn}', "");
Expect(1, 1114109, '\p{^Is_Bc=bn}', "");
Expect(1, 1114109, '\P{Is_Bc=bn}', "");
Expect(0, 1114109, '\P{^Is_Bc=bn}', "");
Expect(1, 921599, '\p{Is_Bc= bn}', "");
Expect(0, 921599, '\p{^Is_Bc= bn}', "");
Expect(0, 921599, '\P{Is_Bc= bn}', "");
Expect(1, 921599, '\P{^Is_Bc= bn}', "");
Expect(0, 1114109, '\p{Is_Bc= bn}', "");
Expect(1, 1114109, '\p{^Is_Bc= bn}', "");
Expect(1, 1114109, '\P{Is_Bc= bn}', "");
Expect(0, 1114109, '\P{^Is_Bc= bn}', "");
Error('\p{Bidi_Class=	:=common_separator}');
Error('\P{Bidi_Class=	:=common_separator}');
Expect(1, 65306, '\p{Bidi_Class=commonseparator}', "");
Expect(0, 65306, '\p{^Bidi_Class=commonseparator}', "");
Expect(0, 65306, '\P{Bidi_Class=commonseparator}', "");
Expect(1, 65306, '\P{^Bidi_Class=commonseparator}', "");
Expect(0, 65307, '\p{Bidi_Class=commonseparator}', "");
Expect(1, 65307, '\p{^Bidi_Class=commonseparator}', "");
Expect(1, 65307, '\P{Bidi_Class=commonseparator}', "");
Expect(0, 65307, '\P{^Bidi_Class=commonseparator}', "");
Expect(1, 65306, '\p{Bidi_Class=_COMMON_Separator}', "");
Expect(0, 65306, '\p{^Bidi_Class=_COMMON_Separator}', "");
Expect(0, 65306, '\P{Bidi_Class=_COMMON_Separator}', "");
Expect(1, 65306, '\P{^Bidi_Class=_COMMON_Separator}', "");
Expect(0, 65307, '\p{Bidi_Class=_COMMON_Separator}', "");
Expect(1, 65307, '\p{^Bidi_Class=_COMMON_Separator}', "");
Expect(1, 65307, '\P{Bidi_Class=_COMMON_Separator}', "");
Expect(0, 65307, '\P{^Bidi_Class=_COMMON_Separator}', "");
Error('\p{Bc= 	cs/a/}');
Error('\P{Bc= 	cs/a/}');
Expect(1, 65306, '\p{Bc=cs}', "");
Expect(0, 65306, '\p{^Bc=cs}', "");
Expect(0, 65306, '\P{Bc=cs}', "");
Expect(1, 65306, '\P{^Bc=cs}', "");
Expect(0, 65307, '\p{Bc=cs}', "");
Expect(1, 65307, '\p{^Bc=cs}', "");
Expect(1, 65307, '\P{Bc=cs}', "");
Expect(0, 65307, '\P{^Bc=cs}', "");
Expect(1, 65306, '\p{Bc=_CS}', "");
Expect(0, 65306, '\p{^Bc=_CS}', "");
Expect(0, 65306, '\P{Bc=_CS}', "");
Expect(1, 65306, '\P{^Bc=_CS}', "");
Expect(0, 65307, '\p{Bc=_CS}', "");
Expect(1, 65307, '\p{^Bc=_CS}', "");
Expect(1, 65307, '\P{Bc=_CS}', "");
Expect(0, 65307, '\P{^Bc=_CS}', "");
Error('\p{Is_Bidi_Class=_/a/Common_Separator}');
Error('\P{Is_Bidi_Class=_/a/Common_Separator}');
Expect(1, 65306, '\p{Is_Bidi_Class=commonseparator}', "");
Expect(0, 65306, '\p{^Is_Bidi_Class=commonseparator}', "");
Expect(0, 65306, '\P{Is_Bidi_Class=commonseparator}', "");
Expect(1, 65306, '\P{^Is_Bidi_Class=commonseparator}', "");
Expect(0, 65307, '\p{Is_Bidi_Class=commonseparator}', "");
Expect(1, 65307, '\p{^Is_Bidi_Class=commonseparator}', "");
Expect(1, 65307, '\P{Is_Bidi_Class=commonseparator}', "");
Expect(0, 65307, '\P{^Is_Bidi_Class=commonseparator}', "");
Expect(1, 65306, '\p{Is_Bidi_Class=- Common_separator}', "");
Expect(0, 65306, '\p{^Is_Bidi_Class=- Common_separator}', "");
Expect(0, 65306, '\P{Is_Bidi_Class=- Common_separator}', "");
Expect(1, 65306, '\P{^Is_Bidi_Class=- Common_separator}', "");
Expect(0, 65307, '\p{Is_Bidi_Class=- Common_separator}', "");
Expect(1, 65307, '\p{^Is_Bidi_Class=- Common_separator}', "");
Expect(1, 65307, '\P{Is_Bidi_Class=- Common_separator}', "");
Expect(0, 65307, '\P{^Is_Bidi_Class=- Common_separator}', "");
Error('\p{Is_Bc=:= -CS}');
Error('\P{Is_Bc=:= -CS}');
Expect(1, 65306, '\p{Is_Bc: cs}', "");
Expect(0, 65306, '\p{^Is_Bc: cs}', "");
Expect(0, 65306, '\P{Is_Bc: cs}', "");
Expect(1, 65306, '\P{^Is_Bc: cs}', "");
Expect(0, 65307, '\p{Is_Bc: cs}', "");
Expect(1, 65307, '\p{^Is_Bc: cs}', "");
Expect(1, 65307, '\P{Is_Bc: cs}', "");
Expect(0, 65307, '\P{^Is_Bc: cs}', "");
Expect(1, 65306, '\p{Is_Bc= 	cs}', "");
Expect(0, 65306, '\p{^Is_Bc= 	cs}', "");
Expect(0, 65306, '\P{Is_Bc= 	cs}', "");
Expect(1, 65306, '\P{^Is_Bc= 	cs}', "");
Expect(0, 65307, '\p{Is_Bc= 	cs}', "");
Expect(1, 65307, '\p{^Is_Bc= 	cs}', "");
Expect(1, 65307, '\P{Is_Bc= 	cs}', "");
Expect(0, 65307, '\P{^Is_Bc= 	cs}', "");
Error('\p{Bidi_Class=:=	_european_Number}');
Error('\P{Bidi_Class=:=	_european_Number}');
Expect(1, 127242, '\p{Bidi_Class=europeannumber}', "");
Expect(0, 127242, '\p{^Bidi_Class=europeannumber}', "");
Expect(0, 127242, '\P{Bidi_Class=europeannumber}', "");
Expect(1, 127242, '\P{^Bidi_Class=europeannumber}', "");
Expect(0, 127243, '\p{Bidi_Class=europeannumber}', "");
Expect(1, 127243, '\p{^Bidi_Class=europeannumber}', "");
Expect(1, 127243, '\P{Bidi_Class=europeannumber}', "");
Expect(0, 127243, '\P{^Bidi_Class=europeannumber}', "");
Expect(1, 127242, '\p{Bidi_Class=-	european_NUMBER}', "");
Expect(0, 127242, '\p{^Bidi_Class=-	european_NUMBER}', "");
Expect(0, 127242, '\P{Bidi_Class=-	european_NUMBER}', "");
Expect(1, 127242, '\P{^Bidi_Class=-	european_NUMBER}', "");
Expect(0, 127243, '\p{Bidi_Class=-	european_NUMBER}', "");
Expect(1, 127243, '\p{^Bidi_Class=-	european_NUMBER}', "");
Expect(1, 127243, '\P{Bidi_Class=-	european_NUMBER}', "");
Expect(0, 127243, '\P{^Bidi_Class=-	european_NUMBER}', "");
Error('\p{Bc=/a/_EN}');
Error('\P{Bc=/a/_EN}');
Expect(1, 127242, '\p{Bc=en}', "");
Expect(0, 127242, '\p{^Bc=en}', "");
Expect(0, 127242, '\P{Bc=en}', "");
Expect(1, 127242, '\P{^Bc=en}', "");
Expect(0, 127243, '\p{Bc=en}', "");
Expect(1, 127243, '\p{^Bc=en}', "");
Expect(1, 127243, '\P{Bc=en}', "");
Expect(0, 127243, '\P{^Bc=en}', "");
Expect(1, 127242, '\p{Bc=		EN}', "");
Expect(0, 127242, '\p{^Bc=		EN}', "");
Expect(0, 127242, '\P{Bc=		EN}', "");
Expect(1, 127242, '\P{^Bc=		EN}', "");
Expect(0, 127243, '\p{Bc=		EN}', "");
Expect(1, 127243, '\p{^Bc=		EN}', "");
Expect(1, 127243, '\P{Bc=		EN}', "");
Expect(0, 127243, '\P{^Bc=		EN}', "");
Error('\p{Is_Bidi_Class=  european_NUMBER:=}');
Error('\P{Is_Bidi_Class=  european_NUMBER:=}');
Expect(1, 127242, '\p{Is_Bidi_Class=europeannumber}', "");
Expect(0, 127242, '\p{^Is_Bidi_Class=europeannumber}', "");
Expect(0, 127242, '\P{Is_Bidi_Class=europeannumber}', "");
Expect(1, 127242, '\P{^Is_Bidi_Class=europeannumber}', "");
Expect(0, 127243, '\p{Is_Bidi_Class=europeannumber}', "");
Expect(1, 127243, '\p{^Is_Bidi_Class=europeannumber}', "");
Expect(1, 127243, '\P{Is_Bidi_Class=europeannumber}', "");
Expect(0, 127243, '\P{^Is_Bidi_Class=europeannumber}', "");
Expect(1, 127242, '\p{Is_Bidi_Class=-European_Number}', "");
Expect(0, 127242, '\p{^Is_Bidi_Class=-European_Number}', "");
Expect(0, 127242, '\P{Is_Bidi_Class=-European_Number}', "");
Expect(1, 127242, '\P{^Is_Bidi_Class=-European_Number}', "");
Expect(0, 127243, '\p{Is_Bidi_Class=-European_Number}', "");
Expect(1, 127243, '\p{^Is_Bidi_Class=-European_Number}', "");
Expect(1, 127243, '\P{Is_Bidi_Class=-European_Number}', "");
Expect(0, 127243, '\P{^Is_Bidi_Class=-European_Number}', "");
Error('\p{Is_Bc=:=  EN}');
Error('\P{Is_Bc=:=  EN}');
Expect(1, 127242, '\p{Is_Bc=en}', "");
Expect(0, 127242, '\p{^Is_Bc=en}', "");
Expect(0, 127242, '\P{Is_Bc=en}', "");
Expect(1, 127242, '\P{^Is_Bc=en}', "");
Expect(0, 127243, '\p{Is_Bc=en}', "");
Expect(1, 127243, '\p{^Is_Bc=en}', "");
Expect(1, 127243, '\P{Is_Bc=en}', "");
Expect(0, 127243, '\P{^Is_Bc=en}', "");
Expect(1, 127242, '\p{Is_Bc:	- EN}', "");
Expect(0, 127242, '\p{^Is_Bc:	- EN}', "");
Expect(0, 127242, '\P{Is_Bc:	- EN}', "");
Expect(1, 127242, '\P{^Is_Bc:	- EN}', "");
Expect(0, 127243, '\p{Is_Bc:	- EN}', "");
Expect(1, 127243, '\p{^Is_Bc:	- EN}', "");
Expect(1, 127243, '\P{Is_Bc:	- EN}', "");
Expect(0, 127243, '\P{^Is_Bc:	- EN}', "");
Error('\p{Bidi_Class=/a/ _EUROPEAN_separator}');
Error('\P{Bidi_Class=/a/ _EUROPEAN_separator}');
Expect(1, 65293, '\p{Bidi_Class=europeanseparator}', "");
Expect(0, 65293, '\p{^Bidi_Class=europeanseparator}', "");
Expect(0, 65293, '\P{Bidi_Class=europeanseparator}', "");
Expect(1, 65293, '\P{^Bidi_Class=europeanseparator}', "");
Expect(0, 65294, '\p{Bidi_Class=europeanseparator}', "");
Expect(1, 65294, '\p{^Bidi_Class=europeanseparator}', "");
Expect(1, 65294, '\P{Bidi_Class=europeanseparator}', "");
Expect(0, 65294, '\P{^Bidi_Class=europeanseparator}', "");
Expect(1, 65293, '\p{Bidi_Class=-_European_Separator}', "");
Expect(0, 65293, '\p{^Bidi_Class=-_European_Separator}', "");
Expect(0, 65293, '\P{Bidi_Class=-_European_Separator}', "");
Expect(1, 65293, '\P{^Bidi_Class=-_European_Separator}', "");
Expect(0, 65294, '\p{Bidi_Class=-_European_Separator}', "");
Expect(1, 65294, '\p{^Bidi_Class=-_European_Separator}', "");
Expect(1, 65294, '\P{Bidi_Class=-_European_Separator}', "");
Expect(0, 65294, '\P{^Bidi_Class=-_European_Separator}', "");
Error('\p{Bc=-	ES:=}');
Error('\P{Bc=-	ES:=}');
Expect(1, 65293, '\p{Bc=es}', "");
Expect(0, 65293, '\p{^Bc=es}', "");
Expect(0, 65293, '\P{Bc=es}', "");
Expect(1, 65293, '\P{^Bc=es}', "");
Expect(0, 65294, '\p{Bc=es}', "");
Expect(1, 65294, '\p{^Bc=es}', "");
Expect(1, 65294, '\P{Bc=es}', "");
Expect(0, 65294, '\P{^Bc=es}', "");
Expect(1, 65293, '\p{Bc=  ES}', "");
Expect(0, 65293, '\p{^Bc=  ES}', "");
Expect(0, 65293, '\P{Bc=  ES}', "");
Expect(1, 65293, '\P{^Bc=  ES}', "");
Expect(0, 65294, '\p{Bc=  ES}', "");
Expect(1, 65294, '\p{^Bc=  ES}', "");
Expect(1, 65294, '\P{Bc=  ES}', "");
Expect(0, 65294, '\P{^Bc=  ES}', "");
Error('\p{Is_Bidi_Class=:= EUROPEAN_separator}');
Error('\P{Is_Bidi_Class=:= EUROPEAN_separator}');
Expect(1, 65293, '\p{Is_Bidi_Class=europeanseparator}', "");
Expect(0, 65293, '\p{^Is_Bidi_Class=europeanseparator}', "");
Expect(0, 65293, '\P{Is_Bidi_Class=europeanseparator}', "");
Expect(1, 65293, '\P{^Is_Bidi_Class=europeanseparator}', "");
Expect(0, 65294, '\p{Is_Bidi_Class=europeanseparator}', "");
Expect(1, 65294, '\p{^Is_Bidi_Class=europeanseparator}', "");
Expect(1, 65294, '\P{Is_Bidi_Class=europeanseparator}', "");
Expect(0, 65294, '\P{^Is_Bidi_Class=europeanseparator}', "");
Expect(1, 65293, '\p{Is_Bidi_Class=  European_Separator}', "");
Expect(0, 65293, '\p{^Is_Bidi_Class=  European_Separator}', "");
Expect(0, 65293, '\P{Is_Bidi_Class=  European_Separator}', "");
Expect(1, 65293, '\P{^Is_Bidi_Class=  European_Separator}', "");
Expect(0, 65294, '\p{Is_Bidi_Class=  European_Separator}', "");
Expect(1, 65294, '\p{^Is_Bidi_Class=  European_Separator}', "");
Expect(1, 65294, '\P{Is_Bidi_Class=  European_Separator}', "");
Expect(0, 65294, '\P{^Is_Bidi_Class=  European_Separator}', "");
Error('\p{Is_Bc=:=_ES}');
Error('\P{Is_Bc=:=_ES}');
Expect(1, 65293, '\p{Is_Bc=es}', "");
Expect(0, 65293, '\p{^Is_Bc=es}', "");
Expect(0, 65293, '\P{Is_Bc=es}', "");
Expect(1, 65293, '\P{^Is_Bc=es}', "");
Expect(0, 65294, '\p{Is_Bc=es}', "");
Expect(1, 65294, '\p{^Is_Bc=es}', "");
Expect(1, 65294, '\P{Is_Bc=es}', "");
Expect(0, 65294, '\P{^Is_Bc=es}', "");
Expect(1, 65293, '\p{Is_Bc=-	ES}', "");
Expect(0, 65293, '\p{^Is_Bc=-	ES}', "");
Expect(0, 65293, '\P{Is_Bc=-	ES}', "");
Expect(1, 65293, '\P{^Is_Bc=-	ES}', "");
Expect(0, 65294, '\p{Is_Bc=-	ES}', "");
Expect(1, 65294, '\p{^Is_Bc=-	ES}', "");
Expect(1, 65294, '\P{Is_Bc=-	ES}', "");
Expect(0, 65294, '\P{^Is_Bc=-	ES}', "");
Error('\p{Bidi_Class:	:= -european_Terminator}');
Error('\P{Bidi_Class:	:= -european_Terminator}');
Expect(1, 65510, '\p{Bidi_Class=europeanterminator}', "");
Expect(0, 65510, '\p{^Bidi_Class=europeanterminator}', "");
Expect(0, 65510, '\P{Bidi_Class=europeanterminator}', "");
Expect(1, 65510, '\P{^Bidi_Class=europeanterminator}', "");
Expect(0, 65511, '\p{Bidi_Class=europeanterminator}', "");
Expect(1, 65511, '\p{^Bidi_Class=europeanterminator}', "");
Expect(1, 65511, '\P{Bidi_Class=europeanterminator}', "");
Expect(0, 65511, '\P{^Bidi_Class=europeanterminator}', "");
Expect(1, 65510, '\p{Bidi_Class=__european_Terminator}', "");
Expect(0, 65510, '\p{^Bidi_Class=__european_Terminator}', "");
Expect(0, 65510, '\P{Bidi_Class=__european_Terminator}', "");
Expect(1, 65510, '\P{^Bidi_Class=__european_Terminator}', "");
Expect(0, 65511, '\p{Bidi_Class=__european_Terminator}', "");
Expect(1, 65511, '\p{^Bidi_Class=__european_Terminator}', "");
Expect(1, 65511, '\P{Bidi_Class=__european_Terminator}', "");
Expect(0, 65511, '\P{^Bidi_Class=__european_Terminator}', "");
Error('\p{Bc:	et/a/}');
Error('\P{Bc:	et/a/}');
Expect(1, 65510, '\p{Bc=et}', "");
Expect(0, 65510, '\p{^Bc=et}', "");
Expect(0, 65510, '\P{Bc=et}', "");
Expect(1, 65510, '\P{^Bc=et}', "");
Expect(0, 65511, '\p{Bc=et}', "");
Expect(1, 65511, '\p{^Bc=et}', "");
Expect(1, 65511, '\P{Bc=et}', "");
Expect(0, 65511, '\P{^Bc=et}', "");
Expect(1, 65510, '\p{Bc:-ET}', "");
Expect(0, 65510, '\p{^Bc:-ET}', "");
Expect(0, 65510, '\P{Bc:-ET}', "");
Expect(1, 65510, '\P{^Bc:-ET}', "");
Expect(0, 65511, '\p{Bc:-ET}', "");
Expect(1, 65511, '\p{^Bc:-ET}', "");
Expect(1, 65511, '\P{Bc:-ET}', "");
Expect(0, 65511, '\P{^Bc:-ET}', "");
Error('\p{Is_Bidi_Class=-:=european_Terminator}');
Error('\P{Is_Bidi_Class=-:=european_Terminator}');
Expect(1, 65510, '\p{Is_Bidi_Class=europeanterminator}', "");
Expect(0, 65510, '\p{^Is_Bidi_Class=europeanterminator}', "");
Expect(0, 65510, '\P{Is_Bidi_Class=europeanterminator}', "");
Expect(1, 65510, '\P{^Is_Bidi_Class=europeanterminator}', "");
Expect(0, 65511, '\p{Is_Bidi_Class=europeanterminator}', "");
Expect(1, 65511, '\p{^Is_Bidi_Class=europeanterminator}', "");
Expect(1, 65511, '\P{Is_Bidi_Class=europeanterminator}', "");
Expect(0, 65511, '\P{^Is_Bidi_Class=europeanterminator}', "");
Expect(1, 65510, '\p{Is_Bidi_Class:	EUROPEAN_TERMINATOR}', "");
Expect(0, 65510, '\p{^Is_Bidi_Class:	EUROPEAN_TERMINATOR}', "");
Expect(0, 65510, '\P{Is_Bidi_Class:	EUROPEAN_TERMINATOR}', "");
Expect(1, 65510, '\P{^Is_Bidi_Class:	EUROPEAN_TERMINATOR}', "");
Expect(0, 65511, '\p{Is_Bidi_Class:	EUROPEAN_TERMINATOR}', "");
Expect(1, 65511, '\p{^Is_Bidi_Class:	EUROPEAN_TERMINATOR}', "");
Expect(1, 65511, '\P{Is_Bidi_Class:	EUROPEAN_TERMINATOR}', "");
Expect(0, 65511, '\P{^Is_Bidi_Class:	EUROPEAN_TERMINATOR}', "");
Error('\p{Is_Bc=- ET/a/}');
Error('\P{Is_Bc=- ET/a/}');
Expect(1, 65510, '\p{Is_Bc=et}', "");
Expect(0, 65510, '\p{^Is_Bc=et}', "");
Expect(0, 65510, '\P{Is_Bc=et}', "");
Expect(1, 65510, '\P{^Is_Bc=et}', "");
Expect(0, 65511, '\p{Is_Bc=et}', "");
Expect(1, 65511, '\p{^Is_Bc=et}', "");
Expect(1, 65511, '\P{Is_Bc=et}', "");
Expect(0, 65511, '\P{^Is_Bc=et}', "");
Expect(1, 65510, '\p{Is_Bc= 	ET}', "");
Expect(0, 65510, '\p{^Is_Bc= 	ET}', "");
Expect(0, 65510, '\P{Is_Bc= 	ET}', "");
Expect(1, 65510, '\P{^Is_Bc= 	ET}', "");
Expect(0, 65511, '\p{Is_Bc= 	ET}', "");
Expect(1, 65511, '\p{^Is_Bc= 	ET}', "");
Expect(1, 65511, '\P{Is_Bc= 	ET}', "");
Expect(0, 65511, '\P{^Is_Bc= 	ET}', "");
Error('\p{Bidi_Class:_	FIRST_strong_isolate/a/}');
Error('\P{Bidi_Class:_	FIRST_strong_isolate/a/}');
Expect(1, 8296, '\p{Bidi_Class=firststrongisolate}', "");
Expect(0, 8296, '\p{^Bidi_Class=firststrongisolate}', "");
Expect(0, 8296, '\P{Bidi_Class=firststrongisolate}', "");
Expect(1, 8296, '\P{^Bidi_Class=firststrongisolate}', "");
Expect(0, 8297, '\p{Bidi_Class=firststrongisolate}', "");
Expect(1, 8297, '\p{^Bidi_Class=firststrongisolate}', "");
Expect(1, 8297, '\P{Bidi_Class=firststrongisolate}', "");
Expect(0, 8297, '\P{^Bidi_Class=firststrongisolate}', "");
Expect(1, 8296, '\p{Bidi_Class= FIRST_Strong_ISOLATE}', "");
Expect(0, 8296, '\p{^Bidi_Class= FIRST_Strong_ISOLATE}', "");
Expect(0, 8296, '\P{Bidi_Class= FIRST_Strong_ISOLATE}', "");
Expect(1, 8296, '\P{^Bidi_Class= FIRST_Strong_ISOLATE}', "");
Expect(0, 8297, '\p{Bidi_Class= FIRST_Strong_ISOLATE}', "");
Expect(1, 8297, '\p{^Bidi_Class= FIRST_Strong_ISOLATE}', "");
Expect(1, 8297, '\P{Bidi_Class= FIRST_Strong_ISOLATE}', "");
Expect(0, 8297, '\P{^Bidi_Class= FIRST_Strong_ISOLATE}', "");
Error('\p{Bc=:= 	FSI}');
Error('\P{Bc=:= 	FSI}');
Expect(1, 8296, '\p{Bc=fsi}', "");
Expect(0, 8296, '\p{^Bc=fsi}', "");
Expect(0, 8296, '\P{Bc=fsi}', "");
Expect(1, 8296, '\P{^Bc=fsi}', "");
Expect(0, 8297, '\p{Bc=fsi}', "");
Expect(1, 8297, '\p{^Bc=fsi}', "");
Expect(1, 8297, '\P{Bc=fsi}', "");
Expect(0, 8297, '\P{^Bc=fsi}', "");
Expect(1, 8296, '\p{Bc=	-FSI}', "");
Expect(0, 8296, '\p{^Bc=	-FSI}', "");
Expect(0, 8296, '\P{Bc=	-FSI}', "");
Expect(1, 8296, '\P{^Bc=	-FSI}', "");
Expect(0, 8297, '\p{Bc=	-FSI}', "");
Expect(1, 8297, '\p{^Bc=	-FSI}', "");
Expect(1, 8297, '\P{Bc=	-FSI}', "");
Expect(0, 8297, '\P{^Bc=	-FSI}', "");
Error('\p{Is_Bidi_Class:	/a/-First_Strong_Isolate}');
Error('\P{Is_Bidi_Class:	/a/-First_Strong_Isolate}');
Expect(1, 8296, '\p{Is_Bidi_Class=firststrongisolate}', "");
Expect(0, 8296, '\p{^Is_Bidi_Class=firststrongisolate}', "");
Expect(0, 8296, '\P{Is_Bidi_Class=firststrongisolate}', "");
Expect(1, 8296, '\P{^Is_Bidi_Class=firststrongisolate}', "");
Expect(0, 8297, '\p{Is_Bidi_Class=firststrongisolate}', "");
Expect(1, 8297, '\p{^Is_Bidi_Class=firststrongisolate}', "");
Expect(1, 8297, '\P{Is_Bidi_Class=firststrongisolate}', "");
Expect(0, 8297, '\P{^Is_Bidi_Class=firststrongisolate}', "");
Expect(1, 8296, '\p{Is_Bidi_Class:	_-FIRST_STRONG_isolate}', "");
Expect(0, 8296, '\p{^Is_Bidi_Class:	_-FIRST_STRONG_isolate}', "");
Expect(0, 8296, '\P{Is_Bidi_Class:	_-FIRST_STRONG_isolate}', "");
Expect(1, 8296, '\P{^Is_Bidi_Class:	_-FIRST_STRONG_isolate}', "");
Expect(0, 8297, '\p{Is_Bidi_Class:	_-FIRST_STRONG_isolate}', "");
Expect(1, 8297, '\p{^Is_Bidi_Class:	_-FIRST_STRONG_isolate}', "");
Expect(1, 8297, '\P{Is_Bidi_Class:	_-FIRST_STRONG_isolate}', "");
Expect(0, 8297, '\P{^Is_Bidi_Class:	_-FIRST_STRONG_isolate}', "");
Error('\p{Is_Bc=-:=FSI}');
Error('\P{Is_Bc=-:=FSI}');
Expect(1, 8296, '\p{Is_Bc=fsi}', "");
Expect(0, 8296, '\p{^Is_Bc=fsi}', "");
Expect(0, 8296, '\P{Is_Bc=fsi}', "");
Expect(1, 8296, '\P{^Is_Bc=fsi}', "");
Expect(0, 8297, '\p{Is_Bc=fsi}', "");
Expect(1, 8297, '\p{^Is_Bc=fsi}', "");
Expect(1, 8297, '\P{Is_Bc=fsi}', "");
Expect(0, 8297, '\P{^Is_Bc=fsi}', "");
Expect(1, 8296, '\p{Is_Bc= FSI}', "");
Expect(0, 8296, '\p{^Is_Bc= FSI}', "");
Expect(0, 8296, '\P{Is_Bc= FSI}', "");
Expect(1, 8296, '\P{^Is_Bc= FSI}', "");
Expect(0, 8297, '\p{Is_Bc= FSI}', "");
Expect(1, 8297, '\p{^Is_Bc= FSI}', "");
Expect(1, 8297, '\P{Is_Bc= FSI}', "");
Expect(0, 8297, '\P{^Is_Bc= FSI}', "");
Error('\p{Bidi_Class=/a/_Left_To_Right}');
Error('\P{Bidi_Class=/a/_Left_To_Right}');
Expect(1, 1114109, '\p{Bidi_Class: lefttoright}', "");
Expect(0, 1114109, '\p{^Bidi_Class: lefttoright}', "");
Expect(0, 1114109, '\P{Bidi_Class: lefttoright}', "");
Expect(1, 1114109, '\P{^Bidi_Class: lefttoright}', "");
Expect(0, 921599, '\p{Bidi_Class: lefttoright}', "");
Expect(1, 921599, '\p{^Bidi_Class: lefttoright}', "");
Expect(1, 921599, '\P{Bidi_Class: lefttoright}', "");
Expect(0, 921599, '\P{^Bidi_Class: lefttoright}', "");
Expect(1, 1114109, '\p{Bidi_Class= 	Left_to_Right}', "");
Expect(0, 1114109, '\p{^Bidi_Class= 	Left_to_Right}', "");
Expect(0, 1114109, '\P{Bidi_Class= 	Left_to_Right}', "");
Expect(1, 1114109, '\P{^Bidi_Class= 	Left_to_Right}', "");
Expect(0, 921599, '\p{Bidi_Class= 	Left_to_Right}', "");
Expect(1, 921599, '\p{^Bidi_Class= 	Left_to_Right}', "");
Expect(1, 921599, '\P{Bidi_Class= 	Left_to_Right}', "");
Expect(0, 921599, '\P{^Bidi_Class= 	Left_to_Right}', "");
Error('\p{Bc=_	L/a/}');
Error('\P{Bc=_	L/a/}');
Expect(1, 1114109, '\p{Bc:	l}', "");
Expect(0, 1114109, '\p{^Bc:	l}', "");
Expect(0, 1114109, '\P{Bc:	l}', "");
Expect(1, 1114109, '\P{^Bc:	l}', "");
Expect(0, 921599, '\p{Bc:	l}', "");
Expect(1, 921599, '\p{^Bc:	l}', "");
Expect(1, 921599, '\P{Bc:	l}', "");
Expect(0, 921599, '\P{^Bc:	l}', "");
Expect(1, 1114109, '\p{Bc=	-L}', "");
Expect(0, 1114109, '\p{^Bc=	-L}', "");
Expect(0, 1114109, '\P{Bc=	-L}', "");
Expect(1, 1114109, '\P{^Bc=	-L}', "");
Expect(0, 921599, '\p{Bc=	-L}', "");
Expect(1, 921599, '\p{^Bc=	-L}', "");
Expect(1, 921599, '\P{Bc=	-L}', "");
Expect(0, 921599, '\P{^Bc=	-L}', "");
Error('\p{Is_Bidi_Class=-:=LEFT_TO_RIGHT}');
Error('\P{Is_Bidi_Class=-:=LEFT_TO_RIGHT}');
Expect(1, 1114109, '\p{Is_Bidi_Class=lefttoright}', "");
Expect(0, 1114109, '\p{^Is_Bidi_Class=lefttoright}', "");
Expect(0, 1114109, '\P{Is_Bidi_Class=lefttoright}', "");
Expect(1, 1114109, '\P{^Is_Bidi_Class=lefttoright}', "");
Expect(0, 921599, '\p{Is_Bidi_Class=lefttoright}', "");
Expect(1, 921599, '\p{^Is_Bidi_Class=lefttoright}', "");
Expect(1, 921599, '\P{Is_Bidi_Class=lefttoright}', "");
Expect(0, 921599, '\P{^Is_Bidi_Class=lefttoright}', "");
Expect(1, 1114109, '\p{Is_Bidi_Class:    Left_To_right}', "");
Expect(0, 1114109, '\p{^Is_Bidi_Class:    Left_To_right}', "");
Expect(0, 1114109, '\P{Is_Bidi_Class:    Left_To_right}', "");
Expect(1, 1114109, '\P{^Is_Bidi_Class:    Left_To_right}', "");
Expect(0, 921599, '\p{Is_Bidi_Class:    Left_To_right}', "");
Expect(1, 921599, '\p{^Is_Bidi_Class:    Left_To_right}', "");
Expect(1, 921599, '\P{Is_Bidi_Class:    Left_To_right}', "");
Expect(0, 921599, '\P{^Is_Bidi_Class:    Left_To_right}', "");
Error('\p{Is_Bc=:= 	l}');
Error('\P{Is_Bc=:= 	l}');
Expect(1, 1114109, '\p{Is_Bc=l}', "");
Expect(0, 1114109, '\p{^Is_Bc=l}', "");
Expect(0, 1114109, '\P{Is_Bc=l}', "");
Expect(1, 1114109, '\P{^Is_Bc=l}', "");
Expect(0, 921599, '\p{Is_Bc=l}', "");
Expect(1, 921599, '\p{^Is_Bc=l}', "");
Expect(1, 921599, '\P{Is_Bc=l}', "");
Expect(0, 921599, '\P{^Is_Bc=l}', "");
Expect(1, 1114109, '\p{Is_Bc=--L}', "");
Expect(0, 1114109, '\p{^Is_Bc=--L}', "");
Expect(0, 1114109, '\P{Is_Bc=--L}', "");
Expect(1, 1114109, '\P{^Is_Bc=--L}', "");
Expect(0, 921599, '\p{Is_Bc=--L}', "");
Expect(1, 921599, '\p{^Is_Bc=--L}', "");
Expect(1, 921599, '\P{Is_Bc=--L}', "");
Expect(0, 921599, '\P{^Is_Bc=--L}', "");
Error('\p{Bidi_Class=/a/ left_to_Right_Embedding}');
Error('\P{Bidi_Class=/a/ left_to_Right_Embedding}');
Expect(1, 8234, '\p{Bidi_Class=lefttorightembedding}', "");
Expect(0, 8234, '\p{^Bidi_Class=lefttorightembedding}', "");
Expect(0, 8234, '\P{Bidi_Class=lefttorightembedding}', "");
Expect(1, 8234, '\P{^Bidi_Class=lefttorightembedding}', "");
Expect(0, 8235, '\p{Bidi_Class=lefttorightembedding}', "");
Expect(1, 8235, '\p{^Bidi_Class=lefttorightembedding}', "");
Expect(1, 8235, '\P{Bidi_Class=lefttorightembedding}', "");
Expect(0, 8235, '\P{^Bidi_Class=lefttorightembedding}', "");
Expect(1, 8234, '\p{Bidi_Class:   	LEFT_TO_Right_embedding}', "");
Expect(0, 8234, '\p{^Bidi_Class:   	LEFT_TO_Right_embedding}', "");
Expect(0, 8234, '\P{Bidi_Class:   	LEFT_TO_Right_embedding}', "");
Expect(1, 8234, '\P{^Bidi_Class:   	LEFT_TO_Right_embedding}', "");
Expect(0, 8235, '\p{Bidi_Class:   	LEFT_TO_Right_embedding}', "");
Expect(1, 8235, '\p{^Bidi_Class:   	LEFT_TO_Right_embedding}', "");
Expect(1, 8235, '\P{Bidi_Class:   	LEFT_TO_Right_embedding}', "");
Expect(0, 8235, '\P{^Bidi_Class:   	LEFT_TO_Right_embedding}', "");
Error('\p{Bc=_ LRE/a/}');
Error('\P{Bc=_ LRE/a/}');
Expect(1, 8234, '\p{Bc=lre}', "");
Expect(0, 8234, '\p{^Bc=lre}', "");
Expect(0, 8234, '\P{Bc=lre}', "");
Expect(1, 8234, '\P{^Bc=lre}', "");
Expect(0, 8235, '\p{Bc=lre}', "");
Expect(1, 8235, '\p{^Bc=lre}', "");
Expect(1, 8235, '\P{Bc=lre}', "");
Expect(0, 8235, '\P{^Bc=lre}', "");
Expect(1, 8234, '\p{Bc=	_LRE}', "");
Expect(0, 8234, '\p{^Bc=	_LRE}', "");
Expect(0, 8234, '\P{Bc=	_LRE}', "");
Expect(1, 8234, '\P{^Bc=	_LRE}', "");
Expect(0, 8235, '\p{Bc=	_LRE}', "");
Expect(1, 8235, '\p{^Bc=	_LRE}', "");
Expect(1, 8235, '\P{Bc=	_LRE}', "");
Expect(0, 8235, '\P{^Bc=	_LRE}', "");
Error('\p{Is_Bidi_Class:   -_Left_To_Right_Embedding/a/}');
Error('\P{Is_Bidi_Class:   -_Left_To_Right_Embedding/a/}');
Expect(1, 8234, '\p{Is_Bidi_Class=lefttorightembedding}', "");
Expect(0, 8234, '\p{^Is_Bidi_Class=lefttorightembedding}', "");
Expect(0, 8234, '\P{Is_Bidi_Class=lefttorightembedding}', "");
Expect(1, 8234, '\P{^Is_Bidi_Class=lefttorightembedding}', "");
Expect(0, 8235, '\p{Is_Bidi_Class=lefttorightembedding}', "");
Expect(1, 8235, '\p{^Is_Bidi_Class=lefttorightembedding}', "");
Expect(1, 8235, '\P{Is_Bidi_Class=lefttorightembedding}', "");
Expect(0, 8235, '\P{^Is_Bidi_Class=lefttorightembedding}', "");
Expect(1, 8234, '\p{Is_Bidi_Class=_	Left_To_RIGHT_Embedding}', "");
Expect(0, 8234, '\p{^Is_Bidi_Class=_	Left_To_RIGHT_Embedding}', "");
Expect(0, 8234, '\P{Is_Bidi_Class=_	Left_To_RIGHT_Embedding}', "");
Expect(1, 8234, '\P{^Is_Bidi_Class=_	Left_To_RIGHT_Embedding}', "");
Expect(0, 8235, '\p{Is_Bidi_Class=_	Left_To_RIGHT_Embedding}', "");
Expect(1, 8235, '\p{^Is_Bidi_Class=_	Left_To_RIGHT_Embedding}', "");
Expect(1, 8235, '\P{Is_Bidi_Class=_	Left_To_RIGHT_Embedding}', "");
Expect(0, 8235, '\P{^Is_Bidi_Class=_	Left_To_RIGHT_Embedding}', "");
Error('\p{Is_Bc=_:=LRE}');
Error('\P{Is_Bc=_:=LRE}');
Expect(1, 8234, '\p{Is_Bc=lre}', "");
Expect(0, 8234, '\p{^Is_Bc=lre}', "");
Expect(0, 8234, '\P{Is_Bc=lre}', "");
Expect(1, 8234, '\P{^Is_Bc=lre}', "");
Expect(0, 8235, '\p{Is_Bc=lre}', "");
Expect(1, 8235, '\p{^Is_Bc=lre}', "");
Expect(1, 8235, '\P{Is_Bc=lre}', "");
Expect(0, 8235, '\P{^Is_Bc=lre}', "");
Expect(1, 8234, '\p{Is_Bc:   --LRE}', "");
Expect(0, 8234, '\p{^Is_Bc:   --LRE}', "");
Expect(0, 8234, '\P{Is_Bc:   --LRE}', "");
Expect(1, 8234, '\P{^Is_Bc:   --LRE}', "");
Expect(0, 8235, '\p{Is_Bc:   --LRE}', "");
Expect(1, 8235, '\p{^Is_Bc:   --LRE}', "");
Expect(1, 8235, '\P{Is_Bc:   --LRE}', "");
Expect(0, 8235, '\P{^Is_Bc:   --LRE}', "");
Error('\p{Bidi_Class=-/a/Left_to_Right_ISOLATE}');
Error('\P{Bidi_Class=-/a/Left_to_Right_ISOLATE}');
Expect(1, 8294, '\p{Bidi_Class=lefttorightisolate}', "");
Expect(0, 8294, '\p{^Bidi_Class=lefttorightisolate}', "");
Expect(0, 8294, '\P{Bidi_Class=lefttorightisolate}', "");
Expect(1, 8294, '\P{^Bidi_Class=lefttorightisolate}', "");
Expect(0, 8295, '\p{Bidi_Class=lefttorightisolate}', "");
Expect(1, 8295, '\p{^Bidi_Class=lefttorightisolate}', "");
Expect(1, 8295, '\P{Bidi_Class=lefttorightisolate}', "");
Expect(0, 8295, '\P{^Bidi_Class=lefttorightisolate}', "");
Expect(1, 8294, '\p{Bidi_Class=_ Left_TO_right_isolate}', "");
Expect(0, 8294, '\p{^Bidi_Class=_ Left_TO_right_isolate}', "");
Expect(0, 8294, '\P{Bidi_Class=_ Left_TO_right_isolate}', "");
Expect(1, 8294, '\P{^Bidi_Class=_ Left_TO_right_isolate}', "");
Expect(0, 8295, '\p{Bidi_Class=_ Left_TO_right_isolate}', "");
Expect(1, 8295, '\p{^Bidi_Class=_ Left_TO_right_isolate}', "");
Expect(1, 8295, '\P{Bidi_Class=_ Left_TO_right_isolate}', "");
Expect(0, 8295, '\P{^Bidi_Class=_ Left_TO_right_isolate}', "");
Error('\p{Bc:   _:=LRI}');
Error('\P{Bc:   _:=LRI}');
Expect(1, 8294, '\p{Bc: lri}', "");
Expect(0, 8294, '\p{^Bc: lri}', "");
Expect(0, 8294, '\P{Bc: lri}', "");
Expect(1, 8294, '\P{^Bc: lri}', "");
Expect(0, 8295, '\p{Bc: lri}', "");
Expect(1, 8295, '\p{^Bc: lri}', "");
Expect(1, 8295, '\P{Bc: lri}', "");
Expect(0, 8295, '\P{^Bc: lri}', "");
Expect(1, 8294, '\p{Bc=		LRI}', "");
Expect(0, 8294, '\p{^Bc=		LRI}', "");
Expect(0, 8294, '\P{Bc=		LRI}', "");
Expect(1, 8294, '\P{^Bc=		LRI}', "");
Expect(0, 8295, '\p{Bc=		LRI}', "");
Expect(1, 8295, '\p{^Bc=		LRI}', "");
Expect(1, 8295, '\P{Bc=		LRI}', "");
Expect(0, 8295, '\P{^Bc=		LRI}', "");
Error('\p{Is_Bidi_Class=/a/-	Left_To_Right_ISOLATE}');
Error('\P{Is_Bidi_Class=/a/-	Left_To_Right_ISOLATE}');
Expect(1, 8294, '\p{Is_Bidi_Class: lefttorightisolate}', "");
Expect(0, 8294, '\p{^Is_Bidi_Class: lefttorightisolate}', "");
Expect(0, 8294, '\P{Is_Bidi_Class: lefttorightisolate}', "");
Expect(1, 8294, '\P{^Is_Bidi_Class: lefttorightisolate}', "");
Expect(0, 8295, '\p{Is_Bidi_Class: lefttorightisolate}', "");
Expect(1, 8295, '\p{^Is_Bidi_Class: lefttorightisolate}', "");
Expect(1, 8295, '\P{Is_Bidi_Class: lefttorightisolate}', "");
Expect(0, 8295, '\P{^Is_Bidi_Class: lefttorightisolate}', "");
Expect(1, 8294, '\p{Is_Bidi_Class=-Left_TO_RIGHT_isolate}', "");
Expect(0, 8294, '\p{^Is_Bidi_Class=-Left_TO_RIGHT_isolate}', "");
Expect(0, 8294, '\P{Is_Bidi_Class=-Left_TO_RIGHT_isolate}', "");
Expect(1, 8294, '\P{^Is_Bidi_Class=-Left_TO_RIGHT_isolate}', "");
Expect(0, 8295, '\p{Is_Bidi_Class=-Left_TO_RIGHT_isolate}', "");
Expect(1, 8295, '\p{^Is_Bidi_Class=-Left_TO_RIGHT_isolate}', "");
Expect(1, 8295, '\P{Is_Bidi_Class=-Left_TO_RIGHT_isolate}', "");
Expect(0, 8295, '\P{^Is_Bidi_Class=-Left_TO_RIGHT_isolate}', "");
Error('\p{Is_Bc=:=LRI}');
Error('\P{Is_Bc=:=LRI}');
Expect(1, 8294, '\p{Is_Bc=lri}', "");
Expect(0, 8294, '\p{^Is_Bc=lri}', "");
Expect(0, 8294, '\P{Is_Bc=lri}', "");
Expect(1, 8294, '\P{^Is_Bc=lri}', "");
Expect(0, 8295, '\p{Is_Bc=lri}', "");
Expect(1, 8295, '\p{^Is_Bc=lri}', "");
Expect(1, 8295, '\P{Is_Bc=lri}', "");
Expect(0, 8295, '\P{^Is_Bc=lri}', "");
Expect(1, 8294, '\p{Is_Bc= LRI}', "");
Expect(0, 8294, '\p{^Is_Bc= LRI}', "");
Expect(0, 8294, '\P{Is_Bc= LRI}', "");
Expect(1, 8294, '\P{^Is_Bc= LRI}', "");
Expect(0, 8295, '\p{Is_Bc= LRI}', "");
Expect(1, 8295, '\p{^Is_Bc= LRI}', "");
Expect(1, 8295, '\P{Is_Bc= LRI}', "");
Expect(0, 8295, '\P{^Is_Bc= LRI}', "");
Error('\p{Bidi_Class=/a/	-Left_To_RIGHT_override}');
Error('\P{Bidi_Class=/a/	-Left_To_RIGHT_override}');
Expect(1, 8237, '\p{Bidi_Class=lefttorightoverride}', "");
Expect(0, 8237, '\p{^Bidi_Class=lefttorightoverride}', "");
Expect(0, 8237, '\P{Bidi_Class=lefttorightoverride}', "");
Expect(1, 8237, '\P{^Bidi_Class=lefttorightoverride}', "");
Expect(0, 8238, '\p{Bidi_Class=lefttorightoverride}', "");
Expect(1, 8238, '\p{^Bidi_Class=lefttorightoverride}', "");
Expect(1, 8238, '\P{Bidi_Class=lefttorightoverride}', "");
Expect(0, 8238, '\P{^Bidi_Class=lefttorightoverride}', "");
Expect(1, 8237, '\p{Bidi_Class=_left_To_RIGHT_Override}', "");
Expect(0, 8237, '\p{^Bidi_Class=_left_To_RIGHT_Override}', "");
Expect(0, 8237, '\P{Bidi_Class=_left_To_RIGHT_Override}', "");
Expect(1, 8237, '\P{^Bidi_Class=_left_To_RIGHT_Override}', "");
Expect(0, 8238, '\p{Bidi_Class=_left_To_RIGHT_Override}', "");
Expect(1, 8238, '\p{^Bidi_Class=_left_To_RIGHT_Override}', "");
Expect(1, 8238, '\P{Bidi_Class=_left_To_RIGHT_Override}', "");
Expect(0, 8238, '\P{^Bidi_Class=_left_To_RIGHT_Override}', "");
Error('\p{Bc:	:=LRO}');
Error('\P{Bc:	:=LRO}');
Expect(1, 8237, '\p{Bc=lro}', "");
Expect(0, 8237, '\p{^Bc=lro}', "");
Expect(0, 8237, '\P{Bc=lro}', "");
Expect(1, 8237, '\P{^Bc=lro}', "");
Expect(0, 8238, '\p{Bc=lro}', "");
Expect(1, 8238, '\p{^Bc=lro}', "");
Expect(1, 8238, '\P{Bc=lro}', "");
Expect(0, 8238, '\P{^Bc=lro}', "");
Expect(1, 8237, '\p{Bc=--LRO}', "");
Expect(0, 8237, '\p{^Bc=--LRO}', "");
Expect(0, 8237, '\P{Bc=--LRO}', "");
Expect(1, 8237, '\P{^Bc=--LRO}', "");
Expect(0, 8238, '\p{Bc=--LRO}', "");
Expect(1, 8238, '\p{^Bc=--LRO}', "");
Expect(1, 8238, '\P{Bc=--LRO}', "");
Expect(0, 8238, '\P{^Bc=--LRO}', "");
Error('\p{Is_Bidi_Class= :=LEFT_To_RIGHT_override}');
Error('\P{Is_Bidi_Class= :=LEFT_To_RIGHT_override}');
Expect(1, 8237, '\p{Is_Bidi_Class=lefttorightoverride}', "");
Expect(0, 8237, '\p{^Is_Bidi_Class=lefttorightoverride}', "");
Expect(0, 8237, '\P{Is_Bidi_Class=lefttorightoverride}', "");
Expect(1, 8237, '\P{^Is_Bidi_Class=lefttorightoverride}', "");
Expect(0, 8238, '\p{Is_Bidi_Class=lefttorightoverride}', "");
Expect(1, 8238, '\p{^Is_Bidi_Class=lefttorightoverride}', "");
Expect(1, 8238, '\P{Is_Bidi_Class=lefttorightoverride}', "");
Expect(0, 8238, '\P{^Is_Bidi_Class=lefttorightoverride}', "");
Expect(1, 8237, '\p{Is_Bidi_Class:   	-Left_To_Right_override}', "");
Expect(0, 8237, '\p{^Is_Bidi_Class:   	-Left_To_Right_override}', "");
Expect(0, 8237, '\P{Is_Bidi_Class:   	-Left_To_Right_override}', "");
Expect(1, 8237, '\P{^Is_Bidi_Class:   	-Left_To_Right_override}', "");
Expect(0, 8238, '\p{Is_Bidi_Class:   	-Left_To_Right_override}', "");
Expect(1, 8238, '\p{^Is_Bidi_Class:   	-Left_To_Right_override}', "");
Expect(1, 8238, '\P{Is_Bidi_Class:   	-Left_To_Right_override}', "");
Expect(0, 8238, '\P{^Is_Bidi_Class:   	-Left_To_Right_override}', "");
Error('\p{Is_Bc:		/a/LRO}');
Error('\P{Is_Bc:		/a/LRO}');
Expect(1, 8237, '\p{Is_Bc=lro}', "");
Expect(0, 8237, '\p{^Is_Bc=lro}', "");
Expect(0, 8237, '\P{Is_Bc=lro}', "");
Expect(1, 8237, '\P{^Is_Bc=lro}', "");
Expect(0, 8238, '\p{Is_Bc=lro}', "");
Expect(1, 8238, '\p{^Is_Bc=lro}', "");
Expect(1, 8238, '\P{Is_Bc=lro}', "");
Expect(0, 8238, '\P{^Is_Bc=lro}', "");
Expect(1, 8237, '\p{Is_Bc=_LRO}', "");
Expect(0, 8237, '\p{^Is_Bc=_LRO}', "");
Expect(0, 8237, '\P{Is_Bc=_LRO}', "");
Expect(1, 8237, '\P{^Is_Bc=_LRO}', "");
Expect(0, 8238, '\p{Is_Bc=_LRO}', "");
Expect(1, 8238, '\p{^Is_Bc=_LRO}', "");
Expect(1, 8238, '\P{Is_Bc=_LRO}', "");
Expect(0, 8238, '\P{^Is_Bc=_LRO}', "");
Error('\p{Bidi_Class=/a/_	Nonspacing_MARK}');
Error('\P{Bidi_Class=/a/_	Nonspacing_MARK}');
Expect(1, 917999, '\p{Bidi_Class=nonspacingmark}', "");
Expect(0, 917999, '\p{^Bidi_Class=nonspacingmark}', "");
Expect(0, 917999, '\P{Bidi_Class=nonspacingmark}', "");
Expect(1, 917999, '\P{^Bidi_Class=nonspacingmark}', "");
Expect(0, 918000, '\p{Bidi_Class=nonspacingmark}', "");
Expect(1, 918000, '\p{^Bidi_Class=nonspacingmark}', "");
Expect(1, 918000, '\P{Bidi_Class=nonspacingmark}', "");
Expect(0, 918000, '\P{^Bidi_Class=nonspacingmark}', "");
Expect(1, 917999, '\p{Bidi_Class=_	NONSPACING_MARK}', "");
Expect(0, 917999, '\p{^Bidi_Class=_	NONSPACING_MARK}', "");
Expect(0, 917999, '\P{Bidi_Class=_	NONSPACING_MARK}', "");
Expect(1, 917999, '\P{^Bidi_Class=_	NONSPACING_MARK}', "");
Expect(0, 918000, '\p{Bidi_Class=_	NONSPACING_MARK}', "");
Expect(1, 918000, '\p{^Bidi_Class=_	NONSPACING_MARK}', "");
Expect(1, 918000, '\P{Bidi_Class=_	NONSPACING_MARK}', "");
Expect(0, 918000, '\P{^Bidi_Class=_	NONSPACING_MARK}', "");
Error('\p{Bc=:=- NSM}');
Error('\P{Bc=:=- NSM}');
Expect(1, 917999, '\p{Bc=nsm}', "");
Expect(0, 917999, '\p{^Bc=nsm}', "");
Expect(0, 917999, '\P{Bc=nsm}', "");
Expect(1, 917999, '\P{^Bc=nsm}', "");
Expect(0, 918000, '\p{Bc=nsm}', "");
Expect(1, 918000, '\p{^Bc=nsm}', "");
Expect(1, 918000, '\P{Bc=nsm}', "");
Expect(0, 918000, '\P{^Bc=nsm}', "");
Expect(1, 917999, '\p{Bc=	nsm}', "");
Expect(0, 917999, '\p{^Bc=	nsm}', "");
Expect(0, 917999, '\P{Bc=	nsm}', "");
Expect(1, 917999, '\P{^Bc=	nsm}', "");
Expect(0, 918000, '\p{Bc=	nsm}', "");
Expect(1, 918000, '\p{^Bc=	nsm}', "");
Expect(1, 918000, '\P{Bc=	nsm}', "");
Expect(0, 918000, '\P{^Bc=	nsm}', "");
Error('\p{Is_Bidi_Class= /a/NONSPACING_Mark}');
Error('\P{Is_Bidi_Class= /a/NONSPACING_Mark}');
Expect(1, 917999, '\p{Is_Bidi_Class=nonspacingmark}', "");
Expect(0, 917999, '\p{^Is_Bidi_Class=nonspacingmark}', "");
Expect(0, 917999, '\P{Is_Bidi_Class=nonspacingmark}', "");
Expect(1, 917999, '\P{^Is_Bidi_Class=nonspacingmark}', "");
Expect(0, 918000, '\p{Is_Bidi_Class=nonspacingmark}', "");
Expect(1, 918000, '\p{^Is_Bidi_Class=nonspacingmark}', "");
Expect(1, 918000, '\P{Is_Bidi_Class=nonspacingmark}', "");
Expect(0, 918000, '\P{^Is_Bidi_Class=nonspacingmark}', "");
Expect(1, 917999, '\p{Is_Bidi_Class=	-NONSPACING_MARK}', "");
Expect(0, 917999, '\p{^Is_Bidi_Class=	-NONSPACING_MARK}', "");
Expect(0, 917999, '\P{Is_Bidi_Class=	-NONSPACING_MARK}', "");
Expect(1, 917999, '\P{^Is_Bidi_Class=	-NONSPACING_MARK}', "");
Expect(0, 918000, '\p{Is_Bidi_Class=	-NONSPACING_MARK}', "");
Expect(1, 918000, '\p{^Is_Bidi_Class=	-NONSPACING_MARK}', "");
Expect(1, 918000, '\P{Is_Bidi_Class=	-NONSPACING_MARK}', "");
Expect(0, 918000, '\P{^Is_Bidi_Class=	-NONSPACING_MARK}', "");
Error('\p{Is_Bc=_ NSM/a/}');
Error('\P{Is_Bc=_ NSM/a/}');
Expect(1, 917999, '\p{Is_Bc=nsm}', "");
Expect(0, 917999, '\p{^Is_Bc=nsm}', "");
Expect(0, 917999, '\P{Is_Bc=nsm}', "");
Expect(1, 917999, '\P{^Is_Bc=nsm}', "");
Expect(0, 918000, '\p{Is_Bc=nsm}', "");
Expect(1, 918000, '\p{^Is_Bc=nsm}', "");
Expect(1, 918000, '\P{Is_Bc=nsm}', "");
Expect(0, 918000, '\P{^Is_Bc=nsm}', "");
Expect(1, 917999, '\p{Is_Bc=-nsm}', "");
Expect(0, 917999, '\p{^Is_Bc=-nsm}', "");
Expect(0, 917999, '\P{Is_Bc=-nsm}', "");
Expect(1, 917999, '\P{^Is_Bc=-nsm}', "");
Expect(0, 918000, '\p{Is_Bc=-nsm}', "");
Expect(1, 918000, '\p{^Is_Bc=-nsm}', "");
Expect(1, 918000, '\P{Is_Bc=-nsm}', "");
Expect(0, 918000, '\P{^Is_Bc=-nsm}', "");
Error('\p{Bidi_Class= :=OTHER_Neutral}');
Error('\P{Bidi_Class= :=OTHER_Neutral}');
Expect(1, 128883, '\p{Bidi_Class=otherneutral}', "");
Expect(0, 128883, '\p{^Bidi_Class=otherneutral}', "");
Expect(0, 128883, '\P{Bidi_Class=otherneutral}', "");
Expect(1, 128883, '\P{^Bidi_Class=otherneutral}', "");
Expect(0, 128884, '\p{Bidi_Class=otherneutral}', "");
Expect(1, 128884, '\p{^Bidi_Class=otherneutral}', "");
Expect(1, 128884, '\P{Bidi_Class=otherneutral}', "");
Expect(0, 128884, '\P{^Bidi_Class=otherneutral}', "");
Expect(1, 128883, '\p{Bidi_Class=	Other_Neutral}', "");
Expect(0, 128883, '\p{^Bidi_Class=	Other_Neutral}', "");
Expect(0, 128883, '\P{Bidi_Class=	Other_Neutral}', "");
Expect(1, 128883, '\P{^Bidi_Class=	Other_Neutral}', "");
Expect(0, 128884, '\p{Bidi_Class=	Other_Neutral}', "");
Expect(1, 128884, '\p{^Bidi_Class=	Other_Neutral}', "");
Expect(1, 128884, '\P{Bidi_Class=	Other_Neutral}', "");
Expect(0, 128884, '\P{^Bidi_Class=	Other_Neutral}', "");
Error('\p{Bc=-ON/a/}');
Error('\P{Bc=-ON/a/}');
Expect(1, 128883, '\p{Bc=on}', "");
Expect(0, 128883, '\p{^Bc=on}', "");
Expect(0, 128883, '\P{Bc=on}', "");
Expect(1, 128883, '\P{^Bc=on}', "");
Expect(0, 128884, '\p{Bc=on}', "");
Expect(1, 128884, '\p{^Bc=on}', "");
Expect(1, 128884, '\P{Bc=on}', "");
Expect(0, 128884, '\P{^Bc=on}', "");
Expect(1, 128883, '\p{Bc= on}', "");
Expect(0, 128883, '\p{^Bc= on}', "");
Expect(0, 128883, '\P{Bc= on}', "");
Expect(1, 128883, '\P{^Bc= on}', "");
Expect(0, 128884, '\p{Bc= on}', "");
Expect(1, 128884, '\p{^Bc= on}', "");
Expect(1, 128884, '\P{Bc= on}', "");
Expect(0, 128884, '\P{^Bc= on}', "");
Error('\p{Is_Bidi_Class=-	other_Neutral:=}');
Error('\P{Is_Bidi_Class=-	other_Neutral:=}');
Expect(1, 128883, '\p{Is_Bidi_Class=otherneutral}', "");
Expect(0, 128883, '\p{^Is_Bidi_Class=otherneutral}', "");
Expect(0, 128883, '\P{Is_Bidi_Class=otherneutral}', "");
Expect(1, 128883, '\P{^Is_Bidi_Class=otherneutral}', "");
Expect(0, 128884, '\p{Is_Bidi_Class=otherneutral}', "");
Expect(1, 128884, '\p{^Is_Bidi_Class=otherneutral}', "");
Expect(1, 128884, '\P{Is_Bidi_Class=otherneutral}', "");
Expect(0, 128884, '\P{^Is_Bidi_Class=otherneutral}', "");
Expect(1, 128883, '\p{Is_Bidi_Class= 	Other_NEUTRAL}', "");
Expect(0, 128883, '\p{^Is_Bidi_Class= 	Other_NEUTRAL}', "");
Expect(0, 128883, '\P{Is_Bidi_Class= 	Other_NEUTRAL}', "");
Expect(1, 128883, '\P{^Is_Bidi_Class= 	Other_NEUTRAL}', "");
Expect(0, 128884, '\p{Is_Bidi_Class= 	Other_NEUTRAL}', "");
Expect(1, 128884, '\p{^Is_Bidi_Class= 	Other_NEUTRAL}', "");
Expect(1, 128884, '\P{Is_Bidi_Class= 	Other_NEUTRAL}', "");
Expect(0, 128884, '\P{^Is_Bidi_Class= 	Other_NEUTRAL}', "");
Error('\p{Is_Bc=_:=on}');
Error('\P{Is_Bc=_:=on}');
Expect(1, 128883, '\p{Is_Bc=on}', "");
Expect(0, 128883, '\p{^Is_Bc=on}', "");
Expect(0, 128883, '\P{Is_Bc=on}', "");
Expect(1, 128883, '\P{^Is_Bc=on}', "");
Expect(0, 128884, '\p{Is_Bc=on}', "");
Expect(1, 128884, '\p{^Is_Bc=on}', "");
Expect(1, 128884, '\P{Is_Bc=on}', "");
Expect(0, 128884, '\P{^Is_Bc=on}', "");
Expect(1, 128883, '\p{Is_Bc=	ON}', "");
Expect(0, 128883, '\p{^Is_Bc=	ON}', "");
Expect(0, 128883, '\P{Is_Bc=	ON}', "");
Expect(1, 128883, '\P{^Is_Bc=	ON}', "");
Expect(0, 128884, '\p{Is_Bc=	ON}', "");
Expect(1, 128884, '\p{^Is_Bc=	ON}', "");
Expect(1, 128884, '\P{Is_Bc=	ON}', "");
Expect(0, 128884, '\P{^Is_Bc=	ON}', "");
Error('\p{Bidi_Class:	/a/ _POP_Directional_format}');
Error('\P{Bidi_Class:	/a/ _POP_Directional_format}');
Expect(1, 8236, '\p{Bidi_Class=popdirectionalformat}', "");
Expect(0, 8236, '\p{^Bidi_Class=popdirectionalformat}', "");
Expect(0, 8236, '\P{Bidi_Class=popdirectionalformat}', "");
Expect(1, 8236, '\P{^Bidi_Class=popdirectionalformat}', "");
Expect(0, 8237, '\p{Bidi_Class=popdirectionalformat}', "");
Expect(1, 8237, '\p{^Bidi_Class=popdirectionalformat}', "");
Expect(1, 8237, '\P{Bidi_Class=popdirectionalformat}', "");
Expect(0, 8237, '\P{^Bidi_Class=popdirectionalformat}', "");
Expect(1, 8236, '\p{Bidi_Class=	_Pop_DIRECTIONAL_format}', "");
Expect(0, 8236, '\p{^Bidi_Class=	_Pop_DIRECTIONAL_format}', "");
Expect(0, 8236, '\P{Bidi_Class=	_Pop_DIRECTIONAL_format}', "");
Expect(1, 8236, '\P{^Bidi_Class=	_Pop_DIRECTIONAL_format}', "");
Expect(0, 8237, '\p{Bidi_Class=	_Pop_DIRECTIONAL_format}', "");
Expect(1, 8237, '\p{^Bidi_Class=	_Pop_DIRECTIONAL_format}', "");
Expect(1, 8237, '\P{Bidi_Class=	_Pop_DIRECTIONAL_format}', "");
Expect(0, 8237, '\P{^Bidi_Class=	_Pop_DIRECTIONAL_format}', "");
Error('\p{Bc=/a/-PDF}');
Error('\P{Bc=/a/-PDF}');
Expect(1, 8236, '\p{Bc: pdf}', "");
Expect(0, 8236, '\p{^Bc: pdf}', "");
Expect(0, 8236, '\P{Bc: pdf}', "");
Expect(1, 8236, '\P{^Bc: pdf}', "");
Expect(0, 8237, '\p{Bc: pdf}', "");
Expect(1, 8237, '\p{^Bc: pdf}', "");
Expect(1, 8237, '\P{Bc: pdf}', "");
Expect(0, 8237, '\P{^Bc: pdf}', "");
Expect(1, 8236, '\p{Bc=--PDF}', "");
Expect(0, 8236, '\p{^Bc=--PDF}', "");
Expect(0, 8236, '\P{Bc=--PDF}', "");
Expect(1, 8236, '\P{^Bc=--PDF}', "");
Expect(0, 8237, '\p{Bc=--PDF}', "");
Expect(1, 8237, '\p{^Bc=--PDF}', "");
Expect(1, 8237, '\P{Bc=--PDF}', "");
Expect(0, 8237, '\P{^Bc=--PDF}', "");
Error('\p{Is_Bidi_Class= Pop_directional_Format:=}');
Error('\P{Is_Bidi_Class= Pop_directional_Format:=}');
Expect(1, 8236, '\p{Is_Bidi_Class=popdirectionalformat}', "");
Expect(0, 8236, '\p{^Is_Bidi_Class=popdirectionalformat}', "");
Expect(0, 8236, '\P{Is_Bidi_Class=popdirectionalformat}', "");
Expect(1, 8236, '\P{^Is_Bidi_Class=popdirectionalformat}', "");
Expect(0, 8237, '\p{Is_Bidi_Class=popdirectionalformat}', "");
Expect(1, 8237, '\p{^Is_Bidi_Class=popdirectionalformat}', "");
Expect(1, 8237, '\P{Is_Bidi_Class=popdirectionalformat}', "");
Expect(0, 8237, '\P{^Is_Bidi_Class=popdirectionalformat}', "");
Expect(1, 8236, '\p{Is_Bidi_Class=Pop_DIRECTIONAL_format}', "");
Expect(0, 8236, '\p{^Is_Bidi_Class=Pop_DIRECTIONAL_format}', "");
Expect(0, 8236, '\P{Is_Bidi_Class=Pop_DIRECTIONAL_format}', "");
Expect(1, 8236, '\P{^Is_Bidi_Class=Pop_DIRECTIONAL_format}', "");
Expect(0, 8237, '\p{Is_Bidi_Class=Pop_DIRECTIONAL_format}', "");
Expect(1, 8237, '\p{^Is_Bidi_Class=Pop_DIRECTIONAL_format}', "");
Expect(1, 8237, '\P{Is_Bidi_Class=Pop_DIRECTIONAL_format}', "");
Expect(0, 8237, '\P{^Is_Bidi_Class=Pop_DIRECTIONAL_format}', "");
Error('\p{Is_Bc=:=_pdf}');
Error('\P{Is_Bc=:=_pdf}');
Expect(1, 8236, '\p{Is_Bc=pdf}', "");
Expect(0, 8236, '\p{^Is_Bc=pdf}', "");
Expect(0, 8236, '\P{Is_Bc=pdf}', "");
Expect(1, 8236, '\P{^Is_Bc=pdf}', "");
Expect(0, 8237, '\p{Is_Bc=pdf}', "");
Expect(1, 8237, '\p{^Is_Bc=pdf}', "");
Expect(1, 8237, '\P{Is_Bc=pdf}', "");
Expect(0, 8237, '\P{^Is_Bc=pdf}', "");
Expect(1, 8236, '\p{Is_Bc=	-pdf}', "");
Expect(0, 8236, '\p{^Is_Bc=	-pdf}', "");
Expect(0, 8236, '\P{Is_Bc=	-pdf}', "");
Expect(1, 8236, '\P{^Is_Bc=	-pdf}', "");
Expect(0, 8237, '\p{Is_Bc=	-pdf}', "");
Expect(1, 8237, '\p{^Is_Bc=	-pdf}', "");
Expect(1, 8237, '\P{Is_Bc=	-pdf}', "");
Expect(0, 8237, '\P{^Is_Bc=	-pdf}', "");
Error('\p{Bidi_Class=  Pop_Directional_isolate:=}');
Error('\P{Bidi_Class=  Pop_Directional_isolate:=}');
Expect(1, 8297, '\p{Bidi_Class=popdirectionalisolate}', "");
Expect(0, 8297, '\p{^Bidi_Class=popdirectionalisolate}', "");
Expect(0, 8297, '\P{Bidi_Class=popdirectionalisolate}', "");
Expect(1, 8297, '\P{^Bidi_Class=popdirectionalisolate}', "");
Expect(0, 8298, '\p{Bidi_Class=popdirectionalisolate}', "");
Expect(1, 8298, '\p{^Bidi_Class=popdirectionalisolate}', "");
Expect(1, 8298, '\P{Bidi_Class=popdirectionalisolate}', "");
Expect(0, 8298, '\P{^Bidi_Class=popdirectionalisolate}', "");
Expect(1, 8297, '\p{Bidi_Class=_ Pop_DIRECTIONAL_Isolate}', "");
Expect(0, 8297, '\p{^Bidi_Class=_ Pop_DIRECTIONAL_Isolate}', "");
Expect(0, 8297, '\P{Bidi_Class=_ Pop_DIRECTIONAL_Isolate}', "");
Expect(1, 8297, '\P{^Bidi_Class=_ Pop_DIRECTIONAL_Isolate}', "");
Expect(0, 8298, '\p{Bidi_Class=_ Pop_DIRECTIONAL_Isolate}', "");
Expect(1, 8298, '\p{^Bidi_Class=_ Pop_DIRECTIONAL_Isolate}', "");
Expect(1, 8298, '\P{Bidi_Class=_ Pop_DIRECTIONAL_Isolate}', "");
Expect(0, 8298, '\P{^Bidi_Class=_ Pop_DIRECTIONAL_Isolate}', "");
Error('\p{Bc=_/a/PDI}');
Error('\P{Bc=_/a/PDI}');
Expect(1, 8297, '\p{Bc=pdi}', "");
Expect(0, 8297, '\p{^Bc=pdi}', "");
Expect(0, 8297, '\P{Bc=pdi}', "");
Expect(1, 8297, '\P{^Bc=pdi}', "");
Expect(0, 8298, '\p{Bc=pdi}', "");
Expect(1, 8298, '\p{^Bc=pdi}', "");
Expect(1, 8298, '\P{Bc=pdi}', "");
Expect(0, 8298, '\P{^Bc=pdi}', "");
Expect(1, 8297, '\p{Bc= PDI}', "");
Expect(0, 8297, '\p{^Bc= PDI}', "");
Expect(0, 8297, '\P{Bc= PDI}', "");
Expect(1, 8297, '\P{^Bc= PDI}', "");
Expect(0, 8298, '\p{Bc= PDI}', "");
Expect(1, 8298, '\p{^Bc= PDI}', "");
Expect(1, 8298, '\P{Bc= PDI}', "");
Expect(0, 8298, '\P{^Bc= PDI}', "");
Error('\p{Is_Bidi_Class= POP_Directional_Isolate:=}');
Error('\P{Is_Bidi_Class= POP_Directional_Isolate:=}');
Expect(1, 8297, '\p{Is_Bidi_Class:   popdirectionalisolate}', "");
Expect(0, 8297, '\p{^Is_Bidi_Class:   popdirectionalisolate}', "");
Expect(0, 8297, '\P{Is_Bidi_Class:   popdirectionalisolate}', "");
Expect(1, 8297, '\P{^Is_Bidi_Class:   popdirectionalisolate}', "");
Expect(0, 8298, '\p{Is_Bidi_Class:   popdirectionalisolate}', "");
Expect(1, 8298, '\p{^Is_Bidi_Class:   popdirectionalisolate}', "");
Expect(1, 8298, '\P{Is_Bidi_Class:   popdirectionalisolate}', "");
Expect(0, 8298, '\P{^Is_Bidi_Class:   popdirectionalisolate}', "");
Expect(1, 8297, '\p{Is_Bidi_Class=_Pop_Directional_ISOLATE}', "");
Expect(0, 8297, '\p{^Is_Bidi_Class=_Pop_Directional_ISOLATE}', "");
Expect(0, 8297, '\P{Is_Bidi_Class=_Pop_Directional_ISOLATE}', "");
Expect(1, 8297, '\P{^Is_Bidi_Class=_Pop_Directional_ISOLATE}', "");
Expect(0, 8298, '\p{Is_Bidi_Class=_Pop_Directional_ISOLATE}', "");
Expect(1, 8298, '\p{^Is_Bidi_Class=_Pop_Directional_ISOLATE}', "");
Expect(1, 8298, '\P{Is_Bidi_Class=_Pop_Directional_ISOLATE}', "");
Expect(0, 8298, '\P{^Is_Bidi_Class=_Pop_Directional_ISOLATE}', "");
Error('\p{Is_Bc=:=PDI}');
Error('\P{Is_Bc=:=PDI}');
Expect(1, 8297, '\p{Is_Bc=pdi}', "");
Expect(0, 8297, '\p{^Is_Bc=pdi}', "");
Expect(0, 8297, '\P{Is_Bc=pdi}', "");
Expect(1, 8297, '\P{^Is_Bc=pdi}', "");
Expect(0, 8298, '\p{Is_Bc=pdi}', "");
Expect(1, 8298, '\p{^Is_Bc=pdi}', "");
Expect(1, 8298, '\P{Is_Bc=pdi}', "");
Expect(0, 8298, '\P{^Is_Bc=pdi}', "");
Expect(1, 8297, '\p{Is_Bc=	PDI}', "");
Expect(0, 8297, '\p{^Is_Bc=	PDI}', "");
Expect(0, 8297, '\P{Is_Bc=	PDI}', "");
Expect(1, 8297, '\P{^Is_Bc=	PDI}', "");
Expect(0, 8298, '\p{Is_Bc=	PDI}', "");
Expect(1, 8298, '\p{^Is_Bc=	PDI}', "");
Expect(1, 8298, '\P{Is_Bc=	PDI}', "");
Expect(0, 8298, '\P{^Is_Bc=	PDI}', "");
Error('\p{Bidi_Class=		Right_to_Left:=}');
Error('\P{Bidi_Class=		Right_to_Left:=}');
Expect(1, 126975, '\p{Bidi_Class=righttoleft}', "");
Expect(0, 126975, '\p{^Bidi_Class=righttoleft}', "");
Expect(0, 126975, '\P{Bidi_Class=righttoleft}', "");
Expect(1, 126975, '\P{^Bidi_Class=righttoleft}', "");
Expect(0, 126976, '\p{Bidi_Class=righttoleft}', "");
Expect(1, 126976, '\p{^Bidi_Class=righttoleft}', "");
Expect(1, 126976, '\P{Bidi_Class=righttoleft}', "");
Expect(0, 126976, '\P{^Bidi_Class=righttoleft}', "");
Expect(1, 126975, '\p{Bidi_Class=  Right_To_Left}', "");
Expect(0, 126975, '\p{^Bidi_Class=  Right_To_Left}', "");
Expect(0, 126975, '\P{Bidi_Class=  Right_To_Left}', "");
Expect(1, 126975, '\P{^Bidi_Class=  Right_To_Left}', "");
Expect(0, 126976, '\p{Bidi_Class=  Right_To_Left}', "");
Expect(1, 126976, '\p{^Bidi_Class=  Right_To_Left}', "");
Expect(1, 126976, '\P{Bidi_Class=  Right_To_Left}', "");
Expect(0, 126976, '\P{^Bidi_Class=  Right_To_Left}', "");
Error('\p{Bc=	/a/R}');
Error('\P{Bc=	/a/R}');
Expect(1, 126975, '\p{Bc=r}', "");
Expect(0, 126975, '\p{^Bc=r}', "");
Expect(0, 126975, '\P{Bc=r}', "");
Expect(1, 126975, '\P{^Bc=r}', "");
Expect(0, 126976, '\p{Bc=r}', "");
Expect(1, 126976, '\p{^Bc=r}', "");
Expect(1, 126976, '\P{Bc=r}', "");
Expect(0, 126976, '\P{^Bc=r}', "");
Expect(1, 126975, '\p{Bc=-_r}', "");
Expect(0, 126975, '\p{^Bc=-_r}', "");
Expect(0, 126975, '\P{Bc=-_r}', "");
Expect(1, 126975, '\P{^Bc=-_r}', "");
Expect(0, 126976, '\p{Bc=-_r}', "");
Expect(1, 126976, '\p{^Bc=-_r}', "");
Expect(1, 126976, '\P{Bc=-_r}', "");
Expect(0, 126976, '\P{^Bc=-_r}', "");
Error('\p{Is_Bidi_Class=	Right_To_LEFT:=}');
Error('\P{Is_Bidi_Class=	Right_To_LEFT:=}');
Expect(1, 126975, '\p{Is_Bidi_Class=righttoleft}', "");
Expect(0, 126975, '\p{^Is_Bidi_Class=righttoleft}', "");
Expect(0, 126975, '\P{Is_Bidi_Class=righttoleft}', "");
Expect(1, 126975, '\P{^Is_Bidi_Class=righttoleft}', "");
Expect(0, 126976, '\p{Is_Bidi_Class=righttoleft}', "");
Expect(1, 126976, '\p{^Is_Bidi_Class=righttoleft}', "");
Expect(1, 126976, '\P{Is_Bidi_Class=righttoleft}', "");
Expect(0, 126976, '\P{^Is_Bidi_Class=righttoleft}', "");
Expect(1, 126975, '\p{Is_Bidi_Class= 	Right_TO_LEFT}', "");
Expect(0, 126975, '\p{^Is_Bidi_Class= 	Right_TO_LEFT}', "");
Expect(0, 126975, '\P{Is_Bidi_Class= 	Right_TO_LEFT}', "");
Expect(1, 126975, '\P{^Is_Bidi_Class= 	Right_TO_LEFT}', "");
Expect(0, 126976, '\p{Is_Bidi_Class= 	Right_TO_LEFT}', "");
Expect(1, 126976, '\p{^Is_Bidi_Class= 	Right_TO_LEFT}', "");
Expect(1, 126976, '\P{Is_Bidi_Class= 	Right_TO_LEFT}', "");
Expect(0, 126976, '\P{^Is_Bidi_Class= 	Right_TO_LEFT}', "");
Error('\p{Is_Bc=-R:=}');
Error('\P{Is_Bc=-R:=}');
Expect(1, 126975, '\p{Is_Bc=r}', "");
Expect(0, 126975, '\p{^Is_Bc=r}', "");
Expect(0, 126975, '\P{Is_Bc=r}', "");
Expect(1, 126975, '\P{^Is_Bc=r}', "");
Expect(0, 126976, '\p{Is_Bc=r}', "");
Expect(1, 126976, '\p{^Is_Bc=r}', "");
Expect(1, 126976, '\P{Is_Bc=r}', "");
Expect(0, 126976, '\P{^Is_Bc=r}', "");
Expect(1, 126975, '\p{Is_Bc:	_R}', "");
Expect(0, 126975, '\p{^Is_Bc:	_R}', "");
Expect(0, 126975, '\P{Is_Bc:	_R}', "");
Expect(1, 126975, '\P{^Is_Bc:	_R}', "");
Expect(0, 126976, '\p{Is_Bc:	_R}', "");
Expect(1, 126976, '\p{^Is_Bc:	_R}', "");
Expect(1, 126976, '\P{Is_Bc:	_R}', "");
Expect(0, 126976, '\P{^Is_Bc:	_R}', "");
Error('\p{Bidi_Class=-_Right_TO_left_EMBEDDING:=}');
Error('\P{Bidi_Class=-_Right_TO_left_EMBEDDING:=}');
Expect(1, 8235, '\p{Bidi_Class=righttoleftembedding}', "");
Expect(0, 8235, '\p{^Bidi_Class=righttoleftembedding}', "");
Expect(0, 8235, '\P{Bidi_Class=righttoleftembedding}', "");
Expect(1, 8235, '\P{^Bidi_Class=righttoleftembedding}', "");
Expect(0, 8236, '\p{Bidi_Class=righttoleftembedding}', "");
Expect(1, 8236, '\p{^Bidi_Class=righttoleftembedding}', "");
Expect(1, 8236, '\P{Bidi_Class=righttoleftembedding}', "");
Expect(0, 8236, '\P{^Bidi_Class=righttoleftembedding}', "");
Expect(1, 8235, '\p{Bidi_Class=_Right_TO_Left_EMBEDDING}', "");
Expect(0, 8235, '\p{^Bidi_Class=_Right_TO_Left_EMBEDDING}', "");
Expect(0, 8235, '\P{Bidi_Class=_Right_TO_Left_EMBEDDING}', "");
Expect(1, 8235, '\P{^Bidi_Class=_Right_TO_Left_EMBEDDING}', "");
Expect(0, 8236, '\p{Bidi_Class=_Right_TO_Left_EMBEDDING}', "");
Expect(1, 8236, '\p{^Bidi_Class=_Right_TO_Left_EMBEDDING}', "");
Expect(1, 8236, '\P{Bidi_Class=_Right_TO_Left_EMBEDDING}', "");
Expect(0, 8236, '\P{^Bidi_Class=_Right_TO_Left_EMBEDDING}', "");
Error('\p{Bc=_ RLE/a/}');
Error('\P{Bc=_ RLE/a/}');
Expect(1, 8235, '\p{Bc=rle}', "");
Expect(0, 8235, '\p{^Bc=rle}', "");
Expect(0, 8235, '\P{Bc=rle}', "");
Expect(1, 8235, '\P{^Bc=rle}', "");
Expect(0, 8236, '\p{Bc=rle}', "");
Expect(1, 8236, '\p{^Bc=rle}', "");
Expect(1, 8236, '\P{Bc=rle}', "");
Expect(0, 8236, '\P{^Bc=rle}', "");
Expect(1, 8235, '\p{Bc= RLE}', "");
Expect(0, 8235, '\p{^Bc= RLE}', "");
Expect(0, 8235, '\P{Bc= RLE}', "");
Expect(1, 8235, '\P{^Bc= RLE}', "");
Expect(0, 8236, '\p{Bc= RLE}', "");
Expect(1, 8236, '\p{^Bc= RLE}', "");
Expect(1, 8236, '\P{Bc= RLE}', "");
Expect(0, 8236, '\P{^Bc= RLE}', "");
Error('\p{Is_Bidi_Class:	:= 	Right_TO_left_EMBEDDING}');
Error('\P{Is_Bidi_Class:	:= 	Right_TO_left_EMBEDDING}');
Expect(1, 8235, '\p{Is_Bidi_Class=righttoleftembedding}', "");
Expect(0, 8235, '\p{^Is_Bidi_Class=righttoleftembedding}', "");
Expect(0, 8235, '\P{Is_Bidi_Class=righttoleftembedding}', "");
Expect(1, 8235, '\P{^Is_Bidi_Class=righttoleftembedding}', "");
Expect(0, 8236, '\p{Is_Bidi_Class=righttoleftembedding}', "");
Expect(1, 8236, '\p{^Is_Bidi_Class=righttoleftembedding}', "");
Expect(1, 8236, '\P{Is_Bidi_Class=righttoleftembedding}', "");
Expect(0, 8236, '\P{^Is_Bidi_Class=righttoleftembedding}', "");
Expect(1, 8235, '\p{Is_Bidi_Class=-Right_To_Left_EMBEDDING}', "");
Expect(0, 8235, '\p{^Is_Bidi_Class=-Right_To_Left_EMBEDDING}', "");
Expect(0, 8235, '\P{Is_Bidi_Class=-Right_To_Left_EMBEDDING}', "");
Expect(1, 8235, '\P{^Is_Bidi_Class=-Right_To_Left_EMBEDDING}', "");
Expect(0, 8236, '\p{Is_Bidi_Class=-Right_To_Left_EMBEDDING}', "");
Expect(1, 8236, '\p{^Is_Bidi_Class=-Right_To_Left_EMBEDDING}', "");
Expect(1, 8236, '\P{Is_Bidi_Class=-Right_To_Left_EMBEDDING}', "");
Expect(0, 8236, '\P{^Is_Bidi_Class=-Right_To_Left_EMBEDDING}', "");
Error('\p{Is_Bc=-/a/RLE}');
Error('\P{Is_Bc=-/a/RLE}');
Expect(1, 8235, '\p{Is_Bc=rle}', "");
Expect(0, 8235, '\p{^Is_Bc=rle}', "");
Expect(0, 8235, '\P{Is_Bc=rle}', "");
Expect(1, 8235, '\P{^Is_Bc=rle}', "");
Expect(0, 8236, '\p{Is_Bc=rle}', "");
Expect(1, 8236, '\p{^Is_Bc=rle}', "");
Expect(1, 8236, '\P{Is_Bc=rle}', "");
Expect(0, 8236, '\P{^Is_Bc=rle}', "");
Expect(1, 8235, '\p{Is_Bc=__RLE}', "");
Expect(0, 8235, '\p{^Is_Bc=__RLE}', "");
Expect(0, 8235, '\P{Is_Bc=__RLE}', "");
Expect(1, 8235, '\P{^Is_Bc=__RLE}', "");
Expect(0, 8236, '\p{Is_Bc=__RLE}', "");
Expect(1, 8236, '\p{^Is_Bc=__RLE}', "");
Expect(1, 8236, '\P{Is_Bc=__RLE}', "");
Expect(0, 8236, '\P{^Is_Bc=__RLE}', "");
Error('\p{Bidi_Class=-/a/Right_TO_LEFT_ISOLATE}');
Error('\P{Bidi_Class=-/a/Right_TO_LEFT_ISOLATE}');
Expect(1, 8295, '\p{Bidi_Class=righttoleftisolate}', "");
Expect(0, 8295, '\p{^Bidi_Class=righttoleftisolate}', "");
Expect(0, 8295, '\P{Bidi_Class=righttoleftisolate}', "");
Expect(1, 8295, '\P{^Bidi_Class=righttoleftisolate}', "");
Expect(0, 8296, '\p{Bidi_Class=righttoleftisolate}', "");
Expect(1, 8296, '\p{^Bidi_Class=righttoleftisolate}', "");
Expect(1, 8296, '\P{Bidi_Class=righttoleftisolate}', "");
Expect(0, 8296, '\P{^Bidi_Class=righttoleftisolate}', "");
Expect(1, 8295, '\p{Bidi_Class=- RIGHT_To_LEFT_ISOLATE}', "");
Expect(0, 8295, '\p{^Bidi_Class=- RIGHT_To_LEFT_ISOLATE}', "");
Expect(0, 8295, '\P{Bidi_Class=- RIGHT_To_LEFT_ISOLATE}', "");
Expect(1, 8295, '\P{^Bidi_Class=- RIGHT_To_LEFT_ISOLATE}', "");
Expect(0, 8296, '\p{Bidi_Class=- RIGHT_To_LEFT_ISOLATE}', "");
Expect(1, 8296, '\p{^Bidi_Class=- RIGHT_To_LEFT_ISOLATE}', "");
Expect(1, 8296, '\P{Bidi_Class=- RIGHT_To_LEFT_ISOLATE}', "");
Expect(0, 8296, '\P{^Bidi_Class=- RIGHT_To_LEFT_ISOLATE}', "");
Error('\p{Bc= :=rli}');
Error('\P{Bc= :=rli}');
Expect(1, 8295, '\p{Bc=rli}', "");
Expect(0, 8295, '\p{^Bc=rli}', "");
Expect(0, 8295, '\P{Bc=rli}', "");
Expect(1, 8295, '\P{^Bc=rli}', "");
Expect(0, 8296, '\p{Bc=rli}', "");
Expect(1, 8296, '\p{^Bc=rli}', "");
Expect(1, 8296, '\P{Bc=rli}', "");
Expect(0, 8296, '\P{^Bc=rli}', "");
Error('\p{Is_Bidi_Class=-/a/Right_To_LEFT_isolate}');
Error('\P{Is_Bidi_Class=-/a/Right_To_LEFT_isolate}');
Expect(1, 8295, '\p{Is_Bidi_Class=righttoleftisolate}', "");
Expect(0, 8295, '\p{^Is_Bidi_Class=righttoleftisolate}', "");
Expect(0, 8295, '\P{Is_Bidi_Class=righttoleftisolate}', "");
Expect(1, 8295, '\P{^Is_Bidi_Class=righttoleftisolate}', "");
Expect(0, 8296, '\p{Is_Bidi_Class=righttoleftisolate}', "");
Expect(1, 8296, '\p{^Is_Bidi_Class=righttoleftisolate}', "");
Expect(1, 8296, '\P{Is_Bidi_Class=righttoleftisolate}', "");
Expect(0, 8296, '\P{^Is_Bidi_Class=righttoleftisolate}', "");
Expect(1, 8295, '\p{Is_Bidi_Class=	_Right_TO_left_ISOLATE}', "");
Expect(0, 8295, '\p{^Is_Bidi_Class=	_Right_TO_left_ISOLATE}', "");
Expect(0, 8295, '\P{Is_Bidi_Class=	_Right_TO_left_ISOLATE}', "");
Expect(1, 8295, '\P{^Is_Bidi_Class=	_Right_TO_left_ISOLATE}', "");
Expect(0, 8296, '\p{Is_Bidi_Class=	_Right_TO_left_ISOLATE}', "");
Expect(1, 8296, '\p{^Is_Bidi_Class=	_Right_TO_left_ISOLATE}', "");
Expect(1, 8296, '\P{Is_Bidi_Class=	_Right_TO_left_ISOLATE}', "");
Expect(0, 8296, '\P{^Is_Bidi_Class=	_Right_TO_left_ISOLATE}', "");
Error('\p{Is_Bc=_RLI/a/}');
Error('\P{Is_Bc=_RLI/a/}');
Expect(1, 8295, '\p{Is_Bc=rli}', "");
Expect(0, 8295, '\p{^Is_Bc=rli}', "");
Expect(0, 8295, '\P{Is_Bc=rli}', "");
Expect(1, 8295, '\P{^Is_Bc=rli}', "");
Expect(0, 8296, '\p{Is_Bc=rli}', "");
Expect(1, 8296, '\p{^Is_Bc=rli}', "");
Expect(1, 8296, '\P{Is_Bc=rli}', "");
Expect(0, 8296, '\P{^Is_Bc=rli}', "");
Expect(1, 8295, '\p{Is_Bc=	-RLI}', "");
Expect(0, 8295, '\p{^Is_Bc=	-RLI}', "");
Expect(0, 8295, '\P{Is_Bc=	-RLI}', "");
Expect(1, 8295, '\P{^Is_Bc=	-RLI}', "");
Expect(0, 8296, '\p{Is_Bc=	-RLI}', "");
Expect(1, 8296, '\p{^Is_Bc=	-RLI}', "");
Expect(1, 8296, '\P{Is_Bc=	-RLI}', "");
Expect(0, 8296, '\P{^Is_Bc=	-RLI}', "");
Error('\p{Bidi_Class=/a/_-right_To_Left_OVERRIDE}');
Error('\P{Bidi_Class=/a/_-right_To_Left_OVERRIDE}');
Expect(1, 8238, '\p{Bidi_Class=righttoleftoverride}', "");
Expect(0, 8238, '\p{^Bidi_Class=righttoleftoverride}', "");
Expect(0, 8238, '\P{Bidi_Class=righttoleftoverride}', "");
Expect(1, 8238, '\P{^Bidi_Class=righttoleftoverride}', "");
Expect(0, 8239, '\p{Bidi_Class=righttoleftoverride}', "");
Expect(1, 8239, '\p{^Bidi_Class=righttoleftoverride}', "");
Expect(1, 8239, '\P{Bidi_Class=righttoleftoverride}', "");
Expect(0, 8239, '\P{^Bidi_Class=righttoleftoverride}', "");
Expect(1, 8238, '\p{Bidi_Class=-Right_To_left_Override}', "");
Expect(0, 8238, '\p{^Bidi_Class=-Right_To_left_Override}', "");
Expect(0, 8238, '\P{Bidi_Class=-Right_To_left_Override}', "");
Expect(1, 8238, '\P{^Bidi_Class=-Right_To_left_Override}', "");
Expect(0, 8239, '\p{Bidi_Class=-Right_To_left_Override}', "");
Expect(1, 8239, '\p{^Bidi_Class=-Right_To_left_Override}', "");
Expect(1, 8239, '\P{Bidi_Class=-Right_To_left_Override}', "");
Expect(0, 8239, '\P{^Bidi_Class=-Right_To_left_Override}', "");
Error('\p{Bc= rlo:=}');
Error('\P{Bc= rlo:=}');
Expect(1, 8238, '\p{Bc=rlo}', "");
Expect(0, 8238, '\p{^Bc=rlo}', "");
Expect(0, 8238, '\P{Bc=rlo}', "");
Expect(1, 8238, '\P{^Bc=rlo}', "");
Expect(0, 8239, '\p{Bc=rlo}', "");
Expect(1, 8239, '\p{^Bc=rlo}', "");
Expect(1, 8239, '\P{Bc=rlo}', "");
Expect(0, 8239, '\P{^Bc=rlo}', "");
Expect(1, 8238, '\p{Bc=- RLO}', "");
Expect(0, 8238, '\p{^Bc=- RLO}', "");
Expect(0, 8238, '\P{Bc=- RLO}', "");
Expect(1, 8238, '\P{^Bc=- RLO}', "");
Expect(0, 8239, '\p{Bc=- RLO}', "");
Expect(1, 8239, '\p{^Bc=- RLO}', "");
Expect(1, 8239, '\P{Bc=- RLO}', "");
Expect(0, 8239, '\P{^Bc=- RLO}', "");
Error('\p{Is_Bidi_Class=/a/RIGHT_TO_Left_Override}');
Error('\P{Is_Bidi_Class=/a/RIGHT_TO_Left_Override}');
Expect(1, 8238, '\p{Is_Bidi_Class=righttoleftoverride}', "");
Expect(0, 8238, '\p{^Is_Bidi_Class=righttoleftoverride}', "");
Expect(0, 8238, '\P{Is_Bidi_Class=righttoleftoverride}', "");
Expect(1, 8238, '\P{^Is_Bidi_Class=righttoleftoverride}', "");
Expect(0, 8239, '\p{Is_Bidi_Class=righttoleftoverride}', "");
Expect(1, 8239, '\p{^Is_Bidi_Class=righttoleftoverride}', "");
Expect(1, 8239, '\P{Is_Bidi_Class=righttoleftoverride}', "");
Expect(0, 8239, '\P{^Is_Bidi_Class=righttoleftoverride}', "");
Expect(1, 8238, '\p{Is_Bidi_Class=	 RIGHT_To_Left_Override}', "");
Expect(0, 8238, '\p{^Is_Bidi_Class=	 RIGHT_To_Left_Override}', "");
Expect(0, 8238, '\P{Is_Bidi_Class=	 RIGHT_To_Left_Override}', "");
Expect(1, 8238, '\P{^Is_Bidi_Class=	 RIGHT_To_Left_Override}', "");
Expect(0, 8239, '\p{Is_Bidi_Class=	 RIGHT_To_Left_Override}', "");
Expect(1, 8239, '\p{^Is_Bidi_Class=	 RIGHT_To_Left_Override}', "");
Expect(1, 8239, '\P{Is_Bidi_Class=	 RIGHT_To_Left_Override}', "");
Expect(0, 8239, '\P{^Is_Bidi_Class=	 RIGHT_To_Left_Override}', "");
Error('\p{Is_Bc=-:=RLO}');
Error('\P{Is_Bc=-:=RLO}');
Expect(1, 8238, '\p{Is_Bc=rlo}', "");
Expect(0, 8238, '\p{^Is_Bc=rlo}', "");
Expect(0, 8238, '\P{Is_Bc=rlo}', "");
Expect(1, 8238, '\P{^Is_Bc=rlo}', "");
Expect(0, 8239, '\p{Is_Bc=rlo}', "");
Expect(1, 8239, '\p{^Is_Bc=rlo}', "");
Expect(1, 8239, '\P{Is_Bc=rlo}', "");
Expect(0, 8239, '\P{^Is_Bc=rlo}', "");
Expect(1, 8238, '\p{Is_Bc=	RLO}', "");
Expect(0, 8238, '\p{^Is_Bc=	RLO}', "");
Expect(0, 8238, '\P{Is_Bc=	RLO}', "");
Expect(1, 8238, '\P{^Is_Bc=	RLO}', "");
Expect(0, 8239, '\p{Is_Bc=	RLO}', "");
Expect(1, 8239, '\p{^Is_Bc=	RLO}', "");
Expect(1, 8239, '\P{Is_Bc=	RLO}', "");
Expect(0, 8239, '\P{^Is_Bc=	RLO}', "");
Error('\p{Bidi_Class=	/a/SEGMENT_Separator}');
Error('\P{Bidi_Class=	/a/SEGMENT_Separator}');
Expect(1, 31, '\p{Bidi_Class=segmentseparator}', "");
Expect(0, 31, '\p{^Bidi_Class=segmentseparator}', "");
Expect(0, 31, '\P{Bidi_Class=segmentseparator}', "");
Expect(1, 31, '\P{^Bidi_Class=segmentseparator}', "");
Expect(0, 32, '\p{Bidi_Class=segmentseparator}', "");
Expect(1, 32, '\p{^Bidi_Class=segmentseparator}', "");
Expect(1, 32, '\P{Bidi_Class=segmentseparator}', "");
Expect(0, 32, '\P{^Bidi_Class=segmentseparator}', "");
Expect(1, 31, '\p{Bidi_Class= 	Segment_Separator}', "");
Expect(0, 31, '\p{^Bidi_Class= 	Segment_Separator}', "");
Expect(0, 31, '\P{Bidi_Class= 	Segment_Separator}', "");
Expect(1, 31, '\P{^Bidi_Class= 	Segment_Separator}', "");
Expect(0, 32, '\p{Bidi_Class= 	Segment_Separator}', "");
Expect(1, 32, '\p{^Bidi_Class= 	Segment_Separator}', "");
Expect(1, 32, '\P{Bidi_Class= 	Segment_Separator}', "");
Expect(0, 32, '\P{^Bidi_Class= 	Segment_Separator}', "");
Error('\p{Bc= /a/S}');
Error('\P{Bc= /a/S}');
Expect(1, 31, '\p{Bc=s}', "");
Expect(0, 31, '\p{^Bc=s}', "");
Expect(0, 31, '\P{Bc=s}', "");
Expect(1, 31, '\P{^Bc=s}', "");
Expect(0, 32, '\p{Bc=s}', "");
Expect(1, 32, '\p{^Bc=s}', "");
Expect(1, 32, '\P{Bc=s}', "");
Expect(0, 32, '\P{^Bc=s}', "");
Expect(1, 31, '\p{Bc=-	S}', "");
Expect(0, 31, '\p{^Bc=-	S}', "");
Expect(0, 31, '\P{Bc=-	S}', "");
Expect(1, 31, '\P{^Bc=-	S}', "");
Expect(0, 32, '\p{Bc=-	S}', "");
Expect(1, 32, '\p{^Bc=-	S}', "");
Expect(1, 32, '\P{Bc=-	S}', "");
Expect(0, 32, '\P{^Bc=-	S}', "");
Error('\p{Is_Bidi_Class=/a/segment_SEPARATOR}');
Error('\P{Is_Bidi_Class=/a/segment_SEPARATOR}');
Expect(1, 31, '\p{Is_Bidi_Class=segmentseparator}', "");
Expect(0, 31, '\p{^Is_Bidi_Class=segmentseparator}', "");
Expect(0, 31, '\P{Is_Bidi_Class=segmentseparator}', "");
Expect(1, 31, '\P{^Is_Bidi_Class=segmentseparator}', "");
Expect(0, 32, '\p{Is_Bidi_Class=segmentseparator}', "");
Expect(1, 32, '\p{^Is_Bidi_Class=segmentseparator}', "");
Expect(1, 32, '\P{Is_Bidi_Class=segmentseparator}', "");
Expect(0, 32, '\P{^Is_Bidi_Class=segmentseparator}', "");
Expect(1, 31, '\p{Is_Bidi_Class:  -segment_Separator}', "");
Expect(0, 31, '\p{^Is_Bidi_Class:  -segment_Separator}', "");
Expect(0, 31, '\P{Is_Bidi_Class:  -segment_Separator}', "");
Expect(1, 31, '\P{^Is_Bidi_Class:  -segment_Separator}', "");
Expect(0, 32, '\p{Is_Bidi_Class:  -segment_Separator}', "");
Expect(1, 32, '\p{^Is_Bidi_Class:  -segment_Separator}', "");
Expect(1, 32, '\P{Is_Bidi_Class:  -segment_Separator}', "");
Expect(0, 32, '\P{^Is_Bidi_Class:  -segment_Separator}', "");
Error('\p{Is_Bc=_-s/a/}');
Error('\P{Is_Bc=_-s/a/}');
Expect(1, 31, '\p{Is_Bc=s}', "");
Expect(0, 31, '\p{^Is_Bc=s}', "");
Expect(0, 31, '\P{Is_Bc=s}', "");
Expect(1, 31, '\P{^Is_Bc=s}', "");
Expect(0, 32, '\p{Is_Bc=s}', "");
Expect(1, 32, '\p{^Is_Bc=s}', "");
Expect(1, 32, '\P{Is_Bc=s}', "");
Expect(0, 32, '\P{^Is_Bc=s}', "");
Expect(1, 31, '\p{Is_Bc:	-_s}', "");
Expect(0, 31, '\p{^Is_Bc:	-_s}', "");
Expect(0, 31, '\P{Is_Bc:	-_s}', "");
Expect(1, 31, '\P{^Is_Bc:	-_s}', "");
Expect(0, 32, '\p{Is_Bc:	-_s}', "");
Expect(1, 32, '\p{^Is_Bc:	-_s}', "");
Expect(1, 32, '\P{Is_Bc:	-_s}', "");
Expect(0, 32, '\P{^Is_Bc:	-_s}', "");
Error('\p{Bidi_Class=/a/		White_Space}');
Error('\P{Bidi_Class=/a/		White_Space}');
Expect(1, 12288, '\p{Bidi_Class:whitespace}', "");
Expect(0, 12288, '\p{^Bidi_Class:whitespace}', "");
Expect(0, 12288, '\P{Bidi_Class:whitespace}', "");
Expect(1, 12288, '\P{^Bidi_Class:whitespace}', "");
Expect(0, 12289, '\p{Bidi_Class:whitespace}', "");
Expect(1, 12289, '\p{^Bidi_Class:whitespace}', "");
Expect(1, 12289, '\P{Bidi_Class:whitespace}', "");
Expect(0, 12289, '\P{^Bidi_Class:whitespace}', "");
Expect(1, 12288, '\p{Bidi_Class= _white_space}', "");
Expect(0, 12288, '\p{^Bidi_Class= _white_space}', "");
Expect(0, 12288, '\P{Bidi_Class= _white_space}', "");
Expect(1, 12288, '\P{^Bidi_Class= _white_space}', "");
Expect(0, 12289, '\p{Bidi_Class= _white_space}', "");
Expect(1, 12289, '\p{^Bidi_Class= _white_space}', "");
Expect(1, 12289, '\P{Bidi_Class= _white_space}', "");
Expect(0, 12289, '\P{^Bidi_Class= _white_space}', "");
Error('\p{Bc=:=WS}');
Error('\P{Bc=:=WS}');
Expect(1, 12288, '\p{Bc=ws}', "");
Expect(0, 12288, '\p{^Bc=ws}', "");
Expect(0, 12288, '\P{Bc=ws}', "");
Expect(1, 12288, '\P{^Bc=ws}', "");
Expect(0, 12289, '\p{Bc=ws}', "");
Expect(1, 12289, '\p{^Bc=ws}', "");
Expect(1, 12289, '\P{Bc=ws}', "");
Expect(0, 12289, '\P{^Bc=ws}', "");
Expect(1, 12288, '\p{Bc= 	WS}', "");
Expect(0, 12288, '\p{^Bc= 	WS}', "");
Expect(0, 12288, '\P{Bc= 	WS}', "");
Expect(1, 12288, '\P{^Bc= 	WS}', "");
Expect(0, 12289, '\p{Bc= 	WS}', "");
Expect(1, 12289, '\p{^Bc= 	WS}', "");
Expect(1, 12289, '\P{Bc= 	WS}', "");
Expect(0, 12289, '\P{^Bc= 	WS}', "");
Error('\p{Is_Bidi_Class=	:=white_space}');
Error('\P{Is_Bidi_Class=	:=white_space}');
Expect(1, 12288, '\p{Is_Bidi_Class=whitespace}', "");
Expect(0, 12288, '\p{^Is_Bidi_Class=whitespace}', "");
Expect(0, 12288, '\P{Is_Bidi_Class=whitespace}', "");
Expect(1, 12288, '\P{^Is_Bidi_Class=whitespace}', "");
Expect(0, 12289, '\p{Is_Bidi_Class=whitespace}', "");
Expect(1, 12289, '\p{^Is_Bidi_Class=whitespace}', "");
Expect(1, 12289, '\P{Is_Bidi_Class=whitespace}', "");
Expect(0, 12289, '\P{^Is_Bidi_Class=whitespace}', "");
Expect(1, 12288, '\p{Is_Bidi_Class= _WHITE_SPACE}', "");
Expect(0, 12288, '\p{^Is_Bidi_Class= _WHITE_SPACE}', "");
Expect(0, 12288, '\P{Is_Bidi_Class= _WHITE_SPACE}', "");
Expect(1, 12288, '\P{^Is_Bidi_Class= _WHITE_SPACE}', "");
Expect(0, 12289, '\p{Is_Bidi_Class= _WHITE_SPACE}', "");
Expect(1, 12289, '\p{^Is_Bidi_Class= _WHITE_SPACE}', "");
Expect(1, 12289, '\P{Is_Bidi_Class= _WHITE_SPACE}', "");
Expect(0, 12289, '\P{^Is_Bidi_Class= _WHITE_SPACE}', "");
Error('\p{Is_Bc=	/a/WS}');
Error('\P{Is_Bc=	/a/WS}');
Expect(1, 12288, '\p{Is_Bc=ws}', "");
Expect(0, 12288, '\p{^Is_Bc=ws}', "");
Expect(0, 12288, '\P{Is_Bc=ws}', "");
Expect(1, 12288, '\P{^Is_Bc=ws}', "");
Expect(0, 12289, '\p{Is_Bc=ws}', "");
Expect(1, 12289, '\p{^Is_Bc=ws}', "");
Expect(1, 12289, '\P{Is_Bc=ws}', "");
Expect(0, 12289, '\P{^Is_Bc=ws}', "");
Expect(1, 12288, '\p{Is_Bc=-WS}', "");
Expect(0, 12288, '\p{^Is_Bc=-WS}', "");
Expect(0, 12288, '\P{Is_Bc=-WS}', "");
Expect(1, 12288, '\P{^Is_Bc=-WS}', "");
Expect(0, 12289, '\p{Is_Bc=-WS}', "");
Expect(1, 12289, '\p{^Is_Bc=-WS}', "");
Expect(1, 12289, '\P{Is_Bc=-WS}', "");
Expect(0, 12289, '\P{^Is_Bc=-WS}', "");
Error('\p{Block=:=_basic_latin}');
Error('\P{Block=:=_basic_latin}');
Expect(1, 127, '\p{Block=basiclatin}', "");
Expect(0, 127, '\p{^Block=basiclatin}', "");
Expect(0, 127, '\P{Block=basiclatin}', "");
Expect(1, 127, '\P{^Block=basiclatin}', "");
Expect(0, 128, '\p{Block=basiclatin}', "");
Expect(1, 128, '\p{^Block=basiclatin}', "");
Expect(1, 128, '\P{Block=basiclatin}', "");
Expect(0, 128, '\P{^Block=basiclatin}', "");
Expect(1, 127, '\p{Block=	 Basic_Latin}', "");
Expect(0, 127, '\p{^Block=	 Basic_Latin}', "");
Expect(0, 127, '\P{Block=	 Basic_Latin}', "");
Expect(1, 127, '\P{^Block=	 Basic_Latin}', "");
Expect(0, 128, '\p{Block=	 Basic_Latin}', "");
Expect(1, 128, '\p{^Block=	 Basic_Latin}', "");
Expect(1, 128, '\P{Block=	 Basic_Latin}', "");
Expect(0, 128, '\P{^Block=	 Basic_Latin}', "");
Error('\p{Blk= ASCII:=}');
Error('\P{Blk= ASCII:=}');
Expect(1, 127, '\p{Blk=ascii}', "");
Expect(0, 127, '\p{^Blk=ascii}', "");
Expect(0, 127, '\P{Blk=ascii}', "");
Expect(1, 127, '\P{^Blk=ascii}', "");
Expect(0, 128, '\p{Blk=ascii}', "");
Expect(1, 128, '\p{^Blk=ascii}', "");
Expect(1, 128, '\P{Blk=ascii}', "");
Expect(0, 128, '\P{^Blk=ascii}', "");
Expect(1, 127, '\p{Blk=_	ASCII}', "");
Expect(0, 127, '\p{^Blk=_	ASCII}', "");
Expect(0, 127, '\P{Blk=_	ASCII}', "");
Expect(1, 127, '\P{^Blk=_	ASCII}', "");
Expect(0, 128, '\p{Blk=_	ASCII}', "");
Expect(1, 128, '\p{^Blk=_	ASCII}', "");
Expect(1, 128, '\P{Blk=_	ASCII}', "");
Expect(0, 128, '\P{^Blk=_	ASCII}', "");
Error('\p{Is_Block=- BASIC_Latin/a/}');
Error('\P{Is_Block=- BASIC_Latin/a/}');
Expect(1, 127, '\p{Is_Block=basiclatin}', "");
Expect(0, 127, '\p{^Is_Block=basiclatin}', "");
Expect(0, 127, '\P{Is_Block=basiclatin}', "");
Expect(1, 127, '\P{^Is_Block=basiclatin}', "");
Expect(0, 128, '\p{Is_Block=basiclatin}', "");
Expect(1, 128, '\p{^Is_Block=basiclatin}', "");
Expect(1, 128, '\P{Is_Block=basiclatin}', "");
Expect(0, 128, '\P{^Is_Block=basiclatin}', "");
Expect(1, 127, '\p{Is_Block=Basic_Latin}', "");
Expect(0, 127, '\p{^Is_Block=Basic_Latin}', "");
Expect(0, 127, '\P{Is_Block=Basic_Latin}', "");
Expect(1, 127, '\P{^Is_Block=Basic_Latin}', "");
Expect(0, 128, '\p{Is_Block=Basic_Latin}', "");
Expect(1, 128, '\p{^Is_Block=Basic_Latin}', "");
Expect(1, 128, '\P{Is_Block=Basic_Latin}', "");
Expect(0, 128, '\P{^Is_Block=Basic_Latin}', "");
Error('\p{Is_Blk=	 ASCII:=}');
Error('\P{Is_Blk=	 ASCII:=}');
Expect(1, 127, '\p{Is_Blk=ascii}', "");
Expect(0, 127, '\p{^Is_Blk=ascii}', "");
Expect(0, 127, '\P{Is_Blk=ascii}', "");
Expect(1, 127, '\P{^Is_Blk=ascii}', "");
Expect(0, 128, '\p{Is_Blk=ascii}', "");
Expect(1, 128, '\p{^Is_Blk=ascii}', "");
Expect(1, 128, '\P{Is_Blk=ascii}', "");
Expect(0, 128, '\P{^Is_Blk=ascii}', "");
Expect(1, 127, '\p{Is_Blk=_ ASCII}', "");
Expect(0, 127, '\p{^Is_Blk=_ ASCII}', "");
Expect(0, 127, '\P{Is_Blk=_ ASCII}', "");
Expect(1, 127, '\P{^Is_Blk=_ ASCII}', "");
Expect(0, 128, '\p{Is_Blk=_ ASCII}', "");
Expect(1, 128, '\p{^Is_Blk=_ ASCII}', "");
Expect(1, 128, '\P{Is_Blk=_ ASCII}', "");
Expect(0, 128, '\P{^Is_Blk=_ ASCII}', "");
Error('\p{Block=  Aegean_Numbers:=}');
Error('\P{Block=  Aegean_Numbers:=}');
Expect(1, 65855, '\p{Block=aegeannumbers}', "");
Expect(0, 65855, '\p{^Block=aegeannumbers}', "");
Expect(0, 65855, '\P{Block=aegeannumbers}', "");
Expect(1, 65855, '\P{^Block=aegeannumbers}', "");
Expect(0, 65856, '\p{Block=aegeannumbers}', "");
Expect(1, 65856, '\p{^Block=aegeannumbers}', "");
Expect(1, 65856, '\P{Block=aegeannumbers}', "");
Expect(0, 65856, '\P{^Block=aegeannumbers}', "");
Expect(1, 65855, '\p{Block:--Aegean_numbers}', "");
Expect(0, 65855, '\p{^Block:--Aegean_numbers}', "");
Expect(0, 65855, '\P{Block:--Aegean_numbers}', "");
Expect(1, 65855, '\P{^Block:--Aegean_numbers}', "");
Expect(0, 65856, '\p{Block:--Aegean_numbers}', "");
Expect(1, 65856, '\p{^Block:--Aegean_numbers}', "");
Expect(1, 65856, '\P{Block:--Aegean_numbers}', "");
Expect(0, 65856, '\P{^Block:--Aegean_numbers}', "");
Error('\p{Blk::=Aegean_numbers}');
Error('\P{Blk::=Aegean_numbers}');
Expect(1, 65855, '\p{Blk=aegeannumbers}', "");
Expect(0, 65855, '\p{^Blk=aegeannumbers}', "");
Expect(0, 65855, '\P{Blk=aegeannumbers}', "");
Expect(1, 65855, '\P{^Blk=aegeannumbers}', "");
Expect(0, 65856, '\p{Blk=aegeannumbers}', "");
Expect(1, 65856, '\p{^Blk=aegeannumbers}', "");
Expect(1, 65856, '\P{Blk=aegeannumbers}', "");
Expect(0, 65856, '\P{^Blk=aegeannumbers}', "");
Expect(1, 65855, '\p{Blk:	  Aegean_NUMBERS}', "");
Expect(0, 65855, '\p{^Blk:	  Aegean_NUMBERS}', "");
Expect(0, 65855, '\P{Blk:	  Aegean_NUMBERS}', "");
Expect(1, 65855, '\P{^Blk:	  Aegean_NUMBERS}', "");
Expect(0, 65856, '\p{Blk:	  Aegean_NUMBERS}', "");
Expect(1, 65856, '\p{^Blk:	  Aegean_NUMBERS}', "");
Expect(1, 65856, '\P{Blk:	  Aegean_NUMBERS}', "");
Expect(0, 65856, '\P{^Blk:	  Aegean_NUMBERS}', "");
Error('\p{Is_Block=:=--AEGEAN_Numbers}');
Error('\P{Is_Block=:=--AEGEAN_Numbers}');
Expect(1, 65855, '\p{Is_Block=aegeannumbers}', "");
Expect(0, 65855, '\p{^Is_Block=aegeannumbers}', "");
Expect(0, 65855, '\P{Is_Block=aegeannumbers}', "");
Expect(1, 65855, '\P{^Is_Block=aegeannumbers}', "");
Expect(0, 65856, '\p{Is_Block=aegeannumbers}', "");
Expect(1, 65856, '\p{^Is_Block=aegeannumbers}', "");
Expect(1, 65856, '\P{Is_Block=aegeannumbers}', "");
Expect(0, 65856, '\P{^Is_Block=aegeannumbers}', "");
Expect(1, 65855, '\p{Is_Block=	 Aegean_NUMBERS}', "");
Expect(0, 65855, '\p{^Is_Block=	 Aegean_NUMBERS}', "");
Expect(0, 65855, '\P{Is_Block=	 Aegean_NUMBERS}', "");
Expect(1, 65855, '\P{^Is_Block=	 Aegean_NUMBERS}', "");
Expect(0, 65856, '\p{Is_Block=	 Aegean_NUMBERS}', "");
Expect(1, 65856, '\p{^Is_Block=	 Aegean_NUMBERS}', "");
Expect(1, 65856, '\P{Is_Block=	 Aegean_NUMBERS}', "");
Expect(0, 65856, '\P{^Is_Block=	 Aegean_NUMBERS}', "");
Error('\p{Is_Blk=:=-	Aegean_Numbers}');
Error('\P{Is_Blk=:=-	Aegean_Numbers}');
Expect(1, 65855, '\p{Is_Blk=aegeannumbers}', "");
Expect(0, 65855, '\p{^Is_Blk=aegeannumbers}', "");
Expect(0, 65855, '\P{Is_Blk=aegeannumbers}', "");
Expect(1, 65855, '\P{^Is_Blk=aegeannumbers}', "");
Expect(0, 65856, '\p{Is_Blk=aegeannumbers}', "");
Expect(1, 65856, '\p{^Is_Blk=aegeannumbers}', "");
Expect(1, 65856, '\P{Is_Blk=aegeannumbers}', "");
Expect(0, 65856, '\P{^Is_Blk=aegeannumbers}', "");
Expect(1, 65855, '\p{Is_Blk=- Aegean_Numbers}', "");
Expect(0, 65855, '\p{^Is_Blk=- Aegean_Numbers}', "");
Expect(0, 65855, '\P{Is_Blk=- Aegean_Numbers}', "");
Expect(1, 65855, '\P{^Is_Blk=- Aegean_Numbers}', "");
Expect(0, 65856, '\p{Is_Blk=- Aegean_Numbers}', "");
Expect(1, 65856, '\p{^Is_Blk=- Aegean_Numbers}', "");
Expect(1, 65856, '\P{Is_Blk=- Aegean_Numbers}', "");
Expect(0, 65856, '\P{^Is_Blk=- Aegean_Numbers}', "");
Error('\p{Block=	-ALCHEMICAL_Symbols/a/}');
Error('\P{Block=	-ALCHEMICAL_Symbols/a/}');
Expect(1, 128895, '\p{Block=alchemicalsymbols}', "");
Expect(0, 128895, '\p{^Block=alchemicalsymbols}', "");
Expect(0, 128895, '\P{Block=alchemicalsymbols}', "");
Expect(1, 128895, '\P{^Block=alchemicalsymbols}', "");
Expect(0, 128896, '\p{Block=alchemicalsymbols}', "");
Expect(1, 128896, '\p{^Block=alchemicalsymbols}', "");
Expect(1, 128896, '\P{Block=alchemicalsymbols}', "");
Expect(0, 128896, '\P{^Block=alchemicalsymbols}', "");
Expect(1, 128895, '\p{Block=- Alchemical_Symbols}', "");
Expect(0, 128895, '\p{^Block=- Alchemical_Symbols}', "");
Expect(0, 128895, '\P{Block=- Alchemical_Symbols}', "");
Expect(1, 128895, '\P{^Block=- Alchemical_Symbols}', "");
Expect(0, 128896, '\p{Block=- Alchemical_Symbols}', "");
Expect(1, 128896, '\p{^Block=- Alchemical_Symbols}', "");
Expect(1, 128896, '\P{Block=- Alchemical_Symbols}', "");
Expect(0, 128896, '\P{^Block=- Alchemical_Symbols}', "");
Error('\p{Blk=-/a/ALCHEMICAL}');
Error('\P{Blk=-/a/ALCHEMICAL}');
Expect(1, 128895, '\p{Blk=alchemical}', "");
Expect(0, 128895, '\p{^Blk=alchemical}', "");
Expect(0, 128895, '\P{Blk=alchemical}', "");
Expect(1, 128895, '\P{^Blk=alchemical}', "");
Expect(0, 128896, '\p{Blk=alchemical}', "");
Expect(1, 128896, '\p{^Blk=alchemical}', "");
Expect(1, 128896, '\P{Blk=alchemical}', "");
Expect(0, 128896, '\P{^Blk=alchemical}', "");
Expect(1, 128895, '\p{Blk=	Alchemical}', "");
Expect(0, 128895, '\p{^Blk=	Alchemical}', "");
Expect(0, 128895, '\P{Blk=	Alchemical}', "");
Expect(1, 128895, '\P{^Blk=	Alchemical}', "");
Expect(0, 128896, '\p{Blk=	Alchemical}', "");
Expect(1, 128896, '\p{^Blk=	Alchemical}', "");
Expect(1, 128896, '\P{Blk=	Alchemical}', "");
Expect(0, 128896, '\P{^Blk=	Alchemical}', "");
Error('\p{Is_Block=:=	_ALCHEMICAL_symbols}');
Error('\P{Is_Block=:=	_ALCHEMICAL_symbols}');
Expect(1, 128895, '\p{Is_Block:alchemicalsymbols}', "");
Expect(0, 128895, '\p{^Is_Block:alchemicalsymbols}', "");
Expect(0, 128895, '\P{Is_Block:alchemicalsymbols}', "");
Expect(1, 128895, '\P{^Is_Block:alchemicalsymbols}', "");
Expect(0, 128896, '\p{Is_Block:alchemicalsymbols}', "");
Expect(1, 128896, '\p{^Is_Block:alchemicalsymbols}', "");
Expect(1, 128896, '\P{Is_Block:alchemicalsymbols}', "");
Expect(0, 128896, '\P{^Is_Block:alchemicalsymbols}', "");
Expect(1, 128895, '\p{Is_Block=_ Alchemical_SYMBOLS}', "");
Expect(0, 128895, '\p{^Is_Block=_ Alchemical_SYMBOLS}', "");
Expect(0, 128895, '\P{Is_Block=_ Alchemical_SYMBOLS}', "");
Expect(1, 128895, '\P{^Is_Block=_ Alchemical_SYMBOLS}', "");
Expect(0, 128896, '\p{Is_Block=_ Alchemical_SYMBOLS}', "");
Expect(1, 128896, '\p{^Is_Block=_ Alchemical_SYMBOLS}', "");
Expect(1, 128896, '\P{Is_Block=_ Alchemical_SYMBOLS}', "");
Expect(0, 128896, '\P{^Is_Block=_ Alchemical_SYMBOLS}', "");
Error('\p{Is_Blk=:=__alchemical}');
Error('\P{Is_Blk=:=__alchemical}');
Expect(1, 128895, '\p{Is_Blk=alchemical}', "");
Expect(0, 128895, '\p{^Is_Blk=alchemical}', "");
Expect(0, 128895, '\P{Is_Blk=alchemical}', "");
Expect(1, 128895, '\P{^Is_Blk=alchemical}', "");
Expect(0, 128896, '\p{Is_Blk=alchemical}', "");
Expect(1, 128896, '\p{^Is_Blk=alchemical}', "");
Expect(1, 128896, '\P{Is_Blk=alchemical}', "");
Expect(0, 128896, '\P{^Is_Blk=alchemical}', "");
Expect(1, 128895, '\p{Is_Blk=-alchemical}', "");
Expect(0, 128895, '\p{^Is_Blk=-alchemical}', "");
Expect(0, 128895, '\P{Is_Blk=-alchemical}', "");
Expect(1, 128895, '\P{^Is_Blk=-alchemical}', "");
Expect(0, 128896, '\p{Is_Blk=-alchemical}', "");
Expect(1, 128896, '\p{^Is_Blk=-alchemical}', "");
Expect(1, 128896, '\P{Is_Blk=-alchemical}', "");
Expect(0, 128896, '\P{^Is_Blk=-alchemical}', "");
Error('\p{Block=/a/Alphabetic_Presentation_forms}');
Error('\P{Block=/a/Alphabetic_Presentation_forms}');
Expect(1, 64335, '\p{Block=alphabeticpresentationforms}', "");
Expect(0, 64335, '\p{^Block=alphabeticpresentationforms}', "");
Expect(0, 64335, '\P{Block=alphabeticpresentationforms}', "");
Expect(1, 64335, '\P{^Block=alphabeticpresentationforms}', "");
Expect(0, 64336, '\p{Block=alphabeticpresentationforms}', "");
Expect(1, 64336, '\p{^Block=alphabeticpresentationforms}', "");
Expect(1, 64336, '\P{Block=alphabeticpresentationforms}', "");
Expect(0, 64336, '\P{^Block=alphabeticpresentationforms}', "");
Expect(1, 64335, '\p{Block=__Alphabetic_Presentation_Forms}', "");
Expect(0, 64335, '\p{^Block=__Alphabetic_Presentation_Forms}', "");
Expect(0, 64335, '\P{Block=__Alphabetic_Presentation_Forms}', "");
Expect(1, 64335, '\P{^Block=__Alphabetic_Presentation_Forms}', "");
Expect(0, 64336, '\p{Block=__Alphabetic_Presentation_Forms}', "");
Expect(1, 64336, '\p{^Block=__Alphabetic_Presentation_Forms}', "");
Expect(1, 64336, '\P{Block=__Alphabetic_Presentation_Forms}', "");
Expect(0, 64336, '\P{^Block=__Alphabetic_Presentation_Forms}', "");
Error('\p{Blk= _Alphabetic_PF:=}');
Error('\P{Blk= _Alphabetic_PF:=}');
Expect(1, 64335, '\p{Blk=alphabeticpf}', "");
Expect(0, 64335, '\p{^Blk=alphabeticpf}', "");
Expect(0, 64335, '\P{Blk=alphabeticpf}', "");
Expect(1, 64335, '\P{^Blk=alphabeticpf}', "");
Expect(0, 64336, '\p{Blk=alphabeticpf}', "");
Expect(1, 64336, '\p{^Blk=alphabeticpf}', "");
Expect(1, 64336, '\P{Blk=alphabeticpf}', "");
Expect(0, 64336, '\P{^Blk=alphabeticpf}', "");
Expect(1, 64335, '\p{Blk=- Alphabetic_pf}', "");
Expect(0, 64335, '\p{^Blk=- Alphabetic_pf}', "");
Expect(0, 64335, '\P{Blk=- Alphabetic_pf}', "");
Expect(1, 64335, '\P{^Blk=- Alphabetic_pf}', "");
Expect(0, 64336, '\p{Blk=- Alphabetic_pf}', "");
Expect(1, 64336, '\p{^Blk=- Alphabetic_pf}', "");
Expect(1, 64336, '\P{Blk=- Alphabetic_pf}', "");
Expect(0, 64336, '\P{^Blk=- Alphabetic_pf}', "");
Error('\p{Is_Block=/a/Alphabetic_PRESENTATION_Forms}');
Error('\P{Is_Block=/a/Alphabetic_PRESENTATION_Forms}');
Expect(1, 64335, '\p{Is_Block=alphabeticpresentationforms}', "");
Expect(0, 64335, '\p{^Is_Block=alphabeticpresentationforms}', "");
Expect(0, 64335, '\P{Is_Block=alphabeticpresentationforms}', "");
Expect(1, 64335, '\P{^Is_Block=alphabeticpresentationforms}', "");
Expect(0, 64336, '\p{Is_Block=alphabeticpresentationforms}', "");
Expect(1, 64336, '\p{^Is_Block=alphabeticpresentationforms}', "");
Expect(1, 64336, '\P{Is_Block=alphabeticpresentationforms}', "");
Expect(0, 64336, '\P{^Is_Block=alphabeticpresentationforms}', "");
Expect(1, 64335, '\p{Is_Block=_	alphabetic_PRESENTATION_Forms}', "");
Expect(0, 64335, '\p{^Is_Block=_	alphabetic_PRESENTATION_Forms}', "");
Expect(0, 64335, '\P{Is_Block=_	alphabetic_PRESENTATION_Forms}', "");
Expect(1, 64335, '\P{^Is_Block=_	alphabetic_PRESENTATION_Forms}', "");
Expect(0, 64336, '\p{Is_Block=_	alphabetic_PRESENTATION_Forms}', "");
Expect(1, 64336, '\p{^Is_Block=_	alphabetic_PRESENTATION_Forms}', "");
Expect(1, 64336, '\P{Is_Block=_	alphabetic_PRESENTATION_Forms}', "");
Expect(0, 64336, '\P{^Is_Block=_	alphabetic_PRESENTATION_Forms}', "");
Error('\p{Is_Blk= Alphabetic_pf:=}');
Error('\P{Is_Blk= Alphabetic_pf:=}');
Expect(1, 64335, '\p{Is_Blk:   alphabeticpf}', "");
Expect(0, 64335, '\p{^Is_Blk:   alphabeticpf}', "");
Expect(0, 64335, '\P{Is_Blk:   alphabeticpf}', "");
Expect(1, 64335, '\P{^Is_Blk:   alphabeticpf}', "");
Expect(0, 64336, '\p{Is_Blk:   alphabeticpf}', "");
Expect(1, 64336, '\p{^Is_Blk:   alphabeticpf}', "");
Expect(1, 64336, '\P{Is_Blk:   alphabeticpf}', "");
Expect(0, 64336, '\P{^Is_Blk:   alphabeticpf}', "");
Expect(1, 64335, '\p{Is_Blk=	ALPHABETIC_PF}', "");
Expect(0, 64335, '\p{^Is_Blk=	ALPHABETIC_PF}', "");
Expect(0, 64335, '\P{Is_Blk=	ALPHABETIC_PF}', "");
Expect(1, 64335, '\P{^Is_Blk=	ALPHABETIC_PF}', "");
Expect(0, 64336, '\p{Is_Blk=	ALPHABETIC_PF}', "");
Expect(1, 64336, '\p{^Is_Blk=	ALPHABETIC_PF}', "");
Expect(1, 64336, '\P{Is_Blk=	ALPHABETIC_PF}', "");
Expect(0, 64336, '\P{^Is_Blk=	ALPHABETIC_PF}', "");
Error('\p{Block=/a/ANCIENT_greek_musical_Notation}');
Error('\P{Block=/a/ANCIENT_greek_musical_Notation}');
Expect(1, 119375, '\p{Block=ancientgreekmusicalnotation}', "");
Expect(0, 119375, '\p{^Block=ancientgreekmusicalnotation}', "");
Expect(0, 119375, '\P{Block=ancientgreekmusicalnotation}', "");
Expect(1, 119375, '\P{^Block=ancientgreekmusicalnotation}', "");
Expect(0, 119376, '\p{Block=ancientgreekmusicalnotation}', "");
Expect(1, 119376, '\p{^Block=ancientgreekmusicalnotation}', "");
Expect(1, 119376, '\P{Block=ancientgreekmusicalnotation}', "");
Expect(0, 119376, '\P{^Block=ancientgreekmusicalnotation}', "");
Expect(1, 119375, '\p{Block=	Ancient_Greek_MUSICAL_Notation}', "");
Expect(0, 119375, '\p{^Block=	Ancient_Greek_MUSICAL_Notation}', "");
Expect(0, 119375, '\P{Block=	Ancient_Greek_MUSICAL_Notation}', "");
Expect(1, 119375, '\P{^Block=	Ancient_Greek_MUSICAL_Notation}', "");
Expect(0, 119376, '\p{Block=	Ancient_Greek_MUSICAL_Notation}', "");
Expect(1, 119376, '\p{^Block=	Ancient_Greek_MUSICAL_Notation}', "");
Expect(1, 119376, '\P{Block=	Ancient_Greek_MUSICAL_Notation}', "");
Expect(0, 119376, '\P{^Block=	Ancient_Greek_MUSICAL_Notation}', "");
Error('\p{Blk=:=- ANCIENT_greek_Music}');
Error('\P{Blk=:=- ANCIENT_greek_Music}');
Expect(1, 119375, '\p{Blk=ancientgreekmusic}', "");
Expect(0, 119375, '\p{^Blk=ancientgreekmusic}', "");
Expect(0, 119375, '\P{Blk=ancientgreekmusic}', "");
Expect(1, 119375, '\P{^Blk=ancientgreekmusic}', "");
Expect(0, 119376, '\p{Blk=ancientgreekmusic}', "");
Expect(1, 119376, '\p{^Blk=ancientgreekmusic}', "");
Expect(1, 119376, '\P{Blk=ancientgreekmusic}', "");
Expect(0, 119376, '\P{^Blk=ancientgreekmusic}', "");
Expect(1, 119375, '\p{Blk=--Ancient_Greek_Music}', "");
Expect(0, 119375, '\p{^Blk=--Ancient_Greek_Music}', "");
Expect(0, 119375, '\P{Blk=--Ancient_Greek_Music}', "");
Expect(1, 119375, '\P{^Blk=--Ancient_Greek_Music}', "");
Expect(0, 119376, '\p{Blk=--Ancient_Greek_Music}', "");
Expect(1, 119376, '\p{^Blk=--Ancient_Greek_Music}', "");
Expect(1, 119376, '\P{Blk=--Ancient_Greek_Music}', "");
Expect(0, 119376, '\P{^Blk=--Ancient_Greek_Music}', "");
Error('\p{Is_Block=_ Ancient_GREEK_Musical_Notation/a/}');
Error('\P{Is_Block=_ Ancient_GREEK_Musical_Notation/a/}');
Expect(1, 119375, '\p{Is_Block=ancientgreekmusicalnotation}', "");
Expect(0, 119375, '\p{^Is_Block=ancientgreekmusicalnotation}', "");
Expect(0, 119375, '\P{Is_Block=ancientgreekmusicalnotation}', "");
Expect(1, 119375, '\P{^Is_Block=ancientgreekmusicalnotation}', "");
Expect(0, 119376, '\p{Is_Block=ancientgreekmusicalnotation}', "");
Expect(1, 119376, '\p{^Is_Block=ancientgreekmusicalnotation}', "");
Expect(1, 119376, '\P{Is_Block=ancientgreekmusicalnotation}', "");
Expect(0, 119376, '\P{^Is_Block=ancientgreekmusicalnotation}', "");
Expect(1, 119375, '\p{Is_Block=--Ancient_Greek_musical_NOTATION}', "");
Expect(0, 119375, '\p{^Is_Block=--Ancient_Greek_musical_NOTATION}', "");
Expect(0, 119375, '\P{Is_Block=--Ancient_Greek_musical_NOTATION}', "");
Expect(1, 119375, '\P{^Is_Block=--Ancient_Greek_musical_NOTATION}', "");
Expect(0, 119376, '\p{Is_Block=--Ancient_Greek_musical_NOTATION}', "");
Expect(1, 119376, '\p{^Is_Block=--Ancient_Greek_musical_NOTATION}', "");
Expect(1, 119376, '\P{Is_Block=--Ancient_Greek_musical_NOTATION}', "");
Expect(0, 119376, '\P{^Is_Block=--Ancient_Greek_musical_NOTATION}', "");
Error('\p{Is_Blk=_ancient_GREEK_music:=}');
Error('\P{Is_Blk=_ancient_GREEK_music:=}');
Expect(1, 119375, '\p{Is_Blk=ancientgreekmusic}', "");
Expect(0, 119375, '\p{^Is_Blk=ancientgreekmusic}', "");
Expect(0, 119375, '\P{Is_Blk=ancientgreekmusic}', "");
Expect(1, 119375, '\P{^Is_Blk=ancientgreekmusic}', "");
Expect(0, 119376, '\p{Is_Blk=ancientgreekmusic}', "");
Expect(1, 119376, '\p{^Is_Blk=ancientgreekmusic}', "");
Expect(1, 119376, '\P{Is_Blk=ancientgreekmusic}', "");
Expect(0, 119376, '\P{^Is_Blk=ancientgreekmusic}', "");
Expect(1, 119375, '\p{Is_Blk= Ancient_Greek_MUSIC}', "");
Expect(0, 119375, '\p{^Is_Blk= Ancient_Greek_MUSIC}', "");
Expect(0, 119375, '\P{Is_Blk= Ancient_Greek_MUSIC}', "");
Expect(1, 119375, '\P{^Is_Blk= Ancient_Greek_MUSIC}', "");
Expect(0, 119376, '\p{Is_Blk= Ancient_Greek_MUSIC}', "");
Expect(1, 119376, '\p{^Is_Blk= Ancient_Greek_MUSIC}', "");
Expect(1, 119376, '\P{Is_Blk= Ancient_Greek_MUSIC}', "");
Expect(0, 119376, '\P{^Is_Blk= Ancient_Greek_MUSIC}', "");
Error('\p{Block=Ancient_Greek_Numbers/a/}');
Error('\P{Block=Ancient_Greek_Numbers/a/}');
Expect(1, 65935, '\p{Block=ancientgreeknumbers}', "");
Expect(0, 65935, '\p{^Block=ancientgreeknumbers}', "");
Expect(0, 65935, '\P{Block=ancientgreeknumbers}', "");
Expect(1, 65935, '\P{^Block=ancientgreeknumbers}', "");
Expect(0, 65936, '\p{Block=ancientgreeknumbers}', "");
Expect(1, 65936, '\p{^Block=ancientgreeknumbers}', "");
Expect(1, 65936, '\P{Block=ancientgreeknumbers}', "");
Expect(0, 65936, '\P{^Block=ancientgreeknumbers}', "");
Expect(1, 65935, '\p{Block:	_ANCIENT_Greek_Numbers}', "");
Expect(0, 65935, '\p{^Block:	_ANCIENT_Greek_Numbers}', "");
Expect(0, 65935, '\P{Block:	_ANCIENT_Greek_Numbers}', "");
Expect(1, 65935, '\P{^Block:	_ANCIENT_Greek_Numbers}', "");
Expect(0, 65936, '\p{Block:	_ANCIENT_Greek_Numbers}', "");
Expect(1, 65936, '\p{^Block:	_ANCIENT_Greek_Numbers}', "");
Expect(1, 65936, '\P{Block:	_ANCIENT_Greek_Numbers}', "");
Expect(0, 65936, '\P{^Block:	_ANCIENT_Greek_Numbers}', "");
Error('\p{Blk=-/a/ANCIENT_Greek_NUMBERS}');
Error('\P{Blk=-/a/ANCIENT_Greek_NUMBERS}');
Expect(1, 65935, '\p{Blk=ancientgreeknumbers}', "");
Expect(0, 65935, '\p{^Blk=ancientgreeknumbers}', "");
Expect(0, 65935, '\P{Blk=ancientgreeknumbers}', "");
Expect(1, 65935, '\P{^Blk=ancientgreeknumbers}', "");
Expect(0, 65936, '\p{Blk=ancientgreeknumbers}', "");
Expect(1, 65936, '\p{^Blk=ancientgreeknumbers}', "");
Expect(1, 65936, '\P{Blk=ancientgreeknumbers}', "");
Expect(0, 65936, '\P{^Blk=ancientgreeknumbers}', "");
Expect(1, 65935, '\p{Blk=-	Ancient_Greek_Numbers}', "");
Expect(0, 65935, '\p{^Blk=-	Ancient_Greek_Numbers}', "");
Expect(0, 65935, '\P{Blk=-	Ancient_Greek_Numbers}', "");
Expect(1, 65935, '\P{^Blk=-	Ancient_Greek_Numbers}', "");
Expect(0, 65936, '\p{Blk=-	Ancient_Greek_Numbers}', "");
Expect(1, 65936, '\p{^Blk=-	Ancient_Greek_Numbers}', "");
Expect(1, 65936, '\P{Blk=-	Ancient_Greek_Numbers}', "");
Expect(0, 65936, '\P{^Blk=-	Ancient_Greek_Numbers}', "");
Error('\p{Is_Block= Ancient_Greek_Numbers/a/}');
Error('\P{Is_Block= Ancient_Greek_Numbers/a/}');
Expect(1, 65935, '\p{Is_Block=ancientgreeknumbers}', "");
Expect(0, 65935, '\p{^Is_Block=ancientgreeknumbers}', "");
Expect(0, 65935, '\P{Is_Block=ancientgreeknumbers}', "");
Expect(1, 65935, '\P{^Is_Block=ancientgreeknumbers}', "");
Expect(0, 65936, '\p{Is_Block=ancientgreeknumbers}', "");
Expect(1, 65936, '\p{^Is_Block=ancientgreeknumbers}', "");
Expect(1, 65936, '\P{Is_Block=ancientgreeknumbers}', "");
Expect(0, 65936, '\P{^Is_Block=ancientgreeknumbers}', "");
Expect(1, 65935, '\p{Is_Block=_ ancient_Greek_Numbers}', "");
Expect(0, 65935, '\p{^Is_Block=_ ancient_Greek_Numbers}', "");
Expect(0, 65935, '\P{Is_Block=_ ancient_Greek_Numbers}', "");
Expect(1, 65935, '\P{^Is_Block=_ ancient_Greek_Numbers}', "");
Expect(0, 65936, '\p{Is_Block=_ ancient_Greek_Numbers}', "");
Expect(1, 65936, '\p{^Is_Block=_ ancient_Greek_Numbers}', "");
Expect(1, 65936, '\P{Is_Block=_ ancient_Greek_Numbers}', "");
Expect(0, 65936, '\P{^Is_Block=_ ancient_Greek_Numbers}', "");
Error('\p{Is_Blk=:=	_ANCIENT_greek_Numbers}');
Error('\P{Is_Blk=:=	_ANCIENT_greek_Numbers}');
Expect(1, 65935, '\p{Is_Blk=ancientgreeknumbers}', "");
Expect(0, 65935, '\p{^Is_Blk=ancientgreeknumbers}', "");
Expect(0, 65935, '\P{Is_Blk=ancientgreeknumbers}', "");
Expect(1, 65935, '\P{^Is_Blk=ancientgreeknumbers}', "");
Expect(0, 65936, '\p{Is_Blk=ancientgreeknumbers}', "");
Expect(1, 65936, '\p{^Is_Blk=ancientgreeknumbers}', "");
Expect(1, 65936, '\P{Is_Blk=ancientgreeknumbers}', "");
Expect(0, 65936, '\P{^Is_Blk=ancientgreeknumbers}', "");
Expect(1, 65935, '\p{Is_Blk=	ANCIENT_GREEK_numbers}', "");
Expect(0, 65935, '\p{^Is_Blk=	ANCIENT_GREEK_numbers}', "");
Expect(0, 65935, '\P{Is_Blk=	ANCIENT_GREEK_numbers}', "");
Expect(1, 65935, '\P{^Is_Blk=	ANCIENT_GREEK_numbers}', "");
Expect(0, 65936, '\p{Is_Blk=	ANCIENT_GREEK_numbers}', "");
Expect(1, 65936, '\p{^Is_Blk=	ANCIENT_GREEK_numbers}', "");
Expect(1, 65936, '\P{Is_Blk=	ANCIENT_GREEK_numbers}', "");
Expect(0, 65936, '\P{^Is_Blk=	ANCIENT_GREEK_numbers}', "");
Error('\p{Block:		:=ANCIENT_Symbols}');
Error('\P{Block:		:=ANCIENT_Symbols}');
Expect(1, 65999, '\p{Block=ancientsymbols}', "");
Expect(0, 65999, '\p{^Block=ancientsymbols}', "");
Expect(0, 65999, '\P{Block=ancientsymbols}', "");
Expect(1, 65999, '\P{^Block=ancientsymbols}', "");
Expect(0, 66000, '\p{Block=ancientsymbols}', "");
Expect(1, 66000, '\p{^Block=ancientsymbols}', "");
Expect(1, 66000, '\P{Block=ancientsymbols}', "");
Expect(0, 66000, '\P{^Block=ancientsymbols}', "");
Expect(1, 65999, '\p{Block=	 ancient_Symbols}', "");
Expect(0, 65999, '\p{^Block=	 ancient_Symbols}', "");
Expect(0, 65999, '\P{Block=	 ancient_Symbols}', "");
Expect(1, 65999, '\P{^Block=	 ancient_Symbols}', "");
Expect(0, 66000, '\p{Block=	 ancient_Symbols}', "");
Expect(1, 66000, '\p{^Block=	 ancient_Symbols}', "");
Expect(1, 66000, '\P{Block=	 ancient_Symbols}', "");
Expect(0, 66000, '\P{^Block=	 ancient_Symbols}', "");
Error('\p{Blk=/a/	_Ancient_Symbols}');
Error('\P{Blk=/a/	_Ancient_Symbols}');
Expect(1, 65999, '\p{Blk=ancientsymbols}', "");
Expect(0, 65999, '\p{^Blk=ancientsymbols}', "");
Expect(0, 65999, '\P{Blk=ancientsymbols}', "");
Expect(1, 65999, '\P{^Blk=ancientsymbols}', "");
Expect(0, 66000, '\p{Blk=ancientsymbols}', "");
Expect(1, 66000, '\p{^Blk=ancientsymbols}', "");
Expect(1, 66000, '\P{Blk=ancientsymbols}', "");
Expect(0, 66000, '\P{^Blk=ancientsymbols}', "");
Expect(1, 65999, '\p{Blk=  ANCIENT_SYMBOLS}', "");
Expect(0, 65999, '\p{^Blk=  ANCIENT_SYMBOLS}', "");
Expect(0, 65999, '\P{Blk=  ANCIENT_SYMBOLS}', "");
Expect(1, 65999, '\P{^Blk=  ANCIENT_SYMBOLS}', "");
Expect(0, 66000, '\p{Blk=  ANCIENT_SYMBOLS}', "");
Expect(1, 66000, '\p{^Blk=  ANCIENT_SYMBOLS}', "");
Expect(1, 66000, '\P{Blk=  ANCIENT_SYMBOLS}', "");
Expect(0, 66000, '\P{^Blk=  ANCIENT_SYMBOLS}', "");
Error('\p{Is_Block:   /a/_	Ancient_SYMBOLS}');
Error('\P{Is_Block:   /a/_	Ancient_SYMBOLS}');
Expect(1, 65999, '\p{Is_Block=ancientsymbols}', "");
Expect(0, 65999, '\p{^Is_Block=ancientsymbols}', "");
Expect(0, 65999, '\P{Is_Block=ancientsymbols}', "");
Expect(1, 65999, '\P{^Is_Block=ancientsymbols}', "");
Expect(0, 66000, '\p{Is_Block=ancientsymbols}', "");
Expect(1, 66000, '\p{^Is_Block=ancientsymbols}', "");
Expect(1, 66000, '\P{Is_Block=ancientsymbols}', "");
Expect(0, 66000, '\P{^Is_Block=ancientsymbols}', "");
Expect(1, 65999, '\p{Is_Block=_ ANCIENT_symbols}', "");
Expect(0, 65999, '\p{^Is_Block=_ ANCIENT_symbols}', "");
Expect(0, 65999, '\P{Is_Block=_ ANCIENT_symbols}', "");
Expect(1, 65999, '\P{^Is_Block=_ ANCIENT_symbols}', "");
Expect(0, 66000, '\p{Is_Block=_ ANCIENT_symbols}', "");
Expect(1, 66000, '\p{^Is_Block=_ ANCIENT_symbols}', "");
Expect(1, 66000, '\P{Is_Block=_ ANCIENT_symbols}', "");
Expect(0, 66000, '\P{^Is_Block=_ ANCIENT_symbols}', "");
Error('\p{Is_Blk: _/a/Ancient_Symbols}');
Error('\P{Is_Blk: _/a/Ancient_Symbols}');
Expect(1, 65999, '\p{Is_Blk:	ancientsymbols}', "");
Expect(0, 65999, '\p{^Is_Blk:	ancientsymbols}', "");
Expect(0, 65999, '\P{Is_Blk:	ancientsymbols}', "");
Expect(1, 65999, '\P{^Is_Blk:	ancientsymbols}', "");
Expect(0, 66000, '\p{Is_Blk:	ancientsymbols}', "");
Expect(1, 66000, '\p{^Is_Blk:	ancientsymbols}', "");
Expect(1, 66000, '\P{Is_Blk:	ancientsymbols}', "");
Expect(0, 66000, '\P{^Is_Blk:	ancientsymbols}', "");
Expect(1, 65999, '\p{Is_Blk=ancient_Symbols}', "");
Expect(0, 65999, '\p{^Is_Blk=ancient_Symbols}', "");
Expect(0, 65999, '\P{Is_Blk=ancient_Symbols}', "");
Expect(1, 65999, '\P{^Is_Blk=ancient_Symbols}', "");
Expect(0, 66000, '\p{Is_Blk=ancient_Symbols}', "");
Expect(1, 66000, '\p{^Is_Blk=ancient_Symbols}', "");
Expect(1, 66000, '\P{Is_Blk=ancient_Symbols}', "");
Expect(0, 66000, '\P{^Is_Blk=ancient_Symbols}', "");
Error('\p{Block=- arabic/a/}');
Error('\P{Block=- arabic/a/}');
Expect(1, 1791, '\p{Block=arabic}', "");
Expect(0, 1791, '\p{^Block=arabic}', "");
Expect(0, 1791, '\P{Block=arabic}', "");
Expect(1, 1791, '\P{^Block=arabic}', "");
Expect(0, 1792, '\p{Block=arabic}', "");
Expect(1, 1792, '\p{^Block=arabic}', "");
Expect(1, 1792, '\P{Block=arabic}', "");
Expect(0, 1792, '\P{^Block=arabic}', "");
Expect(1, 1791, '\p{Block=	 arabic}', "");
Expect(0, 1791, '\p{^Block=	 arabic}', "");
Expect(0, 1791, '\P{Block=	 arabic}', "");
Expect(1, 1791, '\P{^Block=	 arabic}', "");
Expect(0, 1792, '\p{Block=	 arabic}', "");
Expect(1, 1792, '\p{^Block=	 arabic}', "");
Expect(1, 1792, '\P{Block=	 arabic}', "");
Expect(0, 1792, '\P{^Block=	 arabic}', "");
Error('\p{Blk=/a/ arabic}');
Error('\P{Blk=/a/ arabic}');
Expect(1, 1791, '\p{Blk=arabic}', "");
Expect(0, 1791, '\p{^Blk=arabic}', "");
Expect(0, 1791, '\P{Blk=arabic}', "");
Expect(1, 1791, '\P{^Blk=arabic}', "");
Expect(0, 1792, '\p{Blk=arabic}', "");
Expect(1, 1792, '\p{^Blk=arabic}', "");
Expect(1, 1792, '\P{Blk=arabic}', "");
Expect(0, 1792, '\P{^Blk=arabic}', "");
Expect(1, 1791, '\p{Blk=_Arabic}', "");
Expect(0, 1791, '\p{^Blk=_Arabic}', "");
Expect(0, 1791, '\P{Blk=_Arabic}', "");
Expect(1, 1791, '\P{^Blk=_Arabic}', "");
Expect(0, 1792, '\p{Blk=_Arabic}', "");
Expect(1, 1792, '\p{^Blk=_Arabic}', "");
Expect(1, 1792, '\P{Blk=_Arabic}', "");
Expect(0, 1792, '\P{^Blk=_Arabic}', "");
Error('\p{Is_Block=-Arabic:=}');
Error('\P{Is_Block=-Arabic:=}');
Expect(1, 1791, '\p{Is_Block=arabic}', "");
Expect(0, 1791, '\p{^Is_Block=arabic}', "");
Expect(0, 1791, '\P{Is_Block=arabic}', "");
Expect(1, 1791, '\P{^Is_Block=arabic}', "");
Expect(0, 1792, '\p{Is_Block=arabic}', "");
Expect(1, 1792, '\p{^Is_Block=arabic}', "");
Expect(1, 1792, '\P{Is_Block=arabic}', "");
Expect(0, 1792, '\P{^Is_Block=arabic}', "");
Expect(1, 1791, '\p{Is_Block= arabic}', "");
Expect(0, 1791, '\p{^Is_Block= arabic}', "");
Expect(0, 1791, '\P{Is_Block= arabic}', "");
Expect(1, 1791, '\P{^Is_Block= arabic}', "");
Expect(0, 1792, '\p{Is_Block= arabic}', "");
Expect(1, 1792, '\p{^Is_Block= arabic}', "");
Expect(1, 1792, '\P{Is_Block= arabic}', "");
Expect(0, 1792, '\P{^Is_Block= arabic}', "");
Error('\p{Is_Blk=/a/_ARABIC}');
Error('\P{Is_Blk=/a/_ARABIC}');
Expect(1, 1791, '\p{Is_Blk=arabic}', "");
Expect(0, 1791, '\p{^Is_Blk=arabic}', "");
Expect(0, 1791, '\P{Is_Blk=arabic}', "");
Expect(1, 1791, '\P{^Is_Blk=arabic}', "");
Expect(0, 1792, '\p{Is_Blk=arabic}', "");
Expect(1, 1792, '\p{^Is_Blk=arabic}', "");
Expect(1, 1792, '\P{Is_Blk=arabic}', "");
Expect(0, 1792, '\P{^Is_Blk=arabic}', "");
Expect(1, 1791, '\p{Is_Blk=	ARABIC}', "");
Expect(0, 1791, '\p{^Is_Blk=	ARABIC}', "");
Expect(0, 1791, '\P{Is_Blk=	ARABIC}', "");
Expect(1, 1791, '\P{^Is_Blk=	ARABIC}', "");
Expect(0, 1792, '\p{Is_Blk=	ARABIC}', "");
Expect(1, 1792, '\p{^Is_Blk=	ARABIC}', "");
Expect(1, 1792, '\P{Is_Blk=	ARABIC}', "");
Expect(0, 1792, '\P{^Is_Blk=	ARABIC}', "");
Error('\p{Block:	__arabic_Extended_a:=}');
Error('\P{Block:	__arabic_Extended_a:=}');
Expect(1, 2303, '\p{Block=arabicextendeda}', "");
Expect(0, 2303, '\p{^Block=arabicextendeda}', "");
Expect(0, 2303, '\P{Block=arabicextendeda}', "");
Expect(1, 2303, '\P{^Block=arabicextendeda}', "");
Expect(0, 2304, '\p{Block=arabicextendeda}', "");
Expect(1, 2304, '\p{^Block=arabicextendeda}', "");
Expect(1, 2304, '\P{Block=arabicextendeda}', "");
Expect(0, 2304, '\P{^Block=arabicextendeda}', "");
Expect(1, 2303, '\p{Block=- Arabic_EXTENDED_A}', "");
Expect(0, 2303, '\p{^Block=- Arabic_EXTENDED_A}', "");
Expect(0, 2303, '\P{Block=- Arabic_EXTENDED_A}', "");
Expect(1, 2303, '\P{^Block=- Arabic_EXTENDED_A}', "");
Expect(0, 2304, '\p{Block=- Arabic_EXTENDED_A}', "");
Expect(1, 2304, '\p{^Block=- Arabic_EXTENDED_A}', "");
Expect(1, 2304, '\P{Block=- Arabic_EXTENDED_A}', "");
Expect(0, 2304, '\P{^Block=- Arabic_EXTENDED_A}', "");
Error('\p{Blk=/a/- ARABIC_Ext_A}');
Error('\P{Blk=/a/- ARABIC_Ext_A}');
Expect(1, 2303, '\p{Blk=arabicexta}', "");
Expect(0, 2303, '\p{^Blk=arabicexta}', "");
Expect(0, 2303, '\P{Blk=arabicexta}', "");
Expect(1, 2303, '\P{^Blk=arabicexta}', "");
Expect(0, 2304, '\p{Blk=arabicexta}', "");
Expect(1, 2304, '\p{^Blk=arabicexta}', "");
Expect(1, 2304, '\P{Blk=arabicexta}', "");
Expect(0, 2304, '\P{^Blk=arabicexta}', "");
Expect(1, 2303, '\p{Blk=	 Arabic_EXT_A}', "");
Expect(0, 2303, '\p{^Blk=	 Arabic_EXT_A}', "");
Expect(0, 2303, '\P{Blk=	 Arabic_EXT_A}', "");
Expect(1, 2303, '\P{^Blk=	 Arabic_EXT_A}', "");
Expect(0, 2304, '\p{Blk=	 Arabic_EXT_A}', "");
Expect(1, 2304, '\p{^Blk=	 Arabic_EXT_A}', "");
Expect(1, 2304, '\P{Blk=	 Arabic_EXT_A}', "");
Expect(0, 2304, '\P{^Blk=	 Arabic_EXT_A}', "");
Error('\p{Is_Block=:=		ARABIC_Extended_A}');
Error('\P{Is_Block=:=		ARABIC_Extended_A}');
Expect(1, 2303, '\p{Is_Block=arabicextendeda}', "");
Expect(0, 2303, '\p{^Is_Block=arabicextendeda}', "");
Expect(0, 2303, '\P{Is_Block=arabicextendeda}', "");
Expect(1, 2303, '\P{^Is_Block=arabicextendeda}', "");
Expect(0, 2304, '\p{Is_Block=arabicextendeda}', "");
Expect(1, 2304, '\p{^Is_Block=arabicextendeda}', "");
Expect(1, 2304, '\P{Is_Block=arabicextendeda}', "");
Expect(0, 2304, '\P{^Is_Block=arabicextendeda}', "");
Expect(1, 2303, '\p{Is_Block=__Arabic_Extended_A}', "");
Expect(0, 2303, '\p{^Is_Block=__Arabic_Extended_A}', "");
Expect(0, 2303, '\P{Is_Block=__Arabic_Extended_A}', "");
Expect(1, 2303, '\P{^Is_Block=__Arabic_Extended_A}', "");
Expect(0, 2304, '\p{Is_Block=__Arabic_Extended_A}', "");
Expect(1, 2304, '\p{^Is_Block=__Arabic_Extended_A}', "");
Expect(1, 2304, '\P{Is_Block=__Arabic_Extended_A}', "");
Expect(0, 2304, '\P{^Is_Block=__Arabic_Extended_A}', "");
Error('\p{Is_Blk=_ARABIC_EXT_a/a/}');
Error('\P{Is_Blk=_ARABIC_EXT_a/a/}');
Expect(1, 2303, '\p{Is_Blk:	arabicexta}', "");
Expect(0, 2303, '\p{^Is_Blk:	arabicexta}', "");
Expect(0, 2303, '\P{Is_Blk:	arabicexta}', "");
Expect(1, 2303, '\P{^Is_Blk:	arabicexta}', "");
Expect(0, 2304, '\p{Is_Blk:	arabicexta}', "");
Expect(1, 2304, '\p{^Is_Blk:	arabicexta}', "");
Expect(1, 2304, '\P{Is_Blk:	arabicexta}', "");
Expect(0, 2304, '\P{^Is_Blk:	arabicexta}', "");
Expect(1, 2303, '\p{Is_Blk=		Arabic_Ext_A}', "");
Expect(0, 2303, '\p{^Is_Blk=		Arabic_Ext_A}', "");
Expect(0, 2303, '\P{Is_Blk=		Arabic_Ext_A}', "");
Expect(1, 2303, '\P{^Is_Blk=		Arabic_Ext_A}', "");
Expect(0, 2304, '\p{Is_Blk=		Arabic_Ext_A}', "");
Expect(1, 2304, '\p{^Is_Blk=		Arabic_Ext_A}', "");
Expect(1, 2304, '\P{Is_Blk=		Arabic_Ext_A}', "");
Expect(0, 2304, '\P{^Is_Blk=		Arabic_Ext_A}', "");
Error('\p{Block=:=ARABIC_Mathematical_Alphabetic_symbols}');
Error('\P{Block=:=ARABIC_Mathematical_Alphabetic_symbols}');
Expect(1, 126719, '\p{Block=arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\p{^Block=arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\P{Block=arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\P{^Block=arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\p{Block=arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\p{^Block=arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\P{Block=arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\P{^Block=arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\p{Block=-_Arabic_Mathematical_Alphabetic_SYMBOLS}', "");
Expect(0, 126719, '\p{^Block=-_Arabic_Mathematical_Alphabetic_SYMBOLS}', "");
Expect(0, 126719, '\P{Block=-_Arabic_Mathematical_Alphabetic_SYMBOLS}', "");
Expect(1, 126719, '\P{^Block=-_Arabic_Mathematical_Alphabetic_SYMBOLS}', "");
Expect(0, 126720, '\p{Block=-_Arabic_Mathematical_Alphabetic_SYMBOLS}', "");
Expect(1, 126720, '\p{^Block=-_Arabic_Mathematical_Alphabetic_SYMBOLS}', "");
Expect(1, 126720, '\P{Block=-_Arabic_Mathematical_Alphabetic_SYMBOLS}', "");
Expect(0, 126720, '\P{^Block=-_Arabic_Mathematical_Alphabetic_SYMBOLS}', "");
Error('\p{Blk=/a/ -Arabic_MATH}');
Error('\P{Blk=/a/ -Arabic_MATH}');
Expect(1, 126719, '\p{Blk=arabicmath}', "");
Expect(0, 126719, '\p{^Blk=arabicmath}', "");
Expect(0, 126719, '\P{Blk=arabicmath}', "");
Expect(1, 126719, '\P{^Blk=arabicmath}', "");
Expect(0, 126720, '\p{Blk=arabicmath}', "");
Expect(1, 126720, '\p{^Blk=arabicmath}', "");
Expect(1, 126720, '\P{Blk=arabicmath}', "");
Expect(0, 126720, '\P{^Blk=arabicmath}', "");
Expect(1, 126719, '\p{Blk=_	Arabic_Math}', "");
Expect(0, 126719, '\p{^Blk=_	Arabic_Math}', "");
Expect(0, 126719, '\P{Blk=_	Arabic_Math}', "");
Expect(1, 126719, '\P{^Blk=_	Arabic_Math}', "");
Expect(0, 126720, '\p{Blk=_	Arabic_Math}', "");
Expect(1, 126720, '\p{^Blk=_	Arabic_Math}', "");
Expect(1, 126720, '\P{Blk=_	Arabic_Math}', "");
Expect(0, 126720, '\P{^Blk=_	Arabic_Math}', "");
Error('\p{Is_Block=_	arabic_Mathematical_alphabetic_symbols:=}');
Error('\P{Is_Block=_	arabic_Mathematical_alphabetic_symbols:=}');
Expect(1, 126719, '\p{Is_Block=arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\p{^Is_Block=arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\P{Is_Block=arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\P{^Is_Block=arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\p{Is_Block=arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\p{^Is_Block=arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\P{Is_Block=arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\P{^Is_Block=arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\p{Is_Block= 	Arabic_mathematical_Alphabetic_symbols}', "");
Expect(0, 126719, '\p{^Is_Block= 	Arabic_mathematical_Alphabetic_symbols}', "");
Expect(0, 126719, '\P{Is_Block= 	Arabic_mathematical_Alphabetic_symbols}', "");
Expect(1, 126719, '\P{^Is_Block= 	Arabic_mathematical_Alphabetic_symbols}', "");
Expect(0, 126720, '\p{Is_Block= 	Arabic_mathematical_Alphabetic_symbols}', "");
Expect(1, 126720, '\p{^Is_Block= 	Arabic_mathematical_Alphabetic_symbols}', "");
Expect(1, 126720, '\P{Is_Block= 	Arabic_mathematical_Alphabetic_symbols}', "");
Expect(0, 126720, '\P{^Is_Block= 	Arabic_mathematical_Alphabetic_symbols}', "");
Error('\p{Is_Blk=:=ARABIC_math}');
Error('\P{Is_Blk=:=ARABIC_math}');
Expect(1, 126719, '\p{Is_Blk=arabicmath}', "");
Expect(0, 126719, '\p{^Is_Blk=arabicmath}', "");
Expect(0, 126719, '\P{Is_Blk=arabicmath}', "");
Expect(1, 126719, '\P{^Is_Blk=arabicmath}', "");
Expect(0, 126720, '\p{Is_Blk=arabicmath}', "");
Expect(1, 126720, '\p{^Is_Blk=arabicmath}', "");
Expect(1, 126720, '\P{Is_Blk=arabicmath}', "");
Expect(0, 126720, '\P{^Is_Blk=arabicmath}', "");
Expect(1, 126719, '\p{Is_Blk=_ arabic_Math}', "");
Expect(0, 126719, '\p{^Is_Blk=_ arabic_Math}', "");
Expect(0, 126719, '\P{Is_Blk=_ arabic_Math}', "");
Expect(1, 126719, '\P{^Is_Blk=_ arabic_Math}', "");
Expect(0, 126720, '\p{Is_Blk=_ arabic_Math}', "");
Expect(1, 126720, '\p{^Is_Blk=_ arabic_Math}', "");
Expect(1, 126720, '\P{Is_Blk=_ arabic_Math}', "");
Expect(0, 126720, '\P{^Is_Blk=_ arabic_Math}', "");
Error('\p{Block:/a/_Arabic_Presentation_forms_a}');
Error('\P{Block:/a/_Arabic_Presentation_forms_a}');
Expect(1, 65023, '\p{Block=arabicpresentationformsa}', "");
Expect(0, 65023, '\p{^Block=arabicpresentationformsa}', "");
Expect(0, 65023, '\P{Block=arabicpresentationformsa}', "");
Expect(1, 65023, '\P{^Block=arabicpresentationformsa}', "");
Expect(0, 65024, '\p{Block=arabicpresentationformsa}', "");
Expect(1, 65024, '\p{^Block=arabicpresentationformsa}', "");
Expect(1, 65024, '\P{Block=arabicpresentationformsa}', "");
Expect(0, 65024, '\P{^Block=arabicpresentationformsa}', "");
Expect(1, 65023, '\p{Block:   _Arabic_Presentation_Forms_a}', "");
Expect(0, 65023, '\p{^Block:   _Arabic_Presentation_Forms_a}', "");
Expect(0, 65023, '\P{Block:   _Arabic_Presentation_Forms_a}', "");
Expect(1, 65023, '\P{^Block:   _Arabic_Presentation_Forms_a}', "");
Expect(0, 65024, '\p{Block:   _Arabic_Presentation_Forms_a}', "");
Expect(1, 65024, '\p{^Block:   _Arabic_Presentation_Forms_a}', "");
Expect(1, 65024, '\P{Block:   _Arabic_Presentation_Forms_a}', "");
Expect(0, 65024, '\P{^Block:   _Arabic_Presentation_Forms_a}', "");
Error('\p{Blk=/a/	ARABIC_pf_A}');
Error('\P{Blk=/a/	ARABIC_pf_A}');
Expect(1, 65023, '\p{Blk=arabicpfa}', "");
Expect(0, 65023, '\p{^Blk=arabicpfa}', "");
Expect(0, 65023, '\P{Blk=arabicpfa}', "");
Expect(1, 65023, '\P{^Blk=arabicpfa}', "");
Expect(0, 65024, '\p{Blk=arabicpfa}', "");
Expect(1, 65024, '\p{^Blk=arabicpfa}', "");
Expect(1, 65024, '\P{Blk=arabicpfa}', "");
Expect(0, 65024, '\P{^Blk=arabicpfa}', "");
Expect(1, 65023, '\p{Blk=	Arabic_PF_A}', "");
Expect(0, 65023, '\p{^Blk=	Arabic_PF_A}', "");
Expect(0, 65023, '\P{Blk=	Arabic_PF_A}', "");
Expect(1, 65023, '\P{^Blk=	Arabic_PF_A}', "");
Expect(0, 65024, '\p{Blk=	Arabic_PF_A}', "");
Expect(1, 65024, '\p{^Blk=	Arabic_PF_A}', "");
Expect(1, 65024, '\P{Blk=	Arabic_PF_A}', "");
Expect(0, 65024, '\P{^Blk=	Arabic_PF_A}', "");
Error('\p{Is_Block=:=-arabic_PRESENTATION_Forms_a}');
Error('\P{Is_Block=:=-arabic_PRESENTATION_Forms_a}');
Expect(1, 65023, '\p{Is_Block=arabicpresentationformsa}', "");
Expect(0, 65023, '\p{^Is_Block=arabicpresentationformsa}', "");
Expect(0, 65023, '\P{Is_Block=arabicpresentationformsa}', "");
Expect(1, 65023, '\P{^Is_Block=arabicpresentationformsa}', "");
Expect(0, 65024, '\p{Is_Block=arabicpresentationformsa}', "");
Expect(1, 65024, '\p{^Is_Block=arabicpresentationformsa}', "");
Expect(1, 65024, '\P{Is_Block=arabicpresentationformsa}', "");
Expect(0, 65024, '\P{^Is_Block=arabicpresentationformsa}', "");
Expect(1, 65023, '\p{Is_Block=__Arabic_PRESENTATION_Forms_A}', "");
Expect(0, 65023, '\p{^Is_Block=__Arabic_PRESENTATION_Forms_A}', "");
Expect(0, 65023, '\P{Is_Block=__Arabic_PRESENTATION_Forms_A}', "");
Expect(1, 65023, '\P{^Is_Block=__Arabic_PRESENTATION_Forms_A}', "");
Expect(0, 65024, '\p{Is_Block=__Arabic_PRESENTATION_Forms_A}', "");
Expect(1, 65024, '\p{^Is_Block=__Arabic_PRESENTATION_Forms_A}', "");
Expect(1, 65024, '\P{Is_Block=__Arabic_PRESENTATION_Forms_A}', "");
Expect(0, 65024, '\P{^Is_Block=__Arabic_PRESENTATION_Forms_A}', "");
Error('\p{Is_Blk=-/a/Arabic_PF_A}');
Error('\P{Is_Blk=-/a/Arabic_PF_A}');
Expect(1, 65023, '\p{Is_Blk:	arabicpfa}', "");
Expect(0, 65023, '\p{^Is_Blk:	arabicpfa}', "");
Expect(0, 65023, '\P{Is_Blk:	arabicpfa}', "");
Expect(1, 65023, '\P{^Is_Blk:	arabicpfa}', "");
Expect(0, 65024, '\p{Is_Blk:	arabicpfa}', "");
Expect(1, 65024, '\p{^Is_Blk:	arabicpfa}', "");
Expect(1, 65024, '\P{Is_Blk:	arabicpfa}', "");
Expect(0, 65024, '\P{^Is_Blk:	arabicpfa}', "");
Expect(1, 65023, '\p{Is_Blk: 	_ARABIC_PF_A}', "");
Expect(0, 65023, '\p{^Is_Blk: 	_ARABIC_PF_A}', "");
Expect(0, 65023, '\P{Is_Blk: 	_ARABIC_PF_A}', "");
Expect(1, 65023, '\P{^Is_Blk: 	_ARABIC_PF_A}', "");
Expect(0, 65024, '\p{Is_Blk: 	_ARABIC_PF_A}', "");
Expect(1, 65024, '\p{^Is_Blk: 	_ARABIC_PF_A}', "");
Expect(1, 65024, '\P{Is_Blk: 	_ARABIC_PF_A}', "");
Expect(0, 65024, '\P{^Is_Blk: 	_ARABIC_PF_A}', "");
Error('\p{Block= :=ARABIC_PRESENTATION_Forms_B}');
Error('\P{Block= :=ARABIC_PRESENTATION_Forms_B}');
Expect(1, 65279, '\p{Block=arabicpresentationformsb}', "");
Expect(0, 65279, '\p{^Block=arabicpresentationformsb}', "");
Expect(0, 65279, '\P{Block=arabicpresentationformsb}', "");
Expect(1, 65279, '\P{^Block=arabicpresentationformsb}', "");
Expect(0, 65280, '\p{Block=arabicpresentationformsb}', "");
Expect(1, 65280, '\p{^Block=arabicpresentationformsb}', "");
Expect(1, 65280, '\P{Block=arabicpresentationformsb}', "");
Expect(0, 65280, '\P{^Block=arabicpresentationformsb}', "");
Expect(1, 65279, '\p{Block=-ARABIC_PRESENTATION_FORMS_b}', "");
Expect(0, 65279, '\p{^Block=-ARABIC_PRESENTATION_FORMS_b}', "");
Expect(0, 65279, '\P{Block=-ARABIC_PRESENTATION_FORMS_b}', "");
Expect(1, 65279, '\P{^Block=-ARABIC_PRESENTATION_FORMS_b}', "");
Expect(0, 65280, '\p{Block=-ARABIC_PRESENTATION_FORMS_b}', "");
Expect(1, 65280, '\p{^Block=-ARABIC_PRESENTATION_FORMS_b}', "");
Expect(1, 65280, '\P{Block=-ARABIC_PRESENTATION_FORMS_b}', "");
Expect(0, 65280, '\P{^Block=-ARABIC_PRESENTATION_FORMS_b}', "");
Error('\p{Blk=__ARABIC_pf_B/a/}');
Error('\P{Blk=__ARABIC_pf_B/a/}');
Expect(1, 65279, '\p{Blk=arabicpfb}', "");
Expect(0, 65279, '\p{^Blk=arabicpfb}', "");
Expect(0, 65279, '\P{Blk=arabicpfb}', "");
Expect(1, 65279, '\P{^Blk=arabicpfb}', "");
Expect(0, 65280, '\p{Blk=arabicpfb}', "");
Expect(1, 65280, '\p{^Blk=arabicpfb}', "");
Expect(1, 65280, '\P{Blk=arabicpfb}', "");
Expect(0, 65280, '\P{^Blk=arabicpfb}', "");
Expect(1, 65279, '\p{Blk=_ Arabic_pf_B}', "");
Expect(0, 65279, '\p{^Blk=_ Arabic_pf_B}', "");
Expect(0, 65279, '\P{Blk=_ Arabic_pf_B}', "");
Expect(1, 65279, '\P{^Blk=_ Arabic_pf_B}', "");
Expect(0, 65280, '\p{Blk=_ Arabic_pf_B}', "");
Expect(1, 65280, '\p{^Blk=_ Arabic_pf_B}', "");
Expect(1, 65280, '\P{Blk=_ Arabic_pf_B}', "");
Expect(0, 65280, '\P{^Blk=_ Arabic_pf_B}', "");
Error('\p{Is_Block=_	ARABIC_Presentation_FORMS_B:=}');
Error('\P{Is_Block=_	ARABIC_Presentation_FORMS_B:=}');
Expect(1, 65279, '\p{Is_Block=arabicpresentationformsb}', "");
Expect(0, 65279, '\p{^Is_Block=arabicpresentationformsb}', "");
Expect(0, 65279, '\P{Is_Block=arabicpresentationformsb}', "");
Expect(1, 65279, '\P{^Is_Block=arabicpresentationformsb}', "");
Expect(0, 65280, '\p{Is_Block=arabicpresentationformsb}', "");
Expect(1, 65280, '\p{^Is_Block=arabicpresentationformsb}', "");
Expect(1, 65280, '\P{Is_Block=arabicpresentationformsb}', "");
Expect(0, 65280, '\P{^Is_Block=arabicpresentationformsb}', "");
Expect(1, 65279, '\p{Is_Block=-ARABIC_PRESENTATION_forms_B}', "");
Expect(0, 65279, '\p{^Is_Block=-ARABIC_PRESENTATION_forms_B}', "");
Expect(0, 65279, '\P{Is_Block=-ARABIC_PRESENTATION_forms_B}', "");
Expect(1, 65279, '\P{^Is_Block=-ARABIC_PRESENTATION_forms_B}', "");
Expect(0, 65280, '\p{Is_Block=-ARABIC_PRESENTATION_forms_B}', "");
Expect(1, 65280, '\p{^Is_Block=-ARABIC_PRESENTATION_forms_B}', "");
Expect(1, 65280, '\P{Is_Block=-ARABIC_PRESENTATION_forms_B}', "");
Expect(0, 65280, '\P{^Is_Block=-ARABIC_PRESENTATION_forms_B}', "");
Error('\p{Is_Blk=_Arabic_PF_b/a/}');
Error('\P{Is_Blk=_Arabic_PF_b/a/}');
Expect(1, 65279, '\p{Is_Blk=arabicpfb}', "");
Expect(0, 65279, '\p{^Is_Blk=arabicpfb}', "");
Expect(0, 65279, '\P{Is_Blk=arabicpfb}', "");
Expect(1, 65279, '\P{^Is_Blk=arabicpfb}', "");
Expect(0, 65280, '\p{Is_Blk=arabicpfb}', "");
Expect(1, 65280, '\p{^Is_Blk=arabicpfb}', "");
Expect(1, 65280, '\P{Is_Blk=arabicpfb}', "");
Expect(0, 65280, '\P{^Is_Blk=arabicpfb}', "");
Expect(1, 65279, '\p{Is_Blk=	_Arabic_pf_B}', "");
Expect(0, 65279, '\p{^Is_Blk=	_Arabic_pf_B}', "");
Expect(0, 65279, '\P{Is_Blk=	_Arabic_pf_B}', "");
Expect(1, 65279, '\P{^Is_Blk=	_Arabic_pf_B}', "");
Expect(0, 65280, '\p{Is_Blk=	_Arabic_pf_B}', "");
Expect(1, 65280, '\p{^Is_Blk=	_Arabic_pf_B}', "");
Expect(1, 65280, '\P{Is_Blk=	_Arabic_pf_B}', "");
Expect(0, 65280, '\P{^Is_Blk=	_Arabic_pf_B}', "");
Error('\p{Block:	-arabic_supplement/a/}');
Error('\P{Block:	-arabic_supplement/a/}');
Expect(1, 1919, '\p{Block=arabicsupplement}', "");
Expect(0, 1919, '\p{^Block=arabicsupplement}', "");
Expect(0, 1919, '\P{Block=arabicsupplement}', "");
Expect(1, 1919, '\P{^Block=arabicsupplement}', "");
Expect(0, 1920, '\p{Block=arabicsupplement}', "");
Expect(1, 1920, '\p{^Block=arabicsupplement}', "");
Expect(1, 1920, '\P{Block=arabicsupplement}', "");
Expect(0, 1920, '\P{^Block=arabicsupplement}', "");
Expect(1, 1919, '\p{Block=_Arabic_Supplement}', "");
Expect(0, 1919, '\p{^Block=_Arabic_Supplement}', "");
Expect(0, 1919, '\P{Block=_Arabic_Supplement}', "");
Expect(1, 1919, '\P{^Block=_Arabic_Supplement}', "");
Expect(0, 1920, '\p{Block=_Arabic_Supplement}', "");
Expect(1, 1920, '\p{^Block=_Arabic_Supplement}', "");
Expect(1, 1920, '\P{Block=_Arabic_Supplement}', "");
Expect(0, 1920, '\P{^Block=_Arabic_Supplement}', "");
Error('\p{Blk=:=-_Arabic_sup}');
Error('\P{Blk=:=-_Arabic_sup}');
Expect(1, 1919, '\p{Blk:	arabicsup}', "");
Expect(0, 1919, '\p{^Blk:	arabicsup}', "");
Expect(0, 1919, '\P{Blk:	arabicsup}', "");
Expect(1, 1919, '\P{^Blk:	arabicsup}', "");
Expect(0, 1920, '\p{Blk:	arabicsup}', "");
Expect(1, 1920, '\p{^Blk:	arabicsup}', "");
Expect(1, 1920, '\P{Blk:	arabicsup}', "");
Expect(0, 1920, '\P{^Blk:	arabicsup}', "");
Expect(1, 1919, '\p{Blk=	ARABIC_Sup}', "");
Expect(0, 1919, '\p{^Blk=	ARABIC_Sup}', "");
Expect(0, 1919, '\P{Blk=	ARABIC_Sup}', "");
Expect(1, 1919, '\P{^Blk=	ARABIC_Sup}', "");
Expect(0, 1920, '\p{Blk=	ARABIC_Sup}', "");
Expect(1, 1920, '\p{^Blk=	ARABIC_Sup}', "");
Expect(1, 1920, '\P{Blk=	ARABIC_Sup}', "");
Expect(0, 1920, '\P{^Blk=	ARABIC_Sup}', "");
Error('\p{Is_Block=/a/-_arabic_SUPPLEMENT}');
Error('\P{Is_Block=/a/-_arabic_SUPPLEMENT}');
Expect(1, 1919, '\p{Is_Block=arabicsupplement}', "");
Expect(0, 1919, '\p{^Is_Block=arabicsupplement}', "");
Expect(0, 1919, '\P{Is_Block=arabicsupplement}', "");
Expect(1, 1919, '\P{^Is_Block=arabicsupplement}', "");
Expect(0, 1920, '\p{Is_Block=arabicsupplement}', "");
Expect(1, 1920, '\p{^Is_Block=arabicsupplement}', "");
Expect(1, 1920, '\P{Is_Block=arabicsupplement}', "");
Expect(0, 1920, '\P{^Is_Block=arabicsupplement}', "");
Expect(1, 1919, '\p{Is_Block=-_Arabic_SUPPLEMENT}', "");
Expect(0, 1919, '\p{^Is_Block=-_Arabic_SUPPLEMENT}', "");
Expect(0, 1919, '\P{Is_Block=-_Arabic_SUPPLEMENT}', "");
Expect(1, 1919, '\P{^Is_Block=-_Arabic_SUPPLEMENT}', "");
Expect(0, 1920, '\p{Is_Block=-_Arabic_SUPPLEMENT}', "");
Expect(1, 1920, '\p{^Is_Block=-_Arabic_SUPPLEMENT}', "");
Expect(1, 1920, '\P{Is_Block=-_Arabic_SUPPLEMENT}', "");
Expect(0, 1920, '\P{^Is_Block=-_Arabic_SUPPLEMENT}', "");
Error('\p{Is_Blk=:=	Arabic_sup}');
Error('\P{Is_Blk=:=	Arabic_sup}');
Expect(1, 1919, '\p{Is_Blk=arabicsup}', "");
Expect(0, 1919, '\p{^Is_Blk=arabicsup}', "");
Expect(0, 1919, '\P{Is_Blk=arabicsup}', "");
Expect(1, 1919, '\P{^Is_Blk=arabicsup}', "");
Expect(0, 1920, '\p{Is_Blk=arabicsup}', "");
Expect(1, 1920, '\p{^Is_Blk=arabicsup}', "");
Expect(1, 1920, '\P{Is_Blk=arabicsup}', "");
Expect(0, 1920, '\P{^Is_Blk=arabicsup}', "");
Expect(1, 1919, '\p{Is_Blk=	-arabic_SUP}', "");
Expect(0, 1919, '\p{^Is_Blk=	-arabic_SUP}', "");
Expect(0, 1919, '\P{Is_Blk=	-arabic_SUP}', "");
Expect(1, 1919, '\P{^Is_Blk=	-arabic_SUP}', "");
Expect(0, 1920, '\p{Is_Blk=	-arabic_SUP}', "");
Expect(1, 1920, '\p{^Is_Blk=	-arabic_SUP}', "");
Expect(1, 1920, '\P{Is_Blk=	-arabic_SUP}', "");
Expect(0, 1920, '\P{^Is_Blk=	-arabic_SUP}', "");
Error('\p{Block= /a/ARMENIAN}');
Error('\P{Block= /a/ARMENIAN}');
Expect(1, 1423, '\p{Block=armenian}', "");
Expect(0, 1423, '\p{^Block=armenian}', "");
Expect(0, 1423, '\P{Block=armenian}', "");
Expect(1, 1423, '\P{^Block=armenian}', "");
Expect(0, 1424, '\p{Block=armenian}', "");
Expect(1, 1424, '\p{^Block=armenian}', "");
Expect(1, 1424, '\P{Block=armenian}', "");
Expect(0, 1424, '\P{^Block=armenian}', "");
Expect(1, 1423, '\p{Block:	 ARMENIAN}', "");
Expect(0, 1423, '\p{^Block:	 ARMENIAN}', "");
Expect(0, 1423, '\P{Block:	 ARMENIAN}', "");
Expect(1, 1423, '\P{^Block:	 ARMENIAN}', "");
Expect(0, 1424, '\p{Block:	 ARMENIAN}', "");
Expect(1, 1424, '\p{^Block:	 ARMENIAN}', "");
Expect(1, 1424, '\P{Block:	 ARMENIAN}', "");
Expect(0, 1424, '\P{^Block:	 ARMENIAN}', "");
Error('\p{Blk=_/a/Armenian}');
Error('\P{Blk=_/a/Armenian}');
Expect(1, 1423, '\p{Blk=armenian}', "");
Expect(0, 1423, '\p{^Blk=armenian}', "");
Expect(0, 1423, '\P{Blk=armenian}', "");
Expect(1, 1423, '\P{^Blk=armenian}', "");
Expect(0, 1424, '\p{Blk=armenian}', "");
Expect(1, 1424, '\p{^Blk=armenian}', "");
Expect(1, 1424, '\P{Blk=armenian}', "");
Expect(0, 1424, '\P{^Blk=armenian}', "");
Expect(1, 1423, '\p{Blk=-_ARMENIAN}', "");
Expect(0, 1423, '\p{^Blk=-_ARMENIAN}', "");
Expect(0, 1423, '\P{Blk=-_ARMENIAN}', "");
Expect(1, 1423, '\P{^Blk=-_ARMENIAN}', "");
Expect(0, 1424, '\p{Blk=-_ARMENIAN}', "");
Expect(1, 1424, '\p{^Blk=-_ARMENIAN}', "");
Expect(1, 1424, '\P{Blk=-_ARMENIAN}', "");
Expect(0, 1424, '\P{^Blk=-_ARMENIAN}', "");
Error('\p{Is_Block=:=	-Armenian}');
Error('\P{Is_Block=:=	-Armenian}');
Expect(1, 1423, '\p{Is_Block=armenian}', "");
Expect(0, 1423, '\p{^Is_Block=armenian}', "");
Expect(0, 1423, '\P{Is_Block=armenian}', "");
Expect(1, 1423, '\P{^Is_Block=armenian}', "");
Expect(0, 1424, '\p{Is_Block=armenian}', "");
Expect(1, 1424, '\p{^Is_Block=armenian}', "");
Expect(1, 1424, '\P{Is_Block=armenian}', "");
Expect(0, 1424, '\P{^Is_Block=armenian}', "");
Expect(1, 1423, '\p{Is_Block=_	armenian}', "");
Expect(0, 1423, '\p{^Is_Block=_	armenian}', "");
Expect(0, 1423, '\P{Is_Block=_	armenian}', "");
Expect(1, 1423, '\P{^Is_Block=_	armenian}', "");
Expect(0, 1424, '\p{Is_Block=_	armenian}', "");
Expect(1, 1424, '\p{^Is_Block=_	armenian}', "");
Expect(1, 1424, '\P{Is_Block=_	armenian}', "");
Expect(0, 1424, '\P{^Is_Block=_	armenian}', "");
Error('\p{Is_Blk:   	_armenian/a/}');
Error('\P{Is_Blk:   	_armenian/a/}');
Expect(1, 1423, '\p{Is_Blk=armenian}', "");
Expect(0, 1423, '\p{^Is_Blk=armenian}', "");
Expect(0, 1423, '\P{Is_Blk=armenian}', "");
Expect(1, 1423, '\P{^Is_Blk=armenian}', "");
Expect(0, 1424, '\p{Is_Blk=armenian}', "");
Expect(1, 1424, '\p{^Is_Blk=armenian}', "");
Expect(1, 1424, '\P{Is_Blk=armenian}', "");
Expect(0, 1424, '\P{^Is_Blk=armenian}', "");
Expect(1, 1423, '\p{Is_Blk=_ armenian}', "");
Expect(0, 1423, '\p{^Is_Blk=_ armenian}', "");
Expect(0, 1423, '\P{Is_Blk=_ armenian}', "");
Expect(1, 1423, '\P{^Is_Blk=_ armenian}', "");
Expect(0, 1424, '\p{Is_Blk=_ armenian}', "");
Expect(1, 1424, '\p{^Is_Blk=_ armenian}', "");
Expect(1, 1424, '\P{Is_Blk=_ armenian}', "");
Expect(0, 1424, '\P{^Is_Blk=_ armenian}', "");
Error('\p{Block= /a/ARROWS}');
Error('\P{Block= /a/ARROWS}');
Expect(1, 8703, '\p{Block=arrows}', "");
Expect(0, 8703, '\p{^Block=arrows}', "");
Expect(0, 8703, '\P{Block=arrows}', "");
Expect(1, 8703, '\P{^Block=arrows}', "");
Expect(0, 8704, '\p{Block=arrows}', "");
Expect(1, 8704, '\p{^Block=arrows}', "");
Expect(1, 8704, '\P{Block=arrows}', "");
Expect(0, 8704, '\P{^Block=arrows}', "");
Expect(1, 8703, '\p{Block:  -arrows}', "");
Expect(0, 8703, '\p{^Block:  -arrows}', "");
Expect(0, 8703, '\P{Block:  -arrows}', "");
Expect(1, 8703, '\P{^Block:  -arrows}', "");
Expect(0, 8704, '\p{Block:  -arrows}', "");
Expect(1, 8704, '\p{^Block:  -arrows}', "");
Expect(1, 8704, '\P{Block:  -arrows}', "");
Expect(0, 8704, '\P{^Block:  -arrows}', "");
Error('\p{Blk=/a/Arrows}');
Error('\P{Blk=/a/Arrows}');
Expect(1, 8703, '\p{Blk=arrows}', "");
Expect(0, 8703, '\p{^Blk=arrows}', "");
Expect(0, 8703, '\P{Blk=arrows}', "");
Expect(1, 8703, '\P{^Blk=arrows}', "");
Expect(0, 8704, '\p{Blk=arrows}', "");
Expect(1, 8704, '\p{^Blk=arrows}', "");
Expect(1, 8704, '\P{Blk=arrows}', "");
Expect(0, 8704, '\P{^Blk=arrows}', "");
Expect(1, 8703, '\p{Blk=	 arrows}', "");
Expect(0, 8703, '\p{^Blk=	 arrows}', "");
Expect(0, 8703, '\P{Blk=	 arrows}', "");
Expect(1, 8703, '\P{^Blk=	 arrows}', "");
Expect(0, 8704, '\p{Blk=	 arrows}', "");
Expect(1, 8704, '\p{^Blk=	 arrows}', "");
Expect(1, 8704, '\P{Blk=	 arrows}', "");
Expect(0, 8704, '\P{^Blk=	 arrows}', "");
Error('\p{Is_Block=-arrows/a/}');
Error('\P{Is_Block=-arrows/a/}');
Expect(1, 8703, '\p{Is_Block=arrows}', "");
Expect(0, 8703, '\p{^Is_Block=arrows}', "");
Expect(0, 8703, '\P{Is_Block=arrows}', "");
Expect(1, 8703, '\P{^Is_Block=arrows}', "");
Expect(0, 8704, '\p{Is_Block=arrows}', "");
Expect(1, 8704, '\p{^Is_Block=arrows}', "");
Expect(1, 8704, '\P{Is_Block=arrows}', "");
Expect(0, 8704, '\P{^Is_Block=arrows}', "");
Expect(1, 8703, '\p{Is_Block:-Arrows}', "");
Expect(0, 8703, '\p{^Is_Block:-Arrows}', "");
Expect(0, 8703, '\P{Is_Block:-Arrows}', "");
Expect(1, 8703, '\P{^Is_Block:-Arrows}', "");
Expect(0, 8704, '\p{Is_Block:-Arrows}', "");
Expect(1, 8704, '\p{^Is_Block:-Arrows}', "");
Expect(1, 8704, '\P{Is_Block:-Arrows}', "");
Expect(0, 8704, '\P{^Is_Block:-Arrows}', "");
Error('\p{Is_Blk=:=_Arrows}');
Error('\P{Is_Blk=:=_Arrows}');
Expect(1, 8703, '\p{Is_Blk=arrows}', "");
Expect(0, 8703, '\p{^Is_Blk=arrows}', "");
Expect(0, 8703, '\P{Is_Blk=arrows}', "");
Expect(1, 8703, '\P{^Is_Blk=arrows}', "");
Expect(0, 8704, '\p{Is_Blk=arrows}', "");
Expect(1, 8704, '\p{^Is_Blk=arrows}', "");
Expect(1, 8704, '\P{Is_Blk=arrows}', "");
Expect(0, 8704, '\P{^Is_Blk=arrows}', "");
Expect(1, 8703, '\p{Is_Blk=_-Arrows}', "");
Expect(0, 8703, '\p{^Is_Blk=_-Arrows}', "");
Expect(0, 8703, '\P{Is_Blk=_-Arrows}', "");
Expect(1, 8703, '\P{^Is_Blk=_-Arrows}', "");
Expect(0, 8704, '\p{Is_Blk=_-Arrows}', "");
Expect(1, 8704, '\p{^Is_Blk=_-Arrows}', "");
Expect(1, 8704, '\P{Is_Blk=_-Arrows}', "");
Expect(0, 8704, '\P{^Is_Blk=_-Arrows}', "");
Error('\p{Block=:=_AVESTAN}');
Error('\P{Block=:=_AVESTAN}');
Expect(1, 68415, '\p{Block=avestan}', "");
Expect(0, 68415, '\p{^Block=avestan}', "");
Expect(0, 68415, '\P{Block=avestan}', "");
Expect(1, 68415, '\P{^Block=avestan}', "");
Expect(0, 68416, '\p{Block=avestan}', "");
Expect(1, 68416, '\p{^Block=avestan}', "");
Expect(1, 68416, '\P{Block=avestan}', "");
Expect(0, 68416, '\P{^Block=avestan}', "");
Expect(1, 68415, '\p{Block= AVESTAN}', "");
Expect(0, 68415, '\p{^Block= AVESTAN}', "");
Expect(0, 68415, '\P{Block= AVESTAN}', "");
Expect(1, 68415, '\P{^Block= AVESTAN}', "");
Expect(0, 68416, '\p{Block= AVESTAN}', "");
Expect(1, 68416, '\p{^Block= AVESTAN}', "");
Expect(1, 68416, '\P{Block= AVESTAN}', "");
Expect(0, 68416, '\P{^Block= AVESTAN}', "");
Error('\p{Blk= Avestan:=}');
Error('\P{Blk= Avestan:=}');
Expect(1, 68415, '\p{Blk=avestan}', "");
Expect(0, 68415, '\p{^Blk=avestan}', "");
Expect(0, 68415, '\P{Blk=avestan}', "");
Expect(1, 68415, '\P{^Blk=avestan}', "");
Expect(0, 68416, '\p{Blk=avestan}', "");
Expect(1, 68416, '\p{^Blk=avestan}', "");
Expect(1, 68416, '\P{Blk=avestan}', "");
Expect(0, 68416, '\P{^Blk=avestan}', "");
Expect(1, 68415, '\p{Blk=-	Avestan}', "");
Expect(0, 68415, '\p{^Blk=-	Avestan}', "");
Expect(0, 68415, '\P{Blk=-	Avestan}', "");
Expect(1, 68415, '\P{^Blk=-	Avestan}', "");
Expect(0, 68416, '\p{Blk=-	Avestan}', "");
Expect(1, 68416, '\p{^Blk=-	Avestan}', "");
Expect(1, 68416, '\P{Blk=-	Avestan}', "");
Expect(0, 68416, '\P{^Blk=-	Avestan}', "");
Error('\p{Is_Block=:=-	Avestan}');
Error('\P{Is_Block=:=-	Avestan}');
Expect(1, 68415, '\p{Is_Block=avestan}', "");
Expect(0, 68415, '\p{^Is_Block=avestan}', "");
Expect(0, 68415, '\P{Is_Block=avestan}', "");
Expect(1, 68415, '\P{^Is_Block=avestan}', "");
Expect(0, 68416, '\p{Is_Block=avestan}', "");
Expect(1, 68416, '\p{^Is_Block=avestan}', "");
Expect(1, 68416, '\P{Is_Block=avestan}', "");
Expect(0, 68416, '\P{^Is_Block=avestan}', "");
Error('\p{Is_Blk:   	/a/AVESTAN}');
Error('\P{Is_Blk:   	/a/AVESTAN}');
Expect(1, 68415, '\p{Is_Blk=avestan}', "");
Expect(0, 68415, '\p{^Is_Blk=avestan}', "");
Expect(0, 68415, '\P{Is_Blk=avestan}', "");
Expect(1, 68415, '\P{^Is_Blk=avestan}', "");
Expect(0, 68416, '\p{Is_Blk=avestan}', "");
Expect(1, 68416, '\p{^Is_Blk=avestan}', "");
Expect(1, 68416, '\P{Is_Blk=avestan}', "");
Expect(0, 68416, '\P{^Is_Blk=avestan}', "");
Expect(1, 68415, '\p{Is_Blk=- avestan}', "");
Expect(0, 68415, '\p{^Is_Blk=- avestan}', "");
Expect(0, 68415, '\P{Is_Blk=- avestan}', "");
Expect(1, 68415, '\P{^Is_Blk=- avestan}', "");
Expect(0, 68416, '\p{Is_Blk=- avestan}', "");
Expect(1, 68416, '\p{^Is_Blk=- avestan}', "");
Expect(1, 68416, '\P{Is_Blk=- avestan}', "");
Expect(0, 68416, '\P{^Is_Blk=- avestan}', "");
Error('\p{Block=BALINESE:=}');
Error('\P{Block=BALINESE:=}');
Expect(1, 7039, '\p{Block=balinese}', "");
Expect(0, 7039, '\p{^Block=balinese}', "");
Expect(0, 7039, '\P{Block=balinese}', "");
Expect(1, 7039, '\P{^Block=balinese}', "");
Expect(0, 7040, '\p{Block=balinese}', "");
Expect(1, 7040, '\p{^Block=balinese}', "");
Expect(1, 7040, '\P{Block=balinese}', "");
Expect(0, 7040, '\P{^Block=balinese}', "");
Expect(1, 7039, '\p{Block=	Balinese}', "");
Expect(0, 7039, '\p{^Block=	Balinese}', "");
Expect(0, 7039, '\P{Block=	Balinese}', "");
Expect(1, 7039, '\P{^Block=	Balinese}', "");
Expect(0, 7040, '\p{Block=	Balinese}', "");
Expect(1, 7040, '\p{^Block=	Balinese}', "");
Expect(1, 7040, '\P{Block=	Balinese}', "");
Expect(0, 7040, '\P{^Block=	Balinese}', "");
Error('\p{Blk=:=BALINESE}');
Error('\P{Blk=:=BALINESE}');
Expect(1, 7039, '\p{Blk=balinese}', "");
Expect(0, 7039, '\p{^Blk=balinese}', "");
Expect(0, 7039, '\P{Blk=balinese}', "");
Expect(1, 7039, '\P{^Blk=balinese}', "");
Expect(0, 7040, '\p{Blk=balinese}', "");
Expect(1, 7040, '\p{^Blk=balinese}', "");
Expect(1, 7040, '\P{Blk=balinese}', "");
Expect(0, 7040, '\P{^Blk=balinese}', "");
Expect(1, 7039, '\p{Blk=_ Balinese}', "");
Expect(0, 7039, '\p{^Blk=_ Balinese}', "");
Expect(0, 7039, '\P{Blk=_ Balinese}', "");
Expect(1, 7039, '\P{^Blk=_ Balinese}', "");
Expect(0, 7040, '\p{Blk=_ Balinese}', "");
Expect(1, 7040, '\p{^Blk=_ Balinese}', "");
Expect(1, 7040, '\P{Blk=_ Balinese}', "");
Expect(0, 7040, '\P{^Blk=_ Balinese}', "");
Error('\p{Is_Block:   /a/	BALINESE}');
Error('\P{Is_Block:   /a/	BALINESE}');
Expect(1, 7039, '\p{Is_Block=balinese}', "");
Expect(0, 7039, '\p{^Is_Block=balinese}', "");
Expect(0, 7039, '\P{Is_Block=balinese}', "");
Expect(1, 7039, '\P{^Is_Block=balinese}', "");
Expect(0, 7040, '\p{Is_Block=balinese}', "");
Expect(1, 7040, '\p{^Is_Block=balinese}', "");
Expect(1, 7040, '\P{Is_Block=balinese}', "");
Expect(0, 7040, '\P{^Is_Block=balinese}', "");
Expect(1, 7039, '\p{Is_Block=	 balinese}', "");
Expect(0, 7039, '\p{^Is_Block=	 balinese}', "");
Expect(0, 7039, '\P{Is_Block=	 balinese}', "");
Expect(1, 7039, '\P{^Is_Block=	 balinese}', "");
Expect(0, 7040, '\p{Is_Block=	 balinese}', "");
Expect(1, 7040, '\p{^Is_Block=	 balinese}', "");
Expect(1, 7040, '\P{Is_Block=	 balinese}', "");
Expect(0, 7040, '\P{^Is_Block=	 balinese}', "");
Error('\p{Is_Blk=/a/ -BALINESE}');
Error('\P{Is_Blk=/a/ -BALINESE}');
Expect(1, 7039, '\p{Is_Blk=balinese}', "");
Expect(0, 7039, '\p{^Is_Blk=balinese}', "");
Expect(0, 7039, '\P{Is_Blk=balinese}', "");
Expect(1, 7039, '\P{^Is_Blk=balinese}', "");
Expect(0, 7040, '\p{Is_Blk=balinese}', "");
Expect(1, 7040, '\p{^Is_Blk=balinese}', "");
Expect(1, 7040, '\P{Is_Blk=balinese}', "");
Expect(0, 7040, '\P{^Is_Blk=balinese}', "");
Expect(1, 7039, '\p{Is_Blk=	_balinese}', "");
Expect(0, 7039, '\p{^Is_Blk=	_balinese}', "");
Expect(0, 7039, '\P{Is_Blk=	_balinese}', "");
Expect(1, 7039, '\P{^Is_Blk=	_balinese}', "");
Expect(0, 7040, '\p{Is_Blk=	_balinese}', "");
Expect(1, 7040, '\p{^Is_Blk=	_balinese}', "");
Expect(1, 7040, '\P{Is_Blk=	_balinese}', "");
Expect(0, 7040, '\P{^Is_Blk=	_balinese}', "");
Error('\p{Block:	/a/Bamum}');
Error('\P{Block:	/a/Bamum}');
Expect(1, 42751, '\p{Block=bamum}', "");
Expect(0, 42751, '\p{^Block=bamum}', "");
Expect(0, 42751, '\P{Block=bamum}', "");
Expect(1, 42751, '\P{^Block=bamum}', "");
Expect(0, 42752, '\p{Block=bamum}', "");
Expect(1, 42752, '\p{^Block=bamum}', "");
Expect(1, 42752, '\P{Block=bamum}', "");
Expect(0, 42752, '\P{^Block=bamum}', "");
Expect(1, 42751, '\p{Block=__bamum}', "");
Expect(0, 42751, '\p{^Block=__bamum}', "");
Expect(0, 42751, '\P{Block=__bamum}', "");
Expect(1, 42751, '\P{^Block=__bamum}', "");
Expect(0, 42752, '\p{Block=__bamum}', "");
Expect(1, 42752, '\p{^Block=__bamum}', "");
Expect(1, 42752, '\P{Block=__bamum}', "");
Expect(0, 42752, '\P{^Block=__bamum}', "");
Error('\p{Blk=/a/ Bamum}');
Error('\P{Blk=/a/ Bamum}');
Expect(1, 42751, '\p{Blk=bamum}', "");
Expect(0, 42751, '\p{^Blk=bamum}', "");
Expect(0, 42751, '\P{Blk=bamum}', "");
Expect(1, 42751, '\P{^Blk=bamum}', "");
Expect(0, 42752, '\p{Blk=bamum}', "");
Expect(1, 42752, '\p{^Blk=bamum}', "");
Expect(1, 42752, '\P{Blk=bamum}', "");
Expect(0, 42752, '\P{^Blk=bamum}', "");
Expect(1, 42751, '\p{Blk=- Bamum}', "");
Expect(0, 42751, '\p{^Blk=- Bamum}', "");
Expect(0, 42751, '\P{Blk=- Bamum}', "");
Expect(1, 42751, '\P{^Blk=- Bamum}', "");
Expect(0, 42752, '\p{Blk=- Bamum}', "");
Expect(1, 42752, '\p{^Blk=- Bamum}', "");
Expect(1, 42752, '\P{Blk=- Bamum}', "");
Expect(0, 42752, '\P{^Blk=- Bamum}', "");
Error('\p{Is_Block= 	Bamum/a/}');
Error('\P{Is_Block= 	Bamum/a/}');
Expect(1, 42751, '\p{Is_Block=bamum}', "");
Expect(0, 42751, '\p{^Is_Block=bamum}', "");
Expect(0, 42751, '\P{Is_Block=bamum}', "");
Expect(1, 42751, '\P{^Is_Block=bamum}', "");
Expect(0, 42752, '\p{Is_Block=bamum}', "");
Expect(1, 42752, '\p{^Is_Block=bamum}', "");
Expect(1, 42752, '\P{Is_Block=bamum}', "");
Expect(0, 42752, '\P{^Is_Block=bamum}', "");
Expect(1, 42751, '\p{Is_Block=_Bamum}', "");
Expect(0, 42751, '\p{^Is_Block=_Bamum}', "");
Expect(0, 42751, '\P{Is_Block=_Bamum}', "");
Expect(1, 42751, '\P{^Is_Block=_Bamum}', "");
Expect(0, 42752, '\p{Is_Block=_Bamum}', "");
Expect(1, 42752, '\p{^Is_Block=_Bamum}', "");
Expect(1, 42752, '\P{Is_Block=_Bamum}', "");
Expect(0, 42752, '\P{^Is_Block=_Bamum}', "");
Error('\p{Is_Blk=_Bamum/a/}');
Error('\P{Is_Blk=_Bamum/a/}');
Expect(1, 42751, '\p{Is_Blk=bamum}', "");
Expect(0, 42751, '\p{^Is_Blk=bamum}', "");
Expect(0, 42751, '\P{Is_Blk=bamum}', "");
Expect(1, 42751, '\P{^Is_Blk=bamum}', "");
Expect(0, 42752, '\p{Is_Blk=bamum}', "");
Expect(1, 42752, '\p{^Is_Blk=bamum}', "");
Expect(1, 42752, '\P{Is_Blk=bamum}', "");
Expect(0, 42752, '\P{^Is_Blk=bamum}', "");
Expect(1, 42751, '\p{Is_Blk=	Bamum}', "");
Expect(0, 42751, '\p{^Is_Blk=	Bamum}', "");
Expect(0, 42751, '\P{Is_Blk=	Bamum}', "");
Expect(1, 42751, '\P{^Is_Blk=	Bamum}', "");
Expect(0, 42752, '\p{Is_Blk=	Bamum}', "");
Expect(1, 42752, '\p{^Is_Blk=	Bamum}', "");
Expect(1, 42752, '\P{Is_Blk=	Bamum}', "");
Expect(0, 42752, '\P{^Is_Blk=	Bamum}', "");
Error('\p{Block=/a/BAMUM_Supplement}');
Error('\P{Block=/a/BAMUM_Supplement}');
Expect(1, 92735, '\p{Block=bamumsupplement}', "");
Expect(0, 92735, '\p{^Block=bamumsupplement}', "");
Expect(0, 92735, '\P{Block=bamumsupplement}', "");
Expect(1, 92735, '\P{^Block=bamumsupplement}', "");
Expect(0, 92736, '\p{Block=bamumsupplement}', "");
Expect(1, 92736, '\p{^Block=bamumsupplement}', "");
Expect(1, 92736, '\P{Block=bamumsupplement}', "");
Expect(0, 92736, '\P{^Block=bamumsupplement}', "");
Expect(1, 92735, '\p{Block=_ bamum_Supplement}', "");
Expect(0, 92735, '\p{^Block=_ bamum_Supplement}', "");
Expect(0, 92735, '\P{Block=_ bamum_Supplement}', "");
Expect(1, 92735, '\P{^Block=_ bamum_Supplement}', "");
Expect(0, 92736, '\p{Block=_ bamum_Supplement}', "");
Expect(1, 92736, '\p{^Block=_ bamum_Supplement}', "");
Expect(1, 92736, '\P{Block=_ bamum_Supplement}', "");
Expect(0, 92736, '\P{^Block=_ bamum_Supplement}', "");
Error('\p{Blk=	 Bamum_SUP/a/}');
Error('\P{Blk=	 Bamum_SUP/a/}');
Expect(1, 92735, '\p{Blk=bamumsup}', "");
Expect(0, 92735, '\p{^Blk=bamumsup}', "");
Expect(0, 92735, '\P{Blk=bamumsup}', "");
Expect(1, 92735, '\P{^Blk=bamumsup}', "");
Expect(0, 92736, '\p{Blk=bamumsup}', "");
Expect(1, 92736, '\p{^Blk=bamumsup}', "");
Expect(1, 92736, '\P{Blk=bamumsup}', "");
Expect(0, 92736, '\P{^Blk=bamumsup}', "");
Expect(1, 92735, '\p{Blk=_Bamum_sup}', "");
Expect(0, 92735, '\p{^Blk=_Bamum_sup}', "");
Expect(0, 92735, '\P{Blk=_Bamum_sup}', "");
Expect(1, 92735, '\P{^Blk=_Bamum_sup}', "");
Expect(0, 92736, '\p{Blk=_Bamum_sup}', "");
Expect(1, 92736, '\p{^Blk=_Bamum_sup}', "");
Expect(1, 92736, '\P{Blk=_Bamum_sup}', "");
Expect(0, 92736, '\P{^Blk=_Bamum_sup}', "");
Error('\p{Is_Block=-	Bamum_supplement/a/}');
Error('\P{Is_Block=-	Bamum_supplement/a/}');
Expect(1, 92735, '\p{Is_Block=bamumsupplement}', "");
Expect(0, 92735, '\p{^Is_Block=bamumsupplement}', "");
Expect(0, 92735, '\P{Is_Block=bamumsupplement}', "");
Expect(1, 92735, '\P{^Is_Block=bamumsupplement}', "");
Expect(0, 92736, '\p{Is_Block=bamumsupplement}', "");
Expect(1, 92736, '\p{^Is_Block=bamumsupplement}', "");
Expect(1, 92736, '\P{Is_Block=bamumsupplement}', "");
Expect(0, 92736, '\P{^Is_Block=bamumsupplement}', "");
Expect(1, 92735, '\p{Is_Block= 	Bamum_Supplement}', "");
Expect(0, 92735, '\p{^Is_Block= 	Bamum_Supplement}', "");
Expect(0, 92735, '\P{Is_Block= 	Bamum_Supplement}', "");
Expect(1, 92735, '\P{^Is_Block= 	Bamum_Supplement}', "");
Expect(0, 92736, '\p{Is_Block= 	Bamum_Supplement}', "");
Expect(1, 92736, '\p{^Is_Block= 	Bamum_Supplement}', "");
Expect(1, 92736, '\P{Is_Block= 	Bamum_Supplement}', "");
Expect(0, 92736, '\P{^Is_Block= 	Bamum_Supplement}', "");
Error('\p{Is_Blk=/a/_-BAMUM_Sup}');
Error('\P{Is_Blk=/a/_-BAMUM_Sup}');
Expect(1, 92735, '\p{Is_Blk: bamumsup}', "");
Expect(0, 92735, '\p{^Is_Blk: bamumsup}', "");
Expect(0, 92735, '\P{Is_Blk: bamumsup}', "");
Expect(1, 92735, '\P{^Is_Blk: bamumsup}', "");
Expect(0, 92736, '\p{Is_Blk: bamumsup}', "");
Expect(1, 92736, '\p{^Is_Blk: bamumsup}', "");
Expect(1, 92736, '\P{Is_Blk: bamumsup}', "");
Expect(0, 92736, '\P{^Is_Blk: bamumsup}', "");
Expect(1, 92735, '\p{Is_Blk=-	BAMUM_SUP}', "");
Expect(0, 92735, '\p{^Is_Blk=-	BAMUM_SUP}', "");
Expect(0, 92735, '\P{Is_Blk=-	BAMUM_SUP}', "");
Expect(1, 92735, '\P{^Is_Blk=-	BAMUM_SUP}', "");
Expect(0, 92736, '\p{Is_Blk=-	BAMUM_SUP}', "");
Expect(1, 92736, '\p{^Is_Blk=-	BAMUM_SUP}', "");
Expect(1, 92736, '\P{Is_Blk=-	BAMUM_SUP}', "");
Expect(0, 92736, '\P{^Is_Blk=-	BAMUM_SUP}', "");
Error('\p{Block=-/a/batak}');
Error('\P{Block=-/a/batak}');
Expect(1, 7167, '\p{Block:	batak}', "");
Expect(0, 7167, '\p{^Block:	batak}', "");
Expect(0, 7167, '\P{Block:	batak}', "");
Expect(1, 7167, '\P{^Block:	batak}', "");
Expect(0, 7168, '\p{Block:	batak}', "");
Expect(1, 7168, '\p{^Block:	batak}', "");
Expect(1, 7168, '\P{Block:	batak}', "");
Expect(0, 7168, '\P{^Block:	batak}', "");
Expect(1, 7167, '\p{Block= BATAK}', "");
Expect(0, 7167, '\p{^Block= BATAK}', "");
Expect(0, 7167, '\P{Block= BATAK}', "");
Expect(1, 7167, '\P{^Block= BATAK}', "");
Expect(0, 7168, '\p{Block= BATAK}', "");
Expect(1, 7168, '\p{^Block= BATAK}', "");
Expect(1, 7168, '\P{Block= BATAK}', "");
Expect(0, 7168, '\P{^Block= BATAK}', "");
Error('\p{Blk=:=	-batak}');
Error('\P{Blk=:=	-batak}');
Expect(1, 7167, '\p{Blk=batak}', "");
Expect(0, 7167, '\p{^Blk=batak}', "");
Expect(0, 7167, '\P{Blk=batak}', "");
Expect(1, 7167, '\P{^Blk=batak}', "");
Expect(0, 7168, '\p{Blk=batak}', "");
Expect(1, 7168, '\p{^Blk=batak}', "");
Expect(1, 7168, '\P{Blk=batak}', "");
Expect(0, 7168, '\P{^Blk=batak}', "");
Expect(1, 7167, '\p{Blk=-batak}', "");
Expect(0, 7167, '\p{^Blk=-batak}', "");
Expect(0, 7167, '\P{Blk=-batak}', "");
Expect(1, 7167, '\P{^Blk=-batak}', "");
Expect(0, 7168, '\p{Blk=-batak}', "");
Expect(1, 7168, '\p{^Blk=-batak}', "");
Expect(1, 7168, '\P{Blk=-batak}', "");
Expect(0, 7168, '\P{^Blk=-batak}', "");
Error('\p{Is_Block=/a/Batak}');
Error('\P{Is_Block=/a/Batak}');
Expect(1, 7167, '\p{Is_Block=batak}', "");
Expect(0, 7167, '\p{^Is_Block=batak}', "");
Expect(0, 7167, '\P{Is_Block=batak}', "");
Expect(1, 7167, '\P{^Is_Block=batak}', "");
Expect(0, 7168, '\p{Is_Block=batak}', "");
Expect(1, 7168, '\p{^Is_Block=batak}', "");
Expect(1, 7168, '\P{Is_Block=batak}', "");
Expect(0, 7168, '\P{^Is_Block=batak}', "");
Expect(1, 7167, '\p{Is_Block= 	Batak}', "");
Expect(0, 7167, '\p{^Is_Block= 	Batak}', "");
Expect(0, 7167, '\P{Is_Block= 	Batak}', "");
Expect(1, 7167, '\P{^Is_Block= 	Batak}', "");
Expect(0, 7168, '\p{Is_Block= 	Batak}', "");
Expect(1, 7168, '\p{^Is_Block= 	Batak}', "");
Expect(1, 7168, '\P{Is_Block= 	Batak}', "");
Expect(0, 7168, '\P{^Is_Block= 	Batak}', "");
Error('\p{Is_Blk=_:=BATAK}');
Error('\P{Is_Blk=_:=BATAK}');
Expect(1, 7167, '\p{Is_Blk=batak}', "");
Expect(0, 7167, '\p{^Is_Blk=batak}', "");
Expect(0, 7167, '\P{Is_Blk=batak}', "");
Expect(1, 7167, '\P{^Is_Blk=batak}', "");
Expect(0, 7168, '\p{Is_Blk=batak}', "");
Expect(1, 7168, '\p{^Is_Blk=batak}', "");
Expect(1, 7168, '\P{Is_Blk=batak}', "");
Expect(0, 7168, '\P{^Is_Blk=batak}', "");
Expect(1, 7167, '\p{Is_Blk=_-Batak}', "");
Expect(0, 7167, '\p{^Is_Blk=_-Batak}', "");
Expect(0, 7167, '\P{Is_Blk=_-Batak}', "");
Expect(1, 7167, '\P{^Is_Blk=_-Batak}', "");
Expect(0, 7168, '\p{Is_Blk=_-Batak}', "");
Expect(1, 7168, '\p{^Is_Blk=_-Batak}', "");
Expect(1, 7168, '\P{Is_Blk=_-Batak}', "");
Expect(0, 7168, '\P{^Is_Blk=_-Batak}', "");
Error('\p{Block=:=Bengali}');
Error('\P{Block=:=Bengali}');
Expect(1, 2559, '\p{Block=bengali}', "");
Expect(0, 2559, '\p{^Block=bengali}', "");
Expect(0, 2559, '\P{Block=bengali}', "");
Expect(1, 2559, '\P{^Block=bengali}', "");
Expect(0, 2560, '\p{Block=bengali}', "");
Expect(1, 2560, '\p{^Block=bengali}', "");
Expect(1, 2560, '\P{Block=bengali}', "");
Expect(0, 2560, '\P{^Block=bengali}', "");
Expect(1, 2559, '\p{Block=-BENGALI}', "");
Expect(0, 2559, '\p{^Block=-BENGALI}', "");
Expect(0, 2559, '\P{Block=-BENGALI}', "");
Expect(1, 2559, '\P{^Block=-BENGALI}', "");
Expect(0, 2560, '\p{Block=-BENGALI}', "");
Expect(1, 2560, '\p{^Block=-BENGALI}', "");
Expect(1, 2560, '\P{Block=-BENGALI}', "");
Expect(0, 2560, '\P{^Block=-BENGALI}', "");
Error('\p{Blk=		Bengali/a/}');
Error('\P{Blk=		Bengali/a/}');
Expect(1, 2559, '\p{Blk=bengali}', "");
Expect(0, 2559, '\p{^Blk=bengali}', "");
Expect(0, 2559, '\P{Blk=bengali}', "");
Expect(1, 2559, '\P{^Blk=bengali}', "");
Expect(0, 2560, '\p{Blk=bengali}', "");
Expect(1, 2560, '\p{^Blk=bengali}', "");
Expect(1, 2560, '\P{Blk=bengali}', "");
Expect(0, 2560, '\P{^Blk=bengali}', "");
Expect(1, 2559, '\p{Blk:	 -Bengali}', "");
Expect(0, 2559, '\p{^Blk:	 -Bengali}', "");
Expect(0, 2559, '\P{Blk:	 -Bengali}', "");
Expect(1, 2559, '\P{^Blk:	 -Bengali}', "");
Expect(0, 2560, '\p{Blk:	 -Bengali}', "");
Expect(1, 2560, '\p{^Blk:	 -Bengali}', "");
Expect(1, 2560, '\P{Blk:	 -Bengali}', "");
Expect(0, 2560, '\P{^Blk:	 -Bengali}', "");
Error('\p{Is_Block=/a/Bengali}');
Error('\P{Is_Block=/a/Bengali}');
Expect(1, 2559, '\p{Is_Block=bengali}', "");
Expect(0, 2559, '\p{^Is_Block=bengali}', "");
Expect(0, 2559, '\P{Is_Block=bengali}', "");
Expect(1, 2559, '\P{^Is_Block=bengali}', "");
Expect(0, 2560, '\p{Is_Block=bengali}', "");
Expect(1, 2560, '\p{^Is_Block=bengali}', "");
Expect(1, 2560, '\P{Is_Block=bengali}', "");
Expect(0, 2560, '\P{^Is_Block=bengali}', "");
Expect(1, 2559, '\p{Is_Block= -Bengali}', "");
Expect(0, 2559, '\p{^Is_Block= -Bengali}', "");
Expect(0, 2559, '\P{Is_Block= -Bengali}', "");
Expect(1, 2559, '\P{^Is_Block= -Bengali}', "");
Expect(0, 2560, '\p{Is_Block= -Bengali}', "");
Expect(1, 2560, '\p{^Is_Block= -Bengali}', "");
Expect(1, 2560, '\P{Is_Block= -Bengali}', "");
Expect(0, 2560, '\P{^Is_Block= -Bengali}', "");
Error('\p{Is_Blk=/a/_	BENGALI}');
Error('\P{Is_Blk=/a/_	BENGALI}');
Expect(1, 2559, '\p{Is_Blk=bengali}', "");
Expect(0, 2559, '\p{^Is_Blk=bengali}', "");
Expect(0, 2559, '\P{Is_Blk=bengali}', "");
Expect(1, 2559, '\P{^Is_Blk=bengali}', "");
Expect(0, 2560, '\p{Is_Blk=bengali}', "");
Expect(1, 2560, '\p{^Is_Blk=bengali}', "");
Expect(1, 2560, '\P{Is_Blk=bengali}', "");
Expect(0, 2560, '\P{^Is_Blk=bengali}', "");
Expect(1, 2559, '\p{Is_Blk=- Bengali}', "");
Expect(0, 2559, '\p{^Is_Blk=- Bengali}', "");
Expect(0, 2559, '\P{Is_Blk=- Bengali}', "");
Expect(1, 2559, '\P{^Is_Blk=- Bengali}', "");
Expect(0, 2560, '\p{Is_Blk=- Bengali}', "");
Expect(1, 2560, '\p{^Is_Blk=- Bengali}', "");
Expect(1, 2560, '\P{Is_Blk=- Bengali}', "");
Expect(0, 2560, '\P{^Is_Blk=- Bengali}', "");
Error('\p{Block=:=Block_elements}');
Error('\P{Block=:=Block_elements}');
Expect(1, 9631, '\p{Block=blockelements}', "");
Expect(0, 9631, '\p{^Block=blockelements}', "");
Expect(0, 9631, '\P{Block=blockelements}', "");
Expect(1, 9631, '\P{^Block=blockelements}', "");
Expect(0, 9632, '\p{Block=blockelements}', "");
Expect(1, 9632, '\p{^Block=blockelements}', "");
Expect(1, 9632, '\P{Block=blockelements}', "");
Expect(0, 9632, '\P{^Block=blockelements}', "");
Expect(1, 9631, '\p{Block=		Block_Elements}', "");
Expect(0, 9631, '\p{^Block=		Block_Elements}', "");
Expect(0, 9631, '\P{Block=		Block_Elements}', "");
Expect(1, 9631, '\P{^Block=		Block_Elements}', "");
Expect(0, 9632, '\p{Block=		Block_Elements}', "");
Expect(1, 9632, '\p{^Block=		Block_Elements}', "");
Expect(1, 9632, '\P{Block=		Block_Elements}', "");
Expect(0, 9632, '\P{^Block=		Block_Elements}', "");
Error('\p{Blk=	 block_Elements:=}');
Error('\P{Blk=	 block_Elements:=}');
Expect(1, 9631, '\p{Blk=blockelements}', "");
Expect(0, 9631, '\p{^Blk=blockelements}', "");
Expect(0, 9631, '\P{Blk=blockelements}', "");
Expect(1, 9631, '\P{^Blk=blockelements}', "");
Expect(0, 9632, '\p{Blk=blockelements}', "");
Expect(1, 9632, '\p{^Blk=blockelements}', "");
Expect(1, 9632, '\P{Blk=blockelements}', "");
Expect(0, 9632, '\P{^Blk=blockelements}', "");
Expect(1, 9631, '\p{Blk=-	Block_Elements}', "");
Expect(0, 9631, '\p{^Blk=-	Block_Elements}', "");
Expect(0, 9631, '\P{Blk=-	Block_Elements}', "");
Expect(1, 9631, '\P{^Blk=-	Block_Elements}', "");
Expect(0, 9632, '\p{Blk=-	Block_Elements}', "");
Expect(1, 9632, '\p{^Blk=-	Block_Elements}', "");
Expect(1, 9632, '\P{Blk=-	Block_Elements}', "");
Expect(0, 9632, '\P{^Blk=-	Block_Elements}', "");
Error('\p{Is_Block=_:=Block_ELEMENTS}');
Error('\P{Is_Block=_:=Block_ELEMENTS}');
Expect(1, 9631, '\p{Is_Block=blockelements}', "");
Expect(0, 9631, '\p{^Is_Block=blockelements}', "");
Expect(0, 9631, '\P{Is_Block=blockelements}', "");
Expect(1, 9631, '\P{^Is_Block=blockelements}', "");
Expect(0, 9632, '\p{Is_Block=blockelements}', "");
Expect(1, 9632, '\p{^Is_Block=blockelements}', "");
Expect(1, 9632, '\P{Is_Block=blockelements}', "");
Expect(0, 9632, '\P{^Is_Block=blockelements}', "");
Expect(1, 9631, '\p{Is_Block=_-Block_ELEMENTS}', "");
Expect(0, 9631, '\p{^Is_Block=_-Block_ELEMENTS}', "");
Expect(0, 9631, '\P{Is_Block=_-Block_ELEMENTS}', "");
Expect(1, 9631, '\P{^Is_Block=_-Block_ELEMENTS}', "");
Expect(0, 9632, '\p{Is_Block=_-Block_ELEMENTS}', "");
Expect(1, 9632, '\p{^Is_Block=_-Block_ELEMENTS}', "");
Expect(1, 9632, '\P{Is_Block=_-Block_ELEMENTS}', "");
Expect(0, 9632, '\P{^Is_Block=_-Block_ELEMENTS}', "");
Error('\p{Is_Blk:  /a/block_Elements}');
Error('\P{Is_Blk:  /a/block_Elements}');
Expect(1, 9631, '\p{Is_Blk=blockelements}', "");
Expect(0, 9631, '\p{^Is_Blk=blockelements}', "");
Expect(0, 9631, '\P{Is_Blk=blockelements}', "");
Expect(1, 9631, '\P{^Is_Blk=blockelements}', "");
Expect(0, 9632, '\p{Is_Blk=blockelements}', "");
Expect(1, 9632, '\p{^Is_Blk=blockelements}', "");
Expect(1, 9632, '\P{Is_Blk=blockelements}', "");
Expect(0, 9632, '\P{^Is_Blk=blockelements}', "");
Expect(1, 9631, '\p{Is_Blk=-block_ELEMENTS}', "");
Expect(0, 9631, '\p{^Is_Blk=-block_ELEMENTS}', "");
Expect(0, 9631, '\P{Is_Blk=-block_ELEMENTS}', "");
Expect(1, 9631, '\P{^Is_Blk=-block_ELEMENTS}', "");
Expect(0, 9632, '\p{Is_Blk=-block_ELEMENTS}', "");
Expect(1, 9632, '\p{^Is_Blk=-block_ELEMENTS}', "");
Expect(1, 9632, '\P{Is_Blk=-block_ELEMENTS}', "");
Expect(0, 9632, '\P{^Is_Blk=-block_ELEMENTS}', "");
Error('\p{Block=	_bopomofo/a/}');
Error('\P{Block=	_bopomofo/a/}');
Expect(1, 12591, '\p{Block=bopomofo}', "");
Expect(0, 12591, '\p{^Block=bopomofo}', "");
Expect(0, 12591, '\P{Block=bopomofo}', "");
Expect(1, 12591, '\P{^Block=bopomofo}', "");
Expect(0, 12592, '\p{Block=bopomofo}', "");
Expect(1, 12592, '\p{^Block=bopomofo}', "");
Expect(1, 12592, '\P{Block=bopomofo}', "");
Expect(0, 12592, '\P{^Block=bopomofo}', "");
Expect(1, 12591, '\p{Block= _Bopomofo}', "");
Expect(0, 12591, '\p{^Block= _Bopomofo}', "");
Expect(0, 12591, '\P{Block= _Bopomofo}', "");
Expect(1, 12591, '\P{^Block= _Bopomofo}', "");
Expect(0, 12592, '\p{Block= _Bopomofo}', "");
Expect(1, 12592, '\p{^Block= _Bopomofo}', "");
Expect(1, 12592, '\P{Block= _Bopomofo}', "");
Expect(0, 12592, '\P{^Block= _Bopomofo}', "");
Error('\p{Blk=-/a/Bopomofo}');
Error('\P{Blk=-/a/Bopomofo}');
Expect(1, 12591, '\p{Blk=bopomofo}', "");
Expect(0, 12591, '\p{^Blk=bopomofo}', "");
Expect(0, 12591, '\P{Blk=bopomofo}', "");
Expect(1, 12591, '\P{^Blk=bopomofo}', "");
Expect(0, 12592, '\p{Blk=bopomofo}', "");
Expect(1, 12592, '\p{^Blk=bopomofo}', "");
Expect(1, 12592, '\P{Blk=bopomofo}', "");
Expect(0, 12592, '\P{^Blk=bopomofo}', "");
Expect(1, 12591, '\p{Blk= 	Bopomofo}', "");
Expect(0, 12591, '\p{^Blk= 	Bopomofo}', "");
Expect(0, 12591, '\P{Blk= 	Bopomofo}', "");
Expect(1, 12591, '\P{^Blk= 	Bopomofo}', "");
Expect(0, 12592, '\p{Blk= 	Bopomofo}', "");
Expect(1, 12592, '\p{^Blk= 	Bopomofo}', "");
Expect(1, 12592, '\P{Blk= 	Bopomofo}', "");
Expect(0, 12592, '\P{^Blk= 	Bopomofo}', "");
Error('\p{Is_Block=:=- Bopomofo}');
Error('\P{Is_Block=:=- Bopomofo}');
Expect(1, 12591, '\p{Is_Block=bopomofo}', "");
Expect(0, 12591, '\p{^Is_Block=bopomofo}', "");
Expect(0, 12591, '\P{Is_Block=bopomofo}', "");
Expect(1, 12591, '\P{^Is_Block=bopomofo}', "");
Expect(0, 12592, '\p{Is_Block=bopomofo}', "");
Expect(1, 12592, '\p{^Is_Block=bopomofo}', "");
Expect(1, 12592, '\P{Is_Block=bopomofo}', "");
Expect(0, 12592, '\P{^Is_Block=bopomofo}', "");
Expect(1, 12591, '\p{Is_Block=--Bopomofo}', "");
Expect(0, 12591, '\p{^Is_Block=--Bopomofo}', "");
Expect(0, 12591, '\P{Is_Block=--Bopomofo}', "");
Expect(1, 12591, '\P{^Is_Block=--Bopomofo}', "");
Expect(0, 12592, '\p{Is_Block=--Bopomofo}', "");
Expect(1, 12592, '\p{^Is_Block=--Bopomofo}', "");
Expect(1, 12592, '\P{Is_Block=--Bopomofo}', "");
Expect(0, 12592, '\P{^Is_Block=--Bopomofo}', "");
Error('\p{Is_Blk=-	Bopomofo/a/}');
Error('\P{Is_Blk=-	Bopomofo/a/}');
Expect(1, 12591, '\p{Is_Blk=bopomofo}', "");
Expect(0, 12591, '\p{^Is_Blk=bopomofo}', "");
Expect(0, 12591, '\P{Is_Blk=bopomofo}', "");
Expect(1, 12591, '\P{^Is_Blk=bopomofo}', "");
Expect(0, 12592, '\p{Is_Blk=bopomofo}', "");
Expect(1, 12592, '\p{^Is_Blk=bopomofo}', "");
Expect(1, 12592, '\P{Is_Blk=bopomofo}', "");
Expect(0, 12592, '\P{^Is_Blk=bopomofo}', "");
Expect(1, 12591, '\p{Is_Blk=_-bopomofo}', "");
Expect(0, 12591, '\p{^Is_Blk=_-bopomofo}', "");
Expect(0, 12591, '\P{Is_Blk=_-bopomofo}', "");
Expect(1, 12591, '\P{^Is_Blk=_-bopomofo}', "");
Expect(0, 12592, '\p{Is_Blk=_-bopomofo}', "");
Expect(1, 12592, '\p{^Is_Blk=_-bopomofo}', "");
Expect(1, 12592, '\P{Is_Blk=_-bopomofo}', "");
Expect(0, 12592, '\P{^Is_Blk=_-bopomofo}', "");
Error('\p{Block=__Bopomofo_Extended:=}');
Error('\P{Block=__Bopomofo_Extended:=}');
Expect(1, 12735, '\p{Block=bopomofoextended}', "");
Expect(0, 12735, '\p{^Block=bopomofoextended}', "");
Expect(0, 12735, '\P{Block=bopomofoextended}', "");
Expect(1, 12735, '\P{^Block=bopomofoextended}', "");
Expect(0, 12736, '\p{Block=bopomofoextended}', "");
Expect(1, 12736, '\p{^Block=bopomofoextended}', "");
Expect(1, 12736, '\P{Block=bopomofoextended}', "");
Expect(0, 12736, '\P{^Block=bopomofoextended}', "");
Expect(1, 12735, '\p{Block=_	bopomofo_Extended}', "");
Expect(0, 12735, '\p{^Block=_	bopomofo_Extended}', "");
Expect(0, 12735, '\P{Block=_	bopomofo_Extended}', "");
Expect(1, 12735, '\P{^Block=_	bopomofo_Extended}', "");
Expect(0, 12736, '\p{Block=_	bopomofo_Extended}', "");
Expect(1, 12736, '\p{^Block=_	bopomofo_Extended}', "");
Expect(1, 12736, '\P{Block=_	bopomofo_Extended}', "");
Expect(0, 12736, '\P{^Block=_	bopomofo_Extended}', "");
Error('\p{Blk=-/a/BOPOMOFO_ext}');
Error('\P{Blk=-/a/BOPOMOFO_ext}');
Expect(1, 12735, '\p{Blk=bopomofoext}', "");
Expect(0, 12735, '\p{^Blk=bopomofoext}', "");
Expect(0, 12735, '\P{Blk=bopomofoext}', "");
Expect(1, 12735, '\P{^Blk=bopomofoext}', "");
Expect(0, 12736, '\p{Blk=bopomofoext}', "");
Expect(1, 12736, '\p{^Blk=bopomofoext}', "");
Expect(1, 12736, '\P{Blk=bopomofoext}', "");
Expect(0, 12736, '\P{^Blk=bopomofoext}', "");
Expect(1, 12735, '\p{Blk=		bopomofo_Ext}', "");
Expect(0, 12735, '\p{^Blk=		bopomofo_Ext}', "");
Expect(0, 12735, '\P{Blk=		bopomofo_Ext}', "");
Expect(1, 12735, '\P{^Blk=		bopomofo_Ext}', "");
Expect(0, 12736, '\p{Blk=		bopomofo_Ext}', "");
Expect(1, 12736, '\p{^Blk=		bopomofo_Ext}', "");
Expect(1, 12736, '\P{Blk=		bopomofo_Ext}', "");
Expect(0, 12736, '\P{^Blk=		bopomofo_Ext}', "");
Error('\p{Is_Block=/a/__bopomofo_Extended}');
Error('\P{Is_Block=/a/__bopomofo_Extended}');
Expect(1, 12735, '\p{Is_Block=bopomofoextended}', "");
Expect(0, 12735, '\p{^Is_Block=bopomofoextended}', "");
Expect(0, 12735, '\P{Is_Block=bopomofoextended}', "");
Expect(1, 12735, '\P{^Is_Block=bopomofoextended}', "");
Expect(0, 12736, '\p{Is_Block=bopomofoextended}', "");
Expect(1, 12736, '\p{^Is_Block=bopomofoextended}', "");
Expect(1, 12736, '\P{Is_Block=bopomofoextended}', "");
Expect(0, 12736, '\P{^Is_Block=bopomofoextended}', "");
Expect(1, 12735, '\p{Is_Block=		bopomofo_EXTENDED}', "");
Expect(0, 12735, '\p{^Is_Block=		bopomofo_EXTENDED}', "");
Expect(0, 12735, '\P{Is_Block=		bopomofo_EXTENDED}', "");
Expect(1, 12735, '\P{^Is_Block=		bopomofo_EXTENDED}', "");
Expect(0, 12736, '\p{Is_Block=		bopomofo_EXTENDED}', "");
Expect(1, 12736, '\p{^Is_Block=		bopomofo_EXTENDED}', "");
Expect(1, 12736, '\P{Is_Block=		bopomofo_EXTENDED}', "");
Expect(0, 12736, '\P{^Is_Block=		bopomofo_EXTENDED}', "");
Error('\p{Is_Blk=_bopomofo_Ext:=}');
Error('\P{Is_Blk=_bopomofo_Ext:=}');
Expect(1, 12735, '\p{Is_Blk=bopomofoext}', "");
Expect(0, 12735, '\p{^Is_Blk=bopomofoext}', "");
Expect(0, 12735, '\P{Is_Blk=bopomofoext}', "");
Expect(1, 12735, '\P{^Is_Blk=bopomofoext}', "");
Expect(0, 12736, '\p{Is_Blk=bopomofoext}', "");
Expect(1, 12736, '\p{^Is_Blk=bopomofoext}', "");
Expect(1, 12736, '\P{Is_Blk=bopomofoext}', "");
Expect(0, 12736, '\P{^Is_Blk=bopomofoext}', "");
Expect(1, 12735, '\p{Is_Blk=-Bopomofo_Ext}', "");
Expect(0, 12735, '\p{^Is_Blk=-Bopomofo_Ext}', "");
Expect(0, 12735, '\P{Is_Blk=-Bopomofo_Ext}', "");
Expect(1, 12735, '\P{^Is_Blk=-Bopomofo_Ext}', "");
Expect(0, 12736, '\p{Is_Blk=-Bopomofo_Ext}', "");
Expect(1, 12736, '\p{^Is_Blk=-Bopomofo_Ext}', "");
Expect(1, 12736, '\P{Is_Blk=-Bopomofo_Ext}', "");
Expect(0, 12736, '\P{^Is_Blk=-Bopomofo_Ext}', "");
Error('\p{Block=:=	-Box_Drawing}');
Error('\P{Block=:=	-Box_Drawing}');
Expect(1, 9599, '\p{Block=boxdrawing}', "");
Expect(0, 9599, '\p{^Block=boxdrawing}', "");
Expect(0, 9599, '\P{Block=boxdrawing}', "");
Expect(1, 9599, '\P{^Block=boxdrawing}', "");
Expect(0, 9600, '\p{Block=boxdrawing}', "");
Expect(1, 9600, '\p{^Block=boxdrawing}', "");
Expect(1, 9600, '\P{Block=boxdrawing}', "");
Expect(0, 9600, '\P{^Block=boxdrawing}', "");
Expect(1, 9599, '\p{Block: --Box_Drawing}', "");
Expect(0, 9599, '\p{^Block: --Box_Drawing}', "");
Expect(0, 9599, '\P{Block: --Box_Drawing}', "");
Expect(1, 9599, '\P{^Block: --Box_Drawing}', "");
Expect(0, 9600, '\p{Block: --Box_Drawing}', "");
Expect(1, 9600, '\p{^Block: --Box_Drawing}', "");
Expect(1, 9600, '\P{Block: --Box_Drawing}', "");
Expect(0, 9600, '\P{^Block: --Box_Drawing}', "");
Error('\p{Blk=/a/ BOX_DRAWING}');
Error('\P{Blk=/a/ BOX_DRAWING}');
Expect(1, 9599, '\p{Blk=boxdrawing}', "");
Expect(0, 9599, '\p{^Blk=boxdrawing}', "");
Expect(0, 9599, '\P{Blk=boxdrawing}', "");
Expect(1, 9599, '\P{^Blk=boxdrawing}', "");
Expect(0, 9600, '\p{Blk=boxdrawing}', "");
Expect(1, 9600, '\p{^Blk=boxdrawing}', "");
Expect(1, 9600, '\P{Blk=boxdrawing}', "");
Expect(0, 9600, '\P{^Blk=boxdrawing}', "");
Expect(1, 9599, '\p{Blk=		box_Drawing}', "");
Expect(0, 9599, '\p{^Blk=		box_Drawing}', "");
Expect(0, 9599, '\P{Blk=		box_Drawing}', "");
Expect(1, 9599, '\P{^Blk=		box_Drawing}', "");
Expect(0, 9600, '\p{Blk=		box_Drawing}', "");
Expect(1, 9600, '\p{^Blk=		box_Drawing}', "");
Expect(1, 9600, '\P{Blk=		box_Drawing}', "");
Expect(0, 9600, '\P{^Blk=		box_Drawing}', "");
Error('\p{Is_Block=:=Box_Drawing}');
Error('\P{Is_Block=:=Box_Drawing}');
Expect(1, 9599, '\p{Is_Block=boxdrawing}', "");
Expect(0, 9599, '\p{^Is_Block=boxdrawing}', "");
Expect(0, 9599, '\P{Is_Block=boxdrawing}', "");
Expect(1, 9599, '\P{^Is_Block=boxdrawing}', "");
Expect(0, 9600, '\p{Is_Block=boxdrawing}', "");
Expect(1, 9600, '\p{^Is_Block=boxdrawing}', "");
Expect(1, 9600, '\P{Is_Block=boxdrawing}', "");
Expect(0, 9600, '\P{^Is_Block=boxdrawing}', "");
Expect(1, 9599, '\p{Is_Block=_ BOX_Drawing}', "");
Expect(0, 9599, '\p{^Is_Block=_ BOX_Drawing}', "");
Expect(0, 9599, '\P{Is_Block=_ BOX_Drawing}', "");
Expect(1, 9599, '\P{^Is_Block=_ BOX_Drawing}', "");
Expect(0, 9600, '\p{Is_Block=_ BOX_Drawing}', "");
Expect(1, 9600, '\p{^Is_Block=_ BOX_Drawing}', "");
Expect(1, 9600, '\P{Is_Block=_ BOX_Drawing}', "");
Expect(0, 9600, '\P{^Is_Block=_ BOX_Drawing}', "");
Error('\p{Is_Blk:   :=	Box_drawing}');
Error('\P{Is_Blk:   :=	Box_drawing}');
Expect(1, 9599, '\p{Is_Blk=boxdrawing}', "");
Expect(0, 9599, '\p{^Is_Blk=boxdrawing}', "");
Expect(0, 9599, '\P{Is_Blk=boxdrawing}', "");
Expect(1, 9599, '\P{^Is_Blk=boxdrawing}', "");
Expect(0, 9600, '\p{Is_Blk=boxdrawing}', "");
Expect(1, 9600, '\p{^Is_Blk=boxdrawing}', "");
Expect(1, 9600, '\P{Is_Blk=boxdrawing}', "");
Expect(0, 9600, '\P{^Is_Blk=boxdrawing}', "");
Expect(1, 9599, '\p{Is_Blk=-Box_drawing}', "");
Expect(0, 9599, '\p{^Is_Blk=-Box_drawing}', "");
Expect(0, 9599, '\P{Is_Blk=-Box_drawing}', "");
Expect(1, 9599, '\P{^Is_Blk=-Box_drawing}', "");
Expect(0, 9600, '\p{Is_Blk=-Box_drawing}', "");
Expect(1, 9600, '\p{^Is_Blk=-Box_drawing}', "");
Expect(1, 9600, '\P{Is_Blk=-Box_drawing}', "");
Expect(0, 9600, '\P{^Is_Blk=-Box_drawing}', "");
Error('\p{Block=-Brahmi/a/}');
Error('\P{Block=-Brahmi/a/}');
Expect(1, 69759, '\p{Block=brahmi}', "");
Expect(0, 69759, '\p{^Block=brahmi}', "");
Expect(0, 69759, '\P{Block=brahmi}', "");
Expect(1, 69759, '\P{^Block=brahmi}', "");
Expect(0, 69760, '\p{Block=brahmi}', "");
Expect(1, 69760, '\p{^Block=brahmi}', "");
Expect(1, 69760, '\P{Block=brahmi}', "");
Expect(0, 69760, '\P{^Block=brahmi}', "");
Expect(1, 69759, '\p{Block=		brahmi}', "");
Expect(0, 69759, '\p{^Block=		brahmi}', "");
Expect(0, 69759, '\P{Block=		brahmi}', "");
Expect(1, 69759, '\P{^Block=		brahmi}', "");
Expect(0, 69760, '\p{Block=		brahmi}', "");
Expect(1, 69760, '\p{^Block=		brahmi}', "");
Expect(1, 69760, '\P{Block=		brahmi}', "");
Expect(0, 69760, '\P{^Block=		brahmi}', "");
Error('\p{Blk=_brahmi/a/}');
Error('\P{Blk=_brahmi/a/}');
Expect(1, 69759, '\p{Blk=brahmi}', "");
Expect(0, 69759, '\p{^Blk=brahmi}', "");
Expect(0, 69759, '\P{Blk=brahmi}', "");
Expect(1, 69759, '\P{^Blk=brahmi}', "");
Expect(0, 69760, '\p{Blk=brahmi}', "");
Expect(1, 69760, '\p{^Blk=brahmi}', "");
Expect(1, 69760, '\P{Blk=brahmi}', "");
Expect(0, 69760, '\P{^Blk=brahmi}', "");
Expect(1, 69759, '\p{Blk=_	Brahmi}', "");
Expect(0, 69759, '\p{^Blk=_	Brahmi}', "");
Expect(0, 69759, '\P{Blk=_	Brahmi}', "");
Expect(1, 69759, '\P{^Blk=_	Brahmi}', "");
Expect(0, 69760, '\p{Blk=_	Brahmi}', "");
Expect(1, 69760, '\p{^Blk=_	Brahmi}', "");
Expect(1, 69760, '\P{Blk=_	Brahmi}', "");
Expect(0, 69760, '\P{^Blk=_	Brahmi}', "");
Error('\p{Is_Block=:=		Brahmi}');
Error('\P{Is_Block=:=		Brahmi}');
Expect(1, 69759, '\p{Is_Block=brahmi}', "");
Expect(0, 69759, '\p{^Is_Block=brahmi}', "");
Expect(0, 69759, '\P{Is_Block=brahmi}', "");
Expect(1, 69759, '\P{^Is_Block=brahmi}', "");
Expect(0, 69760, '\p{Is_Block=brahmi}', "");
Expect(1, 69760, '\p{^Is_Block=brahmi}', "");
Expect(1, 69760, '\P{Is_Block=brahmi}', "");
Expect(0, 69760, '\P{^Is_Block=brahmi}', "");
Expect(1, 69759, '\p{Is_Block=- BRAHMI}', "");
Expect(0, 69759, '\p{^Is_Block=- BRAHMI}', "");
Expect(0, 69759, '\P{Is_Block=- BRAHMI}', "");
Expect(1, 69759, '\P{^Is_Block=- BRAHMI}', "");
Expect(0, 69760, '\p{Is_Block=- BRAHMI}', "");
Expect(1, 69760, '\p{^Is_Block=- BRAHMI}', "");
Expect(1, 69760, '\P{Is_Block=- BRAHMI}', "");
Expect(0, 69760, '\P{^Is_Block=- BRAHMI}', "");
Error('\p{Is_Blk=	 BRAHMI/a/}');
Error('\P{Is_Blk=	 BRAHMI/a/}');
Expect(1, 69759, '\p{Is_Blk=brahmi}', "");
Expect(0, 69759, '\p{^Is_Blk=brahmi}', "");
Expect(0, 69759, '\P{Is_Blk=brahmi}', "");
Expect(1, 69759, '\P{^Is_Blk=brahmi}', "");
Expect(0, 69760, '\p{Is_Blk=brahmi}', "");
Expect(1, 69760, '\p{^Is_Blk=brahmi}', "");
Expect(1, 69760, '\P{Is_Blk=brahmi}', "");
Expect(0, 69760, '\P{^Is_Blk=brahmi}', "");
Expect(1, 69759, '\p{Is_Blk=_Brahmi}', "");
Expect(0, 69759, '\p{^Is_Blk=_Brahmi}', "");
Expect(0, 69759, '\P{Is_Blk=_Brahmi}', "");
Expect(1, 69759, '\P{^Is_Blk=_Brahmi}', "");
Expect(0, 69760, '\p{Is_Blk=_Brahmi}', "");
Expect(1, 69760, '\p{^Is_Blk=_Brahmi}', "");
Expect(1, 69760, '\P{Is_Blk=_Brahmi}', "");
Expect(0, 69760, '\P{^Is_Blk=_Brahmi}', "");
Error('\p{Block=- BRAILLE_patterns:=}');
Error('\P{Block=- BRAILLE_patterns:=}');
Expect(1, 10495, '\p{Block=braillepatterns}', "");
Expect(0, 10495, '\p{^Block=braillepatterns}', "");
Expect(0, 10495, '\P{Block=braillepatterns}', "");
Expect(1, 10495, '\P{^Block=braillepatterns}', "");
Expect(0, 10496, '\p{Block=braillepatterns}', "");
Expect(1, 10496, '\p{^Block=braillepatterns}', "");
Expect(1, 10496, '\P{Block=braillepatterns}', "");
Expect(0, 10496, '\P{^Block=braillepatterns}', "");
Expect(1, 10495, '\p{Block=	Braille_Patterns}', "");
Expect(0, 10495, '\p{^Block=	Braille_Patterns}', "");
Expect(0, 10495, '\P{Block=	Braille_Patterns}', "");
Expect(1, 10495, '\P{^Block=	Braille_Patterns}', "");
Expect(0, 10496, '\p{Block=	Braille_Patterns}', "");
Expect(1, 10496, '\p{^Block=	Braille_Patterns}', "");
Expect(1, 10496, '\P{Block=	Braille_Patterns}', "");
Expect(0, 10496, '\P{^Block=	Braille_Patterns}', "");
Error('\p{Blk=/a/_BRAILLE}');
Error('\P{Blk=/a/_BRAILLE}');
Expect(1, 10495, '\p{Blk=braille}', "");
Expect(0, 10495, '\p{^Blk=braille}', "");
Expect(0, 10495, '\P{Blk=braille}', "");
Expect(1, 10495, '\P{^Blk=braille}', "");
Expect(0, 10496, '\p{Blk=braille}', "");
Expect(1, 10496, '\p{^Blk=braille}', "");
Expect(1, 10496, '\P{Blk=braille}', "");
Expect(0, 10496, '\P{^Blk=braille}', "");
Expect(1, 10495, '\p{Blk=_BRAILLE}', "");
Expect(0, 10495, '\p{^Blk=_BRAILLE}', "");
Expect(0, 10495, '\P{Blk=_BRAILLE}', "");
Expect(1, 10495, '\P{^Blk=_BRAILLE}', "");
Expect(0, 10496, '\p{Blk=_BRAILLE}', "");
Expect(1, 10496, '\p{^Blk=_BRAILLE}', "");
Expect(1, 10496, '\P{Blk=_BRAILLE}', "");
Expect(0, 10496, '\P{^Blk=_BRAILLE}', "");
Error('\p{Is_Block=-/a/Braille_PATTERNS}');
Error('\P{Is_Block=-/a/Braille_PATTERNS}');
Expect(1, 10495, '\p{Is_Block: braillepatterns}', "");
Expect(0, 10495, '\p{^Is_Block: braillepatterns}', "");
Expect(0, 10495, '\P{Is_Block: braillepatterns}', "");
Expect(1, 10495, '\P{^Is_Block: braillepatterns}', "");
Expect(0, 10496, '\p{Is_Block: braillepatterns}', "");
Expect(1, 10496, '\p{^Is_Block: braillepatterns}', "");
Expect(1, 10496, '\P{Is_Block: braillepatterns}', "");
Expect(0, 10496, '\P{^Is_Block: braillepatterns}', "");
Expect(1, 10495, '\p{Is_Block=_ braille_Patterns}', "");
Expect(0, 10495, '\p{^Is_Block=_ braille_Patterns}', "");
Expect(0, 10495, '\P{Is_Block=_ braille_Patterns}', "");
Expect(1, 10495, '\P{^Is_Block=_ braille_Patterns}', "");
Expect(0, 10496, '\p{Is_Block=_ braille_Patterns}', "");
Expect(1, 10496, '\p{^Is_Block=_ braille_Patterns}', "");
Expect(1, 10496, '\P{Is_Block=_ braille_Patterns}', "");
Expect(0, 10496, '\P{^Is_Block=_ braille_Patterns}', "");
Error('\p{Is_Blk=_ BRAILLE:=}');
Error('\P{Is_Blk=_ BRAILLE:=}');
Expect(1, 10495, '\p{Is_Blk:	braille}', "");
Expect(0, 10495, '\p{^Is_Blk:	braille}', "");
Expect(0, 10495, '\P{Is_Blk:	braille}', "");
Expect(1, 10495, '\P{^Is_Blk:	braille}', "");
Expect(0, 10496, '\p{Is_Blk:	braille}', "");
Expect(1, 10496, '\p{^Is_Blk:	braille}', "");
Expect(1, 10496, '\P{Is_Blk:	braille}', "");
Expect(0, 10496, '\P{^Is_Blk:	braille}', "");
Expect(1, 10495, '\p{Is_Blk=	Braille}', "");
Expect(0, 10495, '\p{^Is_Blk=	Braille}', "");
Expect(0, 10495, '\P{Is_Blk=	Braille}', "");
Expect(1, 10495, '\P{^Is_Blk=	Braille}', "");
Expect(0, 10496, '\p{Is_Blk=	Braille}', "");
Expect(1, 10496, '\p{^Is_Blk=	Braille}', "");
Expect(1, 10496, '\P{Is_Blk=	Braille}', "");
Expect(0, 10496, '\P{^Is_Blk=	Braille}', "");
Error('\p{Block: _/a/buginese}');
Error('\P{Block: _/a/buginese}');
Expect(1, 6687, '\p{Block=buginese}', "");
Expect(0, 6687, '\p{^Block=buginese}', "");
Expect(0, 6687, '\P{Block=buginese}', "");
Expect(1, 6687, '\P{^Block=buginese}', "");
Expect(0, 6688, '\p{Block=buginese}', "");
Expect(1, 6688, '\p{^Block=buginese}', "");
Expect(1, 6688, '\P{Block=buginese}', "");
Expect(0, 6688, '\P{^Block=buginese}', "");
Expect(1, 6687, '\p{Block=  Buginese}', "");
Expect(0, 6687, '\p{^Block=  Buginese}', "");
Expect(0, 6687, '\P{Block=  Buginese}', "");
Expect(1, 6687, '\P{^Block=  Buginese}', "");
Expect(0, 6688, '\p{Block=  Buginese}', "");
Expect(1, 6688, '\p{^Block=  Buginese}', "");
Expect(1, 6688, '\P{Block=  Buginese}', "");
Expect(0, 6688, '\P{^Block=  Buginese}', "");
Error('\p{Blk= Buginese/a/}');
Error('\P{Blk= Buginese/a/}');
Expect(1, 6687, '\p{Blk=buginese}', "");
Expect(0, 6687, '\p{^Blk=buginese}', "");
Expect(0, 6687, '\P{Blk=buginese}', "");
Expect(1, 6687, '\P{^Blk=buginese}', "");
Expect(0, 6688, '\p{Blk=buginese}', "");
Expect(1, 6688, '\p{^Blk=buginese}', "");
Expect(1, 6688, '\P{Blk=buginese}', "");
Expect(0, 6688, '\P{^Blk=buginese}', "");
Expect(1, 6687, '\p{Blk=_ Buginese}', "");
Expect(0, 6687, '\p{^Blk=_ Buginese}', "");
Expect(0, 6687, '\P{Blk=_ Buginese}', "");
Expect(1, 6687, '\P{^Blk=_ Buginese}', "");
Expect(0, 6688, '\p{Blk=_ Buginese}', "");
Expect(1, 6688, '\p{^Blk=_ Buginese}', "");
Expect(1, 6688, '\P{Blk=_ Buginese}', "");
Expect(0, 6688, '\P{^Blk=_ Buginese}', "");
Error('\p{Is_Block:		buginese/a/}');
Error('\P{Is_Block:		buginese/a/}');
Expect(1, 6687, '\p{Is_Block:buginese}', "");
Expect(0, 6687, '\p{^Is_Block:buginese}', "");
Expect(0, 6687, '\P{Is_Block:buginese}', "");
Expect(1, 6687, '\P{^Is_Block:buginese}', "");
Expect(0, 6688, '\p{Is_Block:buginese}', "");
Expect(1, 6688, '\p{^Is_Block:buginese}', "");
Expect(1, 6688, '\P{Is_Block:buginese}', "");
Expect(0, 6688, '\P{^Is_Block:buginese}', "");
Expect(1, 6687, '\p{Is_Block= 	buginese}', "");
Expect(0, 6687, '\p{^Is_Block= 	buginese}', "");
Expect(0, 6687, '\P{Is_Block= 	buginese}', "");
Expect(1, 6687, '\P{^Is_Block= 	buginese}', "");
Expect(0, 6688, '\p{Is_Block= 	buginese}', "");
Expect(1, 6688, '\p{^Is_Block= 	buginese}', "");
Expect(1, 6688, '\P{Is_Block= 	buginese}', "");
Expect(0, 6688, '\P{^Is_Block= 	buginese}', "");
Error('\p{Is_Blk=__buginese:=}');
Error('\P{Is_Blk=__buginese:=}');
Expect(1, 6687, '\p{Is_Blk=buginese}', "");
Expect(0, 6687, '\p{^Is_Blk=buginese}', "");
Expect(0, 6687, '\P{Is_Blk=buginese}', "");
Expect(1, 6687, '\P{^Is_Blk=buginese}', "");
Expect(0, 6688, '\p{Is_Blk=buginese}', "");
Expect(1, 6688, '\p{^Is_Blk=buginese}', "");
Expect(1, 6688, '\P{Is_Blk=buginese}', "");
Expect(0, 6688, '\P{^Is_Blk=buginese}', "");
Error('\p{Block=		BUHID/a/}');
Error('\P{Block=		BUHID/a/}');
Expect(1, 5983, '\p{Block=buhid}', "");
Expect(0, 5983, '\p{^Block=buhid}', "");
Expect(0, 5983, '\P{Block=buhid}', "");
Expect(1, 5983, '\P{^Block=buhid}', "");
Expect(0, 5984, '\p{Block=buhid}', "");
Expect(1, 5984, '\p{^Block=buhid}', "");
Expect(1, 5984, '\P{Block=buhid}', "");
Expect(0, 5984, '\P{^Block=buhid}', "");
Expect(1, 5983, '\p{Block=_Buhid}', "");
Expect(0, 5983, '\p{^Block=_Buhid}', "");
Expect(0, 5983, '\P{Block=_Buhid}', "");
Expect(1, 5983, '\P{^Block=_Buhid}', "");
Expect(0, 5984, '\p{Block=_Buhid}', "");
Expect(1, 5984, '\p{^Block=_Buhid}', "");
Expect(1, 5984, '\P{Block=_Buhid}', "");
Expect(0, 5984, '\P{^Block=_Buhid}', "");
Error('\p{Blk=:=	 Buhid}');
Error('\P{Blk=:=	 Buhid}');
Expect(1, 5983, '\p{Blk=buhid}', "");
Expect(0, 5983, '\p{^Blk=buhid}', "");
Expect(0, 5983, '\P{Blk=buhid}', "");
Expect(1, 5983, '\P{^Blk=buhid}', "");
Expect(0, 5984, '\p{Blk=buhid}', "");
Expect(1, 5984, '\p{^Blk=buhid}', "");
Expect(1, 5984, '\P{Blk=buhid}', "");
Expect(0, 5984, '\P{^Blk=buhid}', "");
Expect(1, 5983, '\p{Blk=-BUHID}', "");
Expect(0, 5983, '\p{^Blk=-BUHID}', "");
Expect(0, 5983, '\P{Blk=-BUHID}', "");
Expect(1, 5983, '\P{^Blk=-BUHID}', "");
Expect(0, 5984, '\p{Blk=-BUHID}', "");
Expect(1, 5984, '\p{^Blk=-BUHID}', "");
Expect(1, 5984, '\P{Blk=-BUHID}', "");
Expect(0, 5984, '\P{^Blk=-BUHID}', "");
Error('\p{Is_Block=	-Buhid:=}');
Error('\P{Is_Block=	-Buhid:=}');
Expect(1, 5983, '\p{Is_Block=buhid}', "");
Expect(0, 5983, '\p{^Is_Block=buhid}', "");
Expect(0, 5983, '\P{Is_Block=buhid}', "");
Expect(1, 5983, '\P{^Is_Block=buhid}', "");
Expect(0, 5984, '\p{Is_Block=buhid}', "");
Expect(1, 5984, '\p{^Is_Block=buhid}', "");
Expect(1, 5984, '\P{Is_Block=buhid}', "");
Expect(0, 5984, '\P{^Is_Block=buhid}', "");
Expect(1, 5983, '\p{Is_Block=_-buhid}', "");
Expect(0, 5983, '\p{^Is_Block=_-buhid}', "");
Expect(0, 5983, '\P{Is_Block=_-buhid}', "");
Expect(1, 5983, '\P{^Is_Block=_-buhid}', "");
Expect(0, 5984, '\p{Is_Block=_-buhid}', "");
Expect(1, 5984, '\p{^Is_Block=_-buhid}', "");
Expect(1, 5984, '\P{Is_Block=_-buhid}', "");
Expect(0, 5984, '\P{^Is_Block=_-buhid}', "");
Error('\p{Is_Blk=_	Buhid:=}');
Error('\P{Is_Blk=_	Buhid:=}');
Expect(1, 5983, '\p{Is_Blk=buhid}', "");
Expect(0, 5983, '\p{^Is_Blk=buhid}', "");
Expect(0, 5983, '\P{Is_Blk=buhid}', "");
Expect(1, 5983, '\P{^Is_Blk=buhid}', "");
Expect(0, 5984, '\p{Is_Blk=buhid}', "");
Expect(1, 5984, '\p{^Is_Blk=buhid}', "");
Expect(1, 5984, '\P{Is_Blk=buhid}', "");
Expect(0, 5984, '\P{^Is_Blk=buhid}', "");
Expect(1, 5983, '\p{Is_Blk: -BUHID}', "");
Expect(0, 5983, '\p{^Is_Blk: -BUHID}', "");
Expect(0, 5983, '\P{Is_Blk: -BUHID}', "");
Expect(1, 5983, '\P{^Is_Blk: -BUHID}', "");
Expect(0, 5984, '\p{Is_Blk: -BUHID}', "");
Expect(1, 5984, '\p{^Is_Blk: -BUHID}', "");
Expect(1, 5984, '\P{Is_Blk: -BUHID}', "");
Expect(0, 5984, '\P{^Is_Blk: -BUHID}', "");
Error('\p{Block: Byzantine_musical_symbols/a/}');
Error('\P{Block: Byzantine_musical_symbols/a/}');
Expect(1, 119039, '\p{Block=byzantinemusicalsymbols}', "");
Expect(0, 119039, '\p{^Block=byzantinemusicalsymbols}', "");
Expect(0, 119039, '\P{Block=byzantinemusicalsymbols}', "");
Expect(1, 119039, '\P{^Block=byzantinemusicalsymbols}', "");
Expect(0, 119040, '\p{Block=byzantinemusicalsymbols}', "");
Expect(1, 119040, '\p{^Block=byzantinemusicalsymbols}', "");
Expect(1, 119040, '\P{Block=byzantinemusicalsymbols}', "");
Expect(0, 119040, '\P{^Block=byzantinemusicalsymbols}', "");
Expect(1, 119039, '\p{Block= 	Byzantine_MUSICAL_symbols}', "");
Expect(0, 119039, '\p{^Block= 	Byzantine_MUSICAL_symbols}', "");
Expect(0, 119039, '\P{Block= 	Byzantine_MUSICAL_symbols}', "");
Expect(1, 119039, '\P{^Block= 	Byzantine_MUSICAL_symbols}', "");
Expect(0, 119040, '\p{Block= 	Byzantine_MUSICAL_symbols}', "");
Expect(1, 119040, '\p{^Block= 	Byzantine_MUSICAL_symbols}', "");
Expect(1, 119040, '\P{Block= 	Byzantine_MUSICAL_symbols}', "");
Expect(0, 119040, '\P{^Block= 	Byzantine_MUSICAL_symbols}', "");
Error('\p{Blk=-_byzantine_MUSIC:=}');
Error('\P{Blk=-_byzantine_MUSIC:=}');
Expect(1, 119039, '\p{Blk=byzantinemusic}', "");
Expect(0, 119039, '\p{^Blk=byzantinemusic}', "");
Expect(0, 119039, '\P{Blk=byzantinemusic}', "");
Expect(1, 119039, '\P{^Blk=byzantinemusic}', "");
Expect(0, 119040, '\p{Blk=byzantinemusic}', "");
Expect(1, 119040, '\p{^Blk=byzantinemusic}', "");
Expect(1, 119040, '\P{Blk=byzantinemusic}', "");
Expect(0, 119040, '\P{^Blk=byzantinemusic}', "");
Expect(1, 119039, '\p{Blk=_Byzantine_MUSIC}', "");
Expect(0, 119039, '\p{^Blk=_Byzantine_MUSIC}', "");
Expect(0, 119039, '\P{Blk=_Byzantine_MUSIC}', "");
Expect(1, 119039, '\P{^Blk=_Byzantine_MUSIC}', "");
Expect(0, 119040, '\p{Blk=_Byzantine_MUSIC}', "");
Expect(1, 119040, '\p{^Blk=_Byzantine_MUSIC}', "");
Expect(1, 119040, '\P{Blk=_Byzantine_MUSIC}', "");
Expect(0, 119040, '\P{^Blk=_Byzantine_MUSIC}', "");
Error('\p{Is_Block=_/a/byzantine_MUSICAL_Symbols}');
Error('\P{Is_Block=_/a/byzantine_MUSICAL_Symbols}');
Expect(1, 119039, '\p{Is_Block=byzantinemusicalsymbols}', "");
Expect(0, 119039, '\p{^Is_Block=byzantinemusicalsymbols}', "");
Expect(0, 119039, '\P{Is_Block=byzantinemusicalsymbols}', "");
Expect(1, 119039, '\P{^Is_Block=byzantinemusicalsymbols}', "");
Expect(0, 119040, '\p{Is_Block=byzantinemusicalsymbols}', "");
Expect(1, 119040, '\p{^Is_Block=byzantinemusicalsymbols}', "");
Expect(1, 119040, '\P{Is_Block=byzantinemusicalsymbols}', "");
Expect(0, 119040, '\P{^Is_Block=byzantinemusicalsymbols}', "");
Expect(1, 119039, '\p{Is_Block:  byzantine_musical_SYMBOLS}', "");
Expect(0, 119039, '\p{^Is_Block:  byzantine_musical_SYMBOLS}', "");
Expect(0, 119039, '\P{Is_Block:  byzantine_musical_SYMBOLS}', "");
Expect(1, 119039, '\P{^Is_Block:  byzantine_musical_SYMBOLS}', "");
Expect(0, 119040, '\p{Is_Block:  byzantine_musical_SYMBOLS}', "");
Expect(1, 119040, '\p{^Is_Block:  byzantine_musical_SYMBOLS}', "");
Expect(1, 119040, '\P{Is_Block:  byzantine_musical_SYMBOLS}', "");
Expect(0, 119040, '\P{^Is_Block:  byzantine_musical_SYMBOLS}', "");
Error('\p{Is_Blk=-:=BYZANTINE_Music}');
Error('\P{Is_Blk=-:=BYZANTINE_Music}');
Expect(1, 119039, '\p{Is_Blk=byzantinemusic}', "");
Expect(0, 119039, '\p{^Is_Blk=byzantinemusic}', "");
Expect(0, 119039, '\P{Is_Blk=byzantinemusic}', "");
Expect(1, 119039, '\P{^Is_Blk=byzantinemusic}', "");
Expect(0, 119040, '\p{Is_Blk=byzantinemusic}', "");
Expect(1, 119040, '\p{^Is_Blk=byzantinemusic}', "");
Expect(1, 119040, '\P{Is_Blk=byzantinemusic}', "");
Expect(0, 119040, '\P{^Is_Blk=byzantinemusic}', "");
Expect(1, 119039, '\p{Is_Blk=--Byzantine_Music}', "");
Expect(0, 119039, '\p{^Is_Blk=--Byzantine_Music}', "");
Expect(0, 119039, '\P{Is_Blk=--Byzantine_Music}', "");
Expect(1, 119039, '\P{^Is_Blk=--Byzantine_Music}', "");
Expect(0, 119040, '\p{Is_Blk=--Byzantine_Music}', "");
Expect(1, 119040, '\p{^Is_Blk=--Byzantine_Music}', "");
Expect(1, 119040, '\P{Is_Blk=--Byzantine_Music}', "");
Expect(0, 119040, '\P{^Is_Blk=--Byzantine_Music}', "");
Error('\p{Block=/a/ 	CJK_UNIFIED_ideographs}');
Error('\P{Block=/a/ 	CJK_UNIFIED_ideographs}');
Expect(1, 40959, '\p{Block=cjkunifiedideographs}', "");
Expect(0, 40959, '\p{^Block=cjkunifiedideographs}', "");
Expect(0, 40959, '\P{Block=cjkunifiedideographs}', "");
Expect(1, 40959, '\P{^Block=cjkunifiedideographs}', "");
Expect(0, 40960, '\p{Block=cjkunifiedideographs}', "");
Expect(1, 40960, '\p{^Block=cjkunifiedideographs}', "");
Expect(1, 40960, '\P{Block=cjkunifiedideographs}', "");
Expect(0, 40960, '\P{^Block=cjkunifiedideographs}', "");
Expect(1, 40959, '\p{Block=_-CJK_Unified_Ideographs}', "");
Expect(0, 40959, '\p{^Block=_-CJK_Unified_Ideographs}', "");
Expect(0, 40959, '\P{Block=_-CJK_Unified_Ideographs}', "");
Expect(1, 40959, '\P{^Block=_-CJK_Unified_Ideographs}', "");
Expect(0, 40960, '\p{Block=_-CJK_Unified_Ideographs}', "");
Expect(1, 40960, '\p{^Block=_-CJK_Unified_Ideographs}', "");
Expect(1, 40960, '\P{Block=_-CJK_Unified_Ideographs}', "");
Expect(0, 40960, '\P{^Block=_-CJK_Unified_Ideographs}', "");
Error('\p{Blk=/a/ -CJK}');
Error('\P{Blk=/a/ -CJK}');
Expect(1, 40959, '\p{Blk=cjk}', "");
Expect(0, 40959, '\p{^Blk=cjk}', "");
Expect(0, 40959, '\P{Blk=cjk}', "");
Expect(1, 40959, '\P{^Blk=cjk}', "");
Expect(0, 40960, '\p{Blk=cjk}', "");
Expect(1, 40960, '\p{^Blk=cjk}', "");
Expect(1, 40960, '\P{Blk=cjk}', "");
Expect(0, 40960, '\P{^Blk=cjk}', "");
Expect(1, 40959, '\p{Blk=-CJK}', "");
Expect(0, 40959, '\p{^Blk=-CJK}', "");
Expect(0, 40959, '\P{Blk=-CJK}', "");
Expect(1, 40959, '\P{^Blk=-CJK}', "");
Expect(0, 40960, '\p{Blk=-CJK}', "");
Expect(1, 40960, '\p{^Blk=-CJK}', "");
Expect(1, 40960, '\P{Blk=-CJK}', "");
Expect(0, 40960, '\P{^Blk=-CJK}', "");
Error('\p{Is_Block=/a/cjk_unified_Ideographs}');
Error('\P{Is_Block=/a/cjk_unified_Ideographs}');
Expect(1, 40959, '\p{Is_Block=cjkunifiedideographs}', "");
Expect(0, 40959, '\p{^Is_Block=cjkunifiedideographs}', "");
Expect(0, 40959, '\P{Is_Block=cjkunifiedideographs}', "");
Expect(1, 40959, '\P{^Is_Block=cjkunifiedideographs}', "");
Expect(0, 40960, '\p{Is_Block=cjkunifiedideographs}', "");
Expect(1, 40960, '\p{^Is_Block=cjkunifiedideographs}', "");
Expect(1, 40960, '\P{Is_Block=cjkunifiedideographs}', "");
Expect(0, 40960, '\P{^Is_Block=cjkunifiedideographs}', "");
Expect(1, 40959, '\p{Is_Block=	 cjk_Unified_Ideographs}', "");
Expect(0, 40959, '\p{^Is_Block=	 cjk_Unified_Ideographs}', "");
Expect(0, 40959, '\P{Is_Block=	 cjk_Unified_Ideographs}', "");
Expect(1, 40959, '\P{^Is_Block=	 cjk_Unified_Ideographs}', "");
Expect(0, 40960, '\p{Is_Block=	 cjk_Unified_Ideographs}', "");
Expect(1, 40960, '\p{^Is_Block=	 cjk_Unified_Ideographs}', "");
Expect(1, 40960, '\P{Is_Block=	 cjk_Unified_Ideographs}', "");
Expect(0, 40960, '\P{^Is_Block=	 cjk_Unified_Ideographs}', "");
Error('\p{Is_Blk= :=CJK}');
Error('\P{Is_Blk= :=CJK}');
Expect(1, 40959, '\p{Is_Blk=cjk}', "");
Expect(0, 40959, '\p{^Is_Blk=cjk}', "");
Expect(0, 40959, '\P{Is_Blk=cjk}', "");
Expect(1, 40959, '\P{^Is_Blk=cjk}', "");
Expect(0, 40960, '\p{Is_Blk=cjk}', "");
Expect(1, 40960, '\p{^Is_Blk=cjk}', "");
Expect(1, 40960, '\P{Is_Blk=cjk}', "");
Expect(0, 40960, '\P{^Is_Blk=cjk}', "");
Expect(1, 40959, '\p{Is_Blk= _CJK}', "");
Expect(0, 40959, '\p{^Is_Blk= _CJK}', "");
Expect(0, 40959, '\P{Is_Blk= _CJK}', "");
Expect(1, 40959, '\P{^Is_Blk= _CJK}', "");
Expect(0, 40960, '\p{Is_Blk= _CJK}', "");
Expect(1, 40960, '\p{^Is_Blk= _CJK}', "");
Expect(1, 40960, '\P{Is_Blk= _CJK}', "");
Expect(0, 40960, '\P{^Is_Blk= _CJK}', "");
Error('\p{Block=CJK_compatibility:=}');
Error('\P{Block=CJK_compatibility:=}');
Expect(1, 13311, '\p{Block=cjkcompatibility}', "");
Expect(0, 13311, '\p{^Block=cjkcompatibility}', "");
Expect(0, 13311, '\P{Block=cjkcompatibility}', "");
Expect(1, 13311, '\P{^Block=cjkcompatibility}', "");
Expect(0, 13312, '\p{Block=cjkcompatibility}', "");
Expect(1, 13312, '\p{^Block=cjkcompatibility}', "");
Expect(1, 13312, '\P{Block=cjkcompatibility}', "");
Expect(0, 13312, '\P{^Block=cjkcompatibility}', "");
Expect(1, 13311, '\p{Block=_CJK_Compatibility}', "");
Expect(0, 13311, '\p{^Block=_CJK_Compatibility}', "");
Expect(0, 13311, '\P{Block=_CJK_Compatibility}', "");
Expect(1, 13311, '\P{^Block=_CJK_Compatibility}', "");
Expect(0, 13312, '\p{Block=_CJK_Compatibility}', "");
Expect(1, 13312, '\p{^Block=_CJK_Compatibility}', "");
Expect(1, 13312, '\P{Block=_CJK_Compatibility}', "");
Expect(0, 13312, '\P{^Block=_CJK_Compatibility}', "");
Error('\p{Blk=:= CJK_compat}');
Error('\P{Blk=:= CJK_compat}');
Expect(1, 13311, '\p{Blk=cjkcompat}', "");
Expect(0, 13311, '\p{^Blk=cjkcompat}', "");
Expect(0, 13311, '\P{Blk=cjkcompat}', "");
Expect(1, 13311, '\P{^Blk=cjkcompat}', "");
Expect(0, 13312, '\p{Blk=cjkcompat}', "");
Expect(1, 13312, '\p{^Blk=cjkcompat}', "");
Expect(1, 13312, '\P{Blk=cjkcompat}', "");
Expect(0, 13312, '\P{^Blk=cjkcompat}', "");
Expect(1, 13311, '\p{Blk=__CJK_Compat}', "");
Expect(0, 13311, '\p{^Blk=__CJK_Compat}', "");
Expect(0, 13311, '\P{Blk=__CJK_Compat}', "");
Expect(1, 13311, '\P{^Blk=__CJK_Compat}', "");
Expect(0, 13312, '\p{Blk=__CJK_Compat}', "");
Expect(1, 13312, '\p{^Blk=__CJK_Compat}', "");
Expect(1, 13312, '\P{Blk=__CJK_Compat}', "");
Expect(0, 13312, '\P{^Blk=__CJK_Compat}', "");
Error('\p{Is_Block=:=_ CJK_compatibility}');
Error('\P{Is_Block=:=_ CJK_compatibility}');
Expect(1, 13311, '\p{Is_Block=cjkcompatibility}', "");
Expect(0, 13311, '\p{^Is_Block=cjkcompatibility}', "");
Expect(0, 13311, '\P{Is_Block=cjkcompatibility}', "");
Expect(1, 13311, '\P{^Is_Block=cjkcompatibility}', "");
Expect(0, 13312, '\p{Is_Block=cjkcompatibility}', "");
Expect(1, 13312, '\p{^Is_Block=cjkcompatibility}', "");
Expect(1, 13312, '\P{Is_Block=cjkcompatibility}', "");
Expect(0, 13312, '\P{^Is_Block=cjkcompatibility}', "");
Expect(1, 13311, '\p{Is_Block=_	CJK_Compatibility}', "");
Expect(0, 13311, '\p{^Is_Block=_	CJK_Compatibility}', "");
Expect(0, 13311, '\P{Is_Block=_	CJK_Compatibility}', "");
Expect(1, 13311, '\P{^Is_Block=_	CJK_Compatibility}', "");
Expect(0, 13312, '\p{Is_Block=_	CJK_Compatibility}', "");
Expect(1, 13312, '\p{^Is_Block=_	CJK_Compatibility}', "");
Expect(1, 13312, '\P{Is_Block=_	CJK_Compatibility}', "");
Expect(0, 13312, '\P{^Is_Block=_	CJK_Compatibility}', "");
Error('\p{Is_Blk=- CJK_Compat/a/}');
Error('\P{Is_Blk=- CJK_Compat/a/}');
Expect(1, 13311, '\p{Is_Blk=cjkcompat}', "");
Expect(0, 13311, '\p{^Is_Blk=cjkcompat}', "");
Expect(0, 13311, '\P{Is_Blk=cjkcompat}', "");
Expect(1, 13311, '\P{^Is_Blk=cjkcompat}', "");
Expect(0, 13312, '\p{Is_Blk=cjkcompat}', "");
Expect(1, 13312, '\p{^Is_Blk=cjkcompat}', "");
Expect(1, 13312, '\P{Is_Blk=cjkcompat}', "");
Expect(0, 13312, '\P{^Is_Blk=cjkcompat}', "");
Expect(1, 13311, '\p{Is_Blk=_	CJK_Compat}', "");
Expect(0, 13311, '\p{^Is_Blk=_	CJK_Compat}', "");
Expect(0, 13311, '\P{Is_Blk=_	CJK_Compat}', "");
Expect(1, 13311, '\P{^Is_Blk=_	CJK_Compat}', "");
Expect(0, 13312, '\p{Is_Blk=_	CJK_Compat}', "");
Expect(1, 13312, '\p{^Is_Blk=_	CJK_Compat}', "");
Expect(1, 13312, '\P{Is_Blk=_	CJK_Compat}', "");
Expect(0, 13312, '\P{^Is_Blk=_	CJK_Compat}', "");
Error('\p{Block=-:=CJK_compatibility_Forms}');
Error('\P{Block=-:=CJK_compatibility_Forms}');
Expect(1, 65103, '\p{Block=cjkcompatibilityforms}', "");
Expect(0, 65103, '\p{^Block=cjkcompatibilityforms}', "");
Expect(0, 65103, '\P{Block=cjkcompatibilityforms}', "");
Expect(1, 65103, '\P{^Block=cjkcompatibilityforms}', "");
Expect(0, 65104, '\p{Block=cjkcompatibilityforms}', "");
Expect(1, 65104, '\p{^Block=cjkcompatibilityforms}', "");
Expect(1, 65104, '\P{Block=cjkcompatibilityforms}', "");
Expect(0, 65104, '\P{^Block=cjkcompatibilityforms}', "");
Expect(1, 65103, '\p{Block=	_CJK_Compatibility_FORMS}', "");
Expect(0, 65103, '\p{^Block=	_CJK_Compatibility_FORMS}', "");
Expect(0, 65103, '\P{Block=	_CJK_Compatibility_FORMS}', "");
Expect(1, 65103, '\P{^Block=	_CJK_Compatibility_FORMS}', "");
Expect(0, 65104, '\p{Block=	_CJK_Compatibility_FORMS}', "");
Expect(1, 65104, '\p{^Block=	_CJK_Compatibility_FORMS}', "");
Expect(1, 65104, '\P{Block=	_CJK_Compatibility_FORMS}', "");
Expect(0, 65104, '\P{^Block=	_CJK_Compatibility_FORMS}', "");
Error('\p{Blk=	/a/CJK_COMPAT_Forms}');
Error('\P{Blk=	/a/CJK_COMPAT_Forms}');
Expect(1, 65103, '\p{Blk=cjkcompatforms}', "");
Expect(0, 65103, '\p{^Blk=cjkcompatforms}', "");
Expect(0, 65103, '\P{Blk=cjkcompatforms}', "");
Expect(1, 65103, '\P{^Blk=cjkcompatforms}', "");
Expect(0, 65104, '\p{Blk=cjkcompatforms}', "");
Expect(1, 65104, '\p{^Blk=cjkcompatforms}', "");
Expect(1, 65104, '\P{Blk=cjkcompatforms}', "");
Expect(0, 65104, '\P{^Blk=cjkcompatforms}', "");
Expect(1, 65103, '\p{Blk=--CJK_Compat_Forms}', "");
Expect(0, 65103, '\p{^Blk=--CJK_Compat_Forms}', "");
Expect(0, 65103, '\P{Blk=--CJK_Compat_Forms}', "");
Expect(1, 65103, '\P{^Blk=--CJK_Compat_Forms}', "");
Expect(0, 65104, '\p{Blk=--CJK_Compat_Forms}', "");
Expect(1, 65104, '\p{^Blk=--CJK_Compat_Forms}', "");
Expect(1, 65104, '\P{Blk=--CJK_Compat_Forms}', "");
Expect(0, 65104, '\P{^Blk=--CJK_Compat_Forms}', "");
Error('\p{Is_Block:	:=-CJK_Compatibility_Forms}');
Error('\P{Is_Block:	:=-CJK_Compatibility_Forms}');
Expect(1, 65103, '\p{Is_Block=cjkcompatibilityforms}', "");
Expect(0, 65103, '\p{^Is_Block=cjkcompatibilityforms}', "");
Expect(0, 65103, '\P{Is_Block=cjkcompatibilityforms}', "");
Expect(1, 65103, '\P{^Is_Block=cjkcompatibilityforms}', "");
Expect(0, 65104, '\p{Is_Block=cjkcompatibilityforms}', "");
Expect(1, 65104, '\p{^Is_Block=cjkcompatibilityforms}', "");
Expect(1, 65104, '\P{Is_Block=cjkcompatibilityforms}', "");
Expect(0, 65104, '\P{^Is_Block=cjkcompatibilityforms}', "");
Expect(1, 65103, '\p{Is_Block=	CJK_Compatibility_FORMS}', "");
Expect(0, 65103, '\p{^Is_Block=	CJK_Compatibility_FORMS}', "");
Expect(0, 65103, '\P{Is_Block=	CJK_Compatibility_FORMS}', "");
Expect(1, 65103, '\P{^Is_Block=	CJK_Compatibility_FORMS}', "");
Expect(0, 65104, '\p{Is_Block=	CJK_Compatibility_FORMS}', "");
Expect(1, 65104, '\p{^Is_Block=	CJK_Compatibility_FORMS}', "");
Expect(1, 65104, '\P{Is_Block=	CJK_Compatibility_FORMS}', "");
Expect(0, 65104, '\P{^Is_Block=	CJK_Compatibility_FORMS}', "");
Error('\p{Is_Blk=:=-CJK_Compat_forms}');
Error('\P{Is_Blk=:=-CJK_Compat_forms}');
Expect(1, 65103, '\p{Is_Blk=cjkcompatforms}', "");
Expect(0, 65103, '\p{^Is_Blk=cjkcompatforms}', "");
Expect(0, 65103, '\P{Is_Blk=cjkcompatforms}', "");
Expect(1, 65103, '\P{^Is_Blk=cjkcompatforms}', "");
Expect(0, 65104, '\p{Is_Blk=cjkcompatforms}', "");
Expect(1, 65104, '\p{^Is_Blk=cjkcompatforms}', "");
Expect(1, 65104, '\P{Is_Blk=cjkcompatforms}', "");
Expect(0, 65104, '\P{^Is_Blk=cjkcompatforms}', "");
Expect(1, 65103, '\p{Is_Blk=CJK_Compat_Forms}', "");
Expect(0, 65103, '\p{^Is_Blk=CJK_Compat_Forms}', "");
Expect(0, 65103, '\P{Is_Blk=CJK_Compat_Forms}', "");
Expect(1, 65103, '\P{^Is_Blk=CJK_Compat_Forms}', "");
Expect(0, 65104, '\p{Is_Blk=CJK_Compat_Forms}', "");
Expect(1, 65104, '\p{^Is_Blk=CJK_Compat_Forms}', "");
Expect(1, 65104, '\P{Is_Blk=CJK_Compat_Forms}', "");
Expect(0, 65104, '\P{^Is_Blk=CJK_Compat_Forms}', "");
Error('\p{Block=	:=cjk_compatibility_Ideographs}');
Error('\P{Block=	:=cjk_compatibility_Ideographs}');
Expect(1, 64255, '\p{Block=cjkcompatibilityideographs}', "");
Expect(0, 64255, '\p{^Block=cjkcompatibilityideographs}', "");
Expect(0, 64255, '\P{Block=cjkcompatibilityideographs}', "");
Expect(1, 64255, '\P{^Block=cjkcompatibilityideographs}', "");
Expect(0, 64256, '\p{Block=cjkcompatibilityideographs}', "");
Expect(1, 64256, '\p{^Block=cjkcompatibilityideographs}', "");
Expect(1, 64256, '\P{Block=cjkcompatibilityideographs}', "");
Expect(0, 64256, '\P{^Block=cjkcompatibilityideographs}', "");
Expect(1, 64255, '\p{Block=- cjk_Compatibility_Ideographs}', "");
Expect(0, 64255, '\p{^Block=- cjk_Compatibility_Ideographs}', "");
Expect(0, 64255, '\P{Block=- cjk_Compatibility_Ideographs}', "");
Expect(1, 64255, '\P{^Block=- cjk_Compatibility_Ideographs}', "");
Expect(0, 64256, '\p{Block=- cjk_Compatibility_Ideographs}', "");
Expect(1, 64256, '\p{^Block=- cjk_Compatibility_Ideographs}', "");
Expect(1, 64256, '\P{Block=- cjk_Compatibility_Ideographs}', "");
Expect(0, 64256, '\P{^Block=- cjk_Compatibility_Ideographs}', "");
Error('\p{Blk=_	CJK_Compat_Ideographs/a/}');
Error('\P{Blk=_	CJK_Compat_Ideographs/a/}');
Expect(1, 64255, '\p{Blk=cjkcompatideographs}', "");
Expect(0, 64255, '\p{^Blk=cjkcompatideographs}', "");
Expect(0, 64255, '\P{Blk=cjkcompatideographs}', "");
Expect(1, 64255, '\P{^Blk=cjkcompatideographs}', "");
Expect(0, 64256, '\p{Blk=cjkcompatideographs}', "");
Expect(1, 64256, '\p{^Blk=cjkcompatideographs}', "");
Expect(1, 64256, '\P{Blk=cjkcompatideographs}', "");
Expect(0, 64256, '\P{^Blk=cjkcompatideographs}', "");
Expect(1, 64255, '\p{Blk=-cjk_COMPAT_IDEOGRAPHS}', "");
Expect(0, 64255, '\p{^Blk=-cjk_COMPAT_IDEOGRAPHS}', "");
Expect(0, 64255, '\P{Blk=-cjk_COMPAT_IDEOGRAPHS}', "");
Expect(1, 64255, '\P{^Blk=-cjk_COMPAT_IDEOGRAPHS}', "");
Expect(0, 64256, '\p{Blk=-cjk_COMPAT_IDEOGRAPHS}', "");
Expect(1, 64256, '\p{^Blk=-cjk_COMPAT_IDEOGRAPHS}', "");
Expect(1, 64256, '\P{Blk=-cjk_COMPAT_IDEOGRAPHS}', "");
Expect(0, 64256, '\P{^Blk=-cjk_COMPAT_IDEOGRAPHS}', "");
Error('\p{Is_Block=/a/-cjk_Compatibility_IDEOGRAPHS}');
Error('\P{Is_Block=/a/-cjk_Compatibility_IDEOGRAPHS}');
Expect(1, 64255, '\p{Is_Block=cjkcompatibilityideographs}', "");
Expect(0, 64255, '\p{^Is_Block=cjkcompatibilityideographs}', "");
Expect(0, 64255, '\P{Is_Block=cjkcompatibilityideographs}', "");
Expect(1, 64255, '\P{^Is_Block=cjkcompatibilityideographs}', "");
Expect(0, 64256, '\p{Is_Block=cjkcompatibilityideographs}', "");
Expect(1, 64256, '\p{^Is_Block=cjkcompatibilityideographs}', "");
Expect(1, 64256, '\P{Is_Block=cjkcompatibilityideographs}', "");
Expect(0, 64256, '\P{^Is_Block=cjkcompatibilityideographs}', "");
Expect(1, 64255, '\p{Is_Block=_ CJK_Compatibility_Ideographs}', "");
Expect(0, 64255, '\p{^Is_Block=_ CJK_Compatibility_Ideographs}', "");
Expect(0, 64255, '\P{Is_Block=_ CJK_Compatibility_Ideographs}', "");
Expect(1, 64255, '\P{^Is_Block=_ CJK_Compatibility_Ideographs}', "");
Expect(0, 64256, '\p{Is_Block=_ CJK_Compatibility_Ideographs}', "");
Expect(1, 64256, '\p{^Is_Block=_ CJK_Compatibility_Ideographs}', "");
Expect(1, 64256, '\P{Is_Block=_ CJK_Compatibility_Ideographs}', "");
Expect(0, 64256, '\P{^Is_Block=_ CJK_Compatibility_Ideographs}', "");
Error('\p{Is_Blk=-cjk_compat_ideographs:=}');
Error('\P{Is_Blk=-cjk_compat_ideographs:=}');
Expect(1, 64255, '\p{Is_Blk=cjkcompatideographs}', "");
Expect(0, 64255, '\p{^Is_Blk=cjkcompatideographs}', "");
Expect(0, 64255, '\P{Is_Blk=cjkcompatideographs}', "");
Expect(1, 64255, '\P{^Is_Blk=cjkcompatideographs}', "");
Expect(0, 64256, '\p{Is_Blk=cjkcompatideographs}', "");
Expect(1, 64256, '\p{^Is_Blk=cjkcompatideographs}', "");
Expect(1, 64256, '\P{Is_Blk=cjkcompatideographs}', "");
Expect(0, 64256, '\P{^Is_Blk=cjkcompatideographs}', "");
Expect(1, 64255, '\p{Is_Blk=	-cjk_Compat_Ideographs}', "");
Expect(0, 64255, '\p{^Is_Blk=	-cjk_Compat_Ideographs}', "");
Expect(0, 64255, '\P{Is_Blk=	-cjk_Compat_Ideographs}', "");
Expect(1, 64255, '\P{^Is_Blk=	-cjk_Compat_Ideographs}', "");
Expect(0, 64256, '\p{Is_Blk=	-cjk_Compat_Ideographs}', "");
Expect(1, 64256, '\p{^Is_Blk=	-cjk_Compat_Ideographs}', "");
Expect(1, 64256, '\P{Is_Blk=	-cjk_Compat_Ideographs}', "");
Expect(0, 64256, '\P{^Is_Blk=	-cjk_Compat_Ideographs}', "");
Error('\p{Block=/a/--cjk_Compatibility_IDEOGRAPHS_SUPPLEMENT}');
Error('\P{Block=/a/--cjk_Compatibility_IDEOGRAPHS_SUPPLEMENT}');
Expect(1, 195103, '\p{Block=cjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\p{^Block=cjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\P{Block=cjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\P{^Block=cjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\p{Block=cjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\p{^Block=cjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\P{Block=cjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\P{^Block=cjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\p{Block=	_CJK_COMPATIBILITY_Ideographs_Supplement}', "");
Expect(0, 195103, '\p{^Block=	_CJK_COMPATIBILITY_Ideographs_Supplement}', "");
Expect(0, 195103, '\P{Block=	_CJK_COMPATIBILITY_Ideographs_Supplement}', "");
Expect(1, 195103, '\P{^Block=	_CJK_COMPATIBILITY_Ideographs_Supplement}', "");
Expect(0, 195104, '\p{Block=	_CJK_COMPATIBILITY_Ideographs_Supplement}', "");
Expect(1, 195104, '\p{^Block=	_CJK_COMPATIBILITY_Ideographs_Supplement}', "");
Expect(1, 195104, '\P{Block=	_CJK_COMPATIBILITY_Ideographs_Supplement}', "");
Expect(0, 195104, '\P{^Block=	_CJK_COMPATIBILITY_Ideographs_Supplement}', "");
Error('\p{Blk=:= _CJK_COMPAT_ideographs_Sup}');
Error('\P{Blk=:= _CJK_COMPAT_ideographs_Sup}');
Expect(1, 195103, '\p{Blk=cjkcompatideographssup}', "");
Expect(0, 195103, '\p{^Blk=cjkcompatideographssup}', "");
Expect(0, 195103, '\P{Blk=cjkcompatideographssup}', "");
Expect(1, 195103, '\P{^Blk=cjkcompatideographssup}', "");
Expect(0, 195104, '\p{Blk=cjkcompatideographssup}', "");
Expect(1, 195104, '\p{^Blk=cjkcompatideographssup}', "");
Expect(1, 195104, '\P{Blk=cjkcompatideographssup}', "");
Expect(0, 195104, '\P{^Blk=cjkcompatideographssup}', "");
Expect(1, 195103, '\p{Blk= 	CJK_Compat_ideographs_Sup}', "");
Expect(0, 195103, '\p{^Blk= 	CJK_Compat_ideographs_Sup}', "");
Expect(0, 195103, '\P{Blk= 	CJK_Compat_ideographs_Sup}', "");
Expect(1, 195103, '\P{^Blk= 	CJK_Compat_ideographs_Sup}', "");
Expect(0, 195104, '\p{Blk= 	CJK_Compat_ideographs_Sup}', "");
Expect(1, 195104, '\p{^Blk= 	CJK_Compat_ideographs_Sup}', "");
Expect(1, 195104, '\P{Blk= 	CJK_Compat_ideographs_Sup}', "");
Expect(0, 195104, '\P{^Blk= 	CJK_Compat_ideographs_Sup}', "");
Error('\p{Is_Block=_/a/cjk_Compatibility_ideographs_supplement}');
Error('\P{Is_Block=_/a/cjk_Compatibility_ideographs_supplement}');
Expect(1, 195103, '\p{Is_Block=cjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\p{^Is_Block=cjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\P{Is_Block=cjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\P{^Is_Block=cjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\p{Is_Block=cjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\p{^Is_Block=cjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\P{Is_Block=cjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\P{^Is_Block=cjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\p{Is_Block=_	cjk_Compatibility_ideographs_Supplement}', "");
Expect(0, 195103, '\p{^Is_Block=_	cjk_Compatibility_ideographs_Supplement}', "");
Expect(0, 195103, '\P{Is_Block=_	cjk_Compatibility_ideographs_Supplement}', "");
Expect(1, 195103, '\P{^Is_Block=_	cjk_Compatibility_ideographs_Supplement}', "");
Expect(0, 195104, '\p{Is_Block=_	cjk_Compatibility_ideographs_Supplement}', "");
Expect(1, 195104, '\p{^Is_Block=_	cjk_Compatibility_ideographs_Supplement}', "");
Expect(1, 195104, '\P{Is_Block=_	cjk_Compatibility_ideographs_Supplement}', "");
Expect(0, 195104, '\P{^Is_Block=_	cjk_Compatibility_ideographs_Supplement}', "");
Error('\p{Is_Blk=/a/_	CJK_COMPAT_IDEOGRAPHS_Sup}');
Error('\P{Is_Blk=/a/_	CJK_COMPAT_IDEOGRAPHS_Sup}');
Expect(1, 195103, '\p{Is_Blk=cjkcompatideographssup}', "");
Expect(0, 195103, '\p{^Is_Blk=cjkcompatideographssup}', "");
Expect(0, 195103, '\P{Is_Blk=cjkcompatideographssup}', "");
Expect(1, 195103, '\P{^Is_Blk=cjkcompatideographssup}', "");
Expect(0, 195104, '\p{Is_Blk=cjkcompatideographssup}', "");
Expect(1, 195104, '\p{^Is_Blk=cjkcompatideographssup}', "");
Expect(1, 195104, '\P{Is_Blk=cjkcompatideographssup}', "");
Expect(0, 195104, '\P{^Is_Blk=cjkcompatideographssup}', "");
Expect(1, 195103, '\p{Is_Blk: _CJK_Compat_Ideographs_sup}', "");
Expect(0, 195103, '\p{^Is_Blk: _CJK_Compat_Ideographs_sup}', "");
Expect(0, 195103, '\P{Is_Blk: _CJK_Compat_Ideographs_sup}', "");
Expect(1, 195103, '\P{^Is_Blk: _CJK_Compat_Ideographs_sup}', "");
Expect(0, 195104, '\p{Is_Blk: _CJK_Compat_Ideographs_sup}', "");
Expect(1, 195104, '\p{^Is_Blk: _CJK_Compat_Ideographs_sup}', "");
Expect(1, 195104, '\P{Is_Blk: _CJK_Compat_Ideographs_sup}', "");
Expect(0, 195104, '\P{^Is_Blk: _CJK_Compat_Ideographs_sup}', "");
Error('\p{Block=/a/		cjk_unified_Ideographs_EXTENSION_A}');
Error('\P{Block=/a/		cjk_unified_Ideographs_EXTENSION_A}');
Expect(1, 19903, '\p{Block=cjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\p{^Block=cjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\P{Block=cjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\P{^Block=cjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\p{Block=cjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\p{^Block=cjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\P{Block=cjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\P{^Block=cjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\p{Block=		CJK_Unified_IDEOGRAPHS_EXTENSION_a}', "");
Expect(0, 19903, '\p{^Block=		CJK_Unified_IDEOGRAPHS_EXTENSION_a}', "");
Expect(0, 19903, '\P{Block=		CJK_Unified_IDEOGRAPHS_EXTENSION_a}', "");
Expect(1, 19903, '\P{^Block=		CJK_Unified_IDEOGRAPHS_EXTENSION_a}', "");
Expect(0, 19904, '\p{Block=		CJK_Unified_IDEOGRAPHS_EXTENSION_a}', "");
Expect(1, 19904, '\p{^Block=		CJK_Unified_IDEOGRAPHS_EXTENSION_a}', "");
Expect(1, 19904, '\P{Block=		CJK_Unified_IDEOGRAPHS_EXTENSION_a}', "");
Expect(0, 19904, '\P{^Block=		CJK_Unified_IDEOGRAPHS_EXTENSION_a}', "");
Error('\p{Blk= cjk_Ext_A:=}');
Error('\P{Blk= cjk_Ext_A:=}');
Expect(1, 19903, '\p{Blk=cjkexta}', "");
Expect(0, 19903, '\p{^Blk=cjkexta}', "");
Expect(0, 19903, '\P{Blk=cjkexta}', "");
Expect(1, 19903, '\P{^Blk=cjkexta}', "");
Expect(0, 19904, '\p{Blk=cjkexta}', "");
Expect(1, 19904, '\p{^Blk=cjkexta}', "");
Expect(1, 19904, '\P{Blk=cjkexta}', "");
Expect(0, 19904, '\P{^Blk=cjkexta}', "");
Expect(1, 19903, '\p{Blk:   -CJK_Ext_A}', "");
Expect(0, 19903, '\p{^Blk:   -CJK_Ext_A}', "");
Expect(0, 19903, '\P{Blk:   -CJK_Ext_A}', "");
Expect(1, 19903, '\P{^Blk:   -CJK_Ext_A}', "");
Expect(0, 19904, '\p{Blk:   -CJK_Ext_A}', "");
Expect(1, 19904, '\p{^Blk:   -CJK_Ext_A}', "");
Expect(1, 19904, '\P{Blk:   -CJK_Ext_A}', "");
Expect(0, 19904, '\P{^Blk:   -CJK_Ext_A}', "");
Error('\p{Is_Block=	CJK_Unified_Ideographs_Extension_A:=}');
Error('\P{Is_Block=	CJK_Unified_Ideographs_Extension_A:=}');
Expect(1, 19903, '\p{Is_Block=cjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\p{^Is_Block=cjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\P{Is_Block=cjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\P{^Is_Block=cjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\p{Is_Block=cjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\p{^Is_Block=cjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\P{Is_Block=cjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\P{^Is_Block=cjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\p{Is_Block:	_CJK_Unified_Ideographs_Extension_A}', "");
Expect(0, 19903, '\p{^Is_Block:	_CJK_Unified_Ideographs_Extension_A}', "");
Expect(0, 19903, '\P{Is_Block:	_CJK_Unified_Ideographs_Extension_A}', "");
Expect(1, 19903, '\P{^Is_Block:	_CJK_Unified_Ideographs_Extension_A}', "");
Expect(0, 19904, '\p{Is_Block:	_CJK_Unified_Ideographs_Extension_A}', "");
Expect(1, 19904, '\p{^Is_Block:	_CJK_Unified_Ideographs_Extension_A}', "");
Expect(1, 19904, '\P{Is_Block:	_CJK_Unified_Ideographs_Extension_A}', "");
Expect(0, 19904, '\P{^Is_Block:	_CJK_Unified_Ideographs_Extension_A}', "");
Error('\p{Is_Blk=_/a/CJK_EXT_A}');
Error('\P{Is_Blk=_/a/CJK_EXT_A}');
Expect(1, 19903, '\p{Is_Blk=cjkexta}', "");
Expect(0, 19903, '\p{^Is_Blk=cjkexta}', "");
Expect(0, 19903, '\P{Is_Blk=cjkexta}', "");
Expect(1, 19903, '\P{^Is_Blk=cjkexta}', "");
Expect(0, 19904, '\p{Is_Blk=cjkexta}', "");
Expect(1, 19904, '\p{^Is_Blk=cjkexta}', "");
Expect(1, 19904, '\P{Is_Blk=cjkexta}', "");
Expect(0, 19904, '\P{^Is_Blk=cjkexta}', "");
Expect(1, 19903, '\p{Is_Blk=	CJK_ext_A}', "");
Expect(0, 19903, '\p{^Is_Blk=	CJK_ext_A}', "");
Expect(0, 19903, '\P{Is_Blk=	CJK_ext_A}', "");
Expect(1, 19903, '\P{^Is_Blk=	CJK_ext_A}', "");
Expect(0, 19904, '\p{Is_Blk=	CJK_ext_A}', "");
Expect(1, 19904, '\p{^Is_Blk=	CJK_ext_A}', "");
Expect(1, 19904, '\P{Is_Blk=	CJK_ext_A}', "");
Expect(0, 19904, '\P{^Is_Blk=	CJK_ext_A}', "");
Error('\p{Block=		cjk_Unified_ideographs_Extension_B/a/}');
Error('\P{Block=		cjk_Unified_ideographs_Extension_B/a/}');
Expect(1, 173791, '\p{Block=cjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\p{^Block=cjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\P{Block=cjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\P{^Block=cjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\p{Block=cjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\p{^Block=cjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\P{Block=cjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\P{^Block=cjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\p{Block:		CJK_unified_Ideographs_extension_b}', "");
Expect(0, 173791, '\p{^Block:		CJK_unified_Ideographs_extension_b}', "");
Expect(0, 173791, '\P{Block:		CJK_unified_Ideographs_extension_b}', "");
Expect(1, 173791, '\P{^Block:		CJK_unified_Ideographs_extension_b}', "");
Expect(0, 173792, '\p{Block:		CJK_unified_Ideographs_extension_b}', "");
Expect(1, 173792, '\p{^Block:		CJK_unified_Ideographs_extension_b}', "");
Expect(1, 173792, '\P{Block:		CJK_unified_Ideographs_extension_b}', "");
Expect(0, 173792, '\P{^Block:		CJK_unified_Ideographs_extension_b}', "");
Error('\p{Blk= -CJK_ext_b:=}');
Error('\P{Blk= -CJK_ext_b:=}');
Expect(1, 173791, '\p{Blk=cjkextb}', "");
Expect(0, 173791, '\p{^Blk=cjkextb}', "");
Expect(0, 173791, '\P{Blk=cjkextb}', "");
Expect(1, 173791, '\P{^Blk=cjkextb}', "");
Expect(0, 173792, '\p{Blk=cjkextb}', "");
Expect(1, 173792, '\p{^Blk=cjkextb}', "");
Expect(1, 173792, '\P{Blk=cjkextb}', "");
Expect(0, 173792, '\P{^Blk=cjkextb}', "");
Expect(1, 173791, '\p{Blk=		CJK_Ext_B}', "");
Expect(0, 173791, '\p{^Blk=		CJK_Ext_B}', "");
Expect(0, 173791, '\P{Blk=		CJK_Ext_B}', "");
Expect(1, 173791, '\P{^Blk=		CJK_Ext_B}', "");
Expect(0, 173792, '\p{Blk=		CJK_Ext_B}', "");
Expect(1, 173792, '\p{^Blk=		CJK_Ext_B}', "");
Expect(1, 173792, '\P{Blk=		CJK_Ext_B}', "");
Expect(0, 173792, '\P{^Blk=		CJK_Ext_B}', "");
Error('\p{Is_Block=:=	_CJK_UNIFIED_IDEOGRAPHS_Extension_B}');
Error('\P{Is_Block=:=	_CJK_UNIFIED_IDEOGRAPHS_Extension_B}');
Expect(1, 173791, '\p{Is_Block:	cjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\p{^Is_Block:	cjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\P{Is_Block:	cjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\P{^Is_Block:	cjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\p{Is_Block:	cjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\p{^Is_Block:	cjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\P{Is_Block:	cjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\P{^Is_Block:	cjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\p{Is_Block= -cjk_Unified_IDEOGRAPHS_EXTENSION_B}', "");
Expect(0, 173791, '\p{^Is_Block= -cjk_Unified_IDEOGRAPHS_EXTENSION_B}', "");
Expect(0, 173791, '\P{Is_Block= -cjk_Unified_IDEOGRAPHS_EXTENSION_B}', "");
Expect(1, 173791, '\P{^Is_Block= -cjk_Unified_IDEOGRAPHS_EXTENSION_B}', "");
Expect(0, 173792, '\p{Is_Block= -cjk_Unified_IDEOGRAPHS_EXTENSION_B}', "");
Expect(1, 173792, '\p{^Is_Block= -cjk_Unified_IDEOGRAPHS_EXTENSION_B}', "");
Expect(1, 173792, '\P{Is_Block= -cjk_Unified_IDEOGRAPHS_EXTENSION_B}', "");
Expect(0, 173792, '\P{^Is_Block= -cjk_Unified_IDEOGRAPHS_EXTENSION_B}', "");
Error('\p{Is_Blk=_ CJK_Ext_b/a/}');
Error('\P{Is_Blk=_ CJK_Ext_b/a/}');
Expect(1, 173791, '\p{Is_Blk=cjkextb}', "");
Expect(0, 173791, '\p{^Is_Blk=cjkextb}', "");
Expect(0, 173791, '\P{Is_Blk=cjkextb}', "");
Expect(1, 173791, '\P{^Is_Blk=cjkextb}', "");
Expect(0, 173792, '\p{Is_Blk=cjkextb}', "");
Expect(1, 173792, '\p{^Is_Blk=cjkextb}', "");
Expect(1, 173792, '\P{Is_Blk=cjkextb}', "");
Expect(0, 173792, '\P{^Is_Blk=cjkextb}', "");
Expect(1, 173791, '\p{Is_Blk=	-CJK_EXT_B}', "");
Expect(0, 173791, '\p{^Is_Blk=	-CJK_EXT_B}', "");
Expect(0, 173791, '\P{Is_Blk=	-CJK_EXT_B}', "");
Expect(1, 173791, '\P{^Is_Blk=	-CJK_EXT_B}', "");
Expect(0, 173792, '\p{Is_Blk=	-CJK_EXT_B}', "");
Expect(1, 173792, '\p{^Is_Blk=	-CJK_EXT_B}', "");
Expect(1, 173792, '\P{Is_Blk=	-CJK_EXT_B}', "");
Expect(0, 173792, '\P{^Is_Blk=	-CJK_EXT_B}', "");
Error('\p{Block=-_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_C/a/}');
Error('\P{Block=-_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_C/a/}');
Expect(1, 177983, '\p{Block=cjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\p{^Block=cjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\P{Block=cjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\P{^Block=cjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\p{Block=cjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\p{^Block=cjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\P{Block=cjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\P{^Block=cjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\p{Block=CJK_unified_Ideographs_Extension_C}', "");
Expect(0, 177983, '\p{^Block=CJK_unified_Ideographs_Extension_C}', "");
Expect(0, 177983, '\P{Block=CJK_unified_Ideographs_Extension_C}', "");
Expect(1, 177983, '\P{^Block=CJK_unified_Ideographs_Extension_C}', "");
Expect(0, 177984, '\p{Block=CJK_unified_Ideographs_Extension_C}', "");
Expect(1, 177984, '\p{^Block=CJK_unified_Ideographs_Extension_C}', "");
Expect(1, 177984, '\P{Block=CJK_unified_Ideographs_Extension_C}', "");
Expect(0, 177984, '\P{^Block=CJK_unified_Ideographs_Extension_C}', "");
Error('\p{Blk=:=_cjk_ext_C}');
Error('\P{Blk=:=_cjk_ext_C}');
Expect(1, 177983, '\p{Blk=cjkextc}', "");
Expect(0, 177983, '\p{^Blk=cjkextc}', "");
Expect(0, 177983, '\P{Blk=cjkextc}', "");
Expect(1, 177983, '\P{^Blk=cjkextc}', "");
Expect(0, 177984, '\p{Blk=cjkextc}', "");
Expect(1, 177984, '\p{^Blk=cjkextc}', "");
Expect(1, 177984, '\P{Blk=cjkextc}', "");
Expect(0, 177984, '\P{^Blk=cjkextc}', "");
Expect(1, 177983, '\p{Blk:_-CJK_ext_c}', "");
Expect(0, 177983, '\p{^Blk:_-CJK_ext_c}', "");
Expect(0, 177983, '\P{Blk:_-CJK_ext_c}', "");
Expect(1, 177983, '\P{^Blk:_-CJK_ext_c}', "");
Expect(0, 177984, '\p{Blk:_-CJK_ext_c}', "");
Expect(1, 177984, '\p{^Blk:_-CJK_ext_c}', "");
Expect(1, 177984, '\P{Blk:_-CJK_ext_c}', "");
Expect(0, 177984, '\P{^Blk:_-CJK_ext_c}', "");
Error('\p{Is_Block=:=_	CJK_Unified_Ideographs_Extension_C}');
Error('\P{Is_Block=:=_	CJK_Unified_Ideographs_Extension_C}');
Expect(1, 177983, '\p{Is_Block=cjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\p{^Is_Block=cjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\P{Is_Block=cjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\P{^Is_Block=cjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\p{Is_Block=cjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\p{^Is_Block=cjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\P{Is_Block=cjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\P{^Is_Block=cjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\p{Is_Block=	CJK_unified_ideographs_extension_C}', "");
Expect(0, 177983, '\p{^Is_Block=	CJK_unified_ideographs_extension_C}', "");
Expect(0, 177983, '\P{Is_Block=	CJK_unified_ideographs_extension_C}', "");
Expect(1, 177983, '\P{^Is_Block=	CJK_unified_ideographs_extension_C}', "");
Expect(0, 177984, '\p{Is_Block=	CJK_unified_ideographs_extension_C}', "");
Expect(1, 177984, '\p{^Is_Block=	CJK_unified_ideographs_extension_C}', "");
Expect(1, 177984, '\P{Is_Block=	CJK_unified_ideographs_extension_C}', "");
Expect(0, 177984, '\P{^Is_Block=	CJK_unified_ideographs_extension_C}', "");
Error('\p{Is_Blk=-	CJK_EXT_C:=}');
Error('\P{Is_Blk=-	CJK_EXT_C:=}');
Expect(1, 177983, '\p{Is_Blk=cjkextc}', "");
Expect(0, 177983, '\p{^Is_Blk=cjkextc}', "");
Expect(0, 177983, '\P{Is_Blk=cjkextc}', "");
Expect(1, 177983, '\P{^Is_Blk=cjkextc}', "");
Expect(0, 177984, '\p{Is_Blk=cjkextc}', "");
Expect(1, 177984, '\p{^Is_Blk=cjkextc}', "");
Expect(1, 177984, '\P{Is_Blk=cjkextc}', "");
Expect(0, 177984, '\P{^Is_Blk=cjkextc}', "");
Expect(1, 177983, '\p{Is_Blk: _	CJK_ext_C}', "");
Expect(0, 177983, '\p{^Is_Blk: _	CJK_ext_C}', "");
Expect(0, 177983, '\P{Is_Blk: _	CJK_ext_C}', "");
Expect(1, 177983, '\P{^Is_Blk: _	CJK_ext_C}', "");
Expect(0, 177984, '\p{Is_Blk: _	CJK_ext_C}', "");
Expect(1, 177984, '\p{^Is_Blk: _	CJK_ext_C}', "");
Expect(1, 177984, '\P{Is_Blk: _	CJK_ext_C}', "");
Expect(0, 177984, '\P{^Is_Blk: _	CJK_ext_C}', "");
Error('\p{Block=_	CJK_unified_Ideographs_EXTENSION_D/a/}');
Error('\P{Block=_	CJK_unified_Ideographs_EXTENSION_D/a/}');
Expect(1, 178207, '\p{Block:   cjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\p{^Block:   cjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\P{Block:   cjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\P{^Block:   cjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\p{Block:   cjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\p{^Block:   cjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\P{Block:   cjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\P{^Block:   cjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\p{Block=-CJK_unified_Ideographs_EXTENSION_D}', "");
Expect(0, 178207, '\p{^Block=-CJK_unified_Ideographs_EXTENSION_D}', "");
Expect(0, 178207, '\P{Block=-CJK_unified_Ideographs_EXTENSION_D}', "");
Expect(1, 178207, '\P{^Block=-CJK_unified_Ideographs_EXTENSION_D}', "");
Expect(0, 178208, '\p{Block=-CJK_unified_Ideographs_EXTENSION_D}', "");
Expect(1, 178208, '\p{^Block=-CJK_unified_Ideographs_EXTENSION_D}', "");
Expect(1, 178208, '\P{Block=-CJK_unified_Ideographs_EXTENSION_D}', "");
Expect(0, 178208, '\P{^Block=-CJK_unified_Ideographs_EXTENSION_D}', "");
Error('\p{Blk=/a/CJK_EXT_D}');
Error('\P{Blk=/a/CJK_EXT_D}');
Expect(1, 178207, '\p{Blk=cjkextd}', "");
Expect(0, 178207, '\p{^Blk=cjkextd}', "");
Expect(0, 178207, '\P{Blk=cjkextd}', "");
Expect(1, 178207, '\P{^Blk=cjkextd}', "");
Expect(0, 178208, '\p{Blk=cjkextd}', "");
Expect(1, 178208, '\p{^Blk=cjkextd}', "");
Expect(1, 178208, '\P{Blk=cjkextd}', "");
Expect(0, 178208, '\P{^Blk=cjkextd}', "");
Expect(1, 178207, '\p{Blk: 	 CJK_Ext_D}', "");
Expect(0, 178207, '\p{^Blk: 	 CJK_Ext_D}', "");
Expect(0, 178207, '\P{Blk: 	 CJK_Ext_D}', "");
Expect(1, 178207, '\P{^Blk: 	 CJK_Ext_D}', "");
Expect(0, 178208, '\p{Blk: 	 CJK_Ext_D}', "");
Expect(1, 178208, '\p{^Blk: 	 CJK_Ext_D}', "");
Expect(1, 178208, '\P{Blk: 	 CJK_Ext_D}', "");
Expect(0, 178208, '\P{^Blk: 	 CJK_Ext_D}', "");
Error('\p{Is_Block=-CJK_Unified_IDEOGRAPHS_Extension_D/a/}');
Error('\P{Is_Block=-CJK_Unified_IDEOGRAPHS_Extension_D/a/}');
Expect(1, 178207, '\p{Is_Block=cjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\p{^Is_Block=cjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\P{Is_Block=cjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\P{^Is_Block=cjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\p{Is_Block=cjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\p{^Is_Block=cjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\P{Is_Block=cjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\P{^Is_Block=cjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\p{Is_Block:		cjk_Unified_Ideographs_extension_D}', "");
Expect(0, 178207, '\p{^Is_Block:		cjk_Unified_Ideographs_extension_D}', "");
Expect(0, 178207, '\P{Is_Block:		cjk_Unified_Ideographs_extension_D}', "");
Expect(1, 178207, '\P{^Is_Block:		cjk_Unified_Ideographs_extension_D}', "");
Expect(0, 178208, '\p{Is_Block:		cjk_Unified_Ideographs_extension_D}', "");
Expect(1, 178208, '\p{^Is_Block:		cjk_Unified_Ideographs_extension_D}', "");
Expect(1, 178208, '\P{Is_Block:		cjk_Unified_Ideographs_extension_D}', "");
Expect(0, 178208, '\P{^Is_Block:		cjk_Unified_Ideographs_extension_D}', "");
Error('\p{Is_Blk= :=CJK_Ext_D}');
Error('\P{Is_Blk= :=CJK_Ext_D}');
Expect(1, 178207, '\p{Is_Blk=cjkextd}', "");
Expect(0, 178207, '\p{^Is_Blk=cjkextd}', "");
Expect(0, 178207, '\P{Is_Blk=cjkextd}', "");
Expect(1, 178207, '\P{^Is_Blk=cjkextd}', "");
Expect(0, 178208, '\p{Is_Blk=cjkextd}', "");
Expect(1, 178208, '\p{^Is_Blk=cjkextd}', "");
Expect(1, 178208, '\P{Is_Blk=cjkextd}', "");
Expect(0, 178208, '\P{^Is_Blk=cjkextd}', "");
Expect(1, 178207, '\p{Is_Blk= _CJK_ext_D}', "");
Expect(0, 178207, '\p{^Is_Blk= _CJK_ext_D}', "");
Expect(0, 178207, '\P{Is_Blk= _CJK_ext_D}', "");
Expect(1, 178207, '\P{^Is_Blk= _CJK_ext_D}', "");
Expect(0, 178208, '\p{Is_Blk= _CJK_ext_D}', "");
Expect(1, 178208, '\p{^Is_Blk= _CJK_ext_D}', "");
Expect(1, 178208, '\P{Is_Blk= _CJK_ext_D}', "");
Expect(0, 178208, '\P{^Is_Blk= _CJK_ext_D}', "");
Error('\p{Block=	:=CJK_Radicals_Supplement}');
Error('\P{Block=	:=CJK_Radicals_Supplement}');
Expect(1, 12031, '\p{Block=cjkradicalssupplement}', "");
Expect(0, 12031, '\p{^Block=cjkradicalssupplement}', "");
Expect(0, 12031, '\P{Block=cjkradicalssupplement}', "");
Expect(1, 12031, '\P{^Block=cjkradicalssupplement}', "");
Expect(0, 12032, '\p{Block=cjkradicalssupplement}', "");
Expect(1, 12032, '\p{^Block=cjkradicalssupplement}', "");
Expect(1, 12032, '\P{Block=cjkradicalssupplement}', "");
Expect(0, 12032, '\P{^Block=cjkradicalssupplement}', "");
Expect(1, 12031, '\p{Block= 	CJK_RADICALS_SUPPLEMENT}', "");
Expect(0, 12031, '\p{^Block= 	CJK_RADICALS_SUPPLEMENT}', "");
Expect(0, 12031, '\P{Block= 	CJK_RADICALS_SUPPLEMENT}', "");
Expect(1, 12031, '\P{^Block= 	CJK_RADICALS_SUPPLEMENT}', "");
Expect(0, 12032, '\p{Block= 	CJK_RADICALS_SUPPLEMENT}', "");
Expect(1, 12032, '\p{^Block= 	CJK_RADICALS_SUPPLEMENT}', "");
Expect(1, 12032, '\P{Block= 	CJK_RADICALS_SUPPLEMENT}', "");
Expect(0, 12032, '\P{^Block= 	CJK_RADICALS_SUPPLEMENT}', "");
Error('\p{Blk:  /a/CJK_radicals_Sup}');
Error('\P{Blk:  /a/CJK_radicals_Sup}');
Expect(1, 12031, '\p{Blk=cjkradicalssup}', "");
Expect(0, 12031, '\p{^Blk=cjkradicalssup}', "");
Expect(0, 12031, '\P{Blk=cjkradicalssup}', "");
Expect(1, 12031, '\P{^Blk=cjkradicalssup}', "");
Expect(0, 12032, '\p{Blk=cjkradicalssup}', "");
Expect(1, 12032, '\p{^Blk=cjkradicalssup}', "");
Expect(1, 12032, '\P{Blk=cjkradicalssup}', "");
Expect(0, 12032, '\P{^Blk=cjkradicalssup}', "");
Expect(1, 12031, '\p{Blk=_CJK_RADICALS_sup}', "");
Expect(0, 12031, '\p{^Blk=_CJK_RADICALS_sup}', "");
Expect(0, 12031, '\P{Blk=_CJK_RADICALS_sup}', "");
Expect(1, 12031, '\P{^Blk=_CJK_RADICALS_sup}', "");
Expect(0, 12032, '\p{Blk=_CJK_RADICALS_sup}', "");
Expect(1, 12032, '\p{^Blk=_CJK_RADICALS_sup}', "");
Expect(1, 12032, '\P{Blk=_CJK_RADICALS_sup}', "");
Expect(0, 12032, '\P{^Blk=_CJK_RADICALS_sup}', "");
Error('\p{Is_Block= _CJK_Radicals_supplement/a/}');
Error('\P{Is_Block= _CJK_Radicals_supplement/a/}');
Expect(1, 12031, '\p{Is_Block=cjkradicalssupplement}', "");
Expect(0, 12031, '\p{^Is_Block=cjkradicalssupplement}', "");
Expect(0, 12031, '\P{Is_Block=cjkradicalssupplement}', "");
Expect(1, 12031, '\P{^Is_Block=cjkradicalssupplement}', "");
Expect(0, 12032, '\p{Is_Block=cjkradicalssupplement}', "");
Expect(1, 12032, '\p{^Is_Block=cjkradicalssupplement}', "");
Expect(1, 12032, '\P{Is_Block=cjkradicalssupplement}', "");
Expect(0, 12032, '\P{^Is_Block=cjkradicalssupplement}', "");
Expect(1, 12031, '\p{Is_Block:--CJK_radicals_SUPPLEMENT}', "");
Expect(0, 12031, '\p{^Is_Block:--CJK_radicals_SUPPLEMENT}', "");
Expect(0, 12031, '\P{Is_Block:--CJK_radicals_SUPPLEMENT}', "");
Expect(1, 12031, '\P{^Is_Block:--CJK_radicals_SUPPLEMENT}', "");
Expect(0, 12032, '\p{Is_Block:--CJK_radicals_SUPPLEMENT}', "");
Expect(1, 12032, '\p{^Is_Block:--CJK_radicals_SUPPLEMENT}', "");
Expect(1, 12032, '\P{Is_Block:--CJK_radicals_SUPPLEMENT}', "");
Expect(0, 12032, '\P{^Is_Block:--CJK_radicals_SUPPLEMENT}', "");
Error('\p{Is_Blk=-:=CJK_Radicals_SUP}');
Error('\P{Is_Blk=-:=CJK_Radicals_SUP}');
Expect(1, 12031, '\p{Is_Blk=cjkradicalssup}', "");
Expect(0, 12031, '\p{^Is_Blk=cjkradicalssup}', "");
Expect(0, 12031, '\P{Is_Blk=cjkradicalssup}', "");
Expect(1, 12031, '\P{^Is_Blk=cjkradicalssup}', "");
Expect(0, 12032, '\p{Is_Blk=cjkradicalssup}', "");
Expect(1, 12032, '\p{^Is_Blk=cjkradicalssup}', "");
Expect(1, 12032, '\P{Is_Blk=cjkradicalssup}', "");
Expect(0, 12032, '\P{^Is_Blk=cjkradicalssup}', "");
Expect(1, 12031, '\p{Is_Blk=		CJK_RADICALS_SUP}', "");
Expect(0, 12031, '\p{^Is_Blk=		CJK_RADICALS_SUP}', "");
Expect(0, 12031, '\P{Is_Blk=		CJK_RADICALS_SUP}', "");
Expect(1, 12031, '\P{^Is_Blk=		CJK_RADICALS_SUP}', "");
Expect(0, 12032, '\p{Is_Blk=		CJK_RADICALS_SUP}', "");
Expect(1, 12032, '\p{^Is_Blk=		CJK_RADICALS_SUP}', "");
Expect(1, 12032, '\P{Is_Blk=		CJK_RADICALS_SUP}', "");
Expect(0, 12032, '\P{^Is_Blk=		CJK_RADICALS_SUP}', "");
Error('\p{Block:	cjk_STROKES:=}');
Error('\P{Block:	cjk_STROKES:=}');
Expect(1, 12783, '\p{Block=cjkstrokes}', "");
Expect(0, 12783, '\p{^Block=cjkstrokes}', "");
Expect(0, 12783, '\P{Block=cjkstrokes}', "");
Expect(1, 12783, '\P{^Block=cjkstrokes}', "");
Expect(0, 12784, '\p{Block=cjkstrokes}', "");
Expect(1, 12784, '\p{^Block=cjkstrokes}', "");
Expect(1, 12784, '\P{Block=cjkstrokes}', "");
Expect(0, 12784, '\P{^Block=cjkstrokes}', "");
Expect(1, 12783, '\p{Block:   	cjk_Strokes}', "");
Expect(0, 12783, '\p{^Block:   	cjk_Strokes}', "");
Expect(0, 12783, '\P{Block:   	cjk_Strokes}', "");
Expect(1, 12783, '\P{^Block:   	cjk_Strokes}', "");
Expect(0, 12784, '\p{Block:   	cjk_Strokes}', "");
Expect(1, 12784, '\p{^Block:   	cjk_Strokes}', "");
Expect(1, 12784, '\P{Block:   	cjk_Strokes}', "");
Expect(0, 12784, '\P{^Block:   	cjk_Strokes}', "");
Error('\p{Blk:	--CJK_strokes:=}');
Error('\P{Blk:	--CJK_strokes:=}');
Expect(1, 12783, '\p{Blk=cjkstrokes}', "");
Expect(0, 12783, '\p{^Blk=cjkstrokes}', "");
Expect(0, 12783, '\P{Blk=cjkstrokes}', "");
Expect(1, 12783, '\P{^Blk=cjkstrokes}', "");
Expect(0, 12784, '\p{Blk=cjkstrokes}', "");
Expect(1, 12784, '\p{^Blk=cjkstrokes}', "");
Expect(1, 12784, '\P{Blk=cjkstrokes}', "");
Expect(0, 12784, '\P{^Blk=cjkstrokes}', "");
Expect(1, 12783, '\p{Blk=_-cjk_STROKES}', "");
Expect(0, 12783, '\p{^Blk=_-cjk_STROKES}', "");
Expect(0, 12783, '\P{Blk=_-cjk_STROKES}', "");
Expect(1, 12783, '\P{^Blk=_-cjk_STROKES}', "");
Expect(0, 12784, '\p{Blk=_-cjk_STROKES}', "");
Expect(1, 12784, '\p{^Blk=_-cjk_STROKES}', "");
Expect(1, 12784, '\P{Blk=_-cjk_STROKES}', "");
Expect(0, 12784, '\P{^Blk=_-cjk_STROKES}', "");
Error('\p{Is_Block= CJK_STROKES/a/}');
Error('\P{Is_Block= CJK_STROKES/a/}');
Expect(1, 12783, '\p{Is_Block=cjkstrokes}', "");
Expect(0, 12783, '\p{^Is_Block=cjkstrokes}', "");
Expect(0, 12783, '\P{Is_Block=cjkstrokes}', "");
Expect(1, 12783, '\P{^Is_Block=cjkstrokes}', "");
Expect(0, 12784, '\p{Is_Block=cjkstrokes}', "");
Expect(1, 12784, '\p{^Is_Block=cjkstrokes}', "");
Expect(1, 12784, '\P{Is_Block=cjkstrokes}', "");
Expect(0, 12784, '\P{^Is_Block=cjkstrokes}', "");
Expect(1, 12783, '\p{Is_Block=--CJK_Strokes}', "");
Expect(0, 12783, '\p{^Is_Block=--CJK_Strokes}', "");
Expect(0, 12783, '\P{Is_Block=--CJK_Strokes}', "");
Expect(1, 12783, '\P{^Is_Block=--CJK_Strokes}', "");
Expect(0, 12784, '\p{Is_Block=--CJK_Strokes}', "");
Expect(1, 12784, '\p{^Is_Block=--CJK_Strokes}', "");
Expect(1, 12784, '\P{Is_Block=--CJK_Strokes}', "");
Expect(0, 12784, '\P{^Is_Block=--CJK_Strokes}', "");
Error('\p{Is_Blk=/a/	 cjk_Strokes}');
Error('\P{Is_Blk=/a/	 cjk_Strokes}');
Expect(1, 12783, '\p{Is_Blk=cjkstrokes}', "");
Expect(0, 12783, '\p{^Is_Blk=cjkstrokes}', "");
Expect(0, 12783, '\P{Is_Blk=cjkstrokes}', "");
Expect(1, 12783, '\P{^Is_Blk=cjkstrokes}', "");
Expect(0, 12784, '\p{Is_Blk=cjkstrokes}', "");
Expect(1, 12784, '\p{^Is_Blk=cjkstrokes}', "");
Expect(1, 12784, '\P{Is_Blk=cjkstrokes}', "");
Expect(0, 12784, '\P{^Is_Blk=cjkstrokes}', "");
Expect(1, 12783, '\p{Is_Blk=-_cjk_Strokes}', "");
Expect(0, 12783, '\p{^Is_Blk=-_cjk_Strokes}', "");
Expect(0, 12783, '\P{Is_Blk=-_cjk_Strokes}', "");
Expect(1, 12783, '\P{^Is_Blk=-_cjk_Strokes}', "");
Expect(0, 12784, '\p{Is_Blk=-_cjk_Strokes}', "");
Expect(1, 12784, '\p{^Is_Blk=-_cjk_Strokes}', "");
Expect(1, 12784, '\P{Is_Blk=-_cjk_Strokes}', "");
Expect(0, 12784, '\P{^Is_Blk=-_cjk_Strokes}', "");
Error('\p{Block= -CJK_Symbols_and_Punctuation/a/}');
Error('\P{Block= -CJK_Symbols_and_Punctuation/a/}');
Expect(1, 12351, '\p{Block:   cjksymbolsandpunctuation}', "");
Expect(0, 12351, '\p{^Block:   cjksymbolsandpunctuation}', "");
Expect(0, 12351, '\P{Block:   cjksymbolsandpunctuation}', "");
Expect(1, 12351, '\P{^Block:   cjksymbolsandpunctuation}', "");
Expect(0, 12352, '\p{Block:   cjksymbolsandpunctuation}', "");
Expect(1, 12352, '\p{^Block:   cjksymbolsandpunctuation}', "");
Expect(1, 12352, '\P{Block:   cjksymbolsandpunctuation}', "");
Expect(0, 12352, '\P{^Block:   cjksymbolsandpunctuation}', "");
Expect(1, 12351, '\p{Block= CJK_SYMBOLS_And_Punctuation}', "");
Expect(0, 12351, '\p{^Block= CJK_SYMBOLS_And_Punctuation}', "");
Expect(0, 12351, '\P{Block= CJK_SYMBOLS_And_Punctuation}', "");
Expect(1, 12351, '\P{^Block= CJK_SYMBOLS_And_Punctuation}', "");
Expect(0, 12352, '\p{Block= CJK_SYMBOLS_And_Punctuation}', "");
Expect(1, 12352, '\p{^Block= CJK_SYMBOLS_And_Punctuation}', "");
Expect(1, 12352, '\P{Block= CJK_SYMBOLS_And_Punctuation}', "");
Expect(0, 12352, '\P{^Block= CJK_SYMBOLS_And_Punctuation}', "");
Error('\p{Blk=:= _CJK_Symbols}');
Error('\P{Blk=:= _CJK_Symbols}');
Expect(1, 12351, '\p{Blk=cjksymbols}', "");
Expect(0, 12351, '\p{^Blk=cjksymbols}', "");
Expect(0, 12351, '\P{Blk=cjksymbols}', "");
Expect(1, 12351, '\P{^Blk=cjksymbols}', "");
Expect(0, 12352, '\p{Blk=cjksymbols}', "");
Expect(1, 12352, '\p{^Blk=cjksymbols}', "");
Expect(1, 12352, '\P{Blk=cjksymbols}', "");
Expect(0, 12352, '\P{^Blk=cjksymbols}', "");
Expect(1, 12351, '\p{Blk=		CJK_symbols}', "");
Expect(0, 12351, '\p{^Blk=		CJK_symbols}', "");
Expect(0, 12351, '\P{Blk=		CJK_symbols}', "");
Expect(1, 12351, '\P{^Blk=		CJK_symbols}', "");
Expect(0, 12352, '\p{Blk=		CJK_symbols}', "");
Expect(1, 12352, '\p{^Blk=		CJK_symbols}', "");
Expect(1, 12352, '\P{Blk=		CJK_symbols}', "");
Expect(0, 12352, '\P{^Blk=		CJK_symbols}', "");
Error('\p{Is_Block=	CJK_SYMBOLS_And_Punctuation/a/}');
Error('\P{Is_Block=	CJK_SYMBOLS_And_Punctuation/a/}');
Expect(1, 12351, '\p{Is_Block=cjksymbolsandpunctuation}', "");
Expect(0, 12351, '\p{^Is_Block=cjksymbolsandpunctuation}', "");
Expect(0, 12351, '\P{Is_Block=cjksymbolsandpunctuation}', "");
Expect(1, 12351, '\P{^Is_Block=cjksymbolsandpunctuation}', "");
Expect(0, 12352, '\p{Is_Block=cjksymbolsandpunctuation}', "");
Expect(1, 12352, '\p{^Is_Block=cjksymbolsandpunctuation}', "");
Expect(1, 12352, '\P{Is_Block=cjksymbolsandpunctuation}', "");
Expect(0, 12352, '\P{^Is_Block=cjksymbolsandpunctuation}', "");
Expect(1, 12351, '\p{Is_Block=-_CJK_Symbols_and_punctuation}', "");
Expect(0, 12351, '\p{^Is_Block=-_CJK_Symbols_and_punctuation}', "");
Expect(0, 12351, '\P{Is_Block=-_CJK_Symbols_and_punctuation}', "");
Expect(1, 12351, '\P{^Is_Block=-_CJK_Symbols_and_punctuation}', "");
Expect(0, 12352, '\p{Is_Block=-_CJK_Symbols_and_punctuation}', "");
Expect(1, 12352, '\p{^Is_Block=-_CJK_Symbols_and_punctuation}', "");
Expect(1, 12352, '\P{Is_Block=-_CJK_Symbols_and_punctuation}', "");
Expect(0, 12352, '\P{^Is_Block=-_CJK_Symbols_and_punctuation}', "");
Error('\p{Is_Blk=-:=CJK_SYMBOLS}');
Error('\P{Is_Blk=-:=CJK_SYMBOLS}');
Expect(1, 12351, '\p{Is_Blk=cjksymbols}', "");
Expect(0, 12351, '\p{^Is_Blk=cjksymbols}', "");
Expect(0, 12351, '\P{Is_Blk=cjksymbols}', "");
Expect(1, 12351, '\P{^Is_Blk=cjksymbols}', "");
Expect(0, 12352, '\p{Is_Blk=cjksymbols}', "");
Expect(1, 12352, '\p{^Is_Blk=cjksymbols}', "");
Expect(1, 12352, '\P{Is_Blk=cjksymbols}', "");
Expect(0, 12352, '\P{^Is_Blk=cjksymbols}', "");
Expect(1, 12351, '\p{Is_Blk=_ cjk_SYMBOLS}', "");
Expect(0, 12351, '\p{^Is_Blk=_ cjk_SYMBOLS}', "");
Expect(0, 12351, '\P{Is_Blk=_ cjk_SYMBOLS}', "");
Expect(1, 12351, '\P{^Is_Blk=_ cjk_SYMBOLS}', "");
Expect(0, 12352, '\p{Is_Blk=_ cjk_SYMBOLS}', "");
Expect(1, 12352, '\p{^Is_Blk=_ cjk_SYMBOLS}', "");
Expect(1, 12352, '\P{Is_Blk=_ cjk_SYMBOLS}', "");
Expect(0, 12352, '\P{^Is_Blk=_ cjk_SYMBOLS}', "");
Error('\p{Block=-CARIAN:=}');
Error('\P{Block=-CARIAN:=}');
Expect(1, 66271, '\p{Block=carian}', "");
Expect(0, 66271, '\p{^Block=carian}', "");
Expect(0, 66271, '\P{Block=carian}', "");
Expect(1, 66271, '\P{^Block=carian}', "");
Expect(0, 66272, '\p{Block=carian}', "");
Expect(1, 66272, '\p{^Block=carian}', "");
Expect(1, 66272, '\P{Block=carian}', "");
Expect(0, 66272, '\P{^Block=carian}', "");
Expect(1, 66271, '\p{Block=- CARIAN}', "");
Expect(0, 66271, '\p{^Block=- CARIAN}', "");
Expect(0, 66271, '\P{Block=- CARIAN}', "");
Expect(1, 66271, '\P{^Block=- CARIAN}', "");
Expect(0, 66272, '\p{Block=- CARIAN}', "");
Expect(1, 66272, '\p{^Block=- CARIAN}', "");
Expect(1, 66272, '\P{Block=- CARIAN}', "");
Expect(0, 66272, '\P{^Block=- CARIAN}', "");
Error('\p{Blk:Carian/a/}');
Error('\P{Blk:Carian/a/}');
Expect(1, 66271, '\p{Blk=carian}', "");
Expect(0, 66271, '\p{^Blk=carian}', "");
Expect(0, 66271, '\P{Blk=carian}', "");
Expect(1, 66271, '\P{^Blk=carian}', "");
Expect(0, 66272, '\p{Blk=carian}', "");
Expect(1, 66272, '\p{^Blk=carian}', "");
Expect(1, 66272, '\P{Blk=carian}', "");
Expect(0, 66272, '\P{^Blk=carian}', "");
Expect(1, 66271, '\p{Blk=-	Carian}', "");
Expect(0, 66271, '\p{^Blk=-	Carian}', "");
Expect(0, 66271, '\P{Blk=-	Carian}', "");
Expect(1, 66271, '\P{^Blk=-	Carian}', "");
Expect(0, 66272, '\p{Blk=-	Carian}', "");
Expect(1, 66272, '\p{^Blk=-	Carian}', "");
Expect(1, 66272, '\P{Blk=-	Carian}', "");
Expect(0, 66272, '\P{^Blk=-	Carian}', "");
Error('\p{Is_Block=	-Carian:=}');
Error('\P{Is_Block=	-Carian:=}');
Expect(1, 66271, '\p{Is_Block=carian}', "");
Expect(0, 66271, '\p{^Is_Block=carian}', "");
Expect(0, 66271, '\P{Is_Block=carian}', "");
Expect(1, 66271, '\P{^Is_Block=carian}', "");
Expect(0, 66272, '\p{Is_Block=carian}', "");
Expect(1, 66272, '\p{^Is_Block=carian}', "");
Expect(1, 66272, '\P{Is_Block=carian}', "");
Expect(0, 66272, '\P{^Is_Block=carian}', "");
Error('\p{Is_Blk=-:=Carian}');
Error('\P{Is_Blk=-:=Carian}');
Expect(1, 66271, '\p{Is_Blk=carian}', "");
Expect(0, 66271, '\p{^Is_Blk=carian}', "");
Expect(0, 66271, '\P{Is_Blk=carian}', "");
Expect(1, 66271, '\P{^Is_Blk=carian}', "");
Expect(0, 66272, '\p{Is_Blk=carian}', "");
Expect(1, 66272, '\p{^Is_Blk=carian}', "");
Expect(1, 66272, '\P{Is_Blk=carian}', "");
Expect(0, 66272, '\P{^Is_Blk=carian}', "");
Expect(1, 66271, '\p{Is_Blk=  CARIAN}', "");
Expect(0, 66271, '\p{^Is_Blk=  CARIAN}', "");
Expect(0, 66271, '\P{Is_Blk=  CARIAN}', "");
Expect(1, 66271, '\P{^Is_Blk=  CARIAN}', "");
Expect(0, 66272, '\p{Is_Blk=  CARIAN}', "");
Expect(1, 66272, '\p{^Is_Blk=  CARIAN}', "");
Expect(1, 66272, '\P{Is_Blk=  CARIAN}', "");
Expect(0, 66272, '\P{^Is_Blk=  CARIAN}', "");
Error('\p{Block= /a/CHAKMA}');
Error('\P{Block= /a/CHAKMA}');
Expect(1, 69967, '\p{Block=chakma}', "");
Expect(0, 69967, '\p{^Block=chakma}', "");
Expect(0, 69967, '\P{Block=chakma}', "");
Expect(1, 69967, '\P{^Block=chakma}', "");
Expect(0, 69968, '\p{Block=chakma}', "");
Expect(1, 69968, '\p{^Block=chakma}', "");
Expect(1, 69968, '\P{Block=chakma}', "");
Expect(0, 69968, '\P{^Block=chakma}', "");
Expect(1, 69967, '\p{Block= chakma}', "");
Expect(0, 69967, '\p{^Block= chakma}', "");
Expect(0, 69967, '\P{Block= chakma}', "");
Expect(1, 69967, '\P{^Block= chakma}', "");
Expect(0, 69968, '\p{Block= chakma}', "");
Expect(1, 69968, '\p{^Block= chakma}', "");
Expect(1, 69968, '\P{Block= chakma}', "");
Expect(0, 69968, '\P{^Block= chakma}', "");
Error('\p{Blk=/a/ -chakma}');
Error('\P{Blk=/a/ -chakma}');
Expect(1, 69967, '\p{Blk=chakma}', "");
Expect(0, 69967, '\p{^Blk=chakma}', "");
Expect(0, 69967, '\P{Blk=chakma}', "");
Expect(1, 69967, '\P{^Blk=chakma}', "");
Expect(0, 69968, '\p{Blk=chakma}', "");
Expect(1, 69968, '\p{^Blk=chakma}', "");
Expect(1, 69968, '\P{Blk=chakma}', "");
Expect(0, 69968, '\P{^Blk=chakma}', "");
Expect(1, 69967, '\p{Blk=-Chakma}', "");
Expect(0, 69967, '\p{^Blk=-Chakma}', "");
Expect(0, 69967, '\P{Blk=-Chakma}', "");
Expect(1, 69967, '\P{^Blk=-Chakma}', "");
Expect(0, 69968, '\p{Blk=-Chakma}', "");
Expect(1, 69968, '\p{^Blk=-Chakma}', "");
Expect(1, 69968, '\P{Blk=-Chakma}', "");
Expect(0, 69968, '\P{^Blk=-Chakma}', "");
Error('\p{Is_Block=_CHAKMA:=}');
Error('\P{Is_Block=_CHAKMA:=}');
Expect(1, 69967, '\p{Is_Block=chakma}', "");
Expect(0, 69967, '\p{^Is_Block=chakma}', "");
Expect(0, 69967, '\P{Is_Block=chakma}', "");
Expect(1, 69967, '\P{^Is_Block=chakma}', "");
Expect(0, 69968, '\p{Is_Block=chakma}', "");
Expect(1, 69968, '\p{^Is_Block=chakma}', "");
Expect(1, 69968, '\P{Is_Block=chakma}', "");
Expect(0, 69968, '\P{^Is_Block=chakma}', "");
Expect(1, 69967, '\p{Is_Block=-	chakma}', "");
Expect(0, 69967, '\p{^Is_Block=-	chakma}', "");
Expect(0, 69967, '\P{Is_Block=-	chakma}', "");
Expect(1, 69967, '\P{^Is_Block=-	chakma}', "");
Expect(0, 69968, '\p{Is_Block=-	chakma}', "");
Expect(1, 69968, '\p{^Is_Block=-	chakma}', "");
Expect(1, 69968, '\P{Is_Block=-	chakma}', "");
Expect(0, 69968, '\P{^Is_Block=-	chakma}', "");
Error('\p{Is_Blk= CHAKMA/a/}');
Error('\P{Is_Blk= CHAKMA/a/}');
Expect(1, 69967, '\p{Is_Blk=chakma}', "");
Expect(0, 69967, '\p{^Is_Blk=chakma}', "");
Expect(0, 69967, '\P{Is_Blk=chakma}', "");
Expect(1, 69967, '\P{^Is_Blk=chakma}', "");
Expect(0, 69968, '\p{Is_Blk=chakma}', "");
Expect(1, 69968, '\p{^Is_Blk=chakma}', "");
Expect(1, 69968, '\P{Is_Blk=chakma}', "");
Expect(0, 69968, '\P{^Is_Blk=chakma}', "");
Expect(1, 69967, '\p{Is_Blk=	 Chakma}', "");
Expect(0, 69967, '\p{^Is_Blk=	 Chakma}', "");
Expect(0, 69967, '\P{Is_Blk=	 Chakma}', "");
Expect(1, 69967, '\P{^Is_Blk=	 Chakma}', "");
Expect(0, 69968, '\p{Is_Blk=	 Chakma}', "");
Expect(1, 69968, '\p{^Is_Blk=	 Chakma}', "");
Expect(1, 69968, '\P{Is_Blk=	 Chakma}', "");
Expect(0, 69968, '\P{^Is_Blk=	 Chakma}', "");
Error('\p{Block=/a/ _Cham}');
Error('\P{Block=/a/ _Cham}');
Expect(1, 43615, '\p{Block:   cham}', "");
Expect(0, 43615, '\p{^Block:   cham}', "");
Expect(0, 43615, '\P{Block:   cham}', "");
Expect(1, 43615, '\P{^Block:   cham}', "");
Expect(0, 43616, '\p{Block:   cham}', "");
Expect(1, 43616, '\p{^Block:   cham}', "");
Expect(1, 43616, '\P{Block:   cham}', "");
Expect(0, 43616, '\P{^Block:   cham}', "");
Expect(1, 43615, '\p{Block=--Cham}', "");
Expect(0, 43615, '\p{^Block=--Cham}', "");
Expect(0, 43615, '\P{Block=--Cham}', "");
Expect(1, 43615, '\P{^Block=--Cham}', "");
Expect(0, 43616, '\p{Block=--Cham}', "");
Expect(1, 43616, '\p{^Block=--Cham}', "");
Expect(1, 43616, '\P{Block=--Cham}', "");
Expect(0, 43616, '\P{^Block=--Cham}', "");
Error('\p{Blk: /a/_-CHAM}');
Error('\P{Blk: /a/_-CHAM}');
Expect(1, 43615, '\p{Blk:	cham}', "");
Expect(0, 43615, '\p{^Blk:	cham}', "");
Expect(0, 43615, '\P{Blk:	cham}', "");
Expect(1, 43615, '\P{^Blk:	cham}', "");
Expect(0, 43616, '\p{Blk:	cham}', "");
Expect(1, 43616, '\p{^Blk:	cham}', "");
Expect(1, 43616, '\P{Blk:	cham}', "");
Expect(0, 43616, '\P{^Blk:	cham}', "");
Expect(1, 43615, '\p{Blk=		Cham}', "");
Expect(0, 43615, '\p{^Blk=		Cham}', "");
Expect(0, 43615, '\P{Blk=		Cham}', "");
Expect(1, 43615, '\P{^Blk=		Cham}', "");
Expect(0, 43616, '\p{Blk=		Cham}', "");
Expect(1, 43616, '\p{^Blk=		Cham}', "");
Expect(1, 43616, '\P{Blk=		Cham}', "");
Expect(0, 43616, '\P{^Blk=		Cham}', "");
Error('\p{Is_Block=-cham:=}');
Error('\P{Is_Block=-cham:=}');
Expect(1, 43615, '\p{Is_Block=cham}', "");
Expect(0, 43615, '\p{^Is_Block=cham}', "");
Expect(0, 43615, '\P{Is_Block=cham}', "");
Expect(1, 43615, '\P{^Is_Block=cham}', "");
Expect(0, 43616, '\p{Is_Block=cham}', "");
Expect(1, 43616, '\p{^Is_Block=cham}', "");
Expect(1, 43616, '\P{Is_Block=cham}', "");
Expect(0, 43616, '\P{^Is_Block=cham}', "");
Expect(1, 43615, '\p{Is_Block=	 Cham}', "");
Expect(0, 43615, '\p{^Is_Block=	 Cham}', "");
Expect(0, 43615, '\P{Is_Block=	 Cham}', "");
Expect(1, 43615, '\P{^Is_Block=	 Cham}', "");
Expect(0, 43616, '\p{Is_Block=	 Cham}', "");
Expect(1, 43616, '\p{^Is_Block=	 Cham}', "");
Expect(1, 43616, '\P{Is_Block=	 Cham}', "");
Expect(0, 43616, '\P{^Is_Block=	 Cham}', "");
Error('\p{Is_Blk= -Cham:=}');
Error('\P{Is_Blk= -Cham:=}');
Expect(1, 43615, '\p{Is_Blk=cham}', "");
Expect(0, 43615, '\p{^Is_Blk=cham}', "");
Expect(0, 43615, '\P{Is_Blk=cham}', "");
Expect(1, 43615, '\P{^Is_Blk=cham}', "");
Expect(0, 43616, '\p{Is_Blk=cham}', "");
Expect(1, 43616, '\p{^Is_Blk=cham}', "");
Expect(1, 43616, '\P{Is_Blk=cham}', "");
Expect(0, 43616, '\P{^Is_Blk=cham}', "");
Expect(1, 43615, '\p{Is_Blk=	-CHAM}', "");
Expect(0, 43615, '\p{^Is_Blk=	-CHAM}', "");
Expect(0, 43615, '\P{Is_Blk=	-CHAM}', "");
Expect(1, 43615, '\P{^Is_Blk=	-CHAM}', "");
Expect(0, 43616, '\p{Is_Blk=	-CHAM}', "");
Expect(1, 43616, '\p{^Is_Blk=	-CHAM}', "");
Expect(1, 43616, '\P{Is_Blk=	-CHAM}', "");
Expect(0, 43616, '\P{^Is_Blk=	-CHAM}', "");
Error('\p{Block=:=  Cherokee}');
Error('\P{Block=:=  Cherokee}');
Expect(1, 5119, '\p{Block=cherokee}', "");
Expect(0, 5119, '\p{^Block=cherokee}', "");
Expect(0, 5119, '\P{Block=cherokee}', "");
Expect(1, 5119, '\P{^Block=cherokee}', "");
Expect(0, 5120, '\p{Block=cherokee}', "");
Expect(1, 5120, '\p{^Block=cherokee}', "");
Expect(1, 5120, '\P{Block=cherokee}', "");
Expect(0, 5120, '\P{^Block=cherokee}', "");
Expect(1, 5119, '\p{Block=__Cherokee}', "");
Expect(0, 5119, '\p{^Block=__Cherokee}', "");
Expect(0, 5119, '\P{Block=__Cherokee}', "");
Expect(1, 5119, '\P{^Block=__Cherokee}', "");
Expect(0, 5120, '\p{Block=__Cherokee}', "");
Expect(1, 5120, '\p{^Block=__Cherokee}', "");
Expect(1, 5120, '\P{Block=__Cherokee}', "");
Expect(0, 5120, '\P{^Block=__Cherokee}', "");
Error('\p{Blk=_ Cherokee/a/}');
Error('\P{Blk=_ Cherokee/a/}');
Expect(1, 5119, '\p{Blk=cherokee}', "");
Expect(0, 5119, '\p{^Blk=cherokee}', "");
Expect(0, 5119, '\P{Blk=cherokee}', "");
Expect(1, 5119, '\P{^Blk=cherokee}', "");
Expect(0, 5120, '\p{Blk=cherokee}', "");
Expect(1, 5120, '\p{^Blk=cherokee}', "");
Expect(1, 5120, '\P{Blk=cherokee}', "");
Expect(0, 5120, '\P{^Blk=cherokee}', "");
Expect(1, 5119, '\p{Blk=-_CHEROKEE}', "");
Expect(0, 5119, '\p{^Blk=-_CHEROKEE}', "");
Expect(0, 5119, '\P{Blk=-_CHEROKEE}', "");
Expect(1, 5119, '\P{^Blk=-_CHEROKEE}', "");
Expect(0, 5120, '\p{Blk=-_CHEROKEE}', "");
Expect(1, 5120, '\p{^Blk=-_CHEROKEE}', "");
Expect(1, 5120, '\P{Blk=-_CHEROKEE}', "");
Expect(0, 5120, '\P{^Blk=-_CHEROKEE}', "");
Error('\p{Is_Block=	_Cherokee/a/}');
Error('\P{Is_Block=	_Cherokee/a/}');
Expect(1, 5119, '\p{Is_Block:   cherokee}', "");
Expect(0, 5119, '\p{^Is_Block:   cherokee}', "");
Expect(0, 5119, '\P{Is_Block:   cherokee}', "");
Expect(1, 5119, '\P{^Is_Block:   cherokee}', "");
Expect(0, 5120, '\p{Is_Block:   cherokee}', "");
Expect(1, 5120, '\p{^Is_Block:   cherokee}', "");
Expect(1, 5120, '\P{Is_Block:   cherokee}', "");
Expect(0, 5120, '\P{^Is_Block:   cherokee}', "");
Expect(1, 5119, '\p{Is_Block=_cherokee}', "");
Expect(0, 5119, '\p{^Is_Block=_cherokee}', "");
Expect(0, 5119, '\P{Is_Block=_cherokee}', "");
Expect(1, 5119, '\P{^Is_Block=_cherokee}', "");
Expect(0, 5120, '\p{Is_Block=_cherokee}', "");
Expect(1, 5120, '\p{^Is_Block=_cherokee}', "");
Expect(1, 5120, '\P{Is_Block=_cherokee}', "");
Expect(0, 5120, '\P{^Is_Block=_cherokee}', "");
Error('\p{Is_Blk=:=_-CHEROKEE}');
Error('\P{Is_Blk=:=_-CHEROKEE}');
Expect(1, 5119, '\p{Is_Blk=cherokee}', "");
Expect(0, 5119, '\p{^Is_Blk=cherokee}', "");
Expect(0, 5119, '\P{Is_Blk=cherokee}', "");
Expect(1, 5119, '\P{^Is_Blk=cherokee}', "");
Expect(0, 5120, '\p{Is_Blk=cherokee}', "");
Expect(1, 5120, '\p{^Is_Blk=cherokee}', "");
Expect(1, 5120, '\P{Is_Blk=cherokee}', "");
Expect(0, 5120, '\P{^Is_Blk=cherokee}', "");
Expect(1, 5119, '\p{Is_Blk=_Cherokee}', "");
Expect(0, 5119, '\p{^Is_Blk=_Cherokee}', "");
Expect(0, 5119, '\P{Is_Blk=_Cherokee}', "");
Expect(1, 5119, '\P{^Is_Blk=_Cherokee}', "");
Expect(0, 5120, '\p{Is_Blk=_Cherokee}', "");
Expect(1, 5120, '\p{^Is_Blk=_Cherokee}', "");
Expect(1, 5120, '\P{Is_Blk=_Cherokee}', "");
Expect(0, 5120, '\P{^Is_Blk=_Cherokee}', "");
Error('\p{Block= 	Hangul_COMPATIBILITY_Jamo:=}');
Error('\P{Block= 	Hangul_COMPATIBILITY_Jamo:=}');
Expect(1, 12687, '\p{Block=hangulcompatibilityjamo}', "");
Expect(0, 12687, '\p{^Block=hangulcompatibilityjamo}', "");
Expect(0, 12687, '\P{Block=hangulcompatibilityjamo}', "");
Expect(1, 12687, '\P{^Block=hangulcompatibilityjamo}', "");
Expect(0, 12688, '\p{Block=hangulcompatibilityjamo}', "");
Expect(1, 12688, '\p{^Block=hangulcompatibilityjamo}', "");
Expect(1, 12688, '\P{Block=hangulcompatibilityjamo}', "");
Expect(0, 12688, '\P{^Block=hangulcompatibilityjamo}', "");
Expect(1, 12687, '\p{Block=	 Hangul_compatibility_Jamo}', "");
Expect(0, 12687, '\p{^Block=	 Hangul_compatibility_Jamo}', "");
Expect(0, 12687, '\P{Block=	 Hangul_compatibility_Jamo}', "");
Expect(1, 12687, '\P{^Block=	 Hangul_compatibility_Jamo}', "");
Expect(0, 12688, '\p{Block=	 Hangul_compatibility_Jamo}', "");
Expect(1, 12688, '\p{^Block=	 Hangul_compatibility_Jamo}', "");
Expect(1, 12688, '\P{Block=	 Hangul_compatibility_Jamo}', "");
Expect(0, 12688, '\P{^Block=	 Hangul_compatibility_Jamo}', "");
Error('\p{Blk=:=	Compat_JAMO}');
Error('\P{Blk=:=	Compat_JAMO}');
Expect(1, 12687, '\p{Blk=compatjamo}', "");
Expect(0, 12687, '\p{^Blk=compatjamo}', "");
Expect(0, 12687, '\P{Blk=compatjamo}', "");
Expect(1, 12687, '\P{^Blk=compatjamo}', "");
Expect(0, 12688, '\p{Blk=compatjamo}', "");
Expect(1, 12688, '\p{^Blk=compatjamo}', "");
Expect(1, 12688, '\P{Blk=compatjamo}', "");
Expect(0, 12688, '\P{^Blk=compatjamo}', "");
Expect(1, 12687, '\p{Blk=- Compat_Jamo}', "");
Expect(0, 12687, '\p{^Blk=- Compat_Jamo}', "");
Expect(0, 12687, '\P{Blk=- Compat_Jamo}', "");
Expect(1, 12687, '\P{^Blk=- Compat_Jamo}', "");
Expect(0, 12688, '\p{Blk=- Compat_Jamo}', "");
Expect(1, 12688, '\p{^Blk=- Compat_Jamo}', "");
Expect(1, 12688, '\P{Blk=- Compat_Jamo}', "");
Expect(0, 12688, '\P{^Blk=- Compat_Jamo}', "");
Error('\p{Is_Block=/a/ HANGUL_compatibility_JAMO}');
Error('\P{Is_Block=/a/ HANGUL_compatibility_JAMO}');
Expect(1, 12687, '\p{Is_Block=hangulcompatibilityjamo}', "");
Expect(0, 12687, '\p{^Is_Block=hangulcompatibilityjamo}', "");
Expect(0, 12687, '\P{Is_Block=hangulcompatibilityjamo}', "");
Expect(1, 12687, '\P{^Is_Block=hangulcompatibilityjamo}', "");
Expect(0, 12688, '\p{Is_Block=hangulcompatibilityjamo}', "");
Expect(1, 12688, '\p{^Is_Block=hangulcompatibilityjamo}', "");
Expect(1, 12688, '\P{Is_Block=hangulcompatibilityjamo}', "");
Expect(0, 12688, '\P{^Is_Block=hangulcompatibilityjamo}', "");
Expect(1, 12687, '\p{Is_Block=	-Hangul_compatibility_Jamo}', "");
Expect(0, 12687, '\p{^Is_Block=	-Hangul_compatibility_Jamo}', "");
Expect(0, 12687, '\P{Is_Block=	-Hangul_compatibility_Jamo}', "");
Expect(1, 12687, '\P{^Is_Block=	-Hangul_compatibility_Jamo}', "");
Expect(0, 12688, '\p{Is_Block=	-Hangul_compatibility_Jamo}', "");
Expect(1, 12688, '\p{^Is_Block=	-Hangul_compatibility_Jamo}', "");
Expect(1, 12688, '\P{Is_Block=	-Hangul_compatibility_Jamo}', "");
Expect(0, 12688, '\P{^Is_Block=	-Hangul_compatibility_Jamo}', "");
Error('\p{Is_Blk= :=Compat_JAMO}');
Error('\P{Is_Blk= :=Compat_JAMO}');
Expect(1, 12687, '\p{Is_Blk=compatjamo}', "");
Expect(0, 12687, '\p{^Is_Blk=compatjamo}', "");
Expect(0, 12687, '\P{Is_Blk=compatjamo}', "");
Expect(1, 12687, '\P{^Is_Blk=compatjamo}', "");
Expect(0, 12688, '\p{Is_Blk=compatjamo}', "");
Expect(1, 12688, '\p{^Is_Blk=compatjamo}', "");
Expect(1, 12688, '\P{Is_Blk=compatjamo}', "");
Expect(0, 12688, '\P{^Is_Blk=compatjamo}', "");
Expect(1, 12687, '\p{Is_Blk=-Compat_Jamo}', "");
Expect(0, 12687, '\p{^Is_Blk=-Compat_Jamo}', "");
Expect(0, 12687, '\P{Is_Blk=-Compat_Jamo}', "");
Expect(1, 12687, '\P{^Is_Blk=-Compat_Jamo}', "");
Expect(0, 12688, '\p{Is_Blk=-Compat_Jamo}', "");
Expect(1, 12688, '\p{^Is_Blk=-Compat_Jamo}', "");
Expect(1, 12688, '\P{Is_Blk=-Compat_Jamo}', "");
Expect(0, 12688, '\P{^Is_Blk=-Compat_Jamo}', "");
Error('\p{Block= :=Control_Pictures}');
Error('\P{Block= :=Control_Pictures}');
Expect(1, 9279, '\p{Block=controlpictures}', "");
Expect(0, 9279, '\p{^Block=controlpictures}', "");
Expect(0, 9279, '\P{Block=controlpictures}', "");
Expect(1, 9279, '\P{^Block=controlpictures}', "");
Expect(0, 9280, '\p{Block=controlpictures}', "");
Expect(1, 9280, '\p{^Block=controlpictures}', "");
Expect(1, 9280, '\P{Block=controlpictures}', "");
Expect(0, 9280, '\P{^Block=controlpictures}', "");
Expect(1, 9279, '\p{Block=_CONTROL_pictures}', "");
Expect(0, 9279, '\p{^Block=_CONTROL_pictures}', "");
Expect(0, 9279, '\P{Block=_CONTROL_pictures}', "");
Expect(1, 9279, '\P{^Block=_CONTROL_pictures}', "");
Expect(0, 9280, '\p{Block=_CONTROL_pictures}', "");
Expect(1, 9280, '\p{^Block=_CONTROL_pictures}', "");
Expect(1, 9280, '\P{Block=_CONTROL_pictures}', "");
Expect(0, 9280, '\P{^Block=_CONTROL_pictures}', "");
Error('\p{Blk=_Control_Pictures/a/}');
Error('\P{Blk=_Control_Pictures/a/}');
Expect(1, 9279, '\p{Blk=controlpictures}', "");
Expect(0, 9279, '\p{^Blk=controlpictures}', "");
Expect(0, 9279, '\P{Blk=controlpictures}', "");
Expect(1, 9279, '\P{^Blk=controlpictures}', "");
Expect(0, 9280, '\p{Blk=controlpictures}', "");
Expect(1, 9280, '\p{^Blk=controlpictures}', "");
Expect(1, 9280, '\P{Blk=controlpictures}', "");
Expect(0, 9280, '\P{^Blk=controlpictures}', "");
Expect(1, 9279, '\p{Blk=_ Control_Pictures}', "");
Expect(0, 9279, '\p{^Blk=_ Control_Pictures}', "");
Expect(0, 9279, '\P{Blk=_ Control_Pictures}', "");
Expect(1, 9279, '\P{^Blk=_ Control_Pictures}', "");
Expect(0, 9280, '\p{Blk=_ Control_Pictures}', "");
Expect(1, 9280, '\p{^Blk=_ Control_Pictures}', "");
Expect(1, 9280, '\P{Blk=_ Control_Pictures}', "");
Expect(0, 9280, '\P{^Blk=_ Control_Pictures}', "");
Error('\p{Is_Block=__Control_Pictures:=}');
Error('\P{Is_Block=__Control_Pictures:=}');
Expect(1, 9279, '\p{Is_Block=controlpictures}', "");
Expect(0, 9279, '\p{^Is_Block=controlpictures}', "");
Expect(0, 9279, '\P{Is_Block=controlpictures}', "");
Expect(1, 9279, '\P{^Is_Block=controlpictures}', "");
Expect(0, 9280, '\p{Is_Block=controlpictures}', "");
Expect(1, 9280, '\p{^Is_Block=controlpictures}', "");
Expect(1, 9280, '\P{Is_Block=controlpictures}', "");
Expect(0, 9280, '\P{^Is_Block=controlpictures}', "");
Expect(1, 9279, '\p{Is_Block=_control_Pictures}', "");
Expect(0, 9279, '\p{^Is_Block=_control_Pictures}', "");
Expect(0, 9279, '\P{Is_Block=_control_Pictures}', "");
Expect(1, 9279, '\P{^Is_Block=_control_Pictures}', "");
Expect(0, 9280, '\p{Is_Block=_control_Pictures}', "");
Expect(1, 9280, '\p{^Is_Block=_control_Pictures}', "");
Expect(1, 9280, '\P{Is_Block=_control_Pictures}', "");
Expect(0, 9280, '\P{^Is_Block=_control_Pictures}', "");
Error('\p{Is_Blk=:=-	CONTROL_Pictures}');
Error('\P{Is_Blk=:=-	CONTROL_Pictures}');
Expect(1, 9279, '\p{Is_Blk=controlpictures}', "");
Expect(0, 9279, '\p{^Is_Blk=controlpictures}', "");
Expect(0, 9279, '\P{Is_Blk=controlpictures}', "");
Expect(1, 9279, '\P{^Is_Blk=controlpictures}', "");
Expect(0, 9280, '\p{Is_Blk=controlpictures}', "");
Expect(1, 9280, '\p{^Is_Blk=controlpictures}', "");
Expect(1, 9280, '\P{Is_Blk=controlpictures}', "");
Expect(0, 9280, '\P{^Is_Blk=controlpictures}', "");
Expect(1, 9279, '\p{Is_Blk=-Control_pictures}', "");
Expect(0, 9279, '\p{^Is_Blk=-Control_pictures}', "");
Expect(0, 9279, '\P{Is_Blk=-Control_pictures}', "");
Expect(1, 9279, '\P{^Is_Blk=-Control_pictures}', "");
Expect(0, 9280, '\p{Is_Blk=-Control_pictures}', "");
Expect(1, 9280, '\p{^Is_Blk=-Control_pictures}', "");
Expect(1, 9280, '\P{Is_Blk=-Control_pictures}', "");
Expect(0, 9280, '\P{^Is_Blk=-Control_pictures}', "");
Error('\p{Block=	_coptic:=}');
Error('\P{Block=	_coptic:=}');
Expect(1, 11519, '\p{Block=coptic}', "");
Expect(0, 11519, '\p{^Block=coptic}', "");
Expect(0, 11519, '\P{Block=coptic}', "");
Expect(1, 11519, '\P{^Block=coptic}', "");
Expect(0, 11520, '\p{Block=coptic}', "");
Expect(1, 11520, '\p{^Block=coptic}', "");
Expect(1, 11520, '\P{Block=coptic}', "");
Expect(0, 11520, '\P{^Block=coptic}', "");
Expect(1, 11519, '\p{Block=		coptic}', "");
Expect(0, 11519, '\p{^Block=		coptic}', "");
Expect(0, 11519, '\P{Block=		coptic}', "");
Expect(1, 11519, '\P{^Block=		coptic}', "");
Expect(0, 11520, '\p{Block=		coptic}', "");
Expect(1, 11520, '\p{^Block=		coptic}', "");
Expect(1, 11520, '\P{Block=		coptic}', "");
Expect(0, 11520, '\P{^Block=		coptic}', "");
Error('\p{Blk=_-coptic:=}');
Error('\P{Blk=_-coptic:=}');
Expect(1, 11519, '\p{Blk=coptic}', "");
Expect(0, 11519, '\p{^Blk=coptic}', "");
Expect(0, 11519, '\P{Blk=coptic}', "");
Expect(1, 11519, '\P{^Blk=coptic}', "");
Expect(0, 11520, '\p{Blk=coptic}', "");
Expect(1, 11520, '\p{^Blk=coptic}', "");
Expect(1, 11520, '\P{Blk=coptic}', "");
Expect(0, 11520, '\P{^Blk=coptic}', "");
Expect(1, 11519, '\p{Blk=		COPTIC}', "");
Expect(0, 11519, '\p{^Blk=		COPTIC}', "");
Expect(0, 11519, '\P{Blk=		COPTIC}', "");
Expect(1, 11519, '\P{^Blk=		COPTIC}', "");
Expect(0, 11520, '\p{Blk=		COPTIC}', "");
Expect(1, 11520, '\p{^Blk=		COPTIC}', "");
Expect(1, 11520, '\P{Blk=		COPTIC}', "");
Expect(0, 11520, '\P{^Blk=		COPTIC}', "");
Error('\p{Is_Block=:=	Coptic}');
Error('\P{Is_Block=:=	Coptic}');
Expect(1, 11519, '\p{Is_Block:   coptic}', "");
Expect(0, 11519, '\p{^Is_Block:   coptic}', "");
Expect(0, 11519, '\P{Is_Block:   coptic}', "");
Expect(1, 11519, '\P{^Is_Block:   coptic}', "");
Expect(0, 11520, '\p{Is_Block:   coptic}', "");
Expect(1, 11520, '\p{^Is_Block:   coptic}', "");
Expect(1, 11520, '\P{Is_Block:   coptic}', "");
Expect(0, 11520, '\P{^Is_Block:   coptic}', "");
Expect(1, 11519, '\p{Is_Block=-COPTIC}', "");
Expect(0, 11519, '\p{^Is_Block=-COPTIC}', "");
Expect(0, 11519, '\P{Is_Block=-COPTIC}', "");
Expect(1, 11519, '\P{^Is_Block=-COPTIC}', "");
Expect(0, 11520, '\p{Is_Block=-COPTIC}', "");
Expect(1, 11520, '\p{^Is_Block=-COPTIC}', "");
Expect(1, 11520, '\P{Is_Block=-COPTIC}', "");
Expect(0, 11520, '\P{^Is_Block=-COPTIC}', "");
Error('\p{Is_Blk=:=- Coptic}');
Error('\P{Is_Blk=:=- Coptic}');
Expect(1, 11519, '\p{Is_Blk=coptic}', "");
Expect(0, 11519, '\p{^Is_Blk=coptic}', "");
Expect(0, 11519, '\P{Is_Blk=coptic}', "");
Expect(1, 11519, '\P{^Is_Blk=coptic}', "");
Expect(0, 11520, '\p{Is_Blk=coptic}', "");
Expect(1, 11520, '\p{^Is_Blk=coptic}', "");
Expect(1, 11520, '\P{Is_Blk=coptic}', "");
Expect(0, 11520, '\P{^Is_Blk=coptic}', "");
Expect(1, 11519, '\p{Is_Blk=		Coptic}', "");
Expect(0, 11519, '\p{^Is_Blk=		Coptic}', "");
Expect(0, 11519, '\P{Is_Blk=		Coptic}', "");
Expect(1, 11519, '\P{^Is_Blk=		Coptic}', "");
Expect(0, 11520, '\p{Is_Blk=		Coptic}', "");
Expect(1, 11520, '\p{^Is_Blk=		Coptic}', "");
Expect(1, 11520, '\P{Is_Blk=		Coptic}', "");
Expect(0, 11520, '\P{^Is_Blk=		Coptic}', "");
Error('\p{Block=/a/-Counting_rod_Numerals}');
Error('\P{Block=/a/-Counting_rod_Numerals}');
Expect(1, 119679, '\p{Block=countingrodnumerals}', "");
Expect(0, 119679, '\p{^Block=countingrodnumerals}', "");
Expect(0, 119679, '\P{Block=countingrodnumerals}', "");
Expect(1, 119679, '\P{^Block=countingrodnumerals}', "");
Expect(0, 119680, '\p{Block=countingrodnumerals}', "");
Expect(1, 119680, '\p{^Block=countingrodnumerals}', "");
Expect(1, 119680, '\P{Block=countingrodnumerals}', "");
Expect(0, 119680, '\P{^Block=countingrodnumerals}', "");
Expect(1, 119679, '\p{Block: _Counting_Rod_NUMERALS}', "");
Expect(0, 119679, '\p{^Block: _Counting_Rod_NUMERALS}', "");
Expect(0, 119679, '\P{Block: _Counting_Rod_NUMERALS}', "");
Expect(1, 119679, '\P{^Block: _Counting_Rod_NUMERALS}', "");
Expect(0, 119680, '\p{Block: _Counting_Rod_NUMERALS}', "");
Expect(1, 119680, '\p{^Block: _Counting_Rod_NUMERALS}', "");
Expect(1, 119680, '\P{Block: _Counting_Rod_NUMERALS}', "");
Expect(0, 119680, '\P{^Block: _Counting_Rod_NUMERALS}', "");
Error('\p{Blk=-_Counting_ROD/a/}');
Error('\P{Blk=-_Counting_ROD/a/}');
Expect(1, 119679, '\p{Blk=countingrod}', "");
Expect(0, 119679, '\p{^Blk=countingrod}', "");
Expect(0, 119679, '\P{Blk=countingrod}', "");
Expect(1, 119679, '\P{^Blk=countingrod}', "");
Expect(0, 119680, '\p{Blk=countingrod}', "");
Expect(1, 119680, '\p{^Blk=countingrod}', "");
Expect(1, 119680, '\P{Blk=countingrod}', "");
Expect(0, 119680, '\P{^Blk=countingrod}', "");
Expect(1, 119679, '\p{Blk= Counting_Rod}', "");
Expect(0, 119679, '\p{^Blk= Counting_Rod}', "");
Expect(0, 119679, '\P{Blk= Counting_Rod}', "");
Expect(1, 119679, '\P{^Blk= Counting_Rod}', "");
Expect(0, 119680, '\p{Blk= Counting_Rod}', "");
Expect(1, 119680, '\p{^Blk= Counting_Rod}', "");
Expect(1, 119680, '\P{Blk= Counting_Rod}', "");
Expect(0, 119680, '\P{^Blk= Counting_Rod}', "");
Error('\p{Is_Block:	Counting_Rod_Numerals/a/}');
Error('\P{Is_Block:	Counting_Rod_Numerals/a/}');
Expect(1, 119679, '\p{Is_Block=countingrodnumerals}', "");
Expect(0, 119679, '\p{^Is_Block=countingrodnumerals}', "");
Expect(0, 119679, '\P{Is_Block=countingrodnumerals}', "");
Expect(1, 119679, '\P{^Is_Block=countingrodnumerals}', "");
Expect(0, 119680, '\p{Is_Block=countingrodnumerals}', "");
Expect(1, 119680, '\p{^Is_Block=countingrodnumerals}', "");
Expect(1, 119680, '\P{Is_Block=countingrodnumerals}', "");
Expect(0, 119680, '\P{^Is_Block=countingrodnumerals}', "");
Expect(1, 119679, '\p{Is_Block=_	counting_ROD_Numerals}', "");
Expect(0, 119679, '\p{^Is_Block=_	counting_ROD_Numerals}', "");
Expect(0, 119679, '\P{Is_Block=_	counting_ROD_Numerals}', "");
Expect(1, 119679, '\P{^Is_Block=_	counting_ROD_Numerals}', "");
Expect(0, 119680, '\p{Is_Block=_	counting_ROD_Numerals}', "");
Expect(1, 119680, '\p{^Is_Block=_	counting_ROD_Numerals}', "");
Expect(1, 119680, '\P{Is_Block=_	counting_ROD_Numerals}', "");
Expect(0, 119680, '\P{^Is_Block=_	counting_ROD_Numerals}', "");
Error('\p{Is_Blk=/a/Counting_Rod}');
Error('\P{Is_Blk=/a/Counting_Rod}');
Expect(1, 119679, '\p{Is_Blk=countingrod}', "");
Expect(0, 119679, '\p{^Is_Blk=countingrod}', "");
Expect(0, 119679, '\P{Is_Blk=countingrod}', "");
Expect(1, 119679, '\P{^Is_Blk=countingrod}', "");
Expect(0, 119680, '\p{Is_Blk=countingrod}', "");
Expect(1, 119680, '\p{^Is_Blk=countingrod}', "");
Expect(1, 119680, '\P{Is_Blk=countingrod}', "");
Expect(0, 119680, '\P{^Is_Blk=countingrod}', "");
Expect(1, 119679, '\p{Is_Blk=- Counting_Rod}', "");
Expect(0, 119679, '\p{^Is_Blk=- Counting_Rod}', "");
Expect(0, 119679, '\P{Is_Blk=- Counting_Rod}', "");
Expect(1, 119679, '\P{^Is_Blk=- Counting_Rod}', "");
Expect(0, 119680, '\p{Is_Blk=- Counting_Rod}', "");
Expect(1, 119680, '\p{^Is_Blk=- Counting_Rod}', "");
Expect(1, 119680, '\P{Is_Blk=- Counting_Rod}', "");
Expect(0, 119680, '\P{^Is_Blk=- Counting_Rod}', "");
Error('\p{Block=--CUNEIFORM/a/}');
Error('\P{Block=--CUNEIFORM/a/}');
Expect(1, 74751, '\p{Block=cuneiform}', "");
Expect(0, 74751, '\p{^Block=cuneiform}', "");
Expect(0, 74751, '\P{Block=cuneiform}', "");
Expect(1, 74751, '\P{^Block=cuneiform}', "");
Expect(0, 74752, '\p{Block=cuneiform}', "");
Expect(1, 74752, '\p{^Block=cuneiform}', "");
Expect(1, 74752, '\P{Block=cuneiform}', "");
Expect(0, 74752, '\P{^Block=cuneiform}', "");
Expect(1, 74751, '\p{Block=-CUNEIFORM}', "");
Expect(0, 74751, '\p{^Block=-CUNEIFORM}', "");
Expect(0, 74751, '\P{Block=-CUNEIFORM}', "");
Expect(1, 74751, '\P{^Block=-CUNEIFORM}', "");
Expect(0, 74752, '\p{Block=-CUNEIFORM}', "");
Expect(1, 74752, '\p{^Block=-CUNEIFORM}', "");
Expect(1, 74752, '\P{Block=-CUNEIFORM}', "");
Expect(0, 74752, '\P{^Block=-CUNEIFORM}', "");
Error('\p{Blk=/a/ -CUNEIFORM}');
Error('\P{Blk=/a/ -CUNEIFORM}');
Expect(1, 74751, '\p{Blk=cuneiform}', "");
Expect(0, 74751, '\p{^Blk=cuneiform}', "");
Expect(0, 74751, '\P{Blk=cuneiform}', "");
Expect(1, 74751, '\P{^Blk=cuneiform}', "");
Expect(0, 74752, '\p{Blk=cuneiform}', "");
Expect(1, 74752, '\p{^Blk=cuneiform}', "");
Expect(1, 74752, '\P{Blk=cuneiform}', "");
Expect(0, 74752, '\P{^Blk=cuneiform}', "");
Expect(1, 74751, '\p{Blk=_Cuneiform}', "");
Expect(0, 74751, '\p{^Blk=_Cuneiform}', "");
Expect(0, 74751, '\P{Blk=_Cuneiform}', "");
Expect(1, 74751, '\P{^Blk=_Cuneiform}', "");
Expect(0, 74752, '\p{Blk=_Cuneiform}', "");
Expect(1, 74752, '\p{^Blk=_Cuneiform}', "");
Expect(1, 74752, '\P{Blk=_Cuneiform}', "");
Expect(0, 74752, '\P{^Blk=_Cuneiform}', "");
Error('\p{Is_Block=-:=CUNEIFORM}');
Error('\P{Is_Block=-:=CUNEIFORM}');
Expect(1, 74751, '\p{Is_Block=cuneiform}', "");
Expect(0, 74751, '\p{^Is_Block=cuneiform}', "");
Expect(0, 74751, '\P{Is_Block=cuneiform}', "");
Expect(1, 74751, '\P{^Is_Block=cuneiform}', "");
Expect(0, 74752, '\p{Is_Block=cuneiform}', "");
Expect(1, 74752, '\p{^Is_Block=cuneiform}', "");
Expect(1, 74752, '\P{Is_Block=cuneiform}', "");
Expect(0, 74752, '\P{^Is_Block=cuneiform}', "");
Expect(1, 74751, '\p{Is_Block=	Cuneiform}', "");
Expect(0, 74751, '\p{^Is_Block=	Cuneiform}', "");
Expect(0, 74751, '\P{Is_Block=	Cuneiform}', "");
Expect(1, 74751, '\P{^Is_Block=	Cuneiform}', "");
Expect(0, 74752, '\p{Is_Block=	Cuneiform}', "");
Expect(1, 74752, '\p{^Is_Block=	Cuneiform}', "");
Expect(1, 74752, '\P{Is_Block=	Cuneiform}', "");
Expect(0, 74752, '\P{^Is_Block=	Cuneiform}', "");
Error('\p{Is_Blk=-Cuneiform/a/}');
Error('\P{Is_Blk=-Cuneiform/a/}');
Expect(1, 74751, '\p{Is_Blk=cuneiform}', "");
Expect(0, 74751, '\p{^Is_Blk=cuneiform}', "");
Expect(0, 74751, '\P{Is_Blk=cuneiform}', "");
Expect(1, 74751, '\P{^Is_Blk=cuneiform}', "");
Expect(0, 74752, '\p{Is_Blk=cuneiform}', "");
Expect(1, 74752, '\p{^Is_Blk=cuneiform}', "");
Expect(1, 74752, '\P{Is_Blk=cuneiform}', "");
Expect(0, 74752, '\P{^Is_Blk=cuneiform}', "");
Expect(1, 74751, '\p{Is_Blk=_ Cuneiform}', "");
Expect(0, 74751, '\p{^Is_Blk=_ Cuneiform}', "");
Expect(0, 74751, '\P{Is_Blk=_ Cuneiform}', "");
Expect(1, 74751, '\P{^Is_Blk=_ Cuneiform}', "");
Expect(0, 74752, '\p{Is_Blk=_ Cuneiform}', "");
Expect(1, 74752, '\p{^Is_Blk=_ Cuneiform}', "");
Expect(1, 74752, '\P{Is_Blk=_ Cuneiform}', "");
Expect(0, 74752, '\P{^Is_Blk=_ Cuneiform}', "");
Error('\p{Block=:=		cuneiform_numbers_and_punctuation}');
Error('\P{Block=:=		cuneiform_numbers_and_punctuation}');
Expect(1, 74879, '\p{Block=cuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\p{^Block=cuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\P{Block=cuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\P{^Block=cuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\p{Block=cuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\p{^Block=cuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\P{Block=cuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\P{^Block=cuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\p{Block=-	cuneiform_NUMBERS_And_PUNCTUATION}', "");
Expect(0, 74879, '\p{^Block=-	cuneiform_NUMBERS_And_PUNCTUATION}', "");
Expect(0, 74879, '\P{Block=-	cuneiform_NUMBERS_And_PUNCTUATION}', "");
Expect(1, 74879, '\P{^Block=-	cuneiform_NUMBERS_And_PUNCTUATION}', "");
Expect(0, 74880, '\p{Block=-	cuneiform_NUMBERS_And_PUNCTUATION}', "");
Expect(1, 74880, '\p{^Block=-	cuneiform_NUMBERS_And_PUNCTUATION}', "");
Expect(1, 74880, '\P{Block=-	cuneiform_NUMBERS_And_PUNCTUATION}', "");
Expect(0, 74880, '\P{^Block=-	cuneiform_NUMBERS_And_PUNCTUATION}', "");
Error('\p{Blk=:=-Cuneiform_Numbers}');
Error('\P{Blk=:=-Cuneiform_Numbers}');
Expect(1, 74879, '\p{Blk=cuneiformnumbers}', "");
Expect(0, 74879, '\p{^Blk=cuneiformnumbers}', "");
Expect(0, 74879, '\P{Blk=cuneiformnumbers}', "");
Expect(1, 74879, '\P{^Blk=cuneiformnumbers}', "");
Expect(0, 74880, '\p{Blk=cuneiformnumbers}', "");
Expect(1, 74880, '\p{^Blk=cuneiformnumbers}', "");
Expect(1, 74880, '\P{Blk=cuneiformnumbers}', "");
Expect(0, 74880, '\P{^Blk=cuneiformnumbers}', "");
Expect(1, 74879, '\p{Blk=_Cuneiform_NUMBERS}', "");
Expect(0, 74879, '\p{^Blk=_Cuneiform_NUMBERS}', "");
Expect(0, 74879, '\P{Blk=_Cuneiform_NUMBERS}', "");
Expect(1, 74879, '\P{^Blk=_Cuneiform_NUMBERS}', "");
Expect(0, 74880, '\p{Blk=_Cuneiform_NUMBERS}', "");
Expect(1, 74880, '\p{^Blk=_Cuneiform_NUMBERS}', "");
Expect(1, 74880, '\P{Blk=_Cuneiform_NUMBERS}', "");
Expect(0, 74880, '\P{^Blk=_Cuneiform_NUMBERS}', "");
Error('\p{Is_Block=:=-CUNEIFORM_NUMBERS_and_punctuation}');
Error('\P{Is_Block=:=-CUNEIFORM_NUMBERS_and_punctuation}');
Expect(1, 74879, '\p{Is_Block:	cuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\p{^Is_Block:	cuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\P{Is_Block:	cuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\P{^Is_Block:	cuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\p{Is_Block:	cuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\p{^Is_Block:	cuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\P{Is_Block:	cuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\P{^Is_Block:	cuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\p{Is_Block= 	Cuneiform_Numbers_And_Punctuation}', "");
Expect(0, 74879, '\p{^Is_Block= 	Cuneiform_Numbers_And_Punctuation}', "");
Expect(0, 74879, '\P{Is_Block= 	Cuneiform_Numbers_And_Punctuation}', "");
Expect(1, 74879, '\P{^Is_Block= 	Cuneiform_Numbers_And_Punctuation}', "");
Expect(0, 74880, '\p{Is_Block= 	Cuneiform_Numbers_And_Punctuation}', "");
Expect(1, 74880, '\p{^Is_Block= 	Cuneiform_Numbers_And_Punctuation}', "");
Expect(1, 74880, '\P{Is_Block= 	Cuneiform_Numbers_And_Punctuation}', "");
Expect(0, 74880, '\P{^Is_Block= 	Cuneiform_Numbers_And_Punctuation}', "");
Error('\p{Is_Blk= /a/Cuneiform_Numbers}');
Error('\P{Is_Blk= /a/Cuneiform_Numbers}');
Expect(1, 74879, '\p{Is_Blk: cuneiformnumbers}', "");
Expect(0, 74879, '\p{^Is_Blk: cuneiformnumbers}', "");
Expect(0, 74879, '\P{Is_Blk: cuneiformnumbers}', "");
Expect(1, 74879, '\P{^Is_Blk: cuneiformnumbers}', "");
Expect(0, 74880, '\p{Is_Blk: cuneiformnumbers}', "");
Expect(1, 74880, '\p{^Is_Blk: cuneiformnumbers}', "");
Expect(1, 74880, '\P{Is_Blk: cuneiformnumbers}', "");
Expect(0, 74880, '\P{^Is_Blk: cuneiformnumbers}', "");
Expect(1, 74879, '\p{Is_Blk=_	Cuneiform_NUMBERS}', "");
Expect(0, 74879, '\p{^Is_Blk=_	Cuneiform_NUMBERS}', "");
Expect(0, 74879, '\P{Is_Blk=_	Cuneiform_NUMBERS}', "");
Expect(1, 74879, '\P{^Is_Blk=_	Cuneiform_NUMBERS}', "");
Expect(0, 74880, '\p{Is_Blk=_	Cuneiform_NUMBERS}', "");
Expect(1, 74880, '\p{^Is_Blk=_	Cuneiform_NUMBERS}', "");
Expect(1, 74880, '\P{Is_Blk=_	Cuneiform_NUMBERS}', "");
Expect(0, 74880, '\P{^Is_Blk=_	Cuneiform_NUMBERS}', "");
Error('\p{Block=	-CURRENCY_symbols/a/}');
Error('\P{Block=	-CURRENCY_symbols/a/}');
Expect(1, 8399, '\p{Block=currencysymbols}', "");
Expect(0, 8399, '\p{^Block=currencysymbols}', "");
Expect(0, 8399, '\P{Block=currencysymbols}', "");
Expect(1, 8399, '\P{^Block=currencysymbols}', "");
Expect(0, 8400, '\p{Block=currencysymbols}', "");
Expect(1, 8400, '\p{^Block=currencysymbols}', "");
Expect(1, 8400, '\P{Block=currencysymbols}', "");
Expect(0, 8400, '\P{^Block=currencysymbols}', "");
Expect(1, 8399, '\p{Block= _Currency_Symbols}', "");
Expect(0, 8399, '\p{^Block= _Currency_Symbols}', "");
Expect(0, 8399, '\P{Block= _Currency_Symbols}', "");
Expect(1, 8399, '\P{^Block= _Currency_Symbols}', "");
Expect(0, 8400, '\p{Block= _Currency_Symbols}', "");
Expect(1, 8400, '\p{^Block= _Currency_Symbols}', "");
Expect(1, 8400, '\P{Block= _Currency_Symbols}', "");
Expect(0, 8400, '\P{^Block= _Currency_Symbols}', "");
Error('\p{Blk=	_Currency_Symbols:=}');
Error('\P{Blk=	_Currency_Symbols:=}');
Expect(1, 8399, '\p{Blk=currencysymbols}', "");
Expect(0, 8399, '\p{^Blk=currencysymbols}', "");
Expect(0, 8399, '\P{Blk=currencysymbols}', "");
Expect(1, 8399, '\P{^Blk=currencysymbols}', "");
Expect(0, 8400, '\p{Blk=currencysymbols}', "");
Expect(1, 8400, '\p{^Blk=currencysymbols}', "");
Expect(1, 8400, '\P{Blk=currencysymbols}', "");
Expect(0, 8400, '\P{^Blk=currencysymbols}', "");
Expect(1, 8399, '\p{Blk=	currency_SYMBOLS}', "");
Expect(0, 8399, '\p{^Blk=	currency_SYMBOLS}', "");
Expect(0, 8399, '\P{Blk=	currency_SYMBOLS}', "");
Expect(1, 8399, '\P{^Blk=	currency_SYMBOLS}', "");
Expect(0, 8400, '\p{Blk=	currency_SYMBOLS}', "");
Expect(1, 8400, '\p{^Blk=	currency_SYMBOLS}', "");
Expect(1, 8400, '\P{Blk=	currency_SYMBOLS}', "");
Expect(0, 8400, '\P{^Blk=	currency_SYMBOLS}', "");
Error('\p{Is_Block=:= -currency_SYMBOLS}');
Error('\P{Is_Block=:= -currency_SYMBOLS}');
Expect(1, 8399, '\p{Is_Block=currencysymbols}', "");
Expect(0, 8399, '\p{^Is_Block=currencysymbols}', "");
Expect(0, 8399, '\P{Is_Block=currencysymbols}', "");
Expect(1, 8399, '\P{^Is_Block=currencysymbols}', "");
Expect(0, 8400, '\p{Is_Block=currencysymbols}', "");
Expect(1, 8400, '\p{^Is_Block=currencysymbols}', "");
Expect(1, 8400, '\P{Is_Block=currencysymbols}', "");
Expect(0, 8400, '\P{^Is_Block=currencysymbols}', "");
Expect(1, 8399, '\p{Is_Block=  Currency_symbols}', "");
Expect(0, 8399, '\p{^Is_Block=  Currency_symbols}', "");
Expect(0, 8399, '\P{Is_Block=  Currency_symbols}', "");
Expect(1, 8399, '\P{^Is_Block=  Currency_symbols}', "");
Expect(0, 8400, '\p{Is_Block=  Currency_symbols}', "");
Expect(1, 8400, '\p{^Is_Block=  Currency_symbols}', "");
Expect(1, 8400, '\P{Is_Block=  Currency_symbols}', "");
Expect(0, 8400, '\P{^Is_Block=  Currency_symbols}', "");
Error('\p{Is_Blk= /a/CURRENCY_symbols}');
Error('\P{Is_Blk= /a/CURRENCY_symbols}');
Expect(1, 8399, '\p{Is_Blk=currencysymbols}', "");
Expect(0, 8399, '\p{^Is_Blk=currencysymbols}', "");
Expect(0, 8399, '\P{Is_Blk=currencysymbols}', "");
Expect(1, 8399, '\P{^Is_Blk=currencysymbols}', "");
Expect(0, 8400, '\p{Is_Blk=currencysymbols}', "");
Expect(1, 8400, '\p{^Is_Blk=currencysymbols}', "");
Expect(1, 8400, '\P{Is_Blk=currencysymbols}', "");
Expect(0, 8400, '\P{^Is_Blk=currencysymbols}', "");
Expect(1, 8399, '\p{Is_Blk=--Currency_symbols}', "");
Expect(0, 8399, '\p{^Is_Blk=--Currency_symbols}', "");
Expect(0, 8399, '\P{Is_Blk=--Currency_symbols}', "");
Expect(1, 8399, '\P{^Is_Blk=--Currency_symbols}', "");
Expect(0, 8400, '\p{Is_Blk=--Currency_symbols}', "");
Expect(1, 8400, '\p{^Is_Blk=--Currency_symbols}', "");
Expect(1, 8400, '\P{Is_Blk=--Currency_symbols}', "");
Expect(0, 8400, '\P{^Is_Blk=--Currency_symbols}', "");
Error('\p{Block=_/a/CYPRIOT_SYLLABARY}');
Error('\P{Block=_/a/CYPRIOT_SYLLABARY}');
Expect(1, 67647, '\p{Block=cypriotsyllabary}', "");
Expect(0, 67647, '\p{^Block=cypriotsyllabary}', "");
Expect(0, 67647, '\P{Block=cypriotsyllabary}', "");
Expect(1, 67647, '\P{^Block=cypriotsyllabary}', "");
Expect(0, 67648, '\p{Block=cypriotsyllabary}', "");
Expect(1, 67648, '\p{^Block=cypriotsyllabary}', "");
Expect(1, 67648, '\P{Block=cypriotsyllabary}', "");
Expect(0, 67648, '\P{^Block=cypriotsyllabary}', "");
Expect(1, 67647, '\p{Block=	_Cypriot_SYLLABARY}', "");
Expect(0, 67647, '\p{^Block=	_Cypriot_SYLLABARY}', "");
Expect(0, 67647, '\P{Block=	_Cypriot_SYLLABARY}', "");
Expect(1, 67647, '\P{^Block=	_Cypriot_SYLLABARY}', "");
Expect(0, 67648, '\p{Block=	_Cypriot_SYLLABARY}', "");
Expect(1, 67648, '\p{^Block=	_Cypriot_SYLLABARY}', "");
Expect(1, 67648, '\P{Block=	_Cypriot_SYLLABARY}', "");
Expect(0, 67648, '\P{^Block=	_Cypriot_SYLLABARY}', "");
Error('\p{Blk=Cypriot_SYLLABARY/a/}');
Error('\P{Blk=Cypriot_SYLLABARY/a/}');
Expect(1, 67647, '\p{Blk=cypriotsyllabary}', "");
Expect(0, 67647, '\p{^Blk=cypriotsyllabary}', "");
Expect(0, 67647, '\P{Blk=cypriotsyllabary}', "");
Expect(1, 67647, '\P{^Blk=cypriotsyllabary}', "");
Expect(0, 67648, '\p{Blk=cypriotsyllabary}', "");
Expect(1, 67648, '\p{^Blk=cypriotsyllabary}', "");
Expect(1, 67648, '\P{Blk=cypriotsyllabary}', "");
Expect(0, 67648, '\P{^Blk=cypriotsyllabary}', "");
Expect(1, 67647, '\p{Blk=-Cypriot_SYLLABARY}', "");
Expect(0, 67647, '\p{^Blk=-Cypriot_SYLLABARY}', "");
Expect(0, 67647, '\P{Blk=-Cypriot_SYLLABARY}', "");
Expect(1, 67647, '\P{^Blk=-Cypriot_SYLLABARY}', "");
Expect(0, 67648, '\p{Blk=-Cypriot_SYLLABARY}', "");
Expect(1, 67648, '\p{^Blk=-Cypriot_SYLLABARY}', "");
Expect(1, 67648, '\P{Blk=-Cypriot_SYLLABARY}', "");
Expect(0, 67648, '\P{^Blk=-Cypriot_SYLLABARY}', "");
Error('\p{Is_Block=	/a/Cypriot_syllabary}');
Error('\P{Is_Block=	/a/Cypriot_syllabary}');
Expect(1, 67647, '\p{Is_Block=cypriotsyllabary}', "");
Expect(0, 67647, '\p{^Is_Block=cypriotsyllabary}', "");
Expect(0, 67647, '\P{Is_Block=cypriotsyllabary}', "");
Expect(1, 67647, '\P{^Is_Block=cypriotsyllabary}', "");
Expect(0, 67648, '\p{Is_Block=cypriotsyllabary}', "");
Expect(1, 67648, '\p{^Is_Block=cypriotsyllabary}', "");
Expect(1, 67648, '\P{Is_Block=cypriotsyllabary}', "");
Expect(0, 67648, '\P{^Is_Block=cypriotsyllabary}', "");
Expect(1, 67647, '\p{Is_Block:	_CYPRIOT_syllabary}', "");
Expect(0, 67647, '\p{^Is_Block:	_CYPRIOT_syllabary}', "");
Expect(0, 67647, '\P{Is_Block:	_CYPRIOT_syllabary}', "");
Expect(1, 67647, '\P{^Is_Block:	_CYPRIOT_syllabary}', "");
Expect(0, 67648, '\p{Is_Block:	_CYPRIOT_syllabary}', "");
Expect(1, 67648, '\p{^Is_Block:	_CYPRIOT_syllabary}', "");
Expect(1, 67648, '\P{Is_Block:	_CYPRIOT_syllabary}', "");
Expect(0, 67648, '\P{^Is_Block:	_CYPRIOT_syllabary}', "");
Error('\p{Is_Blk=-	cypriot_syllabary/a/}');
Error('\P{Is_Blk=-	cypriot_syllabary/a/}');
Expect(1, 67647, '\p{Is_Blk=cypriotsyllabary}', "");
Expect(0, 67647, '\p{^Is_Blk=cypriotsyllabary}', "");
Expect(0, 67647, '\P{Is_Blk=cypriotsyllabary}', "");
Expect(1, 67647, '\P{^Is_Blk=cypriotsyllabary}', "");
Expect(0, 67648, '\p{Is_Blk=cypriotsyllabary}', "");
Expect(1, 67648, '\p{^Is_Blk=cypriotsyllabary}', "");
Expect(1, 67648, '\P{Is_Blk=cypriotsyllabary}', "");
Expect(0, 67648, '\P{^Is_Blk=cypriotsyllabary}', "");
Expect(1, 67647, '\p{Is_Blk=CYPRIOT_Syllabary}', "");
Expect(0, 67647, '\p{^Is_Blk=CYPRIOT_Syllabary}', "");
Expect(0, 67647, '\P{Is_Blk=CYPRIOT_Syllabary}', "");
Expect(1, 67647, '\P{^Is_Blk=CYPRIOT_Syllabary}', "");
Expect(0, 67648, '\p{Is_Blk=CYPRIOT_Syllabary}', "");
Expect(1, 67648, '\p{^Is_Blk=CYPRIOT_Syllabary}', "");
Expect(1, 67648, '\P{Is_Blk=CYPRIOT_Syllabary}', "");
Expect(0, 67648, '\P{^Is_Blk=CYPRIOT_Syllabary}', "");
Error('\p{Block=/a/	_Cyrillic}');
Error('\P{Block=/a/	_Cyrillic}');
Expect(1, 1279, '\p{Block: cyrillic}', "");
Expect(0, 1279, '\p{^Block: cyrillic}', "");
Expect(0, 1279, '\P{Block: cyrillic}', "");
Expect(1, 1279, '\P{^Block: cyrillic}', "");
Expect(0, 1280, '\p{Block: cyrillic}', "");
Expect(1, 1280, '\p{^Block: cyrillic}', "");
Expect(1, 1280, '\P{Block: cyrillic}', "");
Expect(0, 1280, '\P{^Block: cyrillic}', "");
Expect(1, 1279, '\p{Block= Cyrillic}', "");
Expect(0, 1279, '\p{^Block= Cyrillic}', "");
Expect(0, 1279, '\P{Block= Cyrillic}', "");
Expect(1, 1279, '\P{^Block= Cyrillic}', "");
Expect(0, 1280, '\p{Block= Cyrillic}', "");
Expect(1, 1280, '\p{^Block= Cyrillic}', "");
Expect(1, 1280, '\P{Block= Cyrillic}', "");
Expect(0, 1280, '\P{^Block= Cyrillic}', "");
Error('\p{Blk=:=CYRILLIC}');
Error('\P{Blk=:=CYRILLIC}');
Expect(1, 1279, '\p{Blk: cyrillic}', "");
Expect(0, 1279, '\p{^Blk: cyrillic}', "");
Expect(0, 1279, '\P{Blk: cyrillic}', "");
Expect(1, 1279, '\P{^Blk: cyrillic}', "");
Expect(0, 1280, '\p{Blk: cyrillic}', "");
Expect(1, 1280, '\p{^Blk: cyrillic}', "");
Expect(1, 1280, '\P{Blk: cyrillic}', "");
Expect(0, 1280, '\P{^Blk: cyrillic}', "");
Expect(1, 1279, '\p{Blk=-CYRILLIC}', "");
Expect(0, 1279, '\p{^Blk=-CYRILLIC}', "");
Expect(0, 1279, '\P{Blk=-CYRILLIC}', "");
Expect(1, 1279, '\P{^Blk=-CYRILLIC}', "");
Expect(0, 1280, '\p{Blk=-CYRILLIC}', "");
Expect(1, 1280, '\p{^Blk=-CYRILLIC}', "");
Expect(1, 1280, '\P{Blk=-CYRILLIC}', "");
Expect(0, 1280, '\P{^Blk=-CYRILLIC}', "");
Error('\p{Is_Block= -Cyrillic/a/}');
Error('\P{Is_Block= -Cyrillic/a/}');
Expect(1, 1279, '\p{Is_Block=cyrillic}', "");
Expect(0, 1279, '\p{^Is_Block=cyrillic}', "");
Expect(0, 1279, '\P{Is_Block=cyrillic}', "");
Expect(1, 1279, '\P{^Is_Block=cyrillic}', "");
Expect(0, 1280, '\p{Is_Block=cyrillic}', "");
Expect(1, 1280, '\p{^Is_Block=cyrillic}', "");
Expect(1, 1280, '\P{Is_Block=cyrillic}', "");
Expect(0, 1280, '\P{^Is_Block=cyrillic}', "");
Expect(1, 1279, '\p{Is_Block= _Cyrillic}', "");
Expect(0, 1279, '\p{^Is_Block= _Cyrillic}', "");
Expect(0, 1279, '\P{Is_Block= _Cyrillic}', "");
Expect(1, 1279, '\P{^Is_Block= _Cyrillic}', "");
Expect(0, 1280, '\p{Is_Block= _Cyrillic}', "");
Expect(1, 1280, '\p{^Is_Block= _Cyrillic}', "");
Expect(1, 1280, '\P{Is_Block= _Cyrillic}', "");
Expect(0, 1280, '\P{^Is_Block= _Cyrillic}', "");
Error('\p{Is_Blk=/a/_-CYRILLIC}');
Error('\P{Is_Blk=/a/_-CYRILLIC}');
Expect(1, 1279, '\p{Is_Blk:   cyrillic}', "");
Expect(0, 1279, '\p{^Is_Blk:   cyrillic}', "");
Expect(0, 1279, '\P{Is_Blk:   cyrillic}', "");
Expect(1, 1279, '\P{^Is_Blk:   cyrillic}', "");
Expect(0, 1280, '\p{Is_Blk:   cyrillic}', "");
Expect(1, 1280, '\p{^Is_Blk:   cyrillic}', "");
Expect(1, 1280, '\P{Is_Blk:   cyrillic}', "");
Expect(0, 1280, '\P{^Is_Blk:   cyrillic}', "");
Expect(1, 1279, '\p{Is_Blk=-cyrillic}', "");
Expect(0, 1279, '\p{^Is_Blk=-cyrillic}', "");
Expect(0, 1279, '\P{Is_Blk=-cyrillic}', "");
Expect(1, 1279, '\P{^Is_Blk=-cyrillic}', "");
Expect(0, 1280, '\p{Is_Blk=-cyrillic}', "");
Expect(1, 1280, '\p{^Is_Blk=-cyrillic}', "");
Expect(1, 1280, '\P{Is_Blk=-cyrillic}', "");
Expect(0, 1280, '\P{^Is_Blk=-cyrillic}', "");
Error('\p{Block=/a/_	cyrillic_Extended_A}');
Error('\P{Block=/a/_	cyrillic_Extended_A}');
Expect(1, 11775, '\p{Block=cyrillicextendeda}', "");
Expect(0, 11775, '\p{^Block=cyrillicextendeda}', "");
Expect(0, 11775, '\P{Block=cyrillicextendeda}', "");
Expect(1, 11775, '\P{^Block=cyrillicextendeda}', "");
Expect(0, 11776, '\p{Block=cyrillicextendeda}', "");
Expect(1, 11776, '\p{^Block=cyrillicextendeda}', "");
Expect(1, 11776, '\P{Block=cyrillicextendeda}', "");
Expect(0, 11776, '\P{^Block=cyrillicextendeda}', "");
Expect(1, 11775, '\p{Block=_CYRILLIC_EXTENDED_A}', "");
Expect(0, 11775, '\p{^Block=_CYRILLIC_EXTENDED_A}', "");
Expect(0, 11775, '\P{Block=_CYRILLIC_EXTENDED_A}', "");
Expect(1, 11775, '\P{^Block=_CYRILLIC_EXTENDED_A}', "");
Expect(0, 11776, '\p{Block=_CYRILLIC_EXTENDED_A}', "");
Expect(1, 11776, '\p{^Block=_CYRILLIC_EXTENDED_A}', "");
Expect(1, 11776, '\P{Block=_CYRILLIC_EXTENDED_A}', "");
Expect(0, 11776, '\P{^Block=_CYRILLIC_EXTENDED_A}', "");
Error('\p{Blk:   /a/_	Cyrillic_Ext_A}');
Error('\P{Blk:   /a/_	Cyrillic_Ext_A}');
Expect(1, 11775, '\p{Blk=cyrillicexta}', "");
Expect(0, 11775, '\p{^Blk=cyrillicexta}', "");
Expect(0, 11775, '\P{Blk=cyrillicexta}', "");
Expect(1, 11775, '\P{^Blk=cyrillicexta}', "");
Expect(0, 11776, '\p{Blk=cyrillicexta}', "");
Expect(1, 11776, '\p{^Blk=cyrillicexta}', "");
Expect(1, 11776, '\P{Blk=cyrillicexta}', "");
Expect(0, 11776, '\P{^Blk=cyrillicexta}', "");
Expect(1, 11775, '\p{Blk=	 CYRILLIC_Ext_A}', "");
Expect(0, 11775, '\p{^Blk=	 CYRILLIC_Ext_A}', "");
Expect(0, 11775, '\P{Blk=	 CYRILLIC_Ext_A}', "");
Expect(1, 11775, '\P{^Blk=	 CYRILLIC_Ext_A}', "");
Expect(0, 11776, '\p{Blk=	 CYRILLIC_Ext_A}', "");
Expect(1, 11776, '\p{^Blk=	 CYRILLIC_Ext_A}', "");
Expect(1, 11776, '\P{Blk=	 CYRILLIC_Ext_A}', "");
Expect(0, 11776, '\P{^Blk=	 CYRILLIC_Ext_A}', "");
Error('\p{Is_Block:	/a/ cyrillic_EXTENDED_A}');
Error('\P{Is_Block:	/a/ cyrillic_EXTENDED_A}');
Expect(1, 11775, '\p{Is_Block=cyrillicextendeda}', "");
Expect(0, 11775, '\p{^Is_Block=cyrillicextendeda}', "");
Expect(0, 11775, '\P{Is_Block=cyrillicextendeda}', "");
Expect(1, 11775, '\P{^Is_Block=cyrillicextendeda}', "");
Expect(0, 11776, '\p{Is_Block=cyrillicextendeda}', "");
Expect(1, 11776, '\p{^Is_Block=cyrillicextendeda}', "");
Expect(1, 11776, '\P{Is_Block=cyrillicextendeda}', "");
Expect(0, 11776, '\P{^Is_Block=cyrillicextendeda}', "");
Expect(1, 11775, '\p{Is_Block=- Cyrillic_EXTENDED_A}', "");
Expect(0, 11775, '\p{^Is_Block=- Cyrillic_EXTENDED_A}', "");
Expect(0, 11775, '\P{Is_Block=- Cyrillic_EXTENDED_A}', "");
Expect(1, 11775, '\P{^Is_Block=- Cyrillic_EXTENDED_A}', "");
Expect(0, 11776, '\p{Is_Block=- Cyrillic_EXTENDED_A}', "");
Expect(1, 11776, '\p{^Is_Block=- Cyrillic_EXTENDED_A}', "");
Expect(1, 11776, '\P{Is_Block=- Cyrillic_EXTENDED_A}', "");
Expect(0, 11776, '\P{^Is_Block=- Cyrillic_EXTENDED_A}', "");
Error('\p{Is_Blk=_-Cyrillic_EXT_A/a/}');
Error('\P{Is_Blk=_-Cyrillic_EXT_A/a/}');
Expect(1, 11775, '\p{Is_Blk=cyrillicexta}', "");
Expect(0, 11775, '\p{^Is_Blk=cyrillicexta}', "");
Expect(0, 11775, '\P{Is_Blk=cyrillicexta}', "");
Expect(1, 11775, '\P{^Is_Blk=cyrillicexta}', "");
Expect(0, 11776, '\p{Is_Blk=cyrillicexta}', "");
Expect(1, 11776, '\p{^Is_Blk=cyrillicexta}', "");
Expect(1, 11776, '\P{Is_Blk=cyrillicexta}', "");
Expect(0, 11776, '\P{^Is_Blk=cyrillicexta}', "");
Expect(1, 11775, '\p{Is_Blk= 	CYRILLIC_Ext_a}', "");
Expect(0, 11775, '\p{^Is_Blk= 	CYRILLIC_Ext_a}', "");
Expect(0, 11775, '\P{Is_Blk= 	CYRILLIC_Ext_a}', "");
Expect(1, 11775, '\P{^Is_Blk= 	CYRILLIC_Ext_a}', "");
Expect(0, 11776, '\p{Is_Blk= 	CYRILLIC_Ext_a}', "");
Expect(1, 11776, '\p{^Is_Blk= 	CYRILLIC_Ext_a}', "");
Expect(1, 11776, '\P{Is_Blk= 	CYRILLIC_Ext_a}', "");
Expect(0, 11776, '\P{^Is_Blk= 	CYRILLIC_Ext_a}', "");
Error('\p{Block:   	cyrillic_Extended_B:=}');
Error('\P{Block:   	cyrillic_Extended_B:=}');
Expect(1, 42655, '\p{Block: cyrillicextendedb}', "");
Expect(0, 42655, '\p{^Block: cyrillicextendedb}', "");
Expect(0, 42655, '\P{Block: cyrillicextendedb}', "");
Expect(1, 42655, '\P{^Block: cyrillicextendedb}', "");
Expect(0, 42656, '\p{Block: cyrillicextendedb}', "");
Expect(1, 42656, '\p{^Block: cyrillicextendedb}', "");
Expect(1, 42656, '\P{Block: cyrillicextendedb}', "");
Expect(0, 42656, '\P{^Block: cyrillicextendedb}', "");
Expect(1, 42655, '\p{Block=	_CYRILLIC_extended_B}', "");
Expect(0, 42655, '\p{^Block=	_CYRILLIC_extended_B}', "");
Expect(0, 42655, '\P{Block=	_CYRILLIC_extended_B}', "");
Expect(1, 42655, '\P{^Block=	_CYRILLIC_extended_B}', "");
Expect(0, 42656, '\p{Block=	_CYRILLIC_extended_B}', "");
Expect(1, 42656, '\p{^Block=	_CYRILLIC_extended_B}', "");
Expect(1, 42656, '\P{Block=	_CYRILLIC_extended_B}', "");
Expect(0, 42656, '\P{^Block=	_CYRILLIC_extended_B}', "");
Error('\p{Blk=-:=Cyrillic_EXT_B}');
Error('\P{Blk=-:=Cyrillic_EXT_B}');
Expect(1, 42655, '\p{Blk=cyrillicextb}', "");
Expect(0, 42655, '\p{^Blk=cyrillicextb}', "");
Expect(0, 42655, '\P{Blk=cyrillicextb}', "");
Expect(1, 42655, '\P{^Blk=cyrillicextb}', "");
Expect(0, 42656, '\p{Blk=cyrillicextb}', "");
Expect(1, 42656, '\p{^Blk=cyrillicextb}', "");
Expect(1, 42656, '\P{Blk=cyrillicextb}', "");
Expect(0, 42656, '\P{^Blk=cyrillicextb}', "");
Expect(1, 42655, '\p{Blk=-_CYRILLIC_Ext_B}', "");
Expect(0, 42655, '\p{^Blk=-_CYRILLIC_Ext_B}', "");
Expect(0, 42655, '\P{Blk=-_CYRILLIC_Ext_B}', "");
Expect(1, 42655, '\P{^Blk=-_CYRILLIC_Ext_B}', "");
Expect(0, 42656, '\p{Blk=-_CYRILLIC_Ext_B}', "");
Expect(1, 42656, '\p{^Blk=-_CYRILLIC_Ext_B}', "");
Expect(1, 42656, '\P{Blk=-_CYRILLIC_Ext_B}', "");
Expect(0, 42656, '\P{^Blk=-_CYRILLIC_Ext_B}', "");
Error('\p{Is_Block=--Cyrillic_Extended_B/a/}');
Error('\P{Is_Block=--Cyrillic_Extended_B/a/}');
Expect(1, 42655, '\p{Is_Block:   cyrillicextendedb}', "");
Expect(0, 42655, '\p{^Is_Block:   cyrillicextendedb}', "");
Expect(0, 42655, '\P{Is_Block:   cyrillicextendedb}', "");
Expect(1, 42655, '\P{^Is_Block:   cyrillicextendedb}', "");
Expect(0, 42656, '\p{Is_Block:   cyrillicextendedb}', "");
Expect(1, 42656, '\p{^Is_Block:   cyrillicextendedb}', "");
Expect(1, 42656, '\P{Is_Block:   cyrillicextendedb}', "");
Expect(0, 42656, '\P{^Is_Block:   cyrillicextendedb}', "");
Expect(1, 42655, '\p{Is_Block=Cyrillic_Extended_B}', "");
Expect(0, 42655, '\p{^Is_Block=Cyrillic_Extended_B}', "");
Expect(0, 42655, '\P{Is_Block=Cyrillic_Extended_B}', "");
Expect(1, 42655, '\P{^Is_Block=Cyrillic_Extended_B}', "");
Expect(0, 42656, '\p{Is_Block=Cyrillic_Extended_B}', "");
Expect(1, 42656, '\p{^Is_Block=Cyrillic_Extended_B}', "");
Expect(1, 42656, '\P{Is_Block=Cyrillic_Extended_B}', "");
Expect(0, 42656, '\P{^Is_Block=Cyrillic_Extended_B}', "");
Error('\p{Is_Blk=	cyrillic_ext_b/a/}');
Error('\P{Is_Blk=	cyrillic_ext_b/a/}');
Expect(1, 42655, '\p{Is_Blk: cyrillicextb}', "");
Expect(0, 42655, '\p{^Is_Blk: cyrillicextb}', "");
Expect(0, 42655, '\P{Is_Blk: cyrillicextb}', "");
Expect(1, 42655, '\P{^Is_Blk: cyrillicextb}', "");
Expect(0, 42656, '\p{Is_Blk: cyrillicextb}', "");
Expect(1, 42656, '\p{^Is_Blk: cyrillicextb}', "");
Expect(1, 42656, '\P{Is_Blk: cyrillicextb}', "");
Expect(0, 42656, '\P{^Is_Blk: cyrillicextb}', "");
Expect(1, 42655, '\p{Is_Blk=cyrillic_Ext_B}', "");
Expect(0, 42655, '\p{^Is_Blk=cyrillic_Ext_B}', "");
Expect(0, 42655, '\P{Is_Blk=cyrillic_Ext_B}', "");
Expect(1, 42655, '\P{^Is_Blk=cyrillic_Ext_B}', "");
Expect(0, 42656, '\p{Is_Blk=cyrillic_Ext_B}', "");
Expect(1, 42656, '\p{^Is_Blk=cyrillic_Ext_B}', "");
Expect(1, 42656, '\P{Is_Blk=cyrillic_Ext_B}', "");
Expect(0, 42656, '\P{^Is_Blk=cyrillic_Ext_B}', "");
Error('\p{Block= Cyrillic_Supplement/a/}');
Error('\P{Block= Cyrillic_Supplement/a/}');
Expect(1, 1327, '\p{Block=cyrillicsupplement}', "");
Expect(0, 1327, '\p{^Block=cyrillicsupplement}', "");
Expect(0, 1327, '\P{Block=cyrillicsupplement}', "");
Expect(1, 1327, '\P{^Block=cyrillicsupplement}', "");
Expect(0, 1328, '\p{Block=cyrillicsupplement}', "");
Expect(1, 1328, '\p{^Block=cyrillicsupplement}', "");
Expect(1, 1328, '\P{Block=cyrillicsupplement}', "");
Expect(0, 1328, '\P{^Block=cyrillicsupplement}', "");
Expect(1, 1327, '\p{Block=_	cyrillic_SUPPLEMENT}', "");
Expect(0, 1327, '\p{^Block=_	cyrillic_SUPPLEMENT}', "");
Expect(0, 1327, '\P{Block=_	cyrillic_SUPPLEMENT}', "");
Expect(1, 1327, '\P{^Block=_	cyrillic_SUPPLEMENT}', "");
Expect(0, 1328, '\p{Block=_	cyrillic_SUPPLEMENT}', "");
Expect(1, 1328, '\p{^Block=_	cyrillic_SUPPLEMENT}', "");
Expect(1, 1328, '\P{Block=_	cyrillic_SUPPLEMENT}', "");
Expect(0, 1328, '\P{^Block=_	cyrillic_SUPPLEMENT}', "");
Error('\p{Blk= 	CYRILLIC_Sup/a/}');
Error('\P{Blk= 	CYRILLIC_Sup/a/}');
Expect(1, 1327, '\p{Blk=cyrillicsup}', "");
Expect(0, 1327, '\p{^Blk=cyrillicsup}', "");
Expect(0, 1327, '\P{Blk=cyrillicsup}', "");
Expect(1, 1327, '\P{^Blk=cyrillicsup}', "");
Expect(0, 1328, '\p{Blk=cyrillicsup}', "");
Expect(1, 1328, '\p{^Blk=cyrillicsup}', "");
Expect(1, 1328, '\P{Blk=cyrillicsup}', "");
Expect(0, 1328, '\P{^Blk=cyrillicsup}', "");
Expect(1, 1327, '\p{Blk=	-cyrillic_Sup}', "");
Expect(0, 1327, '\p{^Blk=	-cyrillic_Sup}', "");
Expect(0, 1327, '\P{Blk=	-cyrillic_Sup}', "");
Expect(1, 1327, '\P{^Blk=	-cyrillic_Sup}', "");
Expect(0, 1328, '\p{Blk=	-cyrillic_Sup}', "");
Expect(1, 1328, '\p{^Blk=	-cyrillic_Sup}', "");
Expect(1, 1328, '\P{Blk=	-cyrillic_Sup}', "");
Expect(0, 1328, '\P{^Blk=	-cyrillic_Sup}', "");
Error('\p{Is_Block=/a/cyrillic_SUPPLEMENTARY}');
Error('\P{Is_Block=/a/cyrillic_SUPPLEMENTARY}');
Expect(1, 1327, '\p{Is_Block=cyrillicsupplementary}', "");
Expect(0, 1327, '\p{^Is_Block=cyrillicsupplementary}', "");
Expect(0, 1327, '\P{Is_Block=cyrillicsupplementary}', "");
Expect(1, 1327, '\P{^Is_Block=cyrillicsupplementary}', "");
Expect(0, 1328, '\p{Is_Block=cyrillicsupplementary}', "");
Expect(1, 1328, '\p{^Is_Block=cyrillicsupplementary}', "");
Expect(1, 1328, '\P{Is_Block=cyrillicsupplementary}', "");
Expect(0, 1328, '\P{^Is_Block=cyrillicsupplementary}', "");
Expect(1, 1327, '\p{Is_Block:			Cyrillic_supplementary}', "");
Expect(0, 1327, '\p{^Is_Block:			Cyrillic_supplementary}', "");
Expect(0, 1327, '\P{Is_Block:			Cyrillic_supplementary}', "");
Expect(1, 1327, '\P{^Is_Block:			Cyrillic_supplementary}', "");
Expect(0, 1328, '\p{Is_Block:			Cyrillic_supplementary}', "");
Expect(1, 1328, '\p{^Is_Block:			Cyrillic_supplementary}', "");
Expect(1, 1328, '\P{Is_Block:			Cyrillic_supplementary}', "");
Expect(0, 1328, '\P{^Is_Block:			Cyrillic_supplementary}', "");
Error('\p{Is_Blk= _CYRILLIC_supplement/a/}');
Error('\P{Is_Blk= _CYRILLIC_supplement/a/}');
Expect(1, 1327, '\p{Is_Blk: cyrillicsupplement}', "");
Expect(0, 1327, '\p{^Is_Blk: cyrillicsupplement}', "");
Expect(0, 1327, '\P{Is_Blk: cyrillicsupplement}', "");
Expect(1, 1327, '\P{^Is_Blk: cyrillicsupplement}', "");
Expect(0, 1328, '\p{Is_Blk: cyrillicsupplement}', "");
Expect(1, 1328, '\p{^Is_Blk: cyrillicsupplement}', "");
Expect(1, 1328, '\P{Is_Blk: cyrillicsupplement}', "");
Expect(0, 1328, '\P{^Is_Blk: cyrillicsupplement}', "");
Expect(1, 1327, '\p{Is_Blk= 	Cyrillic_supplement}', "");
Expect(0, 1327, '\p{^Is_Blk= 	Cyrillic_supplement}', "");
Expect(0, 1327, '\P{Is_Blk= 	Cyrillic_supplement}', "");
Expect(1, 1327, '\P{^Is_Blk= 	Cyrillic_supplement}', "");
Expect(0, 1328, '\p{Is_Blk= 	Cyrillic_supplement}', "");
Expect(1, 1328, '\p{^Is_Blk= 	Cyrillic_supplement}', "");
Expect(1, 1328, '\P{Is_Blk= 	Cyrillic_supplement}', "");
Expect(0, 1328, '\P{^Is_Blk= 	Cyrillic_supplement}', "");
Error('\p{Block=-_DESERET/a/}');
Error('\P{Block=-_DESERET/a/}');
Expect(1, 66639, '\p{Block=deseret}', "");
Expect(0, 66639, '\p{^Block=deseret}', "");
Expect(0, 66639, '\P{Block=deseret}', "");
Expect(1, 66639, '\P{^Block=deseret}', "");
Expect(0, 66640, '\p{Block=deseret}', "");
Expect(1, 66640, '\p{^Block=deseret}', "");
Expect(1, 66640, '\P{Block=deseret}', "");
Expect(0, 66640, '\P{^Block=deseret}', "");
Expect(1, 66639, '\p{Block= DESERET}', "");
Expect(0, 66639, '\p{^Block= DESERET}', "");
Expect(0, 66639, '\P{Block= DESERET}', "");
Expect(1, 66639, '\P{^Block= DESERET}', "");
Expect(0, 66640, '\p{Block= DESERET}', "");
Expect(1, 66640, '\p{^Block= DESERET}', "");
Expect(1, 66640, '\P{Block= DESERET}', "");
Expect(0, 66640, '\P{^Block= DESERET}', "");
Error('\p{Blk=-:=deseret}');
Error('\P{Blk=-:=deseret}');
Expect(1, 66639, '\p{Blk:   deseret}', "");
Expect(0, 66639, '\p{^Blk:   deseret}', "");
Expect(0, 66639, '\P{Blk:   deseret}', "");
Expect(1, 66639, '\P{^Blk:   deseret}', "");
Expect(0, 66640, '\p{Blk:   deseret}', "");
Expect(1, 66640, '\p{^Blk:   deseret}', "");
Expect(1, 66640, '\P{Blk:   deseret}', "");
Expect(0, 66640, '\P{^Blk:   deseret}', "");
Expect(1, 66639, '\p{Blk= 	DESERET}', "");
Expect(0, 66639, '\p{^Blk= 	DESERET}', "");
Expect(0, 66639, '\P{Blk= 	DESERET}', "");
Expect(1, 66639, '\P{^Blk= 	DESERET}', "");
Expect(0, 66640, '\p{Blk= 	DESERET}', "");
Expect(1, 66640, '\p{^Blk= 	DESERET}', "");
Expect(1, 66640, '\P{Blk= 	DESERET}', "");
Expect(0, 66640, '\P{^Blk= 	DESERET}', "");
Error('\p{Is_Block=	/a/Deseret}');
Error('\P{Is_Block=	/a/Deseret}');
Expect(1, 66639, '\p{Is_Block=deseret}', "");
Expect(0, 66639, '\p{^Is_Block=deseret}', "");
Expect(0, 66639, '\P{Is_Block=deseret}', "");
Expect(1, 66639, '\P{^Is_Block=deseret}', "");
Expect(0, 66640, '\p{Is_Block=deseret}', "");
Expect(1, 66640, '\p{^Is_Block=deseret}', "");
Expect(1, 66640, '\P{Is_Block=deseret}', "");
Expect(0, 66640, '\P{^Is_Block=deseret}', "");
Expect(1, 66639, '\p{Is_Block=-deseret}', "");
Expect(0, 66639, '\p{^Is_Block=-deseret}', "");
Expect(0, 66639, '\P{Is_Block=-deseret}', "");
Expect(1, 66639, '\P{^Is_Block=-deseret}', "");
Expect(0, 66640, '\p{Is_Block=-deseret}', "");
Expect(1, 66640, '\p{^Is_Block=-deseret}', "");
Expect(1, 66640, '\P{Is_Block=-deseret}', "");
Expect(0, 66640, '\P{^Is_Block=-deseret}', "");
Error('\p{Is_Blk=:=-_Deseret}');
Error('\P{Is_Blk=:=-_Deseret}');
Expect(1, 66639, '\p{Is_Blk=deseret}', "");
Expect(0, 66639, '\p{^Is_Blk=deseret}', "");
Expect(0, 66639, '\P{Is_Blk=deseret}', "");
Expect(1, 66639, '\P{^Is_Blk=deseret}', "");
Expect(0, 66640, '\p{Is_Blk=deseret}', "");
Expect(1, 66640, '\p{^Is_Blk=deseret}', "");
Expect(1, 66640, '\P{Is_Blk=deseret}', "");
Expect(0, 66640, '\P{^Is_Blk=deseret}', "");
Expect(1, 66639, '\p{Is_Blk=	_Deseret}', "");
Expect(0, 66639, '\p{^Is_Blk=	_Deseret}', "");
Expect(0, 66639, '\P{Is_Blk=	_Deseret}', "");
Expect(1, 66639, '\P{^Is_Blk=	_Deseret}', "");
Expect(0, 66640, '\p{Is_Blk=	_Deseret}', "");
Expect(1, 66640, '\p{^Is_Blk=	_Deseret}', "");
Expect(1, 66640, '\P{Is_Blk=	_Deseret}', "");
Expect(0, 66640, '\P{^Is_Blk=	_Deseret}', "");
Error('\p{Block=:=Devanagari}');
Error('\P{Block=:=Devanagari}');
Expect(1, 2431, '\p{Block=devanagari}', "");
Expect(0, 2431, '\p{^Block=devanagari}', "");
Expect(0, 2431, '\P{Block=devanagari}', "");
Expect(1, 2431, '\P{^Block=devanagari}', "");
Expect(0, 2432, '\p{Block=devanagari}', "");
Expect(1, 2432, '\p{^Block=devanagari}', "");
Expect(1, 2432, '\P{Block=devanagari}', "");
Expect(0, 2432, '\P{^Block=devanagari}', "");
Expect(1, 2431, '\p{Block=-	devanagari}', "");
Expect(0, 2431, '\p{^Block=-	devanagari}', "");
Expect(0, 2431, '\P{Block=-	devanagari}', "");
Expect(1, 2431, '\P{^Block=-	devanagari}', "");
Expect(0, 2432, '\p{Block=-	devanagari}', "");
Expect(1, 2432, '\p{^Block=-	devanagari}', "");
Expect(1, 2432, '\P{Block=-	devanagari}', "");
Expect(0, 2432, '\P{^Block=-	devanagari}', "");
Error('\p{Blk=/a/	Devanagari}');
Error('\P{Blk=/a/	Devanagari}');
Expect(1, 2431, '\p{Blk=devanagari}', "");
Expect(0, 2431, '\p{^Blk=devanagari}', "");
Expect(0, 2431, '\P{Blk=devanagari}', "");
Expect(1, 2431, '\P{^Blk=devanagari}', "");
Expect(0, 2432, '\p{Blk=devanagari}', "");
Expect(1, 2432, '\p{^Blk=devanagari}', "");
Expect(1, 2432, '\P{Blk=devanagari}', "");
Expect(0, 2432, '\P{^Blk=devanagari}', "");
Expect(1, 2431, '\p{Blk= Devanagari}', "");
Expect(0, 2431, '\p{^Blk= Devanagari}', "");
Expect(0, 2431, '\P{Blk= Devanagari}', "");
Expect(1, 2431, '\P{^Blk= Devanagari}', "");
Expect(0, 2432, '\p{Blk= Devanagari}', "");
Expect(1, 2432, '\p{^Blk= Devanagari}', "");
Expect(1, 2432, '\P{Blk= Devanagari}', "");
Expect(0, 2432, '\P{^Blk= Devanagari}', "");
Error('\p{Is_Block:   :=-DEVANAGARI}');
Error('\P{Is_Block:   :=-DEVANAGARI}');
Expect(1, 2431, '\p{Is_Block=devanagari}', "");
Expect(0, 2431, '\p{^Is_Block=devanagari}', "");
Expect(0, 2431, '\P{Is_Block=devanagari}', "");
Expect(1, 2431, '\P{^Is_Block=devanagari}', "");
Expect(0, 2432, '\p{Is_Block=devanagari}', "");
Expect(1, 2432, '\p{^Is_Block=devanagari}', "");
Expect(1, 2432, '\P{Is_Block=devanagari}', "");
Expect(0, 2432, '\P{^Is_Block=devanagari}', "");
Expect(1, 2431, '\p{Is_Block= _Devanagari}', "");
Expect(0, 2431, '\p{^Is_Block= _Devanagari}', "");
Expect(0, 2431, '\P{Is_Block= _Devanagari}', "");
Expect(1, 2431, '\P{^Is_Block= _Devanagari}', "");
Expect(0, 2432, '\p{Is_Block= _Devanagari}', "");
Expect(1, 2432, '\p{^Is_Block= _Devanagari}', "");
Expect(1, 2432, '\P{Is_Block= _Devanagari}', "");
Expect(0, 2432, '\P{^Is_Block= _Devanagari}', "");
Error('\p{Is_Blk:   /a/Devanagari}');
Error('\P{Is_Blk:   /a/Devanagari}');
Expect(1, 2431, '\p{Is_Blk=devanagari}', "");
Expect(0, 2431, '\p{^Is_Blk=devanagari}', "");
Expect(0, 2431, '\P{Is_Blk=devanagari}', "");
Expect(1, 2431, '\P{^Is_Blk=devanagari}', "");
Expect(0, 2432, '\p{Is_Blk=devanagari}', "");
Expect(1, 2432, '\p{^Is_Blk=devanagari}', "");
Expect(1, 2432, '\P{Is_Blk=devanagari}', "");
Expect(0, 2432, '\P{^Is_Blk=devanagari}', "");
Expect(1, 2431, '\p{Is_Blk= Devanagari}', "");
Expect(0, 2431, '\p{^Is_Blk= Devanagari}', "");
Expect(0, 2431, '\P{Is_Blk= Devanagari}', "");
Expect(1, 2431, '\P{^Is_Blk= Devanagari}', "");
Expect(0, 2432, '\p{Is_Blk= Devanagari}', "");
Expect(1, 2432, '\p{^Is_Blk= Devanagari}', "");
Expect(1, 2432, '\P{Is_Blk= Devanagari}', "");
Expect(0, 2432, '\P{^Is_Blk= Devanagari}', "");
Error('\p{Block:/a/ DEVANAGARI_extended}');
Error('\P{Block:/a/ DEVANAGARI_extended}');
Expect(1, 43263, '\p{Block=devanagariextended}', "");
Expect(0, 43263, '\p{^Block=devanagariextended}', "");
Expect(0, 43263, '\P{Block=devanagariextended}', "");
Expect(1, 43263, '\P{^Block=devanagariextended}', "");
Expect(0, 43264, '\p{Block=devanagariextended}', "");
Expect(1, 43264, '\p{^Block=devanagariextended}', "");
Expect(1, 43264, '\P{Block=devanagariextended}', "");
Expect(0, 43264, '\P{^Block=devanagariextended}', "");
Expect(1, 43263, '\p{Block=- devanagari_EXTENDED}', "");
Expect(0, 43263, '\p{^Block=- devanagari_EXTENDED}', "");
Expect(0, 43263, '\P{Block=- devanagari_EXTENDED}', "");
Expect(1, 43263, '\P{^Block=- devanagari_EXTENDED}', "");
Expect(0, 43264, '\p{Block=- devanagari_EXTENDED}', "");
Expect(1, 43264, '\p{^Block=- devanagari_EXTENDED}', "");
Expect(1, 43264, '\P{Block=- devanagari_EXTENDED}', "");
Expect(0, 43264, '\P{^Block=- devanagari_EXTENDED}', "");
Error('\p{Blk=/a/devanagari_ext}');
Error('\P{Blk=/a/devanagari_ext}');
Expect(1, 43263, '\p{Blk=devanagariext}', "");
Expect(0, 43263, '\p{^Blk=devanagariext}', "");
Expect(0, 43263, '\P{Blk=devanagariext}', "");
Expect(1, 43263, '\P{^Blk=devanagariext}', "");
Expect(0, 43264, '\p{Blk=devanagariext}', "");
Expect(1, 43264, '\p{^Blk=devanagariext}', "");
Expect(1, 43264, '\P{Blk=devanagariext}', "");
Expect(0, 43264, '\P{^Blk=devanagariext}', "");
Expect(1, 43263, '\p{Blk=_	Devanagari_EXT}', "");
Expect(0, 43263, '\p{^Blk=_	Devanagari_EXT}', "");
Expect(0, 43263, '\P{Blk=_	Devanagari_EXT}', "");
Expect(1, 43263, '\P{^Blk=_	Devanagari_EXT}', "");
Expect(0, 43264, '\p{Blk=_	Devanagari_EXT}', "");
Expect(1, 43264, '\p{^Blk=_	Devanagari_EXT}', "");
Expect(1, 43264, '\P{Blk=_	Devanagari_EXT}', "");
Expect(0, 43264, '\P{^Blk=_	Devanagari_EXT}', "");
Error('\p{Is_Block=	:=DEVANAGARI_EXTENDED}');
Error('\P{Is_Block=	:=DEVANAGARI_EXTENDED}');
Expect(1, 43263, '\p{Is_Block=devanagariextended}', "");
Expect(0, 43263, '\p{^Is_Block=devanagariextended}', "");
Expect(0, 43263, '\P{Is_Block=devanagariextended}', "");
Expect(1, 43263, '\P{^Is_Block=devanagariextended}', "");
Expect(0, 43264, '\p{Is_Block=devanagariextended}', "");
Expect(1, 43264, '\p{^Is_Block=devanagariextended}', "");
Expect(1, 43264, '\P{Is_Block=devanagariextended}', "");
Expect(0, 43264, '\P{^Is_Block=devanagariextended}', "");
Expect(1, 43263, '\p{Is_Block=  DEVANAGARI_Extended}', "");
Expect(0, 43263, '\p{^Is_Block=  DEVANAGARI_Extended}', "");
Expect(0, 43263, '\P{Is_Block=  DEVANAGARI_Extended}', "");
Expect(1, 43263, '\P{^Is_Block=  DEVANAGARI_Extended}', "");
Expect(0, 43264, '\p{Is_Block=  DEVANAGARI_Extended}', "");
Expect(1, 43264, '\p{^Is_Block=  DEVANAGARI_Extended}', "");
Expect(1, 43264, '\P{Is_Block=  DEVANAGARI_Extended}', "");
Expect(0, 43264, '\P{^Is_Block=  DEVANAGARI_Extended}', "");
Error('\p{Is_Blk=	:=Devanagari_Ext}');
Error('\P{Is_Blk=	:=Devanagari_Ext}');
Expect(1, 43263, '\p{Is_Blk=devanagariext}', "");
Expect(0, 43263, '\p{^Is_Blk=devanagariext}', "");
Expect(0, 43263, '\P{Is_Blk=devanagariext}', "");
Expect(1, 43263, '\P{^Is_Blk=devanagariext}', "");
Expect(0, 43264, '\p{Is_Blk=devanagariext}', "");
Expect(1, 43264, '\p{^Is_Blk=devanagariext}', "");
Expect(1, 43264, '\P{Is_Blk=devanagariext}', "");
Expect(0, 43264, '\P{^Is_Blk=devanagariext}', "");
Expect(1, 43263, '\p{Is_Blk=_-Devanagari_Ext}', "");
Expect(0, 43263, '\p{^Is_Blk=_-Devanagari_Ext}', "");
Expect(0, 43263, '\P{Is_Blk=_-Devanagari_Ext}', "");
Expect(1, 43263, '\P{^Is_Blk=_-Devanagari_Ext}', "");
Expect(0, 43264, '\p{Is_Blk=_-Devanagari_Ext}', "");
Expect(1, 43264, '\p{^Is_Blk=_-Devanagari_Ext}', "");
Expect(1, 43264, '\P{Is_Blk=_-Devanagari_Ext}', "");
Expect(0, 43264, '\P{^Is_Blk=_-Devanagari_Ext}', "");
Error('\p{Block=:=	-Combining_Diacritical_MARKS}');
Error('\P{Block=:=	-Combining_Diacritical_MARKS}');
Expect(1, 879, '\p{Block=combiningdiacriticalmarks}', "");
Expect(0, 879, '\p{^Block=combiningdiacriticalmarks}', "");
Expect(0, 879, '\P{Block=combiningdiacriticalmarks}', "");
Expect(1, 879, '\P{^Block=combiningdiacriticalmarks}', "");
Expect(0, 880, '\p{Block=combiningdiacriticalmarks}', "");
Expect(1, 880, '\p{^Block=combiningdiacriticalmarks}', "");
Expect(1, 880, '\P{Block=combiningdiacriticalmarks}', "");
Expect(0, 880, '\P{^Block=combiningdiacriticalmarks}', "");
Expect(1, 879, '\p{Block:  Combining_Diacritical_MARKS}', "");
Expect(0, 879, '\p{^Block:  Combining_Diacritical_MARKS}', "");
Expect(0, 879, '\P{Block:  Combining_Diacritical_MARKS}', "");
Expect(1, 879, '\P{^Block:  Combining_Diacritical_MARKS}', "");
Expect(0, 880, '\p{Block:  Combining_Diacritical_MARKS}', "");
Expect(1, 880, '\p{^Block:  Combining_Diacritical_MARKS}', "");
Expect(1, 880, '\P{Block:  Combining_Diacritical_MARKS}', "");
Expect(0, 880, '\P{^Block:  Combining_Diacritical_MARKS}', "");
Error('\p{Blk= /a/Diacriticals}');
Error('\P{Blk= /a/Diacriticals}');
Expect(1, 879, '\p{Blk=diacriticals}', "");
Expect(0, 879, '\p{^Blk=diacriticals}', "");
Expect(0, 879, '\P{Blk=diacriticals}', "");
Expect(1, 879, '\P{^Blk=diacriticals}', "");
Expect(0, 880, '\p{Blk=diacriticals}', "");
Expect(1, 880, '\p{^Blk=diacriticals}', "");
Expect(1, 880, '\P{Blk=diacriticals}', "");
Expect(0, 880, '\P{^Blk=diacriticals}', "");
Expect(1, 879, '\p{Blk:  DIACRITICALS}', "");
Expect(0, 879, '\p{^Blk:  DIACRITICALS}', "");
Expect(0, 879, '\P{Blk:  DIACRITICALS}', "");
Expect(1, 879, '\P{^Blk:  DIACRITICALS}', "");
Expect(0, 880, '\p{Blk:  DIACRITICALS}', "");
Expect(1, 880, '\p{^Blk:  DIACRITICALS}', "");
Expect(1, 880, '\P{Blk:  DIACRITICALS}', "");
Expect(0, 880, '\P{^Blk:  DIACRITICALS}', "");
Error('\p{Is_Block=:=--Combining_DIACRITICAL_MARKS}');
Error('\P{Is_Block=:=--Combining_DIACRITICAL_MARKS}');
Expect(1, 879, '\p{Is_Block=combiningdiacriticalmarks}', "");
Expect(0, 879, '\p{^Is_Block=combiningdiacriticalmarks}', "");
Expect(0, 879, '\P{Is_Block=combiningdiacriticalmarks}', "");
Expect(1, 879, '\P{^Is_Block=combiningdiacriticalmarks}', "");
Expect(0, 880, '\p{Is_Block=combiningdiacriticalmarks}', "");
Expect(1, 880, '\p{^Is_Block=combiningdiacriticalmarks}', "");
Expect(1, 880, '\P{Is_Block=combiningdiacriticalmarks}', "");
Expect(0, 880, '\P{^Is_Block=combiningdiacriticalmarks}', "");
Expect(1, 879, '\p{Is_Block= Combining_DIACRITICAL_Marks}', "");
Expect(0, 879, '\p{^Is_Block= Combining_DIACRITICAL_Marks}', "");
Expect(0, 879, '\P{Is_Block= Combining_DIACRITICAL_Marks}', "");
Expect(1, 879, '\P{^Is_Block= Combining_DIACRITICAL_Marks}', "");
Expect(0, 880, '\p{Is_Block= Combining_DIACRITICAL_Marks}', "");
Expect(1, 880, '\p{^Is_Block= Combining_DIACRITICAL_Marks}', "");
Expect(1, 880, '\P{Is_Block= Combining_DIACRITICAL_Marks}', "");
Expect(0, 880, '\P{^Is_Block= Combining_DIACRITICAL_Marks}', "");
Error('\p{Is_Blk=	/a/diacriticals}');
Error('\P{Is_Blk=	/a/diacriticals}');
Expect(1, 879, '\p{Is_Blk=diacriticals}', "");
Expect(0, 879, '\p{^Is_Blk=diacriticals}', "");
Expect(0, 879, '\P{Is_Blk=diacriticals}', "");
Expect(1, 879, '\P{^Is_Blk=diacriticals}', "");
Expect(0, 880, '\p{Is_Blk=diacriticals}', "");
Expect(1, 880, '\p{^Is_Blk=diacriticals}', "");
Expect(1, 880, '\P{Is_Blk=diacriticals}', "");
Expect(0, 880, '\P{^Is_Blk=diacriticals}', "");
Expect(1, 879, '\p{Is_Blk=		diacriticals}', "");
Expect(0, 879, '\p{^Is_Blk=		diacriticals}', "");
Expect(0, 879, '\P{Is_Blk=		diacriticals}', "");
Expect(1, 879, '\P{^Is_Blk=		diacriticals}', "");
Expect(0, 880, '\p{Is_Blk=		diacriticals}', "");
Expect(1, 880, '\p{^Is_Blk=		diacriticals}', "");
Expect(1, 880, '\P{Is_Blk=		diacriticals}', "");
Expect(0, 880, '\P{^Is_Blk=		diacriticals}', "");
Error('\p{Block=	 combining_diacritical_marks_for_symbols:=}');
Error('\P{Block=	 combining_diacritical_marks_for_symbols:=}');
Expect(1, 8447, '\p{Block=combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\p{^Block=combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\P{Block=combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\P{^Block=combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\p{Block=combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\p{^Block=combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\P{Block=combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\P{^Block=combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\p{Block=COMBINING_Diacritical_Marks_FOR_symbols}', "");
Expect(0, 8447, '\p{^Block=COMBINING_Diacritical_Marks_FOR_symbols}', "");
Expect(0, 8447, '\P{Block=COMBINING_Diacritical_Marks_FOR_symbols}', "");
Expect(1, 8447, '\P{^Block=COMBINING_Diacritical_Marks_FOR_symbols}', "");
Expect(0, 8448, '\p{Block=COMBINING_Diacritical_Marks_FOR_symbols}', "");
Expect(1, 8448, '\p{^Block=COMBINING_Diacritical_Marks_FOR_symbols}', "");
Expect(1, 8448, '\P{Block=COMBINING_Diacritical_Marks_FOR_symbols}', "");
Expect(0, 8448, '\P{^Block=COMBINING_Diacritical_Marks_FOR_symbols}', "");
Error('\p{Blk=:=_ DIACRITICALS_For_SYMBOLS}');
Error('\P{Blk=:=_ DIACRITICALS_For_SYMBOLS}');
Expect(1, 8447, '\p{Blk=diacriticalsforsymbols}', "");
Expect(0, 8447, '\p{^Blk=diacriticalsforsymbols}', "");
Expect(0, 8447, '\P{Blk=diacriticalsforsymbols}', "");
Expect(1, 8447, '\P{^Blk=diacriticalsforsymbols}', "");
Expect(0, 8448, '\p{Blk=diacriticalsforsymbols}', "");
Expect(1, 8448, '\p{^Blk=diacriticalsforsymbols}', "");
Expect(1, 8448, '\P{Blk=diacriticalsforsymbols}', "");
Expect(0, 8448, '\P{^Blk=diacriticalsforsymbols}', "");
Expect(1, 8447, '\p{Blk=_ Diacriticals_For_symbols}', "");
Expect(0, 8447, '\p{^Blk=_ Diacriticals_For_symbols}', "");
Expect(0, 8447, '\P{Blk=_ Diacriticals_For_symbols}', "");
Expect(1, 8447, '\P{^Blk=_ Diacriticals_For_symbols}', "");
Expect(0, 8448, '\p{Blk=_ Diacriticals_For_symbols}', "");
Expect(1, 8448, '\p{^Blk=_ Diacriticals_For_symbols}', "");
Expect(1, 8448, '\P{Blk=_ Diacriticals_For_symbols}', "");
Expect(0, 8448, '\P{^Blk=_ Diacriticals_For_symbols}', "");
Error('\p{Is_Block: _-Combining_MARKS_For_SYMBOLS:=}');
Error('\P{Is_Block: _-Combining_MARKS_For_SYMBOLS:=}');
Expect(1, 8447, '\p{Is_Block=combiningmarksforsymbols}', "");
Expect(0, 8447, '\p{^Is_Block=combiningmarksforsymbols}', "");
Expect(0, 8447, '\P{Is_Block=combiningmarksforsymbols}', "");
Expect(1, 8447, '\P{^Is_Block=combiningmarksforsymbols}', "");
Expect(0, 8448, '\p{Is_Block=combiningmarksforsymbols}', "");
Expect(1, 8448, '\p{^Is_Block=combiningmarksforsymbols}', "");
Expect(1, 8448, '\P{Is_Block=combiningmarksforsymbols}', "");
Expect(0, 8448, '\P{^Is_Block=combiningmarksforsymbols}', "");
Expect(1, 8447, '\p{Is_Block=_combining_MARKS_FOR_Symbols}', "");
Expect(0, 8447, '\p{^Is_Block=_combining_MARKS_FOR_Symbols}', "");
Expect(0, 8447, '\P{Is_Block=_combining_MARKS_FOR_Symbols}', "");
Expect(1, 8447, '\P{^Is_Block=_combining_MARKS_FOR_Symbols}', "");
Expect(0, 8448, '\p{Is_Block=_combining_MARKS_FOR_Symbols}', "");
Expect(1, 8448, '\p{^Is_Block=_combining_MARKS_FOR_Symbols}', "");
Expect(1, 8448, '\P{Is_Block=_combining_MARKS_FOR_Symbols}', "");
Expect(0, 8448, '\P{^Is_Block=_combining_MARKS_FOR_Symbols}', "");
Error('\p{Is_Blk=_combining_Diacritical_MARKS_FOR_Symbols/a/}');
Error('\P{Is_Blk=_combining_Diacritical_MARKS_FOR_Symbols/a/}');
Expect(1, 8447, '\p{Is_Blk=combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\p{^Is_Blk=combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\P{Is_Blk=combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\P{^Is_Blk=combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\p{Is_Blk=combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\p{^Is_Blk=combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\P{Is_Blk=combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\P{^Is_Blk=combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\p{Is_Blk= 	combining_Diacritical_MARKS_For_SYMBOLS}', "");
Expect(0, 8447, '\p{^Is_Blk= 	combining_Diacritical_MARKS_For_SYMBOLS}', "");
Expect(0, 8447, '\P{Is_Blk= 	combining_Diacritical_MARKS_For_SYMBOLS}', "");
Expect(1, 8447, '\P{^Is_Blk= 	combining_Diacritical_MARKS_For_SYMBOLS}', "");
Expect(0, 8448, '\p{Is_Blk= 	combining_Diacritical_MARKS_For_SYMBOLS}', "");
Expect(1, 8448, '\p{^Is_Blk= 	combining_Diacritical_MARKS_For_SYMBOLS}', "");
Expect(1, 8448, '\P{Is_Blk= 	combining_Diacritical_MARKS_For_SYMBOLS}', "");
Expect(0, 8448, '\P{^Is_Blk= 	combining_Diacritical_MARKS_For_SYMBOLS}', "");
Error('\p{Block=-_Combining_diacritical_Marks_Supplement:=}');
Error('\P{Block=-_Combining_diacritical_Marks_Supplement:=}');
Expect(1, 7679, '\p{Block=combiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\p{^Block=combiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\P{Block=combiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\P{^Block=combiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\p{Block=combiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\p{^Block=combiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\P{Block=combiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\P{^Block=combiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\p{Block=--Combining_DIACRITICAL_Marks_supplement}', "");
Expect(0, 7679, '\p{^Block=--Combining_DIACRITICAL_Marks_supplement}', "");
Expect(0, 7679, '\P{Block=--Combining_DIACRITICAL_Marks_supplement}', "");
Expect(1, 7679, '\P{^Block=--Combining_DIACRITICAL_Marks_supplement}', "");
Expect(0, 7680, '\p{Block=--Combining_DIACRITICAL_Marks_supplement}', "");
Expect(1, 7680, '\p{^Block=--Combining_DIACRITICAL_Marks_supplement}', "");
Expect(1, 7680, '\P{Block=--Combining_DIACRITICAL_Marks_supplement}', "");
Expect(0, 7680, '\P{^Block=--Combining_DIACRITICAL_Marks_supplement}', "");
Error('\p{Blk=_:=Diacriticals_sup}');
Error('\P{Blk=_:=Diacriticals_sup}');
Expect(1, 7679, '\p{Blk=diacriticalssup}', "");
Expect(0, 7679, '\p{^Blk=diacriticalssup}', "");
Expect(0, 7679, '\P{Blk=diacriticalssup}', "");
Expect(1, 7679, '\P{^Blk=diacriticalssup}', "");
Expect(0, 7680, '\p{Blk=diacriticalssup}', "");
Expect(1, 7680, '\p{^Blk=diacriticalssup}', "");
Expect(1, 7680, '\P{Blk=diacriticalssup}', "");
Expect(0, 7680, '\P{^Blk=diacriticalssup}', "");
Expect(1, 7679, '\p{Blk=__Diacriticals_sup}', "");
Expect(0, 7679, '\p{^Blk=__Diacriticals_sup}', "");
Expect(0, 7679, '\P{Blk=__Diacriticals_sup}', "");
Expect(1, 7679, '\P{^Blk=__Diacriticals_sup}', "");
Expect(0, 7680, '\p{Blk=__Diacriticals_sup}', "");
Expect(1, 7680, '\p{^Blk=__Diacriticals_sup}', "");
Expect(1, 7680, '\P{Blk=__Diacriticals_sup}', "");
Expect(0, 7680, '\P{^Blk=__Diacriticals_sup}', "");
Error('\p{Is_Block=/a/-	Combining_Diacritical_Marks_SUPPLEMENT}');
Error('\P{Is_Block=/a/-	Combining_Diacritical_Marks_SUPPLEMENT}');
Expect(1, 7679, '\p{Is_Block: combiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\p{^Is_Block: combiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\P{Is_Block: combiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\P{^Is_Block: combiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\p{Is_Block: combiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\p{^Is_Block: combiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\P{Is_Block: combiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\P{^Is_Block: combiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\p{Is_Block=COMBINING_Diacritical_MARKS_Supplement}', "");
Expect(0, 7679, '\p{^Is_Block=COMBINING_Diacritical_MARKS_Supplement}', "");
Expect(0, 7679, '\P{Is_Block=COMBINING_Diacritical_MARKS_Supplement}', "");
Expect(1, 7679, '\P{^Is_Block=COMBINING_Diacritical_MARKS_Supplement}', "");
Expect(0, 7680, '\p{Is_Block=COMBINING_Diacritical_MARKS_Supplement}', "");
Expect(1, 7680, '\p{^Is_Block=COMBINING_Diacritical_MARKS_Supplement}', "");
Expect(1, 7680, '\P{Is_Block=COMBINING_Diacritical_MARKS_Supplement}', "");
Expect(0, 7680, '\P{^Is_Block=COMBINING_Diacritical_MARKS_Supplement}', "");
Error('\p{Is_Blk=-/a/Diacriticals_Sup}');
Error('\P{Is_Blk=-/a/Diacriticals_Sup}');
Expect(1, 7679, '\p{Is_Blk=diacriticalssup}', "");
Expect(0, 7679, '\p{^Is_Blk=diacriticalssup}', "");
Expect(0, 7679, '\P{Is_Blk=diacriticalssup}', "");
Expect(1, 7679, '\P{^Is_Blk=diacriticalssup}', "");
Expect(0, 7680, '\p{Is_Blk=diacriticalssup}', "");
Expect(1, 7680, '\p{^Is_Blk=diacriticalssup}', "");
Expect(1, 7680, '\P{Is_Blk=diacriticalssup}', "");
Expect(0, 7680, '\P{^Is_Blk=diacriticalssup}', "");
Expect(1, 7679, '\p{Is_Blk=_Diacriticals_SUP}', "");
Expect(0, 7679, '\p{^Is_Blk=_Diacriticals_SUP}', "");
Expect(0, 7679, '\P{Is_Blk=_Diacriticals_SUP}', "");
Expect(1, 7679, '\P{^Is_Blk=_Diacriticals_SUP}', "");
Expect(0, 7680, '\p{Is_Blk=_Diacriticals_SUP}', "");
Expect(1, 7680, '\p{^Is_Blk=_Diacriticals_SUP}', "");
Expect(1, 7680, '\P{Is_Blk=_Diacriticals_SUP}', "");
Expect(0, 7680, '\P{^Is_Blk=_Diacriticals_SUP}', "");
Error('\p{Block:_	DINGBATS/a/}');
Error('\P{Block:_	DINGBATS/a/}');
Expect(1, 10175, '\p{Block:	dingbats}', "");
Expect(0, 10175, '\p{^Block:	dingbats}', "");
Expect(0, 10175, '\P{Block:	dingbats}', "");
Expect(1, 10175, '\P{^Block:	dingbats}', "");
Expect(0, 10176, '\p{Block:	dingbats}', "");
Expect(1, 10176, '\p{^Block:	dingbats}', "");
Expect(1, 10176, '\P{Block:	dingbats}', "");
Expect(0, 10176, '\P{^Block:	dingbats}', "");
Expect(1, 10175, '\p{Block=Dingbats}', "");
Expect(0, 10175, '\p{^Block=Dingbats}', "");
Expect(0, 10175, '\P{Block=Dingbats}', "");
Expect(1, 10175, '\P{^Block=Dingbats}', "");
Expect(0, 10176, '\p{Block=Dingbats}', "");
Expect(1, 10176, '\p{^Block=Dingbats}', "");
Expect(1, 10176, '\P{Block=Dingbats}', "");
Expect(0, 10176, '\P{^Block=Dingbats}', "");
Error('\p{Blk=  dingbats:=}');
Error('\P{Blk=  dingbats:=}');
Expect(1, 10175, '\p{Blk=dingbats}', "");
Expect(0, 10175, '\p{^Blk=dingbats}', "");
Expect(0, 10175, '\P{Blk=dingbats}', "");
Expect(1, 10175, '\P{^Blk=dingbats}', "");
Expect(0, 10176, '\p{Blk=dingbats}', "");
Expect(1, 10176, '\p{^Blk=dingbats}', "");
Expect(1, 10176, '\P{Blk=dingbats}', "");
Expect(0, 10176, '\P{^Blk=dingbats}', "");
Expect(1, 10175, '\p{Blk= _dingbats}', "");
Expect(0, 10175, '\p{^Blk= _dingbats}', "");
Expect(0, 10175, '\P{Blk= _dingbats}', "");
Expect(1, 10175, '\P{^Blk= _dingbats}', "");
Expect(0, 10176, '\p{Blk= _dingbats}', "");
Expect(1, 10176, '\p{^Blk= _dingbats}', "");
Expect(1, 10176, '\P{Blk= _dingbats}', "");
Expect(0, 10176, '\P{^Blk= _dingbats}', "");
Error('\p{Is_Block=		dingbats/a/}');
Error('\P{Is_Block=		dingbats/a/}');
Expect(1, 10175, '\p{Is_Block=dingbats}', "");
Expect(0, 10175, '\p{^Is_Block=dingbats}', "");
Expect(0, 10175, '\P{Is_Block=dingbats}', "");
Expect(1, 10175, '\P{^Is_Block=dingbats}', "");
Expect(0, 10176, '\p{Is_Block=dingbats}', "");
Expect(1, 10176, '\p{^Is_Block=dingbats}', "");
Expect(1, 10176, '\P{Is_Block=dingbats}', "");
Expect(0, 10176, '\P{^Is_Block=dingbats}', "");
Expect(1, 10175, '\p{Is_Block=_dingbats}', "");
Expect(0, 10175, '\p{^Is_Block=_dingbats}', "");
Expect(0, 10175, '\P{Is_Block=_dingbats}', "");
Expect(1, 10175, '\P{^Is_Block=_dingbats}', "");
Expect(0, 10176, '\p{Is_Block=_dingbats}', "");
Expect(1, 10176, '\p{^Is_Block=_dingbats}', "");
Expect(1, 10176, '\P{Is_Block=_dingbats}', "");
Expect(0, 10176, '\P{^Is_Block=_dingbats}', "");
Error('\p{Is_Blk=-_DINGBATS/a/}');
Error('\P{Is_Blk=-_DINGBATS/a/}');
Expect(1, 10175, '\p{Is_Blk=dingbats}', "");
Expect(0, 10175, '\p{^Is_Blk=dingbats}', "");
Expect(0, 10175, '\P{Is_Blk=dingbats}', "");
Expect(1, 10175, '\P{^Is_Blk=dingbats}', "");
Expect(0, 10176, '\p{Is_Blk=dingbats}', "");
Expect(1, 10176, '\p{^Is_Blk=dingbats}', "");
Expect(1, 10176, '\P{Is_Blk=dingbats}', "");
Expect(0, 10176, '\P{^Is_Blk=dingbats}', "");
Expect(1, 10175, '\p{Is_Blk=-_Dingbats}', "");
Expect(0, 10175, '\p{^Is_Blk=-_Dingbats}', "");
Expect(0, 10175, '\P{Is_Blk=-_Dingbats}', "");
Expect(1, 10175, '\P{^Is_Blk=-_Dingbats}', "");
Expect(0, 10176, '\p{Is_Blk=-_Dingbats}', "");
Expect(1, 10176, '\p{^Is_Blk=-_Dingbats}', "");
Expect(1, 10176, '\P{Is_Blk=-_Dingbats}', "");
Expect(0, 10176, '\P{^Is_Blk=-_Dingbats}', "");
Error('\p{Block=:=	domino_tiles}');
Error('\P{Block=:=	domino_tiles}');
Expect(1, 127135, '\p{Block:   dominotiles}', "");
Expect(0, 127135, '\p{^Block:   dominotiles}', "");
Expect(0, 127135, '\P{Block:   dominotiles}', "");
Expect(1, 127135, '\P{^Block:   dominotiles}', "");
Expect(0, 127136, '\p{Block:   dominotiles}', "");
Expect(1, 127136, '\p{^Block:   dominotiles}', "");
Expect(1, 127136, '\P{Block:   dominotiles}', "");
Expect(0, 127136, '\P{^Block:   dominotiles}', "");
Expect(1, 127135, '\p{Block:		_domino_TILES}', "");
Expect(0, 127135, '\p{^Block:		_domino_TILES}', "");
Expect(0, 127135, '\P{Block:		_domino_TILES}', "");
Expect(1, 127135, '\P{^Block:		_domino_TILES}', "");
Expect(0, 127136, '\p{Block:		_domino_TILES}', "");
Expect(1, 127136, '\p{^Block:		_domino_TILES}', "");
Expect(1, 127136, '\P{Block:		_domino_TILES}', "");
Expect(0, 127136, '\P{^Block:		_domino_TILES}', "");
Error('\p{Blk=		Domino/a/}');
Error('\P{Blk=		Domino/a/}');
Expect(1, 127135, '\p{Blk=domino}', "");
Expect(0, 127135, '\p{^Blk=domino}', "");
Expect(0, 127135, '\P{Blk=domino}', "");
Expect(1, 127135, '\P{^Blk=domino}', "");
Expect(0, 127136, '\p{Blk=domino}', "");
Expect(1, 127136, '\p{^Blk=domino}', "");
Expect(1, 127136, '\P{Blk=domino}', "");
Expect(0, 127136, '\P{^Blk=domino}', "");
Expect(1, 127135, '\p{Blk=_	Domino}', "");
Expect(0, 127135, '\p{^Blk=_	Domino}', "");
Expect(0, 127135, '\P{Blk=_	Domino}', "");
Expect(1, 127135, '\P{^Blk=_	Domino}', "");
Expect(0, 127136, '\p{Blk=_	Domino}', "");
Expect(1, 127136, '\p{^Blk=_	Domino}', "");
Expect(1, 127136, '\P{Blk=_	Domino}', "");
Expect(0, 127136, '\P{^Blk=_	Domino}', "");
Error('\p{Is_Block=:=_	Domino_TILES}');
Error('\P{Is_Block=:=_	Domino_TILES}');
Expect(1, 127135, '\p{Is_Block=dominotiles}', "");
Expect(0, 127135, '\p{^Is_Block=dominotiles}', "");
Expect(0, 127135, '\P{Is_Block=dominotiles}', "");
Expect(1, 127135, '\P{^Is_Block=dominotiles}', "");
Expect(0, 127136, '\p{Is_Block=dominotiles}', "");
Expect(1, 127136, '\p{^Is_Block=dominotiles}', "");
Expect(1, 127136, '\P{Is_Block=dominotiles}', "");
Expect(0, 127136, '\P{^Is_Block=dominotiles}', "");
Expect(1, 127135, '\p{Is_Block= _Domino_Tiles}', "");
Expect(0, 127135, '\p{^Is_Block= _Domino_Tiles}', "");
Expect(0, 127135, '\P{Is_Block= _Domino_Tiles}', "");
Expect(1, 127135, '\P{^Is_Block= _Domino_Tiles}', "");
Expect(0, 127136, '\p{Is_Block= _Domino_Tiles}', "");
Expect(1, 127136, '\p{^Is_Block= _Domino_Tiles}', "");
Expect(1, 127136, '\P{Is_Block= _Domino_Tiles}', "");
Expect(0, 127136, '\P{^Is_Block= _Domino_Tiles}', "");
Error('\p{Is_Blk=	:=Domino}');
Error('\P{Is_Blk=	:=Domino}');
Expect(1, 127135, '\p{Is_Blk=domino}', "");
Expect(0, 127135, '\p{^Is_Blk=domino}', "");
Expect(0, 127135, '\P{Is_Blk=domino}', "");
Expect(1, 127135, '\P{^Is_Blk=domino}', "");
Expect(0, 127136, '\p{Is_Blk=domino}', "");
Expect(1, 127136, '\p{^Is_Blk=domino}', "");
Expect(1, 127136, '\P{Is_Blk=domino}', "");
Expect(0, 127136, '\P{^Is_Blk=domino}', "");
Expect(1, 127135, '\p{Is_Blk=-Domino}', "");
Expect(0, 127135, '\p{^Is_Blk=-Domino}', "");
Expect(0, 127135, '\P{Is_Blk=-Domino}', "");
Expect(1, 127135, '\P{^Is_Blk=-Domino}', "");
Expect(0, 127136, '\p{Is_Blk=-Domino}', "");
Expect(1, 127136, '\p{^Is_Blk=-Domino}', "");
Expect(1, 127136, '\P{Is_Blk=-Domino}', "");
Expect(0, 127136, '\P{^Is_Blk=-Domino}', "");
Error('\p{Block=--egyptian_HIEROGLYPHS:=}');
Error('\P{Block=--egyptian_HIEROGLYPHS:=}');
Expect(1, 78895, '\p{Block=egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{^Block=egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{Block=egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{^Block=egyptianhieroglyphs}', "");
Expect(0, 78896, '\p{Block=egyptianhieroglyphs}', "");
Expect(1, 78896, '\p{^Block=egyptianhieroglyphs}', "");
Expect(1, 78896, '\P{Block=egyptianhieroglyphs}', "");
Expect(0, 78896, '\P{^Block=egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{Block=	Egyptian_Hieroglyphs}', "");
Expect(0, 78895, '\p{^Block=	Egyptian_Hieroglyphs}', "");
Expect(0, 78895, '\P{Block=	Egyptian_Hieroglyphs}', "");
Expect(1, 78895, '\P{^Block=	Egyptian_Hieroglyphs}', "");
Expect(0, 78896, '\p{Block=	Egyptian_Hieroglyphs}', "");
Expect(1, 78896, '\p{^Block=	Egyptian_Hieroglyphs}', "");
Expect(1, 78896, '\P{Block=	Egyptian_Hieroglyphs}', "");
Expect(0, 78896, '\P{^Block=	Egyptian_Hieroglyphs}', "");
Error('\p{Blk=_	Egyptian_Hieroglyphs/a/}');
Error('\P{Blk=_	Egyptian_Hieroglyphs/a/}');
Expect(1, 78895, '\p{Blk=egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{^Blk=egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{Blk=egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{^Blk=egyptianhieroglyphs}', "");
Expect(0, 78896, '\p{Blk=egyptianhieroglyphs}', "");
Expect(1, 78896, '\p{^Blk=egyptianhieroglyphs}', "");
Expect(1, 78896, '\P{Blk=egyptianhieroglyphs}', "");
Expect(0, 78896, '\P{^Blk=egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{Blk=_ Egyptian_Hieroglyphs}', "");
Expect(0, 78895, '\p{^Blk=_ Egyptian_Hieroglyphs}', "");
Expect(0, 78895, '\P{Blk=_ Egyptian_Hieroglyphs}', "");
Expect(1, 78895, '\P{^Blk=_ Egyptian_Hieroglyphs}', "");
Expect(0, 78896, '\p{Blk=_ Egyptian_Hieroglyphs}', "");
Expect(1, 78896, '\p{^Blk=_ Egyptian_Hieroglyphs}', "");
Expect(1, 78896, '\P{Blk=_ Egyptian_Hieroglyphs}', "");
Expect(0, 78896, '\P{^Blk=_ Egyptian_Hieroglyphs}', "");
Error('\p{Is_Block=-EGYPTIAN_Hieroglyphs/a/}');
Error('\P{Is_Block=-EGYPTIAN_Hieroglyphs/a/}');
Expect(1, 78895, '\p{Is_Block=egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{^Is_Block=egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{Is_Block=egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{^Is_Block=egyptianhieroglyphs}', "");
Expect(0, 78896, '\p{Is_Block=egyptianhieroglyphs}', "");
Expect(1, 78896, '\p{^Is_Block=egyptianhieroglyphs}', "");
Expect(1, 78896, '\P{Is_Block=egyptianhieroglyphs}', "");
Expect(0, 78896, '\P{^Is_Block=egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{Is_Block=egyptian_Hieroglyphs}', "");
Expect(0, 78895, '\p{^Is_Block=egyptian_Hieroglyphs}', "");
Expect(0, 78895, '\P{Is_Block=egyptian_Hieroglyphs}', "");
Expect(1, 78895, '\P{^Is_Block=egyptian_Hieroglyphs}', "");
Expect(0, 78896, '\p{Is_Block=egyptian_Hieroglyphs}', "");
Expect(1, 78896, '\p{^Is_Block=egyptian_Hieroglyphs}', "");
Expect(1, 78896, '\P{Is_Block=egyptian_Hieroglyphs}', "");
Expect(0, 78896, '\P{^Is_Block=egyptian_Hieroglyphs}', "");
Error('\p{Is_Blk=/a/_ Egyptian_hieroglyphs}');
Error('\P{Is_Blk=/a/_ Egyptian_hieroglyphs}');
Expect(1, 78895, '\p{Is_Blk=egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{^Is_Blk=egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{Is_Blk=egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{^Is_Blk=egyptianhieroglyphs}', "");
Expect(0, 78896, '\p{Is_Blk=egyptianhieroglyphs}', "");
Expect(1, 78896, '\p{^Is_Blk=egyptianhieroglyphs}', "");
Expect(1, 78896, '\P{Is_Blk=egyptianhieroglyphs}', "");
Expect(0, 78896, '\P{^Is_Blk=egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{Is_Blk=	-EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78895, '\p{^Is_Blk=	-EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78895, '\P{Is_Blk=	-EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78895, '\P{^Is_Blk=	-EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78896, '\p{Is_Blk=	-EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78896, '\p{^Is_Blk=	-EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78896, '\P{Is_Blk=	-EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78896, '\P{^Is_Blk=	-EGYPTIAN_Hieroglyphs}', "");
Error('\p{Block=/a/-Emoticons}');
Error('\P{Block=/a/-Emoticons}');
Expect(1, 128591, '\p{Block=emoticons}', "");
Expect(0, 128591, '\p{^Block=emoticons}', "");
Expect(0, 128591, '\P{Block=emoticons}', "");
Expect(1, 128591, '\P{^Block=emoticons}', "");
Expect(0, 128592, '\p{Block=emoticons}', "");
Expect(1, 128592, '\p{^Block=emoticons}', "");
Expect(1, 128592, '\P{Block=emoticons}', "");
Expect(0, 128592, '\P{^Block=emoticons}', "");
Expect(1, 128591, '\p{Block= 	Emoticons}', "");
Expect(0, 128591, '\p{^Block= 	Emoticons}', "");
Expect(0, 128591, '\P{Block= 	Emoticons}', "");
Expect(1, 128591, '\P{^Block= 	Emoticons}', "");
Expect(0, 128592, '\p{Block= 	Emoticons}', "");
Expect(1, 128592, '\p{^Block= 	Emoticons}', "");
Expect(1, 128592, '\P{Block= 	Emoticons}', "");
Expect(0, 128592, '\P{^Block= 	Emoticons}', "");
Error('\p{Blk=-/a/Emoticons}');
Error('\P{Blk=-/a/Emoticons}');
Expect(1, 128591, '\p{Blk=emoticons}', "");
Expect(0, 128591, '\p{^Blk=emoticons}', "");
Expect(0, 128591, '\P{Blk=emoticons}', "");
Expect(1, 128591, '\P{^Blk=emoticons}', "");
Expect(0, 128592, '\p{Blk=emoticons}', "");
Expect(1, 128592, '\p{^Blk=emoticons}', "");
Expect(1, 128592, '\P{Blk=emoticons}', "");
Expect(0, 128592, '\P{^Blk=emoticons}', "");
Expect(1, 128591, '\p{Blk:	_Emoticons}', "");
Expect(0, 128591, '\p{^Blk:	_Emoticons}', "");
Expect(0, 128591, '\P{Blk:	_Emoticons}', "");
Expect(1, 128591, '\P{^Blk:	_Emoticons}', "");
Expect(0, 128592, '\p{Blk:	_Emoticons}', "");
Expect(1, 128592, '\p{^Blk:	_Emoticons}', "");
Expect(1, 128592, '\P{Blk:	_Emoticons}', "");
Expect(0, 128592, '\P{^Blk:	_Emoticons}', "");
Error('\p{Is_Block=- Emoticons:=}');
Error('\P{Is_Block=- Emoticons:=}');
Expect(1, 128591, '\p{Is_Block=emoticons}', "");
Expect(0, 128591, '\p{^Is_Block=emoticons}', "");
Expect(0, 128591, '\P{Is_Block=emoticons}', "");
Expect(1, 128591, '\P{^Is_Block=emoticons}', "");
Expect(0, 128592, '\p{Is_Block=emoticons}', "");
Expect(1, 128592, '\p{^Is_Block=emoticons}', "");
Expect(1, 128592, '\P{Is_Block=emoticons}', "");
Expect(0, 128592, '\P{^Is_Block=emoticons}', "");
Expect(1, 128591, '\p{Is_Block=-EMOTICONS}', "");
Expect(0, 128591, '\p{^Is_Block=-EMOTICONS}', "");
Expect(0, 128591, '\P{Is_Block=-EMOTICONS}', "");
Expect(1, 128591, '\P{^Is_Block=-EMOTICONS}', "");
Expect(0, 128592, '\p{Is_Block=-EMOTICONS}', "");
Expect(1, 128592, '\p{^Is_Block=-EMOTICONS}', "");
Expect(1, 128592, '\P{Is_Block=-EMOTICONS}', "");
Expect(0, 128592, '\P{^Is_Block=-EMOTICONS}', "");
Error('\p{Is_Blk:-/a/Emoticons}');
Error('\P{Is_Blk:-/a/Emoticons}');
Expect(1, 128591, '\p{Is_Blk=emoticons}', "");
Expect(0, 128591, '\p{^Is_Blk=emoticons}', "");
Expect(0, 128591, '\P{Is_Blk=emoticons}', "");
Expect(1, 128591, '\P{^Is_Blk=emoticons}', "");
Expect(0, 128592, '\p{Is_Blk=emoticons}', "");
Expect(1, 128592, '\p{^Is_Blk=emoticons}', "");
Expect(1, 128592, '\P{Is_Blk=emoticons}', "");
Expect(0, 128592, '\P{^Is_Blk=emoticons}', "");
Expect(1, 128591, '\p{Is_Blk=- Emoticons}', "");
Expect(0, 128591, '\p{^Is_Blk=- Emoticons}', "");
Expect(0, 128591, '\P{Is_Blk=- Emoticons}', "");
Expect(1, 128591, '\P{^Is_Blk=- Emoticons}', "");
Expect(0, 128592, '\p{Is_Blk=- Emoticons}', "");
Expect(1, 128592, '\p{^Is_Blk=- Emoticons}', "");
Expect(1, 128592, '\P{Is_Blk=- Emoticons}', "");
Expect(0, 128592, '\P{^Is_Blk=- Emoticons}', "");
Error('\p{Block=	:=enclosed_alphanumerics}');
Error('\P{Block=	:=enclosed_alphanumerics}');
Expect(1, 9471, '\p{Block=enclosedalphanumerics}', "");
Expect(0, 9471, '\p{^Block=enclosedalphanumerics}', "");
Expect(0, 9471, '\P{Block=enclosedalphanumerics}', "");
Expect(1, 9471, '\P{^Block=enclosedalphanumerics}', "");
Expect(0, 9472, '\p{Block=enclosedalphanumerics}', "");
Expect(1, 9472, '\p{^Block=enclosedalphanumerics}', "");
Expect(1, 9472, '\P{Block=enclosedalphanumerics}', "");
Expect(0, 9472, '\P{^Block=enclosedalphanumerics}', "");
Expect(1, 9471, '\p{Block=	Enclosed_alphanumerics}', "");
Expect(0, 9471, '\p{^Block=	Enclosed_alphanumerics}', "");
Expect(0, 9471, '\P{Block=	Enclosed_alphanumerics}', "");
Expect(1, 9471, '\P{^Block=	Enclosed_alphanumerics}', "");
Expect(0, 9472, '\p{Block=	Enclosed_alphanumerics}', "");
Expect(1, 9472, '\p{^Block=	Enclosed_alphanumerics}', "");
Expect(1, 9472, '\P{Block=	Enclosed_alphanumerics}', "");
Expect(0, 9472, '\P{^Block=	Enclosed_alphanumerics}', "");
Error('\p{Blk: := 	Enclosed_Alphanum}');
Error('\P{Blk: := 	Enclosed_Alphanum}');
Expect(1, 9471, '\p{Blk=enclosedalphanum}', "");
Expect(0, 9471, '\p{^Blk=enclosedalphanum}', "");
Expect(0, 9471, '\P{Blk=enclosedalphanum}', "");
Expect(1, 9471, '\P{^Blk=enclosedalphanum}', "");
Expect(0, 9472, '\p{Blk=enclosedalphanum}', "");
Expect(1, 9472, '\p{^Blk=enclosedalphanum}', "");
Expect(1, 9472, '\P{Blk=enclosedalphanum}', "");
Expect(0, 9472, '\P{^Blk=enclosedalphanum}', "");
Expect(1, 9471, '\p{Blk=__Enclosed_ALPHANUM}', "");
Expect(0, 9471, '\p{^Blk=__Enclosed_ALPHANUM}', "");
Expect(0, 9471, '\P{Blk=__Enclosed_ALPHANUM}', "");
Expect(1, 9471, '\P{^Blk=__Enclosed_ALPHANUM}', "");
Expect(0, 9472, '\p{Blk=__Enclosed_ALPHANUM}', "");
Expect(1, 9472, '\p{^Blk=__Enclosed_ALPHANUM}', "");
Expect(1, 9472, '\P{Blk=__Enclosed_ALPHANUM}', "");
Expect(0, 9472, '\P{^Blk=__Enclosed_ALPHANUM}', "");
Error('\p{Is_Block=_Enclosed_ALPHANUMERICS/a/}');
Error('\P{Is_Block=_Enclosed_ALPHANUMERICS/a/}');
Expect(1, 9471, '\p{Is_Block=enclosedalphanumerics}', "");
Expect(0, 9471, '\p{^Is_Block=enclosedalphanumerics}', "");
Expect(0, 9471, '\P{Is_Block=enclosedalphanumerics}', "");
Expect(1, 9471, '\P{^Is_Block=enclosedalphanumerics}', "");
Expect(0, 9472, '\p{Is_Block=enclosedalphanumerics}', "");
Expect(1, 9472, '\p{^Is_Block=enclosedalphanumerics}', "");
Expect(1, 9472, '\P{Is_Block=enclosedalphanumerics}', "");
Expect(0, 9472, '\P{^Is_Block=enclosedalphanumerics}', "");
Expect(1, 9471, '\p{Is_Block=_enclosed_alphanumerics}', "");
Expect(0, 9471, '\p{^Is_Block=_enclosed_alphanumerics}', "");
Expect(0, 9471, '\P{Is_Block=_enclosed_alphanumerics}', "");
Expect(1, 9471, '\P{^Is_Block=_enclosed_alphanumerics}', "");
Expect(0, 9472, '\p{Is_Block=_enclosed_alphanumerics}', "");
Expect(1, 9472, '\p{^Is_Block=_enclosed_alphanumerics}', "");
Expect(1, 9472, '\P{Is_Block=_enclosed_alphanumerics}', "");
Expect(0, 9472, '\P{^Is_Block=_enclosed_alphanumerics}', "");
Error('\p{Is_Blk=	-enclosed_Alphanum:=}');
Error('\P{Is_Blk=	-enclosed_Alphanum:=}');
Expect(1, 9471, '\p{Is_Blk=enclosedalphanum}', "");
Expect(0, 9471, '\p{^Is_Blk=enclosedalphanum}', "");
Expect(0, 9471, '\P{Is_Blk=enclosedalphanum}', "");
Expect(1, 9471, '\P{^Is_Blk=enclosedalphanum}', "");
Expect(0, 9472, '\p{Is_Blk=enclosedalphanum}', "");
Expect(1, 9472, '\p{^Is_Blk=enclosedalphanum}', "");
Expect(1, 9472, '\P{Is_Blk=enclosedalphanum}', "");
Expect(0, 9472, '\P{^Is_Blk=enclosedalphanum}', "");
Expect(1, 9471, '\p{Is_Blk= enclosed_Alphanum}', "");
Expect(0, 9471, '\p{^Is_Blk= enclosed_Alphanum}', "");
Expect(0, 9471, '\P{Is_Blk= enclosed_Alphanum}', "");
Expect(1, 9471, '\P{^Is_Blk= enclosed_Alphanum}', "");
Expect(0, 9472, '\p{Is_Blk= enclosed_Alphanum}', "");
Expect(1, 9472, '\p{^Is_Blk= enclosed_Alphanum}', "");
Expect(1, 9472, '\P{Is_Blk= enclosed_Alphanum}', "");
Expect(0, 9472, '\P{^Is_Blk= enclosed_Alphanum}', "");
Error('\p{Block=_:=ENCLOSED_ALPHANUMERIC_SUPPLEMENT}');
Error('\P{Block=_:=ENCLOSED_ALPHANUMERIC_SUPPLEMENT}');
Expect(1, 127487, '\p{Block:	enclosedalphanumericsupplement}', "");
Expect(0, 127487, '\p{^Block:	enclosedalphanumericsupplement}', "");
Expect(0, 127487, '\P{Block:	enclosedalphanumericsupplement}', "");
Expect(1, 127487, '\P{^Block:	enclosedalphanumericsupplement}', "");
Expect(0, 127488, '\p{Block:	enclosedalphanumericsupplement}', "");
Expect(1, 127488, '\p{^Block:	enclosedalphanumericsupplement}', "");
Expect(1, 127488, '\P{Block:	enclosedalphanumericsupplement}', "");
Expect(0, 127488, '\P{^Block:	enclosedalphanumericsupplement}', "");
Expect(1, 127487, '\p{Block=_-ENCLOSED_ALPHANUMERIC_Supplement}', "");
Expect(0, 127487, '\p{^Block=_-ENCLOSED_ALPHANUMERIC_Supplement}', "");
Expect(0, 127487, '\P{Block=_-ENCLOSED_ALPHANUMERIC_Supplement}', "");
Expect(1, 127487, '\P{^Block=_-ENCLOSED_ALPHANUMERIC_Supplement}', "");
Expect(0, 127488, '\p{Block=_-ENCLOSED_ALPHANUMERIC_Supplement}', "");
Expect(1, 127488, '\p{^Block=_-ENCLOSED_ALPHANUMERIC_Supplement}', "");
Expect(1, 127488, '\P{Block=_-ENCLOSED_ALPHANUMERIC_Supplement}', "");
Expect(0, 127488, '\P{^Block=_-ENCLOSED_ALPHANUMERIC_Supplement}', "");
Error('\p{Blk=-Enclosed_alphanum_sup/a/}');
Error('\P{Blk=-Enclosed_alphanum_sup/a/}');
Expect(1, 127487, '\p{Blk=enclosedalphanumsup}', "");
Expect(0, 127487, '\p{^Blk=enclosedalphanumsup}', "");
Expect(0, 127487, '\P{Blk=enclosedalphanumsup}', "");
Expect(1, 127487, '\P{^Blk=enclosedalphanumsup}', "");
Expect(0, 127488, '\p{Blk=enclosedalphanumsup}', "");
Expect(1, 127488, '\p{^Blk=enclosedalphanumsup}', "");
Expect(1, 127488, '\P{Blk=enclosedalphanumsup}', "");
Expect(0, 127488, '\P{^Blk=enclosedalphanumsup}', "");
Expect(1, 127487, '\p{Blk=-enclosed_Alphanum_Sup}', "");
Expect(0, 127487, '\p{^Blk=-enclosed_Alphanum_Sup}', "");
Expect(0, 127487, '\P{Blk=-enclosed_Alphanum_Sup}', "");
Expect(1, 127487, '\P{^Blk=-enclosed_Alphanum_Sup}', "");
Expect(0, 127488, '\p{Blk=-enclosed_Alphanum_Sup}', "");
Expect(1, 127488, '\p{^Blk=-enclosed_Alphanum_Sup}', "");
Expect(1, 127488, '\P{Blk=-enclosed_Alphanum_Sup}', "");
Expect(0, 127488, '\P{^Blk=-enclosed_Alphanum_Sup}', "");
Error('\p{Is_Block= ENCLOSED_ALPHANUMERIC_Supplement/a/}');
Error('\P{Is_Block= ENCLOSED_ALPHANUMERIC_Supplement/a/}');
Expect(1, 127487, '\p{Is_Block=enclosedalphanumericsupplement}', "");
Expect(0, 127487, '\p{^Is_Block=enclosedalphanumericsupplement}', "");
Expect(0, 127487, '\P{Is_Block=enclosedalphanumericsupplement}', "");
Expect(1, 127487, '\P{^Is_Block=enclosedalphanumericsupplement}', "");
Expect(0, 127488, '\p{Is_Block=enclosedalphanumericsupplement}', "");
Expect(1, 127488, '\p{^Is_Block=enclosedalphanumericsupplement}', "");
Expect(1, 127488, '\P{Is_Block=enclosedalphanumericsupplement}', "");
Expect(0, 127488, '\P{^Is_Block=enclosedalphanumericsupplement}', "");
Expect(1, 127487, '\p{Is_Block=		ENCLOSED_ALPHANUMERIC_Supplement}', "");
Expect(0, 127487, '\p{^Is_Block=		ENCLOSED_ALPHANUMERIC_Supplement}', "");
Expect(0, 127487, '\P{Is_Block=		ENCLOSED_ALPHANUMERIC_Supplement}', "");
Expect(1, 127487, '\P{^Is_Block=		ENCLOSED_ALPHANUMERIC_Supplement}', "");
Expect(0, 127488, '\p{Is_Block=		ENCLOSED_ALPHANUMERIC_Supplement}', "");
Expect(1, 127488, '\p{^Is_Block=		ENCLOSED_ALPHANUMERIC_Supplement}', "");
Expect(1, 127488, '\P{Is_Block=		ENCLOSED_ALPHANUMERIC_Supplement}', "");
Expect(0, 127488, '\P{^Is_Block=		ENCLOSED_ALPHANUMERIC_Supplement}', "");
Error('\p{Is_Blk= _ENCLOSED_Alphanum_sup:=}');
Error('\P{Is_Blk= _ENCLOSED_Alphanum_sup:=}');
Expect(1, 127487, '\p{Is_Blk=enclosedalphanumsup}', "");
Expect(0, 127487, '\p{^Is_Blk=enclosedalphanumsup}', "");
Expect(0, 127487, '\P{Is_Blk=enclosedalphanumsup}', "");
Expect(1, 127487, '\P{^Is_Blk=enclosedalphanumsup}', "");
Expect(0, 127488, '\p{Is_Blk=enclosedalphanumsup}', "");
Expect(1, 127488, '\p{^Is_Blk=enclosedalphanumsup}', "");
Expect(1, 127488, '\P{Is_Blk=enclosedalphanumsup}', "");
Expect(0, 127488, '\P{^Is_Blk=enclosedalphanumsup}', "");
Expect(1, 127487, '\p{Is_Blk=- Enclosed_Alphanum_Sup}', "");
Expect(0, 127487, '\p{^Is_Blk=- Enclosed_Alphanum_Sup}', "");
Expect(0, 127487, '\P{Is_Blk=- Enclosed_Alphanum_Sup}', "");
Expect(1, 127487, '\P{^Is_Blk=- Enclosed_Alphanum_Sup}', "");
Expect(0, 127488, '\p{Is_Blk=- Enclosed_Alphanum_Sup}', "");
Expect(1, 127488, '\p{^Is_Blk=- Enclosed_Alphanum_Sup}', "");
Expect(1, 127488, '\P{Is_Blk=- Enclosed_Alphanum_Sup}', "");
Expect(0, 127488, '\P{^Is_Blk=- Enclosed_Alphanum_Sup}', "");
Error('\p{Block=/a/Enclosed_CJK_LETTERS_And_MONTHS}');
Error('\P{Block=/a/Enclosed_CJK_LETTERS_And_MONTHS}');
Expect(1, 13055, '\p{Block=enclosedcjklettersandmonths}', "");
Expect(0, 13055, '\p{^Block=enclosedcjklettersandmonths}', "");
Expect(0, 13055, '\P{Block=enclosedcjklettersandmonths}', "");
Expect(1, 13055, '\P{^Block=enclosedcjklettersandmonths}', "");
Expect(0, 13056, '\p{Block=enclosedcjklettersandmonths}', "");
Expect(1, 13056, '\p{^Block=enclosedcjklettersandmonths}', "");
Expect(1, 13056, '\P{Block=enclosedcjklettersandmonths}', "");
Expect(0, 13056, '\P{^Block=enclosedcjklettersandmonths}', "");
Expect(1, 13055, '\p{Block=_enclosed_cjk_LETTERS_And_Months}', "");
Expect(0, 13055, '\p{^Block=_enclosed_cjk_LETTERS_And_Months}', "");
Expect(0, 13055, '\P{Block=_enclosed_cjk_LETTERS_And_Months}', "");
Expect(1, 13055, '\P{^Block=_enclosed_cjk_LETTERS_And_Months}', "");
Expect(0, 13056, '\p{Block=_enclosed_cjk_LETTERS_And_Months}', "");
Expect(1, 13056, '\p{^Block=_enclosed_cjk_LETTERS_And_Months}', "");
Expect(1, 13056, '\P{Block=_enclosed_cjk_LETTERS_And_Months}', "");
Expect(0, 13056, '\P{^Block=_enclosed_cjk_LETTERS_And_Months}', "");
Error('\p{Blk= 	ENCLOSED_cjk:=}');
Error('\P{Blk= 	ENCLOSED_cjk:=}');
Expect(1, 13055, '\p{Blk=enclosedcjk}', "");
Expect(0, 13055, '\p{^Blk=enclosedcjk}', "");
Expect(0, 13055, '\P{Blk=enclosedcjk}', "");
Expect(1, 13055, '\P{^Blk=enclosedcjk}', "");
Expect(0, 13056, '\p{Blk=enclosedcjk}', "");
Expect(1, 13056, '\p{^Blk=enclosedcjk}', "");
Expect(1, 13056, '\P{Blk=enclosedcjk}', "");
Expect(0, 13056, '\P{^Blk=enclosedcjk}', "");
Expect(1, 13055, '\p{Blk=-ENCLOSED_CJK}', "");
Expect(0, 13055, '\p{^Blk=-ENCLOSED_CJK}', "");
Expect(0, 13055, '\P{Blk=-ENCLOSED_CJK}', "");
Expect(1, 13055, '\P{^Blk=-ENCLOSED_CJK}', "");
Expect(0, 13056, '\p{Blk=-ENCLOSED_CJK}', "");
Expect(1, 13056, '\p{^Blk=-ENCLOSED_CJK}', "");
Expect(1, 13056, '\P{Blk=-ENCLOSED_CJK}', "");
Expect(0, 13056, '\P{^Blk=-ENCLOSED_CJK}', "");
Error('\p{Is_Block= 	ENCLOSED_cjk_LETTERS_and_Months:=}');
Error('\P{Is_Block= 	ENCLOSED_cjk_LETTERS_and_Months:=}');
Expect(1, 13055, '\p{Is_Block=enclosedcjklettersandmonths}', "");
Expect(0, 13055, '\p{^Is_Block=enclosedcjklettersandmonths}', "");
Expect(0, 13055, '\P{Is_Block=enclosedcjklettersandmonths}', "");
Expect(1, 13055, '\P{^Is_Block=enclosedcjklettersandmonths}', "");
Expect(0, 13056, '\p{Is_Block=enclosedcjklettersandmonths}', "");
Expect(1, 13056, '\p{^Is_Block=enclosedcjklettersandmonths}', "");
Expect(1, 13056, '\P{Is_Block=enclosedcjklettersandmonths}', "");
Expect(0, 13056, '\P{^Is_Block=enclosedcjklettersandmonths}', "");
Expect(1, 13055, '\p{Is_Block=_ENCLOSED_CJK_Letters_And_months}', "");
Expect(0, 13055, '\p{^Is_Block=_ENCLOSED_CJK_Letters_And_months}', "");
Expect(0, 13055, '\P{Is_Block=_ENCLOSED_CJK_Letters_And_months}', "");
Expect(1, 13055, '\P{^Is_Block=_ENCLOSED_CJK_Letters_And_months}', "");
Expect(0, 13056, '\p{Is_Block=_ENCLOSED_CJK_Letters_And_months}', "");
Expect(1, 13056, '\p{^Is_Block=_ENCLOSED_CJK_Letters_And_months}', "");
Expect(1, 13056, '\P{Is_Block=_ENCLOSED_CJK_Letters_And_months}', "");
Expect(0, 13056, '\P{^Is_Block=_ENCLOSED_CJK_Letters_And_months}', "");
Error('\p{Is_Blk= enclosed_CJK:=}');
Error('\P{Is_Blk= enclosed_CJK:=}');
Expect(1, 13055, '\p{Is_Blk=enclosedcjk}', "");
Expect(0, 13055, '\p{^Is_Blk=enclosedcjk}', "");
Expect(0, 13055, '\P{Is_Blk=enclosedcjk}', "");
Expect(1, 13055, '\P{^Is_Blk=enclosedcjk}', "");
Expect(0, 13056, '\p{Is_Blk=enclosedcjk}', "");
Expect(1, 13056, '\p{^Is_Blk=enclosedcjk}', "");
Expect(1, 13056, '\P{Is_Blk=enclosedcjk}', "");
Expect(0, 13056, '\P{^Is_Blk=enclosedcjk}', "");
Expect(1, 13055, '\p{Is_Blk=	ENCLOSED_CJK}', "");
Expect(0, 13055, '\p{^Is_Blk=	ENCLOSED_CJK}', "");
Expect(0, 13055, '\P{Is_Blk=	ENCLOSED_CJK}', "");
Expect(1, 13055, '\P{^Is_Blk=	ENCLOSED_CJK}', "");
Expect(0, 13056, '\p{Is_Blk=	ENCLOSED_CJK}', "");
Expect(1, 13056, '\p{^Is_Blk=	ENCLOSED_CJK}', "");
Expect(1, 13056, '\P{Is_Blk=	ENCLOSED_CJK}', "");
Expect(0, 13056, '\P{^Is_Blk=	ENCLOSED_CJK}', "");
Error('\p{Block=_ Enclosed_Ideographic_Supplement/a/}');
Error('\P{Block=_ Enclosed_Ideographic_Supplement/a/}');
Expect(1, 127743, '\p{Block=enclosedideographicsupplement}', "");
Expect(0, 127743, '\p{^Block=enclosedideographicsupplement}', "");
Expect(0, 127743, '\P{Block=enclosedideographicsupplement}', "");
Expect(1, 127743, '\P{^Block=enclosedideographicsupplement}', "");
Expect(0, 127744, '\p{Block=enclosedideographicsupplement}', "");
Expect(1, 127744, '\p{^Block=enclosedideographicsupplement}', "");
Expect(1, 127744, '\P{Block=enclosedideographicsupplement}', "");
Expect(0, 127744, '\P{^Block=enclosedideographicsupplement}', "");
Expect(1, 127743, '\p{Block= Enclosed_ideographic_Supplement}', "");
Expect(0, 127743, '\p{^Block= Enclosed_ideographic_Supplement}', "");
Expect(0, 127743, '\P{Block= Enclosed_ideographic_Supplement}', "");
Expect(1, 127743, '\P{^Block= Enclosed_ideographic_Supplement}', "");
Expect(0, 127744, '\p{Block= Enclosed_ideographic_Supplement}', "");
Expect(1, 127744, '\p{^Block= Enclosed_ideographic_Supplement}', "");
Expect(1, 127744, '\P{Block= Enclosed_ideographic_Supplement}', "");
Expect(0, 127744, '\P{^Block= Enclosed_ideographic_Supplement}', "");
Error('\p{Blk=-:=enclosed_Ideographic_Sup}');
Error('\P{Blk=-:=enclosed_Ideographic_Sup}');
Expect(1, 127743, '\p{Blk=enclosedideographicsup}', "");
Expect(0, 127743, '\p{^Blk=enclosedideographicsup}', "");
Expect(0, 127743, '\P{Blk=enclosedideographicsup}', "");
Expect(1, 127743, '\P{^Blk=enclosedideographicsup}', "");
Expect(0, 127744, '\p{Blk=enclosedideographicsup}', "");
Expect(1, 127744, '\p{^Blk=enclosedideographicsup}', "");
Expect(1, 127744, '\P{Blk=enclosedideographicsup}', "");
Expect(0, 127744, '\P{^Blk=enclosedideographicsup}', "");
Expect(1, 127743, '\p{Blk=	Enclosed_IDEOGRAPHIC_SUP}', "");
Expect(0, 127743, '\p{^Blk=	Enclosed_IDEOGRAPHIC_SUP}', "");
Expect(0, 127743, '\P{Blk=	Enclosed_IDEOGRAPHIC_SUP}', "");
Expect(1, 127743, '\P{^Blk=	Enclosed_IDEOGRAPHIC_SUP}', "");
Expect(0, 127744, '\p{Blk=	Enclosed_IDEOGRAPHIC_SUP}', "");
Expect(1, 127744, '\p{^Blk=	Enclosed_IDEOGRAPHIC_SUP}', "");
Expect(1, 127744, '\P{Blk=	Enclosed_IDEOGRAPHIC_SUP}', "");
Expect(0, 127744, '\P{^Blk=	Enclosed_IDEOGRAPHIC_SUP}', "");
Error('\p{Is_Block=-/a/Enclosed_Ideographic_Supplement}');
Error('\P{Is_Block=-/a/Enclosed_Ideographic_Supplement}');
Expect(1, 127743, '\p{Is_Block=enclosedideographicsupplement}', "");
Expect(0, 127743, '\p{^Is_Block=enclosedideographicsupplement}', "");
Expect(0, 127743, '\P{Is_Block=enclosedideographicsupplement}', "");
Expect(1, 127743, '\P{^Is_Block=enclosedideographicsupplement}', "");
Expect(0, 127744, '\p{Is_Block=enclosedideographicsupplement}', "");
Expect(1, 127744, '\p{^Is_Block=enclosedideographicsupplement}', "");
Expect(1, 127744, '\P{Is_Block=enclosedideographicsupplement}', "");
Expect(0, 127744, '\P{^Is_Block=enclosedideographicsupplement}', "");
Expect(1, 127743, '\p{Is_Block=_ ENCLOSED_Ideographic_SUPPLEMENT}', "");
Expect(0, 127743, '\p{^Is_Block=_ ENCLOSED_Ideographic_SUPPLEMENT}', "");
Expect(0, 127743, '\P{Is_Block=_ ENCLOSED_Ideographic_SUPPLEMENT}', "");
Expect(1, 127743, '\P{^Is_Block=_ ENCLOSED_Ideographic_SUPPLEMENT}', "");
Expect(0, 127744, '\p{Is_Block=_ ENCLOSED_Ideographic_SUPPLEMENT}', "");
Expect(1, 127744, '\p{^Is_Block=_ ENCLOSED_Ideographic_SUPPLEMENT}', "");
Expect(1, 127744, '\P{Is_Block=_ ENCLOSED_Ideographic_SUPPLEMENT}', "");
Expect(0, 127744, '\P{^Is_Block=_ ENCLOSED_Ideographic_SUPPLEMENT}', "");
Error('\p{Is_Blk= :=enclosed_IDEOGRAPHIC_Sup}');
Error('\P{Is_Blk= :=enclosed_IDEOGRAPHIC_Sup}');
Expect(1, 127743, '\p{Is_Blk=enclosedideographicsup}', "");
Expect(0, 127743, '\p{^Is_Blk=enclosedideographicsup}', "");
Expect(0, 127743, '\P{Is_Blk=enclosedideographicsup}', "");
Expect(1, 127743, '\P{^Is_Blk=enclosedideographicsup}', "");
Expect(0, 127744, '\p{Is_Blk=enclosedideographicsup}', "");
Expect(1, 127744, '\p{^Is_Blk=enclosedideographicsup}', "");
Expect(1, 127744, '\P{Is_Blk=enclosedideographicsup}', "");
Expect(0, 127744, '\P{^Is_Blk=enclosedideographicsup}', "");
Expect(1, 127743, '\p{Is_Blk= _ENCLOSED_Ideographic_SUP}', "");
Expect(0, 127743, '\p{^Is_Blk= _ENCLOSED_Ideographic_SUP}', "");
Expect(0, 127743, '\P{Is_Blk= _ENCLOSED_Ideographic_SUP}', "");
Expect(1, 127743, '\P{^Is_Blk= _ENCLOSED_Ideographic_SUP}', "");
Expect(0, 127744, '\p{Is_Blk= _ENCLOSED_Ideographic_SUP}', "");
Expect(1, 127744, '\p{^Is_Blk= _ENCLOSED_Ideographic_SUP}', "");
Expect(1, 127744, '\P{Is_Blk= _ENCLOSED_Ideographic_SUP}', "");
Expect(0, 127744, '\P{^Is_Blk= _ENCLOSED_Ideographic_SUP}', "");
Error('\p{Block=:=_ethiopic}');
Error('\P{Block=:=_ethiopic}');
Expect(1, 4991, '\p{Block=ethiopic}', "");
Expect(0, 4991, '\p{^Block=ethiopic}', "");
Expect(0, 4991, '\P{Block=ethiopic}', "");
Expect(1, 4991, '\P{^Block=ethiopic}', "");
Expect(0, 4992, '\p{Block=ethiopic}', "");
Expect(1, 4992, '\p{^Block=ethiopic}', "");
Expect(1, 4992, '\P{Block=ethiopic}', "");
Expect(0, 4992, '\P{^Block=ethiopic}', "");
Expect(1, 4991, '\p{Block=  Ethiopic}', "");
Expect(0, 4991, '\p{^Block=  Ethiopic}', "");
Expect(0, 4991, '\P{Block=  Ethiopic}', "");
Expect(1, 4991, '\P{^Block=  Ethiopic}', "");
Expect(0, 4992, '\p{Block=  Ethiopic}', "");
Expect(1, 4992, '\p{^Block=  Ethiopic}', "");
Expect(1, 4992, '\P{Block=  Ethiopic}', "");
Expect(0, 4992, '\P{^Block=  Ethiopic}', "");
Error('\p{Blk=/a/Ethiopic}');
Error('\P{Blk=/a/Ethiopic}');
Expect(1, 4991, '\p{Blk=ethiopic}', "");
Expect(0, 4991, '\p{^Blk=ethiopic}', "");
Expect(0, 4991, '\P{Blk=ethiopic}', "");
Expect(1, 4991, '\P{^Blk=ethiopic}', "");
Expect(0, 4992, '\p{Blk=ethiopic}', "");
Expect(1, 4992, '\p{^Blk=ethiopic}', "");
Expect(1, 4992, '\P{Blk=ethiopic}', "");
Expect(0, 4992, '\P{^Blk=ethiopic}', "");
Expect(1, 4991, '\p{Blk=-ETHIOPIC}', "");
Expect(0, 4991, '\p{^Blk=-ETHIOPIC}', "");
Expect(0, 4991, '\P{Blk=-ETHIOPIC}', "");
Expect(1, 4991, '\P{^Blk=-ETHIOPIC}', "");
Expect(0, 4992, '\p{Blk=-ETHIOPIC}', "");
Expect(1, 4992, '\p{^Blk=-ETHIOPIC}', "");
Expect(1, 4992, '\P{Blk=-ETHIOPIC}', "");
Expect(0, 4992, '\P{^Blk=-ETHIOPIC}', "");
Error('\p{Is_Block=-_Ethiopic/a/}');
Error('\P{Is_Block=-_Ethiopic/a/}');
Expect(1, 4991, '\p{Is_Block=ethiopic}', "");
Expect(0, 4991, '\p{^Is_Block=ethiopic}', "");
Expect(0, 4991, '\P{Is_Block=ethiopic}', "");
Expect(1, 4991, '\P{^Is_Block=ethiopic}', "");
Expect(0, 4992, '\p{Is_Block=ethiopic}', "");
Expect(1, 4992, '\p{^Is_Block=ethiopic}', "");
Expect(1, 4992, '\P{Is_Block=ethiopic}', "");
Expect(0, 4992, '\P{^Is_Block=ethiopic}', "");
Expect(1, 4991, '\p{Is_Block=  Ethiopic}', "");
Expect(0, 4991, '\p{^Is_Block=  Ethiopic}', "");
Expect(0, 4991, '\P{Is_Block=  Ethiopic}', "");
Expect(1, 4991, '\P{^Is_Block=  Ethiopic}', "");
Expect(0, 4992, '\p{Is_Block=  Ethiopic}', "");
Expect(1, 4992, '\p{^Is_Block=  Ethiopic}', "");
Expect(1, 4992, '\P{Is_Block=  Ethiopic}', "");
Expect(0, 4992, '\P{^Is_Block=  Ethiopic}', "");
Error('\p{Is_Blk=	/a/Ethiopic}');
Error('\P{Is_Blk=	/a/Ethiopic}');
Expect(1, 4991, '\p{Is_Blk:ethiopic}', "");
Expect(0, 4991, '\p{^Is_Blk:ethiopic}', "");
Expect(0, 4991, '\P{Is_Blk:ethiopic}', "");
Expect(1, 4991, '\P{^Is_Blk:ethiopic}', "");
Expect(0, 4992, '\p{Is_Blk:ethiopic}', "");
Expect(1, 4992, '\p{^Is_Blk:ethiopic}', "");
Expect(1, 4992, '\P{Is_Blk:ethiopic}', "");
Expect(0, 4992, '\P{^Is_Blk:ethiopic}', "");
Expect(1, 4991, '\p{Is_Blk=--Ethiopic}', "");
Expect(0, 4991, '\p{^Is_Blk=--Ethiopic}', "");
Expect(0, 4991, '\P{Is_Blk=--Ethiopic}', "");
Expect(1, 4991, '\P{^Is_Blk=--Ethiopic}', "");
Expect(0, 4992, '\p{Is_Blk=--Ethiopic}', "");
Expect(1, 4992, '\p{^Is_Blk=--Ethiopic}', "");
Expect(1, 4992, '\P{Is_Blk=--Ethiopic}', "");
Expect(0, 4992, '\P{^Is_Blk=--Ethiopic}', "");
Error('\p{Block=:=	Ethiopic_extended}');
Error('\P{Block=:=	Ethiopic_extended}');
Expect(1, 11743, '\p{Block=ethiopicextended}', "");
Expect(0, 11743, '\p{^Block=ethiopicextended}', "");
Expect(0, 11743, '\P{Block=ethiopicextended}', "");
Expect(1, 11743, '\P{^Block=ethiopicextended}', "");
Expect(0, 11744, '\p{Block=ethiopicextended}', "");
Expect(1, 11744, '\p{^Block=ethiopicextended}', "");
Expect(1, 11744, '\P{Block=ethiopicextended}', "");
Expect(0, 11744, '\P{^Block=ethiopicextended}', "");
Expect(1, 11743, '\p{Block=- ethiopic_extended}', "");
Expect(0, 11743, '\p{^Block=- ethiopic_extended}', "");
Expect(0, 11743, '\P{Block=- ethiopic_extended}', "");
Expect(1, 11743, '\P{^Block=- ethiopic_extended}', "");
Expect(0, 11744, '\p{Block=- ethiopic_extended}', "");
Expect(1, 11744, '\p{^Block=- ethiopic_extended}', "");
Expect(1, 11744, '\P{Block=- ethiopic_extended}', "");
Expect(0, 11744, '\P{^Block=- ethiopic_extended}', "");
Error('\p{Blk=:=_-ETHIOPIC_EXT}');
Error('\P{Blk=:=_-ETHIOPIC_EXT}');
Expect(1, 11743, '\p{Blk=ethiopicext}', "");
Expect(0, 11743, '\p{^Blk=ethiopicext}', "");
Expect(0, 11743, '\P{Blk=ethiopicext}', "");
Expect(1, 11743, '\P{^Blk=ethiopicext}', "");
Expect(0, 11744, '\p{Blk=ethiopicext}', "");
Expect(1, 11744, '\p{^Blk=ethiopicext}', "");
Expect(1, 11744, '\P{Blk=ethiopicext}', "");
Expect(0, 11744, '\P{^Blk=ethiopicext}', "");
Expect(1, 11743, '\p{Blk=	 Ethiopic_ext}', "");
Expect(0, 11743, '\p{^Blk=	 Ethiopic_ext}', "");
Expect(0, 11743, '\P{Blk=	 Ethiopic_ext}', "");
Expect(1, 11743, '\P{^Blk=	 Ethiopic_ext}', "");
Expect(0, 11744, '\p{Blk=	 Ethiopic_ext}', "");
Expect(1, 11744, '\p{^Blk=	 Ethiopic_ext}', "");
Expect(1, 11744, '\P{Blk=	 Ethiopic_ext}', "");
Expect(0, 11744, '\P{^Blk=	 Ethiopic_ext}', "");
Error('\p{Is_Block=:=_ ethiopic_Extended}');
Error('\P{Is_Block=:=_ ethiopic_Extended}');
Expect(1, 11743, '\p{Is_Block=ethiopicextended}', "");
Expect(0, 11743, '\p{^Is_Block=ethiopicextended}', "");
Expect(0, 11743, '\P{Is_Block=ethiopicextended}', "");
Expect(1, 11743, '\P{^Is_Block=ethiopicextended}', "");
Expect(0, 11744, '\p{Is_Block=ethiopicextended}', "");
Expect(1, 11744, '\p{^Is_Block=ethiopicextended}', "");
Expect(1, 11744, '\P{Is_Block=ethiopicextended}', "");
Expect(0, 11744, '\P{^Is_Block=ethiopicextended}', "");
Expect(1, 11743, '\p{Is_Block:   	ethiopic_EXTENDED}', "");
Expect(0, 11743, '\p{^Is_Block:   	ethiopic_EXTENDED}', "");
Expect(0, 11743, '\P{Is_Block:   	ethiopic_EXTENDED}', "");
Expect(1, 11743, '\P{^Is_Block:   	ethiopic_EXTENDED}', "");
Expect(0, 11744, '\p{Is_Block:   	ethiopic_EXTENDED}', "");
Expect(1, 11744, '\p{^Is_Block:   	ethiopic_EXTENDED}', "");
Expect(1, 11744, '\P{Is_Block:   	ethiopic_EXTENDED}', "");
Expect(0, 11744, '\P{^Is_Block:   	ethiopic_EXTENDED}', "");
Error('\p{Is_Blk:   	 ETHIOPIC_ext/a/}');
Error('\P{Is_Blk:   	 ETHIOPIC_ext/a/}');
Expect(1, 11743, '\p{Is_Blk=ethiopicext}', "");
Expect(0, 11743, '\p{^Is_Blk=ethiopicext}', "");
Expect(0, 11743, '\P{Is_Blk=ethiopicext}', "");
Expect(1, 11743, '\P{^Is_Blk=ethiopicext}', "");
Expect(0, 11744, '\p{Is_Blk=ethiopicext}', "");
Expect(1, 11744, '\p{^Is_Blk=ethiopicext}', "");
Expect(1, 11744, '\P{Is_Blk=ethiopicext}', "");
Expect(0, 11744, '\P{^Is_Blk=ethiopicext}', "");
Expect(1, 11743, '\p{Is_Blk= _ethiopic_Ext}', "");
Expect(0, 11743, '\p{^Is_Blk= _ethiopic_Ext}', "");
Expect(0, 11743, '\P{Is_Blk= _ethiopic_Ext}', "");
Expect(1, 11743, '\P{^Is_Blk= _ethiopic_Ext}', "");
Expect(0, 11744, '\p{Is_Blk= _ethiopic_Ext}', "");
Expect(1, 11744, '\p{^Is_Blk= _ethiopic_Ext}', "");
Expect(1, 11744, '\P{Is_Blk= _ethiopic_Ext}', "");
Expect(0, 11744, '\P{^Is_Blk= _ethiopic_Ext}', "");
Error('\p{Block=:=_ETHIOPIC_extended_A}');
Error('\P{Block=:=_ETHIOPIC_extended_A}');
Expect(1, 43823, '\p{Block=ethiopicextendeda}', "");
Expect(0, 43823, '\p{^Block=ethiopicextendeda}', "");
Expect(0, 43823, '\P{Block=ethiopicextendeda}', "");
Expect(1, 43823, '\P{^Block=ethiopicextendeda}', "");
Expect(0, 43824, '\p{Block=ethiopicextendeda}', "");
Expect(1, 43824, '\p{^Block=ethiopicextendeda}', "");
Expect(1, 43824, '\P{Block=ethiopicextendeda}', "");
Expect(0, 43824, '\P{^Block=ethiopicextendeda}', "");
Expect(1, 43823, '\p{Block=_ Ethiopic_EXTENDED_a}', "");
Expect(0, 43823, '\p{^Block=_ Ethiopic_EXTENDED_a}', "");
Expect(0, 43823, '\P{Block=_ Ethiopic_EXTENDED_a}', "");
Expect(1, 43823, '\P{^Block=_ Ethiopic_EXTENDED_a}', "");
Expect(0, 43824, '\p{Block=_ Ethiopic_EXTENDED_a}', "");
Expect(1, 43824, '\p{^Block=_ Ethiopic_EXTENDED_a}', "");
Expect(1, 43824, '\P{Block=_ Ethiopic_EXTENDED_a}', "");
Expect(0, 43824, '\P{^Block=_ Ethiopic_EXTENDED_a}', "");
Error('\p{Blk=		ETHIOPIC_EXT_A/a/}');
Error('\P{Blk=		ETHIOPIC_EXT_A/a/}');
Expect(1, 43823, '\p{Blk=ethiopicexta}', "");
Expect(0, 43823, '\p{^Blk=ethiopicexta}', "");
Expect(0, 43823, '\P{Blk=ethiopicexta}', "");
Expect(1, 43823, '\P{^Blk=ethiopicexta}', "");
Expect(0, 43824, '\p{Blk=ethiopicexta}', "");
Expect(1, 43824, '\p{^Blk=ethiopicexta}', "");
Expect(1, 43824, '\P{Blk=ethiopicexta}', "");
Expect(0, 43824, '\P{^Blk=ethiopicexta}', "");
Expect(1, 43823, '\p{Blk= 	Ethiopic_ext_A}', "");
Expect(0, 43823, '\p{^Blk= 	Ethiopic_ext_A}', "");
Expect(0, 43823, '\P{Blk= 	Ethiopic_ext_A}', "");
Expect(1, 43823, '\P{^Blk= 	Ethiopic_ext_A}', "");
Expect(0, 43824, '\p{Blk= 	Ethiopic_ext_A}', "");
Expect(1, 43824, '\p{^Blk= 	Ethiopic_ext_A}', "");
Expect(1, 43824, '\P{Blk= 	Ethiopic_ext_A}', "");
Expect(0, 43824, '\P{^Blk= 	Ethiopic_ext_A}', "");
Error('\p{Is_Block=:=Ethiopic_extended_A}');
Error('\P{Is_Block=:=Ethiopic_extended_A}');
Expect(1, 43823, '\p{Is_Block=ethiopicextendeda}', "");
Expect(0, 43823, '\p{^Is_Block=ethiopicextendeda}', "");
Expect(0, 43823, '\P{Is_Block=ethiopicextendeda}', "");
Expect(1, 43823, '\P{^Is_Block=ethiopicextendeda}', "");
Expect(0, 43824, '\p{Is_Block=ethiopicextendeda}', "");
Expect(1, 43824, '\p{^Is_Block=ethiopicextendeda}', "");
Expect(1, 43824, '\P{Is_Block=ethiopicextendeda}', "");
Expect(0, 43824, '\P{^Is_Block=ethiopicextendeda}', "");
Expect(1, 43823, '\p{Is_Block= _ETHIOPIC_EXTENDED_A}', "");
Expect(0, 43823, '\p{^Is_Block= _ETHIOPIC_EXTENDED_A}', "");
Expect(0, 43823, '\P{Is_Block= _ETHIOPIC_EXTENDED_A}', "");
Expect(1, 43823, '\P{^Is_Block= _ETHIOPIC_EXTENDED_A}', "");
Expect(0, 43824, '\p{Is_Block= _ETHIOPIC_EXTENDED_A}', "");
Expect(1, 43824, '\p{^Is_Block= _ETHIOPIC_EXTENDED_A}', "");
Expect(1, 43824, '\P{Is_Block= _ETHIOPIC_EXTENDED_A}', "");
Expect(0, 43824, '\P{^Is_Block= _ETHIOPIC_EXTENDED_A}', "");
Error('\p{Is_Blk=:=ethiopic_Ext_A}');
Error('\P{Is_Blk=:=ethiopic_Ext_A}');
Expect(1, 43823, '\p{Is_Blk=ethiopicexta}', "");
Expect(0, 43823, '\p{^Is_Blk=ethiopicexta}', "");
Expect(0, 43823, '\P{Is_Blk=ethiopicexta}', "");
Expect(1, 43823, '\P{^Is_Blk=ethiopicexta}', "");
Expect(0, 43824, '\p{Is_Blk=ethiopicexta}', "");
Expect(1, 43824, '\p{^Is_Blk=ethiopicexta}', "");
Expect(1, 43824, '\P{Is_Blk=ethiopicexta}', "");
Expect(0, 43824, '\P{^Is_Blk=ethiopicexta}', "");
Expect(1, 43823, '\p{Is_Blk=	_Ethiopic_EXT_A}', "");
Expect(0, 43823, '\p{^Is_Blk=	_Ethiopic_EXT_A}', "");
Expect(0, 43823, '\P{Is_Blk=	_Ethiopic_EXT_A}', "");
Expect(1, 43823, '\P{^Is_Blk=	_Ethiopic_EXT_A}', "");
Expect(0, 43824, '\p{Is_Blk=	_Ethiopic_EXT_A}', "");
Expect(1, 43824, '\p{^Is_Blk=	_Ethiopic_EXT_A}', "");
Expect(1, 43824, '\P{Is_Blk=	_Ethiopic_EXT_A}', "");
Expect(0, 43824, '\P{^Is_Blk=	_Ethiopic_EXT_A}', "");
Error('\p{Block=	_ethiopic_Supplement:=}');
Error('\P{Block=	_ethiopic_Supplement:=}');
Expect(1, 5023, '\p{Block=ethiopicsupplement}', "");
Expect(0, 5023, '\p{^Block=ethiopicsupplement}', "");
Expect(0, 5023, '\P{Block=ethiopicsupplement}', "");
Expect(1, 5023, '\P{^Block=ethiopicsupplement}', "");
Expect(0, 5024, '\p{Block=ethiopicsupplement}', "");
Expect(1, 5024, '\p{^Block=ethiopicsupplement}', "");
Expect(1, 5024, '\P{Block=ethiopicsupplement}', "");
Expect(0, 5024, '\P{^Block=ethiopicsupplement}', "");
Expect(1, 5023, '\p{Block=_	ethiopic_Supplement}', "");
Expect(0, 5023, '\p{^Block=_	ethiopic_Supplement}', "");
Expect(0, 5023, '\P{Block=_	ethiopic_Supplement}', "");
Expect(1, 5023, '\P{^Block=_	ethiopic_Supplement}', "");
Expect(0, 5024, '\p{Block=_	ethiopic_Supplement}', "");
Expect(1, 5024, '\p{^Block=_	ethiopic_Supplement}', "");
Expect(1, 5024, '\P{Block=_	ethiopic_Supplement}', "");
Expect(0, 5024, '\P{^Block=_	ethiopic_Supplement}', "");
Error('\p{Blk=-/a/Ethiopic_sup}');
Error('\P{Blk=-/a/Ethiopic_sup}');
Expect(1, 5023, '\p{Blk=ethiopicsup}', "");
Expect(0, 5023, '\p{^Blk=ethiopicsup}', "");
Expect(0, 5023, '\P{Blk=ethiopicsup}', "");
Expect(1, 5023, '\P{^Blk=ethiopicsup}', "");
Expect(0, 5024, '\p{Blk=ethiopicsup}', "");
Expect(1, 5024, '\p{^Blk=ethiopicsup}', "");
Expect(1, 5024, '\P{Blk=ethiopicsup}', "");
Expect(0, 5024, '\P{^Blk=ethiopicsup}', "");
Expect(1, 5023, '\p{Blk=__ETHIOPIC_Sup}', "");
Expect(0, 5023, '\p{^Blk=__ETHIOPIC_Sup}', "");
Expect(0, 5023, '\P{Blk=__ETHIOPIC_Sup}', "");
Expect(1, 5023, '\P{^Blk=__ETHIOPIC_Sup}', "");
Expect(0, 5024, '\p{Blk=__ETHIOPIC_Sup}', "");
Expect(1, 5024, '\p{^Blk=__ETHIOPIC_Sup}', "");
Expect(1, 5024, '\P{Blk=__ETHIOPIC_Sup}', "");
Expect(0, 5024, '\P{^Blk=__ETHIOPIC_Sup}', "");
Error('\p{Is_Block=-/a/ETHIOPIC_Supplement}');
Error('\P{Is_Block=-/a/ETHIOPIC_Supplement}');
Expect(1, 5023, '\p{Is_Block=ethiopicsupplement}', "");
Expect(0, 5023, '\p{^Is_Block=ethiopicsupplement}', "");
Expect(0, 5023, '\P{Is_Block=ethiopicsupplement}', "");
Expect(1, 5023, '\P{^Is_Block=ethiopicsupplement}', "");
Expect(0, 5024, '\p{Is_Block=ethiopicsupplement}', "");
Expect(1, 5024, '\p{^Is_Block=ethiopicsupplement}', "");
Expect(1, 5024, '\P{Is_Block=ethiopicsupplement}', "");
Expect(0, 5024, '\P{^Is_Block=ethiopicsupplement}', "");
Expect(1, 5023, '\p{Is_Block=	_ethiopic_SUPPLEMENT}', "");
Expect(0, 5023, '\p{^Is_Block=	_ethiopic_SUPPLEMENT}', "");
Expect(0, 5023, '\P{Is_Block=	_ethiopic_SUPPLEMENT}', "");
Expect(1, 5023, '\P{^Is_Block=	_ethiopic_SUPPLEMENT}', "");
Expect(0, 5024, '\p{Is_Block=	_ethiopic_SUPPLEMENT}', "");
Expect(1, 5024, '\p{^Is_Block=	_ethiopic_SUPPLEMENT}', "");
Expect(1, 5024, '\P{Is_Block=	_ethiopic_SUPPLEMENT}', "");
Expect(0, 5024, '\P{^Is_Block=	_ethiopic_SUPPLEMENT}', "");
Error('\p{Is_Blk= /a/Ethiopic_Sup}');
Error('\P{Is_Blk= /a/Ethiopic_Sup}');
Expect(1, 5023, '\p{Is_Blk=ethiopicsup}', "");
Expect(0, 5023, '\p{^Is_Blk=ethiopicsup}', "");
Expect(0, 5023, '\P{Is_Blk=ethiopicsup}', "");
Expect(1, 5023, '\P{^Is_Blk=ethiopicsup}', "");
Expect(0, 5024, '\p{Is_Blk=ethiopicsup}', "");
Expect(1, 5024, '\p{^Is_Blk=ethiopicsup}', "");
Expect(1, 5024, '\P{Is_Blk=ethiopicsup}', "");
Expect(0, 5024, '\P{^Is_Blk=ethiopicsup}', "");
Expect(1, 5023, '\p{Is_Blk:   ETHIOPIC_sup}', "");
Expect(0, 5023, '\p{^Is_Blk:   ETHIOPIC_sup}', "");
Expect(0, 5023, '\P{Is_Blk:   ETHIOPIC_sup}', "");
Expect(1, 5023, '\P{^Is_Blk:   ETHIOPIC_sup}', "");
Expect(0, 5024, '\p{Is_Blk:   ETHIOPIC_sup}', "");
Expect(1, 5024, '\p{^Is_Blk:   ETHIOPIC_sup}', "");
Expect(1, 5024, '\P{Is_Blk:   ETHIOPIC_sup}', "");
Expect(0, 5024, '\P{^Is_Blk:   ETHIOPIC_sup}', "");
Error('\p{Block=	GEOMETRIC_Shapes:=}');
Error('\P{Block=	GEOMETRIC_Shapes:=}');
Expect(1, 9727, '\p{Block=geometricshapes}', "");
Expect(0, 9727, '\p{^Block=geometricshapes}', "");
Expect(0, 9727, '\P{Block=geometricshapes}', "");
Expect(1, 9727, '\P{^Block=geometricshapes}', "");
Expect(0, 9728, '\p{Block=geometricshapes}', "");
Expect(1, 9728, '\p{^Block=geometricshapes}', "");
Expect(1, 9728, '\P{Block=geometricshapes}', "");
Expect(0, 9728, '\P{^Block=geometricshapes}', "");
Expect(1, 9727, '\p{Block=--Geometric_Shapes}', "");
Expect(0, 9727, '\p{^Block=--Geometric_Shapes}', "");
Expect(0, 9727, '\P{Block=--Geometric_Shapes}', "");
Expect(1, 9727, '\P{^Block=--Geometric_Shapes}', "");
Expect(0, 9728, '\p{Block=--Geometric_Shapes}', "");
Expect(1, 9728, '\p{^Block=--Geometric_Shapes}', "");
Expect(1, 9728, '\P{Block=--Geometric_Shapes}', "");
Expect(0, 9728, '\P{^Block=--Geometric_Shapes}', "");
Error('\p{Blk: GEOMETRIC_Shapes/a/}');
Error('\P{Blk: GEOMETRIC_Shapes/a/}');
Expect(1, 9727, '\p{Blk=geometricshapes}', "");
Expect(0, 9727, '\p{^Blk=geometricshapes}', "");
Expect(0, 9727, '\P{Blk=geometricshapes}', "");
Expect(1, 9727, '\P{^Blk=geometricshapes}', "");
Expect(0, 9728, '\p{Blk=geometricshapes}', "");
Expect(1, 9728, '\p{^Blk=geometricshapes}', "");
Expect(1, 9728, '\P{Blk=geometricshapes}', "");
Expect(0, 9728, '\P{^Blk=geometricshapes}', "");
Expect(1, 9727, '\p{Blk=_Geometric_Shapes}', "");
Expect(0, 9727, '\p{^Blk=_Geometric_Shapes}', "");
Expect(0, 9727, '\P{Blk=_Geometric_Shapes}', "");
Expect(1, 9727, '\P{^Blk=_Geometric_Shapes}', "");
Expect(0, 9728, '\p{Blk=_Geometric_Shapes}', "");
Expect(1, 9728, '\p{^Blk=_Geometric_Shapes}', "");
Expect(1, 9728, '\P{Blk=_Geometric_Shapes}', "");
Expect(0, 9728, '\P{^Blk=_Geometric_Shapes}', "");
Error('\p{Is_Block::= -Geometric_Shapes}');
Error('\P{Is_Block::= -Geometric_Shapes}');
Expect(1, 9727, '\p{Is_Block=geometricshapes}', "");
Expect(0, 9727, '\p{^Is_Block=geometricshapes}', "");
Expect(0, 9727, '\P{Is_Block=geometricshapes}', "");
Expect(1, 9727, '\P{^Is_Block=geometricshapes}', "");
Expect(0, 9728, '\p{Is_Block=geometricshapes}', "");
Expect(1, 9728, '\p{^Is_Block=geometricshapes}', "");
Expect(1, 9728, '\P{Is_Block=geometricshapes}', "");
Expect(0, 9728, '\P{^Is_Block=geometricshapes}', "");
Expect(1, 9727, '\p{Is_Block=_-geometric_Shapes}', "");
Expect(0, 9727, '\p{^Is_Block=_-geometric_Shapes}', "");
Expect(0, 9727, '\P{Is_Block=_-geometric_Shapes}', "");
Expect(1, 9727, '\P{^Is_Block=_-geometric_Shapes}', "");
Expect(0, 9728, '\p{Is_Block=_-geometric_Shapes}', "");
Expect(1, 9728, '\p{^Is_Block=_-geometric_Shapes}', "");
Expect(1, 9728, '\P{Is_Block=_-geometric_Shapes}', "");
Expect(0, 9728, '\P{^Is_Block=_-geometric_Shapes}', "");
Error('\p{Is_Blk=-_GEOMETRIC_Shapes/a/}');
Error('\P{Is_Blk=-_GEOMETRIC_Shapes/a/}');
Expect(1, 9727, '\p{Is_Blk=geometricshapes}', "");
Expect(0, 9727, '\p{^Is_Blk=geometricshapes}', "");
Expect(0, 9727, '\P{Is_Blk=geometricshapes}', "");
Expect(1, 9727, '\P{^Is_Blk=geometricshapes}', "");
Expect(0, 9728, '\p{Is_Blk=geometricshapes}', "");
Expect(1, 9728, '\p{^Is_Blk=geometricshapes}', "");
Expect(1, 9728, '\P{Is_Blk=geometricshapes}', "");
Expect(0, 9728, '\P{^Is_Blk=geometricshapes}', "");
Expect(1, 9727, '\p{Is_Blk:	-geometric_Shapes}', "");
Expect(0, 9727, '\p{^Is_Blk:	-geometric_Shapes}', "");
Expect(0, 9727, '\P{Is_Blk:	-geometric_Shapes}', "");
Expect(1, 9727, '\P{^Is_Blk:	-geometric_Shapes}', "");
Expect(0, 9728, '\p{Is_Blk:	-geometric_Shapes}', "");
Expect(1, 9728, '\p{^Is_Blk:	-geometric_Shapes}', "");
Expect(1, 9728, '\P{Is_Blk:	-geometric_Shapes}', "");
Expect(0, 9728, '\P{^Is_Blk:	-geometric_Shapes}', "");
Error('\p{Block:	/a/_ GEORGIAN}');
Error('\P{Block:	/a/_ GEORGIAN}');
Expect(1, 4351, '\p{Block:georgian}', "");
Expect(0, 4351, '\p{^Block:georgian}', "");
Expect(0, 4351, '\P{Block:georgian}', "");
Expect(1, 4351, '\P{^Block:georgian}', "");
Expect(0, 4352, '\p{Block:georgian}', "");
Expect(1, 4352, '\p{^Block:georgian}', "");
Expect(1, 4352, '\P{Block:georgian}', "");
Expect(0, 4352, '\P{^Block:georgian}', "");
Expect(1, 4351, '\p{Block=--GEORGIAN}', "");
Expect(0, 4351, '\p{^Block=--GEORGIAN}', "");
Expect(0, 4351, '\P{Block=--GEORGIAN}', "");
Expect(1, 4351, '\P{^Block=--GEORGIAN}', "");
Expect(0, 4352, '\p{Block=--GEORGIAN}', "");
Expect(1, 4352, '\p{^Block=--GEORGIAN}', "");
Expect(1, 4352, '\P{Block=--GEORGIAN}', "");
Expect(0, 4352, '\P{^Block=--GEORGIAN}', "");
Error('\p{Blk:/a/_	georgian}');
Error('\P{Blk:/a/_	georgian}');
Expect(1, 4351, '\p{Blk=georgian}', "");
Expect(0, 4351, '\p{^Blk=georgian}', "");
Expect(0, 4351, '\P{Blk=georgian}', "");
Expect(1, 4351, '\P{^Blk=georgian}', "");
Expect(0, 4352, '\p{Blk=georgian}', "");
Expect(1, 4352, '\p{^Blk=georgian}', "");
Expect(1, 4352, '\P{Blk=georgian}', "");
Expect(0, 4352, '\P{^Blk=georgian}', "");
Expect(1, 4351, '\p{Blk=- Georgian}', "");
Expect(0, 4351, '\p{^Blk=- Georgian}', "");
Expect(0, 4351, '\P{Blk=- Georgian}', "");
Expect(1, 4351, '\P{^Blk=- Georgian}', "");
Expect(0, 4352, '\p{Blk=- Georgian}', "");
Expect(1, 4352, '\p{^Blk=- Georgian}', "");
Expect(1, 4352, '\P{Blk=- Georgian}', "");
Expect(0, 4352, '\P{^Blk=- Georgian}', "");
Error('\p{Is_Block=_/a/Georgian}');
Error('\P{Is_Block=_/a/Georgian}');
Expect(1, 4351, '\p{Is_Block=georgian}', "");
Expect(0, 4351, '\p{^Is_Block=georgian}', "");
Expect(0, 4351, '\P{Is_Block=georgian}', "");
Expect(1, 4351, '\P{^Is_Block=georgian}', "");
Expect(0, 4352, '\p{Is_Block=georgian}', "");
Expect(1, 4352, '\p{^Is_Block=georgian}', "");
Expect(1, 4352, '\P{Is_Block=georgian}', "");
Expect(0, 4352, '\P{^Is_Block=georgian}', "");
Expect(1, 4351, '\p{Is_Block: 	Georgian}', "");
Expect(0, 4351, '\p{^Is_Block: 	Georgian}', "");
Expect(0, 4351, '\P{Is_Block: 	Georgian}', "");
Expect(1, 4351, '\P{^Is_Block: 	Georgian}', "");
Expect(0, 4352, '\p{Is_Block: 	Georgian}', "");
Expect(1, 4352, '\p{^Is_Block: 	Georgian}', "");
Expect(1, 4352, '\P{Is_Block: 	Georgian}', "");
Expect(0, 4352, '\P{^Is_Block: 	Georgian}', "");
Error('\p{Is_Blk=-	GEORGIAN:=}');
Error('\P{Is_Blk=-	GEORGIAN:=}');
Expect(1, 4351, '\p{Is_Blk=georgian}', "");
Expect(0, 4351, '\p{^Is_Blk=georgian}', "");
Expect(0, 4351, '\P{Is_Blk=georgian}', "");
Expect(1, 4351, '\P{^Is_Blk=georgian}', "");
Expect(0, 4352, '\p{Is_Blk=georgian}', "");
Expect(1, 4352, '\p{^Is_Blk=georgian}', "");
Expect(1, 4352, '\P{Is_Blk=georgian}', "");
Expect(0, 4352, '\P{^Is_Blk=georgian}', "");
Expect(1, 4351, '\p{Is_Blk=_Georgian}', "");
Expect(0, 4351, '\p{^Is_Blk=_Georgian}', "");
Expect(0, 4351, '\P{Is_Blk=_Georgian}', "");
Expect(1, 4351, '\P{^Is_Blk=_Georgian}', "");
Expect(0, 4352, '\p{Is_Blk=_Georgian}', "");
Expect(1, 4352, '\p{^Is_Blk=_Georgian}', "");
Expect(1, 4352, '\P{Is_Blk=_Georgian}', "");
Expect(0, 4352, '\P{^Is_Blk=_Georgian}', "");
Error('\p{Block=/a/-GEORGIAN_Supplement}');
Error('\P{Block=/a/-GEORGIAN_Supplement}');
Expect(1, 11567, '\p{Block=georgiansupplement}', "");
Expect(0, 11567, '\p{^Block=georgiansupplement}', "");
Expect(0, 11567, '\P{Block=georgiansupplement}', "");
Expect(1, 11567, '\P{^Block=georgiansupplement}', "");
Expect(0, 11568, '\p{Block=georgiansupplement}', "");
Expect(1, 11568, '\p{^Block=georgiansupplement}', "");
Expect(1, 11568, '\P{Block=georgiansupplement}', "");
Expect(0, 11568, '\P{^Block=georgiansupplement}', "");
Expect(1, 11567, '\p{Block=		Georgian_Supplement}', "");
Expect(0, 11567, '\p{^Block=		Georgian_Supplement}', "");
Expect(0, 11567, '\P{Block=		Georgian_Supplement}', "");
Expect(1, 11567, '\P{^Block=		Georgian_Supplement}', "");
Expect(0, 11568, '\p{Block=		Georgian_Supplement}', "");
Expect(1, 11568, '\p{^Block=		Georgian_Supplement}', "");
Expect(1, 11568, '\P{Block=		Georgian_Supplement}', "");
Expect(0, 11568, '\P{^Block=		Georgian_Supplement}', "");
Error('\p{Blk=:=_georgian_Sup}');
Error('\P{Blk=:=_georgian_Sup}');
Expect(1, 11567, '\p{Blk=georgiansup}', "");
Expect(0, 11567, '\p{^Blk=georgiansup}', "");
Expect(0, 11567, '\P{Blk=georgiansup}', "");
Expect(1, 11567, '\P{^Blk=georgiansup}', "");
Expect(0, 11568, '\p{Blk=georgiansup}', "");
Expect(1, 11568, '\p{^Blk=georgiansup}', "");
Expect(1, 11568, '\P{Blk=georgiansup}', "");
Expect(0, 11568, '\P{^Blk=georgiansup}', "");
Expect(1, 11567, '\p{Blk=	-GEORGIAN_sup}', "");
Expect(0, 11567, '\p{^Blk=	-GEORGIAN_sup}', "");
Expect(0, 11567, '\P{Blk=	-GEORGIAN_sup}', "");
Expect(1, 11567, '\P{^Blk=	-GEORGIAN_sup}', "");
Expect(0, 11568, '\p{Blk=	-GEORGIAN_sup}', "");
Expect(1, 11568, '\p{^Blk=	-GEORGIAN_sup}', "");
Expect(1, 11568, '\P{Blk=	-GEORGIAN_sup}', "");
Expect(0, 11568, '\P{^Blk=	-GEORGIAN_sup}', "");
Error('\p{Is_Block=- Georgian_SUPPLEMENT:=}');
Error('\P{Is_Block=- Georgian_SUPPLEMENT:=}');
Expect(1, 11567, '\p{Is_Block=georgiansupplement}', "");
Expect(0, 11567, '\p{^Is_Block=georgiansupplement}', "");
Expect(0, 11567, '\P{Is_Block=georgiansupplement}', "");
Expect(1, 11567, '\P{^Is_Block=georgiansupplement}', "");
Expect(0, 11568, '\p{Is_Block=georgiansupplement}', "");
Expect(1, 11568, '\p{^Is_Block=georgiansupplement}', "");
Expect(1, 11568, '\P{Is_Block=georgiansupplement}', "");
Expect(0, 11568, '\P{^Is_Block=georgiansupplement}', "");
Expect(1, 11567, '\p{Is_Block=		georgian_supplement}', "");
Expect(0, 11567, '\p{^Is_Block=		georgian_supplement}', "");
Expect(0, 11567, '\P{Is_Block=		georgian_supplement}', "");
Expect(1, 11567, '\P{^Is_Block=		georgian_supplement}', "");
Expect(0, 11568, '\p{Is_Block=		georgian_supplement}', "");
Expect(1, 11568, '\p{^Is_Block=		georgian_supplement}', "");
Expect(1, 11568, '\P{Is_Block=		georgian_supplement}', "");
Expect(0, 11568, '\P{^Is_Block=		georgian_supplement}', "");
Error('\p{Is_Blk=_	Georgian_Sup/a/}');
Error('\P{Is_Blk=_	Georgian_Sup/a/}');
Expect(1, 11567, '\p{Is_Blk:georgiansup}', "");
Expect(0, 11567, '\p{^Is_Blk:georgiansup}', "");
Expect(0, 11567, '\P{Is_Blk:georgiansup}', "");
Expect(1, 11567, '\P{^Is_Blk:georgiansup}', "");
Expect(0, 11568, '\p{Is_Blk:georgiansup}', "");
Expect(1, 11568, '\p{^Is_Blk:georgiansup}', "");
Expect(1, 11568, '\P{Is_Blk:georgiansup}', "");
Expect(0, 11568, '\P{^Is_Blk:georgiansup}', "");
Expect(1, 11567, '\p{Is_Blk=- GEORGIAN_Sup}', "");
Expect(0, 11567, '\p{^Is_Blk=- GEORGIAN_Sup}', "");
Expect(0, 11567, '\P{Is_Blk=- GEORGIAN_Sup}', "");
Expect(1, 11567, '\P{^Is_Blk=- GEORGIAN_Sup}', "");
Expect(0, 11568, '\p{Is_Blk=- GEORGIAN_Sup}', "");
Expect(1, 11568, '\p{^Is_Blk=- GEORGIAN_Sup}', "");
Expect(1, 11568, '\P{Is_Blk=- GEORGIAN_Sup}', "");
Expect(0, 11568, '\P{^Is_Blk=- GEORGIAN_Sup}', "");
Error('\p{Block= Glagolitic/a/}');
Error('\P{Block= Glagolitic/a/}');
Expect(1, 11359, '\p{Block=glagolitic}', "");
Expect(0, 11359, '\p{^Block=glagolitic}', "");
Expect(0, 11359, '\P{Block=glagolitic}', "");
Expect(1, 11359, '\P{^Block=glagolitic}', "");
Expect(0, 11360, '\p{Block=glagolitic}', "");
Expect(1, 11360, '\p{^Block=glagolitic}', "");
Expect(1, 11360, '\P{Block=glagolitic}', "");
Expect(0, 11360, '\P{^Block=glagolitic}', "");
Expect(1, 11359, '\p{Block:-Glagolitic}', "");
Expect(0, 11359, '\p{^Block:-Glagolitic}', "");
Expect(0, 11359, '\P{Block:-Glagolitic}', "");
Expect(1, 11359, '\P{^Block:-Glagolitic}', "");
Expect(0, 11360, '\p{Block:-Glagolitic}', "");
Expect(1, 11360, '\p{^Block:-Glagolitic}', "");
Expect(1, 11360, '\P{Block:-Glagolitic}', "");
Expect(0, 11360, '\P{^Block:-Glagolitic}', "");
Error('\p{Blk=-:=glagolitic}');
Error('\P{Blk=-:=glagolitic}');
Expect(1, 11359, '\p{Blk=glagolitic}', "");
Expect(0, 11359, '\p{^Blk=glagolitic}', "");
Expect(0, 11359, '\P{Blk=glagolitic}', "");
Expect(1, 11359, '\P{^Blk=glagolitic}', "");
Expect(0, 11360, '\p{Blk=glagolitic}', "");
Expect(1, 11360, '\p{^Blk=glagolitic}', "");
Expect(1, 11360, '\P{Blk=glagolitic}', "");
Expect(0, 11360, '\P{^Blk=glagolitic}', "");
Expect(1, 11359, '\p{Blk=  Glagolitic}', "");
Expect(0, 11359, '\p{^Blk=  Glagolitic}', "");
Expect(0, 11359, '\P{Blk=  Glagolitic}', "");
Expect(1, 11359, '\P{^Blk=  Glagolitic}', "");
Expect(0, 11360, '\p{Blk=  Glagolitic}', "");
Expect(1, 11360, '\p{^Blk=  Glagolitic}', "");
Expect(1, 11360, '\P{Blk=  Glagolitic}', "");
Expect(0, 11360, '\P{^Blk=  Glagolitic}', "");
Error('\p{Is_Block=/a/-	Glagolitic}');
Error('\P{Is_Block=/a/-	Glagolitic}');
Expect(1, 11359, '\p{Is_Block: glagolitic}', "");
Expect(0, 11359, '\p{^Is_Block: glagolitic}', "");
Expect(0, 11359, '\P{Is_Block: glagolitic}', "");
Expect(1, 11359, '\P{^Is_Block: glagolitic}', "");
Expect(0, 11360, '\p{Is_Block: glagolitic}', "");
Expect(1, 11360, '\p{^Is_Block: glagolitic}', "");
Expect(1, 11360, '\P{Is_Block: glagolitic}', "");
Expect(0, 11360, '\P{^Is_Block: glagolitic}', "");
Expect(1, 11359, '\p{Is_Block=-glagolitic}', "");
Expect(0, 11359, '\p{^Is_Block=-glagolitic}', "");
Expect(0, 11359, '\P{Is_Block=-glagolitic}', "");
Expect(1, 11359, '\P{^Is_Block=-glagolitic}', "");
Expect(0, 11360, '\p{Is_Block=-glagolitic}', "");
Expect(1, 11360, '\p{^Is_Block=-glagolitic}', "");
Expect(1, 11360, '\P{Is_Block=-glagolitic}', "");
Expect(0, 11360, '\P{^Is_Block=-glagolitic}', "");
Error('\p{Is_Blk=/a/ Glagolitic}');
Error('\P{Is_Blk=/a/ Glagolitic}');
Expect(1, 11359, '\p{Is_Blk=glagolitic}', "");
Expect(0, 11359, '\p{^Is_Blk=glagolitic}', "");
Expect(0, 11359, '\P{Is_Blk=glagolitic}', "");
Expect(1, 11359, '\P{^Is_Blk=glagolitic}', "");
Expect(0, 11360, '\p{Is_Blk=glagolitic}', "");
Expect(1, 11360, '\p{^Is_Blk=glagolitic}', "");
Expect(1, 11360, '\P{Is_Blk=glagolitic}', "");
Expect(0, 11360, '\P{^Is_Blk=glagolitic}', "");
Expect(1, 11359, '\p{Is_Blk=GLAGOLITIC}', "");
Expect(0, 11359, '\p{^Is_Blk=GLAGOLITIC}', "");
Expect(0, 11359, '\P{Is_Blk=GLAGOLITIC}', "");
Expect(1, 11359, '\P{^Is_Blk=GLAGOLITIC}', "");
Expect(0, 11360, '\p{Is_Blk=GLAGOLITIC}', "");
Expect(1, 11360, '\p{^Is_Blk=GLAGOLITIC}', "");
Expect(1, 11360, '\P{Is_Blk=GLAGOLITIC}', "");
Expect(0, 11360, '\P{^Is_Blk=GLAGOLITIC}', "");
Error('\p{Block=:=Gothic}');
Error('\P{Block=:=Gothic}');
Expect(1, 66383, '\p{Block=gothic}', "");
Expect(0, 66383, '\p{^Block=gothic}', "");
Expect(0, 66383, '\P{Block=gothic}', "");
Expect(1, 66383, '\P{^Block=gothic}', "");
Expect(0, 66384, '\p{Block=gothic}', "");
Expect(1, 66384, '\p{^Block=gothic}', "");
Expect(1, 66384, '\P{Block=gothic}', "");
Expect(0, 66384, '\P{^Block=gothic}', "");
Expect(1, 66383, '\p{Block=-_Gothic}', "");
Expect(0, 66383, '\p{^Block=-_Gothic}', "");
Expect(0, 66383, '\P{Block=-_Gothic}', "");
Expect(1, 66383, '\P{^Block=-_Gothic}', "");
Expect(0, 66384, '\p{Block=-_Gothic}', "");
Expect(1, 66384, '\p{^Block=-_Gothic}', "");
Expect(1, 66384, '\P{Block=-_Gothic}', "");
Expect(0, 66384, '\P{^Block=-_Gothic}', "");
Error('\p{Blk=Gothic/a/}');
Error('\P{Blk=Gothic/a/}');
Expect(1, 66383, '\p{Blk=gothic}', "");
Expect(0, 66383, '\p{^Blk=gothic}', "");
Expect(0, 66383, '\P{Blk=gothic}', "");
Expect(1, 66383, '\P{^Blk=gothic}', "");
Expect(0, 66384, '\p{Blk=gothic}', "");
Expect(1, 66384, '\p{^Blk=gothic}', "");
Expect(1, 66384, '\P{Blk=gothic}', "");
Expect(0, 66384, '\P{^Blk=gothic}', "");
Expect(1, 66383, '\p{Blk:	_Gothic}', "");
Expect(0, 66383, '\p{^Blk:	_Gothic}', "");
Expect(0, 66383, '\P{Blk:	_Gothic}', "");
Expect(1, 66383, '\P{^Blk:	_Gothic}', "");
Expect(0, 66384, '\p{Blk:	_Gothic}', "");
Expect(1, 66384, '\p{^Blk:	_Gothic}', "");
Expect(1, 66384, '\P{Blk:	_Gothic}', "");
Expect(0, 66384, '\P{^Blk:	_Gothic}', "");
Error('\p{Is_Block= 	gothic/a/}');
Error('\P{Is_Block= 	gothic/a/}');
Expect(1, 66383, '\p{Is_Block=gothic}', "");
Expect(0, 66383, '\p{^Is_Block=gothic}', "");
Expect(0, 66383, '\P{Is_Block=gothic}', "");
Expect(1, 66383, '\P{^Is_Block=gothic}', "");
Expect(0, 66384, '\p{Is_Block=gothic}', "");
Expect(1, 66384, '\p{^Is_Block=gothic}', "");
Expect(1, 66384, '\P{Is_Block=gothic}', "");
Expect(0, 66384, '\P{^Is_Block=gothic}', "");
Expect(1, 66383, '\p{Is_Block=	gothic}', "");
Expect(0, 66383, '\p{^Is_Block=	gothic}', "");
Expect(0, 66383, '\P{Is_Block=	gothic}', "");
Expect(1, 66383, '\P{^Is_Block=	gothic}', "");
Expect(0, 66384, '\p{Is_Block=	gothic}', "");
Expect(1, 66384, '\p{^Is_Block=	gothic}', "");
Expect(1, 66384, '\P{Is_Block=	gothic}', "");
Expect(0, 66384, '\P{^Is_Block=	gothic}', "");
Error('\p{Is_Blk=:=_ GOTHIC}');
Error('\P{Is_Blk=:=_ GOTHIC}');
Expect(1, 66383, '\p{Is_Blk=gothic}', "");
Expect(0, 66383, '\p{^Is_Blk=gothic}', "");
Expect(0, 66383, '\P{Is_Blk=gothic}', "");
Expect(1, 66383, '\P{^Is_Blk=gothic}', "");
Expect(0, 66384, '\p{Is_Blk=gothic}', "");
Expect(1, 66384, '\p{^Is_Blk=gothic}', "");
Expect(1, 66384, '\P{Is_Blk=gothic}', "");
Expect(0, 66384, '\P{^Is_Blk=gothic}', "");
Expect(1, 66383, '\p{Is_Blk=		GOTHIC}', "");
Expect(0, 66383, '\p{^Is_Blk=		GOTHIC}', "");
Expect(0, 66383, '\P{Is_Blk=		GOTHIC}', "");
Expect(1, 66383, '\P{^Is_Blk=		GOTHIC}', "");
Expect(0, 66384, '\p{Is_Blk=		GOTHIC}', "");
Expect(1, 66384, '\p{^Is_Blk=		GOTHIC}', "");
Expect(1, 66384, '\P{Is_Blk=		GOTHIC}', "");
Expect(0, 66384, '\P{^Is_Blk=		GOTHIC}', "");
Error('\p{Block=-/a/Greek_And_Coptic}');
Error('\P{Block=-/a/Greek_And_Coptic}');
Expect(1, 1023, '\p{Block=greekandcoptic}', "");
Expect(0, 1023, '\p{^Block=greekandcoptic}', "");
Expect(0, 1023, '\P{Block=greekandcoptic}', "");
Expect(1, 1023, '\P{^Block=greekandcoptic}', "");
Expect(0, 1024, '\p{Block=greekandcoptic}', "");
Expect(1, 1024, '\p{^Block=greekandcoptic}', "");
Expect(1, 1024, '\P{Block=greekandcoptic}', "");
Expect(0, 1024, '\P{^Block=greekandcoptic}', "");
Expect(1, 1023, '\p{Block=-Greek_AND_coptic}', "");
Expect(0, 1023, '\p{^Block=-Greek_AND_coptic}', "");
Expect(0, 1023, '\P{Block=-Greek_AND_coptic}', "");
Expect(1, 1023, '\P{^Block=-Greek_AND_coptic}', "");
Expect(0, 1024, '\p{Block=-Greek_AND_coptic}', "");
Expect(1, 1024, '\p{^Block=-Greek_AND_coptic}', "");
Expect(1, 1024, '\P{Block=-Greek_AND_coptic}', "");
Expect(0, 1024, '\P{^Block=-Greek_AND_coptic}', "");
Error('\p{Blk=/a/_-greek}');
Error('\P{Blk=/a/_-greek}');
Expect(1, 1023, '\p{Blk=greek}', "");
Expect(0, 1023, '\p{^Blk=greek}', "");
Expect(0, 1023, '\P{Blk=greek}', "");
Expect(1, 1023, '\P{^Blk=greek}', "");
Expect(0, 1024, '\p{Blk=greek}', "");
Expect(1, 1024, '\p{^Blk=greek}', "");
Expect(1, 1024, '\P{Blk=greek}', "");
Expect(0, 1024, '\P{^Blk=greek}', "");
Expect(1, 1023, '\p{Blk= -greek}', "");
Expect(0, 1023, '\p{^Blk= -greek}', "");
Expect(0, 1023, '\P{Blk= -greek}', "");
Expect(1, 1023, '\P{^Blk= -greek}', "");
Expect(0, 1024, '\p{Blk= -greek}', "");
Expect(1, 1024, '\p{^Blk= -greek}', "");
Expect(1, 1024, '\P{Blk= -greek}', "");
Expect(0, 1024, '\P{^Blk= -greek}', "");
Error('\p{Is_Block=  Greek_and_Coptic/a/}');
Error('\P{Is_Block=  Greek_and_Coptic/a/}');
Expect(1, 1023, '\p{Is_Block=greekandcoptic}', "");
Expect(0, 1023, '\p{^Is_Block=greekandcoptic}', "");
Expect(0, 1023, '\P{Is_Block=greekandcoptic}', "");
Expect(1, 1023, '\P{^Is_Block=greekandcoptic}', "");
Expect(0, 1024, '\p{Is_Block=greekandcoptic}', "");
Expect(1, 1024, '\p{^Is_Block=greekandcoptic}', "");
Expect(1, 1024, '\P{Is_Block=greekandcoptic}', "");
Expect(0, 1024, '\P{^Is_Block=greekandcoptic}', "");
Expect(1, 1023, '\p{Is_Block:	greek_and_coptic}', "");
Expect(0, 1023, '\p{^Is_Block:	greek_and_coptic}', "");
Expect(0, 1023, '\P{Is_Block:	greek_and_coptic}', "");
Expect(1, 1023, '\P{^Is_Block:	greek_and_coptic}', "");
Expect(0, 1024, '\p{Is_Block:	greek_and_coptic}', "");
Expect(1, 1024, '\p{^Is_Block:	greek_and_coptic}', "");
Expect(1, 1024, '\P{Is_Block:	greek_and_coptic}', "");
Expect(0, 1024, '\P{^Is_Block:	greek_and_coptic}', "");
Error('\p{Is_Blk=:=	GREEK}');
Error('\P{Is_Blk=:=	GREEK}');
Expect(1, 1023, '\p{Is_Blk:greek}', "");
Expect(0, 1023, '\p{^Is_Blk:greek}', "");
Expect(0, 1023, '\P{Is_Blk:greek}', "");
Expect(1, 1023, '\P{^Is_Blk:greek}', "");
Expect(0, 1024, '\p{Is_Blk:greek}', "");
Expect(1, 1024, '\p{^Is_Blk:greek}', "");
Expect(1, 1024, '\P{Is_Blk:greek}', "");
Expect(0, 1024, '\P{^Is_Blk:greek}', "");
Expect(1, 1023, '\p{Is_Blk=	-greek}', "");
Expect(0, 1023, '\p{^Is_Blk=	-greek}', "");
Expect(0, 1023, '\P{Is_Blk=	-greek}', "");
Expect(1, 1023, '\P{^Is_Blk=	-greek}', "");
Expect(0, 1024, '\p{Is_Blk=	-greek}', "");
Expect(1, 1024, '\p{^Is_Blk=	-greek}', "");
Expect(1, 1024, '\P{Is_Blk=	-greek}', "");
Expect(0, 1024, '\P{^Is_Blk=	-greek}', "");
Error('\p{Block=:=-	greek_EXTENDED}');
Error('\P{Block=:=-	greek_EXTENDED}');
Expect(1, 8191, '\p{Block=greekextended}', "");
Expect(0, 8191, '\p{^Block=greekextended}', "");
Expect(0, 8191, '\P{Block=greekextended}', "");
Expect(1, 8191, '\P{^Block=greekextended}', "");
Expect(0, 8192, '\p{Block=greekextended}', "");
Expect(1, 8192, '\p{^Block=greekextended}', "");
Expect(1, 8192, '\P{Block=greekextended}', "");
Expect(0, 8192, '\P{^Block=greekextended}', "");
Expect(1, 8191, '\p{Block= greek_extended}', "");
Expect(0, 8191, '\p{^Block= greek_extended}', "");
Expect(0, 8191, '\P{Block= greek_extended}', "");
Expect(1, 8191, '\P{^Block= greek_extended}', "");
Expect(0, 8192, '\p{Block= greek_extended}', "");
Expect(1, 8192, '\p{^Block= greek_extended}', "");
Expect(1, 8192, '\P{Block= greek_extended}', "");
Expect(0, 8192, '\P{^Block= greek_extended}', "");
Error('\p{Blk=	 GREEK_Ext/a/}');
Error('\P{Blk=	 GREEK_Ext/a/}');
Expect(1, 8191, '\p{Blk=greekext}', "");
Expect(0, 8191, '\p{^Blk=greekext}', "");
Expect(0, 8191, '\P{Blk=greekext}', "");
Expect(1, 8191, '\P{^Blk=greekext}', "");
Expect(0, 8192, '\p{Blk=greekext}', "");
Expect(1, 8192, '\p{^Blk=greekext}', "");
Expect(1, 8192, '\P{Blk=greekext}', "");
Expect(0, 8192, '\P{^Blk=greekext}', "");
Expect(1, 8191, '\p{Blk=  Greek_ext}', "");
Expect(0, 8191, '\p{^Blk=  Greek_ext}', "");
Expect(0, 8191, '\P{Blk=  Greek_ext}', "");
Expect(1, 8191, '\P{^Blk=  Greek_ext}', "");
Expect(0, 8192, '\p{Blk=  Greek_ext}', "");
Expect(1, 8192, '\p{^Blk=  Greek_ext}', "");
Expect(1, 8192, '\P{Blk=  Greek_ext}', "");
Expect(0, 8192, '\P{^Blk=  Greek_ext}', "");
Error('\p{Is_Block=-GREEK_EXTENDED:=}');
Error('\P{Is_Block=-GREEK_EXTENDED:=}');
Expect(1, 8191, '\p{Is_Block:   greekextended}', "");
Expect(0, 8191, '\p{^Is_Block:   greekextended}', "");
Expect(0, 8191, '\P{Is_Block:   greekextended}', "");
Expect(1, 8191, '\P{^Is_Block:   greekextended}', "");
Expect(0, 8192, '\p{Is_Block:   greekextended}', "");
Expect(1, 8192, '\p{^Is_Block:   greekextended}', "");
Expect(1, 8192, '\P{Is_Block:   greekextended}', "");
Expect(0, 8192, '\P{^Is_Block:   greekextended}', "");
Expect(1, 8191, '\p{Is_Block=-Greek_Extended}', "");
Expect(0, 8191, '\p{^Is_Block=-Greek_Extended}', "");
Expect(0, 8191, '\P{Is_Block=-Greek_Extended}', "");
Expect(1, 8191, '\P{^Is_Block=-Greek_Extended}', "");
Expect(0, 8192, '\p{Is_Block=-Greek_Extended}', "");
Expect(1, 8192, '\p{^Is_Block=-Greek_Extended}', "");
Expect(1, 8192, '\P{Is_Block=-Greek_Extended}', "");
Expect(0, 8192, '\P{^Is_Block=-Greek_Extended}', "");
Error('\p{Is_Blk=_:=greek_EXT}');
Error('\P{Is_Blk=_:=greek_EXT}');
Expect(1, 8191, '\p{Is_Blk=greekext}', "");
Expect(0, 8191, '\p{^Is_Blk=greekext}', "");
Expect(0, 8191, '\P{Is_Blk=greekext}', "");
Expect(1, 8191, '\P{^Is_Blk=greekext}', "");
Expect(0, 8192, '\p{Is_Blk=greekext}', "");
Expect(1, 8192, '\p{^Is_Blk=greekext}', "");
Expect(1, 8192, '\P{Is_Blk=greekext}', "");
Expect(0, 8192, '\P{^Is_Blk=greekext}', "");
Expect(1, 8191, '\p{Is_Blk=	Greek_Ext}', "");
Expect(0, 8191, '\p{^Is_Blk=	Greek_Ext}', "");
Expect(0, 8191, '\P{Is_Blk=	Greek_Ext}', "");
Expect(1, 8191, '\P{^Is_Blk=	Greek_Ext}', "");
Expect(0, 8192, '\p{Is_Blk=	Greek_Ext}', "");
Expect(1, 8192, '\p{^Is_Blk=	Greek_Ext}', "");
Expect(1, 8192, '\P{Is_Blk=	Greek_Ext}', "");
Expect(0, 8192, '\P{^Is_Blk=	Greek_Ext}', "");
Error('\p{Block=:= _GUJARATI}');
Error('\P{Block=:= _GUJARATI}');
Expect(1, 2815, '\p{Block:	gujarati}', "");
Expect(0, 2815, '\p{^Block:	gujarati}', "");
Expect(0, 2815, '\P{Block:	gujarati}', "");
Expect(1, 2815, '\P{^Block:	gujarati}', "");
Expect(0, 2816, '\p{Block:	gujarati}', "");
Expect(1, 2816, '\p{^Block:	gujarati}', "");
Expect(1, 2816, '\P{Block:	gujarati}', "");
Expect(0, 2816, '\P{^Block:	gujarati}', "");
Expect(1, 2815, '\p{Block= gujarati}', "");
Expect(0, 2815, '\p{^Block= gujarati}', "");
Expect(0, 2815, '\P{Block= gujarati}', "");
Expect(1, 2815, '\P{^Block= gujarati}', "");
Expect(0, 2816, '\p{Block= gujarati}', "");
Expect(1, 2816, '\p{^Block= gujarati}', "");
Expect(1, 2816, '\P{Block= gujarati}', "");
Expect(0, 2816, '\P{^Block= gujarati}', "");
Error('\p{Blk= _Gujarati:=}');
Error('\P{Blk= _Gujarati:=}');
Expect(1, 2815, '\p{Blk=gujarati}', "");
Expect(0, 2815, '\p{^Blk=gujarati}', "");
Expect(0, 2815, '\P{Blk=gujarati}', "");
Expect(1, 2815, '\P{^Blk=gujarati}', "");
Expect(0, 2816, '\p{Blk=gujarati}', "");
Expect(1, 2816, '\p{^Blk=gujarati}', "");
Expect(1, 2816, '\P{Blk=gujarati}', "");
Expect(0, 2816, '\P{^Blk=gujarati}', "");
Expect(1, 2815, '\p{Blk=  gujarati}', "");
Expect(0, 2815, '\p{^Blk=  gujarati}', "");
Expect(0, 2815, '\P{Blk=  gujarati}', "");
Expect(1, 2815, '\P{^Blk=  gujarati}', "");
Expect(0, 2816, '\p{Blk=  gujarati}', "");
Expect(1, 2816, '\p{^Blk=  gujarati}', "");
Expect(1, 2816, '\P{Blk=  gujarati}', "");
Expect(0, 2816, '\P{^Blk=  gujarati}', "");
Error('\p{Is_Block: /a/-Gujarati}');
Error('\P{Is_Block: /a/-Gujarati}');
Expect(1, 2815, '\p{Is_Block=gujarati}', "");
Expect(0, 2815, '\p{^Is_Block=gujarati}', "");
Expect(0, 2815, '\P{Is_Block=gujarati}', "");
Expect(1, 2815, '\P{^Is_Block=gujarati}', "");
Expect(0, 2816, '\p{Is_Block=gujarati}', "");
Expect(1, 2816, '\p{^Is_Block=gujarati}', "");
Expect(1, 2816, '\P{Is_Block=gujarati}', "");
Expect(0, 2816, '\P{^Is_Block=gujarati}', "");
Expect(1, 2815, '\p{Is_Block=_gujarati}', "");
Expect(0, 2815, '\p{^Is_Block=_gujarati}', "");
Expect(0, 2815, '\P{Is_Block=_gujarati}', "");
Expect(1, 2815, '\P{^Is_Block=_gujarati}', "");
Expect(0, 2816, '\p{Is_Block=_gujarati}', "");
Expect(1, 2816, '\p{^Is_Block=_gujarati}', "");
Expect(1, 2816, '\P{Is_Block=_gujarati}', "");
Expect(0, 2816, '\P{^Is_Block=_gujarati}', "");
Error('\p{Is_Blk=/a/-_Gujarati}');
Error('\P{Is_Blk=/a/-_Gujarati}');
Expect(1, 2815, '\p{Is_Blk=gujarati}', "");
Expect(0, 2815, '\p{^Is_Blk=gujarati}', "");
Expect(0, 2815, '\P{Is_Blk=gujarati}', "");
Expect(1, 2815, '\P{^Is_Blk=gujarati}', "");
Expect(0, 2816, '\p{Is_Blk=gujarati}', "");
Expect(1, 2816, '\p{^Is_Blk=gujarati}', "");
Expect(1, 2816, '\P{Is_Blk=gujarati}', "");
Expect(0, 2816, '\P{^Is_Blk=gujarati}', "");
Expect(1, 2815, '\p{Is_Blk=__gujarati}', "");
Expect(0, 2815, '\p{^Is_Blk=__gujarati}', "");
Expect(0, 2815, '\P{Is_Blk=__gujarati}', "");
Expect(1, 2815, '\P{^Is_Blk=__gujarati}', "");
Expect(0, 2816, '\p{Is_Blk=__gujarati}', "");
Expect(1, 2816, '\p{^Is_Blk=__gujarati}', "");
Expect(1, 2816, '\P{Is_Blk=__gujarati}', "");
Expect(0, 2816, '\P{^Is_Blk=__gujarati}', "");
Error('\p{Block=_ Gurmukhi/a/}');
Error('\P{Block=_ Gurmukhi/a/}');
Expect(1, 2687, '\p{Block=gurmukhi}', "");
Expect(0, 2687, '\p{^Block=gurmukhi}', "");
Expect(0, 2687, '\P{Block=gurmukhi}', "");
Expect(1, 2687, '\P{^Block=gurmukhi}', "");
Expect(0, 2688, '\p{Block=gurmukhi}', "");
Expect(1, 2688, '\p{^Block=gurmukhi}', "");
Expect(1, 2688, '\P{Block=gurmukhi}', "");
Expect(0, 2688, '\P{^Block=gurmukhi}', "");
Expect(1, 2687, '\p{Block=		gurmukhi}', "");
Expect(0, 2687, '\p{^Block=		gurmukhi}', "");
Expect(0, 2687, '\P{Block=		gurmukhi}', "");
Expect(1, 2687, '\P{^Block=		gurmukhi}', "");
Expect(0, 2688, '\p{Block=		gurmukhi}', "");
Expect(1, 2688, '\p{^Block=		gurmukhi}', "");
Expect(1, 2688, '\P{Block=		gurmukhi}', "");
Expect(0, 2688, '\P{^Block=		gurmukhi}', "");
Error('\p{Blk=	:=Gurmukhi}');
Error('\P{Blk=	:=Gurmukhi}');
Expect(1, 2687, '\p{Blk=gurmukhi}', "");
Expect(0, 2687, '\p{^Blk=gurmukhi}', "");
Expect(0, 2687, '\P{Blk=gurmukhi}', "");
Expect(1, 2687, '\P{^Blk=gurmukhi}', "");
Expect(0, 2688, '\p{Blk=gurmukhi}', "");
Expect(1, 2688, '\p{^Blk=gurmukhi}', "");
Expect(1, 2688, '\P{Blk=gurmukhi}', "");
Expect(0, 2688, '\P{^Blk=gurmukhi}', "");
Expect(1, 2687, '\p{Blk=_ Gurmukhi}', "");
Expect(0, 2687, '\p{^Blk=_ Gurmukhi}', "");
Expect(0, 2687, '\P{Blk=_ Gurmukhi}', "");
Expect(1, 2687, '\P{^Blk=_ Gurmukhi}', "");
Expect(0, 2688, '\p{Blk=_ Gurmukhi}', "");
Expect(1, 2688, '\p{^Blk=_ Gurmukhi}', "");
Expect(1, 2688, '\P{Blk=_ Gurmukhi}', "");
Expect(0, 2688, '\P{^Blk=_ Gurmukhi}', "");
Error('\p{Is_Block=/a/GURMUKHI}');
Error('\P{Is_Block=/a/GURMUKHI}');
Expect(1, 2687, '\p{Is_Block=gurmukhi}', "");
Expect(0, 2687, '\p{^Is_Block=gurmukhi}', "");
Expect(0, 2687, '\P{Is_Block=gurmukhi}', "");
Expect(1, 2687, '\P{^Is_Block=gurmukhi}', "");
Expect(0, 2688, '\p{Is_Block=gurmukhi}', "");
Expect(1, 2688, '\p{^Is_Block=gurmukhi}', "");
Expect(1, 2688, '\P{Is_Block=gurmukhi}', "");
Expect(0, 2688, '\P{^Is_Block=gurmukhi}', "");
Expect(1, 2687, '\p{Is_Block= -Gurmukhi}', "");
Expect(0, 2687, '\p{^Is_Block= -Gurmukhi}', "");
Expect(0, 2687, '\P{Is_Block= -Gurmukhi}', "");
Expect(1, 2687, '\P{^Is_Block= -Gurmukhi}', "");
Expect(0, 2688, '\p{Is_Block= -Gurmukhi}', "");
Expect(1, 2688, '\p{^Is_Block= -Gurmukhi}', "");
Expect(1, 2688, '\P{Is_Block= -Gurmukhi}', "");
Expect(0, 2688, '\P{^Is_Block= -Gurmukhi}', "");
Error('\p{Is_Blk=/a/gurmukhi}');
Error('\P{Is_Blk=/a/gurmukhi}');
Expect(1, 2687, '\p{Is_Blk=gurmukhi}', "");
Expect(0, 2687, '\p{^Is_Blk=gurmukhi}', "");
Expect(0, 2687, '\P{Is_Blk=gurmukhi}', "");
Expect(1, 2687, '\P{^Is_Blk=gurmukhi}', "");
Expect(0, 2688, '\p{Is_Blk=gurmukhi}', "");
Expect(1, 2688, '\p{^Is_Blk=gurmukhi}', "");
Expect(1, 2688, '\P{Is_Blk=gurmukhi}', "");
Expect(0, 2688, '\P{^Is_Blk=gurmukhi}', "");
Expect(1, 2687, '\p{Is_Blk=_Gurmukhi}', "");
Expect(0, 2687, '\p{^Is_Blk=_Gurmukhi}', "");
Expect(0, 2687, '\P{Is_Blk=_Gurmukhi}', "");
Expect(1, 2687, '\P{^Is_Blk=_Gurmukhi}', "");
Expect(0, 2688, '\p{Is_Blk=_Gurmukhi}', "");
Expect(1, 2688, '\p{^Is_Blk=_Gurmukhi}', "");
Expect(1, 2688, '\P{Is_Blk=_Gurmukhi}', "");
Expect(0, 2688, '\P{^Is_Blk=_Gurmukhi}', "");
Error('\p{Block=/a/	-HALFWIDTH_And_FULLWIDTH_Forms}');
Error('\P{Block=/a/	-HALFWIDTH_And_FULLWIDTH_Forms}');
Expect(1, 65519, '\p{Block=halfwidthandfullwidthforms}', "");
Expect(0, 65519, '\p{^Block=halfwidthandfullwidthforms}', "");
Expect(0, 65519, '\P{Block=halfwidthandfullwidthforms}', "");
Expect(1, 65519, '\P{^Block=halfwidthandfullwidthforms}', "");
Expect(0, 65520, '\p{Block=halfwidthandfullwidthforms}', "");
Expect(1, 65520, '\p{^Block=halfwidthandfullwidthforms}', "");
Expect(1, 65520, '\P{Block=halfwidthandfullwidthforms}', "");
Expect(0, 65520, '\P{^Block=halfwidthandfullwidthforms}', "");
Expect(1, 65519, '\p{Block=-	Halfwidth_and_Fullwidth_forms}', "");
Expect(0, 65519, '\p{^Block=-	Halfwidth_and_Fullwidth_forms}', "");
Expect(0, 65519, '\P{Block=-	Halfwidth_and_Fullwidth_forms}', "");
Expect(1, 65519, '\P{^Block=-	Halfwidth_and_Fullwidth_forms}', "");
Expect(0, 65520, '\p{Block=-	Halfwidth_and_Fullwidth_forms}', "");
Expect(1, 65520, '\p{^Block=-	Halfwidth_and_Fullwidth_forms}', "");
Expect(1, 65520, '\P{Block=-	Halfwidth_and_Fullwidth_forms}', "");
Expect(0, 65520, '\P{^Block=-	Halfwidth_and_Fullwidth_forms}', "");
Error('\p{Blk=/a/-_HALF_and_Full_FORMS}');
Error('\P{Blk=/a/-_HALF_and_Full_FORMS}');
Expect(1, 65519, '\p{Blk=halfandfullforms}', "");
Expect(0, 65519, '\p{^Blk=halfandfullforms}', "");
Expect(0, 65519, '\P{Blk=halfandfullforms}', "");
Expect(1, 65519, '\P{^Blk=halfandfullforms}', "");
Expect(0, 65520, '\p{Blk=halfandfullforms}', "");
Expect(1, 65520, '\p{^Blk=halfandfullforms}', "");
Expect(1, 65520, '\P{Blk=halfandfullforms}', "");
Expect(0, 65520, '\P{^Blk=halfandfullforms}', "");
Expect(1, 65519, '\p{Blk=	-Half_And_FULL_Forms}', "");
Expect(0, 65519, '\p{^Blk=	-Half_And_FULL_Forms}', "");
Expect(0, 65519, '\P{Blk=	-Half_And_FULL_Forms}', "");
Expect(1, 65519, '\P{^Blk=	-Half_And_FULL_Forms}', "");
Expect(0, 65520, '\p{Blk=	-Half_And_FULL_Forms}', "");
Expect(1, 65520, '\p{^Blk=	-Half_And_FULL_Forms}', "");
Expect(1, 65520, '\P{Blk=	-Half_And_FULL_Forms}', "");
Expect(0, 65520, '\P{^Blk=	-Half_And_FULL_Forms}', "");
Error('\p{Is_Block: -:=Halfwidth_And_FULLWIDTH_FORMS}');
Error('\P{Is_Block: -:=Halfwidth_And_FULLWIDTH_FORMS}');
Expect(1, 65519, '\p{Is_Block=halfwidthandfullwidthforms}', "");
Expect(0, 65519, '\p{^Is_Block=halfwidthandfullwidthforms}', "");
Expect(0, 65519, '\P{Is_Block=halfwidthandfullwidthforms}', "");
Expect(1, 65519, '\P{^Is_Block=halfwidthandfullwidthforms}', "");
Expect(0, 65520, '\p{Is_Block=halfwidthandfullwidthforms}', "");
Expect(1, 65520, '\p{^Is_Block=halfwidthandfullwidthforms}', "");
Expect(1, 65520, '\P{Is_Block=halfwidthandfullwidthforms}', "");
Expect(0, 65520, '\P{^Is_Block=halfwidthandfullwidthforms}', "");
Expect(1, 65519, '\p{Is_Block=-_Halfwidth_And_Fullwidth_FORMS}', "");
Expect(0, 65519, '\p{^Is_Block=-_Halfwidth_And_Fullwidth_FORMS}', "");
Expect(0, 65519, '\P{Is_Block=-_Halfwidth_And_Fullwidth_FORMS}', "");
Expect(1, 65519, '\P{^Is_Block=-_Halfwidth_And_Fullwidth_FORMS}', "");
Expect(0, 65520, '\p{Is_Block=-_Halfwidth_And_Fullwidth_FORMS}', "");
Expect(1, 65520, '\p{^Is_Block=-_Halfwidth_And_Fullwidth_FORMS}', "");
Expect(1, 65520, '\P{Is_Block=-_Halfwidth_And_Fullwidth_FORMS}', "");
Expect(0, 65520, '\P{^Is_Block=-_Halfwidth_And_Fullwidth_FORMS}', "");
Error('\p{Is_Blk=/a/Half_AND_Full_forms}');
Error('\P{Is_Blk=/a/Half_AND_Full_forms}');
Expect(1, 65519, '\p{Is_Blk=halfandfullforms}', "");
Expect(0, 65519, '\p{^Is_Blk=halfandfullforms}', "");
Expect(0, 65519, '\P{Is_Blk=halfandfullforms}', "");
Expect(1, 65519, '\P{^Is_Blk=halfandfullforms}', "");
Expect(0, 65520, '\p{Is_Blk=halfandfullforms}', "");
Expect(1, 65520, '\p{^Is_Blk=halfandfullforms}', "");
Expect(1, 65520, '\P{Is_Blk=halfandfullforms}', "");
Expect(0, 65520, '\P{^Is_Blk=halfandfullforms}', "");
Expect(1, 65519, '\p{Is_Blk=--half_And_Full_Forms}', "");
Expect(0, 65519, '\p{^Is_Blk=--half_And_Full_Forms}', "");
Expect(0, 65519, '\P{Is_Blk=--half_And_Full_Forms}', "");
Expect(1, 65519, '\P{^Is_Blk=--half_And_Full_Forms}', "");
Expect(0, 65520, '\p{Is_Blk=--half_And_Full_Forms}', "");
Expect(1, 65520, '\p{^Is_Blk=--half_And_Full_Forms}', "");
Expect(1, 65520, '\P{Is_Blk=--half_And_Full_Forms}', "");
Expect(0, 65520, '\P{^Is_Blk=--half_And_Full_Forms}', "");
Error('\p{Block=/a/ _Combining_HALF_MARKS}');
Error('\P{Block=/a/ _Combining_HALF_MARKS}');
Expect(1, 65071, '\p{Block=combininghalfmarks}', "");
Expect(0, 65071, '\p{^Block=combininghalfmarks}', "");
Expect(0, 65071, '\P{Block=combininghalfmarks}', "");
Expect(1, 65071, '\P{^Block=combininghalfmarks}', "");
Expect(0, 65072, '\p{Block=combininghalfmarks}', "");
Expect(1, 65072, '\p{^Block=combininghalfmarks}', "");
Expect(1, 65072, '\P{Block=combininghalfmarks}', "");
Expect(0, 65072, '\P{^Block=combininghalfmarks}', "");
Expect(1, 65071, '\p{Block=-_COMBINING_HALF_Marks}', "");
Expect(0, 65071, '\p{^Block=-_COMBINING_HALF_Marks}', "");
Expect(0, 65071, '\P{Block=-_COMBINING_HALF_Marks}', "");
Expect(1, 65071, '\P{^Block=-_COMBINING_HALF_Marks}', "");
Expect(0, 65072, '\p{Block=-_COMBINING_HALF_Marks}', "");
Expect(1, 65072, '\p{^Block=-_COMBINING_HALF_Marks}', "");
Expect(1, 65072, '\P{Block=-_COMBINING_HALF_Marks}', "");
Expect(0, 65072, '\P{^Block=-_COMBINING_HALF_Marks}', "");
Error('\p{Blk=:=	_Half_MARKS}');
Error('\P{Blk=:=	_Half_MARKS}');
Expect(1, 65071, '\p{Blk=halfmarks}', "");
Expect(0, 65071, '\p{^Blk=halfmarks}', "");
Expect(0, 65071, '\P{Blk=halfmarks}', "");
Expect(1, 65071, '\P{^Blk=halfmarks}', "");
Expect(0, 65072, '\p{Blk=halfmarks}', "");
Expect(1, 65072, '\p{^Blk=halfmarks}', "");
Expect(1, 65072, '\P{Blk=halfmarks}', "");
Expect(0, 65072, '\P{^Blk=halfmarks}', "");
Expect(1, 65071, '\p{Blk=-_Half_Marks}', "");
Expect(0, 65071, '\p{^Blk=-_Half_Marks}', "");
Expect(0, 65071, '\P{Blk=-_Half_Marks}', "");
Expect(1, 65071, '\P{^Blk=-_Half_Marks}', "");
Expect(0, 65072, '\p{Blk=-_Half_Marks}', "");
Expect(1, 65072, '\p{^Blk=-_Half_Marks}', "");
Expect(1, 65072, '\P{Blk=-_Half_Marks}', "");
Expect(0, 65072, '\P{^Blk=-_Half_Marks}', "");
Error('\p{Is_Block=:=- Combining_Half_MARKS}');
Error('\P{Is_Block=:=- Combining_Half_MARKS}');
Expect(1, 65071, '\p{Is_Block=combininghalfmarks}', "");
Expect(0, 65071, '\p{^Is_Block=combininghalfmarks}', "");
Expect(0, 65071, '\P{Is_Block=combininghalfmarks}', "");
Expect(1, 65071, '\P{^Is_Block=combininghalfmarks}', "");
Expect(0, 65072, '\p{Is_Block=combininghalfmarks}', "");
Expect(1, 65072, '\p{^Is_Block=combininghalfmarks}', "");
Expect(1, 65072, '\P{Is_Block=combininghalfmarks}', "");
Expect(0, 65072, '\P{^Is_Block=combininghalfmarks}', "");
Expect(1, 65071, '\p{Is_Block=_Combining_Half_MARKS}', "");
Expect(0, 65071, '\p{^Is_Block=_Combining_Half_MARKS}', "");
Expect(0, 65071, '\P{Is_Block=_Combining_Half_MARKS}', "");
Expect(1, 65071, '\P{^Is_Block=_Combining_Half_MARKS}', "");
Expect(0, 65072, '\p{Is_Block=_Combining_Half_MARKS}', "");
Expect(1, 65072, '\p{^Is_Block=_Combining_Half_MARKS}', "");
Expect(1, 65072, '\P{Is_Block=_Combining_Half_MARKS}', "");
Expect(0, 65072, '\P{^Is_Block=_Combining_Half_MARKS}', "");
Error('\p{Is_Blk=:=--half_MARKS}');
Error('\P{Is_Blk=:=--half_MARKS}');
Expect(1, 65071, '\p{Is_Blk=halfmarks}', "");
Expect(0, 65071, '\p{^Is_Blk=halfmarks}', "");
Expect(0, 65071, '\P{Is_Blk=halfmarks}', "");
Expect(1, 65071, '\P{^Is_Blk=halfmarks}', "");
Expect(0, 65072, '\p{Is_Blk=halfmarks}', "");
Expect(1, 65072, '\p{^Is_Blk=halfmarks}', "");
Expect(1, 65072, '\P{Is_Blk=halfmarks}', "");
Expect(0, 65072, '\P{^Is_Blk=halfmarks}', "");
Expect(1, 65071, '\p{Is_Blk=	half_MARKS}', "");
Expect(0, 65071, '\p{^Is_Blk=	half_MARKS}', "");
Expect(0, 65071, '\P{Is_Blk=	half_MARKS}', "");
Expect(1, 65071, '\P{^Is_Blk=	half_MARKS}', "");
Expect(0, 65072, '\p{Is_Blk=	half_MARKS}', "");
Expect(1, 65072, '\p{^Is_Blk=	half_MARKS}', "");
Expect(1, 65072, '\P{Is_Blk=	half_MARKS}', "");
Expect(0, 65072, '\P{^Is_Blk=	half_MARKS}', "");
Error('\p{Block= :=hangul_Syllables}');
Error('\P{Block= :=hangul_Syllables}');
Expect(1, 55215, '\p{Block=hangulsyllables}', "");
Expect(0, 55215, '\p{^Block=hangulsyllables}', "");
Expect(0, 55215, '\P{Block=hangulsyllables}', "");
Expect(1, 55215, '\P{^Block=hangulsyllables}', "");
Expect(0, 55216, '\p{Block=hangulsyllables}', "");
Expect(1, 55216, '\p{^Block=hangulsyllables}', "");
Expect(1, 55216, '\P{Block=hangulsyllables}', "");
Expect(0, 55216, '\P{^Block=hangulsyllables}', "");
Expect(1, 55215, '\p{Block=	Hangul_Syllables}', "");
Expect(0, 55215, '\p{^Block=	Hangul_Syllables}', "");
Expect(0, 55215, '\P{Block=	Hangul_Syllables}', "");
Expect(1, 55215, '\P{^Block=	Hangul_Syllables}', "");
Expect(0, 55216, '\p{Block=	Hangul_Syllables}', "");
Expect(1, 55216, '\p{^Block=	Hangul_Syllables}', "");
Expect(1, 55216, '\P{Block=	Hangul_Syllables}', "");
Expect(0, 55216, '\P{^Block=	Hangul_Syllables}', "");
Error('\p{Blk:/a/-Hangul}');
Error('\P{Blk:/a/-Hangul}');
Expect(1, 55215, '\p{Blk=hangul}', "");
Expect(0, 55215, '\p{^Blk=hangul}', "");
Expect(0, 55215, '\P{Blk=hangul}', "");
Expect(1, 55215, '\P{^Blk=hangul}', "");
Expect(0, 55216, '\p{Blk=hangul}', "");
Expect(1, 55216, '\p{^Blk=hangul}', "");
Expect(1, 55216, '\P{Blk=hangul}', "");
Expect(0, 55216, '\P{^Blk=hangul}', "");
Expect(1, 55215, '\p{Blk=--HANGUL}', "");
Expect(0, 55215, '\p{^Blk=--HANGUL}', "");
Expect(0, 55215, '\P{Blk=--HANGUL}', "");
Expect(1, 55215, '\P{^Blk=--HANGUL}', "");
Expect(0, 55216, '\p{Blk=--HANGUL}', "");
Expect(1, 55216, '\p{^Blk=--HANGUL}', "");
Expect(1, 55216, '\P{Blk=--HANGUL}', "");
Expect(0, 55216, '\P{^Blk=--HANGUL}', "");
Error('\p{Is_Block=:=_Hangul_Syllables}');
Error('\P{Is_Block=:=_Hangul_Syllables}');
Expect(1, 55215, '\p{Is_Block=hangulsyllables}', "");
Expect(0, 55215, '\p{^Is_Block=hangulsyllables}', "");
Expect(0, 55215, '\P{Is_Block=hangulsyllables}', "");
Expect(1, 55215, '\P{^Is_Block=hangulsyllables}', "");
Expect(0, 55216, '\p{Is_Block=hangulsyllables}', "");
Expect(1, 55216, '\p{^Is_Block=hangulsyllables}', "");
Expect(1, 55216, '\P{Is_Block=hangulsyllables}', "");
Expect(0, 55216, '\P{^Is_Block=hangulsyllables}', "");
Expect(1, 55215, '\p{Is_Block=		Hangul_Syllables}', "");
Expect(0, 55215, '\p{^Is_Block=		Hangul_Syllables}', "");
Expect(0, 55215, '\P{Is_Block=		Hangul_Syllables}', "");
Expect(1, 55215, '\P{^Is_Block=		Hangul_Syllables}', "");
Expect(0, 55216, '\p{Is_Block=		Hangul_Syllables}', "");
Expect(1, 55216, '\p{^Is_Block=		Hangul_Syllables}', "");
Expect(1, 55216, '\P{Is_Block=		Hangul_Syllables}', "");
Expect(0, 55216, '\P{^Is_Block=		Hangul_Syllables}', "");
Error('\p{Is_Blk=:=_	Hangul}');
Error('\P{Is_Blk=:=_	Hangul}');
Expect(1, 55215, '\p{Is_Blk=hangul}', "");
Expect(0, 55215, '\p{^Is_Blk=hangul}', "");
Expect(0, 55215, '\P{Is_Blk=hangul}', "");
Expect(1, 55215, '\P{^Is_Blk=hangul}', "");
Expect(0, 55216, '\p{Is_Blk=hangul}', "");
Expect(1, 55216, '\p{^Is_Blk=hangul}', "");
Expect(1, 55216, '\P{Is_Blk=hangul}', "");
Expect(0, 55216, '\P{^Is_Blk=hangul}', "");
Expect(1, 55215, '\p{Is_Blk=_HANGUL}', "");
Expect(0, 55215, '\p{^Is_Blk=_HANGUL}', "");
Expect(0, 55215, '\P{Is_Blk=_HANGUL}', "");
Expect(1, 55215, '\P{^Is_Blk=_HANGUL}', "");
Expect(0, 55216, '\p{Is_Blk=_HANGUL}', "");
Expect(1, 55216, '\p{^Is_Blk=_HANGUL}', "");
Expect(1, 55216, '\P{Is_Blk=_HANGUL}', "");
Expect(0, 55216, '\P{^Is_Blk=_HANGUL}', "");
Error('\p{Block=	:=Hanunoo}');
Error('\P{Block=	:=Hanunoo}');
Expect(1, 5951, '\p{Block=hanunoo}', "");
Expect(0, 5951, '\p{^Block=hanunoo}', "");
Expect(0, 5951, '\P{Block=hanunoo}', "");
Expect(1, 5951, '\P{^Block=hanunoo}', "");
Expect(0, 5952, '\p{Block=hanunoo}', "");
Expect(1, 5952, '\p{^Block=hanunoo}', "");
Expect(1, 5952, '\P{Block=hanunoo}', "");
Expect(0, 5952, '\P{^Block=hanunoo}', "");
Expect(1, 5951, '\p{Block: Hanunoo}', "");
Expect(0, 5951, '\p{^Block: Hanunoo}', "");
Expect(0, 5951, '\P{Block: Hanunoo}', "");
Expect(1, 5951, '\P{^Block: Hanunoo}', "");
Expect(0, 5952, '\p{Block: Hanunoo}', "");
Expect(1, 5952, '\p{^Block: Hanunoo}', "");
Expect(1, 5952, '\P{Block: Hanunoo}', "");
Expect(0, 5952, '\P{^Block: Hanunoo}', "");
Error('\p{Blk=:=	Hanunoo}');
Error('\P{Blk=:=	Hanunoo}');
Expect(1, 5951, '\p{Blk=hanunoo}', "");
Expect(0, 5951, '\p{^Blk=hanunoo}', "");
Expect(0, 5951, '\P{Blk=hanunoo}', "");
Expect(1, 5951, '\P{^Blk=hanunoo}', "");
Expect(0, 5952, '\p{Blk=hanunoo}', "");
Expect(1, 5952, '\p{^Blk=hanunoo}', "");
Expect(1, 5952, '\P{Blk=hanunoo}', "");
Expect(0, 5952, '\P{^Blk=hanunoo}', "");
Expect(1, 5951, '\p{Blk=	hanunoo}', "");
Expect(0, 5951, '\p{^Blk=	hanunoo}', "");
Expect(0, 5951, '\P{Blk=	hanunoo}', "");
Expect(1, 5951, '\P{^Blk=	hanunoo}', "");
Expect(0, 5952, '\p{Blk=	hanunoo}', "");
Expect(1, 5952, '\p{^Blk=	hanunoo}', "");
Expect(1, 5952, '\P{Blk=	hanunoo}', "");
Expect(0, 5952, '\P{^Blk=	hanunoo}', "");
Error('\p{Is_Block=	/a/hanunoo}');
Error('\P{Is_Block=	/a/hanunoo}');
Expect(1, 5951, '\p{Is_Block:   hanunoo}', "");
Expect(0, 5951, '\p{^Is_Block:   hanunoo}', "");
Expect(0, 5951, '\P{Is_Block:   hanunoo}', "");
Expect(1, 5951, '\P{^Is_Block:   hanunoo}', "");
Expect(0, 5952, '\p{Is_Block:   hanunoo}', "");
Expect(1, 5952, '\p{^Is_Block:   hanunoo}', "");
Expect(1, 5952, '\P{Is_Block:   hanunoo}', "");
Expect(0, 5952, '\P{^Is_Block:   hanunoo}', "");
Expect(1, 5951, '\p{Is_Block:	-hanunoo}', "");
Expect(0, 5951, '\p{^Is_Block:	-hanunoo}', "");
Expect(0, 5951, '\P{Is_Block:	-hanunoo}', "");
Expect(1, 5951, '\P{^Is_Block:	-hanunoo}', "");
Expect(0, 5952, '\p{Is_Block:	-hanunoo}', "");
Expect(1, 5952, '\p{^Is_Block:	-hanunoo}', "");
Expect(1, 5952, '\P{Is_Block:	-hanunoo}', "");
Expect(0, 5952, '\P{^Is_Block:	-hanunoo}', "");
Error('\p{Is_Blk=_:=Hanunoo}');
Error('\P{Is_Blk=_:=Hanunoo}');
Expect(1, 5951, '\p{Is_Blk=hanunoo}', "");
Expect(0, 5951, '\p{^Is_Blk=hanunoo}', "");
Expect(0, 5951, '\P{Is_Blk=hanunoo}', "");
Expect(1, 5951, '\P{^Is_Blk=hanunoo}', "");
Expect(0, 5952, '\p{Is_Blk=hanunoo}', "");
Expect(1, 5952, '\p{^Is_Blk=hanunoo}', "");
Expect(1, 5952, '\P{Is_Blk=hanunoo}', "");
Expect(0, 5952, '\P{^Is_Blk=hanunoo}', "");
Expect(1, 5951, '\p{Is_Blk=	-Hanunoo}', "");
Expect(0, 5951, '\p{^Is_Blk=	-Hanunoo}', "");
Expect(0, 5951, '\P{Is_Blk=	-Hanunoo}', "");
Expect(1, 5951, '\P{^Is_Blk=	-Hanunoo}', "");
Expect(0, 5952, '\p{Is_Blk=	-Hanunoo}', "");
Expect(1, 5952, '\p{^Is_Blk=	-Hanunoo}', "");
Expect(1, 5952, '\P{Is_Blk=	-Hanunoo}', "");
Expect(0, 5952, '\P{^Is_Blk=	-Hanunoo}', "");
Error('\p{Block=:=Hebrew}');
Error('\P{Block=:=Hebrew}');
Expect(1, 1535, '\p{Block=hebrew}', "");
Expect(0, 1535, '\p{^Block=hebrew}', "");
Expect(0, 1535, '\P{Block=hebrew}', "");
Expect(1, 1535, '\P{^Block=hebrew}', "");
Expect(0, 1536, '\p{Block=hebrew}', "");
Expect(1, 1536, '\p{^Block=hebrew}', "");
Expect(1, 1536, '\P{Block=hebrew}', "");
Expect(0, 1536, '\P{^Block=hebrew}', "");
Expect(1, 1535, '\p{Block=		HEBREW}', "");
Expect(0, 1535, '\p{^Block=		HEBREW}', "");
Expect(0, 1535, '\P{Block=		HEBREW}', "");
Expect(1, 1535, '\P{^Block=		HEBREW}', "");
Expect(0, 1536, '\p{Block=		HEBREW}', "");
Expect(1, 1536, '\p{^Block=		HEBREW}', "");
Expect(1, 1536, '\P{Block=		HEBREW}', "");
Expect(0, 1536, '\P{^Block=		HEBREW}', "");
Error('\p{Blk=-/a/Hebrew}');
Error('\P{Blk=-/a/Hebrew}');
Expect(1, 1535, '\p{Blk=hebrew}', "");
Expect(0, 1535, '\p{^Blk=hebrew}', "");
Expect(0, 1535, '\P{Blk=hebrew}', "");
Expect(1, 1535, '\P{^Blk=hebrew}', "");
Expect(0, 1536, '\p{Blk=hebrew}', "");
Expect(1, 1536, '\p{^Blk=hebrew}', "");
Expect(1, 1536, '\P{Blk=hebrew}', "");
Expect(0, 1536, '\P{^Blk=hebrew}', "");
Expect(1, 1535, '\p{Blk=		hebrew}', "");
Expect(0, 1535, '\p{^Blk=		hebrew}', "");
Expect(0, 1535, '\P{Blk=		hebrew}', "");
Expect(1, 1535, '\P{^Blk=		hebrew}', "");
Expect(0, 1536, '\p{Blk=		hebrew}', "");
Expect(1, 1536, '\p{^Blk=		hebrew}', "");
Expect(1, 1536, '\P{Blk=		hebrew}', "");
Expect(0, 1536, '\P{^Blk=		hebrew}', "");
Error('\p{Is_Block=/a/_ HEBREW}');
Error('\P{Is_Block=/a/_ HEBREW}');
Expect(1, 1535, '\p{Is_Block=hebrew}', "");
Expect(0, 1535, '\p{^Is_Block=hebrew}', "");
Expect(0, 1535, '\P{Is_Block=hebrew}', "");
Expect(1, 1535, '\P{^Is_Block=hebrew}', "");
Expect(0, 1536, '\p{Is_Block=hebrew}', "");
Expect(1, 1536, '\p{^Is_Block=hebrew}', "");
Expect(1, 1536, '\P{Is_Block=hebrew}', "");
Expect(0, 1536, '\P{^Is_Block=hebrew}', "");
Expect(1, 1535, '\p{Is_Block=_ HEBREW}', "");
Expect(0, 1535, '\p{^Is_Block=_ HEBREW}', "");
Expect(0, 1535, '\P{Is_Block=_ HEBREW}', "");
Expect(1, 1535, '\P{^Is_Block=_ HEBREW}', "");
Expect(0, 1536, '\p{Is_Block=_ HEBREW}', "");
Expect(1, 1536, '\p{^Is_Block=_ HEBREW}', "");
Expect(1, 1536, '\P{Is_Block=_ HEBREW}', "");
Expect(0, 1536, '\P{^Is_Block=_ HEBREW}', "");
Error('\p{Is_Blk=_	hebrew:=}');
Error('\P{Is_Blk=_	hebrew:=}');
Expect(1, 1535, '\p{Is_Blk=hebrew}', "");
Expect(0, 1535, '\p{^Is_Blk=hebrew}', "");
Expect(0, 1535, '\P{Is_Blk=hebrew}', "");
Expect(1, 1535, '\P{^Is_Blk=hebrew}', "");
Expect(0, 1536, '\p{Is_Blk=hebrew}', "");
Expect(1, 1536, '\p{^Is_Blk=hebrew}', "");
Expect(1, 1536, '\P{Is_Blk=hebrew}', "");
Expect(0, 1536, '\P{^Is_Blk=hebrew}', "");
Expect(1, 1535, '\p{Is_Blk= Hebrew}', "");
Expect(0, 1535, '\p{^Is_Blk= Hebrew}', "");
Expect(0, 1535, '\P{Is_Blk= Hebrew}', "");
Expect(1, 1535, '\P{^Is_Blk= Hebrew}', "");
Expect(0, 1536, '\p{Is_Blk= Hebrew}', "");
Expect(1, 1536, '\p{^Is_Blk= Hebrew}', "");
Expect(1, 1536, '\P{Is_Blk= Hebrew}', "");
Expect(0, 1536, '\P{^Is_Blk= Hebrew}', "");
Error('\p{Block=/a/-_HIGH_PRIVATE_USE_surrogates}');
Error('\P{Block=/a/-_HIGH_PRIVATE_USE_surrogates}');
Expect(1, 56319, '\p{Block=highprivateusesurrogates}', "");
Expect(0, 56319, '\p{^Block=highprivateusesurrogates}', "");
Expect(0, 56319, '\P{Block=highprivateusesurrogates}', "");
Expect(1, 56319, '\P{^Block=highprivateusesurrogates}', "");
Expect(0, 57344, '\p{Block=highprivateusesurrogates}', "");
Expect(1, 57344, '\p{^Block=highprivateusesurrogates}', "");
Expect(1, 57344, '\P{Block=highprivateusesurrogates}', "");
Expect(0, 57344, '\P{^Block=highprivateusesurrogates}', "");
Expect(1, 56319, '\p{Block= 	HIGH_private_USE_Surrogates}', "");
Expect(0, 56319, '\p{^Block= 	HIGH_private_USE_Surrogates}', "");
Expect(0, 56319, '\P{Block= 	HIGH_private_USE_Surrogates}', "");
Expect(1, 56319, '\P{^Block= 	HIGH_private_USE_Surrogates}', "");
Expect(0, 57344, '\p{Block= 	HIGH_private_USE_Surrogates}', "");
Expect(1, 57344, '\p{^Block= 	HIGH_private_USE_Surrogates}', "");
Expect(1, 57344, '\P{Block= 	HIGH_private_USE_Surrogates}', "");
Expect(0, 57344, '\P{^Block= 	HIGH_private_USE_Surrogates}', "");
Error('\p{Blk=_/a/High_PU_SURROGATES}');
Error('\P{Blk=_/a/High_PU_SURROGATES}');
Expect(1, 56319, '\p{Blk=highpusurrogates}', "");
Expect(0, 56319, '\p{^Blk=highpusurrogates}', "");
Expect(0, 56319, '\P{Blk=highpusurrogates}', "");
Expect(1, 56319, '\P{^Blk=highpusurrogates}', "");
Expect(0, 57344, '\p{Blk=highpusurrogates}', "");
Expect(1, 57344, '\p{^Blk=highpusurrogates}', "");
Expect(1, 57344, '\P{Blk=highpusurrogates}', "");
Expect(0, 57344, '\P{^Blk=highpusurrogates}', "");
Expect(1, 56319, '\p{Blk=-	High_PU_surrogates}', "");
Expect(0, 56319, '\p{^Blk=-	High_PU_surrogates}', "");
Expect(0, 56319, '\P{Blk=-	High_PU_surrogates}', "");
Expect(1, 56319, '\P{^Blk=-	High_PU_surrogates}', "");
Expect(0, 57344, '\p{Blk=-	High_PU_surrogates}', "");
Expect(1, 57344, '\p{^Blk=-	High_PU_surrogates}', "");
Expect(1, 57344, '\P{Blk=-	High_PU_surrogates}', "");
Expect(0, 57344, '\P{^Blk=-	High_PU_surrogates}', "");
Error('\p{Is_Block=:= 	high_Private_Use_Surrogates}');
Error('\P{Is_Block=:= 	high_Private_Use_Surrogates}');
Expect(1, 56319, '\p{Is_Block=highprivateusesurrogates}', "");
Expect(0, 56319, '\p{^Is_Block=highprivateusesurrogates}', "");
Expect(0, 56319, '\P{Is_Block=highprivateusesurrogates}', "");
Expect(1, 56319, '\P{^Is_Block=highprivateusesurrogates}', "");
Expect(0, 57344, '\p{Is_Block=highprivateusesurrogates}', "");
Expect(1, 57344, '\p{^Is_Block=highprivateusesurrogates}', "");
Expect(1, 57344, '\P{Is_Block=highprivateusesurrogates}', "");
Expect(0, 57344, '\P{^Is_Block=highprivateusesurrogates}', "");
Expect(1, 56319, '\p{Is_Block=	_high_Private_Use_surrogates}', "");
Expect(0, 56319, '\p{^Is_Block=	_high_Private_Use_surrogates}', "");
Expect(0, 56319, '\P{Is_Block=	_high_Private_Use_surrogates}', "");
Expect(1, 56319, '\P{^Is_Block=	_high_Private_Use_surrogates}', "");
Expect(0, 57344, '\p{Is_Block=	_high_Private_Use_surrogates}', "");
Expect(1, 57344, '\p{^Is_Block=	_high_Private_Use_surrogates}', "");
Expect(1, 57344, '\P{Is_Block=	_high_Private_Use_surrogates}', "");
Expect(0, 57344, '\P{^Is_Block=	_high_Private_Use_surrogates}', "");
Error('\p{Is_Blk=_/a/High_PU_SURROGATES}');
Error('\P{Is_Blk=_/a/High_PU_SURROGATES}');
Expect(1, 56319, '\p{Is_Blk=highpusurrogates}', "");
Expect(0, 56319, '\p{^Is_Blk=highpusurrogates}', "");
Expect(0, 56319, '\P{Is_Blk=highpusurrogates}', "");
Expect(1, 56319, '\P{^Is_Blk=highpusurrogates}', "");
Expect(0, 57344, '\p{Is_Blk=highpusurrogates}', "");
Expect(1, 57344, '\p{^Is_Blk=highpusurrogates}', "");
Expect(1, 57344, '\P{Is_Blk=highpusurrogates}', "");
Expect(0, 57344, '\P{^Is_Blk=highpusurrogates}', "");
Expect(1, 56319, '\p{Is_Blk= High_PU_Surrogates}', "");
Expect(0, 56319, '\p{^Is_Blk= High_PU_Surrogates}', "");
Expect(0, 56319, '\P{Is_Blk= High_PU_Surrogates}', "");
Expect(1, 56319, '\P{^Is_Blk= High_PU_Surrogates}', "");
Expect(0, 57344, '\p{Is_Blk= High_PU_Surrogates}', "");
Expect(1, 57344, '\p{^Is_Blk= High_PU_Surrogates}', "");
Expect(1, 57344, '\P{Is_Blk= High_PU_Surrogates}', "");
Expect(0, 57344, '\P{^Is_Blk= High_PU_Surrogates}', "");
Error('\p{Block=-	High_Surrogates:=}');
Error('\P{Block=-	High_Surrogates:=}');
Expect(1, 56191, '\p{Block=highsurrogates}', "");
Expect(0, 56191, '\p{^Block=highsurrogates}', "");
Expect(0, 56191, '\P{Block=highsurrogates}', "");
Expect(1, 56191, '\P{^Block=highsurrogates}', "");
Expect(0, 57344, '\p{Block=highsurrogates}', "");
Expect(1, 57344, '\p{^Block=highsurrogates}', "");
Expect(1, 57344, '\P{Block=highsurrogates}', "");
Expect(0, 57344, '\P{^Block=highsurrogates}', "");
Expect(1, 56191, '\p{Block=high_Surrogates}', "");
Expect(0, 56191, '\p{^Block=high_Surrogates}', "");
Expect(0, 56191, '\P{Block=high_Surrogates}', "");
Expect(1, 56191, '\P{^Block=high_Surrogates}', "");
Expect(0, 57344, '\p{Block=high_Surrogates}', "");
Expect(1, 57344, '\p{^Block=high_Surrogates}', "");
Expect(1, 57344, '\P{Block=high_Surrogates}', "");
Expect(0, 57344, '\P{^Block=high_Surrogates}', "");
Error('\p{Blk=	_high_surrogates:=}');
Error('\P{Blk=	_high_surrogates:=}');
Expect(1, 56191, '\p{Blk=highsurrogates}', "");
Expect(0, 56191, '\p{^Blk=highsurrogates}', "");
Expect(0, 56191, '\P{Blk=highsurrogates}', "");
Expect(1, 56191, '\P{^Blk=highsurrogates}', "");
Expect(0, 57344, '\p{Blk=highsurrogates}', "");
Expect(1, 57344, '\p{^Blk=highsurrogates}', "");
Expect(1, 57344, '\P{Blk=highsurrogates}', "");
Expect(0, 57344, '\P{^Blk=highsurrogates}', "");
Expect(1, 56191, '\p{Blk=-_High_Surrogates}', "");
Expect(0, 56191, '\p{^Blk=-_High_Surrogates}', "");
Expect(0, 56191, '\P{Blk=-_High_Surrogates}', "");
Expect(1, 56191, '\P{^Blk=-_High_Surrogates}', "");
Expect(0, 57344, '\p{Blk=-_High_Surrogates}', "");
Expect(1, 57344, '\p{^Blk=-_High_Surrogates}', "");
Expect(1, 57344, '\P{Blk=-_High_Surrogates}', "");
Expect(0, 57344, '\P{^Blk=-_High_Surrogates}', "");
Error('\p{Is_Block= _HIGH_Surrogates:=}');
Error('\P{Is_Block= _HIGH_Surrogates:=}');
Expect(1, 56191, '\p{Is_Block:	highsurrogates}', "");
Expect(0, 56191, '\p{^Is_Block:	highsurrogates}', "");
Expect(0, 56191, '\P{Is_Block:	highsurrogates}', "");
Expect(1, 56191, '\P{^Is_Block:	highsurrogates}', "");
Expect(0, 57344, '\p{Is_Block:	highsurrogates}', "");
Expect(1, 57344, '\p{^Is_Block:	highsurrogates}', "");
Expect(1, 57344, '\P{Is_Block:	highsurrogates}', "");
Expect(0, 57344, '\P{^Is_Block:	highsurrogates}', "");
Expect(1, 56191, '\p{Is_Block=_-HIGH_surrogates}', "");
Expect(0, 56191, '\p{^Is_Block=_-HIGH_surrogates}', "");
Expect(0, 56191, '\P{Is_Block=_-HIGH_surrogates}', "");
Expect(1, 56191, '\P{^Is_Block=_-HIGH_surrogates}', "");
Expect(0, 57344, '\p{Is_Block=_-HIGH_surrogates}', "");
Expect(1, 57344, '\p{^Is_Block=_-HIGH_surrogates}', "");
Expect(1, 57344, '\P{Is_Block=_-HIGH_surrogates}', "");
Expect(0, 57344, '\P{^Is_Block=_-HIGH_surrogates}', "");
Error('\p{Is_Blk=__HIGH_surrogates:=}');
Error('\P{Is_Blk=__HIGH_surrogates:=}');
Expect(1, 56191, '\p{Is_Blk=highsurrogates}', "");
Expect(0, 56191, '\p{^Is_Blk=highsurrogates}', "");
Expect(0, 56191, '\P{Is_Blk=highsurrogates}', "");
Expect(1, 56191, '\P{^Is_Blk=highsurrogates}', "");
Expect(0, 57344, '\p{Is_Blk=highsurrogates}', "");
Expect(1, 57344, '\p{^Is_Blk=highsurrogates}', "");
Expect(1, 57344, '\P{Is_Blk=highsurrogates}', "");
Expect(0, 57344, '\P{^Is_Blk=highsurrogates}', "");
Expect(1, 56191, '\p{Is_Blk: HIGH_Surrogates}', "");
Expect(0, 56191, '\p{^Is_Blk: HIGH_Surrogates}', "");
Expect(0, 56191, '\P{Is_Blk: HIGH_Surrogates}', "");
Expect(1, 56191, '\P{^Is_Blk: HIGH_Surrogates}', "");
Expect(0, 57344, '\p{Is_Blk: HIGH_Surrogates}', "");
Expect(1, 57344, '\p{^Is_Blk: HIGH_Surrogates}', "");
Expect(1, 57344, '\P{Is_Blk: HIGH_Surrogates}', "");
Expect(0, 57344, '\P{^Is_Blk: HIGH_Surrogates}', "");
Error('\p{Block=-:=HIRAGANA}');
Error('\P{Block=-:=HIRAGANA}');
Expect(1, 12447, '\p{Block=hiragana}', "");
Expect(0, 12447, '\p{^Block=hiragana}', "");
Expect(0, 12447, '\P{Block=hiragana}', "");
Expect(1, 12447, '\P{^Block=hiragana}', "");
Expect(0, 12448, '\p{Block=hiragana}', "");
Expect(1, 12448, '\p{^Block=hiragana}', "");
Expect(1, 12448, '\P{Block=hiragana}', "");
Expect(0, 12448, '\P{^Block=hiragana}', "");
Expect(1, 12447, '\p{Block=--Hiragana}', "");
Expect(0, 12447, '\p{^Block=--Hiragana}', "");
Expect(0, 12447, '\P{Block=--Hiragana}', "");
Expect(1, 12447, '\P{^Block=--Hiragana}', "");
Expect(0, 12448, '\p{Block=--Hiragana}', "");
Expect(1, 12448, '\p{^Block=--Hiragana}', "");
Expect(1, 12448, '\P{Block=--Hiragana}', "");
Expect(0, 12448, '\P{^Block=--Hiragana}', "");
Error('\p{Blk= Hiragana:=}');
Error('\P{Blk= Hiragana:=}');
Expect(1, 12447, '\p{Blk:hiragana}', "");
Expect(0, 12447, '\p{^Blk:hiragana}', "");
Expect(0, 12447, '\P{Blk:hiragana}', "");
Expect(1, 12447, '\P{^Blk:hiragana}', "");
Expect(0, 12448, '\p{Blk:hiragana}', "");
Expect(1, 12448, '\p{^Blk:hiragana}', "");
Expect(1, 12448, '\P{Blk:hiragana}', "");
Expect(0, 12448, '\P{^Blk:hiragana}', "");
Expect(1, 12447, '\p{Blk=_ hiragana}', "");
Expect(0, 12447, '\p{^Blk=_ hiragana}', "");
Expect(0, 12447, '\P{Blk=_ hiragana}', "");
Expect(1, 12447, '\P{^Blk=_ hiragana}', "");
Expect(0, 12448, '\p{Blk=_ hiragana}', "");
Expect(1, 12448, '\p{^Blk=_ hiragana}', "");
Expect(1, 12448, '\P{Blk=_ hiragana}', "");
Expect(0, 12448, '\P{^Blk=_ hiragana}', "");
Error('\p{Is_Block=	/a/Hiragana}');
Error('\P{Is_Block=	/a/Hiragana}');
Expect(1, 12447, '\p{Is_Block=hiragana}', "");
Expect(0, 12447, '\p{^Is_Block=hiragana}', "");
Expect(0, 12447, '\P{Is_Block=hiragana}', "");
Expect(1, 12447, '\P{^Is_Block=hiragana}', "");
Expect(0, 12448, '\p{Is_Block=hiragana}', "");
Expect(1, 12448, '\p{^Is_Block=hiragana}', "");
Expect(1, 12448, '\P{Is_Block=hiragana}', "");
Expect(0, 12448, '\P{^Is_Block=hiragana}', "");
Expect(1, 12447, '\p{Is_Block: 	hiragana}', "");
Expect(0, 12447, '\p{^Is_Block: 	hiragana}', "");
Expect(0, 12447, '\P{Is_Block: 	hiragana}', "");
Expect(1, 12447, '\P{^Is_Block: 	hiragana}', "");
Expect(0, 12448, '\p{Is_Block: 	hiragana}', "");
Expect(1, 12448, '\p{^Is_Block: 	hiragana}', "");
Expect(1, 12448, '\P{Is_Block: 	hiragana}', "");
Expect(0, 12448, '\P{^Is_Block: 	hiragana}', "");
Error('\p{Is_Blk= hiragana:=}');
Error('\P{Is_Blk= hiragana:=}');
Expect(1, 12447, '\p{Is_Blk=hiragana}', "");
Expect(0, 12447, '\p{^Is_Blk=hiragana}', "");
Expect(0, 12447, '\P{Is_Blk=hiragana}', "");
Expect(1, 12447, '\P{^Is_Blk=hiragana}', "");
Expect(0, 12448, '\p{Is_Blk=hiragana}', "");
Expect(1, 12448, '\p{^Is_Blk=hiragana}', "");
Expect(1, 12448, '\P{Is_Blk=hiragana}', "");
Expect(0, 12448, '\P{^Is_Blk=hiragana}', "");
Expect(1, 12447, '\p{Is_Blk=-	HIRAGANA}', "");
Expect(0, 12447, '\p{^Is_Blk=-	HIRAGANA}', "");
Expect(0, 12447, '\P{Is_Blk=-	HIRAGANA}', "");
Expect(1, 12447, '\P{^Is_Blk=-	HIRAGANA}', "");
Expect(0, 12448, '\p{Is_Blk=-	HIRAGANA}', "");
Expect(1, 12448, '\p{^Is_Blk=-	HIRAGANA}', "");
Expect(1, 12448, '\P{Is_Blk=-	HIRAGANA}', "");
Expect(0, 12448, '\P{^Is_Blk=-	HIRAGANA}', "");
Error('\p{Block= _Ideographic_Description_Characters:=}');
Error('\P{Block= _Ideographic_Description_Characters:=}');
Expect(1, 12287, '\p{Block=ideographicdescriptioncharacters}', "");
Expect(0, 12287, '\p{^Block=ideographicdescriptioncharacters}', "");
Expect(0, 12287, '\P{Block=ideographicdescriptioncharacters}', "");
Expect(1, 12287, '\P{^Block=ideographicdescriptioncharacters}', "");
Expect(0, 12288, '\p{Block=ideographicdescriptioncharacters}', "");
Expect(1, 12288, '\p{^Block=ideographicdescriptioncharacters}', "");
Expect(1, 12288, '\P{Block=ideographicdescriptioncharacters}', "");
Expect(0, 12288, '\P{^Block=ideographicdescriptioncharacters}', "");
Expect(1, 12287, '\p{Block=__Ideographic_DESCRIPTION_Characters}', "");
Expect(0, 12287, '\p{^Block=__Ideographic_DESCRIPTION_Characters}', "");
Expect(0, 12287, '\P{Block=__Ideographic_DESCRIPTION_Characters}', "");
Expect(1, 12287, '\P{^Block=__Ideographic_DESCRIPTION_Characters}', "");
Expect(0, 12288, '\p{Block=__Ideographic_DESCRIPTION_Characters}', "");
Expect(1, 12288, '\p{^Block=__Ideographic_DESCRIPTION_Characters}', "");
Expect(1, 12288, '\P{Block=__Ideographic_DESCRIPTION_Characters}', "");
Expect(0, 12288, '\P{^Block=__Ideographic_DESCRIPTION_Characters}', "");
Error('\p{Blk=-/a/IDC}');
Error('\P{Blk=-/a/IDC}');
Expect(1, 12287, '\p{Blk: idc}', "");
Expect(0, 12287, '\p{^Blk: idc}', "");
Expect(0, 12287, '\P{Blk: idc}', "");
Expect(1, 12287, '\P{^Blk: idc}', "");
Expect(0, 12288, '\p{Blk: idc}', "");
Expect(1, 12288, '\p{^Blk: idc}', "");
Expect(1, 12288, '\P{Blk: idc}', "");
Expect(0, 12288, '\P{^Blk: idc}', "");
Expect(1, 12287, '\p{Blk=	idc}', "");
Expect(0, 12287, '\p{^Blk=	idc}', "");
Expect(0, 12287, '\P{Blk=	idc}', "");
Expect(1, 12287, '\P{^Blk=	idc}', "");
Expect(0, 12288, '\p{Blk=	idc}', "");
Expect(1, 12288, '\p{^Blk=	idc}', "");
Expect(1, 12288, '\P{Blk=	idc}', "");
Expect(0, 12288, '\P{^Blk=	idc}', "");
Error('\p{Is_Block=--Ideographic_DESCRIPTION_Characters:=}');
Error('\P{Is_Block=--Ideographic_DESCRIPTION_Characters:=}');
Expect(1, 12287, '\p{Is_Block=ideographicdescriptioncharacters}', "");
Expect(0, 12287, '\p{^Is_Block=ideographicdescriptioncharacters}', "");
Expect(0, 12287, '\P{Is_Block=ideographicdescriptioncharacters}', "");
Expect(1, 12287, '\P{^Is_Block=ideographicdescriptioncharacters}', "");
Expect(0, 12288, '\p{Is_Block=ideographicdescriptioncharacters}', "");
Expect(1, 12288, '\p{^Is_Block=ideographicdescriptioncharacters}', "");
Expect(1, 12288, '\P{Is_Block=ideographicdescriptioncharacters}', "");
Expect(0, 12288, '\P{^Is_Block=ideographicdescriptioncharacters}', "");
Expect(1, 12287, '\p{Is_Block=-IDEOGRAPHIC_DESCRIPTION_Characters}', "");
Expect(0, 12287, '\p{^Is_Block=-IDEOGRAPHIC_DESCRIPTION_Characters}', "");
Expect(0, 12287, '\P{Is_Block=-IDEOGRAPHIC_DESCRIPTION_Characters}', "");
Expect(1, 12287, '\P{^Is_Block=-IDEOGRAPHIC_DESCRIPTION_Characters}', "");
Expect(0, 12288, '\p{Is_Block=-IDEOGRAPHIC_DESCRIPTION_Characters}', "");
Expect(1, 12288, '\p{^Is_Block=-IDEOGRAPHIC_DESCRIPTION_Characters}', "");
Expect(1, 12288, '\P{Is_Block=-IDEOGRAPHIC_DESCRIPTION_Characters}', "");
Expect(0, 12288, '\P{^Is_Block=-IDEOGRAPHIC_DESCRIPTION_Characters}', "");
Error('\p{Is_Blk=-	IDC/a/}');
Error('\P{Is_Blk=-	IDC/a/}');
Expect(1, 12287, '\p{Is_Blk=idc}', "");
Expect(0, 12287, '\p{^Is_Blk=idc}', "");
Expect(0, 12287, '\P{Is_Blk=idc}', "");
Expect(1, 12287, '\P{^Is_Blk=idc}', "");
Expect(0, 12288, '\p{Is_Blk=idc}', "");
Expect(1, 12288, '\p{^Is_Blk=idc}', "");
Expect(1, 12288, '\P{Is_Blk=idc}', "");
Expect(0, 12288, '\P{^Is_Blk=idc}', "");
Expect(1, 12287, '\p{Is_Blk=-IDC}', "");
Expect(0, 12287, '\p{^Is_Blk=-IDC}', "");
Expect(0, 12287, '\P{Is_Blk=-IDC}', "");
Expect(1, 12287, '\P{^Is_Blk=-IDC}', "");
Expect(0, 12288, '\p{Is_Blk=-IDC}', "");
Expect(1, 12288, '\p{^Is_Blk=-IDC}', "");
Expect(1, 12288, '\P{Is_Blk=-IDC}', "");
Expect(0, 12288, '\P{^Is_Blk=-IDC}', "");
Error('\p{Block=-/a/ipa_EXTENSIONS}');
Error('\P{Block=-/a/ipa_EXTENSIONS}');
Expect(1, 687, '\p{Block:   ipaextensions}', "");
Expect(0, 687, '\p{^Block:   ipaextensions}', "");
Expect(0, 687, '\P{Block:   ipaextensions}', "");
Expect(1, 687, '\P{^Block:   ipaextensions}', "");
Expect(0, 688, '\p{Block:   ipaextensions}', "");
Expect(1, 688, '\p{^Block:   ipaextensions}', "");
Expect(1, 688, '\P{Block:   ipaextensions}', "");
Expect(0, 688, '\P{^Block:   ipaextensions}', "");
Expect(1, 687, '\p{Block= IPA_Extensions}', "");
Expect(0, 687, '\p{^Block= IPA_Extensions}', "");
Expect(0, 687, '\P{Block= IPA_Extensions}', "");
Expect(1, 687, '\P{^Block= IPA_Extensions}', "");
Expect(0, 688, '\p{Block= IPA_Extensions}', "");
Expect(1, 688, '\p{^Block= IPA_Extensions}', "");
Expect(1, 688, '\P{Block= IPA_Extensions}', "");
Expect(0, 688, '\P{^Block= IPA_Extensions}', "");
Error('\p{Blk=:= _ipa_Ext}');
Error('\P{Blk=:= _ipa_Ext}');
Expect(1, 687, '\p{Blk=ipaext}', "");
Expect(0, 687, '\p{^Blk=ipaext}', "");
Expect(0, 687, '\P{Blk=ipaext}', "");
Expect(1, 687, '\P{^Blk=ipaext}', "");
Expect(0, 688, '\p{Blk=ipaext}', "");
Expect(1, 688, '\p{^Blk=ipaext}', "");
Expect(1, 688, '\P{Blk=ipaext}', "");
Expect(0, 688, '\P{^Blk=ipaext}', "");
Expect(1, 687, '\p{Blk=- IPA_ext}', "");
Expect(0, 687, '\p{^Blk=- IPA_ext}', "");
Expect(0, 687, '\P{Blk=- IPA_ext}', "");
Expect(1, 687, '\P{^Blk=- IPA_ext}', "");
Expect(0, 688, '\p{Blk=- IPA_ext}', "");
Expect(1, 688, '\p{^Blk=- IPA_ext}', "");
Expect(1, 688, '\P{Blk=- IPA_ext}', "");
Expect(0, 688, '\P{^Blk=- IPA_ext}', "");
Error('\p{Is_Block=:=__IPA_Extensions}');
Error('\P{Is_Block=:=__IPA_Extensions}');
Expect(1, 687, '\p{Is_Block=ipaextensions}', "");
Expect(0, 687, '\p{^Is_Block=ipaextensions}', "");
Expect(0, 687, '\P{Is_Block=ipaextensions}', "");
Expect(1, 687, '\P{^Is_Block=ipaextensions}', "");
Expect(0, 688, '\p{Is_Block=ipaextensions}', "");
Expect(1, 688, '\p{^Is_Block=ipaextensions}', "");
Expect(1, 688, '\P{Is_Block=ipaextensions}', "");
Expect(0, 688, '\P{^Is_Block=ipaextensions}', "");
Expect(1, 687, '\p{Is_Block=	IPA_extensions}', "");
Expect(0, 687, '\p{^Is_Block=	IPA_extensions}', "");
Expect(0, 687, '\P{Is_Block=	IPA_extensions}', "");
Expect(1, 687, '\P{^Is_Block=	IPA_extensions}', "");
Expect(0, 688, '\p{Is_Block=	IPA_extensions}', "");
Expect(1, 688, '\p{^Is_Block=	IPA_extensions}', "");
Expect(1, 688, '\P{Is_Block=	IPA_extensions}', "");
Expect(0, 688, '\P{^Is_Block=	IPA_extensions}', "");
Error('\p{Is_Blk=/a/ _ipa_Ext}');
Error('\P{Is_Blk=/a/ _ipa_Ext}');
Expect(1, 687, '\p{Is_Blk=ipaext}', "");
Expect(0, 687, '\p{^Is_Blk=ipaext}', "");
Expect(0, 687, '\P{Is_Blk=ipaext}', "");
Expect(1, 687, '\P{^Is_Blk=ipaext}', "");
Expect(0, 688, '\p{Is_Blk=ipaext}', "");
Expect(1, 688, '\p{^Is_Blk=ipaext}', "");
Expect(1, 688, '\P{Is_Blk=ipaext}', "");
Expect(0, 688, '\P{^Is_Blk=ipaext}', "");
Expect(1, 687, '\p{Is_Blk=_ IPA_Ext}', "");
Expect(0, 687, '\p{^Is_Blk=_ IPA_Ext}', "");
Expect(0, 687, '\P{Is_Blk=_ IPA_Ext}', "");
Expect(1, 687, '\P{^Is_Blk=_ IPA_Ext}', "");
Expect(0, 688, '\p{Is_Blk=_ IPA_Ext}', "");
Expect(1, 688, '\p{^Is_Blk=_ IPA_Ext}', "");
Expect(1, 688, '\P{Is_Blk=_ IPA_Ext}', "");
Expect(0, 688, '\P{^Is_Blk=_ IPA_Ext}', "");
Error('\p{Block=/a/_imperial_aramaic}');
Error('\P{Block=/a/_imperial_aramaic}');
Expect(1, 67679, '\p{Block=imperialaramaic}', "");
Expect(0, 67679, '\p{^Block=imperialaramaic}', "");
Expect(0, 67679, '\P{Block=imperialaramaic}', "");
Expect(1, 67679, '\P{^Block=imperialaramaic}', "");
Expect(0, 67680, '\p{Block=imperialaramaic}', "");
Expect(1, 67680, '\p{^Block=imperialaramaic}', "");
Expect(1, 67680, '\P{Block=imperialaramaic}', "");
Expect(0, 67680, '\P{^Block=imperialaramaic}', "");
Expect(1, 67679, '\p{Block=imperial_aramaic}', "");
Expect(0, 67679, '\p{^Block=imperial_aramaic}', "");
Expect(0, 67679, '\P{Block=imperial_aramaic}', "");
Expect(1, 67679, '\P{^Block=imperial_aramaic}', "");
Expect(0, 67680, '\p{Block=imperial_aramaic}', "");
Expect(1, 67680, '\p{^Block=imperial_aramaic}', "");
Expect(1, 67680, '\P{Block=imperial_aramaic}', "");
Expect(0, 67680, '\P{^Block=imperial_aramaic}', "");
Error('\p{Blk=/a/ IMPERIAL_Aramaic}');
Error('\P{Blk=/a/ IMPERIAL_Aramaic}');
Expect(1, 67679, '\p{Blk:   imperialaramaic}', "");
Expect(0, 67679, '\p{^Blk:   imperialaramaic}', "");
Expect(0, 67679, '\P{Blk:   imperialaramaic}', "");
Expect(1, 67679, '\P{^Blk:   imperialaramaic}', "");
Expect(0, 67680, '\p{Blk:   imperialaramaic}', "");
Expect(1, 67680, '\p{^Blk:   imperialaramaic}', "");
Expect(1, 67680, '\P{Blk:   imperialaramaic}', "");
Expect(0, 67680, '\P{^Blk:   imperialaramaic}', "");
Expect(1, 67679, '\p{Blk=__imperial_aramaic}', "");
Expect(0, 67679, '\p{^Blk=__imperial_aramaic}', "");
Expect(0, 67679, '\P{Blk=__imperial_aramaic}', "");
Expect(1, 67679, '\P{^Blk=__imperial_aramaic}', "");
Expect(0, 67680, '\p{Blk=__imperial_aramaic}', "");
Expect(1, 67680, '\p{^Blk=__imperial_aramaic}', "");
Expect(1, 67680, '\P{Blk=__imperial_aramaic}', "");
Expect(0, 67680, '\P{^Blk=__imperial_aramaic}', "");
Error('\p{Is_Block=/a/	IMPERIAL_aramaic}');
Error('\P{Is_Block=/a/	IMPERIAL_aramaic}');
Expect(1, 67679, '\p{Is_Block:   imperialaramaic}', "");
Expect(0, 67679, '\p{^Is_Block:   imperialaramaic}', "");
Expect(0, 67679, '\P{Is_Block:   imperialaramaic}', "");
Expect(1, 67679, '\P{^Is_Block:   imperialaramaic}', "");
Expect(0, 67680, '\p{Is_Block:   imperialaramaic}', "");
Expect(1, 67680, '\p{^Is_Block:   imperialaramaic}', "");
Expect(1, 67680, '\P{Is_Block:   imperialaramaic}', "");
Expect(0, 67680, '\P{^Is_Block:   imperialaramaic}', "");
Expect(1, 67679, '\p{Is_Block=_Imperial_aramaic}', "");
Expect(0, 67679, '\p{^Is_Block=_Imperial_aramaic}', "");
Expect(0, 67679, '\P{Is_Block=_Imperial_aramaic}', "");
Expect(1, 67679, '\P{^Is_Block=_Imperial_aramaic}', "");
Expect(0, 67680, '\p{Is_Block=_Imperial_aramaic}', "");
Expect(1, 67680, '\p{^Is_Block=_Imperial_aramaic}', "");
Expect(1, 67680, '\P{Is_Block=_Imperial_aramaic}', "");
Expect(0, 67680, '\P{^Is_Block=_Imperial_aramaic}', "");
Error('\p{Is_Blk=-imperial_aramaic/a/}');
Error('\P{Is_Blk=-imperial_aramaic/a/}');
Expect(1, 67679, '\p{Is_Blk=imperialaramaic}', "");
Expect(0, 67679, '\p{^Is_Blk=imperialaramaic}', "");
Expect(0, 67679, '\P{Is_Blk=imperialaramaic}', "");
Expect(1, 67679, '\P{^Is_Blk=imperialaramaic}', "");
Expect(0, 67680, '\p{Is_Blk=imperialaramaic}', "");
Expect(1, 67680, '\p{^Is_Blk=imperialaramaic}', "");
Expect(1, 67680, '\P{Is_Blk=imperialaramaic}', "");
Expect(0, 67680, '\P{^Is_Blk=imperialaramaic}', "");
Expect(1, 67679, '\p{Is_Blk=_-Imperial_ARAMAIC}', "");
Expect(0, 67679, '\p{^Is_Blk=_-Imperial_ARAMAIC}', "");
Expect(0, 67679, '\P{Is_Blk=_-Imperial_ARAMAIC}', "");
Expect(1, 67679, '\P{^Is_Blk=_-Imperial_ARAMAIC}', "");
Expect(0, 67680, '\p{Is_Blk=_-Imperial_ARAMAIC}', "");
Expect(1, 67680, '\p{^Is_Blk=_-Imperial_ARAMAIC}', "");
Expect(1, 67680, '\P{Is_Blk=_-Imperial_ARAMAIC}', "");
Expect(0, 67680, '\P{^Is_Blk=_-Imperial_ARAMAIC}', "");
Error('\p{Block=/a/_common_indic_Number_FORMS}');
Error('\P{Block=/a/_common_indic_Number_FORMS}');
Expect(1, 43071, '\p{Block=commonindicnumberforms}', "");
Expect(0, 43071, '\p{^Block=commonindicnumberforms}', "");
Expect(0, 43071, '\P{Block=commonindicnumberforms}', "");
Expect(1, 43071, '\P{^Block=commonindicnumberforms}', "");
Expect(0, 43072, '\p{Block=commonindicnumberforms}', "");
Expect(1, 43072, '\p{^Block=commonindicnumberforms}', "");
Expect(1, 43072, '\P{Block=commonindicnumberforms}', "");
Expect(0, 43072, '\P{^Block=commonindicnumberforms}', "");
Expect(1, 43071, '\p{Block=_	Common_Indic_number_Forms}', "");
Expect(0, 43071, '\p{^Block=_	Common_Indic_number_Forms}', "");
Expect(0, 43071, '\P{Block=_	Common_Indic_number_Forms}', "");
Expect(1, 43071, '\P{^Block=_	Common_Indic_number_Forms}', "");
Expect(0, 43072, '\p{Block=_	Common_Indic_number_Forms}', "");
Expect(1, 43072, '\p{^Block=_	Common_Indic_number_Forms}', "");
Expect(1, 43072, '\P{Block=_	Common_Indic_number_Forms}', "");
Expect(0, 43072, '\P{^Block=_	Common_Indic_number_Forms}', "");
Error('\p{Blk=-/a/INDIC_number_Forms}');
Error('\P{Blk=-/a/INDIC_number_Forms}');
Expect(1, 43071, '\p{Blk=indicnumberforms}', "");
Expect(0, 43071, '\p{^Blk=indicnumberforms}', "");
Expect(0, 43071, '\P{Blk=indicnumberforms}', "");
Expect(1, 43071, '\P{^Blk=indicnumberforms}', "");
Expect(0, 43072, '\p{Blk=indicnumberforms}', "");
Expect(1, 43072, '\p{^Blk=indicnumberforms}', "");
Expect(1, 43072, '\P{Blk=indicnumberforms}', "");
Expect(0, 43072, '\P{^Blk=indicnumberforms}', "");
Expect(1, 43071, '\p{Blk=- Indic_Number_forms}', "");
Expect(0, 43071, '\p{^Blk=- Indic_Number_forms}', "");
Expect(0, 43071, '\P{Blk=- Indic_Number_forms}', "");
Expect(1, 43071, '\P{^Blk=- Indic_Number_forms}', "");
Expect(0, 43072, '\p{Blk=- Indic_Number_forms}', "");
Expect(1, 43072, '\p{^Blk=- Indic_Number_forms}', "");
Expect(1, 43072, '\P{Blk=- Indic_Number_forms}', "");
Expect(0, 43072, '\P{^Blk=- Indic_Number_forms}', "");
Error('\p{Is_Block= _Common_INDIC_number_Forms:=}');
Error('\P{Is_Block= _Common_INDIC_number_Forms:=}');
Expect(1, 43071, '\p{Is_Block: commonindicnumberforms}', "");
Expect(0, 43071, '\p{^Is_Block: commonindicnumberforms}', "");
Expect(0, 43071, '\P{Is_Block: commonindicnumberforms}', "");
Expect(1, 43071, '\P{^Is_Block: commonindicnumberforms}', "");
Expect(0, 43072, '\p{Is_Block: commonindicnumberforms}', "");
Expect(1, 43072, '\p{^Is_Block: commonindicnumberforms}', "");
Expect(1, 43072, '\P{Is_Block: commonindicnumberforms}', "");
Expect(0, 43072, '\P{^Is_Block: commonindicnumberforms}', "");
Expect(1, 43071, '\p{Is_Block:   -_Common_indic_Number_Forms}', "");
Expect(0, 43071, '\p{^Is_Block:   -_Common_indic_Number_Forms}', "");
Expect(0, 43071, '\P{Is_Block:   -_Common_indic_Number_Forms}', "");
Expect(1, 43071, '\P{^Is_Block:   -_Common_indic_Number_Forms}', "");
Expect(0, 43072, '\p{Is_Block:   -_Common_indic_Number_Forms}', "");
Expect(1, 43072, '\p{^Is_Block:   -_Common_indic_Number_Forms}', "");
Expect(1, 43072, '\P{Is_Block:   -_Common_indic_Number_Forms}', "");
Expect(0, 43072, '\P{^Is_Block:   -_Common_indic_Number_Forms}', "");
Error('\p{Is_Blk=	 Indic_Number_FORMS:=}');
Error('\P{Is_Blk=	 Indic_Number_FORMS:=}');
Expect(1, 43071, '\p{Is_Blk=indicnumberforms}', "");
Expect(0, 43071, '\p{^Is_Blk=indicnumberforms}', "");
Expect(0, 43071, '\P{Is_Blk=indicnumberforms}', "");
Expect(1, 43071, '\P{^Is_Blk=indicnumberforms}', "");
Expect(0, 43072, '\p{Is_Blk=indicnumberforms}', "");
Expect(1, 43072, '\p{^Is_Blk=indicnumberforms}', "");
Expect(1, 43072, '\P{Is_Blk=indicnumberforms}', "");
Expect(0, 43072, '\P{^Is_Blk=indicnumberforms}', "");
Expect(1, 43071, '\p{Is_Blk=	INDIC_NUMBER_Forms}', "");
Expect(0, 43071, '\p{^Is_Blk=	INDIC_NUMBER_Forms}', "");
Expect(0, 43071, '\P{Is_Blk=	INDIC_NUMBER_Forms}', "");
Expect(1, 43071, '\P{^Is_Blk=	INDIC_NUMBER_Forms}', "");
Expect(0, 43072, '\p{Is_Blk=	INDIC_NUMBER_Forms}', "");
Expect(1, 43072, '\p{^Is_Blk=	INDIC_NUMBER_Forms}', "");
Expect(1, 43072, '\P{Is_Blk=	INDIC_NUMBER_Forms}', "");
Expect(0, 43072, '\P{^Is_Blk=	INDIC_NUMBER_Forms}', "");
Error('\p{Block=-/a/INSCRIPTIONAL_pahlavi}');
Error('\P{Block=-/a/INSCRIPTIONAL_pahlavi}');
Expect(1, 68479, '\p{Block=inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^Block=inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{Block=inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^Block=inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{Block=inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^Block=inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{Block=inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^Block=inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{Block=_	INSCRIPTIONAL_Pahlavi}', "");
Expect(0, 68479, '\p{^Block=_	INSCRIPTIONAL_Pahlavi}', "");
Expect(0, 68479, '\P{Block=_	INSCRIPTIONAL_Pahlavi}', "");
Expect(1, 68479, '\P{^Block=_	INSCRIPTIONAL_Pahlavi}', "");
Expect(0, 68480, '\p{Block=_	INSCRIPTIONAL_Pahlavi}', "");
Expect(1, 68480, '\p{^Block=_	INSCRIPTIONAL_Pahlavi}', "");
Expect(1, 68480, '\P{Block=_	INSCRIPTIONAL_Pahlavi}', "");
Expect(0, 68480, '\P{^Block=_	INSCRIPTIONAL_Pahlavi}', "");
Error('\p{Blk=	/a/inscriptional_PAHLAVI}');
Error('\P{Blk=	/a/inscriptional_PAHLAVI}');
Expect(1, 68479, '\p{Blk=inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^Blk=inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{Blk=inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^Blk=inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{Blk=inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^Blk=inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{Blk=inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^Blk=inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{Blk= _Inscriptional_PAHLAVI}', "");
Expect(0, 68479, '\p{^Blk= _Inscriptional_PAHLAVI}', "");
Expect(0, 68479, '\P{Blk= _Inscriptional_PAHLAVI}', "");
Expect(1, 68479, '\P{^Blk= _Inscriptional_PAHLAVI}', "");
Expect(0, 68480, '\p{Blk= _Inscriptional_PAHLAVI}', "");
Expect(1, 68480, '\p{^Blk= _Inscriptional_PAHLAVI}', "");
Expect(1, 68480, '\P{Blk= _Inscriptional_PAHLAVI}', "");
Expect(0, 68480, '\P{^Blk= _Inscriptional_PAHLAVI}', "");
Error('\p{Is_Block=inscriptional_pahlavi/a/}');
Error('\P{Is_Block=inscriptional_pahlavi/a/}');
Expect(1, 68479, '\p{Is_Block=inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^Is_Block=inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{Is_Block=inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^Is_Block=inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{Is_Block=inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^Is_Block=inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{Is_Block=inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^Is_Block=inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{Is_Block=_ INSCRIPTIONAL_Pahlavi}', "");
Expect(0, 68479, '\p{^Is_Block=_ INSCRIPTIONAL_Pahlavi}', "");
Expect(0, 68479, '\P{Is_Block=_ INSCRIPTIONAL_Pahlavi}', "");
Expect(1, 68479, '\P{^Is_Block=_ INSCRIPTIONAL_Pahlavi}', "");
Expect(0, 68480, '\p{Is_Block=_ INSCRIPTIONAL_Pahlavi}', "");
Expect(1, 68480, '\p{^Is_Block=_ INSCRIPTIONAL_Pahlavi}', "");
Expect(1, 68480, '\P{Is_Block=_ INSCRIPTIONAL_Pahlavi}', "");
Expect(0, 68480, '\P{^Is_Block=_ INSCRIPTIONAL_Pahlavi}', "");
Error('\p{Is_Blk=_/a/Inscriptional_PAHLAVI}');
Error('\P{Is_Blk=_/a/Inscriptional_PAHLAVI}');
Expect(1, 68479, '\p{Is_Blk=inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^Is_Blk=inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{Is_Blk=inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^Is_Blk=inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{Is_Blk=inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^Is_Blk=inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{Is_Blk=inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^Is_Blk=inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{Is_Blk=-Inscriptional_Pahlavi}', "");
Expect(0, 68479, '\p{^Is_Blk=-Inscriptional_Pahlavi}', "");
Expect(0, 68479, '\P{Is_Blk=-Inscriptional_Pahlavi}', "");
Expect(1, 68479, '\P{^Is_Blk=-Inscriptional_Pahlavi}', "");
Expect(0, 68480, '\p{Is_Blk=-Inscriptional_Pahlavi}', "");
Expect(1, 68480, '\p{^Is_Blk=-Inscriptional_Pahlavi}', "");
Expect(1, 68480, '\P{Is_Blk=-Inscriptional_Pahlavi}', "");
Expect(0, 68480, '\P{^Is_Blk=-Inscriptional_Pahlavi}', "");
Error('\p{Block=Inscriptional_Parthian:=}');
Error('\P{Block=Inscriptional_Parthian:=}');
Expect(1, 68447, '\p{Block=inscriptionalparthian}', "");
Expect(0, 68447, '\p{^Block=inscriptionalparthian}', "");
Expect(0, 68447, '\P{Block=inscriptionalparthian}', "");
Expect(1, 68447, '\P{^Block=inscriptionalparthian}', "");
Expect(0, 68448, '\p{Block=inscriptionalparthian}', "");
Expect(1, 68448, '\p{^Block=inscriptionalparthian}', "");
Expect(1, 68448, '\P{Block=inscriptionalparthian}', "");
Expect(0, 68448, '\P{^Block=inscriptionalparthian}', "");
Expect(1, 68447, '\p{Block=-_Inscriptional_PARTHIAN}', "");
Expect(0, 68447, '\p{^Block=-_Inscriptional_PARTHIAN}', "");
Expect(0, 68447, '\P{Block=-_Inscriptional_PARTHIAN}', "");
Expect(1, 68447, '\P{^Block=-_Inscriptional_PARTHIAN}', "");
Expect(0, 68448, '\p{Block=-_Inscriptional_PARTHIAN}', "");
Expect(1, 68448, '\p{^Block=-_Inscriptional_PARTHIAN}', "");
Expect(1, 68448, '\P{Block=-_Inscriptional_PARTHIAN}', "");
Expect(0, 68448, '\P{^Block=-_Inscriptional_PARTHIAN}', "");
Error('\p{Blk=	/a/Inscriptional_PARTHIAN}');
Error('\P{Blk=	/a/Inscriptional_PARTHIAN}');
Expect(1, 68447, '\p{Blk=inscriptionalparthian}', "");
Expect(0, 68447, '\p{^Blk=inscriptionalparthian}', "");
Expect(0, 68447, '\P{Blk=inscriptionalparthian}', "");
Expect(1, 68447, '\P{^Blk=inscriptionalparthian}', "");
Expect(0, 68448, '\p{Blk=inscriptionalparthian}', "");
Expect(1, 68448, '\p{^Blk=inscriptionalparthian}', "");
Expect(1, 68448, '\P{Blk=inscriptionalparthian}', "");
Expect(0, 68448, '\P{^Blk=inscriptionalparthian}', "");
Expect(1, 68447, '\p{Blk=_Inscriptional_Parthian}', "");
Expect(0, 68447, '\p{^Blk=_Inscriptional_Parthian}', "");
Expect(0, 68447, '\P{Blk=_Inscriptional_Parthian}', "");
Expect(1, 68447, '\P{^Blk=_Inscriptional_Parthian}', "");
Expect(0, 68448, '\p{Blk=_Inscriptional_Parthian}', "");
Expect(1, 68448, '\p{^Blk=_Inscriptional_Parthian}', "");
Expect(1, 68448, '\P{Blk=_Inscriptional_Parthian}', "");
Expect(0, 68448, '\P{^Blk=_Inscriptional_Parthian}', "");
Error('\p{Is_Block= :=Inscriptional_Parthian}');
Error('\P{Is_Block= :=Inscriptional_Parthian}');
Expect(1, 68447, '\p{Is_Block=inscriptionalparthian}', "");
Expect(0, 68447, '\p{^Is_Block=inscriptionalparthian}', "");
Expect(0, 68447, '\P{Is_Block=inscriptionalparthian}', "");
Expect(1, 68447, '\P{^Is_Block=inscriptionalparthian}', "");
Expect(0, 68448, '\p{Is_Block=inscriptionalparthian}', "");
Expect(1, 68448, '\p{^Is_Block=inscriptionalparthian}', "");
Expect(1, 68448, '\P{Is_Block=inscriptionalparthian}', "");
Expect(0, 68448, '\P{^Is_Block=inscriptionalparthian}', "");
Expect(1, 68447, '\p{Is_Block=	_INSCRIPTIONAL_Parthian}', "");
Expect(0, 68447, '\p{^Is_Block=	_INSCRIPTIONAL_Parthian}', "");
Expect(0, 68447, '\P{Is_Block=	_INSCRIPTIONAL_Parthian}', "");
Expect(1, 68447, '\P{^Is_Block=	_INSCRIPTIONAL_Parthian}', "");
Expect(0, 68448, '\p{Is_Block=	_INSCRIPTIONAL_Parthian}', "");
Expect(1, 68448, '\p{^Is_Block=	_INSCRIPTIONAL_Parthian}', "");
Expect(1, 68448, '\P{Is_Block=	_INSCRIPTIONAL_Parthian}', "");
Expect(0, 68448, '\P{^Is_Block=	_INSCRIPTIONAL_Parthian}', "");
Error('\p{Is_Blk:	:=Inscriptional_PARTHIAN}');
Error('\P{Is_Blk:	:=Inscriptional_PARTHIAN}');
Expect(1, 68447, '\p{Is_Blk=inscriptionalparthian}', "");
Expect(0, 68447, '\p{^Is_Blk=inscriptionalparthian}', "");
Expect(0, 68447, '\P{Is_Blk=inscriptionalparthian}', "");
Expect(1, 68447, '\P{^Is_Blk=inscriptionalparthian}', "");
Expect(0, 68448, '\p{Is_Blk=inscriptionalparthian}', "");
Expect(1, 68448, '\p{^Is_Blk=inscriptionalparthian}', "");
Expect(1, 68448, '\P{Is_Blk=inscriptionalparthian}', "");
Expect(0, 68448, '\P{^Is_Blk=inscriptionalparthian}', "");
Expect(1, 68447, '\p{Is_Blk=	INSCRIPTIONAL_parthian}', "");
Expect(0, 68447, '\p{^Is_Blk=	INSCRIPTIONAL_parthian}', "");
Expect(0, 68447, '\P{Is_Blk=	INSCRIPTIONAL_parthian}', "");
Expect(1, 68447, '\P{^Is_Blk=	INSCRIPTIONAL_parthian}', "");
Expect(0, 68448, '\p{Is_Blk=	INSCRIPTIONAL_parthian}', "");
Expect(1, 68448, '\p{^Is_Blk=	INSCRIPTIONAL_parthian}', "");
Expect(1, 68448, '\P{Is_Blk=	INSCRIPTIONAL_parthian}', "");
Expect(0, 68448, '\P{^Is_Blk=	INSCRIPTIONAL_parthian}', "");
Error('\p{Block: /a/_ Hangul_Jamo}');
Error('\P{Block: /a/_ Hangul_Jamo}');
Expect(1, 4607, '\p{Block=hanguljamo}', "");
Expect(0, 4607, '\p{^Block=hanguljamo}', "");
Expect(0, 4607, '\P{Block=hanguljamo}', "");
Expect(1, 4607, '\P{^Block=hanguljamo}', "");
Expect(0, 4608, '\p{Block=hanguljamo}', "");
Expect(1, 4608, '\p{^Block=hanguljamo}', "");
Expect(1, 4608, '\P{Block=hanguljamo}', "");
Expect(0, 4608, '\P{^Block=hanguljamo}', "");
Expect(1, 4607, '\p{Block=- hangul_Jamo}', "");
Expect(0, 4607, '\p{^Block=- hangul_Jamo}', "");
Expect(0, 4607, '\P{Block=- hangul_Jamo}', "");
Expect(1, 4607, '\P{^Block=- hangul_Jamo}', "");
Expect(0, 4608, '\p{Block=- hangul_Jamo}', "");
Expect(1, 4608, '\p{^Block=- hangul_Jamo}', "");
Expect(1, 4608, '\P{Block=- hangul_Jamo}', "");
Expect(0, 4608, '\P{^Block=- hangul_Jamo}', "");
Error('\p{Blk=:=	jamo}');
Error('\P{Blk=:=	jamo}');
Expect(1, 4607, '\p{Blk=jamo}', "");
Expect(0, 4607, '\p{^Blk=jamo}', "");
Expect(0, 4607, '\P{Blk=jamo}', "");
Expect(1, 4607, '\P{^Blk=jamo}', "");
Expect(0, 4608, '\p{Blk=jamo}', "");
Expect(1, 4608, '\p{^Blk=jamo}', "");
Expect(1, 4608, '\P{Blk=jamo}', "");
Expect(0, 4608, '\P{^Blk=jamo}', "");
Expect(1, 4607, '\p{Blk=-	Jamo}', "");
Expect(0, 4607, '\p{^Blk=-	Jamo}', "");
Expect(0, 4607, '\P{Blk=-	Jamo}', "");
Expect(1, 4607, '\P{^Blk=-	Jamo}', "");
Expect(0, 4608, '\p{Blk=-	Jamo}', "");
Expect(1, 4608, '\p{^Blk=-	Jamo}', "");
Expect(1, 4608, '\P{Blk=-	Jamo}', "");
Expect(0, 4608, '\P{^Blk=-	Jamo}', "");
Error('\p{Is_Block=/a/ -Hangul_JAMO}');
Error('\P{Is_Block=/a/ -Hangul_JAMO}');
Expect(1, 4607, '\p{Is_Block=hanguljamo}', "");
Expect(0, 4607, '\p{^Is_Block=hanguljamo}', "");
Expect(0, 4607, '\P{Is_Block=hanguljamo}', "");
Expect(1, 4607, '\P{^Is_Block=hanguljamo}', "");
Expect(0, 4608, '\p{Is_Block=hanguljamo}', "");
Expect(1, 4608, '\p{^Is_Block=hanguljamo}', "");
Expect(1, 4608, '\P{Is_Block=hanguljamo}', "");
Expect(0, 4608, '\P{^Is_Block=hanguljamo}', "");
Expect(1, 4607, '\p{Is_Block=  Hangul_JAMO}', "");
Expect(0, 4607, '\p{^Is_Block=  Hangul_JAMO}', "");
Expect(0, 4607, '\P{Is_Block=  Hangul_JAMO}', "");
Expect(1, 4607, '\P{^Is_Block=  Hangul_JAMO}', "");
Expect(0, 4608, '\p{Is_Block=  Hangul_JAMO}', "");
Expect(1, 4608, '\p{^Is_Block=  Hangul_JAMO}', "");
Expect(1, 4608, '\P{Is_Block=  Hangul_JAMO}', "");
Expect(0, 4608, '\P{^Is_Block=  Hangul_JAMO}', "");
Error('\p{Is_Blk=:= 	Jamo}');
Error('\P{Is_Blk=:= 	Jamo}');
Expect(1, 4607, '\p{Is_Blk=jamo}', "");
Expect(0, 4607, '\p{^Is_Blk=jamo}', "");
Expect(0, 4607, '\P{Is_Blk=jamo}', "");
Expect(1, 4607, '\P{^Is_Blk=jamo}', "");
Expect(0, 4608, '\p{Is_Blk=jamo}', "");
Expect(1, 4608, '\p{^Is_Blk=jamo}', "");
Expect(1, 4608, '\P{Is_Blk=jamo}', "");
Expect(0, 4608, '\P{^Is_Blk=jamo}', "");
Expect(1, 4607, '\p{Is_Blk= jamo}', "");
Expect(0, 4607, '\p{^Is_Blk= jamo}', "");
Expect(0, 4607, '\P{Is_Blk= jamo}', "");
Expect(1, 4607, '\P{^Is_Blk= jamo}', "");
Expect(0, 4608, '\p{Is_Blk= jamo}', "");
Expect(1, 4608, '\p{^Is_Blk= jamo}', "");
Expect(1, 4608, '\P{Is_Blk= jamo}', "");
Expect(0, 4608, '\P{^Is_Blk= jamo}', "");
Error('\p{Block=-_hangul_JAMO_EXTENDED_a/a/}');
Error('\P{Block=-_hangul_JAMO_EXTENDED_a/a/}');
Expect(1, 43391, '\p{Block: hanguljamoextendeda}', "");
Expect(0, 43391, '\p{^Block: hanguljamoextendeda}', "");
Expect(0, 43391, '\P{Block: hanguljamoextendeda}', "");
Expect(1, 43391, '\P{^Block: hanguljamoextendeda}', "");
Expect(0, 43392, '\p{Block: hanguljamoextendeda}', "");
Expect(1, 43392, '\p{^Block: hanguljamoextendeda}', "");
Expect(1, 43392, '\P{Block: hanguljamoextendeda}', "");
Expect(0, 43392, '\P{^Block: hanguljamoextendeda}', "");
Expect(1, 43391, '\p{Block:   _HANGUL_Jamo_extended_a}', "");
Expect(0, 43391, '\p{^Block:   _HANGUL_Jamo_extended_a}', "");
Expect(0, 43391, '\P{Block:   _HANGUL_Jamo_extended_a}', "");
Expect(1, 43391, '\P{^Block:   _HANGUL_Jamo_extended_a}', "");
Expect(0, 43392, '\p{Block:   _HANGUL_Jamo_extended_a}', "");
Expect(1, 43392, '\p{^Block:   _HANGUL_Jamo_extended_a}', "");
Expect(1, 43392, '\P{Block:   _HANGUL_Jamo_extended_a}', "");
Expect(0, 43392, '\P{^Block:   _HANGUL_Jamo_extended_a}', "");
Error('\p{Blk=-/a/JAMO_ext_A}');
Error('\P{Blk=-/a/JAMO_ext_A}');
Expect(1, 43391, '\p{Blk=jamoexta}', "");
Expect(0, 43391, '\p{^Blk=jamoexta}', "");
Expect(0, 43391, '\P{Blk=jamoexta}', "");
Expect(1, 43391, '\P{^Blk=jamoexta}', "");
Expect(0, 43392, '\p{Blk=jamoexta}', "");
Expect(1, 43392, '\p{^Blk=jamoexta}', "");
Expect(1, 43392, '\P{Blk=jamoexta}', "");
Expect(0, 43392, '\P{^Blk=jamoexta}', "");
Expect(1, 43391, '\p{Blk:	_ Jamo_Ext_A}', "");
Expect(0, 43391, '\p{^Blk:	_ Jamo_Ext_A}', "");
Expect(0, 43391, '\P{Blk:	_ Jamo_Ext_A}', "");
Expect(1, 43391, '\P{^Blk:	_ Jamo_Ext_A}', "");
Expect(0, 43392, '\p{Blk:	_ Jamo_Ext_A}', "");
Expect(1, 43392, '\p{^Blk:	_ Jamo_Ext_A}', "");
Expect(1, 43392, '\P{Blk:	_ Jamo_Ext_A}', "");
Expect(0, 43392, '\P{^Blk:	_ Jamo_Ext_A}', "");
Error('\p{Is_Block=/a/ _HANGUL_Jamo_extended_A}');
Error('\P{Is_Block=/a/ _HANGUL_Jamo_extended_A}');
Expect(1, 43391, '\p{Is_Block=hanguljamoextendeda}', "");
Expect(0, 43391, '\p{^Is_Block=hanguljamoextendeda}', "");
Expect(0, 43391, '\P{Is_Block=hanguljamoextendeda}', "");
Expect(1, 43391, '\P{^Is_Block=hanguljamoextendeda}', "");
Expect(0, 43392, '\p{Is_Block=hanguljamoextendeda}', "");
Expect(1, 43392, '\p{^Is_Block=hanguljamoextendeda}', "");
Expect(1, 43392, '\P{Is_Block=hanguljamoextendeda}', "");
Expect(0, 43392, '\P{^Is_Block=hanguljamoextendeda}', "");
Expect(1, 43391, '\p{Is_Block=-_HANGUL_jamo_EXTENDED_a}', "");
Expect(0, 43391, '\p{^Is_Block=-_HANGUL_jamo_EXTENDED_a}', "");
Expect(0, 43391, '\P{Is_Block=-_HANGUL_jamo_EXTENDED_a}', "");
Expect(1, 43391, '\P{^Is_Block=-_HANGUL_jamo_EXTENDED_a}', "");
Expect(0, 43392, '\p{Is_Block=-_HANGUL_jamo_EXTENDED_a}', "");
Expect(1, 43392, '\p{^Is_Block=-_HANGUL_jamo_EXTENDED_a}', "");
Expect(1, 43392, '\P{Is_Block=-_HANGUL_jamo_EXTENDED_a}', "");
Expect(0, 43392, '\P{^Is_Block=-_HANGUL_jamo_EXTENDED_a}', "");
Error('\p{Is_Blk: -:=jamo_Ext_A}');
Error('\P{Is_Blk: -:=jamo_Ext_A}');
Expect(1, 43391, '\p{Is_Blk=jamoexta}', "");
Expect(0, 43391, '\p{^Is_Blk=jamoexta}', "");
Expect(0, 43391, '\P{Is_Blk=jamoexta}', "");
Expect(1, 43391, '\P{^Is_Blk=jamoexta}', "");
Expect(0, 43392, '\p{Is_Blk=jamoexta}', "");
Expect(1, 43392, '\p{^Is_Blk=jamoexta}', "");
Expect(1, 43392, '\P{Is_Blk=jamoexta}', "");
Expect(0, 43392, '\P{^Is_Blk=jamoexta}', "");
Expect(1, 43391, '\p{Is_Blk=--JAMO_EXT_A}', "");
Expect(0, 43391, '\p{^Is_Blk=--JAMO_EXT_A}', "");
Expect(0, 43391, '\P{Is_Blk=--JAMO_EXT_A}', "");
Expect(1, 43391, '\P{^Is_Blk=--JAMO_EXT_A}', "");
Expect(0, 43392, '\p{Is_Blk=--JAMO_EXT_A}', "");
Expect(1, 43392, '\p{^Is_Blk=--JAMO_EXT_A}', "");
Expect(1, 43392, '\P{Is_Blk=--JAMO_EXT_A}', "");
Expect(0, 43392, '\P{^Is_Blk=--JAMO_EXT_A}', "");
Error('\p{Block:/a/  Hangul_Jamo_extended_B}');
Error('\P{Block:/a/  Hangul_Jamo_extended_B}');
Expect(1, 55295, '\p{Block=hanguljamoextendedb}', "");
Expect(0, 55295, '\p{^Block=hanguljamoextendedb}', "");
Expect(0, 55295, '\P{Block=hanguljamoextendedb}', "");
Expect(1, 55295, '\P{^Block=hanguljamoextendedb}', "");
Expect(0, 57344, '\p{Block=hanguljamoextendedb}', "");
Expect(1, 57344, '\p{^Block=hanguljamoextendedb}', "");
Expect(1, 57344, '\P{Block=hanguljamoextendedb}', "");
Expect(0, 57344, '\P{^Block=hanguljamoextendedb}', "");
Expect(1, 55295, '\p{Block=_ Hangul_Jamo_Extended_B}', "");
Expect(0, 55295, '\p{^Block=_ Hangul_Jamo_Extended_B}', "");
Expect(0, 55295, '\P{Block=_ Hangul_Jamo_Extended_B}', "");
Expect(1, 55295, '\P{^Block=_ Hangul_Jamo_Extended_B}', "");
Expect(0, 57344, '\p{Block=_ Hangul_Jamo_Extended_B}', "");
Expect(1, 57344, '\p{^Block=_ Hangul_Jamo_Extended_B}', "");
Expect(1, 57344, '\P{Block=_ Hangul_Jamo_Extended_B}', "");
Expect(0, 57344, '\P{^Block=_ Hangul_Jamo_Extended_B}', "");
Error('\p{Blk=/a/	Jamo_Ext_B}');
Error('\P{Blk=/a/	Jamo_Ext_B}');
Expect(1, 55295, '\p{Blk=jamoextb}', "");
Expect(0, 55295, '\p{^Blk=jamoextb}', "");
Expect(0, 55295, '\P{Blk=jamoextb}', "");
Expect(1, 55295, '\P{^Blk=jamoextb}', "");
Expect(0, 57344, '\p{Blk=jamoextb}', "");
Expect(1, 57344, '\p{^Blk=jamoextb}', "");
Expect(1, 57344, '\P{Blk=jamoextb}', "");
Expect(0, 57344, '\P{^Blk=jamoextb}', "");
Expect(1, 55295, '\p{Blk=  jamo_Ext_b}', "");
Expect(0, 55295, '\p{^Blk=  jamo_Ext_b}', "");
Expect(0, 55295, '\P{Blk=  jamo_Ext_b}', "");
Expect(1, 55295, '\P{^Blk=  jamo_Ext_b}', "");
Expect(0, 57344, '\p{Blk=  jamo_Ext_b}', "");
Expect(1, 57344, '\p{^Blk=  jamo_Ext_b}', "");
Expect(1, 57344, '\P{Blk=  jamo_Ext_b}', "");
Expect(0, 57344, '\P{^Blk=  jamo_Ext_b}', "");
Error('\p{Is_Block=/a/-HANGUL_Jamo_extended_B}');
Error('\P{Is_Block=/a/-HANGUL_Jamo_extended_B}');
Expect(1, 55295, '\p{Is_Block=hanguljamoextendedb}', "");
Expect(0, 55295, '\p{^Is_Block=hanguljamoextendedb}', "");
Expect(0, 55295, '\P{Is_Block=hanguljamoextendedb}', "");
Expect(1, 55295, '\P{^Is_Block=hanguljamoextendedb}', "");
Expect(0, 57344, '\p{Is_Block=hanguljamoextendedb}', "");
Expect(1, 57344, '\p{^Is_Block=hanguljamoextendedb}', "");
Expect(1, 57344, '\P{Is_Block=hanguljamoextendedb}', "");
Expect(0, 57344, '\P{^Is_Block=hanguljamoextendedb}', "");
Expect(1, 55295, '\p{Is_Block= _HANGUL_jamo_Extended_B}', "");
Expect(0, 55295, '\p{^Is_Block= _HANGUL_jamo_Extended_B}', "");
Expect(0, 55295, '\P{Is_Block= _HANGUL_jamo_Extended_B}', "");
Expect(1, 55295, '\P{^Is_Block= _HANGUL_jamo_Extended_B}', "");
Expect(0, 57344, '\p{Is_Block= _HANGUL_jamo_Extended_B}', "");
Expect(1, 57344, '\p{^Is_Block= _HANGUL_jamo_Extended_B}', "");
Expect(1, 57344, '\P{Is_Block= _HANGUL_jamo_Extended_B}', "");
Expect(0, 57344, '\P{^Is_Block= _HANGUL_jamo_Extended_B}', "");
Error('\p{Is_Blk=_Jamo_Ext_B/a/}');
Error('\P{Is_Blk=_Jamo_Ext_B/a/}');
Expect(1, 55295, '\p{Is_Blk=jamoextb}', "");
Expect(0, 55295, '\p{^Is_Blk=jamoextb}', "");
Expect(0, 55295, '\P{Is_Blk=jamoextb}', "");
Expect(1, 55295, '\P{^Is_Blk=jamoextb}', "");
Expect(0, 57344, '\p{Is_Blk=jamoextb}', "");
Expect(1, 57344, '\p{^Is_Blk=jamoextb}', "");
Expect(1, 57344, '\P{Is_Blk=jamoextb}', "");
Expect(0, 57344, '\P{^Is_Blk=jamoextb}', "");
Expect(1, 55295, '\p{Is_Blk=_jamo_EXT_b}', "");
Expect(0, 55295, '\p{^Is_Blk=_jamo_EXT_b}', "");
Expect(0, 55295, '\P{Is_Blk=_jamo_EXT_b}', "");
Expect(1, 55295, '\P{^Is_Blk=_jamo_EXT_b}', "");
Expect(0, 57344, '\p{Is_Blk=_jamo_EXT_b}', "");
Expect(1, 57344, '\p{^Is_Blk=_jamo_EXT_b}', "");
Expect(1, 57344, '\P{Is_Blk=_jamo_EXT_b}', "");
Expect(0, 57344, '\P{^Is_Blk=_jamo_EXT_b}', "");
Error('\p{Block=-javanese/a/}');
Error('\P{Block=-javanese/a/}');
Expect(1, 43487, '\p{Block=javanese}', "");
Expect(0, 43487, '\p{^Block=javanese}', "");
Expect(0, 43487, '\P{Block=javanese}', "");
Expect(1, 43487, '\P{^Block=javanese}', "");
Expect(0, 43488, '\p{Block=javanese}', "");
Expect(1, 43488, '\p{^Block=javanese}', "");
Expect(1, 43488, '\P{Block=javanese}', "");
Expect(0, 43488, '\P{^Block=javanese}', "");
Expect(1, 43487, '\p{Block=-Javanese}', "");
Expect(0, 43487, '\p{^Block=-Javanese}', "");
Expect(0, 43487, '\P{Block=-Javanese}', "");
Expect(1, 43487, '\P{^Block=-Javanese}', "");
Expect(0, 43488, '\p{Block=-Javanese}', "");
Expect(1, 43488, '\p{^Block=-Javanese}', "");
Expect(1, 43488, '\P{Block=-Javanese}', "");
Expect(0, 43488, '\P{^Block=-Javanese}', "");
Error('\p{Blk=:=JAVANESE}');
Error('\P{Blk=:=JAVANESE}');
Expect(1, 43487, '\p{Blk=javanese}', "");
Expect(0, 43487, '\p{^Blk=javanese}', "");
Expect(0, 43487, '\P{Blk=javanese}', "");
Expect(1, 43487, '\P{^Blk=javanese}', "");
Expect(0, 43488, '\p{Blk=javanese}', "");
Expect(1, 43488, '\p{^Blk=javanese}', "");
Expect(1, 43488, '\P{Blk=javanese}', "");
Expect(0, 43488, '\P{^Blk=javanese}', "");
Expect(1, 43487, '\p{Blk= _Javanese}', "");
Expect(0, 43487, '\p{^Blk= _Javanese}', "");
Expect(0, 43487, '\P{Blk= _Javanese}', "");
Expect(1, 43487, '\P{^Blk= _Javanese}', "");
Expect(0, 43488, '\p{Blk= _Javanese}', "");
Expect(1, 43488, '\p{^Blk= _Javanese}', "");
Expect(1, 43488, '\P{Blk= _Javanese}', "");
Expect(0, 43488, '\P{^Blk= _Javanese}', "");
Error('\p{Is_Block=_:=javanese}');
Error('\P{Is_Block=_:=javanese}');
Expect(1, 43487, '\p{Is_Block=javanese}', "");
Expect(0, 43487, '\p{^Is_Block=javanese}', "");
Expect(0, 43487, '\P{Is_Block=javanese}', "");
Expect(1, 43487, '\P{^Is_Block=javanese}', "");
Expect(0, 43488, '\p{Is_Block=javanese}', "");
Expect(1, 43488, '\p{^Is_Block=javanese}', "");
Expect(1, 43488, '\P{Is_Block=javanese}', "");
Expect(0, 43488, '\P{^Is_Block=javanese}', "");
Expect(1, 43487, '\p{Is_Block= JAVANESE}', "");
Expect(0, 43487, '\p{^Is_Block= JAVANESE}', "");
Expect(0, 43487, '\P{Is_Block= JAVANESE}', "");
Expect(1, 43487, '\P{^Is_Block= JAVANESE}', "");
Expect(0, 43488, '\p{Is_Block= JAVANESE}', "");
Expect(1, 43488, '\p{^Is_Block= JAVANESE}', "");
Expect(1, 43488, '\P{Is_Block= JAVANESE}', "");
Expect(0, 43488, '\P{^Is_Block= JAVANESE}', "");
Error('\p{Is_Blk=	 Javanese/a/}');
Error('\P{Is_Blk=	 Javanese/a/}');
Expect(1, 43487, '\p{Is_Blk=javanese}', "");
Expect(0, 43487, '\p{^Is_Blk=javanese}', "");
Expect(0, 43487, '\P{Is_Blk=javanese}', "");
Expect(1, 43487, '\P{^Is_Blk=javanese}', "");
Expect(0, 43488, '\p{Is_Blk=javanese}', "");
Expect(1, 43488, '\p{^Is_Blk=javanese}', "");
Expect(1, 43488, '\P{Is_Blk=javanese}', "");
Expect(0, 43488, '\P{^Is_Blk=javanese}', "");
Expect(1, 43487, '\p{Is_Blk=-Javanese}', "");
Expect(0, 43487, '\p{^Is_Blk=-Javanese}', "");
Expect(0, 43487, '\P{Is_Blk=-Javanese}', "");
Expect(1, 43487, '\P{^Is_Blk=-Javanese}', "");
Expect(0, 43488, '\p{Is_Blk=-Javanese}', "");
Expect(1, 43488, '\p{^Is_Blk=-Javanese}', "");
Expect(1, 43488, '\P{Is_Blk=-Javanese}', "");
Expect(0, 43488, '\P{^Is_Blk=-Javanese}', "");
Error('\p{Block=	-Kaithi:=}');
Error('\P{Block=	-Kaithi:=}');
Expect(1, 69839, '\p{Block=kaithi}', "");
Expect(0, 69839, '\p{^Block=kaithi}', "");
Expect(0, 69839, '\P{Block=kaithi}', "");
Expect(1, 69839, '\P{^Block=kaithi}', "");
Expect(0, 69840, '\p{Block=kaithi}', "");
Expect(1, 69840, '\p{^Block=kaithi}', "");
Expect(1, 69840, '\P{Block=kaithi}', "");
Expect(0, 69840, '\P{^Block=kaithi}', "");
Expect(1, 69839, '\p{Block=-_Kaithi}', "");
Expect(0, 69839, '\p{^Block=-_Kaithi}', "");
Expect(0, 69839, '\P{Block=-_Kaithi}', "");
Expect(1, 69839, '\P{^Block=-_Kaithi}', "");
Expect(0, 69840, '\p{Block=-_Kaithi}', "");
Expect(1, 69840, '\p{^Block=-_Kaithi}', "");
Expect(1, 69840, '\P{Block=-_Kaithi}', "");
Expect(0, 69840, '\P{^Block=-_Kaithi}', "");
Error('\p{Blk:   :=  Kaithi}');
Error('\P{Blk:   :=  Kaithi}');
Expect(1, 69839, '\p{Blk=kaithi}', "");
Expect(0, 69839, '\p{^Blk=kaithi}', "");
Expect(0, 69839, '\P{Blk=kaithi}', "");
Expect(1, 69839, '\P{^Blk=kaithi}', "");
Expect(0, 69840, '\p{Blk=kaithi}', "");
Expect(1, 69840, '\p{^Blk=kaithi}', "");
Expect(1, 69840, '\P{Blk=kaithi}', "");
Expect(0, 69840, '\P{^Blk=kaithi}', "");
Expect(1, 69839, '\p{Blk=__kaithi}', "");
Expect(0, 69839, '\p{^Blk=__kaithi}', "");
Expect(0, 69839, '\P{Blk=__kaithi}', "");
Expect(1, 69839, '\P{^Blk=__kaithi}', "");
Expect(0, 69840, '\p{Blk=__kaithi}', "");
Expect(1, 69840, '\p{^Blk=__kaithi}', "");
Expect(1, 69840, '\P{Blk=__kaithi}', "");
Expect(0, 69840, '\P{^Blk=__kaithi}', "");
Error('\p{Is_Block=	_Kaithi/a/}');
Error('\P{Is_Block=	_Kaithi/a/}');
Expect(1, 69839, '\p{Is_Block=kaithi}', "");
Expect(0, 69839, '\p{^Is_Block=kaithi}', "");
Expect(0, 69839, '\P{Is_Block=kaithi}', "");
Expect(1, 69839, '\P{^Is_Block=kaithi}', "");
Expect(0, 69840, '\p{Is_Block=kaithi}', "");
Expect(1, 69840, '\p{^Is_Block=kaithi}', "");
Expect(1, 69840, '\P{Is_Block=kaithi}', "");
Expect(0, 69840, '\P{^Is_Block=kaithi}', "");
Expect(1, 69839, '\p{Is_Block=	Kaithi}', "");
Expect(0, 69839, '\p{^Is_Block=	Kaithi}', "");
Expect(0, 69839, '\P{Is_Block=	Kaithi}', "");
Expect(1, 69839, '\P{^Is_Block=	Kaithi}', "");
Expect(0, 69840, '\p{Is_Block=	Kaithi}', "");
Expect(1, 69840, '\p{^Is_Block=	Kaithi}', "");
Expect(1, 69840, '\P{Is_Block=	Kaithi}', "");
Expect(0, 69840, '\P{^Is_Block=	Kaithi}', "");
Error('\p{Is_Blk=-	kaithi/a/}');
Error('\P{Is_Blk=-	kaithi/a/}');
Expect(1, 69839, '\p{Is_Blk=kaithi}', "");
Expect(0, 69839, '\p{^Is_Blk=kaithi}', "");
Expect(0, 69839, '\P{Is_Blk=kaithi}', "");
Expect(1, 69839, '\P{^Is_Blk=kaithi}', "");
Expect(0, 69840, '\p{Is_Blk=kaithi}', "");
Expect(1, 69840, '\p{^Is_Blk=kaithi}', "");
Expect(1, 69840, '\P{Is_Blk=kaithi}', "");
Expect(0, 69840, '\P{^Is_Blk=kaithi}', "");
Expect(1, 69839, '\p{Is_Blk:   - KAITHI}', "");
Expect(0, 69839, '\p{^Is_Blk:   - KAITHI}', "");
Expect(0, 69839, '\P{Is_Blk:   - KAITHI}', "");
Expect(1, 69839, '\P{^Is_Blk:   - KAITHI}', "");
Expect(0, 69840, '\p{Is_Blk:   - KAITHI}', "");
Expect(1, 69840, '\p{^Is_Blk:   - KAITHI}', "");
Expect(1, 69840, '\P{Is_Blk:   - KAITHI}', "");
Expect(0, 69840, '\P{^Is_Blk:   - KAITHI}', "");
Error('\p{Block=	-Kana_SUPPLEMENT/a/}');
Error('\P{Block=	-Kana_SUPPLEMENT/a/}');
Expect(1, 110847, '\p{Block=kanasupplement}', "");
Expect(0, 110847, '\p{^Block=kanasupplement}', "");
Expect(0, 110847, '\P{Block=kanasupplement}', "");
Expect(1, 110847, '\P{^Block=kanasupplement}', "");
Expect(0, 110848, '\p{Block=kanasupplement}', "");
Expect(1, 110848, '\p{^Block=kanasupplement}', "");
Expect(1, 110848, '\P{Block=kanasupplement}', "");
Expect(0, 110848, '\P{^Block=kanasupplement}', "");
Expect(1, 110847, '\p{Block=__Kana_Supplement}', "");
Expect(0, 110847, '\p{^Block=__Kana_Supplement}', "");
Expect(0, 110847, '\P{Block=__Kana_Supplement}', "");
Expect(1, 110847, '\P{^Block=__Kana_Supplement}', "");
Expect(0, 110848, '\p{Block=__Kana_Supplement}', "");
Expect(1, 110848, '\p{^Block=__Kana_Supplement}', "");
Expect(1, 110848, '\P{Block=__Kana_Supplement}', "");
Expect(0, 110848, '\P{^Block=__Kana_Supplement}', "");
Error('\p{Blk:    Kana_SUP:=}');
Error('\P{Blk:    Kana_SUP:=}');
Expect(1, 110847, '\p{Blk=kanasup}', "");
Expect(0, 110847, '\p{^Blk=kanasup}', "");
Expect(0, 110847, '\P{Blk=kanasup}', "");
Expect(1, 110847, '\P{^Blk=kanasup}', "");
Expect(0, 110848, '\p{Blk=kanasup}', "");
Expect(1, 110848, '\p{^Blk=kanasup}', "");
Expect(1, 110848, '\P{Blk=kanasup}', "");
Expect(0, 110848, '\P{^Blk=kanasup}', "");
Expect(1, 110847, '\p{Blk= Kana_sup}', "");
Expect(0, 110847, '\p{^Blk= Kana_sup}', "");
Expect(0, 110847, '\P{Blk= Kana_sup}', "");
Expect(1, 110847, '\P{^Blk= Kana_sup}', "");
Expect(0, 110848, '\p{Blk= Kana_sup}', "");
Expect(1, 110848, '\p{^Blk= Kana_sup}', "");
Expect(1, 110848, '\P{Blk= Kana_sup}', "");
Expect(0, 110848, '\P{^Blk= Kana_sup}', "");
Error('\p{Is_Block=:=Kana_SUPPLEMENT}');
Error('\P{Is_Block=:=Kana_SUPPLEMENT}');
Expect(1, 110847, '\p{Is_Block=kanasupplement}', "");
Expect(0, 110847, '\p{^Is_Block=kanasupplement}', "");
Expect(0, 110847, '\P{Is_Block=kanasupplement}', "");
Expect(1, 110847, '\P{^Is_Block=kanasupplement}', "");
Expect(0, 110848, '\p{Is_Block=kanasupplement}', "");
Expect(1, 110848, '\p{^Is_Block=kanasupplement}', "");
Expect(1, 110848, '\P{Is_Block=kanasupplement}', "");
Expect(0, 110848, '\P{^Is_Block=kanasupplement}', "");
Expect(1, 110847, '\p{Is_Block=_kana_Supplement}', "");
Expect(0, 110847, '\p{^Is_Block=_kana_Supplement}', "");
Expect(0, 110847, '\P{Is_Block=_kana_Supplement}', "");
Expect(1, 110847, '\P{^Is_Block=_kana_Supplement}', "");
Expect(0, 110848, '\p{Is_Block=_kana_Supplement}', "");
Expect(1, 110848, '\p{^Is_Block=_kana_Supplement}', "");
Expect(1, 110848, '\P{Is_Block=_kana_Supplement}', "");
Expect(0, 110848, '\P{^Is_Block=_kana_Supplement}', "");
Error('\p{Is_Blk=-kana_Sup:=}');
Error('\P{Is_Blk=-kana_Sup:=}');
Expect(1, 110847, '\p{Is_Blk=kanasup}', "");
Expect(0, 110847, '\p{^Is_Blk=kanasup}', "");
Expect(0, 110847, '\P{Is_Blk=kanasup}', "");
Expect(1, 110847, '\P{^Is_Blk=kanasup}', "");
Expect(0, 110848, '\p{Is_Blk=kanasup}', "");
Expect(1, 110848, '\p{^Is_Blk=kanasup}', "");
Expect(1, 110848, '\P{Is_Blk=kanasup}', "");
Expect(0, 110848, '\P{^Is_Blk=kanasup}', "");
Expect(1, 110847, '\p{Is_Blk= kana_sup}', "");
Expect(0, 110847, '\p{^Is_Blk= kana_sup}', "");
Expect(0, 110847, '\P{Is_Blk= kana_sup}', "");
Expect(1, 110847, '\P{^Is_Blk= kana_sup}', "");
Expect(0, 110848, '\p{Is_Blk= kana_sup}', "");
Expect(1, 110848, '\p{^Is_Blk= kana_sup}', "");
Expect(1, 110848, '\P{Is_Blk= kana_sup}', "");
Expect(0, 110848, '\P{^Is_Blk= kana_sup}', "");
Error('\p{Block= Kanbun/a/}');
Error('\P{Block= Kanbun/a/}');
Expect(1, 12703, '\p{Block=kanbun}', "");
Expect(0, 12703, '\p{^Block=kanbun}', "");
Expect(0, 12703, '\P{Block=kanbun}', "");
Expect(1, 12703, '\P{^Block=kanbun}', "");
Expect(0, 12704, '\p{Block=kanbun}', "");
Expect(1, 12704, '\p{^Block=kanbun}', "");
Expect(1, 12704, '\P{Block=kanbun}', "");
Expect(0, 12704, '\P{^Block=kanbun}', "");
Expect(1, 12703, '\p{Block= 	KANBUN}', "");
Expect(0, 12703, '\p{^Block= 	KANBUN}', "");
Expect(0, 12703, '\P{Block= 	KANBUN}', "");
Expect(1, 12703, '\P{^Block= 	KANBUN}', "");
Expect(0, 12704, '\p{Block= 	KANBUN}', "");
Expect(1, 12704, '\p{^Block= 	KANBUN}', "");
Expect(1, 12704, '\P{Block= 	KANBUN}', "");
Expect(0, 12704, '\P{^Block= 	KANBUN}', "");
Error('\p{Blk=:= _Kanbun}');
Error('\P{Blk=:= _Kanbun}');
Expect(1, 12703, '\p{Blk=kanbun}', "");
Expect(0, 12703, '\p{^Blk=kanbun}', "");
Expect(0, 12703, '\P{Blk=kanbun}', "");
Expect(1, 12703, '\P{^Blk=kanbun}', "");
Expect(0, 12704, '\p{Blk=kanbun}', "");
Expect(1, 12704, '\p{^Blk=kanbun}', "");
Expect(1, 12704, '\P{Blk=kanbun}', "");
Expect(0, 12704, '\P{^Blk=kanbun}', "");
Expect(1, 12703, '\p{Blk:	__KANBUN}', "");
Expect(0, 12703, '\p{^Blk:	__KANBUN}', "");
Expect(0, 12703, '\P{Blk:	__KANBUN}', "");
Expect(1, 12703, '\P{^Blk:	__KANBUN}', "");
Expect(0, 12704, '\p{Blk:	__KANBUN}', "");
Expect(1, 12704, '\p{^Blk:	__KANBUN}', "");
Expect(1, 12704, '\P{Blk:	__KANBUN}', "");
Expect(0, 12704, '\P{^Blk:	__KANBUN}', "");
Error('\p{Is_Block= 	KANBUN:=}');
Error('\P{Is_Block= 	KANBUN:=}');
Expect(1, 12703, '\p{Is_Block=kanbun}', "");
Expect(0, 12703, '\p{^Is_Block=kanbun}', "");
Expect(0, 12703, '\P{Is_Block=kanbun}', "");
Expect(1, 12703, '\P{^Is_Block=kanbun}', "");
Expect(0, 12704, '\p{Is_Block=kanbun}', "");
Expect(1, 12704, '\p{^Is_Block=kanbun}', "");
Expect(1, 12704, '\P{Is_Block=kanbun}', "");
Expect(0, 12704, '\P{^Is_Block=kanbun}', "");
Expect(1, 12703, '\p{Is_Block=_kanbun}', "");
Expect(0, 12703, '\p{^Is_Block=_kanbun}', "");
Expect(0, 12703, '\P{Is_Block=_kanbun}', "");
Expect(1, 12703, '\P{^Is_Block=_kanbun}', "");
Expect(0, 12704, '\p{Is_Block=_kanbun}', "");
Expect(1, 12704, '\p{^Is_Block=_kanbun}', "");
Expect(1, 12704, '\P{Is_Block=_kanbun}', "");
Expect(0, 12704, '\P{^Is_Block=_kanbun}', "");
Error('\p{Is_Blk= /a/KANBUN}');
Error('\P{Is_Blk= /a/KANBUN}');
Expect(1, 12703, '\p{Is_Blk=kanbun}', "");
Expect(0, 12703, '\p{^Is_Blk=kanbun}', "");
Expect(0, 12703, '\P{Is_Blk=kanbun}', "");
Expect(1, 12703, '\P{^Is_Blk=kanbun}', "");
Expect(0, 12704, '\p{Is_Blk=kanbun}', "");
Expect(1, 12704, '\p{^Is_Blk=kanbun}', "");
Expect(1, 12704, '\P{Is_Blk=kanbun}', "");
Expect(0, 12704, '\P{^Is_Blk=kanbun}', "");
Expect(1, 12703, '\p{Is_Blk=	 KANBUN}', "");
Expect(0, 12703, '\p{^Is_Blk=	 KANBUN}', "");
Expect(0, 12703, '\P{Is_Blk=	 KANBUN}', "");
Expect(1, 12703, '\P{^Is_Blk=	 KANBUN}', "");
Expect(0, 12704, '\p{Is_Blk=	 KANBUN}', "");
Expect(1, 12704, '\p{^Is_Blk=	 KANBUN}', "");
Expect(1, 12704, '\P{Is_Blk=	 KANBUN}', "");
Expect(0, 12704, '\P{^Is_Blk=	 KANBUN}', "");
Error('\p{Block=:=--kangxi_RADICALS}');
Error('\P{Block=:=--kangxi_RADICALS}');
Expect(1, 12255, '\p{Block:	kangxiradicals}', "");
Expect(0, 12255, '\p{^Block:	kangxiradicals}', "");
Expect(0, 12255, '\P{Block:	kangxiradicals}', "");
Expect(1, 12255, '\P{^Block:	kangxiradicals}', "");
Expect(0, 12256, '\p{Block:	kangxiradicals}', "");
Expect(1, 12256, '\p{^Block:	kangxiradicals}', "");
Expect(1, 12256, '\P{Block:	kangxiradicals}', "");
Expect(0, 12256, '\P{^Block:	kangxiradicals}', "");
Expect(1, 12255, '\p{Block=-	Kangxi_Radicals}', "");
Expect(0, 12255, '\p{^Block=-	Kangxi_Radicals}', "");
Expect(0, 12255, '\P{Block=-	Kangxi_Radicals}', "");
Expect(1, 12255, '\P{^Block=-	Kangxi_Radicals}', "");
Expect(0, 12256, '\p{Block=-	Kangxi_Radicals}', "");
Expect(1, 12256, '\p{^Block=-	Kangxi_Radicals}', "");
Expect(1, 12256, '\P{Block=-	Kangxi_Radicals}', "");
Expect(0, 12256, '\P{^Block=-	Kangxi_Radicals}', "");
Error('\p{Blk=_ Kangxi/a/}');
Error('\P{Blk=_ Kangxi/a/}');
Expect(1, 12255, '\p{Blk=kangxi}', "");
Expect(0, 12255, '\p{^Blk=kangxi}', "");
Expect(0, 12255, '\P{Blk=kangxi}', "");
Expect(1, 12255, '\P{^Blk=kangxi}', "");
Expect(0, 12256, '\p{Blk=kangxi}', "");
Expect(1, 12256, '\p{^Blk=kangxi}', "");
Expect(1, 12256, '\P{Blk=kangxi}', "");
Expect(0, 12256, '\P{^Blk=kangxi}', "");
Expect(1, 12255, '\p{Blk:			kangxi}', "");
Expect(0, 12255, '\p{^Blk:			kangxi}', "");
Expect(0, 12255, '\P{Blk:			kangxi}', "");
Expect(1, 12255, '\P{^Blk:			kangxi}', "");
Expect(0, 12256, '\p{Blk:			kangxi}', "");
Expect(1, 12256, '\p{^Blk:			kangxi}', "");
Expect(1, 12256, '\P{Blk:			kangxi}', "");
Expect(0, 12256, '\P{^Blk:			kangxi}', "");
Error('\p{Is_Block:	 -Kangxi_RADICALS/a/}');
Error('\P{Is_Block:	 -Kangxi_RADICALS/a/}');
Expect(1, 12255, '\p{Is_Block=kangxiradicals}', "");
Expect(0, 12255, '\p{^Is_Block=kangxiradicals}', "");
Expect(0, 12255, '\P{Is_Block=kangxiradicals}', "");
Expect(1, 12255, '\P{^Is_Block=kangxiradicals}', "");
Expect(0, 12256, '\p{Is_Block=kangxiradicals}', "");
Expect(1, 12256, '\p{^Is_Block=kangxiradicals}', "");
Expect(1, 12256, '\P{Is_Block=kangxiradicals}', "");
Expect(0, 12256, '\P{^Is_Block=kangxiradicals}', "");
Expect(1, 12255, '\p{Is_Block=--KANGXI_Radicals}', "");
Expect(0, 12255, '\p{^Is_Block=--KANGXI_Radicals}', "");
Expect(0, 12255, '\P{Is_Block=--KANGXI_Radicals}', "");
Expect(1, 12255, '\P{^Is_Block=--KANGXI_Radicals}', "");
Expect(0, 12256, '\p{Is_Block=--KANGXI_Radicals}', "");
Expect(1, 12256, '\p{^Is_Block=--KANGXI_Radicals}', "");
Expect(1, 12256, '\P{Is_Block=--KANGXI_Radicals}', "");
Expect(0, 12256, '\P{^Is_Block=--KANGXI_Radicals}', "");
Error('\p{Is_Blk=/a/KANGXI}');
Error('\P{Is_Blk=/a/KANGXI}');
Expect(1, 12255, '\p{Is_Blk:kangxi}', "");
Expect(0, 12255, '\p{^Is_Blk:kangxi}', "");
Expect(0, 12255, '\P{Is_Blk:kangxi}', "");
Expect(1, 12255, '\P{^Is_Blk:kangxi}', "");
Expect(0, 12256, '\p{Is_Blk:kangxi}', "");
Expect(1, 12256, '\p{^Is_Blk:kangxi}', "");
Expect(1, 12256, '\P{Is_Blk:kangxi}', "");
Expect(0, 12256, '\P{^Is_Blk:kangxi}', "");
Expect(1, 12255, '\p{Is_Blk=-KANGXI}', "");
Expect(0, 12255, '\p{^Is_Blk=-KANGXI}', "");
Expect(0, 12255, '\P{Is_Blk=-KANGXI}', "");
Expect(1, 12255, '\P{^Is_Blk=-KANGXI}', "");
Expect(0, 12256, '\p{Is_Blk=-KANGXI}', "");
Expect(1, 12256, '\p{^Is_Blk=-KANGXI}', "");
Expect(1, 12256, '\P{Is_Blk=-KANGXI}', "");
Expect(0, 12256, '\P{^Is_Blk=-KANGXI}', "");
Error('\p{Block=:=Kannada}');
Error('\P{Block=:=Kannada}');
Expect(1, 3327, '\p{Block=kannada}', "");
Expect(0, 3327, '\p{^Block=kannada}', "");
Expect(0, 3327, '\P{Block=kannada}', "");
Expect(1, 3327, '\P{^Block=kannada}', "");
Expect(0, 3328, '\p{Block=kannada}', "");
Expect(1, 3328, '\p{^Block=kannada}', "");
Expect(1, 3328, '\P{Block=kannada}', "");
Expect(0, 3328, '\P{^Block=kannada}', "");
Expect(1, 3327, '\p{Block: 	 Kannada}', "");
Expect(0, 3327, '\p{^Block: 	 Kannada}', "");
Expect(0, 3327, '\P{Block: 	 Kannada}', "");
Expect(1, 3327, '\P{^Block: 	 Kannada}', "");
Expect(0, 3328, '\p{Block: 	 Kannada}', "");
Expect(1, 3328, '\p{^Block: 	 Kannada}', "");
Expect(1, 3328, '\P{Block: 	 Kannada}', "");
Expect(0, 3328, '\P{^Block: 	 Kannada}', "");
Error('\p{Blk= :=KANNADA}');
Error('\P{Blk= :=KANNADA}');
Expect(1, 3327, '\p{Blk=kannada}', "");
Expect(0, 3327, '\p{^Blk=kannada}', "");
Expect(0, 3327, '\P{Blk=kannada}', "");
Expect(1, 3327, '\P{^Blk=kannada}', "");
Expect(0, 3328, '\p{Blk=kannada}', "");
Expect(1, 3328, '\p{^Blk=kannada}', "");
Expect(1, 3328, '\P{Blk=kannada}', "");
Expect(0, 3328, '\P{^Blk=kannada}', "");
Expect(1, 3327, '\p{Blk= -Kannada}', "");
Expect(0, 3327, '\p{^Blk= -Kannada}', "");
Expect(0, 3327, '\P{Blk= -Kannada}', "");
Expect(1, 3327, '\P{^Blk= -Kannada}', "");
Expect(0, 3328, '\p{Blk= -Kannada}', "");
Expect(1, 3328, '\p{^Blk= -Kannada}', "");
Expect(1, 3328, '\P{Blk= -Kannada}', "");
Expect(0, 3328, '\P{^Blk= -Kannada}', "");
Error('\p{Is_Block:  -kannada/a/}');
Error('\P{Is_Block:  -kannada/a/}');
Expect(1, 3327, '\p{Is_Block=kannada}', "");
Expect(0, 3327, '\p{^Is_Block=kannada}', "");
Expect(0, 3327, '\P{Is_Block=kannada}', "");
Expect(1, 3327, '\P{^Is_Block=kannada}', "");
Expect(0, 3328, '\p{Is_Block=kannada}', "");
Expect(1, 3328, '\p{^Is_Block=kannada}', "");
Expect(1, 3328, '\P{Is_Block=kannada}', "");
Expect(0, 3328, '\P{^Is_Block=kannada}', "");
Expect(1, 3327, '\p{Is_Block=_Kannada}', "");
Expect(0, 3327, '\p{^Is_Block=_Kannada}', "");
Expect(0, 3327, '\P{Is_Block=_Kannada}', "");
Expect(1, 3327, '\P{^Is_Block=_Kannada}', "");
Expect(0, 3328, '\p{Is_Block=_Kannada}', "");
Expect(1, 3328, '\p{^Is_Block=_Kannada}', "");
Expect(1, 3328, '\P{Is_Block=_Kannada}', "");
Expect(0, 3328, '\P{^Is_Block=_Kannada}', "");
Error('\p{Is_Blk=/a/  Kannada}');
Error('\P{Is_Blk=/a/  Kannada}');
Expect(1, 3327, '\p{Is_Blk=kannada}', "");
Expect(0, 3327, '\p{^Is_Blk=kannada}', "");
Expect(0, 3327, '\P{Is_Blk=kannada}', "");
Expect(1, 3327, '\P{^Is_Blk=kannada}', "");
Expect(0, 3328, '\p{Is_Blk=kannada}', "");
Expect(1, 3328, '\p{^Is_Blk=kannada}', "");
Expect(1, 3328, '\P{Is_Blk=kannada}', "");
Expect(0, 3328, '\P{^Is_Blk=kannada}', "");
Expect(1, 3327, '\p{Is_Blk= _kannada}', "");
Expect(0, 3327, '\p{^Is_Blk= _kannada}', "");
Expect(0, 3327, '\P{Is_Blk= _kannada}', "");
Expect(1, 3327, '\P{^Is_Blk= _kannada}', "");
Expect(0, 3328, '\p{Is_Blk= _kannada}', "");
Expect(1, 3328, '\p{^Is_Blk= _kannada}', "");
Expect(1, 3328, '\P{Is_Blk= _kannada}', "");
Expect(0, 3328, '\P{^Is_Blk= _kannada}', "");
Error('\p{Block=/a/-_katakana}');
Error('\P{Block=/a/-_katakana}');
Expect(1, 12543, '\p{Block=katakana}', "");
Expect(0, 12543, '\p{^Block=katakana}', "");
Expect(0, 12543, '\P{Block=katakana}', "");
Expect(1, 12543, '\P{^Block=katakana}', "");
Expect(0, 12544, '\p{Block=katakana}', "");
Expect(1, 12544, '\p{^Block=katakana}', "");
Expect(1, 12544, '\P{Block=katakana}', "");
Expect(0, 12544, '\P{^Block=katakana}', "");
Expect(1, 12543, '\p{Block= _katakana}', "");
Expect(0, 12543, '\p{^Block= _katakana}', "");
Expect(0, 12543, '\P{Block= _katakana}', "");
Expect(1, 12543, '\P{^Block= _katakana}', "");
Expect(0, 12544, '\p{Block= _katakana}', "");
Expect(1, 12544, '\p{^Block= _katakana}', "");
Expect(1, 12544, '\P{Block= _katakana}', "");
Expect(0, 12544, '\P{^Block= _katakana}', "");
Error('\p{Blk:/a/KATAKANA}');
Error('\P{Blk:/a/KATAKANA}');
Expect(1, 12543, '\p{Blk=katakana}', "");
Expect(0, 12543, '\p{^Blk=katakana}', "");
Expect(0, 12543, '\P{Blk=katakana}', "");
Expect(1, 12543, '\P{^Blk=katakana}', "");
Expect(0, 12544, '\p{Blk=katakana}', "");
Expect(1, 12544, '\p{^Blk=katakana}', "");
Expect(1, 12544, '\P{Blk=katakana}', "");
Expect(0, 12544, '\P{^Blk=katakana}', "");
Expect(1, 12543, '\p{Blk=_katakana}', "");
Expect(0, 12543, '\p{^Blk=_katakana}', "");
Expect(0, 12543, '\P{Blk=_katakana}', "");
Expect(1, 12543, '\P{^Blk=_katakana}', "");
Expect(0, 12544, '\p{Blk=_katakana}', "");
Expect(1, 12544, '\p{^Blk=_katakana}', "");
Expect(1, 12544, '\P{Blk=_katakana}', "");
Expect(0, 12544, '\P{^Blk=_katakana}', "");
Error('\p{Is_Block=/a/_katakana}');
Error('\P{Is_Block=/a/_katakana}');
Expect(1, 12543, '\p{Is_Block=katakana}', "");
Expect(0, 12543, '\p{^Is_Block=katakana}', "");
Expect(0, 12543, '\P{Is_Block=katakana}', "");
Expect(1, 12543, '\P{^Is_Block=katakana}', "");
Expect(0, 12544, '\p{Is_Block=katakana}', "");
Expect(1, 12544, '\p{^Is_Block=katakana}', "");
Expect(1, 12544, '\P{Is_Block=katakana}', "");
Expect(0, 12544, '\P{^Is_Block=katakana}', "");
Expect(1, 12543, '\p{Is_Block:	_katakana}', "");
Expect(0, 12543, '\p{^Is_Block:	_katakana}', "");
Expect(0, 12543, '\P{Is_Block:	_katakana}', "");
Expect(1, 12543, '\P{^Is_Block:	_katakana}', "");
Expect(0, 12544, '\p{Is_Block:	_katakana}', "");
Expect(1, 12544, '\p{^Is_Block:	_katakana}', "");
Expect(1, 12544, '\P{Is_Block:	_katakana}', "");
Expect(0, 12544, '\P{^Is_Block:	_katakana}', "");
Error('\p{Is_Blk=:=_Katakana}');
Error('\P{Is_Blk=:=_Katakana}');
Expect(1, 12543, '\p{Is_Blk=katakana}', "");
Expect(0, 12543, '\p{^Is_Blk=katakana}', "");
Expect(0, 12543, '\P{Is_Blk=katakana}', "");
Expect(1, 12543, '\P{^Is_Blk=katakana}', "");
Expect(0, 12544, '\p{Is_Blk=katakana}', "");
Expect(1, 12544, '\p{^Is_Blk=katakana}', "");
Expect(1, 12544, '\P{Is_Blk=katakana}', "");
Expect(0, 12544, '\P{^Is_Blk=katakana}', "");
Expect(1, 12543, '\p{Is_Blk=	 Katakana}', "");
Expect(0, 12543, '\p{^Is_Blk=	 Katakana}', "");
Expect(0, 12543, '\P{Is_Blk=	 Katakana}', "");
Expect(1, 12543, '\P{^Is_Blk=	 Katakana}', "");
Expect(0, 12544, '\p{Is_Blk=	 Katakana}', "");
Expect(1, 12544, '\p{^Is_Blk=	 Katakana}', "");
Expect(1, 12544, '\P{Is_Blk=	 Katakana}', "");
Expect(0, 12544, '\P{^Is_Blk=	 Katakana}', "");
Error('\p{Block=:= 	KATAKANA_Phonetic_Extensions}');
Error('\P{Block=:= 	KATAKANA_Phonetic_Extensions}');
Expect(1, 12799, '\p{Block=katakanaphoneticextensions}', "");
Expect(0, 12799, '\p{^Block=katakanaphoneticextensions}', "");
Expect(0, 12799, '\P{Block=katakanaphoneticextensions}', "");
Expect(1, 12799, '\P{^Block=katakanaphoneticextensions}', "");
Expect(0, 12800, '\p{Block=katakanaphoneticextensions}', "");
Expect(1, 12800, '\p{^Block=katakanaphoneticextensions}', "");
Expect(1, 12800, '\P{Block=katakanaphoneticextensions}', "");
Expect(0, 12800, '\P{^Block=katakanaphoneticextensions}', "");
Expect(1, 12799, '\p{Block=-	Katakana_phonetic_Extensions}', "");
Expect(0, 12799, '\p{^Block=-	Katakana_phonetic_Extensions}', "");
Expect(0, 12799, '\P{Block=-	Katakana_phonetic_Extensions}', "");
Expect(1, 12799, '\P{^Block=-	Katakana_phonetic_Extensions}', "");
Expect(0, 12800, '\p{Block=-	Katakana_phonetic_Extensions}', "");
Expect(1, 12800, '\p{^Block=-	Katakana_phonetic_Extensions}', "");
Expect(1, 12800, '\P{Block=-	Katakana_phonetic_Extensions}', "");
Expect(0, 12800, '\P{^Block=-	Katakana_phonetic_Extensions}', "");
Error('\p{Blk=_:=KATAKANA_EXT}');
Error('\P{Blk=_:=KATAKANA_EXT}');
Expect(1, 12799, '\p{Blk=katakanaext}', "");
Expect(0, 12799, '\p{^Blk=katakanaext}', "");
Expect(0, 12799, '\P{Blk=katakanaext}', "");
Expect(1, 12799, '\P{^Blk=katakanaext}', "");
Expect(0, 12800, '\p{Blk=katakanaext}', "");
Expect(1, 12800, '\p{^Blk=katakanaext}', "");
Expect(1, 12800, '\P{Blk=katakanaext}', "");
Expect(0, 12800, '\P{^Blk=katakanaext}', "");
Expect(1, 12799, '\p{Blk=_KATAKANA_Ext}', "");
Expect(0, 12799, '\p{^Blk=_KATAKANA_Ext}', "");
Expect(0, 12799, '\P{Blk=_KATAKANA_Ext}', "");
Expect(1, 12799, '\P{^Blk=_KATAKANA_Ext}', "");
Expect(0, 12800, '\p{Blk=_KATAKANA_Ext}', "");
Expect(1, 12800, '\p{^Blk=_KATAKANA_Ext}', "");
Expect(1, 12800, '\P{Blk=_KATAKANA_Ext}', "");
Expect(0, 12800, '\P{^Blk=_KATAKANA_Ext}', "");
Error('\p{Is_Block=-:=katakana_phonetic_extensions}');
Error('\P{Is_Block=-:=katakana_phonetic_extensions}');
Expect(1, 12799, '\p{Is_Block=katakanaphoneticextensions}', "");
Expect(0, 12799, '\p{^Is_Block=katakanaphoneticextensions}', "");
Expect(0, 12799, '\P{Is_Block=katakanaphoneticextensions}', "");
Expect(1, 12799, '\P{^Is_Block=katakanaphoneticextensions}', "");
Expect(0, 12800, '\p{Is_Block=katakanaphoneticextensions}', "");
Expect(1, 12800, '\p{^Is_Block=katakanaphoneticextensions}', "");
Expect(1, 12800, '\P{Is_Block=katakanaphoneticextensions}', "");
Expect(0, 12800, '\P{^Is_Block=katakanaphoneticextensions}', "");
Expect(1, 12799, '\p{Is_Block:	katakana_phonetic_Extensions}', "");
Expect(0, 12799, '\p{^Is_Block:	katakana_phonetic_Extensions}', "");
Expect(0, 12799, '\P{Is_Block:	katakana_phonetic_Extensions}', "");
Expect(1, 12799, '\P{^Is_Block:	katakana_phonetic_Extensions}', "");
Expect(0, 12800, '\p{Is_Block:	katakana_phonetic_Extensions}', "");
Expect(1, 12800, '\p{^Is_Block:	katakana_phonetic_Extensions}', "");
Expect(1, 12800, '\P{Is_Block:	katakana_phonetic_Extensions}', "");
Expect(0, 12800, '\P{^Is_Block:	katakana_phonetic_Extensions}', "");
Error('\p{Is_Blk=_:=Katakana_Ext}');
Error('\P{Is_Blk=_:=Katakana_Ext}');
Expect(1, 12799, '\p{Is_Blk=katakanaext}', "");
Expect(0, 12799, '\p{^Is_Blk=katakanaext}', "");
Expect(0, 12799, '\P{Is_Blk=katakanaext}', "");
Expect(1, 12799, '\P{^Is_Blk=katakanaext}', "");
Expect(0, 12800, '\p{Is_Blk=katakanaext}', "");
Expect(1, 12800, '\p{^Is_Blk=katakanaext}', "");
Expect(1, 12800, '\P{Is_Blk=katakanaext}', "");
Expect(0, 12800, '\P{^Is_Blk=katakanaext}', "");
Expect(1, 12799, '\p{Is_Blk= KATAKANA_Ext}', "");
Expect(0, 12799, '\p{^Is_Blk= KATAKANA_Ext}', "");
Expect(0, 12799, '\P{Is_Blk= KATAKANA_Ext}', "");
Expect(1, 12799, '\P{^Is_Blk= KATAKANA_Ext}', "");
Expect(0, 12800, '\p{Is_Blk= KATAKANA_Ext}', "");
Expect(1, 12800, '\p{^Is_Blk= KATAKANA_Ext}', "");
Expect(1, 12800, '\P{Is_Blk= KATAKANA_Ext}', "");
Expect(0, 12800, '\P{^Is_Blk= KATAKANA_Ext}', "");
Error('\p{Block=/a/kayah_Li}');
Error('\P{Block=/a/kayah_Li}');
Expect(1, 43311, '\p{Block=kayahli}', "");
Expect(0, 43311, '\p{^Block=kayahli}', "");
Expect(0, 43311, '\P{Block=kayahli}', "");
Expect(1, 43311, '\P{^Block=kayahli}', "");
Expect(0, 43312, '\p{Block=kayahli}', "");
Expect(1, 43312, '\p{^Block=kayahli}', "");
Expect(1, 43312, '\P{Block=kayahli}', "");
Expect(0, 43312, '\P{^Block=kayahli}', "");
Expect(1, 43311, '\p{Block=__Kayah_Li}', "");
Expect(0, 43311, '\p{^Block=__Kayah_Li}', "");
Expect(0, 43311, '\P{Block=__Kayah_Li}', "");
Expect(1, 43311, '\P{^Block=__Kayah_Li}', "");
Expect(0, 43312, '\p{Block=__Kayah_Li}', "");
Expect(1, 43312, '\p{^Block=__Kayah_Li}', "");
Expect(1, 43312, '\P{Block=__Kayah_Li}', "");
Expect(0, 43312, '\P{^Block=__Kayah_Li}', "");
Error('\p{Blk=/a/ 	KAYAH_li}');
Error('\P{Blk=/a/ 	KAYAH_li}');
Expect(1, 43311, '\p{Blk=kayahli}', "");
Expect(0, 43311, '\p{^Blk=kayahli}', "");
Expect(0, 43311, '\P{Blk=kayahli}', "");
Expect(1, 43311, '\P{^Blk=kayahli}', "");
Expect(0, 43312, '\p{Blk=kayahli}', "");
Expect(1, 43312, '\p{^Blk=kayahli}', "");
Expect(1, 43312, '\P{Blk=kayahli}', "");
Expect(0, 43312, '\P{^Blk=kayahli}', "");
Expect(1, 43311, '\p{Blk=_KAYAH_li}', "");
Expect(0, 43311, '\p{^Blk=_KAYAH_li}', "");
Expect(0, 43311, '\P{Blk=_KAYAH_li}', "");
Expect(1, 43311, '\P{^Blk=_KAYAH_li}', "");
Expect(0, 43312, '\p{Blk=_KAYAH_li}', "");
Expect(1, 43312, '\p{^Blk=_KAYAH_li}', "");
Expect(1, 43312, '\P{Blk=_KAYAH_li}', "");
Expect(0, 43312, '\P{^Blk=_KAYAH_li}', "");
Error('\p{Is_Block: :=kayah_LI}');
Error('\P{Is_Block: :=kayah_LI}');
Expect(1, 43311, '\p{Is_Block=kayahli}', "");
Expect(0, 43311, '\p{^Is_Block=kayahli}', "");
Expect(0, 43311, '\P{Is_Block=kayahli}', "");
Expect(1, 43311, '\P{^Is_Block=kayahli}', "");
Expect(0, 43312, '\p{Is_Block=kayahli}', "");
Expect(1, 43312, '\p{^Is_Block=kayahli}', "");
Expect(1, 43312, '\P{Is_Block=kayahli}', "");
Expect(0, 43312, '\P{^Is_Block=kayahli}', "");
Expect(1, 43311, '\p{Is_Block:KAYAH_Li}', "");
Expect(0, 43311, '\p{^Is_Block:KAYAH_Li}', "");
Expect(0, 43311, '\P{Is_Block:KAYAH_Li}', "");
Expect(1, 43311, '\P{^Is_Block:KAYAH_Li}', "");
Expect(0, 43312, '\p{Is_Block:KAYAH_Li}', "");
Expect(1, 43312, '\p{^Is_Block:KAYAH_Li}', "");
Expect(1, 43312, '\P{Is_Block:KAYAH_Li}', "");
Expect(0, 43312, '\P{^Is_Block:KAYAH_Li}', "");
Error('\p{Is_Blk=/a/_ Kayah_LI}');
Error('\P{Is_Blk=/a/_ Kayah_LI}');
Expect(1, 43311, '\p{Is_Blk=kayahli}', "");
Expect(0, 43311, '\p{^Is_Blk=kayahli}', "");
Expect(0, 43311, '\P{Is_Blk=kayahli}', "");
Expect(1, 43311, '\P{^Is_Blk=kayahli}', "");
Expect(0, 43312, '\p{Is_Blk=kayahli}', "");
Expect(1, 43312, '\p{^Is_Blk=kayahli}', "");
Expect(1, 43312, '\P{Is_Blk=kayahli}', "");
Expect(0, 43312, '\P{^Is_Blk=kayahli}', "");
Expect(1, 43311, '\p{Is_Blk=-Kayah_li}', "");
Expect(0, 43311, '\p{^Is_Blk=-Kayah_li}', "");
Expect(0, 43311, '\P{Is_Blk=-Kayah_li}', "");
Expect(1, 43311, '\P{^Is_Blk=-Kayah_li}', "");
Expect(0, 43312, '\p{Is_Blk=-Kayah_li}', "");
Expect(1, 43312, '\p{^Is_Blk=-Kayah_li}', "");
Expect(1, 43312, '\P{Is_Blk=-Kayah_li}', "");
Expect(0, 43312, '\P{^Is_Blk=-Kayah_li}', "");
Error('\p{Block=:=	Kharoshthi}');
Error('\P{Block=:=	Kharoshthi}');
Expect(1, 68191, '\p{Block=kharoshthi}', "");
Expect(0, 68191, '\p{^Block=kharoshthi}', "");
Expect(0, 68191, '\P{Block=kharoshthi}', "");
Expect(1, 68191, '\P{^Block=kharoshthi}', "");
Expect(0, 68192, '\p{Block=kharoshthi}', "");
Expect(1, 68192, '\p{^Block=kharoshthi}', "");
Expect(1, 68192, '\P{Block=kharoshthi}', "");
Expect(0, 68192, '\P{^Block=kharoshthi}', "");
Expect(1, 68191, '\p{Block=	Kharoshthi}', "");
Expect(0, 68191, '\p{^Block=	Kharoshthi}', "");
Expect(0, 68191, '\P{Block=	Kharoshthi}', "");
Expect(1, 68191, '\P{^Block=	Kharoshthi}', "");
Expect(0, 68192, '\p{Block=	Kharoshthi}', "");
Expect(1, 68192, '\p{^Block=	Kharoshthi}', "");
Expect(1, 68192, '\P{Block=	Kharoshthi}', "");
Expect(0, 68192, '\P{^Block=	Kharoshthi}', "");
Error('\p{Blk=:= Kharoshthi}');
Error('\P{Blk=:= Kharoshthi}');
Expect(1, 68191, '\p{Blk=kharoshthi}', "");
Expect(0, 68191, '\p{^Blk=kharoshthi}', "");
Expect(0, 68191, '\P{Blk=kharoshthi}', "");
Expect(1, 68191, '\P{^Blk=kharoshthi}', "");
Expect(0, 68192, '\p{Blk=kharoshthi}', "");
Expect(1, 68192, '\p{^Blk=kharoshthi}', "");
Expect(1, 68192, '\P{Blk=kharoshthi}', "");
Expect(0, 68192, '\P{^Blk=kharoshthi}', "");
Expect(1, 68191, '\p{Blk=_Kharoshthi}', "");
Expect(0, 68191, '\p{^Blk=_Kharoshthi}', "");
Expect(0, 68191, '\P{Blk=_Kharoshthi}', "");
Expect(1, 68191, '\P{^Blk=_Kharoshthi}', "");
Expect(0, 68192, '\p{Blk=_Kharoshthi}', "");
Expect(1, 68192, '\p{^Blk=_Kharoshthi}', "");
Expect(1, 68192, '\P{Blk=_Kharoshthi}', "");
Expect(0, 68192, '\P{^Blk=_Kharoshthi}', "");
Error('\p{Is_Block=/a/kharoshthi}');
Error('\P{Is_Block=/a/kharoshthi}');
Expect(1, 68191, '\p{Is_Block=kharoshthi}', "");
Expect(0, 68191, '\p{^Is_Block=kharoshthi}', "");
Expect(0, 68191, '\P{Is_Block=kharoshthi}', "");
Expect(1, 68191, '\P{^Is_Block=kharoshthi}', "");
Expect(0, 68192, '\p{Is_Block=kharoshthi}', "");
Expect(1, 68192, '\p{^Is_Block=kharoshthi}', "");
Expect(1, 68192, '\P{Is_Block=kharoshthi}', "");
Expect(0, 68192, '\P{^Is_Block=kharoshthi}', "");
Expect(1, 68191, '\p{Is_Block=	 KHAROSHTHI}', "");
Expect(0, 68191, '\p{^Is_Block=	 KHAROSHTHI}', "");
Expect(0, 68191, '\P{Is_Block=	 KHAROSHTHI}', "");
Expect(1, 68191, '\P{^Is_Block=	 KHAROSHTHI}', "");
Expect(0, 68192, '\p{Is_Block=	 KHAROSHTHI}', "");
Expect(1, 68192, '\p{^Is_Block=	 KHAROSHTHI}', "");
Expect(1, 68192, '\P{Is_Block=	 KHAROSHTHI}', "");
Expect(0, 68192, '\P{^Is_Block=	 KHAROSHTHI}', "");
Error('\p{Is_Blk= 	kharoshthi/a/}');
Error('\P{Is_Blk= 	kharoshthi/a/}');
Expect(1, 68191, '\p{Is_Blk=kharoshthi}', "");
Expect(0, 68191, '\p{^Is_Blk=kharoshthi}', "");
Expect(0, 68191, '\P{Is_Blk=kharoshthi}', "");
Expect(1, 68191, '\P{^Is_Blk=kharoshthi}', "");
Expect(0, 68192, '\p{Is_Blk=kharoshthi}', "");
Expect(1, 68192, '\p{^Is_Blk=kharoshthi}', "");
Expect(1, 68192, '\P{Is_Blk=kharoshthi}', "");
Expect(0, 68192, '\P{^Is_Blk=kharoshthi}', "");
Expect(1, 68191, '\p{Is_Blk= 	Kharoshthi}', "");
Expect(0, 68191, '\p{^Is_Blk= 	Kharoshthi}', "");
Expect(0, 68191, '\P{Is_Blk= 	Kharoshthi}', "");
Expect(1, 68191, '\P{^Is_Blk= 	Kharoshthi}', "");
Expect(0, 68192, '\p{Is_Blk= 	Kharoshthi}', "");
Expect(1, 68192, '\p{^Is_Blk= 	Kharoshthi}', "");
Expect(1, 68192, '\P{Is_Blk= 	Kharoshthi}', "");
Expect(0, 68192, '\P{^Is_Blk= 	Kharoshthi}', "");
Error('\p{Block=:= Khmer}');
Error('\P{Block=:= Khmer}');
Expect(1, 6143, '\p{Block:   khmer}', "");
Expect(0, 6143, '\p{^Block:   khmer}', "");
Expect(0, 6143, '\P{Block:   khmer}', "");
Expect(1, 6143, '\P{^Block:   khmer}', "");
Expect(0, 6144, '\p{Block:   khmer}', "");
Expect(1, 6144, '\p{^Block:   khmer}', "");
Expect(1, 6144, '\P{Block:   khmer}', "");
Expect(0, 6144, '\P{^Block:   khmer}', "");
Expect(1, 6143, '\p{Block=__Khmer}', "");
Expect(0, 6143, '\p{^Block=__Khmer}', "");
Expect(0, 6143, '\P{Block=__Khmer}', "");
Expect(1, 6143, '\P{^Block=__Khmer}', "");
Expect(0, 6144, '\p{Block=__Khmer}', "");
Expect(1, 6144, '\p{^Block=__Khmer}', "");
Expect(1, 6144, '\P{Block=__Khmer}', "");
Expect(0, 6144, '\P{^Block=__Khmer}', "");
Error('\p{Blk=:=--Khmer}');
Error('\P{Blk=:=--Khmer}');
Expect(1, 6143, '\p{Blk=khmer}', "");
Expect(0, 6143, '\p{^Blk=khmer}', "");
Expect(0, 6143, '\P{Blk=khmer}', "");
Expect(1, 6143, '\P{^Blk=khmer}', "");
Expect(0, 6144, '\p{Blk=khmer}', "");
Expect(1, 6144, '\p{^Blk=khmer}', "");
Expect(1, 6144, '\P{Blk=khmer}', "");
Expect(0, 6144, '\P{^Blk=khmer}', "");
Expect(1, 6143, '\p{Blk=_ KHMER}', "");
Expect(0, 6143, '\p{^Blk=_ KHMER}', "");
Expect(0, 6143, '\P{Blk=_ KHMER}', "");
Expect(1, 6143, '\P{^Blk=_ KHMER}', "");
Expect(0, 6144, '\p{Blk=_ KHMER}', "");
Expect(1, 6144, '\p{^Blk=_ KHMER}', "");
Expect(1, 6144, '\P{Blk=_ KHMER}', "");
Expect(0, 6144, '\P{^Blk=_ KHMER}', "");
Error('\p{Is_Block=/a/	-KHMER}');
Error('\P{Is_Block=/a/	-KHMER}');
Expect(1, 6143, '\p{Is_Block=khmer}', "");
Expect(0, 6143, '\p{^Is_Block=khmer}', "");
Expect(0, 6143, '\P{Is_Block=khmer}', "");
Expect(1, 6143, '\P{^Is_Block=khmer}', "");
Expect(0, 6144, '\p{Is_Block=khmer}', "");
Expect(1, 6144, '\p{^Is_Block=khmer}', "");
Expect(1, 6144, '\P{Is_Block=khmer}', "");
Expect(0, 6144, '\P{^Is_Block=khmer}', "");
Expect(1, 6143, '\p{Is_Block=	 KHMER}', "");
Expect(0, 6143, '\p{^Is_Block=	 KHMER}', "");
Expect(0, 6143, '\P{Is_Block=	 KHMER}', "");
Expect(1, 6143, '\P{^Is_Block=	 KHMER}', "");
Expect(0, 6144, '\p{Is_Block=	 KHMER}', "");
Expect(1, 6144, '\p{^Is_Block=	 KHMER}', "");
Expect(1, 6144, '\P{Is_Block=	 KHMER}', "");
Expect(0, 6144, '\P{^Is_Block=	 KHMER}', "");
Error('\p{Is_Blk=	/a/Khmer}');
Error('\P{Is_Blk=	/a/Khmer}');
Expect(1, 6143, '\p{Is_Blk=khmer}', "");
Expect(0, 6143, '\p{^Is_Blk=khmer}', "");
Expect(0, 6143, '\P{Is_Blk=khmer}', "");
Expect(1, 6143, '\P{^Is_Blk=khmer}', "");
Expect(0, 6144, '\p{Is_Blk=khmer}', "");
Expect(1, 6144, '\p{^Is_Blk=khmer}', "");
Expect(1, 6144, '\P{Is_Blk=khmer}', "");
Expect(0, 6144, '\P{^Is_Blk=khmer}', "");
Expect(1, 6143, '\p{Is_Blk=_-Khmer}', "");
Expect(0, 6143, '\p{^Is_Blk=_-Khmer}', "");
Expect(0, 6143, '\P{Is_Blk=_-Khmer}', "");
Expect(1, 6143, '\P{^Is_Blk=_-Khmer}', "");
Expect(0, 6144, '\p{Is_Blk=_-Khmer}', "");
Expect(1, 6144, '\p{^Is_Blk=_-Khmer}', "");
Expect(1, 6144, '\P{Is_Blk=_-Khmer}', "");
Expect(0, 6144, '\P{^Is_Blk=_-Khmer}', "");
Error('\p{Block:	 /a/khmer_symbols}');
Error('\P{Block:	 /a/khmer_symbols}');
Expect(1, 6655, '\p{Block:khmersymbols}', "");
Expect(0, 6655, '\p{^Block:khmersymbols}', "");
Expect(0, 6655, '\P{Block:khmersymbols}', "");
Expect(1, 6655, '\P{^Block:khmersymbols}', "");
Expect(0, 6656, '\p{Block:khmersymbols}', "");
Expect(1, 6656, '\p{^Block:khmersymbols}', "");
Expect(1, 6656, '\P{Block:khmersymbols}', "");
Expect(0, 6656, '\P{^Block:khmersymbols}', "");
Expect(1, 6655, '\p{Block=- Khmer_symbols}', "");
Expect(0, 6655, '\p{^Block=- Khmer_symbols}', "");
Expect(0, 6655, '\P{Block=- Khmer_symbols}', "");
Expect(1, 6655, '\P{^Block=- Khmer_symbols}', "");
Expect(0, 6656, '\p{Block=- Khmer_symbols}', "");
Expect(1, 6656, '\p{^Block=- Khmer_symbols}', "");
Expect(1, 6656, '\P{Block=- Khmer_symbols}', "");
Expect(0, 6656, '\P{^Block=- Khmer_symbols}', "");
Error('\p{Blk=-:=Khmer_symbols}');
Error('\P{Blk=-:=Khmer_symbols}');
Expect(1, 6655, '\p{Blk=khmersymbols}', "");
Expect(0, 6655, '\p{^Blk=khmersymbols}', "");
Expect(0, 6655, '\P{Blk=khmersymbols}', "");
Expect(1, 6655, '\P{^Blk=khmersymbols}', "");
Expect(0, 6656, '\p{Blk=khmersymbols}', "");
Expect(1, 6656, '\p{^Blk=khmersymbols}', "");
Expect(1, 6656, '\P{Blk=khmersymbols}', "");
Expect(0, 6656, '\P{^Blk=khmersymbols}', "");
Expect(1, 6655, '\p{Blk= Khmer_Symbols}', "");
Expect(0, 6655, '\p{^Blk= Khmer_Symbols}', "");
Expect(0, 6655, '\P{Blk= Khmer_Symbols}', "");
Expect(1, 6655, '\P{^Blk= Khmer_Symbols}', "");
Expect(0, 6656, '\p{Blk= Khmer_Symbols}', "");
Expect(1, 6656, '\p{^Blk= Khmer_Symbols}', "");
Expect(1, 6656, '\P{Blk= Khmer_Symbols}', "");
Expect(0, 6656, '\P{^Blk= Khmer_Symbols}', "");
Error('\p{Is_Block= /a/KHMER_SYMBOLS}');
Error('\P{Is_Block= /a/KHMER_SYMBOLS}');
Expect(1, 6655, '\p{Is_Block=khmersymbols}', "");
Expect(0, 6655, '\p{^Is_Block=khmersymbols}', "");
Expect(0, 6655, '\P{Is_Block=khmersymbols}', "");
Expect(1, 6655, '\P{^Is_Block=khmersymbols}', "");
Expect(0, 6656, '\p{Is_Block=khmersymbols}', "");
Expect(1, 6656, '\p{^Is_Block=khmersymbols}', "");
Expect(1, 6656, '\P{Is_Block=khmersymbols}', "");
Expect(0, 6656, '\P{^Is_Block=khmersymbols}', "");
Expect(1, 6655, '\p{Is_Block=_ khmer_SYMBOLS}', "");
Expect(0, 6655, '\p{^Is_Block=_ khmer_SYMBOLS}', "");
Expect(0, 6655, '\P{Is_Block=_ khmer_SYMBOLS}', "");
Expect(1, 6655, '\P{^Is_Block=_ khmer_SYMBOLS}', "");
Expect(0, 6656, '\p{Is_Block=_ khmer_SYMBOLS}', "");
Expect(1, 6656, '\p{^Is_Block=_ khmer_SYMBOLS}', "");
Expect(1, 6656, '\P{Is_Block=_ khmer_SYMBOLS}', "");
Expect(0, 6656, '\P{^Is_Block=_ khmer_SYMBOLS}', "");
Error('\p{Is_Blk=	-KHMER_Symbols:=}');
Error('\P{Is_Blk=	-KHMER_Symbols:=}');
Expect(1, 6655, '\p{Is_Blk=khmersymbols}', "");
Expect(0, 6655, '\p{^Is_Blk=khmersymbols}', "");
Expect(0, 6655, '\P{Is_Blk=khmersymbols}', "");
Expect(1, 6655, '\P{^Is_Blk=khmersymbols}', "");
Expect(0, 6656, '\p{Is_Blk=khmersymbols}', "");
Expect(1, 6656, '\p{^Is_Blk=khmersymbols}', "");
Expect(1, 6656, '\P{Is_Blk=khmersymbols}', "");
Expect(0, 6656, '\P{^Is_Blk=khmersymbols}', "");
Expect(1, 6655, '\p{Is_Blk= khmer_Symbols}', "");
Expect(0, 6655, '\p{^Is_Blk= khmer_Symbols}', "");
Expect(0, 6655, '\P{Is_Blk= khmer_Symbols}', "");
Expect(1, 6655, '\P{^Is_Blk= khmer_Symbols}', "");
Expect(0, 6656, '\p{Is_Blk= khmer_Symbols}', "");
Expect(1, 6656, '\p{^Is_Blk= khmer_Symbols}', "");
Expect(1, 6656, '\P{Is_Blk= khmer_Symbols}', "");
Expect(0, 6656, '\P{^Is_Blk= khmer_Symbols}', "");
Error('\p{Block=-lao:=}');
Error('\P{Block=-lao:=}');
Expect(1, 3839, '\p{Block=lao}', "");
Expect(0, 3839, '\p{^Block=lao}', "");
Expect(0, 3839, '\P{Block=lao}', "");
Expect(1, 3839, '\P{^Block=lao}', "");
Expect(0, 3840, '\p{Block=lao}', "");
Expect(1, 3840, '\p{^Block=lao}', "");
Expect(1, 3840, '\P{Block=lao}', "");
Expect(0, 3840, '\P{^Block=lao}', "");
Expect(1, 3839, '\p{Block=-_lao}', "");
Expect(0, 3839, '\p{^Block=-_lao}', "");
Expect(0, 3839, '\P{Block=-_lao}', "");
Expect(1, 3839, '\P{^Block=-_lao}', "");
Expect(0, 3840, '\p{Block=-_lao}', "");
Expect(1, 3840, '\p{^Block=-_lao}', "");
Expect(1, 3840, '\P{Block=-_lao}', "");
Expect(0, 3840, '\P{^Block=-_lao}', "");
Error('\p{Blk=	Lao/a/}');
Error('\P{Blk=	Lao/a/}');
Expect(1, 3839, '\p{Blk=lao}', "");
Expect(0, 3839, '\p{^Blk=lao}', "");
Expect(0, 3839, '\P{Blk=lao}', "");
Expect(1, 3839, '\P{^Blk=lao}', "");
Expect(0, 3840, '\p{Blk=lao}', "");
Expect(1, 3840, '\p{^Blk=lao}', "");
Expect(1, 3840, '\P{Blk=lao}', "");
Expect(0, 3840, '\P{^Blk=lao}', "");
Expect(1, 3839, '\p{Blk=-	Lao}', "");
Expect(0, 3839, '\p{^Blk=-	Lao}', "");
Expect(0, 3839, '\P{Blk=-	Lao}', "");
Expect(1, 3839, '\P{^Blk=-	Lao}', "");
Expect(0, 3840, '\p{Blk=-	Lao}', "");
Expect(1, 3840, '\p{^Blk=-	Lao}', "");
Expect(1, 3840, '\P{Blk=-	Lao}', "");
Expect(0, 3840, '\P{^Blk=-	Lao}', "");
Error('\p{Is_Block=/a/  lao}');
Error('\P{Is_Block=/a/  lao}');
Expect(1, 3839, '\p{Is_Block=lao}', "");
Expect(0, 3839, '\p{^Is_Block=lao}', "");
Expect(0, 3839, '\P{Is_Block=lao}', "");
Expect(1, 3839, '\P{^Is_Block=lao}', "");
Expect(0, 3840, '\p{Is_Block=lao}', "");
Expect(1, 3840, '\p{^Is_Block=lao}', "");
Expect(1, 3840, '\P{Is_Block=lao}', "");
Expect(0, 3840, '\P{^Is_Block=lao}', "");
Expect(1, 3839, '\p{Is_Block=-Lao}', "");
Expect(0, 3839, '\p{^Is_Block=-Lao}', "");
Expect(0, 3839, '\P{Is_Block=-Lao}', "");
Expect(1, 3839, '\P{^Is_Block=-Lao}', "");
Expect(0, 3840, '\p{Is_Block=-Lao}', "");
Expect(1, 3840, '\p{^Is_Block=-Lao}', "");
Expect(1, 3840, '\P{Is_Block=-Lao}', "");
Expect(0, 3840, '\P{^Is_Block=-Lao}', "");
Error('\p{Is_Blk=/a/ -Lao}');
Error('\P{Is_Blk=/a/ -Lao}');
Expect(1, 3839, '\p{Is_Blk=lao}', "");
Expect(0, 3839, '\p{^Is_Blk=lao}', "");
Expect(0, 3839, '\P{Is_Blk=lao}', "");
Expect(1, 3839, '\P{^Is_Blk=lao}', "");
Expect(0, 3840, '\p{Is_Blk=lao}', "");
Expect(1, 3840, '\p{^Is_Blk=lao}', "");
Expect(1, 3840, '\P{Is_Blk=lao}', "");
Expect(0, 3840, '\P{^Is_Blk=lao}', "");
Expect(1, 3839, '\p{Is_Blk:   _lao}', "");
Expect(0, 3839, '\p{^Is_Blk:   _lao}', "");
Expect(0, 3839, '\P{Is_Blk:   _lao}', "");
Expect(1, 3839, '\P{^Is_Blk:   _lao}', "");
Expect(0, 3840, '\p{Is_Blk:   _lao}', "");
Expect(1, 3840, '\p{^Is_Blk:   _lao}', "");
Expect(1, 3840, '\P{Is_Blk:   _lao}', "");
Expect(0, 3840, '\P{^Is_Blk:   _lao}', "");
Error('\p{Block=-Latin_1_supplement/a/}');
Error('\P{Block=-Latin_1_supplement/a/}');
Expect(1, 255, '\p{Block=latin1supplement}', "");
Expect(0, 255, '\p{^Block=latin1supplement}', "");
Expect(0, 255, '\P{Block=latin1supplement}', "");
Expect(1, 255, '\P{^Block=latin1supplement}', "");
Expect(0, 256, '\p{Block=latin1supplement}', "");
Expect(1, 256, '\p{^Block=latin1supplement}', "");
Expect(1, 256, '\P{Block=latin1supplement}', "");
Expect(0, 256, '\P{^Block=latin1supplement}', "");
Expect(1, 255, '\p{Block=		latin_1_supplement}', "");
Expect(0, 255, '\p{^Block=		latin_1_supplement}', "");
Expect(0, 255, '\P{Block=		latin_1_supplement}', "");
Expect(1, 255, '\P{^Block=		latin_1_supplement}', "");
Expect(0, 256, '\p{Block=		latin_1_supplement}', "");
Expect(1, 256, '\p{^Block=		latin_1_supplement}', "");
Expect(1, 256, '\P{Block=		latin_1_supplement}', "");
Expect(0, 256, '\P{^Block=		latin_1_supplement}', "");
Error('\p{Blk=-:=Latin_1_Sup}');
Error('\P{Blk=-:=Latin_1_Sup}');
Expect(1, 255, '\p{Blk=latin1sup}', "");
Expect(0, 255, '\p{^Blk=latin1sup}', "");
Expect(0, 255, '\P{Blk=latin1sup}', "");
Expect(1, 255, '\P{^Blk=latin1sup}', "");
Expect(0, 256, '\p{Blk=latin1sup}', "");
Expect(1, 256, '\p{^Blk=latin1sup}', "");
Expect(1, 256, '\P{Blk=latin1sup}', "");
Expect(0, 256, '\P{^Blk=latin1sup}', "");
Expect(1, 255, '\p{Blk:-	Latin_1_Sup}', "");
Expect(0, 255, '\p{^Blk:-	Latin_1_Sup}', "");
Expect(0, 255, '\P{Blk:-	Latin_1_Sup}', "");
Expect(1, 255, '\P{^Blk:-	Latin_1_Sup}', "");
Expect(0, 256, '\p{Blk:-	Latin_1_Sup}', "");
Expect(1, 256, '\p{^Blk:-	Latin_1_Sup}', "");
Expect(1, 256, '\P{Blk:-	Latin_1_Sup}', "");
Expect(0, 256, '\P{^Blk:-	Latin_1_Sup}', "");
Error('\p{Is_Block: :=-Latin_1}');
Error('\P{Is_Block: :=-Latin_1}');
Expect(1, 255, '\p{Is_Block:latin1}', "");
Expect(0, 255, '\p{^Is_Block:latin1}', "");
Expect(0, 255, '\P{Is_Block:latin1}', "");
Expect(1, 255, '\P{^Is_Block:latin1}', "");
Expect(0, 256, '\p{Is_Block:latin1}', "");
Expect(1, 256, '\p{^Is_Block:latin1}', "");
Expect(1, 256, '\P{Is_Block:latin1}', "");
Expect(0, 256, '\P{^Is_Block:latin1}', "");
Expect(1, 255, '\p{Is_Block=-	LATIN_1}', "");
Expect(0, 255, '\p{^Is_Block=-	LATIN_1}', "");
Expect(0, 255, '\P{Is_Block=-	LATIN_1}', "");
Expect(1, 255, '\P{^Is_Block=-	LATIN_1}', "");
Expect(0, 256, '\p{Is_Block=-	LATIN_1}', "");
Expect(1, 256, '\p{^Is_Block=-	LATIN_1}', "");
Expect(1, 256, '\P{Is_Block=-	LATIN_1}', "");
Expect(0, 256, '\P{^Is_Block=-	LATIN_1}', "");
Error('\p{Is_Blk=/a/Latin_1_supplement}');
Error('\P{Is_Blk=/a/Latin_1_supplement}');
Expect(1, 255, '\p{Is_Blk:	latin1supplement}', "");
Expect(0, 255, '\p{^Is_Blk:	latin1supplement}', "");
Expect(0, 255, '\P{Is_Blk:	latin1supplement}', "");
Expect(1, 255, '\P{^Is_Blk:	latin1supplement}', "");
Expect(0, 256, '\p{Is_Blk:	latin1supplement}', "");
Expect(1, 256, '\p{^Is_Blk:	latin1supplement}', "");
Expect(1, 256, '\P{Is_Blk:	latin1supplement}', "");
Expect(0, 256, '\P{^Is_Blk:	latin1supplement}', "");
Expect(1, 255, '\p{Is_Blk: - Latin_1_SUPPLEMENT}', "");
Expect(0, 255, '\p{^Is_Blk: - Latin_1_SUPPLEMENT}', "");
Expect(0, 255, '\P{Is_Blk: - Latin_1_SUPPLEMENT}', "");
Expect(1, 255, '\P{^Is_Blk: - Latin_1_SUPPLEMENT}', "");
Expect(0, 256, '\p{Is_Blk: - Latin_1_SUPPLEMENT}', "");
Expect(1, 256, '\p{^Is_Blk: - Latin_1_SUPPLEMENT}', "");
Expect(1, 256, '\P{Is_Blk: - Latin_1_SUPPLEMENT}', "");
Expect(0, 256, '\P{^Is_Blk: - Latin_1_SUPPLEMENT}', "");
Error('\p{Block=- latin_EXTENDED_A/a/}');
Error('\P{Block=- latin_EXTENDED_A/a/}');
Expect(1, 383, '\p{Block=latinextendeda}', "");
Expect(0, 383, '\p{^Block=latinextendeda}', "");
Expect(0, 383, '\P{Block=latinextendeda}', "");
Expect(1, 383, '\P{^Block=latinextendeda}', "");
Expect(0, 384, '\p{Block=latinextendeda}', "");
Expect(1, 384, '\p{^Block=latinextendeda}', "");
Expect(1, 384, '\P{Block=latinextendeda}', "");
Expect(0, 384, '\P{^Block=latinextendeda}', "");
Expect(1, 383, '\p{Block= LATIN_Extended_A}', "");
Expect(0, 383, '\p{^Block= LATIN_Extended_A}', "");
Expect(0, 383, '\P{Block= LATIN_Extended_A}', "");
Expect(1, 383, '\P{^Block= LATIN_Extended_A}', "");
Expect(0, 384, '\p{Block= LATIN_Extended_A}', "");
Expect(1, 384, '\p{^Block= LATIN_Extended_A}', "");
Expect(1, 384, '\P{Block= LATIN_Extended_A}', "");
Expect(0, 384, '\P{^Block= LATIN_Extended_A}', "");
Error('\p{Blk=_:=LATIN_Ext_A}');
Error('\P{Blk=_:=LATIN_Ext_A}');
Expect(1, 383, '\p{Blk=latinexta}', "");
Expect(0, 383, '\p{^Blk=latinexta}', "");
Expect(0, 383, '\P{Blk=latinexta}', "");
Expect(1, 383, '\P{^Blk=latinexta}', "");
Expect(0, 384, '\p{Blk=latinexta}', "");
Expect(1, 384, '\p{^Blk=latinexta}', "");
Expect(1, 384, '\P{Blk=latinexta}', "");
Expect(0, 384, '\P{^Blk=latinexta}', "");
Expect(1, 383, '\p{Blk=_	Latin_Ext_A}', "");
Expect(0, 383, '\p{^Blk=_	Latin_Ext_A}', "");
Expect(0, 383, '\P{Blk=_	Latin_Ext_A}', "");
Expect(1, 383, '\P{^Blk=_	Latin_Ext_A}', "");
Expect(0, 384, '\p{Blk=_	Latin_Ext_A}', "");
Expect(1, 384, '\p{^Blk=_	Latin_Ext_A}', "");
Expect(1, 384, '\P{Blk=_	Latin_Ext_A}', "");
Expect(0, 384, '\P{^Blk=_	Latin_Ext_A}', "");
Error('\p{Is_Block= /a/latin_extended_A}');
Error('\P{Is_Block= /a/latin_extended_A}');
Expect(1, 383, '\p{Is_Block=latinextendeda}', "");
Expect(0, 383, '\p{^Is_Block=latinextendeda}', "");
Expect(0, 383, '\P{Is_Block=latinextendeda}', "");
Expect(1, 383, '\P{^Is_Block=latinextendeda}', "");
Expect(0, 384, '\p{Is_Block=latinextendeda}', "");
Expect(1, 384, '\p{^Is_Block=latinextendeda}', "");
Expect(1, 384, '\P{Is_Block=latinextendeda}', "");
Expect(0, 384, '\P{^Is_Block=latinextendeda}', "");
Expect(1, 383, '\p{Is_Block:	latin_Extended_A}', "");
Expect(0, 383, '\p{^Is_Block:	latin_Extended_A}', "");
Expect(0, 383, '\P{Is_Block:	latin_Extended_A}', "");
Expect(1, 383, '\P{^Is_Block:	latin_Extended_A}', "");
Expect(0, 384, '\p{Is_Block:	latin_Extended_A}', "");
Expect(1, 384, '\p{^Is_Block:	latin_Extended_A}', "");
Expect(1, 384, '\P{Is_Block:	latin_Extended_A}', "");
Expect(0, 384, '\P{^Is_Block:	latin_Extended_A}', "");
Error('\p{Is_Blk=/a/  Latin_Ext_A}');
Error('\P{Is_Blk=/a/  Latin_Ext_A}');
Expect(1, 383, '\p{Is_Blk=latinexta}', "");
Expect(0, 383, '\p{^Is_Blk=latinexta}', "");
Expect(0, 383, '\P{Is_Blk=latinexta}', "");
Expect(1, 383, '\P{^Is_Blk=latinexta}', "");
Expect(0, 384, '\p{Is_Blk=latinexta}', "");
Expect(1, 384, '\p{^Is_Blk=latinexta}', "");
Expect(1, 384, '\P{Is_Blk=latinexta}', "");
Expect(0, 384, '\P{^Is_Blk=latinexta}', "");
Expect(1, 383, '\p{Is_Blk=_Latin_ext_a}', "");
Expect(0, 383, '\p{^Is_Blk=_Latin_ext_a}', "");
Expect(0, 383, '\P{Is_Blk=_Latin_ext_a}', "");
Expect(1, 383, '\P{^Is_Blk=_Latin_ext_a}', "");
Expect(0, 384, '\p{Is_Blk=_Latin_ext_a}', "");
Expect(1, 384, '\p{^Is_Blk=_Latin_ext_a}', "");
Expect(1, 384, '\P{Is_Blk=_Latin_ext_a}', "");
Expect(0, 384, '\P{^Is_Blk=_Latin_ext_a}', "");
Error('\p{Block=:= 	Latin_Extended_additional}');
Error('\P{Block=:= 	Latin_Extended_additional}');
Expect(1, 7935, '\p{Block=latinextendedadditional}', "");
Expect(0, 7935, '\p{^Block=latinextendedadditional}', "");
Expect(0, 7935, '\P{Block=latinextendedadditional}', "");
Expect(1, 7935, '\P{^Block=latinextendedadditional}', "");
Expect(0, 7936, '\p{Block=latinextendedadditional}', "");
Expect(1, 7936, '\p{^Block=latinextendedadditional}', "");
Expect(1, 7936, '\P{Block=latinextendedadditional}', "");
Expect(0, 7936, '\P{^Block=latinextendedadditional}', "");
Expect(1, 7935, '\p{Block= Latin_Extended_Additional}', "");
Expect(0, 7935, '\p{^Block= Latin_Extended_Additional}', "");
Expect(0, 7935, '\P{Block= Latin_Extended_Additional}', "");
Expect(1, 7935, '\P{^Block= Latin_Extended_Additional}', "");
Expect(0, 7936, '\p{Block= Latin_Extended_Additional}', "");
Expect(1, 7936, '\p{^Block= Latin_Extended_Additional}', "");
Expect(1, 7936, '\P{Block= Latin_Extended_Additional}', "");
Expect(0, 7936, '\P{^Block= Latin_Extended_Additional}', "");
Error('\p{Blk:	:=--LATIN_ext_ADDITIONAL}');
Error('\P{Blk:	:=--LATIN_ext_ADDITIONAL}');
Expect(1, 7935, '\p{Blk=latinextadditional}', "");
Expect(0, 7935, '\p{^Blk=latinextadditional}', "");
Expect(0, 7935, '\P{Blk=latinextadditional}', "");
Expect(1, 7935, '\P{^Blk=latinextadditional}', "");
Expect(0, 7936, '\p{Blk=latinextadditional}', "");
Expect(1, 7936, '\p{^Blk=latinextadditional}', "");
Expect(1, 7936, '\P{Blk=latinextadditional}', "");
Expect(0, 7936, '\P{^Blk=latinextadditional}', "");
Expect(1, 7935, '\p{Blk= Latin_Ext_Additional}', "");
Expect(0, 7935, '\p{^Blk= Latin_Ext_Additional}', "");
Expect(0, 7935, '\P{Blk= Latin_Ext_Additional}', "");
Expect(1, 7935, '\P{^Blk= Latin_Ext_Additional}', "");
Expect(0, 7936, '\p{Blk= Latin_Ext_Additional}', "");
Expect(1, 7936, '\p{^Blk= Latin_Ext_Additional}', "");
Expect(1, 7936, '\P{Blk= Latin_Ext_Additional}', "");
Expect(0, 7936, '\P{^Blk= Latin_Ext_Additional}', "");
Error('\p{Is_Block=	_latin_extended_Additional/a/}');
Error('\P{Is_Block=	_latin_extended_Additional/a/}');
Expect(1, 7935, '\p{Is_Block=latinextendedadditional}', "");
Expect(0, 7935, '\p{^Is_Block=latinextendedadditional}', "");
Expect(0, 7935, '\P{Is_Block=latinextendedadditional}', "");
Expect(1, 7935, '\P{^Is_Block=latinextendedadditional}', "");
Expect(0, 7936, '\p{Is_Block=latinextendedadditional}', "");
Expect(1, 7936, '\p{^Is_Block=latinextendedadditional}', "");
Expect(1, 7936, '\P{Is_Block=latinextendedadditional}', "");
Expect(0, 7936, '\P{^Is_Block=latinextendedadditional}', "");
Expect(1, 7935, '\p{Is_Block= Latin_Extended_ADDITIONAL}', "");
Expect(0, 7935, '\p{^Is_Block= Latin_Extended_ADDITIONAL}', "");
Expect(0, 7935, '\P{Is_Block= Latin_Extended_ADDITIONAL}', "");
Expect(1, 7935, '\P{^Is_Block= Latin_Extended_ADDITIONAL}', "");
Expect(0, 7936, '\p{Is_Block= Latin_Extended_ADDITIONAL}', "");
Expect(1, 7936, '\p{^Is_Block= Latin_Extended_ADDITIONAL}', "");
Expect(1, 7936, '\P{Is_Block= Latin_Extended_ADDITIONAL}', "");
Expect(0, 7936, '\P{^Is_Block= Latin_Extended_ADDITIONAL}', "");
Error('\p{Is_Blk: 	Latin_Ext_additional:=}');
Error('\P{Is_Blk: 	Latin_Ext_additional:=}');
Expect(1, 7935, '\p{Is_Blk=latinextadditional}', "");
Expect(0, 7935, '\p{^Is_Blk=latinextadditional}', "");
Expect(0, 7935, '\P{Is_Blk=latinextadditional}', "");
Expect(1, 7935, '\P{^Is_Blk=latinextadditional}', "");
Expect(0, 7936, '\p{Is_Blk=latinextadditional}', "");
Expect(1, 7936, '\p{^Is_Blk=latinextadditional}', "");
Expect(1, 7936, '\P{Is_Blk=latinextadditional}', "");
Expect(0, 7936, '\P{^Is_Blk=latinextadditional}', "");
Expect(1, 7935, '\p{Is_Blk=	latin_Ext_Additional}', "");
Expect(0, 7935, '\p{^Is_Blk=	latin_Ext_Additional}', "");
Expect(0, 7935, '\P{Is_Blk=	latin_Ext_Additional}', "");
Expect(1, 7935, '\P{^Is_Blk=	latin_Ext_Additional}', "");
Expect(0, 7936, '\p{Is_Blk=	latin_Ext_Additional}', "");
Expect(1, 7936, '\p{^Is_Blk=	latin_Ext_Additional}', "");
Expect(1, 7936, '\P{Is_Blk=	latin_Ext_Additional}', "");
Expect(0, 7936, '\P{^Is_Blk=	latin_Ext_Additional}', "");
Error('\p{Block=	:=latin_Extended_b}');
Error('\P{Block=	:=latin_Extended_b}');
Expect(1, 591, '\p{Block=latinextendedb}', "");
Expect(0, 591, '\p{^Block=latinextendedb}', "");
Expect(0, 591, '\P{Block=latinextendedb}', "");
Expect(1, 591, '\P{^Block=latinextendedb}', "");
Expect(0, 592, '\p{Block=latinextendedb}', "");
Expect(1, 592, '\p{^Block=latinextendedb}', "");
Expect(1, 592, '\P{Block=latinextendedb}', "");
Expect(0, 592, '\P{^Block=latinextendedb}', "");
Expect(1, 591, '\p{Block=-	latin_extended_B}', "");
Expect(0, 591, '\p{^Block=-	latin_extended_B}', "");
Expect(0, 591, '\P{Block=-	latin_extended_B}', "");
Expect(1, 591, '\P{^Block=-	latin_extended_B}', "");
Expect(0, 592, '\p{Block=-	latin_extended_B}', "");
Expect(1, 592, '\p{^Block=-	latin_extended_B}', "");
Expect(1, 592, '\P{Block=-	latin_extended_B}', "");
Expect(0, 592, '\P{^Block=-	latin_extended_B}', "");
Error('\p{Blk=_/a/latin_Ext_B}');
Error('\P{Blk=_/a/latin_Ext_B}');
Expect(1, 591, '\p{Blk=latinextb}', "");
Expect(0, 591, '\p{^Blk=latinextb}', "");
Expect(0, 591, '\P{Blk=latinextb}', "");
Expect(1, 591, '\P{^Blk=latinextb}', "");
Expect(0, 592, '\p{Blk=latinextb}', "");
Expect(1, 592, '\p{^Blk=latinextb}', "");
Expect(1, 592, '\P{Blk=latinextb}', "");
Expect(0, 592, '\P{^Blk=latinextb}', "");
Expect(1, 591, '\p{Blk=_-Latin_Ext_B}', "");
Expect(0, 591, '\p{^Blk=_-Latin_Ext_B}', "");
Expect(0, 591, '\P{Blk=_-Latin_Ext_B}', "");
Expect(1, 591, '\P{^Blk=_-Latin_Ext_B}', "");
Expect(0, 592, '\p{Blk=_-Latin_Ext_B}', "");
Expect(1, 592, '\p{^Blk=_-Latin_Ext_B}', "");
Expect(1, 592, '\P{Blk=_-Latin_Ext_B}', "");
Expect(0, 592, '\P{^Blk=_-Latin_Ext_B}', "");
Error('\p{Is_Block= _latin_Extended_B/a/}');
Error('\P{Is_Block= _latin_Extended_B/a/}');
Expect(1, 591, '\p{Is_Block=latinextendedb}', "");
Expect(0, 591, '\p{^Is_Block=latinextendedb}', "");
Expect(0, 591, '\P{Is_Block=latinextendedb}', "");
Expect(1, 591, '\P{^Is_Block=latinextendedb}', "");
Expect(0, 592, '\p{Is_Block=latinextendedb}', "");
Expect(1, 592, '\p{^Is_Block=latinextendedb}', "");
Expect(1, 592, '\P{Is_Block=latinextendedb}', "");
Expect(0, 592, '\P{^Is_Block=latinextendedb}', "");
Expect(1, 591, '\p{Is_Block= 	Latin_extended_b}', "");
Expect(0, 591, '\p{^Is_Block= 	Latin_extended_b}', "");
Expect(0, 591, '\P{Is_Block= 	Latin_extended_b}', "");
Expect(1, 591, '\P{^Is_Block= 	Latin_extended_b}', "");
Expect(0, 592, '\p{Is_Block= 	Latin_extended_b}', "");
Expect(1, 592, '\p{^Is_Block= 	Latin_extended_b}', "");
Expect(1, 592, '\P{Is_Block= 	Latin_extended_b}', "");
Expect(0, 592, '\P{^Is_Block= 	Latin_extended_b}', "");
Error('\p{Is_Blk=/a/ latin_EXT_B}');
Error('\P{Is_Blk=/a/ latin_EXT_B}');
Expect(1, 591, '\p{Is_Blk=latinextb}', "");
Expect(0, 591, '\p{^Is_Blk=latinextb}', "");
Expect(0, 591, '\P{Is_Blk=latinextb}', "");
Expect(1, 591, '\P{^Is_Blk=latinextb}', "");
Expect(0, 592, '\p{Is_Blk=latinextb}', "");
Expect(1, 592, '\p{^Is_Blk=latinextb}', "");
Expect(1, 592, '\P{Is_Blk=latinextb}', "");
Expect(0, 592, '\P{^Is_Blk=latinextb}', "");
Expect(1, 591, '\p{Is_Blk=	Latin_EXT_b}', "");
Expect(0, 591, '\p{^Is_Blk=	Latin_EXT_b}', "");
Expect(0, 591, '\P{Is_Blk=	Latin_EXT_b}', "");
Expect(1, 591, '\P{^Is_Blk=	Latin_EXT_b}', "");
Expect(0, 592, '\p{Is_Blk=	Latin_EXT_b}', "");
Expect(1, 592, '\p{^Is_Blk=	Latin_EXT_b}', "");
Expect(1, 592, '\P{Is_Blk=	Latin_EXT_b}', "");
Expect(0, 592, '\P{^Is_Blk=	Latin_EXT_b}', "");
Error('\p{Block=-_Latin_EXTENDED_c:=}');
Error('\P{Block=-_Latin_EXTENDED_c:=}');
Expect(1, 11391, '\p{Block=latinextendedc}', "");
Expect(0, 11391, '\p{^Block=latinextendedc}', "");
Expect(0, 11391, '\P{Block=latinextendedc}', "");
Expect(1, 11391, '\P{^Block=latinextendedc}', "");
Expect(0, 11392, '\p{Block=latinextendedc}', "");
Expect(1, 11392, '\p{^Block=latinextendedc}', "");
Expect(1, 11392, '\P{Block=latinextendedc}', "");
Expect(0, 11392, '\P{^Block=latinextendedc}', "");
Expect(1, 11391, '\p{Block=--Latin_Extended_C}', "");
Expect(0, 11391, '\p{^Block=--Latin_Extended_C}', "");
Expect(0, 11391, '\P{Block=--Latin_Extended_C}', "");
Expect(1, 11391, '\P{^Block=--Latin_Extended_C}', "");
Expect(0, 11392, '\p{Block=--Latin_Extended_C}', "");
Expect(1, 11392, '\p{^Block=--Latin_Extended_C}', "");
Expect(1, 11392, '\P{Block=--Latin_Extended_C}', "");
Expect(0, 11392, '\P{^Block=--Latin_Extended_C}', "");
Error('\p{Blk=_-latin_Ext_C/a/}');
Error('\P{Blk=_-latin_Ext_C/a/}');
Expect(1, 11391, '\p{Blk=latinextc}', "");
Expect(0, 11391, '\p{^Blk=latinextc}', "");
Expect(0, 11391, '\P{Blk=latinextc}', "");
Expect(1, 11391, '\P{^Blk=latinextc}', "");
Expect(0, 11392, '\p{Blk=latinextc}', "");
Expect(1, 11392, '\p{^Blk=latinextc}', "");
Expect(1, 11392, '\P{Blk=latinextc}', "");
Expect(0, 11392, '\P{^Blk=latinextc}', "");
Expect(1, 11391, '\p{Blk=__Latin_Ext_c}', "");
Expect(0, 11391, '\p{^Blk=__Latin_Ext_c}', "");
Expect(0, 11391, '\P{Blk=__Latin_Ext_c}', "");
Expect(1, 11391, '\P{^Blk=__Latin_Ext_c}', "");
Expect(0, 11392, '\p{Blk=__Latin_Ext_c}', "");
Expect(1, 11392, '\p{^Blk=__Latin_Ext_c}', "");
Expect(1, 11392, '\P{Blk=__Latin_Ext_c}', "");
Expect(0, 11392, '\P{^Blk=__Latin_Ext_c}', "");
Error('\p{Is_Block=/a/latin_Extended_C}');
Error('\P{Is_Block=/a/latin_Extended_C}');
Expect(1, 11391, '\p{Is_Block=latinextendedc}', "");
Expect(0, 11391, '\p{^Is_Block=latinextendedc}', "");
Expect(0, 11391, '\P{Is_Block=latinextendedc}', "");
Expect(1, 11391, '\P{^Is_Block=latinextendedc}', "");
Expect(0, 11392, '\p{Is_Block=latinextendedc}', "");
Expect(1, 11392, '\p{^Is_Block=latinextendedc}', "");
Expect(1, 11392, '\P{Is_Block=latinextendedc}', "");
Expect(0, 11392, '\P{^Is_Block=latinextendedc}', "");
Expect(1, 11391, '\p{Is_Block= latin_extended_c}', "");
Expect(0, 11391, '\p{^Is_Block= latin_extended_c}', "");
Expect(0, 11391, '\P{Is_Block= latin_extended_c}', "");
Expect(1, 11391, '\P{^Is_Block= latin_extended_c}', "");
Expect(0, 11392, '\p{Is_Block= latin_extended_c}', "");
Expect(1, 11392, '\p{^Is_Block= latin_extended_c}', "");
Expect(1, 11392, '\P{Is_Block= latin_extended_c}', "");
Expect(0, 11392, '\P{^Is_Block= latin_extended_c}', "");
Error('\p{Is_Blk=/a/ -latin_Ext_C}');
Error('\P{Is_Blk=/a/ -latin_Ext_C}');
Expect(1, 11391, '\p{Is_Blk=latinextc}', "");
Expect(0, 11391, '\p{^Is_Blk=latinextc}', "");
Expect(0, 11391, '\P{Is_Blk=latinextc}', "");
Expect(1, 11391, '\P{^Is_Blk=latinextc}', "");
Expect(0, 11392, '\p{Is_Blk=latinextc}', "");
Expect(1, 11392, '\p{^Is_Blk=latinextc}', "");
Expect(1, 11392, '\P{Is_Blk=latinextc}', "");
Expect(0, 11392, '\P{^Is_Blk=latinextc}', "");
Expect(1, 11391, '\p{Is_Blk=_Latin_Ext_C}', "");
Expect(0, 11391, '\p{^Is_Blk=_Latin_Ext_C}', "");
Expect(0, 11391, '\P{Is_Blk=_Latin_Ext_C}', "");
Expect(1, 11391, '\P{^Is_Blk=_Latin_Ext_C}', "");
Expect(0, 11392, '\p{Is_Blk=_Latin_Ext_C}', "");
Expect(1, 11392, '\p{^Is_Blk=_Latin_Ext_C}', "");
Expect(1, 11392, '\P{Is_Blk=_Latin_Ext_C}', "");
Expect(0, 11392, '\P{^Is_Blk=_Latin_Ext_C}', "");
Error('\p{Block=:=- LATIN_Extended_D}');
Error('\P{Block=:=- LATIN_Extended_D}');
Expect(1, 43007, '\p{Block:   latinextendedd}', "");
Expect(0, 43007, '\p{^Block:   latinextendedd}', "");
Expect(0, 43007, '\P{Block:   latinextendedd}', "");
Expect(1, 43007, '\P{^Block:   latinextendedd}', "");
Expect(0, 43008, '\p{Block:   latinextendedd}', "");
Expect(1, 43008, '\p{^Block:   latinextendedd}', "");
Expect(1, 43008, '\P{Block:   latinextendedd}', "");
Expect(0, 43008, '\P{^Block:   latinextendedd}', "");
Expect(1, 43007, '\p{Block=_-Latin_extended_D}', "");
Expect(0, 43007, '\p{^Block=_-Latin_extended_D}', "");
Expect(0, 43007, '\P{Block=_-Latin_extended_D}', "");
Expect(1, 43007, '\P{^Block=_-Latin_extended_D}', "");
Expect(0, 43008, '\p{Block=_-Latin_extended_D}', "");
Expect(1, 43008, '\p{^Block=_-Latin_extended_D}', "");
Expect(1, 43008, '\P{Block=_-Latin_extended_D}', "");
Expect(0, 43008, '\P{^Block=_-Latin_extended_D}', "");
Error('\p{Blk=-/a/latin_Ext_D}');
Error('\P{Blk=-/a/latin_Ext_D}');
Expect(1, 43007, '\p{Blk=latinextd}', "");
Expect(0, 43007, '\p{^Blk=latinextd}', "");
Expect(0, 43007, '\P{Blk=latinextd}', "");
Expect(1, 43007, '\P{^Blk=latinextd}', "");
Expect(0, 43008, '\p{Blk=latinextd}', "");
Expect(1, 43008, '\p{^Blk=latinextd}', "");
Expect(1, 43008, '\P{Blk=latinextd}', "");
Expect(0, 43008, '\P{^Blk=latinextd}', "");
Expect(1, 43007, '\p{Blk=- latin_Ext_D}', "");
Expect(0, 43007, '\p{^Blk=- latin_Ext_D}', "");
Expect(0, 43007, '\P{Blk=- latin_Ext_D}', "");
Expect(1, 43007, '\P{^Blk=- latin_Ext_D}', "");
Expect(0, 43008, '\p{Blk=- latin_Ext_D}', "");
Expect(1, 43008, '\p{^Blk=- latin_Ext_D}', "");
Expect(1, 43008, '\P{Blk=- latin_Ext_D}', "");
Expect(0, 43008, '\P{^Blk=- latin_Ext_D}', "");
Error('\p{Is_Block=/a/ Latin_EXTENDED_D}');
Error('\P{Is_Block=/a/ Latin_EXTENDED_D}');
Expect(1, 43007, '\p{Is_Block=latinextendedd}', "");
Expect(0, 43007, '\p{^Is_Block=latinextendedd}', "");
Expect(0, 43007, '\P{Is_Block=latinextendedd}', "");
Expect(1, 43007, '\P{^Is_Block=latinextendedd}', "");
Expect(0, 43008, '\p{Is_Block=latinextendedd}', "");
Expect(1, 43008, '\p{^Is_Block=latinextendedd}', "");
Expect(1, 43008, '\P{Is_Block=latinextendedd}', "");
Expect(0, 43008, '\P{^Is_Block=latinextendedd}', "");
Expect(1, 43007, '\p{Is_Block=	_LATIN_EXTENDED_D}', "");
Expect(0, 43007, '\p{^Is_Block=	_LATIN_EXTENDED_D}', "");
Expect(0, 43007, '\P{Is_Block=	_LATIN_EXTENDED_D}', "");
Expect(1, 43007, '\P{^Is_Block=	_LATIN_EXTENDED_D}', "");
Expect(0, 43008, '\p{Is_Block=	_LATIN_EXTENDED_D}', "");
Expect(1, 43008, '\p{^Is_Block=	_LATIN_EXTENDED_D}', "");
Expect(1, 43008, '\P{Is_Block=	_LATIN_EXTENDED_D}', "");
Expect(0, 43008, '\P{^Is_Block=	_LATIN_EXTENDED_D}', "");
Error('\p{Is_Blk:/a/latin_Ext_D}');
Error('\P{Is_Blk:/a/latin_Ext_D}');
Expect(1, 43007, '\p{Is_Blk=latinextd}', "");
Expect(0, 43007, '\p{^Is_Blk=latinextd}', "");
Expect(0, 43007, '\P{Is_Blk=latinextd}', "");
Expect(1, 43007, '\P{^Is_Blk=latinextd}', "");
Expect(0, 43008, '\p{Is_Blk=latinextd}', "");
Expect(1, 43008, '\p{^Is_Blk=latinextd}', "");
Expect(1, 43008, '\P{Is_Blk=latinextd}', "");
Expect(0, 43008, '\P{^Is_Blk=latinextd}', "");
Expect(1, 43007, '\p{Is_Blk= 	Latin_Ext_D}', "");
Expect(0, 43007, '\p{^Is_Blk= 	Latin_Ext_D}', "");
Expect(0, 43007, '\P{Is_Blk= 	Latin_Ext_D}', "");
Expect(1, 43007, '\P{^Is_Blk= 	Latin_Ext_D}', "");
Expect(0, 43008, '\p{Is_Blk= 	Latin_Ext_D}', "");
Expect(1, 43008, '\p{^Is_Blk= 	Latin_Ext_D}', "");
Expect(1, 43008, '\P{Is_Blk= 	Latin_Ext_D}', "");
Expect(0, 43008, '\P{^Is_Blk= 	Latin_Ext_D}', "");
Error('\p{Block=/a/_-lepcha}');
Error('\P{Block=/a/_-lepcha}');
Expect(1, 7247, '\p{Block=lepcha}', "");
Expect(0, 7247, '\p{^Block=lepcha}', "");
Expect(0, 7247, '\P{Block=lepcha}', "");
Expect(1, 7247, '\P{^Block=lepcha}', "");
Expect(0, 7248, '\p{Block=lepcha}', "");
Expect(1, 7248, '\p{^Block=lepcha}', "");
Expect(1, 7248, '\P{Block=lepcha}', "");
Expect(0, 7248, '\P{^Block=lepcha}', "");
Expect(1, 7247, '\p{Block=_Lepcha}', "");
Expect(0, 7247, '\p{^Block=_Lepcha}', "");
Expect(0, 7247, '\P{Block=_Lepcha}', "");
Expect(1, 7247, '\P{^Block=_Lepcha}', "");
Expect(0, 7248, '\p{Block=_Lepcha}', "");
Expect(1, 7248, '\p{^Block=_Lepcha}', "");
Expect(1, 7248, '\P{Block=_Lepcha}', "");
Expect(0, 7248, '\P{^Block=_Lepcha}', "");
Error('\p{Blk= Lepcha:=}');
Error('\P{Blk= Lepcha:=}');
Expect(1, 7247, '\p{Blk=lepcha}', "");
Expect(0, 7247, '\p{^Blk=lepcha}', "");
Expect(0, 7247, '\P{Blk=lepcha}', "");
Expect(1, 7247, '\P{^Blk=lepcha}', "");
Expect(0, 7248, '\p{Blk=lepcha}', "");
Expect(1, 7248, '\p{^Blk=lepcha}', "");
Expect(1, 7248, '\P{Blk=lepcha}', "");
Expect(0, 7248, '\P{^Blk=lepcha}', "");
Expect(1, 7247, '\p{Blk=-lepcha}', "");
Expect(0, 7247, '\p{^Blk=-lepcha}', "");
Expect(0, 7247, '\P{Blk=-lepcha}', "");
Expect(1, 7247, '\P{^Blk=-lepcha}', "");
Expect(0, 7248, '\p{Blk=-lepcha}', "");
Expect(1, 7248, '\p{^Blk=-lepcha}', "");
Expect(1, 7248, '\P{Blk=-lepcha}', "");
Expect(0, 7248, '\P{^Blk=-lepcha}', "");
Error('\p{Is_Block=/a/ Lepcha}');
Error('\P{Is_Block=/a/ Lepcha}');
Expect(1, 7247, '\p{Is_Block=lepcha}', "");
Expect(0, 7247, '\p{^Is_Block=lepcha}', "");
Expect(0, 7247, '\P{Is_Block=lepcha}', "");
Expect(1, 7247, '\P{^Is_Block=lepcha}', "");
Expect(0, 7248, '\p{Is_Block=lepcha}', "");
Expect(1, 7248, '\p{^Is_Block=lepcha}', "");
Expect(1, 7248, '\P{Is_Block=lepcha}', "");
Expect(0, 7248, '\P{^Is_Block=lepcha}', "");
Expect(1, 7247, '\p{Is_Block: -Lepcha}', "");
Expect(0, 7247, '\p{^Is_Block: -Lepcha}', "");
Expect(0, 7247, '\P{Is_Block: -Lepcha}', "");
Expect(1, 7247, '\P{^Is_Block: -Lepcha}', "");
Expect(0, 7248, '\p{Is_Block: -Lepcha}', "");
Expect(1, 7248, '\p{^Is_Block: -Lepcha}', "");
Expect(1, 7248, '\P{Is_Block: -Lepcha}', "");
Expect(0, 7248, '\P{^Is_Block: -Lepcha}', "");
Error('\p{Is_Blk=/a/_-lepcha}');
Error('\P{Is_Blk=/a/_-lepcha}');
Expect(1, 7247, '\p{Is_Blk=lepcha}', "");
Expect(0, 7247, '\p{^Is_Blk=lepcha}', "");
Expect(0, 7247, '\P{Is_Blk=lepcha}', "");
Expect(1, 7247, '\P{^Is_Blk=lepcha}', "");
Expect(0, 7248, '\p{Is_Blk=lepcha}', "");
Expect(1, 7248, '\p{^Is_Blk=lepcha}', "");
Expect(1, 7248, '\P{Is_Blk=lepcha}', "");
Expect(0, 7248, '\P{^Is_Blk=lepcha}', "");
Expect(1, 7247, '\p{Is_Blk= lepcha}', "");
Expect(0, 7247, '\p{^Is_Blk= lepcha}', "");
Expect(0, 7247, '\P{Is_Blk= lepcha}', "");
Expect(1, 7247, '\P{^Is_Blk= lepcha}', "");
Expect(0, 7248, '\p{Is_Blk= lepcha}', "");
Expect(1, 7248, '\p{^Is_Blk= lepcha}', "");
Expect(1, 7248, '\P{Is_Blk= lepcha}', "");
Expect(0, 7248, '\P{^Is_Blk= lepcha}', "");
Error('\p{Block:/a/LETTERLIKE_SYMBOLS}');
Error('\P{Block:/a/LETTERLIKE_SYMBOLS}');
Expect(1, 8527, '\p{Block=letterlikesymbols}', "");
Expect(0, 8527, '\p{^Block=letterlikesymbols}', "");
Expect(0, 8527, '\P{Block=letterlikesymbols}', "");
Expect(1, 8527, '\P{^Block=letterlikesymbols}', "");
Expect(0, 8528, '\p{Block=letterlikesymbols}', "");
Expect(1, 8528, '\p{^Block=letterlikesymbols}', "");
Expect(1, 8528, '\P{Block=letterlikesymbols}', "");
Expect(0, 8528, '\P{^Block=letterlikesymbols}', "");
Expect(1, 8527, '\p{Block:   -_Letterlike_Symbols}', "");
Expect(0, 8527, '\p{^Block:   -_Letterlike_Symbols}', "");
Expect(0, 8527, '\P{Block:   -_Letterlike_Symbols}', "");
Expect(1, 8527, '\P{^Block:   -_Letterlike_Symbols}', "");
Expect(0, 8528, '\p{Block:   -_Letterlike_Symbols}', "");
Expect(1, 8528, '\p{^Block:   -_Letterlike_Symbols}', "");
Expect(1, 8528, '\P{Block:   -_Letterlike_Symbols}', "");
Expect(0, 8528, '\P{^Block:   -_Letterlike_Symbols}', "");
Error('\p{Blk=:=- LETTERLIKE_Symbols}');
Error('\P{Blk=:=- LETTERLIKE_Symbols}');
Expect(1, 8527, '\p{Blk=letterlikesymbols}', "");
Expect(0, 8527, '\p{^Blk=letterlikesymbols}', "");
Expect(0, 8527, '\P{Blk=letterlikesymbols}', "");
Expect(1, 8527, '\P{^Blk=letterlikesymbols}', "");
Expect(0, 8528, '\p{Blk=letterlikesymbols}', "");
Expect(1, 8528, '\p{^Blk=letterlikesymbols}', "");
Expect(1, 8528, '\P{Blk=letterlikesymbols}', "");
Expect(0, 8528, '\P{^Blk=letterlikesymbols}', "");
Expect(1, 8527, '\p{Blk=	-letterlike_Symbols}', "");
Expect(0, 8527, '\p{^Blk=	-letterlike_Symbols}', "");
Expect(0, 8527, '\P{Blk=	-letterlike_Symbols}', "");
Expect(1, 8527, '\P{^Blk=	-letterlike_Symbols}', "");
Expect(0, 8528, '\p{Blk=	-letterlike_Symbols}', "");
Expect(1, 8528, '\p{^Blk=	-letterlike_Symbols}', "");
Expect(1, 8528, '\P{Blk=	-letterlike_Symbols}', "");
Expect(0, 8528, '\P{^Blk=	-letterlike_Symbols}', "");
Error('\p{Is_Block:   _:=letterlike_symbols}');
Error('\P{Is_Block:   _:=letterlike_symbols}');
Expect(1, 8527, '\p{Is_Block=letterlikesymbols}', "");
Expect(0, 8527, '\p{^Is_Block=letterlikesymbols}', "");
Expect(0, 8527, '\P{Is_Block=letterlikesymbols}', "");
Expect(1, 8527, '\P{^Is_Block=letterlikesymbols}', "");
Expect(0, 8528, '\p{Is_Block=letterlikesymbols}', "");
Expect(1, 8528, '\p{^Is_Block=letterlikesymbols}', "");
Expect(1, 8528, '\P{Is_Block=letterlikesymbols}', "");
Expect(0, 8528, '\P{^Is_Block=letterlikesymbols}', "");
Expect(1, 8527, '\p{Is_Block=__Letterlike_SYMBOLS}', "");
Expect(0, 8527, '\p{^Is_Block=__Letterlike_SYMBOLS}', "");
Expect(0, 8527, '\P{Is_Block=__Letterlike_SYMBOLS}', "");
Expect(1, 8527, '\P{^Is_Block=__Letterlike_SYMBOLS}', "");
Expect(0, 8528, '\p{Is_Block=__Letterlike_SYMBOLS}', "");
Expect(1, 8528, '\p{^Is_Block=__Letterlike_SYMBOLS}', "");
Expect(1, 8528, '\P{Is_Block=__Letterlike_SYMBOLS}', "");
Expect(0, 8528, '\P{^Is_Block=__Letterlike_SYMBOLS}', "");
Error('\p{Is_Blk=/a/-	LETTERLIKE_Symbols}');
Error('\P{Is_Blk=/a/-	LETTERLIKE_Symbols}');
Expect(1, 8527, '\p{Is_Blk=letterlikesymbols}', "");
Expect(0, 8527, '\p{^Is_Blk=letterlikesymbols}', "");
Expect(0, 8527, '\P{Is_Blk=letterlikesymbols}', "");
Expect(1, 8527, '\P{^Is_Blk=letterlikesymbols}', "");
Expect(0, 8528, '\p{Is_Blk=letterlikesymbols}', "");
Expect(1, 8528, '\p{^Is_Blk=letterlikesymbols}', "");
Expect(1, 8528, '\P{Is_Blk=letterlikesymbols}', "");
Expect(0, 8528, '\P{^Is_Blk=letterlikesymbols}', "");
Expect(1, 8527, '\p{Is_Blk= 	Letterlike_symbols}', "");
Expect(0, 8527, '\p{^Is_Blk= 	Letterlike_symbols}', "");
Expect(0, 8527, '\P{Is_Blk= 	Letterlike_symbols}', "");
Expect(1, 8527, '\P{^Is_Blk= 	Letterlike_symbols}', "");
Expect(0, 8528, '\p{Is_Blk= 	Letterlike_symbols}', "");
Expect(1, 8528, '\p{^Is_Blk= 	Letterlike_symbols}', "");
Expect(1, 8528, '\P{Is_Blk= 	Letterlike_symbols}', "");
Expect(0, 8528, '\P{^Is_Blk= 	Letterlike_symbols}', "");
Error('\p{Block=_LIMBU/a/}');
Error('\P{Block=_LIMBU/a/}');
Expect(1, 6479, '\p{Block=limbu}', "");
Expect(0, 6479, '\p{^Block=limbu}', "");
Expect(0, 6479, '\P{Block=limbu}', "");
Expect(1, 6479, '\P{^Block=limbu}', "");
Expect(0, 6480, '\p{Block=limbu}', "");
Expect(1, 6480, '\p{^Block=limbu}', "");
Expect(1, 6480, '\P{Block=limbu}', "");
Expect(0, 6480, '\P{^Block=limbu}', "");
Expect(1, 6479, '\p{Block=	 Limbu}', "");
Expect(0, 6479, '\p{^Block=	 Limbu}', "");
Expect(0, 6479, '\P{Block=	 Limbu}', "");
Expect(1, 6479, '\P{^Block=	 Limbu}', "");
Expect(0, 6480, '\p{Block=	 Limbu}', "");
Expect(1, 6480, '\p{^Block=	 Limbu}', "");
Expect(1, 6480, '\P{Block=	 Limbu}', "");
Expect(0, 6480, '\P{^Block=	 Limbu}', "");
Error('\p{Blk=/a/_limbu}');
Error('\P{Blk=/a/_limbu}');
Expect(1, 6479, '\p{Blk=limbu}', "");
Expect(0, 6479, '\p{^Blk=limbu}', "");
Expect(0, 6479, '\P{Blk=limbu}', "");
Expect(1, 6479, '\P{^Blk=limbu}', "");
Expect(0, 6480, '\p{Blk=limbu}', "");
Expect(1, 6480, '\p{^Blk=limbu}', "");
Expect(1, 6480, '\P{Blk=limbu}', "");
Expect(0, 6480, '\P{^Blk=limbu}', "");
Expect(1, 6479, '\p{Blk=	limbu}', "");
Expect(0, 6479, '\p{^Blk=	limbu}', "");
Expect(0, 6479, '\P{Blk=	limbu}', "");
Expect(1, 6479, '\P{^Blk=	limbu}', "");
Expect(0, 6480, '\p{Blk=	limbu}', "");
Expect(1, 6480, '\p{^Blk=	limbu}', "");
Expect(1, 6480, '\P{Blk=	limbu}', "");
Expect(0, 6480, '\P{^Blk=	limbu}', "");
Error('\p{Is_Block:   /a/--LIMBU}');
Error('\P{Is_Block:   /a/--LIMBU}');
Expect(1, 6479, '\p{Is_Block=limbu}', "");
Expect(0, 6479, '\p{^Is_Block=limbu}', "");
Expect(0, 6479, '\P{Is_Block=limbu}', "");
Expect(1, 6479, '\P{^Is_Block=limbu}', "");
Expect(0, 6480, '\p{Is_Block=limbu}', "");
Expect(1, 6480, '\p{^Is_Block=limbu}', "");
Expect(1, 6480, '\P{Is_Block=limbu}', "");
Expect(0, 6480, '\P{^Is_Block=limbu}', "");
Expect(1, 6479, '\p{Is_Block=	_limbu}', "");
Expect(0, 6479, '\p{^Is_Block=	_limbu}', "");
Expect(0, 6479, '\P{Is_Block=	_limbu}', "");
Expect(1, 6479, '\P{^Is_Block=	_limbu}', "");
Expect(0, 6480, '\p{Is_Block=	_limbu}', "");
Expect(1, 6480, '\p{^Is_Block=	_limbu}', "");
Expect(1, 6480, '\P{Is_Block=	_limbu}', "");
Expect(0, 6480, '\P{^Is_Block=	_limbu}', "");
Error('\p{Is_Blk=:=  Limbu}');
Error('\P{Is_Blk=:=  Limbu}');
Expect(1, 6479, '\p{Is_Blk=limbu}', "");
Expect(0, 6479, '\p{^Is_Blk=limbu}', "");
Expect(0, 6479, '\P{Is_Blk=limbu}', "");
Expect(1, 6479, '\P{^Is_Blk=limbu}', "");
Expect(0, 6480, '\p{Is_Blk=limbu}', "");
Expect(1, 6480, '\p{^Is_Blk=limbu}', "");
Expect(1, 6480, '\P{Is_Blk=limbu}', "");
Expect(0, 6480, '\P{^Is_Blk=limbu}', "");
Expect(1, 6479, '\p{Is_Blk=		Limbu}', "");
Expect(0, 6479, '\p{^Is_Blk=		Limbu}', "");
Expect(0, 6479, '\P{Is_Blk=		Limbu}', "");
Expect(1, 6479, '\P{^Is_Blk=		Limbu}', "");
Expect(0, 6480, '\p{Is_Blk=		Limbu}', "");
Expect(1, 6480, '\p{^Is_Blk=		Limbu}', "");
Expect(1, 6480, '\P{Is_Blk=		Limbu}', "");
Expect(0, 6480, '\P{^Is_Blk=		Limbu}', "");
Error('\p{Block=/a/_	linear_B_Ideograms}');
Error('\P{Block=/a/_	linear_B_Ideograms}');
Expect(1, 65791, '\p{Block=linearbideograms}', "");
Expect(0, 65791, '\p{^Block=linearbideograms}', "");
Expect(0, 65791, '\P{Block=linearbideograms}', "");
Expect(1, 65791, '\P{^Block=linearbideograms}', "");
Expect(0, 65792, '\p{Block=linearbideograms}', "");
Expect(1, 65792, '\p{^Block=linearbideograms}', "");
Expect(1, 65792, '\P{Block=linearbideograms}', "");
Expect(0, 65792, '\P{^Block=linearbideograms}', "");
Expect(1, 65791, '\p{Block=--Linear_B_Ideograms}', "");
Expect(0, 65791, '\p{^Block=--Linear_B_Ideograms}', "");
Expect(0, 65791, '\P{Block=--Linear_B_Ideograms}', "");
Expect(1, 65791, '\P{^Block=--Linear_B_Ideograms}', "");
Expect(0, 65792, '\p{Block=--Linear_B_Ideograms}', "");
Expect(1, 65792, '\p{^Block=--Linear_B_Ideograms}', "");
Expect(1, 65792, '\P{Block=--Linear_B_Ideograms}', "");
Expect(0, 65792, '\P{^Block=--Linear_B_Ideograms}', "");
Error('\p{Blk=-:=linear_B_Ideograms}');
Error('\P{Blk=-:=linear_B_Ideograms}');
Expect(1, 65791, '\p{Blk=linearbideograms}', "");
Expect(0, 65791, '\p{^Blk=linearbideograms}', "");
Expect(0, 65791, '\P{Blk=linearbideograms}', "");
Expect(1, 65791, '\P{^Blk=linearbideograms}', "");
Expect(0, 65792, '\p{Blk=linearbideograms}', "");
Expect(1, 65792, '\p{^Blk=linearbideograms}', "");
Expect(1, 65792, '\P{Blk=linearbideograms}', "");
Expect(0, 65792, '\P{^Blk=linearbideograms}', "");
Expect(1, 65791, '\p{Blk=_	LINEAR_B_Ideograms}', "");
Expect(0, 65791, '\p{^Blk=_	LINEAR_B_Ideograms}', "");
Expect(0, 65791, '\P{Blk=_	LINEAR_B_Ideograms}', "");
Expect(1, 65791, '\P{^Blk=_	LINEAR_B_Ideograms}', "");
Expect(0, 65792, '\p{Blk=_	LINEAR_B_Ideograms}', "");
Expect(1, 65792, '\p{^Blk=_	LINEAR_B_Ideograms}', "");
Expect(1, 65792, '\P{Blk=_	LINEAR_B_Ideograms}', "");
Expect(0, 65792, '\P{^Blk=_	LINEAR_B_Ideograms}', "");
Error('\p{Is_Block= :=Linear_B_ideograms}');
Error('\P{Is_Block= :=Linear_B_ideograms}');
Expect(1, 65791, '\p{Is_Block:	linearbideograms}', "");
Expect(0, 65791, '\p{^Is_Block:	linearbideograms}', "");
Expect(0, 65791, '\P{Is_Block:	linearbideograms}', "");
Expect(1, 65791, '\P{^Is_Block:	linearbideograms}', "");
Expect(0, 65792, '\p{Is_Block:	linearbideograms}', "");
Expect(1, 65792, '\p{^Is_Block:	linearbideograms}', "");
Expect(1, 65792, '\P{Is_Block:	linearbideograms}', "");
Expect(0, 65792, '\P{^Is_Block:	linearbideograms}', "");
Expect(1, 65791, '\p{Is_Block= -LINEAR_B_IDEOGRAMS}', "");
Expect(0, 65791, '\p{^Is_Block= -LINEAR_B_IDEOGRAMS}', "");
Expect(0, 65791, '\P{Is_Block= -LINEAR_B_IDEOGRAMS}', "");
Expect(1, 65791, '\P{^Is_Block= -LINEAR_B_IDEOGRAMS}', "");
Expect(0, 65792, '\p{Is_Block= -LINEAR_B_IDEOGRAMS}', "");
Expect(1, 65792, '\p{^Is_Block= -LINEAR_B_IDEOGRAMS}', "");
Expect(1, 65792, '\P{Is_Block= -LINEAR_B_IDEOGRAMS}', "");
Expect(0, 65792, '\P{^Is_Block= -LINEAR_B_IDEOGRAMS}', "");
Error('\p{Is_Blk=_ Linear_B_Ideograms:=}');
Error('\P{Is_Blk=_ Linear_B_Ideograms:=}');
Expect(1, 65791, '\p{Is_Blk=linearbideograms}', "");
Expect(0, 65791, '\p{^Is_Blk=linearbideograms}', "");
Expect(0, 65791, '\P{Is_Blk=linearbideograms}', "");
Expect(1, 65791, '\P{^Is_Blk=linearbideograms}', "");
Expect(0, 65792, '\p{Is_Blk=linearbideograms}', "");
Expect(1, 65792, '\p{^Is_Blk=linearbideograms}', "");
Expect(1, 65792, '\P{Is_Blk=linearbideograms}', "");
Expect(0, 65792, '\P{^Is_Blk=linearbideograms}', "");
Expect(1, 65791, '\p{Is_Blk:-_Linear_B_Ideograms}', "");
Expect(0, 65791, '\p{^Is_Blk:-_Linear_B_Ideograms}', "");
Expect(0, 65791, '\P{Is_Blk:-_Linear_B_Ideograms}', "");
Expect(1, 65791, '\P{^Is_Blk:-_Linear_B_Ideograms}', "");
Expect(0, 65792, '\p{Is_Blk:-_Linear_B_Ideograms}', "");
Expect(1, 65792, '\p{^Is_Blk:-_Linear_B_Ideograms}', "");
Expect(1, 65792, '\P{Is_Blk:-_Linear_B_Ideograms}', "");
Expect(0, 65792, '\P{^Is_Blk:-_Linear_B_Ideograms}', "");
Error('\p{Block=_	linear_b_Syllabary:=}');
Error('\P{Block=_	linear_b_Syllabary:=}');
Expect(1, 65663, '\p{Block=linearbsyllabary}', "");
Expect(0, 65663, '\p{^Block=linearbsyllabary}', "");
Expect(0, 65663, '\P{Block=linearbsyllabary}', "");
Expect(1, 65663, '\P{^Block=linearbsyllabary}', "");
Expect(0, 65664, '\p{Block=linearbsyllabary}', "");
Expect(1, 65664, '\p{^Block=linearbsyllabary}', "");
Expect(1, 65664, '\P{Block=linearbsyllabary}', "");
Expect(0, 65664, '\P{^Block=linearbsyllabary}', "");
Expect(1, 65663, '\p{Block= -LINEAR_B_syllabary}', "");
Expect(0, 65663, '\p{^Block= -LINEAR_B_syllabary}', "");
Expect(0, 65663, '\P{Block= -LINEAR_B_syllabary}', "");
Expect(1, 65663, '\P{^Block= -LINEAR_B_syllabary}', "");
Expect(0, 65664, '\p{Block= -LINEAR_B_syllabary}', "");
Expect(1, 65664, '\p{^Block= -LINEAR_B_syllabary}', "");
Expect(1, 65664, '\P{Block= -LINEAR_B_syllabary}', "");
Expect(0, 65664, '\P{^Block= -LINEAR_B_syllabary}', "");
Error('\p{Blk=/a/ Linear_b_SYLLABARY}');
Error('\P{Blk=/a/ Linear_b_SYLLABARY}');
Expect(1, 65663, '\p{Blk=linearbsyllabary}', "");
Expect(0, 65663, '\p{^Blk=linearbsyllabary}', "");
Expect(0, 65663, '\P{Blk=linearbsyllabary}', "");
Expect(1, 65663, '\P{^Blk=linearbsyllabary}', "");
Expect(0, 65664, '\p{Blk=linearbsyllabary}', "");
Expect(1, 65664, '\p{^Blk=linearbsyllabary}', "");
Expect(1, 65664, '\P{Blk=linearbsyllabary}', "");
Expect(0, 65664, '\P{^Blk=linearbsyllabary}', "");
Expect(1, 65663, '\p{Blk=_Linear_B_syllabary}', "");
Expect(0, 65663, '\p{^Blk=_Linear_B_syllabary}', "");
Expect(0, 65663, '\P{Blk=_Linear_B_syllabary}', "");
Expect(1, 65663, '\P{^Blk=_Linear_B_syllabary}', "");
Expect(0, 65664, '\p{Blk=_Linear_B_syllabary}', "");
Expect(1, 65664, '\p{^Blk=_Linear_B_syllabary}', "");
Expect(1, 65664, '\P{Blk=_Linear_B_syllabary}', "");
Expect(0, 65664, '\P{^Blk=_Linear_B_syllabary}', "");
Error('\p{Is_Block=/a/		Linear_b_syllabary}');
Error('\P{Is_Block=/a/		Linear_b_syllabary}');
Expect(1, 65663, '\p{Is_Block=linearbsyllabary}', "");
Expect(0, 65663, '\p{^Is_Block=linearbsyllabary}', "");
Expect(0, 65663, '\P{Is_Block=linearbsyllabary}', "");
Expect(1, 65663, '\P{^Is_Block=linearbsyllabary}', "");
Expect(0, 65664, '\p{Is_Block=linearbsyllabary}', "");
Expect(1, 65664, '\p{^Is_Block=linearbsyllabary}', "");
Expect(1, 65664, '\P{Is_Block=linearbsyllabary}', "");
Expect(0, 65664, '\P{^Is_Block=linearbsyllabary}', "");
Expect(1, 65663, '\p{Is_Block=	 linear_B_SYLLABARY}', "");
Expect(0, 65663, '\p{^Is_Block=	 linear_B_SYLLABARY}', "");
Expect(0, 65663, '\P{Is_Block=	 linear_B_SYLLABARY}', "");
Expect(1, 65663, '\P{^Is_Block=	 linear_B_SYLLABARY}', "");
Expect(0, 65664, '\p{Is_Block=	 linear_B_SYLLABARY}', "");
Expect(1, 65664, '\p{^Is_Block=	 linear_B_SYLLABARY}', "");
Expect(1, 65664, '\P{Is_Block=	 linear_B_SYLLABARY}', "");
Expect(0, 65664, '\P{^Is_Block=	 linear_B_SYLLABARY}', "");
Error('\p{Is_Blk=_ Linear_B_Syllabary/a/}');
Error('\P{Is_Blk=_ Linear_B_Syllabary/a/}');
Expect(1, 65663, '\p{Is_Blk=linearbsyllabary}', "");
Expect(0, 65663, '\p{^Is_Blk=linearbsyllabary}', "");
Expect(0, 65663, '\P{Is_Blk=linearbsyllabary}', "");
Expect(1, 65663, '\P{^Is_Blk=linearbsyllabary}', "");
Expect(0, 65664, '\p{Is_Blk=linearbsyllabary}', "");
Expect(1, 65664, '\p{^Is_Blk=linearbsyllabary}', "");
Expect(1, 65664, '\P{Is_Blk=linearbsyllabary}', "");
Expect(0, 65664, '\P{^Is_Blk=linearbsyllabary}', "");
Expect(1, 65663, '\p{Is_Blk=_-Linear_b_Syllabary}', "");
Expect(0, 65663, '\p{^Is_Blk=_-Linear_b_Syllabary}', "");
Expect(0, 65663, '\P{Is_Blk=_-Linear_b_Syllabary}', "");
Expect(1, 65663, '\P{^Is_Blk=_-Linear_b_Syllabary}', "");
Expect(0, 65664, '\p{Is_Blk=_-Linear_b_Syllabary}', "");
Expect(1, 65664, '\p{^Is_Blk=_-Linear_b_Syllabary}', "");
Expect(1, 65664, '\P{Is_Blk=_-Linear_b_Syllabary}', "");
Expect(0, 65664, '\P{^Is_Blk=_-Linear_b_Syllabary}', "");
Error('\p{Block=-/a/Lisu}');
Error('\P{Block=-/a/Lisu}');
Expect(1, 42239, '\p{Block=lisu}', "");
Expect(0, 42239, '\p{^Block=lisu}', "");
Expect(0, 42239, '\P{Block=lisu}', "");
Expect(1, 42239, '\P{^Block=lisu}', "");
Expect(0, 42240, '\p{Block=lisu}', "");
Expect(1, 42240, '\p{^Block=lisu}', "");
Expect(1, 42240, '\P{Block=lisu}', "");
Expect(0, 42240, '\P{^Block=lisu}', "");
Expect(1, 42239, '\p{Block=__LISU}', "");
Expect(0, 42239, '\p{^Block=__LISU}', "");
Expect(0, 42239, '\P{Block=__LISU}', "");
Expect(1, 42239, '\P{^Block=__LISU}', "");
Expect(0, 42240, '\p{Block=__LISU}', "");
Expect(1, 42240, '\p{^Block=__LISU}', "");
Expect(1, 42240, '\P{Block=__LISU}', "");
Expect(0, 42240, '\P{^Block=__LISU}', "");
Error('\p{Blk=--lisu/a/}');
Error('\P{Blk=--lisu/a/}');
Expect(1, 42239, '\p{Blk=lisu}', "");
Expect(0, 42239, '\p{^Blk=lisu}', "");
Expect(0, 42239, '\P{Blk=lisu}', "");
Expect(1, 42239, '\P{^Blk=lisu}', "");
Expect(0, 42240, '\p{Blk=lisu}', "");
Expect(1, 42240, '\p{^Blk=lisu}', "");
Expect(1, 42240, '\P{Blk=lisu}', "");
Expect(0, 42240, '\P{^Blk=lisu}', "");
Expect(1, 42239, '\p{Blk=-LISU}', "");
Expect(0, 42239, '\p{^Blk=-LISU}', "");
Expect(0, 42239, '\P{Blk=-LISU}', "");
Expect(1, 42239, '\P{^Blk=-LISU}', "");
Expect(0, 42240, '\p{Blk=-LISU}', "");
Expect(1, 42240, '\p{^Blk=-LISU}', "");
Expect(1, 42240, '\P{Blk=-LISU}', "");
Expect(0, 42240, '\P{^Blk=-LISU}', "");
Error('\p{Is_Block=/a/-	lisu}');
Error('\P{Is_Block=/a/-	lisu}');
Expect(1, 42239, '\p{Is_Block=lisu}', "");
Expect(0, 42239, '\p{^Is_Block=lisu}', "");
Expect(0, 42239, '\P{Is_Block=lisu}', "");
Expect(1, 42239, '\P{^Is_Block=lisu}', "");
Expect(0, 42240, '\p{Is_Block=lisu}', "");
Expect(1, 42240, '\p{^Is_Block=lisu}', "");
Expect(1, 42240, '\P{Is_Block=lisu}', "");
Expect(0, 42240, '\P{^Is_Block=lisu}', "");
Expect(1, 42239, '\p{Is_Block=	LISU}', "");
Expect(0, 42239, '\p{^Is_Block=	LISU}', "");
Expect(0, 42239, '\P{Is_Block=	LISU}', "");
Expect(1, 42239, '\P{^Is_Block=	LISU}', "");
Expect(0, 42240, '\p{Is_Block=	LISU}', "");
Expect(1, 42240, '\p{^Is_Block=	LISU}', "");
Expect(1, 42240, '\P{Is_Block=	LISU}', "");
Expect(0, 42240, '\P{^Is_Block=	LISU}', "");
Error('\p{Is_Blk=/a/- LISU}');
Error('\P{Is_Blk=/a/- LISU}');
Expect(1, 42239, '\p{Is_Blk=lisu}', "");
Expect(0, 42239, '\p{^Is_Blk=lisu}', "");
Expect(0, 42239, '\P{Is_Blk=lisu}', "");
Expect(1, 42239, '\P{^Is_Blk=lisu}', "");
Expect(0, 42240, '\p{Is_Blk=lisu}', "");
Expect(1, 42240, '\p{^Is_Blk=lisu}', "");
Expect(1, 42240, '\P{Is_Blk=lisu}', "");
Expect(0, 42240, '\P{^Is_Blk=lisu}', "");
Expect(1, 42239, '\p{Is_Blk=	 lisu}', "");
Expect(0, 42239, '\p{^Is_Blk=	 lisu}', "");
Expect(0, 42239, '\P{Is_Blk=	 lisu}', "");
Expect(1, 42239, '\P{^Is_Blk=	 lisu}', "");
Expect(0, 42240, '\p{Is_Blk=	 lisu}', "");
Expect(1, 42240, '\p{^Is_Blk=	 lisu}', "");
Expect(1, 42240, '\P{Is_Blk=	 lisu}', "");
Expect(0, 42240, '\P{^Is_Blk=	 lisu}', "");
Error('\p{Block=/a/_Low_Surrogates}');
Error('\P{Block=/a/_Low_Surrogates}');
Expect(1, 57343, '\p{Block=lowsurrogates}', "");
Expect(0, 57343, '\p{^Block=lowsurrogates}', "");
Expect(0, 57343, '\P{Block=lowsurrogates}', "");
Expect(1, 57343, '\P{^Block=lowsurrogates}', "");
Expect(0, 57344, '\p{Block=lowsurrogates}', "");
Expect(1, 57344, '\p{^Block=lowsurrogates}', "");
Expect(1, 57344, '\P{Block=lowsurrogates}', "");
Expect(0, 57344, '\P{^Block=lowsurrogates}', "");
Expect(1, 57343, '\p{Block=	_Low_Surrogates}', "");
Expect(0, 57343, '\p{^Block=	_Low_Surrogates}', "");
Expect(0, 57343, '\P{Block=	_Low_Surrogates}', "");
Expect(1, 57343, '\P{^Block=	_Low_Surrogates}', "");
Expect(0, 57344, '\p{Block=	_Low_Surrogates}', "");
Expect(1, 57344, '\p{^Block=	_Low_Surrogates}', "");
Expect(1, 57344, '\P{Block=	_Low_Surrogates}', "");
Expect(0, 57344, '\P{^Block=	_Low_Surrogates}', "");
Error('\p{Blk=low_Surrogates/a/}');
Error('\P{Blk=low_Surrogates/a/}');
Expect(1, 57343, '\p{Blk=lowsurrogates}', "");
Expect(0, 57343, '\p{^Blk=lowsurrogates}', "");
Expect(0, 57343, '\P{Blk=lowsurrogates}', "");
Expect(1, 57343, '\P{^Blk=lowsurrogates}', "");
Expect(0, 57344, '\p{Blk=lowsurrogates}', "");
Expect(1, 57344, '\p{^Blk=lowsurrogates}', "");
Expect(1, 57344, '\P{Blk=lowsurrogates}', "");
Expect(0, 57344, '\P{^Blk=lowsurrogates}', "");
Expect(1, 57343, '\p{Blk=	LOW_Surrogates}', "");
Expect(0, 57343, '\p{^Blk=	LOW_Surrogates}', "");
Expect(0, 57343, '\P{Blk=	LOW_Surrogates}', "");
Expect(1, 57343, '\P{^Blk=	LOW_Surrogates}', "");
Expect(0, 57344, '\p{Blk=	LOW_Surrogates}', "");
Expect(1, 57344, '\p{^Blk=	LOW_Surrogates}', "");
Expect(1, 57344, '\P{Blk=	LOW_Surrogates}', "");
Expect(0, 57344, '\P{^Blk=	LOW_Surrogates}', "");
Error('\p{Is_Block: := -low_SURROGATES}');
Error('\P{Is_Block: := -low_SURROGATES}');
Expect(1, 57343, '\p{Is_Block=lowsurrogates}', "");
Expect(0, 57343, '\p{^Is_Block=lowsurrogates}', "");
Expect(0, 57343, '\P{Is_Block=lowsurrogates}', "");
Expect(1, 57343, '\P{^Is_Block=lowsurrogates}', "");
Expect(0, 57344, '\p{Is_Block=lowsurrogates}', "");
Expect(1, 57344, '\p{^Is_Block=lowsurrogates}', "");
Expect(1, 57344, '\P{Is_Block=lowsurrogates}', "");
Expect(0, 57344, '\P{^Is_Block=lowsurrogates}', "");
Expect(1, 57343, '\p{Is_Block=		Low_Surrogates}', "");
Expect(0, 57343, '\p{^Is_Block=		Low_Surrogates}', "");
Expect(0, 57343, '\P{Is_Block=		Low_Surrogates}', "");
Expect(1, 57343, '\P{^Is_Block=		Low_Surrogates}', "");
Expect(0, 57344, '\p{Is_Block=		Low_Surrogates}', "");
Expect(1, 57344, '\p{^Is_Block=		Low_Surrogates}', "");
Expect(1, 57344, '\P{Is_Block=		Low_Surrogates}', "");
Expect(0, 57344, '\P{^Is_Block=		Low_Surrogates}', "");
Error('\p{Is_Blk= /a/Low_surrogates}');
Error('\P{Is_Blk= /a/Low_surrogates}');
Expect(1, 57343, '\p{Is_Blk=lowsurrogates}', "");
Expect(0, 57343, '\p{^Is_Blk=lowsurrogates}', "");
Expect(0, 57343, '\P{Is_Blk=lowsurrogates}', "");
Expect(1, 57343, '\P{^Is_Blk=lowsurrogates}', "");
Expect(0, 57344, '\p{Is_Blk=lowsurrogates}', "");
Expect(1, 57344, '\p{^Is_Blk=lowsurrogates}', "");
Expect(1, 57344, '\P{Is_Blk=lowsurrogates}', "");
Expect(0, 57344, '\P{^Is_Blk=lowsurrogates}', "");
Expect(1, 57343, '\p{Is_Blk:			Low_SURROGATES}', "");
Expect(0, 57343, '\p{^Is_Blk:			Low_SURROGATES}', "");
Expect(0, 57343, '\P{Is_Blk:			Low_SURROGATES}', "");
Expect(1, 57343, '\P{^Is_Blk:			Low_SURROGATES}', "");
Expect(0, 57344, '\p{Is_Blk:			Low_SURROGATES}', "");
Expect(1, 57344, '\p{^Is_Blk:			Low_SURROGATES}', "");
Expect(1, 57344, '\P{Is_Blk:			Low_SURROGATES}', "");
Expect(0, 57344, '\P{^Is_Blk:			Low_SURROGATES}', "");
Error('\p{Block=-/a/Lycian}');
Error('\P{Block=-/a/Lycian}');
Expect(1, 66207, '\p{Block=lycian}', "");
Expect(0, 66207, '\p{^Block=lycian}', "");
Expect(0, 66207, '\P{Block=lycian}', "");
Expect(1, 66207, '\P{^Block=lycian}', "");
Expect(0, 66208, '\p{Block=lycian}', "");
Expect(1, 66208, '\p{^Block=lycian}', "");
Expect(1, 66208, '\P{Block=lycian}', "");
Expect(0, 66208, '\P{^Block=lycian}', "");
Expect(1, 66207, '\p{Block:	Lycian}', "");
Expect(0, 66207, '\p{^Block:	Lycian}', "");
Expect(0, 66207, '\P{Block:	Lycian}', "");
Expect(1, 66207, '\P{^Block:	Lycian}', "");
Expect(0, 66208, '\p{Block:	Lycian}', "");
Expect(1, 66208, '\p{^Block:	Lycian}', "");
Expect(1, 66208, '\P{Block:	Lycian}', "");
Expect(0, 66208, '\P{^Block:	Lycian}', "");
Error('\p{Blk=	_LYCIAN:=}');
Error('\P{Blk=	_LYCIAN:=}');
Expect(1, 66207, '\p{Blk=lycian}', "");
Expect(0, 66207, '\p{^Blk=lycian}', "");
Expect(0, 66207, '\P{Blk=lycian}', "");
Expect(1, 66207, '\P{^Blk=lycian}', "");
Expect(0, 66208, '\p{Blk=lycian}', "");
Expect(1, 66208, '\p{^Blk=lycian}', "");
Expect(1, 66208, '\P{Blk=lycian}', "");
Expect(0, 66208, '\P{^Blk=lycian}', "");
Expect(1, 66207, '\p{Blk=	-Lycian}', "");
Expect(0, 66207, '\p{^Blk=	-Lycian}', "");
Expect(0, 66207, '\P{Blk=	-Lycian}', "");
Expect(1, 66207, '\P{^Blk=	-Lycian}', "");
Expect(0, 66208, '\p{Blk=	-Lycian}', "");
Expect(1, 66208, '\p{^Blk=	-Lycian}', "");
Expect(1, 66208, '\P{Blk=	-Lycian}', "");
Expect(0, 66208, '\P{^Blk=	-Lycian}', "");
Error('\p{Is_Block= Lycian:=}');
Error('\P{Is_Block= Lycian:=}');
Expect(1, 66207, '\p{Is_Block=lycian}', "");
Expect(0, 66207, '\p{^Is_Block=lycian}', "");
Expect(0, 66207, '\P{Is_Block=lycian}', "");
Expect(1, 66207, '\P{^Is_Block=lycian}', "");
Expect(0, 66208, '\p{Is_Block=lycian}', "");
Expect(1, 66208, '\p{^Is_Block=lycian}', "");
Expect(1, 66208, '\P{Is_Block=lycian}', "");
Expect(0, 66208, '\P{^Is_Block=lycian}', "");
Expect(1, 66207, '\p{Is_Block= _Lycian}', "");
Expect(0, 66207, '\p{^Is_Block= _Lycian}', "");
Expect(0, 66207, '\P{Is_Block= _Lycian}', "");
Expect(1, 66207, '\P{^Is_Block= _Lycian}', "");
Expect(0, 66208, '\p{Is_Block= _Lycian}', "");
Expect(1, 66208, '\p{^Is_Block= _Lycian}', "");
Expect(1, 66208, '\P{Is_Block= _Lycian}', "");
Expect(0, 66208, '\P{^Is_Block= _Lycian}', "");
Error('\p{Is_Blk=-:=Lycian}');
Error('\P{Is_Blk=-:=Lycian}');
Expect(1, 66207, '\p{Is_Blk=lycian}', "");
Expect(0, 66207, '\p{^Is_Blk=lycian}', "");
Expect(0, 66207, '\P{Is_Blk=lycian}', "");
Expect(1, 66207, '\P{^Is_Blk=lycian}', "");
Expect(0, 66208, '\p{Is_Blk=lycian}', "");
Expect(1, 66208, '\p{^Is_Blk=lycian}', "");
Expect(1, 66208, '\P{Is_Blk=lycian}', "");
Expect(0, 66208, '\P{^Is_Blk=lycian}', "");
Expect(1, 66207, '\p{Is_Blk=_ lycian}', "");
Expect(0, 66207, '\p{^Is_Blk=_ lycian}', "");
Expect(0, 66207, '\P{Is_Blk=_ lycian}', "");
Expect(1, 66207, '\P{^Is_Blk=_ lycian}', "");
Expect(0, 66208, '\p{Is_Blk=_ lycian}', "");
Expect(1, 66208, '\p{^Is_Blk=_ lycian}', "");
Expect(1, 66208, '\P{Is_Blk=_ lycian}', "");
Expect(0, 66208, '\P{^Is_Blk=_ lycian}', "");
Error('\p{Block:		/a/LYDIAN}');
Error('\P{Block:		/a/LYDIAN}');
Expect(1, 67903, '\p{Block=lydian}', "");
Expect(0, 67903, '\p{^Block=lydian}', "");
Expect(0, 67903, '\P{Block=lydian}', "");
Expect(1, 67903, '\P{^Block=lydian}', "");
Expect(0, 67904, '\p{Block=lydian}', "");
Expect(1, 67904, '\p{^Block=lydian}', "");
Expect(1, 67904, '\P{Block=lydian}', "");
Expect(0, 67904, '\P{^Block=lydian}', "");
Expect(1, 67903, '\p{Block=  Lydian}', "");
Expect(0, 67903, '\p{^Block=  Lydian}', "");
Expect(0, 67903, '\P{Block=  Lydian}', "");
Expect(1, 67903, '\P{^Block=  Lydian}', "");
Expect(0, 67904, '\p{Block=  Lydian}', "");
Expect(1, 67904, '\p{^Block=  Lydian}', "");
Expect(1, 67904, '\P{Block=  Lydian}', "");
Expect(0, 67904, '\P{^Block=  Lydian}', "");
Error('\p{Blk=-_lydian:=}');
Error('\P{Blk=-_lydian:=}');
Expect(1, 67903, '\p{Blk=lydian}', "");
Expect(0, 67903, '\p{^Blk=lydian}', "");
Expect(0, 67903, '\P{Blk=lydian}', "");
Expect(1, 67903, '\P{^Blk=lydian}', "");
Expect(0, 67904, '\p{Blk=lydian}', "");
Expect(1, 67904, '\p{^Blk=lydian}', "");
Expect(1, 67904, '\P{Blk=lydian}', "");
Expect(0, 67904, '\P{^Blk=lydian}', "");
Expect(1, 67903, '\p{Blk=_-Lydian}', "");
Expect(0, 67903, '\p{^Blk=_-Lydian}', "");
Expect(0, 67903, '\P{Blk=_-Lydian}', "");
Expect(1, 67903, '\P{^Blk=_-Lydian}', "");
Expect(0, 67904, '\p{Blk=_-Lydian}', "");
Expect(1, 67904, '\p{^Blk=_-Lydian}', "");
Expect(1, 67904, '\P{Blk=_-Lydian}', "");
Expect(0, 67904, '\P{^Blk=_-Lydian}', "");
Error('\p{Is_Block=/a/lydian}');
Error('\P{Is_Block=/a/lydian}');
Expect(1, 67903, '\p{Is_Block=lydian}', "");
Expect(0, 67903, '\p{^Is_Block=lydian}', "");
Expect(0, 67903, '\P{Is_Block=lydian}', "");
Expect(1, 67903, '\P{^Is_Block=lydian}', "");
Expect(0, 67904, '\p{Is_Block=lydian}', "");
Expect(1, 67904, '\p{^Is_Block=lydian}', "");
Expect(1, 67904, '\P{Is_Block=lydian}', "");
Expect(0, 67904, '\P{^Is_Block=lydian}', "");
Expect(1, 67903, '\p{Is_Block=-	LYDIAN}', "");
Expect(0, 67903, '\p{^Is_Block=-	LYDIAN}', "");
Expect(0, 67903, '\P{Is_Block=-	LYDIAN}', "");
Expect(1, 67903, '\P{^Is_Block=-	LYDIAN}', "");
Expect(0, 67904, '\p{Is_Block=-	LYDIAN}', "");
Expect(1, 67904, '\p{^Is_Block=-	LYDIAN}', "");
Expect(1, 67904, '\P{Is_Block=-	LYDIAN}', "");
Expect(0, 67904, '\P{^Is_Block=-	LYDIAN}', "");
Error('\p{Is_Blk= /a/lydian}');
Error('\P{Is_Blk= /a/lydian}');
Expect(1, 67903, '\p{Is_Blk:	lydian}', "");
Expect(0, 67903, '\p{^Is_Blk:	lydian}', "");
Expect(0, 67903, '\P{Is_Blk:	lydian}', "");
Expect(1, 67903, '\P{^Is_Blk:	lydian}', "");
Expect(0, 67904, '\p{Is_Blk:	lydian}', "");
Expect(1, 67904, '\p{^Is_Blk:	lydian}', "");
Expect(1, 67904, '\P{Is_Blk:	lydian}', "");
Expect(0, 67904, '\P{^Is_Blk:	lydian}', "");
Expect(1, 67903, '\p{Is_Blk=_-lydian}', "");
Expect(0, 67903, '\p{^Is_Blk=_-lydian}', "");
Expect(0, 67903, '\P{Is_Blk=_-lydian}', "");
Expect(1, 67903, '\P{^Is_Blk=_-lydian}', "");
Expect(0, 67904, '\p{Is_Blk=_-lydian}', "");
Expect(1, 67904, '\p{^Is_Blk=_-lydian}', "");
Expect(1, 67904, '\P{Is_Blk=_-lydian}', "");
Expect(0, 67904, '\P{^Is_Blk=_-lydian}', "");
Error('\p{Block=-:=mahjong_TILES}');
Error('\P{Block=-:=mahjong_TILES}');
Expect(1, 127023, '\p{Block:mahjongtiles}', "");
Expect(0, 127023, '\p{^Block:mahjongtiles}', "");
Expect(0, 127023, '\P{Block:mahjongtiles}', "");
Expect(1, 127023, '\P{^Block:mahjongtiles}', "");
Expect(0, 127024, '\p{Block:mahjongtiles}', "");
Expect(1, 127024, '\p{^Block:mahjongtiles}', "");
Expect(1, 127024, '\P{Block:mahjongtiles}', "");
Expect(0, 127024, '\P{^Block:mahjongtiles}', "");
Expect(1, 127023, '\p{Block:  Mahjong_TILES}', "");
Expect(0, 127023, '\p{^Block:  Mahjong_TILES}', "");
Expect(0, 127023, '\P{Block:  Mahjong_TILES}', "");
Expect(1, 127023, '\P{^Block:  Mahjong_TILES}', "");
Expect(0, 127024, '\p{Block:  Mahjong_TILES}', "");
Expect(1, 127024, '\p{^Block:  Mahjong_TILES}', "");
Expect(1, 127024, '\P{Block:  Mahjong_TILES}', "");
Expect(0, 127024, '\P{^Block:  Mahjong_TILES}', "");
Error('\p{Blk=	/a/Mahjong}');
Error('\P{Blk=	/a/Mahjong}');
Expect(1, 127023, '\p{Blk=mahjong}', "");
Expect(0, 127023, '\p{^Blk=mahjong}', "");
Expect(0, 127023, '\P{Blk=mahjong}', "");
Expect(1, 127023, '\P{^Blk=mahjong}', "");
Expect(0, 127024, '\p{Blk=mahjong}', "");
Expect(1, 127024, '\p{^Blk=mahjong}', "");
Expect(1, 127024, '\P{Blk=mahjong}', "");
Expect(0, 127024, '\P{^Blk=mahjong}', "");
Expect(1, 127023, '\p{Blk= MAHJONG}', "");
Expect(0, 127023, '\p{^Blk= MAHJONG}', "");
Expect(0, 127023, '\P{Blk= MAHJONG}', "");
Expect(1, 127023, '\P{^Blk= MAHJONG}', "");
Expect(0, 127024, '\p{Blk= MAHJONG}', "");
Expect(1, 127024, '\p{^Blk= MAHJONG}', "");
Expect(1, 127024, '\P{Blk= MAHJONG}', "");
Expect(0, 127024, '\P{^Blk= MAHJONG}', "");
Error('\p{Is_Block=:=Mahjong_tiles}');
Error('\P{Is_Block=:=Mahjong_tiles}');
Expect(1, 127023, '\p{Is_Block=mahjongtiles}', "");
Expect(0, 127023, '\p{^Is_Block=mahjongtiles}', "");
Expect(0, 127023, '\P{Is_Block=mahjongtiles}', "");
Expect(1, 127023, '\P{^Is_Block=mahjongtiles}', "");
Expect(0, 127024, '\p{Is_Block=mahjongtiles}', "");
Expect(1, 127024, '\p{^Is_Block=mahjongtiles}', "");
Expect(1, 127024, '\P{Is_Block=mahjongtiles}', "");
Expect(0, 127024, '\P{^Is_Block=mahjongtiles}', "");
Expect(1, 127023, '\p{Is_Block=- Mahjong_Tiles}', "");
Expect(0, 127023, '\p{^Is_Block=- Mahjong_Tiles}', "");
Expect(0, 127023, '\P{Is_Block=- Mahjong_Tiles}', "");
Expect(1, 127023, '\P{^Is_Block=- Mahjong_Tiles}', "");
Expect(0, 127024, '\p{Is_Block=- Mahjong_Tiles}', "");
Expect(1, 127024, '\p{^Is_Block=- Mahjong_Tiles}', "");
Expect(1, 127024, '\P{Is_Block=- Mahjong_Tiles}', "");
Expect(0, 127024, '\P{^Is_Block=- Mahjong_Tiles}', "");
Error('\p{Is_Blk=:=	 Mahjong}');
Error('\P{Is_Blk=:=	 Mahjong}');
Expect(1, 127023, '\p{Is_Blk=mahjong}', "");
Expect(0, 127023, '\p{^Is_Blk=mahjong}', "");
Expect(0, 127023, '\P{Is_Blk=mahjong}', "");
Expect(1, 127023, '\P{^Is_Blk=mahjong}', "");
Expect(0, 127024, '\p{Is_Blk=mahjong}', "");
Expect(1, 127024, '\p{^Is_Blk=mahjong}', "");
Expect(1, 127024, '\P{Is_Blk=mahjong}', "");
Expect(0, 127024, '\P{^Is_Blk=mahjong}', "");
Expect(1, 127023, '\p{Is_Blk=--mahjong}', "");
Expect(0, 127023, '\p{^Is_Blk=--mahjong}', "");
Expect(0, 127023, '\P{Is_Blk=--mahjong}', "");
Expect(1, 127023, '\P{^Is_Blk=--mahjong}', "");
Expect(0, 127024, '\p{Is_Blk=--mahjong}', "");
Expect(1, 127024, '\p{^Is_Blk=--mahjong}', "");
Expect(1, 127024, '\P{Is_Blk=--mahjong}', "");
Expect(0, 127024, '\P{^Is_Blk=--mahjong}', "");
Error('\p{Block=_:=Malayalam}');
Error('\P{Block=_:=Malayalam}');
Expect(1, 3455, '\p{Block=malayalam}', "");
Expect(0, 3455, '\p{^Block=malayalam}', "");
Expect(0, 3455, '\P{Block=malayalam}', "");
Expect(1, 3455, '\P{^Block=malayalam}', "");
Expect(0, 3456, '\p{Block=malayalam}', "");
Expect(1, 3456, '\p{^Block=malayalam}', "");
Expect(1, 3456, '\P{Block=malayalam}', "");
Expect(0, 3456, '\P{^Block=malayalam}', "");
Expect(1, 3455, '\p{Block=	malayalam}', "");
Expect(0, 3455, '\p{^Block=	malayalam}', "");
Expect(0, 3455, '\P{Block=	malayalam}', "");
Expect(1, 3455, '\P{^Block=	malayalam}', "");
Expect(0, 3456, '\p{Block=	malayalam}', "");
Expect(1, 3456, '\p{^Block=	malayalam}', "");
Expect(1, 3456, '\P{Block=	malayalam}', "");
Expect(0, 3456, '\P{^Block=	malayalam}', "");
Error('\p{Blk=:= -Malayalam}');
Error('\P{Blk=:= -Malayalam}');
Expect(1, 3455, '\p{Blk=malayalam}', "");
Expect(0, 3455, '\p{^Blk=malayalam}', "");
Expect(0, 3455, '\P{Blk=malayalam}', "");
Expect(1, 3455, '\P{^Blk=malayalam}', "");
Expect(0, 3456, '\p{Blk=malayalam}', "");
Expect(1, 3456, '\p{^Blk=malayalam}', "");
Expect(1, 3456, '\P{Blk=malayalam}', "");
Expect(0, 3456, '\P{^Blk=malayalam}', "");
Expect(1, 3455, '\p{Blk=_ malayalam}', "");
Expect(0, 3455, '\p{^Blk=_ malayalam}', "");
Expect(0, 3455, '\P{Blk=_ malayalam}', "");
Expect(1, 3455, '\P{^Blk=_ malayalam}', "");
Expect(0, 3456, '\p{Blk=_ malayalam}', "");
Expect(1, 3456, '\p{^Blk=_ malayalam}', "");
Expect(1, 3456, '\P{Blk=_ malayalam}', "");
Expect(0, 3456, '\P{^Blk=_ malayalam}', "");
Error('\p{Is_Block=-/a/Malayalam}');
Error('\P{Is_Block=-/a/Malayalam}');
Expect(1, 3455, '\p{Is_Block=malayalam}', "");
Expect(0, 3455, '\p{^Is_Block=malayalam}', "");
Expect(0, 3455, '\P{Is_Block=malayalam}', "");
Expect(1, 3455, '\P{^Is_Block=malayalam}', "");
Expect(0, 3456, '\p{Is_Block=malayalam}', "");
Expect(1, 3456, '\p{^Is_Block=malayalam}', "");
Expect(1, 3456, '\P{Is_Block=malayalam}', "");
Expect(0, 3456, '\P{^Is_Block=malayalam}', "");
Expect(1, 3455, '\p{Is_Block= Malayalam}', "");
Expect(0, 3455, '\p{^Is_Block= Malayalam}', "");
Expect(0, 3455, '\P{Is_Block= Malayalam}', "");
Expect(1, 3455, '\P{^Is_Block= Malayalam}', "");
Expect(0, 3456, '\p{Is_Block= Malayalam}', "");
Expect(1, 3456, '\p{^Is_Block= Malayalam}', "");
Expect(1, 3456, '\P{Is_Block= Malayalam}', "");
Expect(0, 3456, '\P{^Is_Block= Malayalam}', "");
Error('\p{Is_Blk= _Malayalam:=}');
Error('\P{Is_Blk= _Malayalam:=}');
Expect(1, 3455, '\p{Is_Blk=malayalam}', "");
Expect(0, 3455, '\p{^Is_Blk=malayalam}', "");
Expect(0, 3455, '\P{Is_Blk=malayalam}', "");
Expect(1, 3455, '\P{^Is_Blk=malayalam}', "");
Expect(0, 3456, '\p{Is_Blk=malayalam}', "");
Expect(1, 3456, '\p{^Is_Blk=malayalam}', "");
Expect(1, 3456, '\P{Is_Blk=malayalam}', "");
Expect(0, 3456, '\P{^Is_Blk=malayalam}', "");
Expect(1, 3455, '\p{Is_Blk=	-MALAYALAM}', "");
Expect(0, 3455, '\p{^Is_Blk=	-MALAYALAM}', "");
Expect(0, 3455, '\P{Is_Blk=	-MALAYALAM}', "");
Expect(1, 3455, '\P{^Is_Blk=	-MALAYALAM}', "");
Expect(0, 3456, '\p{Is_Blk=	-MALAYALAM}', "");
Expect(1, 3456, '\p{^Is_Blk=	-MALAYALAM}', "");
Expect(1, 3456, '\P{Is_Blk=	-MALAYALAM}', "");
Expect(0, 3456, '\P{^Is_Blk=	-MALAYALAM}', "");
Error('\p{Block= /a/MANDAIC}');
Error('\P{Block= /a/MANDAIC}');
Expect(1, 2143, '\p{Block=mandaic}', "");
Expect(0, 2143, '\p{^Block=mandaic}', "");
Expect(0, 2143, '\P{Block=mandaic}', "");
Expect(1, 2143, '\P{^Block=mandaic}', "");
Expect(0, 2144, '\p{Block=mandaic}', "");
Expect(1, 2144, '\p{^Block=mandaic}', "");
Expect(1, 2144, '\P{Block=mandaic}', "");
Expect(0, 2144, '\P{^Block=mandaic}', "");
Expect(1, 2143, '\p{Block=- MANDAIC}', "");
Expect(0, 2143, '\p{^Block=- MANDAIC}', "");
Expect(0, 2143, '\P{Block=- MANDAIC}', "");
Expect(1, 2143, '\P{^Block=- MANDAIC}', "");
Expect(0, 2144, '\p{Block=- MANDAIC}', "");
Expect(1, 2144, '\p{^Block=- MANDAIC}', "");
Expect(1, 2144, '\P{Block=- MANDAIC}', "");
Expect(0, 2144, '\P{^Block=- MANDAIC}', "");
Error('\p{Blk=/a/_ mandaic}');
Error('\P{Blk=/a/_ mandaic}');
Expect(1, 2143, '\p{Blk=mandaic}', "");
Expect(0, 2143, '\p{^Blk=mandaic}', "");
Expect(0, 2143, '\P{Blk=mandaic}', "");
Expect(1, 2143, '\P{^Blk=mandaic}', "");
Expect(0, 2144, '\p{Blk=mandaic}', "");
Expect(1, 2144, '\p{^Blk=mandaic}', "");
Expect(1, 2144, '\P{Blk=mandaic}', "");
Expect(0, 2144, '\P{^Blk=mandaic}', "");
Expect(1, 2143, '\p{Blk=-_MANDAIC}', "");
Expect(0, 2143, '\p{^Blk=-_MANDAIC}', "");
Expect(0, 2143, '\P{Blk=-_MANDAIC}', "");
Expect(1, 2143, '\P{^Blk=-_MANDAIC}', "");
Expect(0, 2144, '\p{Blk=-_MANDAIC}', "");
Expect(1, 2144, '\p{^Blk=-_MANDAIC}', "");
Expect(1, 2144, '\P{Blk=-_MANDAIC}', "");
Expect(0, 2144, '\P{^Blk=-_MANDAIC}', "");
Error('\p{Is_Block=_-mandaic/a/}');
Error('\P{Is_Block=_-mandaic/a/}');
Expect(1, 2143, '\p{Is_Block=mandaic}', "");
Expect(0, 2143, '\p{^Is_Block=mandaic}', "");
Expect(0, 2143, '\P{Is_Block=mandaic}', "");
Expect(1, 2143, '\P{^Is_Block=mandaic}', "");
Expect(0, 2144, '\p{Is_Block=mandaic}', "");
Expect(1, 2144, '\p{^Is_Block=mandaic}', "");
Expect(1, 2144, '\P{Is_Block=mandaic}', "");
Expect(0, 2144, '\P{^Is_Block=mandaic}', "");
Expect(1, 2143, '\p{Is_Block: -	Mandaic}', "");
Expect(0, 2143, '\p{^Is_Block: -	Mandaic}', "");
Expect(0, 2143, '\P{Is_Block: -	Mandaic}', "");
Expect(1, 2143, '\P{^Is_Block: -	Mandaic}', "");
Expect(0, 2144, '\p{Is_Block: -	Mandaic}', "");
Expect(1, 2144, '\p{^Is_Block: -	Mandaic}', "");
Expect(1, 2144, '\P{Is_Block: -	Mandaic}', "");
Expect(0, 2144, '\P{^Is_Block: -	Mandaic}', "");
Error('\p{Is_Blk=/a/	 mandaic}');
Error('\P{Is_Blk=/a/	 mandaic}');
Expect(1, 2143, '\p{Is_Blk=mandaic}', "");
Expect(0, 2143, '\p{^Is_Blk=mandaic}', "");
Expect(0, 2143, '\P{Is_Blk=mandaic}', "");
Expect(1, 2143, '\P{^Is_Blk=mandaic}', "");
Expect(0, 2144, '\p{Is_Blk=mandaic}', "");
Expect(1, 2144, '\p{^Is_Blk=mandaic}', "");
Expect(1, 2144, '\P{Is_Blk=mandaic}', "");
Expect(0, 2144, '\P{^Is_Blk=mandaic}', "");
Expect(1, 2143, '\p{Is_Blk= -MANDAIC}', "");
Expect(0, 2143, '\p{^Is_Blk= -MANDAIC}', "");
Expect(0, 2143, '\P{Is_Blk= -MANDAIC}', "");
Expect(1, 2143, '\P{^Is_Blk= -MANDAIC}', "");
Expect(0, 2144, '\p{Is_Blk= -MANDAIC}', "");
Expect(1, 2144, '\p{^Is_Blk= -MANDAIC}', "");
Expect(1, 2144, '\P{Is_Blk= -MANDAIC}', "");
Expect(0, 2144, '\P{^Is_Blk= -MANDAIC}', "");
Error('\p{Block=-/a/mathematical_Alphanumeric_SYMBOLS}');
Error('\P{Block=-/a/mathematical_Alphanumeric_SYMBOLS}');
Expect(1, 120831, '\p{Block=mathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\p{^Block=mathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\P{Block=mathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\P{^Block=mathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\p{Block=mathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\p{^Block=mathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\P{Block=mathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\P{^Block=mathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\p{Block= MATHEMATICAL_ALPHANUMERIC_Symbols}', "");
Expect(0, 120831, '\p{^Block= MATHEMATICAL_ALPHANUMERIC_Symbols}', "");
Expect(0, 120831, '\P{Block= MATHEMATICAL_ALPHANUMERIC_Symbols}', "");
Expect(1, 120831, '\P{^Block= MATHEMATICAL_ALPHANUMERIC_Symbols}', "");
Expect(0, 120832, '\p{Block= MATHEMATICAL_ALPHANUMERIC_Symbols}', "");
Expect(1, 120832, '\p{^Block= MATHEMATICAL_ALPHANUMERIC_Symbols}', "");
Expect(1, 120832, '\P{Block= MATHEMATICAL_ALPHANUMERIC_Symbols}', "");
Expect(0, 120832, '\P{^Block= MATHEMATICAL_ALPHANUMERIC_Symbols}', "");
Error('\p{Blk=-MATH_Alphanum:=}');
Error('\P{Blk=-MATH_Alphanum:=}');
Expect(1, 120831, '\p{Blk=mathalphanum}', "");
Expect(0, 120831, '\p{^Blk=mathalphanum}', "");
Expect(0, 120831, '\P{Blk=mathalphanum}', "");
Expect(1, 120831, '\P{^Blk=mathalphanum}', "");
Expect(0, 120832, '\p{Blk=mathalphanum}', "");
Expect(1, 120832, '\p{^Blk=mathalphanum}', "");
Expect(1, 120832, '\P{Blk=mathalphanum}', "");
Expect(0, 120832, '\P{^Blk=mathalphanum}', "");
Expect(1, 120831, '\p{Blk: - MATH_Alphanum}', "");
Expect(0, 120831, '\p{^Blk: - MATH_Alphanum}', "");
Expect(0, 120831, '\P{Blk: - MATH_Alphanum}', "");
Expect(1, 120831, '\P{^Blk: - MATH_Alphanum}', "");
Expect(0, 120832, '\p{Blk: - MATH_Alphanum}', "");
Expect(1, 120832, '\p{^Blk: - MATH_Alphanum}', "");
Expect(1, 120832, '\P{Blk: - MATH_Alphanum}', "");
Expect(0, 120832, '\P{^Blk: - MATH_Alphanum}', "");
Error('\p{Is_Block=:=- mathematical_Alphanumeric_symbols}');
Error('\P{Is_Block=:=- mathematical_Alphanumeric_symbols}');
Expect(1, 120831, '\p{Is_Block=mathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\p{^Is_Block=mathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\P{Is_Block=mathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\P{^Is_Block=mathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\p{Is_Block=mathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\p{^Is_Block=mathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\P{Is_Block=mathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\P{^Is_Block=mathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\p{Is_Block= 	mathematical_ALPHANUMERIC_SYMBOLS}', "");
Expect(0, 120831, '\p{^Is_Block= 	mathematical_ALPHANUMERIC_SYMBOLS}', "");
Expect(0, 120831, '\P{Is_Block= 	mathematical_ALPHANUMERIC_SYMBOLS}', "");
Expect(1, 120831, '\P{^Is_Block= 	mathematical_ALPHANUMERIC_SYMBOLS}', "");
Expect(0, 120832, '\p{Is_Block= 	mathematical_ALPHANUMERIC_SYMBOLS}', "");
Expect(1, 120832, '\p{^Is_Block= 	mathematical_ALPHANUMERIC_SYMBOLS}', "");
Expect(1, 120832, '\P{Is_Block= 	mathematical_ALPHANUMERIC_SYMBOLS}', "");
Expect(0, 120832, '\P{^Is_Block= 	mathematical_ALPHANUMERIC_SYMBOLS}', "");
Error('\p{Is_Blk=	/a/Math_Alphanum}');
Error('\P{Is_Blk=	/a/Math_Alphanum}');
Expect(1, 120831, '\p{Is_Blk=mathalphanum}', "");
Expect(0, 120831, '\p{^Is_Blk=mathalphanum}', "");
Expect(0, 120831, '\P{Is_Blk=mathalphanum}', "");
Expect(1, 120831, '\P{^Is_Blk=mathalphanum}', "");
Expect(0, 120832, '\p{Is_Blk=mathalphanum}', "");
Expect(1, 120832, '\p{^Is_Blk=mathalphanum}', "");
Expect(1, 120832, '\P{Is_Blk=mathalphanum}', "");
Expect(0, 120832, '\P{^Is_Blk=mathalphanum}', "");
Expect(1, 120831, '\p{Is_Blk=-Math_alphanum}', "");
Expect(0, 120831, '\p{^Is_Blk=-Math_alphanum}', "");
Expect(0, 120831, '\P{Is_Blk=-Math_alphanum}', "");
Expect(1, 120831, '\P{^Is_Blk=-Math_alphanum}', "");
Expect(0, 120832, '\p{Is_Blk=-Math_alphanum}', "");
Expect(1, 120832, '\p{^Is_Blk=-Math_alphanum}', "");
Expect(1, 120832, '\P{Is_Blk=-Math_alphanum}', "");
Expect(0, 120832, '\P{^Is_Blk=-Math_alphanum}', "");
Error('\p{Block=_:=Mathematical_Operators}');
Error('\P{Block=_:=Mathematical_Operators}');
Expect(1, 8959, '\p{Block=mathematicaloperators}', "");
Expect(0, 8959, '\p{^Block=mathematicaloperators}', "");
Expect(0, 8959, '\P{Block=mathematicaloperators}', "");
Expect(1, 8959, '\P{^Block=mathematicaloperators}', "");
Expect(0, 8960, '\p{Block=mathematicaloperators}', "");
Expect(1, 8960, '\p{^Block=mathematicaloperators}', "");
Expect(1, 8960, '\P{Block=mathematicaloperators}', "");
Expect(0, 8960, '\P{^Block=mathematicaloperators}', "");
Expect(1, 8959, '\p{Block=_ Mathematical_Operators}', "");
Expect(0, 8959, '\p{^Block=_ Mathematical_Operators}', "");
Expect(0, 8959, '\P{Block=_ Mathematical_Operators}', "");
Expect(1, 8959, '\P{^Block=_ Mathematical_Operators}', "");
Expect(0, 8960, '\p{Block=_ Mathematical_Operators}', "");
Expect(1, 8960, '\p{^Block=_ Mathematical_Operators}', "");
Expect(1, 8960, '\P{Block=_ Mathematical_Operators}', "");
Expect(0, 8960, '\P{^Block=_ Mathematical_Operators}', "");
Error('\p{Blk=	:=MATH_operators}');
Error('\P{Blk=	:=MATH_operators}');
Expect(1, 8959, '\p{Blk=mathoperators}', "");
Expect(0, 8959, '\p{^Blk=mathoperators}', "");
Expect(0, 8959, '\P{Blk=mathoperators}', "");
Expect(1, 8959, '\P{^Blk=mathoperators}', "");
Expect(0, 8960, '\p{Blk=mathoperators}', "");
Expect(1, 8960, '\p{^Blk=mathoperators}', "");
Expect(1, 8960, '\P{Blk=mathoperators}', "");
Expect(0, 8960, '\P{^Blk=mathoperators}', "");
Expect(1, 8959, '\p{Blk=	Math_OPERATORS}', "");
Expect(0, 8959, '\p{^Blk=	Math_OPERATORS}', "");
Expect(0, 8959, '\P{Blk=	Math_OPERATORS}', "");
Expect(1, 8959, '\P{^Blk=	Math_OPERATORS}', "");
Expect(0, 8960, '\p{Blk=	Math_OPERATORS}', "");
Expect(1, 8960, '\p{^Blk=	Math_OPERATORS}', "");
Expect(1, 8960, '\P{Blk=	Math_OPERATORS}', "");
Expect(0, 8960, '\P{^Blk=	Math_OPERATORS}', "");
Error('\p{Is_Block=_Mathematical_Operators/a/}');
Error('\P{Is_Block=_Mathematical_Operators/a/}');
Expect(1, 8959, '\p{Is_Block=mathematicaloperators}', "");
Expect(0, 8959, '\p{^Is_Block=mathematicaloperators}', "");
Expect(0, 8959, '\P{Is_Block=mathematicaloperators}', "");
Expect(1, 8959, '\P{^Is_Block=mathematicaloperators}', "");
Expect(0, 8960, '\p{Is_Block=mathematicaloperators}', "");
Expect(1, 8960, '\p{^Is_Block=mathematicaloperators}', "");
Expect(1, 8960, '\P{Is_Block=mathematicaloperators}', "");
Expect(0, 8960, '\P{^Is_Block=mathematicaloperators}', "");
Expect(1, 8959, '\p{Is_Block= -mathematical_Operators}', "");
Expect(0, 8959, '\p{^Is_Block= -mathematical_Operators}', "");
Expect(0, 8959, '\P{Is_Block= -mathematical_Operators}', "");
Expect(1, 8959, '\P{^Is_Block= -mathematical_Operators}', "");
Expect(0, 8960, '\p{Is_Block= -mathematical_Operators}', "");
Expect(1, 8960, '\p{^Is_Block= -mathematical_Operators}', "");
Expect(1, 8960, '\P{Is_Block= -mathematical_Operators}', "");
Expect(0, 8960, '\P{^Is_Block= -mathematical_Operators}', "");
Error('\p{Is_Blk:-	Math_Operators:=}');
Error('\P{Is_Blk:-	Math_Operators:=}');
Expect(1, 8959, '\p{Is_Blk=mathoperators}', "");
Expect(0, 8959, '\p{^Is_Blk=mathoperators}', "");
Expect(0, 8959, '\P{Is_Blk=mathoperators}', "");
Expect(1, 8959, '\P{^Is_Blk=mathoperators}', "");
Expect(0, 8960, '\p{Is_Blk=mathoperators}', "");
Expect(1, 8960, '\p{^Is_Blk=mathoperators}', "");
Expect(1, 8960, '\P{Is_Blk=mathoperators}', "");
Expect(0, 8960, '\P{^Is_Blk=mathoperators}', "");
Expect(1, 8959, '\p{Is_Blk=__Math_Operators}', "");
Expect(0, 8959, '\p{^Is_Blk=__Math_Operators}', "");
Expect(0, 8959, '\P{Is_Blk=__Math_Operators}', "");
Expect(1, 8959, '\P{^Is_Blk=__Math_Operators}', "");
Expect(0, 8960, '\p{Is_Blk=__Math_Operators}', "");
Expect(1, 8960, '\p{^Is_Blk=__Math_Operators}', "");
Expect(1, 8960, '\P{Is_Blk=__Math_Operators}', "");
Expect(0, 8960, '\P{^Is_Blk=__Math_Operators}', "");
Error('\p{Block=/a/--Meetei_mayek}');
Error('\P{Block=/a/--Meetei_mayek}');
Expect(1, 44031, '\p{Block=meeteimayek}', "");
Expect(0, 44031, '\p{^Block=meeteimayek}', "");
Expect(0, 44031, '\P{Block=meeteimayek}', "");
Expect(1, 44031, '\P{^Block=meeteimayek}', "");
Expect(0, 44032, '\p{Block=meeteimayek}', "");
Expect(1, 44032, '\p{^Block=meeteimayek}', "");
Expect(1, 44032, '\P{Block=meeteimayek}', "");
Expect(0, 44032, '\P{^Block=meeteimayek}', "");
Expect(1, 44031, '\p{Block=--Meetei_Mayek}', "");
Expect(0, 44031, '\p{^Block=--Meetei_Mayek}', "");
Expect(0, 44031, '\P{Block=--Meetei_Mayek}', "");
Expect(1, 44031, '\P{^Block=--Meetei_Mayek}', "");
Expect(0, 44032, '\p{Block=--Meetei_Mayek}', "");
Expect(1, 44032, '\p{^Block=--Meetei_Mayek}', "");
Expect(1, 44032, '\P{Block=--Meetei_Mayek}', "");
Expect(0, 44032, '\P{^Block=--Meetei_Mayek}', "");
Error('\p{Blk=-	meetei_mayek/a/}');
Error('\P{Blk=-	meetei_mayek/a/}');
Expect(1, 44031, '\p{Blk=meeteimayek}', "");
Expect(0, 44031, '\p{^Blk=meeteimayek}', "");
Expect(0, 44031, '\P{Blk=meeteimayek}', "");
Expect(1, 44031, '\P{^Blk=meeteimayek}', "");
Expect(0, 44032, '\p{Blk=meeteimayek}', "");
Expect(1, 44032, '\p{^Blk=meeteimayek}', "");
Expect(1, 44032, '\P{Blk=meeteimayek}', "");
Expect(0, 44032, '\P{^Blk=meeteimayek}', "");
Expect(1, 44031, '\p{Blk= Meetei_mayek}', "");
Expect(0, 44031, '\p{^Blk= Meetei_mayek}', "");
Expect(0, 44031, '\P{Blk= Meetei_mayek}', "");
Expect(1, 44031, '\P{^Blk= Meetei_mayek}', "");
Expect(0, 44032, '\p{Blk= Meetei_mayek}', "");
Expect(1, 44032, '\p{^Blk= Meetei_mayek}', "");
Expect(1, 44032, '\P{Blk= Meetei_mayek}', "");
Expect(0, 44032, '\P{^Blk= Meetei_mayek}', "");
Error('\p{Is_Block=:= Meetei_Mayek}');
Error('\P{Is_Block=:= Meetei_Mayek}');
Expect(1, 44031, '\p{Is_Block=meeteimayek}', "");
Expect(0, 44031, '\p{^Is_Block=meeteimayek}', "");
Expect(0, 44031, '\P{Is_Block=meeteimayek}', "");
Expect(1, 44031, '\P{^Is_Block=meeteimayek}', "");
Expect(0, 44032, '\p{Is_Block=meeteimayek}', "");
Expect(1, 44032, '\p{^Is_Block=meeteimayek}', "");
Expect(1, 44032, '\P{Is_Block=meeteimayek}', "");
Expect(0, 44032, '\P{^Is_Block=meeteimayek}', "");
Expect(1, 44031, '\p{Is_Block=_meetei_mayek}', "");
Expect(0, 44031, '\p{^Is_Block=_meetei_mayek}', "");
Expect(0, 44031, '\P{Is_Block=_meetei_mayek}', "");
Expect(1, 44031, '\P{^Is_Block=_meetei_mayek}', "");
Expect(0, 44032, '\p{Is_Block=_meetei_mayek}', "");
Expect(1, 44032, '\p{^Is_Block=_meetei_mayek}', "");
Expect(1, 44032, '\P{Is_Block=_meetei_mayek}', "");
Expect(0, 44032, '\P{^Is_Block=_meetei_mayek}', "");
Error('\p{Is_Blk=	meetei_Mayek:=}');
Error('\P{Is_Blk=	meetei_Mayek:=}');
Expect(1, 44031, '\p{Is_Blk=meeteimayek}', "");
Expect(0, 44031, '\p{^Is_Blk=meeteimayek}', "");
Expect(0, 44031, '\P{Is_Blk=meeteimayek}', "");
Expect(1, 44031, '\P{^Is_Blk=meeteimayek}', "");
Expect(0, 44032, '\p{Is_Blk=meeteimayek}', "");
Expect(1, 44032, '\p{^Is_Blk=meeteimayek}', "");
Expect(1, 44032, '\P{Is_Blk=meeteimayek}', "");
Expect(0, 44032, '\P{^Is_Blk=meeteimayek}', "");
Expect(1, 44031, '\p{Is_Blk= -MEETEI_MAYEK}', "");
Expect(0, 44031, '\p{^Is_Blk= -MEETEI_MAYEK}', "");
Expect(0, 44031, '\P{Is_Blk= -MEETEI_MAYEK}', "");
Expect(1, 44031, '\P{^Is_Blk= -MEETEI_MAYEK}', "");
Expect(0, 44032, '\p{Is_Blk= -MEETEI_MAYEK}', "");
Expect(1, 44032, '\p{^Is_Blk= -MEETEI_MAYEK}', "");
Expect(1, 44032, '\P{Is_Blk= -MEETEI_MAYEK}', "");
Expect(0, 44032, '\P{^Is_Blk= -MEETEI_MAYEK}', "");
Error('\p{Block=	:=meetei_Mayek_extensions}');
Error('\P{Block=	:=meetei_Mayek_extensions}');
Expect(1, 43775, '\p{Block:   meeteimayekextensions}', "");
Expect(0, 43775, '\p{^Block:   meeteimayekextensions}', "");
Expect(0, 43775, '\P{Block:   meeteimayekextensions}', "");
Expect(1, 43775, '\P{^Block:   meeteimayekextensions}', "");
Expect(0, 43776, '\p{Block:   meeteimayekextensions}', "");
Expect(1, 43776, '\p{^Block:   meeteimayekextensions}', "");
Expect(1, 43776, '\P{Block:   meeteimayekextensions}', "");
Expect(0, 43776, '\P{^Block:   meeteimayekextensions}', "");
Expect(1, 43775, '\p{Block=-meetei_Mayek_extensions}', "");
Expect(0, 43775, '\p{^Block=-meetei_Mayek_extensions}', "");
Expect(0, 43775, '\P{Block=-meetei_Mayek_extensions}', "");
Expect(1, 43775, '\P{^Block=-meetei_Mayek_extensions}', "");
Expect(0, 43776, '\p{Block=-meetei_Mayek_extensions}', "");
Expect(1, 43776, '\p{^Block=-meetei_Mayek_extensions}', "");
Expect(1, 43776, '\P{Block=-meetei_Mayek_extensions}', "");
Expect(0, 43776, '\P{^Block=-meetei_Mayek_extensions}', "");
Error('\p{Blk=:=_-Meetei_Mayek_Ext}');
Error('\P{Blk=:=_-Meetei_Mayek_Ext}');
Expect(1, 43775, '\p{Blk=meeteimayekext}', "");
Expect(0, 43775, '\p{^Blk=meeteimayekext}', "");
Expect(0, 43775, '\P{Blk=meeteimayekext}', "");
Expect(1, 43775, '\P{^Blk=meeteimayekext}', "");
Expect(0, 43776, '\p{Blk=meeteimayekext}', "");
Expect(1, 43776, '\p{^Blk=meeteimayekext}', "");
Expect(1, 43776, '\P{Blk=meeteimayekext}', "");
Expect(0, 43776, '\P{^Blk=meeteimayekext}', "");
Expect(1, 43775, '\p{Blk:    Meetei_Mayek_Ext}', "");
Expect(0, 43775, '\p{^Blk:    Meetei_Mayek_Ext}', "");
Expect(0, 43775, '\P{Blk:    Meetei_Mayek_Ext}', "");
Expect(1, 43775, '\P{^Blk:    Meetei_Mayek_Ext}', "");
Expect(0, 43776, '\p{Blk:    Meetei_Mayek_Ext}', "");
Expect(1, 43776, '\p{^Blk:    Meetei_Mayek_Ext}', "");
Expect(1, 43776, '\P{Blk:    Meetei_Mayek_Ext}', "");
Expect(0, 43776, '\P{^Blk:    Meetei_Mayek_Ext}', "");
Error('\p{Is_Block=:=Meetei_Mayek_extensions}');
Error('\P{Is_Block=:=Meetei_Mayek_extensions}');
Expect(1, 43775, '\p{Is_Block:   meeteimayekextensions}', "");
Expect(0, 43775, '\p{^Is_Block:   meeteimayekextensions}', "");
Expect(0, 43775, '\P{Is_Block:   meeteimayekextensions}', "");
Expect(1, 43775, '\P{^Is_Block:   meeteimayekextensions}', "");
Expect(0, 43776, '\p{Is_Block:   meeteimayekextensions}', "");
Expect(1, 43776, '\p{^Is_Block:   meeteimayekextensions}', "");
Expect(1, 43776, '\P{Is_Block:   meeteimayekextensions}', "");
Expect(0, 43776, '\P{^Is_Block:   meeteimayekextensions}', "");
Expect(1, 43775, '\p{Is_Block=	meetei_Mayek_EXTENSIONS}', "");
Expect(0, 43775, '\p{^Is_Block=	meetei_Mayek_EXTENSIONS}', "");
Expect(0, 43775, '\P{Is_Block=	meetei_Mayek_EXTENSIONS}', "");
Expect(1, 43775, '\P{^Is_Block=	meetei_Mayek_EXTENSIONS}', "");
Expect(0, 43776, '\p{Is_Block=	meetei_Mayek_EXTENSIONS}', "");
Expect(1, 43776, '\p{^Is_Block=	meetei_Mayek_EXTENSIONS}', "");
Expect(1, 43776, '\P{Is_Block=	meetei_Mayek_EXTENSIONS}', "");
Expect(0, 43776, '\P{^Is_Block=	meetei_Mayek_EXTENSIONS}', "");
Error('\p{Is_Blk=:= 	MEETEI_Mayek_ext}');
Error('\P{Is_Blk=:= 	MEETEI_Mayek_ext}');
Expect(1, 43775, '\p{Is_Blk=meeteimayekext}', "");
Expect(0, 43775, '\p{^Is_Blk=meeteimayekext}', "");
Expect(0, 43775, '\P{Is_Blk=meeteimayekext}', "");
Expect(1, 43775, '\P{^Is_Blk=meeteimayekext}', "");
Expect(0, 43776, '\p{Is_Blk=meeteimayekext}', "");
Expect(1, 43776, '\p{^Is_Blk=meeteimayekext}', "");
Expect(1, 43776, '\P{Is_Blk=meeteimayekext}', "");
Expect(0, 43776, '\P{^Is_Blk=meeteimayekext}', "");
Expect(1, 43775, '\p{Is_Blk= -MEETEI_mayek_Ext}', "");
Expect(0, 43775, '\p{^Is_Blk= -MEETEI_mayek_Ext}', "");
Expect(0, 43775, '\P{Is_Blk= -MEETEI_mayek_Ext}', "");
Expect(1, 43775, '\P{^Is_Blk= -MEETEI_mayek_Ext}', "");
Expect(0, 43776, '\p{Is_Blk= -MEETEI_mayek_Ext}', "");
Expect(1, 43776, '\p{^Is_Blk= -MEETEI_mayek_Ext}', "");
Expect(1, 43776, '\P{Is_Blk= -MEETEI_mayek_Ext}', "");
Expect(0, 43776, '\P{^Is_Blk= -MEETEI_mayek_Ext}', "");
Error('\p{Block:_-meroitic_Cursive/a/}');
Error('\P{Block:_-meroitic_Cursive/a/}');
Expect(1, 68095, '\p{Block=meroiticcursive}', "");
Expect(0, 68095, '\p{^Block=meroiticcursive}', "");
Expect(0, 68095, '\P{Block=meroiticcursive}', "");
Expect(1, 68095, '\P{^Block=meroiticcursive}', "");
Expect(0, 68096, '\p{Block=meroiticcursive}', "");
Expect(1, 68096, '\p{^Block=meroiticcursive}', "");
Expect(1, 68096, '\P{Block=meroiticcursive}', "");
Expect(0, 68096, '\P{^Block=meroiticcursive}', "");
Expect(1, 68095, '\p{Block=	Meroitic_cursive}', "");
Expect(0, 68095, '\p{^Block=	Meroitic_cursive}', "");
Expect(0, 68095, '\P{Block=	Meroitic_cursive}', "");
Expect(1, 68095, '\P{^Block=	Meroitic_cursive}', "");
Expect(0, 68096, '\p{Block=	Meroitic_cursive}', "");
Expect(1, 68096, '\p{^Block=	Meroitic_cursive}', "");
Expect(1, 68096, '\P{Block=	Meroitic_cursive}', "");
Expect(0, 68096, '\P{^Block=	Meroitic_cursive}', "");
Error('\p{Blk: /a/__MEROITIC_CURSIVE}');
Error('\P{Blk: /a/__MEROITIC_CURSIVE}');
Expect(1, 68095, '\p{Blk:	meroiticcursive}', "");
Expect(0, 68095, '\p{^Blk:	meroiticcursive}', "");
Expect(0, 68095, '\P{Blk:	meroiticcursive}', "");
Expect(1, 68095, '\P{^Blk:	meroiticcursive}', "");
Expect(0, 68096, '\p{Blk:	meroiticcursive}', "");
Expect(1, 68096, '\p{^Blk:	meroiticcursive}', "");
Expect(1, 68096, '\P{Blk:	meroiticcursive}', "");
Expect(0, 68096, '\P{^Blk:	meroiticcursive}', "");
Expect(1, 68095, '\p{Blk=	_meroitic_Cursive}', "");
Expect(0, 68095, '\p{^Blk=	_meroitic_Cursive}', "");
Expect(0, 68095, '\P{Blk=	_meroitic_Cursive}', "");
Expect(1, 68095, '\P{^Blk=	_meroitic_Cursive}', "");
Expect(0, 68096, '\p{Blk=	_meroitic_Cursive}', "");
Expect(1, 68096, '\p{^Blk=	_meroitic_Cursive}', "");
Expect(1, 68096, '\P{Blk=	_meroitic_Cursive}', "");
Expect(0, 68096, '\P{^Blk=	_meroitic_Cursive}', "");
Error('\p{Is_Block=-:=MEROITIC_Cursive}');
Error('\P{Is_Block=-:=MEROITIC_Cursive}');
Expect(1, 68095, '\p{Is_Block=meroiticcursive}', "");
Expect(0, 68095, '\p{^Is_Block=meroiticcursive}', "");
Expect(0, 68095, '\P{Is_Block=meroiticcursive}', "");
Expect(1, 68095, '\P{^Is_Block=meroiticcursive}', "");
Expect(0, 68096, '\p{Is_Block=meroiticcursive}', "");
Expect(1, 68096, '\p{^Is_Block=meroiticcursive}', "");
Expect(1, 68096, '\P{Is_Block=meroiticcursive}', "");
Expect(0, 68096, '\P{^Is_Block=meroiticcursive}', "");
Expect(1, 68095, '\p{Is_Block=_MEROITIC_CURSIVE}', "");
Expect(0, 68095, '\p{^Is_Block=_MEROITIC_CURSIVE}', "");
Expect(0, 68095, '\P{Is_Block=_MEROITIC_CURSIVE}', "");
Expect(1, 68095, '\P{^Is_Block=_MEROITIC_CURSIVE}', "");
Expect(0, 68096, '\p{Is_Block=_MEROITIC_CURSIVE}', "");
Expect(1, 68096, '\p{^Is_Block=_MEROITIC_CURSIVE}', "");
Expect(1, 68096, '\P{Is_Block=_MEROITIC_CURSIVE}', "");
Expect(0, 68096, '\P{^Is_Block=_MEROITIC_CURSIVE}', "");
Error('\p{Is_Blk=  meroitic_Cursive:=}');
Error('\P{Is_Blk=  meroitic_Cursive:=}');
Expect(1, 68095, '\p{Is_Blk=meroiticcursive}', "");
Expect(0, 68095, '\p{^Is_Blk=meroiticcursive}', "");
Expect(0, 68095, '\P{Is_Blk=meroiticcursive}', "");
Expect(1, 68095, '\P{^Is_Blk=meroiticcursive}', "");
Expect(0, 68096, '\p{Is_Blk=meroiticcursive}', "");
Expect(1, 68096, '\p{^Is_Blk=meroiticcursive}', "");
Expect(1, 68096, '\P{Is_Blk=meroiticcursive}', "");
Expect(0, 68096, '\P{^Is_Blk=meroiticcursive}', "");
Expect(1, 68095, '\p{Is_Blk=_ meroitic_cursive}', "");
Expect(0, 68095, '\p{^Is_Blk=_ meroitic_cursive}', "");
Expect(0, 68095, '\P{Is_Blk=_ meroitic_cursive}', "");
Expect(1, 68095, '\P{^Is_Blk=_ meroitic_cursive}', "");
Expect(0, 68096, '\p{Is_Blk=_ meroitic_cursive}', "");
Expect(1, 68096, '\p{^Is_Blk=_ meroitic_cursive}', "");
Expect(1, 68096, '\P{Is_Blk=_ meroitic_cursive}', "");
Expect(0, 68096, '\P{^Is_Blk=_ meroitic_cursive}', "");
Error('\p{Block: _:=Meroitic_hieroglyphs}');
Error('\P{Block: _:=Meroitic_hieroglyphs}');
Expect(1, 67999, '\p{Block=meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^Block=meroitichieroglyphs}', "");
Expect(0, 67999, '\P{Block=meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^Block=meroitichieroglyphs}', "");
Expect(0, 68000, '\p{Block=meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^Block=meroitichieroglyphs}', "");
Expect(1, 68000, '\P{Block=meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^Block=meroitichieroglyphs}', "");
Expect(1, 67999, '\p{Block=	-Meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\p{^Block=	-Meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\P{Block=	-Meroitic_Hieroglyphs}', "");
Expect(1, 67999, '\P{^Block=	-Meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\p{Block=	-Meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\p{^Block=	-Meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\P{Block=	-Meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\P{^Block=	-Meroitic_Hieroglyphs}', "");
Error('\p{Blk=/a/ Meroitic_Hieroglyphs}');
Error('\P{Blk=/a/ Meroitic_Hieroglyphs}');
Expect(1, 67999, '\p{Blk=meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^Blk=meroitichieroglyphs}', "");
Expect(0, 67999, '\P{Blk=meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^Blk=meroitichieroglyphs}', "");
Expect(0, 68000, '\p{Blk=meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^Blk=meroitichieroglyphs}', "");
Expect(1, 68000, '\P{Blk=meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^Blk=meroitichieroglyphs}', "");
Expect(1, 67999, '\p{Blk=		meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\p{^Blk=		meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\P{Blk=		meroitic_Hieroglyphs}', "");
Expect(1, 67999, '\P{^Blk=		meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\p{Blk=		meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\p{^Blk=		meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\P{Blk=		meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\P{^Blk=		meroitic_Hieroglyphs}', "");
Error('\p{Is_Block= _Meroitic_Hieroglyphs:=}');
Error('\P{Is_Block= _Meroitic_Hieroglyphs:=}');
Expect(1, 67999, '\p{Is_Block=meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^Is_Block=meroitichieroglyphs}', "");
Expect(0, 67999, '\P{Is_Block=meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^Is_Block=meroitichieroglyphs}', "");
Expect(0, 68000, '\p{Is_Block=meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^Is_Block=meroitichieroglyphs}', "");
Expect(1, 68000, '\P{Is_Block=meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^Is_Block=meroitichieroglyphs}', "");
Expect(1, 67999, '\p{Is_Block= meroitic_HIEROGLYPHS}', "");
Expect(0, 67999, '\p{^Is_Block= meroitic_HIEROGLYPHS}', "");
Expect(0, 67999, '\P{Is_Block= meroitic_HIEROGLYPHS}', "");
Expect(1, 67999, '\P{^Is_Block= meroitic_HIEROGLYPHS}', "");
Expect(0, 68000, '\p{Is_Block= meroitic_HIEROGLYPHS}', "");
Expect(1, 68000, '\p{^Is_Block= meroitic_HIEROGLYPHS}', "");
Expect(1, 68000, '\P{Is_Block= meroitic_HIEROGLYPHS}', "");
Expect(0, 68000, '\P{^Is_Block= meroitic_HIEROGLYPHS}', "");
Error('\p{Is_Blk=:=-Meroitic_Hieroglyphs}');
Error('\P{Is_Blk=:=-Meroitic_Hieroglyphs}');
Expect(1, 67999, '\p{Is_Blk=meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^Is_Blk=meroitichieroglyphs}', "");
Expect(0, 67999, '\P{Is_Blk=meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^Is_Blk=meroitichieroglyphs}', "");
Expect(0, 68000, '\p{Is_Blk=meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^Is_Blk=meroitichieroglyphs}', "");
Expect(1, 68000, '\P{Is_Blk=meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^Is_Blk=meroitichieroglyphs}', "");
Expect(1, 67999, '\p{Is_Blk=	Meroitic_hieroglyphs}', "");
Expect(0, 67999, '\p{^Is_Blk=	Meroitic_hieroglyphs}', "");
Expect(0, 67999, '\P{Is_Blk=	Meroitic_hieroglyphs}', "");
Expect(1, 67999, '\P{^Is_Blk=	Meroitic_hieroglyphs}', "");
Expect(0, 68000, '\p{Is_Blk=	Meroitic_hieroglyphs}', "");
Expect(1, 68000, '\p{^Is_Blk=	Meroitic_hieroglyphs}', "");
Expect(1, 68000, '\P{Is_Blk=	Meroitic_hieroglyphs}', "");
Expect(0, 68000, '\P{^Is_Blk=	Meroitic_hieroglyphs}', "");
Error('\p{Block=:= Miao}');
Error('\P{Block=:= Miao}');
Expect(1, 94111, '\p{Block=miao}', "");
Expect(0, 94111, '\p{^Block=miao}', "");
Expect(0, 94111, '\P{Block=miao}', "");
Expect(1, 94111, '\P{^Block=miao}', "");
Expect(0, 94112, '\p{Block=miao}', "");
Expect(1, 94112, '\p{^Block=miao}', "");
Expect(1, 94112, '\P{Block=miao}', "");
Expect(0, 94112, '\P{^Block=miao}', "");
Expect(1, 94111, '\p{Block=_ Miao}', "");
Expect(0, 94111, '\p{^Block=_ Miao}', "");
Expect(0, 94111, '\P{Block=_ Miao}', "");
Expect(1, 94111, '\P{^Block=_ Miao}', "");
Expect(0, 94112, '\p{Block=_ Miao}', "");
Expect(1, 94112, '\p{^Block=_ Miao}', "");
Expect(1, 94112, '\P{Block=_ Miao}', "");
Expect(0, 94112, '\P{^Block=_ Miao}', "");
Error('\p{Blk=:=Miao}');
Error('\P{Blk=:=Miao}');
Expect(1, 94111, '\p{Blk:	miao}', "");
Expect(0, 94111, '\p{^Blk:	miao}', "");
Expect(0, 94111, '\P{Blk:	miao}', "");
Expect(1, 94111, '\P{^Blk:	miao}', "");
Expect(0, 94112, '\p{Blk:	miao}', "");
Expect(1, 94112, '\p{^Blk:	miao}', "");
Expect(1, 94112, '\P{Blk:	miao}', "");
Expect(0, 94112, '\P{^Blk:	miao}', "");
Expect(1, 94111, '\p{Blk: 	-miao}', "");
Expect(0, 94111, '\p{^Blk: 	-miao}', "");
Expect(0, 94111, '\P{Blk: 	-miao}', "");
Expect(1, 94111, '\P{^Blk: 	-miao}', "");
Expect(0, 94112, '\p{Blk: 	-miao}', "");
Expect(1, 94112, '\p{^Blk: 	-miao}', "");
Expect(1, 94112, '\P{Blk: 	-miao}', "");
Expect(0, 94112, '\P{^Blk: 	-miao}', "");
Error('\p{Is_Block=:= _miao}');
Error('\P{Is_Block=:= _miao}');
Expect(1, 94111, '\p{Is_Block:   miao}', "");
Expect(0, 94111, '\p{^Is_Block:   miao}', "");
Expect(0, 94111, '\P{Is_Block:   miao}', "");
Expect(1, 94111, '\P{^Is_Block:   miao}', "");
Expect(0, 94112, '\p{Is_Block:   miao}', "");
Expect(1, 94112, '\p{^Is_Block:   miao}', "");
Expect(1, 94112, '\P{Is_Block:   miao}', "");
Expect(0, 94112, '\P{^Is_Block:   miao}', "");
Expect(1, 94111, '\p{Is_Block=--MIAO}', "");
Expect(0, 94111, '\p{^Is_Block=--MIAO}', "");
Expect(0, 94111, '\P{Is_Block=--MIAO}', "");
Expect(1, 94111, '\P{^Is_Block=--MIAO}', "");
Expect(0, 94112, '\p{Is_Block=--MIAO}', "");
Expect(1, 94112, '\p{^Is_Block=--MIAO}', "");
Expect(1, 94112, '\P{Is_Block=--MIAO}', "");
Expect(0, 94112, '\P{^Is_Block=--MIAO}', "");
Error('\p{Is_Blk=  Miao/a/}');
Error('\P{Is_Blk=  Miao/a/}');
Expect(1, 94111, '\p{Is_Blk=miao}', "");
Expect(0, 94111, '\p{^Is_Blk=miao}', "");
Expect(0, 94111, '\P{Is_Blk=miao}', "");
Expect(1, 94111, '\P{^Is_Blk=miao}', "");
Expect(0, 94112, '\p{Is_Blk=miao}', "");
Expect(1, 94112, '\p{^Is_Blk=miao}', "");
Expect(1, 94112, '\P{Is_Blk=miao}', "");
Expect(0, 94112, '\P{^Is_Blk=miao}', "");
Expect(1, 94111, '\p{Is_Blk:   _-miao}', "");
Expect(0, 94111, '\p{^Is_Blk:   _-miao}', "");
Expect(0, 94111, '\P{Is_Blk:   _-miao}', "");
Expect(1, 94111, '\P{^Is_Blk:   _-miao}', "");
Expect(0, 94112, '\p{Is_Blk:   _-miao}', "");
Expect(1, 94112, '\p{^Is_Blk:   _-miao}', "");
Expect(1, 94112, '\P{Is_Blk:   _-miao}', "");
Expect(0, 94112, '\P{^Is_Blk:   _-miao}', "");
Error('\p{Block=-:=MISCELLANEOUS_SYMBOLS_and_Arrows}');
Error('\P{Block=-:=MISCELLANEOUS_SYMBOLS_and_Arrows}');
Expect(1, 11263, '\p{Block=miscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\p{^Block=miscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\P{Block=miscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\P{^Block=miscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\p{Block=miscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\p{^Block=miscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\P{Block=miscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\P{^Block=miscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\p{Block=-	Miscellaneous_SYMBOLS_And_ARROWS}', "");
Expect(0, 11263, '\p{^Block=-	Miscellaneous_SYMBOLS_And_ARROWS}', "");
Expect(0, 11263, '\P{Block=-	Miscellaneous_SYMBOLS_And_ARROWS}', "");
Expect(1, 11263, '\P{^Block=-	Miscellaneous_SYMBOLS_And_ARROWS}', "");
Expect(0, 11264, '\p{Block=-	Miscellaneous_SYMBOLS_And_ARROWS}', "");
Expect(1, 11264, '\p{^Block=-	Miscellaneous_SYMBOLS_And_ARROWS}', "");
Expect(1, 11264, '\P{Block=-	Miscellaneous_SYMBOLS_And_ARROWS}', "");
Expect(0, 11264, '\P{^Block=-	Miscellaneous_SYMBOLS_And_ARROWS}', "");
Error('\p{Blk=	Misc_ARROWS:=}');
Error('\P{Blk=	Misc_ARROWS:=}');
Expect(1, 11263, '\p{Blk=miscarrows}', "");
Expect(0, 11263, '\p{^Blk=miscarrows}', "");
Expect(0, 11263, '\P{Blk=miscarrows}', "");
Expect(1, 11263, '\P{^Blk=miscarrows}', "");
Expect(0, 11264, '\p{Blk=miscarrows}', "");
Expect(1, 11264, '\p{^Blk=miscarrows}', "");
Expect(1, 11264, '\P{Blk=miscarrows}', "");
Expect(0, 11264, '\P{^Blk=miscarrows}', "");
Expect(1, 11263, '\p{Blk=- Misc_Arrows}', "");
Expect(0, 11263, '\p{^Blk=- Misc_Arrows}', "");
Expect(0, 11263, '\P{Blk=- Misc_Arrows}', "");
Expect(1, 11263, '\P{^Blk=- Misc_Arrows}', "");
Expect(0, 11264, '\p{Blk=- Misc_Arrows}', "");
Expect(1, 11264, '\p{^Blk=- Misc_Arrows}', "");
Expect(1, 11264, '\P{Blk=- Misc_Arrows}', "");
Expect(0, 11264, '\P{^Blk=- Misc_Arrows}', "");
Error('\p{Is_Block::=_-MISCELLANEOUS_Symbols_And_Arrows}');
Error('\P{Is_Block::=_-MISCELLANEOUS_Symbols_And_Arrows}');
Expect(1, 11263, '\p{Is_Block=miscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\p{^Is_Block=miscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\P{Is_Block=miscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\P{^Is_Block=miscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\p{Is_Block=miscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\p{^Is_Block=miscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\P{Is_Block=miscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\P{^Is_Block=miscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\p{Is_Block:	- Miscellaneous_Symbols_and_Arrows}', "");
Expect(0, 11263, '\p{^Is_Block:	- Miscellaneous_Symbols_and_Arrows}', "");
Expect(0, 11263, '\P{Is_Block:	- Miscellaneous_Symbols_and_Arrows}', "");
Expect(1, 11263, '\P{^Is_Block:	- Miscellaneous_Symbols_and_Arrows}', "");
Expect(0, 11264, '\p{Is_Block:	- Miscellaneous_Symbols_and_Arrows}', "");
Expect(1, 11264, '\p{^Is_Block:	- Miscellaneous_Symbols_and_Arrows}', "");
Expect(1, 11264, '\P{Is_Block:	- Miscellaneous_Symbols_and_Arrows}', "");
Expect(0, 11264, '\P{^Is_Block:	- Miscellaneous_Symbols_and_Arrows}', "");
Error('\p{Is_Blk: := -misc_ARROWS}');
Error('\P{Is_Blk: := -misc_ARROWS}');
Expect(1, 11263, '\p{Is_Blk=miscarrows}', "");
Expect(0, 11263, '\p{^Is_Blk=miscarrows}', "");
Expect(0, 11263, '\P{Is_Blk=miscarrows}', "");
Expect(1, 11263, '\P{^Is_Blk=miscarrows}', "");
Expect(0, 11264, '\p{Is_Blk=miscarrows}', "");
Expect(1, 11264, '\p{^Is_Blk=miscarrows}', "");
Expect(1, 11264, '\P{Is_Blk=miscarrows}', "");
Expect(0, 11264, '\P{^Is_Blk=miscarrows}', "");
Expect(1, 11263, '\p{Is_Blk= 	Misc_ARROWS}', "");
Expect(0, 11263, '\p{^Is_Blk= 	Misc_ARROWS}', "");
Expect(0, 11263, '\P{Is_Blk= 	Misc_ARROWS}', "");
Expect(1, 11263, '\P{^Is_Blk= 	Misc_ARROWS}', "");
Expect(0, 11264, '\p{Is_Blk= 	Misc_ARROWS}', "");
Expect(1, 11264, '\p{^Is_Blk= 	Misc_ARROWS}', "");
Expect(1, 11264, '\P{Is_Blk= 	Misc_ARROWS}', "");
Expect(0, 11264, '\P{^Is_Blk= 	Misc_ARROWS}', "");
Error('\p{Block= /a/Miscellaneous_mathematical_Symbols_A}');
Error('\P{Block= /a/Miscellaneous_mathematical_Symbols_A}');
Expect(1, 10223, '\p{Block=miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\p{^Block=miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\P{Block=miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\P{^Block=miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\p{Block=miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\p{^Block=miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\P{Block=miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\P{^Block=miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\p{Block=  MISCELLANEOUS_mathematical_SYMBOLS_a}', "");
Expect(0, 10223, '\p{^Block=  MISCELLANEOUS_mathematical_SYMBOLS_a}', "");
Expect(0, 10223, '\P{Block=  MISCELLANEOUS_mathematical_SYMBOLS_a}', "");
Expect(1, 10223, '\P{^Block=  MISCELLANEOUS_mathematical_SYMBOLS_a}', "");
Expect(0, 10224, '\p{Block=  MISCELLANEOUS_mathematical_SYMBOLS_a}', "");
Expect(1, 10224, '\p{^Block=  MISCELLANEOUS_mathematical_SYMBOLS_a}', "");
Expect(1, 10224, '\P{Block=  MISCELLANEOUS_mathematical_SYMBOLS_a}', "");
Expect(0, 10224, '\P{^Block=  MISCELLANEOUS_mathematical_SYMBOLS_a}', "");
Error('\p{Blk=:=Misc_Math_SYMBOLS_a}');
Error('\P{Blk=:=Misc_Math_SYMBOLS_a}');
Expect(1, 10223, '\p{Blk=miscmathsymbolsa}', "");
Expect(0, 10223, '\p{^Blk=miscmathsymbolsa}', "");
Expect(0, 10223, '\P{Blk=miscmathsymbolsa}', "");
Expect(1, 10223, '\P{^Blk=miscmathsymbolsa}', "");
Expect(0, 10224, '\p{Blk=miscmathsymbolsa}', "");
Expect(1, 10224, '\p{^Blk=miscmathsymbolsa}', "");
Expect(1, 10224, '\P{Blk=miscmathsymbolsa}', "");
Expect(0, 10224, '\P{^Blk=miscmathsymbolsa}', "");
Expect(1, 10223, '\p{Blk=  Misc_MATH_SYMBOLS_A}', "");
Expect(0, 10223, '\p{^Blk=  Misc_MATH_SYMBOLS_A}', "");
Expect(0, 10223, '\P{Blk=  Misc_MATH_SYMBOLS_A}', "");
Expect(1, 10223, '\P{^Blk=  Misc_MATH_SYMBOLS_A}', "");
Expect(0, 10224, '\p{Blk=  Misc_MATH_SYMBOLS_A}', "");
Expect(1, 10224, '\p{^Blk=  Misc_MATH_SYMBOLS_A}', "");
Expect(1, 10224, '\P{Blk=  Misc_MATH_SYMBOLS_A}', "");
Expect(0, 10224, '\P{^Blk=  Misc_MATH_SYMBOLS_A}', "");
Error('\p{Is_Block=--miscellaneous_Mathematical_SYMBOLS_A/a/}');
Error('\P{Is_Block=--miscellaneous_Mathematical_SYMBOLS_A/a/}');
Expect(1, 10223, '\p{Is_Block=miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\p{^Is_Block=miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\P{Is_Block=miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\P{^Is_Block=miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\p{Is_Block=miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\p{^Is_Block=miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\P{Is_Block=miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\P{^Is_Block=miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\p{Is_Block=Miscellaneous_mathematical_Symbols_a}', "");
Expect(0, 10223, '\p{^Is_Block=Miscellaneous_mathematical_Symbols_a}', "");
Expect(0, 10223, '\P{Is_Block=Miscellaneous_mathematical_Symbols_a}', "");
Expect(1, 10223, '\P{^Is_Block=Miscellaneous_mathematical_Symbols_a}', "");
Expect(0, 10224, '\p{Is_Block=Miscellaneous_mathematical_Symbols_a}', "");
Expect(1, 10224, '\p{^Is_Block=Miscellaneous_mathematical_Symbols_a}', "");
Expect(1, 10224, '\P{Is_Block=Miscellaneous_mathematical_Symbols_a}', "");
Expect(0, 10224, '\P{^Is_Block=Miscellaneous_mathematical_Symbols_a}', "");
Error('\p{Is_Blk: - Misc_Math_symbols_A:=}');
Error('\P{Is_Blk: - Misc_Math_symbols_A:=}');
Expect(1, 10223, '\p{Is_Blk=miscmathsymbolsa}', "");
Expect(0, 10223, '\p{^Is_Blk=miscmathsymbolsa}', "");
Expect(0, 10223, '\P{Is_Blk=miscmathsymbolsa}', "");
Expect(1, 10223, '\P{^Is_Blk=miscmathsymbolsa}', "");
Expect(0, 10224, '\p{Is_Blk=miscmathsymbolsa}', "");
Expect(1, 10224, '\p{^Is_Blk=miscmathsymbolsa}', "");
Expect(1, 10224, '\P{Is_Blk=miscmathsymbolsa}', "");
Expect(0, 10224, '\P{^Is_Blk=miscmathsymbolsa}', "");
Expect(1, 10223, '\p{Is_Blk: 	_MISC_math_SYMBOLS_a}', "");
Expect(0, 10223, '\p{^Is_Blk: 	_MISC_math_SYMBOLS_a}', "");
Expect(0, 10223, '\P{Is_Blk: 	_MISC_math_SYMBOLS_a}', "");
Expect(1, 10223, '\P{^Is_Blk: 	_MISC_math_SYMBOLS_a}', "");
Expect(0, 10224, '\p{Is_Blk: 	_MISC_math_SYMBOLS_a}', "");
Expect(1, 10224, '\p{^Is_Blk: 	_MISC_math_SYMBOLS_a}', "");
Expect(1, 10224, '\P{Is_Blk: 	_MISC_math_SYMBOLS_a}', "");
Expect(0, 10224, '\P{^Is_Blk: 	_MISC_math_SYMBOLS_a}', "");
Error('\p{Block= miscellaneous_MATHEMATICAL_Symbols_b/a/}');
Error('\P{Block= miscellaneous_MATHEMATICAL_Symbols_b/a/}');
Expect(1, 10751, '\p{Block=miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\p{^Block=miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\P{Block=miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\P{^Block=miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\p{Block=miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\p{^Block=miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\P{Block=miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\P{^Block=miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\p{Block: 	Miscellaneous_MATHEMATICAL_Symbols_B}', "");
Expect(0, 10751, '\p{^Block: 	Miscellaneous_MATHEMATICAL_Symbols_B}', "");
Expect(0, 10751, '\P{Block: 	Miscellaneous_MATHEMATICAL_Symbols_B}', "");
Expect(1, 10751, '\P{^Block: 	Miscellaneous_MATHEMATICAL_Symbols_B}', "");
Expect(0, 10752, '\p{Block: 	Miscellaneous_MATHEMATICAL_Symbols_B}', "");
Expect(1, 10752, '\p{^Block: 	Miscellaneous_MATHEMATICAL_Symbols_B}', "");
Expect(1, 10752, '\P{Block: 	Miscellaneous_MATHEMATICAL_Symbols_B}', "");
Expect(0, 10752, '\P{^Block: 	Miscellaneous_MATHEMATICAL_Symbols_B}', "");
Error('\p{Blk=:=--MISC_MATH_symbols_B}');
Error('\P{Blk=:=--MISC_MATH_symbols_B}');
Expect(1, 10751, '\p{Blk=miscmathsymbolsb}', "");
Expect(0, 10751, '\p{^Blk=miscmathsymbolsb}', "");
Expect(0, 10751, '\P{Blk=miscmathsymbolsb}', "");
Expect(1, 10751, '\P{^Blk=miscmathsymbolsb}', "");
Expect(0, 10752, '\p{Blk=miscmathsymbolsb}', "");
Expect(1, 10752, '\p{^Blk=miscmathsymbolsb}', "");
Expect(1, 10752, '\P{Blk=miscmathsymbolsb}', "");
Expect(0, 10752, '\P{^Blk=miscmathsymbolsb}', "");
Expect(1, 10751, '\p{Blk=	 Misc_Math_Symbols_b}', "");
Expect(0, 10751, '\p{^Blk=	 Misc_Math_Symbols_b}', "");
Expect(0, 10751, '\P{Blk=	 Misc_Math_Symbols_b}', "");
Expect(1, 10751, '\P{^Blk=	 Misc_Math_Symbols_b}', "");
Expect(0, 10752, '\p{Blk=	 Misc_Math_Symbols_b}', "");
Expect(1, 10752, '\p{^Blk=	 Misc_Math_Symbols_b}', "");
Expect(1, 10752, '\P{Blk=	 Misc_Math_Symbols_b}', "");
Expect(0, 10752, '\P{^Blk=	 Misc_Math_Symbols_b}', "");
Error('\p{Is_Block=--Miscellaneous_Mathematical_symbols_B/a/}');
Error('\P{Is_Block=--Miscellaneous_Mathematical_symbols_B/a/}');
Expect(1, 10751, '\p{Is_Block=miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\p{^Is_Block=miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\P{Is_Block=miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\P{^Is_Block=miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\p{Is_Block=miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\p{^Is_Block=miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\P{Is_Block=miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\P{^Is_Block=miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\p{Is_Block=Miscellaneous_MATHEMATICAL_SYMBOLS_B}', "");
Expect(0, 10751, '\p{^Is_Block=Miscellaneous_MATHEMATICAL_SYMBOLS_B}', "");
Expect(0, 10751, '\P{Is_Block=Miscellaneous_MATHEMATICAL_SYMBOLS_B}', "");
Expect(1, 10751, '\P{^Is_Block=Miscellaneous_MATHEMATICAL_SYMBOLS_B}', "");
Expect(0, 10752, '\p{Is_Block=Miscellaneous_MATHEMATICAL_SYMBOLS_B}', "");
Expect(1, 10752, '\p{^Is_Block=Miscellaneous_MATHEMATICAL_SYMBOLS_B}', "");
Expect(1, 10752, '\P{Is_Block=Miscellaneous_MATHEMATICAL_SYMBOLS_B}', "");
Expect(0, 10752, '\P{^Is_Block=Miscellaneous_MATHEMATICAL_SYMBOLS_B}', "");
Error('\p{Is_Blk=/a/--Misc_Math_Symbols_B}');
Error('\P{Is_Blk=/a/--Misc_Math_Symbols_B}');
Expect(1, 10751, '\p{Is_Blk=miscmathsymbolsb}', "");
Expect(0, 10751, '\p{^Is_Blk=miscmathsymbolsb}', "");
Expect(0, 10751, '\P{Is_Blk=miscmathsymbolsb}', "");
Expect(1, 10751, '\P{^Is_Blk=miscmathsymbolsb}', "");
Expect(0, 10752, '\p{Is_Blk=miscmathsymbolsb}', "");
Expect(1, 10752, '\p{^Is_Blk=miscmathsymbolsb}', "");
Expect(1, 10752, '\P{Is_Blk=miscmathsymbolsb}', "");
Expect(0, 10752, '\P{^Is_Blk=miscmathsymbolsb}', "");
Expect(1, 10751, '\p{Is_Blk:   Misc_MATH_Symbols_b}', "");
Expect(0, 10751, '\p{^Is_Blk:   Misc_MATH_Symbols_b}', "");
Expect(0, 10751, '\P{Is_Blk:   Misc_MATH_Symbols_b}', "");
Expect(1, 10751, '\P{^Is_Blk:   Misc_MATH_Symbols_b}', "");
Expect(0, 10752, '\p{Is_Blk:   Misc_MATH_Symbols_b}', "");
Expect(1, 10752, '\p{^Is_Blk:   Misc_MATH_Symbols_b}', "");
Expect(1, 10752, '\P{Is_Blk:   Misc_MATH_Symbols_b}', "");
Expect(0, 10752, '\P{^Is_Blk:   Misc_MATH_Symbols_b}', "");
Error('\p{Block: 	Miscellaneous_Symbols_and_PICTOGRAPHS/a/}');
Error('\P{Block: 	Miscellaneous_Symbols_and_PICTOGRAPHS/a/}');
Expect(1, 128511, '\p{Block=miscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\p{^Block=miscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\P{Block=miscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\P{^Block=miscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\p{Block=miscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\p{^Block=miscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\P{Block=miscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\P{^Block=miscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\p{Block=_	miscellaneous_Symbols_and_PICTOGRAPHS}', "");
Expect(0, 128511, '\p{^Block=_	miscellaneous_Symbols_and_PICTOGRAPHS}', "");
Expect(0, 128511, '\P{Block=_	miscellaneous_Symbols_and_PICTOGRAPHS}', "");
Expect(1, 128511, '\P{^Block=_	miscellaneous_Symbols_and_PICTOGRAPHS}', "");
Expect(0, 128512, '\p{Block=_	miscellaneous_Symbols_and_PICTOGRAPHS}', "");
Expect(1, 128512, '\p{^Block=_	miscellaneous_Symbols_and_PICTOGRAPHS}', "");
Expect(1, 128512, '\P{Block=_	miscellaneous_Symbols_and_PICTOGRAPHS}', "");
Expect(0, 128512, '\P{^Block=_	miscellaneous_Symbols_and_PICTOGRAPHS}', "");
Error('\p{Blk=	:=Misc_Pictographs}');
Error('\P{Blk=	:=Misc_Pictographs}');
Expect(1, 128511, '\p{Blk=miscpictographs}', "");
Expect(0, 128511, '\p{^Blk=miscpictographs}', "");
Expect(0, 128511, '\P{Blk=miscpictographs}', "");
Expect(1, 128511, '\P{^Blk=miscpictographs}', "");
Expect(0, 128512, '\p{Blk=miscpictographs}', "");
Expect(1, 128512, '\p{^Blk=miscpictographs}', "");
Expect(1, 128512, '\P{Blk=miscpictographs}', "");
Expect(0, 128512, '\P{^Blk=miscpictographs}', "");
Expect(1, 128511, '\p{Blk=_-Misc_pictographs}', "");
Expect(0, 128511, '\p{^Blk=_-Misc_pictographs}', "");
Expect(0, 128511, '\P{Blk=_-Misc_pictographs}', "");
Expect(1, 128511, '\P{^Blk=_-Misc_pictographs}', "");
Expect(0, 128512, '\p{Blk=_-Misc_pictographs}', "");
Expect(1, 128512, '\p{^Blk=_-Misc_pictographs}', "");
Expect(1, 128512, '\P{Blk=_-Misc_pictographs}', "");
Expect(0, 128512, '\P{^Blk=_-Misc_pictographs}', "");
Error('\p{Is_Block:/a/-Miscellaneous_symbols_and_PICTOGRAPHS}');
Error('\P{Is_Block:/a/-Miscellaneous_symbols_and_PICTOGRAPHS}');
Expect(1, 128511, '\p{Is_Block=miscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\p{^Is_Block=miscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\P{Is_Block=miscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\P{^Is_Block=miscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\p{Is_Block=miscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\p{^Is_Block=miscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\P{Is_Block=miscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\P{^Is_Block=miscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\p{Is_Block=__Miscellaneous_Symbols_AND_Pictographs}', "");
Expect(0, 128511, '\p{^Is_Block=__Miscellaneous_Symbols_AND_Pictographs}', "");
Expect(0, 128511, '\P{Is_Block=__Miscellaneous_Symbols_AND_Pictographs}', "");
Expect(1, 128511, '\P{^Is_Block=__Miscellaneous_Symbols_AND_Pictographs}', "");
Expect(0, 128512, '\p{Is_Block=__Miscellaneous_Symbols_AND_Pictographs}', "");
Expect(1, 128512, '\p{^Is_Block=__Miscellaneous_Symbols_AND_Pictographs}', "");
Expect(1, 128512, '\P{Is_Block=__Miscellaneous_Symbols_AND_Pictographs}', "");
Expect(0, 128512, '\P{^Is_Block=__Miscellaneous_Symbols_AND_Pictographs}', "");
Error('\p{Is_Blk=/a/--misc_Pictographs}');
Error('\P{Is_Blk=/a/--misc_Pictographs}');
Expect(1, 128511, '\p{Is_Blk=miscpictographs}', "");
Expect(0, 128511, '\p{^Is_Blk=miscpictographs}', "");
Expect(0, 128511, '\P{Is_Blk=miscpictographs}', "");
Expect(1, 128511, '\P{^Is_Blk=miscpictographs}', "");
Expect(0, 128512, '\p{Is_Blk=miscpictographs}', "");
Expect(1, 128512, '\p{^Is_Blk=miscpictographs}', "");
Expect(1, 128512, '\P{Is_Blk=miscpictographs}', "");
Expect(0, 128512, '\P{^Is_Blk=miscpictographs}', "");
Expect(1, 128511, '\p{Is_Blk:Misc_pictographs}', "");
Expect(0, 128511, '\p{^Is_Blk:Misc_pictographs}', "");
Expect(0, 128511, '\P{Is_Blk:Misc_pictographs}', "");
Expect(1, 128511, '\P{^Is_Blk:Misc_pictographs}', "");
Expect(0, 128512, '\p{Is_Blk:Misc_pictographs}', "");
Expect(1, 128512, '\p{^Is_Blk:Misc_pictographs}', "");
Expect(1, 128512, '\P{Is_Blk:Misc_pictographs}', "");
Expect(0, 128512, '\P{^Is_Blk:Misc_pictographs}', "");
Error('\p{Block=	_MISCELLANEOUS_Symbols/a/}');
Error('\P{Block=	_MISCELLANEOUS_Symbols/a/}');
Expect(1, 9983, '\p{Block=miscellaneoussymbols}', "");
Expect(0, 9983, '\p{^Block=miscellaneoussymbols}', "");
Expect(0, 9983, '\P{Block=miscellaneoussymbols}', "");
Expect(1, 9983, '\P{^Block=miscellaneoussymbols}', "");
Expect(0, 9984, '\p{Block=miscellaneoussymbols}', "");
Expect(1, 9984, '\p{^Block=miscellaneoussymbols}', "");
Expect(1, 9984, '\P{Block=miscellaneoussymbols}', "");
Expect(0, 9984, '\P{^Block=miscellaneoussymbols}', "");
Expect(1, 9983, '\p{Block= _MISCELLANEOUS_symbols}', "");
Expect(0, 9983, '\p{^Block= _MISCELLANEOUS_symbols}', "");
Expect(0, 9983, '\P{Block= _MISCELLANEOUS_symbols}', "");
Expect(1, 9983, '\P{^Block= _MISCELLANEOUS_symbols}', "");
Expect(0, 9984, '\p{Block= _MISCELLANEOUS_symbols}', "");
Expect(1, 9984, '\p{^Block= _MISCELLANEOUS_symbols}', "");
Expect(1, 9984, '\P{Block= _MISCELLANEOUS_symbols}', "");
Expect(0, 9984, '\P{^Block= _MISCELLANEOUS_symbols}', "");
Error('\p{Blk=-	Misc_SYMBOLS:=}');
Error('\P{Blk=-	Misc_SYMBOLS:=}');
Expect(1, 9983, '\p{Blk=miscsymbols}', "");
Expect(0, 9983, '\p{^Blk=miscsymbols}', "");
Expect(0, 9983, '\P{Blk=miscsymbols}', "");
Expect(1, 9983, '\P{^Blk=miscsymbols}', "");
Expect(0, 9984, '\p{Blk=miscsymbols}', "");
Expect(1, 9984, '\p{^Blk=miscsymbols}', "");
Expect(1, 9984, '\P{Blk=miscsymbols}', "");
Expect(0, 9984, '\P{^Blk=miscsymbols}', "");
Expect(1, 9983, '\p{Blk=_-Misc_symbols}', "");
Expect(0, 9983, '\p{^Blk=_-Misc_symbols}', "");
Expect(0, 9983, '\P{Blk=_-Misc_symbols}', "");
Expect(1, 9983, '\P{^Blk=_-Misc_symbols}', "");
Expect(0, 9984, '\p{Blk=_-Misc_symbols}', "");
Expect(1, 9984, '\p{^Blk=_-Misc_symbols}', "");
Expect(1, 9984, '\P{Blk=_-Misc_symbols}', "");
Expect(0, 9984, '\P{^Blk=_-Misc_symbols}', "");
Error('\p{Is_Block=	-Miscellaneous_SYMBOLS/a/}');
Error('\P{Is_Block=	-Miscellaneous_SYMBOLS/a/}');
Expect(1, 9983, '\p{Is_Block:miscellaneoussymbols}', "");
Expect(0, 9983, '\p{^Is_Block:miscellaneoussymbols}', "");
Expect(0, 9983, '\P{Is_Block:miscellaneoussymbols}', "");
Expect(1, 9983, '\P{^Is_Block:miscellaneoussymbols}', "");
Expect(0, 9984, '\p{Is_Block:miscellaneoussymbols}', "");
Expect(1, 9984, '\p{^Is_Block:miscellaneoussymbols}', "");
Expect(1, 9984, '\P{Is_Block:miscellaneoussymbols}', "");
Expect(0, 9984, '\P{^Is_Block:miscellaneoussymbols}', "");
Expect(1, 9983, '\p{Is_Block:   -_MISCELLANEOUS_Symbols}', "");
Expect(0, 9983, '\p{^Is_Block:   -_MISCELLANEOUS_Symbols}', "");
Expect(0, 9983, '\P{Is_Block:   -_MISCELLANEOUS_Symbols}', "");
Expect(1, 9983, '\P{^Is_Block:   -_MISCELLANEOUS_Symbols}', "");
Expect(0, 9984, '\p{Is_Block:   -_MISCELLANEOUS_Symbols}', "");
Expect(1, 9984, '\p{^Is_Block:   -_MISCELLANEOUS_Symbols}', "");
Expect(1, 9984, '\P{Is_Block:   -_MISCELLANEOUS_Symbols}', "");
Expect(0, 9984, '\P{^Is_Block:   -_MISCELLANEOUS_Symbols}', "");
Error('\p{Is_Blk=:= 	Misc_Symbols}');
Error('\P{Is_Blk=:= 	Misc_Symbols}');
Expect(1, 9983, '\p{Is_Blk=miscsymbols}', "");
Expect(0, 9983, '\p{^Is_Blk=miscsymbols}', "");
Expect(0, 9983, '\P{Is_Blk=miscsymbols}', "");
Expect(1, 9983, '\P{^Is_Blk=miscsymbols}', "");
Expect(0, 9984, '\p{Is_Blk=miscsymbols}', "");
Expect(1, 9984, '\p{^Is_Blk=miscsymbols}', "");
Expect(1, 9984, '\P{Is_Blk=miscsymbols}', "");
Expect(0, 9984, '\P{^Is_Blk=miscsymbols}', "");
Expect(1, 9983, '\p{Is_Blk=	_misc_Symbols}', "");
Expect(0, 9983, '\p{^Is_Blk=	_misc_Symbols}', "");
Expect(0, 9983, '\P{Is_Blk=	_misc_Symbols}', "");
Expect(1, 9983, '\P{^Is_Blk=	_misc_Symbols}', "");
Expect(0, 9984, '\p{Is_Blk=	_misc_Symbols}', "");
Expect(1, 9984, '\p{^Is_Blk=	_misc_Symbols}', "");
Expect(1, 9984, '\P{Is_Blk=	_misc_Symbols}', "");
Expect(0, 9984, '\P{^Is_Blk=	_misc_Symbols}', "");
Error('\p{Block=	Miscellaneous_technical/a/}');
Error('\P{Block=	Miscellaneous_technical/a/}');
Expect(1, 9215, '\p{Block=miscellaneoustechnical}', "");
Expect(0, 9215, '\p{^Block=miscellaneoustechnical}', "");
Expect(0, 9215, '\P{Block=miscellaneoustechnical}', "");
Expect(1, 9215, '\P{^Block=miscellaneoustechnical}', "");
Expect(0, 9216, '\p{Block=miscellaneoustechnical}', "");
Expect(1, 9216, '\p{^Block=miscellaneoustechnical}', "");
Expect(1, 9216, '\P{Block=miscellaneoustechnical}', "");
Expect(0, 9216, '\P{^Block=miscellaneoustechnical}', "");
Expect(1, 9215, '\p{Block=-MISCELLANEOUS_Technical}', "");
Expect(0, 9215, '\p{^Block=-MISCELLANEOUS_Technical}', "");
Expect(0, 9215, '\P{Block=-MISCELLANEOUS_Technical}', "");
Expect(1, 9215, '\P{^Block=-MISCELLANEOUS_Technical}', "");
Expect(0, 9216, '\p{Block=-MISCELLANEOUS_Technical}', "");
Expect(1, 9216, '\p{^Block=-MISCELLANEOUS_Technical}', "");
Expect(1, 9216, '\P{Block=-MISCELLANEOUS_Technical}', "");
Expect(0, 9216, '\P{^Block=-MISCELLANEOUS_Technical}', "");
Error('\p{Blk=/a/ Misc_technical}');
Error('\P{Blk=/a/ Misc_technical}');
Expect(1, 9215, '\p{Blk=misctechnical}', "");
Expect(0, 9215, '\p{^Blk=misctechnical}', "");
Expect(0, 9215, '\P{Blk=misctechnical}', "");
Expect(1, 9215, '\P{^Blk=misctechnical}', "");
Expect(0, 9216, '\p{Blk=misctechnical}', "");
Expect(1, 9216, '\p{^Blk=misctechnical}', "");
Expect(1, 9216, '\P{Blk=misctechnical}', "");
Expect(0, 9216, '\P{^Blk=misctechnical}', "");
Expect(1, 9215, '\p{Blk=-misc_Technical}', "");
Expect(0, 9215, '\p{^Blk=-misc_Technical}', "");
Expect(0, 9215, '\P{Blk=-misc_Technical}', "");
Expect(1, 9215, '\P{^Blk=-misc_Technical}', "");
Expect(0, 9216, '\p{Blk=-misc_Technical}', "");
Expect(1, 9216, '\p{^Blk=-misc_Technical}', "");
Expect(1, 9216, '\P{Blk=-misc_Technical}', "");
Expect(0, 9216, '\P{^Blk=-misc_Technical}', "");
Error('\p{Is_Block=:=Miscellaneous_Technical}');
Error('\P{Is_Block=:=Miscellaneous_Technical}');
Expect(1, 9215, '\p{Is_Block:	miscellaneoustechnical}', "");
Expect(0, 9215, '\p{^Is_Block:	miscellaneoustechnical}', "");
Expect(0, 9215, '\P{Is_Block:	miscellaneoustechnical}', "");
Expect(1, 9215, '\P{^Is_Block:	miscellaneoustechnical}', "");
Expect(0, 9216, '\p{Is_Block:	miscellaneoustechnical}', "");
Expect(1, 9216, '\p{^Is_Block:	miscellaneoustechnical}', "");
Expect(1, 9216, '\P{Is_Block:	miscellaneoustechnical}', "");
Expect(0, 9216, '\P{^Is_Block:	miscellaneoustechnical}', "");
Expect(1, 9215, '\p{Is_Block=_ Miscellaneous_technical}', "");
Expect(0, 9215, '\p{^Is_Block=_ Miscellaneous_technical}', "");
Expect(0, 9215, '\P{Is_Block=_ Miscellaneous_technical}', "");
Expect(1, 9215, '\P{^Is_Block=_ Miscellaneous_technical}', "");
Expect(0, 9216, '\p{Is_Block=_ Miscellaneous_technical}', "");
Expect(1, 9216, '\p{^Is_Block=_ Miscellaneous_technical}', "");
Expect(1, 9216, '\P{Is_Block=_ Miscellaneous_technical}', "");
Expect(0, 9216, '\P{^Is_Block=_ Miscellaneous_technical}', "");
Error('\p{Is_Blk=/a/ -MISC_Technical}');
Error('\P{Is_Blk=/a/ -MISC_Technical}');
Expect(1, 9215, '\p{Is_Blk=misctechnical}', "");
Expect(0, 9215, '\p{^Is_Blk=misctechnical}', "");
Expect(0, 9215, '\P{Is_Blk=misctechnical}', "");
Expect(1, 9215, '\P{^Is_Blk=misctechnical}', "");
Expect(0, 9216, '\p{Is_Blk=misctechnical}', "");
Expect(1, 9216, '\p{^Is_Blk=misctechnical}', "");
Expect(1, 9216, '\P{Is_Blk=misctechnical}', "");
Expect(0, 9216, '\P{^Is_Blk=misctechnical}', "");
Expect(1, 9215, '\p{Is_Blk=-	MISC_Technical}', "");
Expect(0, 9215, '\p{^Is_Blk=-	MISC_Technical}', "");
Expect(0, 9215, '\P{Is_Blk=-	MISC_Technical}', "");
Expect(1, 9215, '\P{^Is_Blk=-	MISC_Technical}', "");
Expect(0, 9216, '\p{Is_Blk=-	MISC_Technical}', "");
Expect(1, 9216, '\p{^Is_Blk=-	MISC_Technical}', "");
Expect(1, 9216, '\P{Is_Blk=-	MISC_Technical}', "");
Expect(0, 9216, '\P{^Is_Blk=-	MISC_Technical}', "");
Error('\p{Block: :=_	spacing_Modifier_letters}');
Error('\P{Block: :=_	spacing_Modifier_letters}');
Expect(1, 767, '\p{Block=spacingmodifierletters}', "");
Expect(0, 767, '\p{^Block=spacingmodifierletters}', "");
Expect(0, 767, '\P{Block=spacingmodifierletters}', "");
Expect(1, 767, '\P{^Block=spacingmodifierletters}', "");
Expect(0, 768, '\p{Block=spacingmodifierletters}', "");
Expect(1, 768, '\p{^Block=spacingmodifierletters}', "");
Expect(1, 768, '\P{Block=spacingmodifierletters}', "");
Expect(0, 768, '\P{^Block=spacingmodifierletters}', "");
Expect(1, 767, '\p{Block=	SPACING_Modifier_Letters}', "");
Expect(0, 767, '\p{^Block=	SPACING_Modifier_Letters}', "");
Expect(0, 767, '\P{Block=	SPACING_Modifier_Letters}', "");
Expect(1, 767, '\P{^Block=	SPACING_Modifier_Letters}', "");
Expect(0, 768, '\p{Block=	SPACING_Modifier_Letters}', "");
Expect(1, 768, '\p{^Block=	SPACING_Modifier_Letters}', "");
Expect(1, 768, '\P{Block=	SPACING_Modifier_Letters}', "");
Expect(0, 768, '\P{^Block=	SPACING_Modifier_Letters}', "");
Error('\p{Blk=_:=modifier_Letters}');
Error('\P{Blk=_:=modifier_Letters}');
Expect(1, 767, '\p{Blk=modifierletters}', "");
Expect(0, 767, '\p{^Blk=modifierletters}', "");
Expect(0, 767, '\P{Blk=modifierletters}', "");
Expect(1, 767, '\P{^Blk=modifierletters}', "");
Expect(0, 768, '\p{Blk=modifierletters}', "");
Expect(1, 768, '\p{^Blk=modifierletters}', "");
Expect(1, 768, '\P{Blk=modifierletters}', "");
Expect(0, 768, '\P{^Blk=modifierletters}', "");
Expect(1, 767, '\p{Blk=-Modifier_LETTERS}', "");
Expect(0, 767, '\p{^Blk=-Modifier_LETTERS}', "");
Expect(0, 767, '\P{Blk=-Modifier_LETTERS}', "");
Expect(1, 767, '\P{^Blk=-Modifier_LETTERS}', "");
Expect(0, 768, '\p{Blk=-Modifier_LETTERS}', "");
Expect(1, 768, '\p{^Blk=-Modifier_LETTERS}', "");
Expect(1, 768, '\P{Blk=-Modifier_LETTERS}', "");
Expect(0, 768, '\P{^Blk=-Modifier_LETTERS}', "");
Error('\p{Is_Block= /a/Spacing_modifier_letters}');
Error('\P{Is_Block= /a/Spacing_modifier_letters}');
Expect(1, 767, '\p{Is_Block=spacingmodifierletters}', "");
Expect(0, 767, '\p{^Is_Block=spacingmodifierletters}', "");
Expect(0, 767, '\P{Is_Block=spacingmodifierletters}', "");
Expect(1, 767, '\P{^Is_Block=spacingmodifierletters}', "");
Expect(0, 768, '\p{Is_Block=spacingmodifierletters}', "");
Expect(1, 768, '\p{^Is_Block=spacingmodifierletters}', "");
Expect(1, 768, '\P{Is_Block=spacingmodifierletters}', "");
Expect(0, 768, '\P{^Is_Block=spacingmodifierletters}', "");
Expect(1, 767, '\p{Is_Block=		spacing_Modifier_letters}', "");
Expect(0, 767, '\p{^Is_Block=		spacing_Modifier_letters}', "");
Expect(0, 767, '\P{Is_Block=		spacing_Modifier_letters}', "");
Expect(1, 767, '\P{^Is_Block=		spacing_Modifier_letters}', "");
Expect(0, 768, '\p{Is_Block=		spacing_Modifier_letters}', "");
Expect(1, 768, '\p{^Is_Block=		spacing_Modifier_letters}', "");
Expect(1, 768, '\P{Is_Block=		spacing_Modifier_letters}', "");
Expect(0, 768, '\P{^Is_Block=		spacing_Modifier_letters}', "");
Error('\p{Is_Blk=_ Modifier_letters/a/}');
Error('\P{Is_Blk=_ Modifier_letters/a/}');
Expect(1, 767, '\p{Is_Blk=modifierletters}', "");
Expect(0, 767, '\p{^Is_Blk=modifierletters}', "");
Expect(0, 767, '\P{Is_Blk=modifierletters}', "");
Expect(1, 767, '\P{^Is_Blk=modifierletters}', "");
Expect(0, 768, '\p{Is_Blk=modifierletters}', "");
Expect(1, 768, '\p{^Is_Blk=modifierletters}', "");
Expect(1, 768, '\P{Is_Blk=modifierletters}', "");
Expect(0, 768, '\P{^Is_Blk=modifierletters}', "");
Expect(1, 767, '\p{Is_Blk=_MODIFIER_Letters}', "");
Expect(0, 767, '\p{^Is_Blk=_MODIFIER_Letters}', "");
Expect(0, 767, '\P{Is_Blk=_MODIFIER_Letters}', "");
Expect(1, 767, '\P{^Is_Blk=_MODIFIER_Letters}', "");
Expect(0, 768, '\p{Is_Blk=_MODIFIER_Letters}', "");
Expect(1, 768, '\p{^Is_Blk=_MODIFIER_Letters}', "");
Expect(1, 768, '\P{Is_Blk=_MODIFIER_Letters}', "");
Expect(0, 768, '\P{^Is_Blk=_MODIFIER_Letters}', "");
Error('\p{Block=/a/  MODIFIER_TONE_LETTERS}');
Error('\P{Block=/a/  MODIFIER_TONE_LETTERS}');
Expect(1, 42783, '\p{Block=modifiertoneletters}', "");
Expect(0, 42783, '\p{^Block=modifiertoneletters}', "");
Expect(0, 42783, '\P{Block=modifiertoneletters}', "");
Expect(1, 42783, '\P{^Block=modifiertoneletters}', "");
Expect(0, 42784, '\p{Block=modifiertoneletters}', "");
Expect(1, 42784, '\p{^Block=modifiertoneletters}', "");
Expect(1, 42784, '\P{Block=modifiertoneletters}', "");
Expect(0, 42784, '\P{^Block=modifiertoneletters}', "");
Expect(1, 42783, '\p{Block= 	Modifier_Tone_letters}', "");
Expect(0, 42783, '\p{^Block= 	Modifier_Tone_letters}', "");
Expect(0, 42783, '\P{Block= 	Modifier_Tone_letters}', "");
Expect(1, 42783, '\P{^Block= 	Modifier_Tone_letters}', "");
Expect(0, 42784, '\p{Block= 	Modifier_Tone_letters}', "");
Expect(1, 42784, '\p{^Block= 	Modifier_Tone_letters}', "");
Expect(1, 42784, '\P{Block= 	Modifier_Tone_letters}', "");
Expect(0, 42784, '\P{^Block= 	Modifier_Tone_letters}', "");
Error('\p{Blk=/a/	-modifier_tone_LETTERS}');
Error('\P{Blk=/a/	-modifier_tone_LETTERS}');
Expect(1, 42783, '\p{Blk=modifiertoneletters}', "");
Expect(0, 42783, '\p{^Blk=modifiertoneletters}', "");
Expect(0, 42783, '\P{Blk=modifiertoneletters}', "");
Expect(1, 42783, '\P{^Blk=modifiertoneletters}', "");
Expect(0, 42784, '\p{Blk=modifiertoneletters}', "");
Expect(1, 42784, '\p{^Blk=modifiertoneletters}', "");
Expect(1, 42784, '\P{Blk=modifiertoneletters}', "");
Expect(0, 42784, '\P{^Blk=modifiertoneletters}', "");
Expect(1, 42783, '\p{Blk=	MODIFIER_tone_LETTERS}', "");
Expect(0, 42783, '\p{^Blk=	MODIFIER_tone_LETTERS}', "");
Expect(0, 42783, '\P{Blk=	MODIFIER_tone_LETTERS}', "");
Expect(1, 42783, '\P{^Blk=	MODIFIER_tone_LETTERS}', "");
Expect(0, 42784, '\p{Blk=	MODIFIER_tone_LETTERS}', "");
Expect(1, 42784, '\p{^Blk=	MODIFIER_tone_LETTERS}', "");
Expect(1, 42784, '\P{Blk=	MODIFIER_tone_LETTERS}', "");
Expect(0, 42784, '\P{^Blk=	MODIFIER_tone_LETTERS}', "");
Error('\p{Is_Block=-:=MODIFIER_Tone_letters}');
Error('\P{Is_Block=-:=MODIFIER_Tone_letters}');
Expect(1, 42783, '\p{Is_Block=modifiertoneletters}', "");
Expect(0, 42783, '\p{^Is_Block=modifiertoneletters}', "");
Expect(0, 42783, '\P{Is_Block=modifiertoneletters}', "");
Expect(1, 42783, '\P{^Is_Block=modifiertoneletters}', "");
Expect(0, 42784, '\p{Is_Block=modifiertoneletters}', "");
Expect(1, 42784, '\p{^Is_Block=modifiertoneletters}', "");
Expect(1, 42784, '\P{Is_Block=modifiertoneletters}', "");
Expect(0, 42784, '\P{^Is_Block=modifiertoneletters}', "");
Expect(1, 42783, '\p{Is_Block=--Modifier_Tone_letters}', "");
Expect(0, 42783, '\p{^Is_Block=--Modifier_Tone_letters}', "");
Expect(0, 42783, '\P{Is_Block=--Modifier_Tone_letters}', "");
Expect(1, 42783, '\P{^Is_Block=--Modifier_Tone_letters}', "");
Expect(0, 42784, '\p{Is_Block=--Modifier_Tone_letters}', "");
Expect(1, 42784, '\p{^Is_Block=--Modifier_Tone_letters}', "");
Expect(1, 42784, '\P{Is_Block=--Modifier_Tone_letters}', "");
Expect(0, 42784, '\P{^Is_Block=--Modifier_Tone_letters}', "");
Error('\p{Is_Blk= -modifier_Tone_Letters/a/}');
Error('\P{Is_Blk= -modifier_Tone_Letters/a/}');
Expect(1, 42783, '\p{Is_Blk=modifiertoneletters}', "");
Expect(0, 42783, '\p{^Is_Blk=modifiertoneletters}', "");
Expect(0, 42783, '\P{Is_Blk=modifiertoneletters}', "");
Expect(1, 42783, '\P{^Is_Blk=modifiertoneletters}', "");
Expect(0, 42784, '\p{Is_Blk=modifiertoneletters}', "");
Expect(1, 42784, '\p{^Is_Blk=modifiertoneletters}', "");
Expect(1, 42784, '\P{Is_Blk=modifiertoneletters}', "");
Expect(0, 42784, '\P{^Is_Blk=modifiertoneletters}', "");
Expect(1, 42783, '\p{Is_Blk=- Modifier_Tone_letters}', "");
Expect(0, 42783, '\p{^Is_Blk=- Modifier_Tone_letters}', "");
Expect(0, 42783, '\P{Is_Blk=- Modifier_Tone_letters}', "");
Expect(1, 42783, '\P{^Is_Blk=- Modifier_Tone_letters}', "");
Expect(0, 42784, '\p{Is_Blk=- Modifier_Tone_letters}', "");
Expect(1, 42784, '\p{^Is_Blk=- Modifier_Tone_letters}', "");
Expect(1, 42784, '\P{Is_Blk=- Modifier_Tone_letters}', "");
Expect(0, 42784, '\P{^Is_Blk=- Modifier_Tone_letters}', "");
Error('\p{Block=/a/__MONGOLIAN}');
Error('\P{Block=/a/__MONGOLIAN}');
Expect(1, 6319, '\p{Block=mongolian}', "");
Expect(0, 6319, '\p{^Block=mongolian}', "");
Expect(0, 6319, '\P{Block=mongolian}', "");
Expect(1, 6319, '\P{^Block=mongolian}', "");
Expect(0, 6320, '\p{Block=mongolian}', "");
Expect(1, 6320, '\p{^Block=mongolian}', "");
Expect(1, 6320, '\P{Block=mongolian}', "");
Expect(0, 6320, '\P{^Block=mongolian}', "");
Expect(1, 6319, '\p{Block=		mongolian}', "");
Expect(0, 6319, '\p{^Block=		mongolian}', "");
Expect(0, 6319, '\P{Block=		mongolian}', "");
Expect(1, 6319, '\P{^Block=		mongolian}', "");
Expect(0, 6320, '\p{Block=		mongolian}', "");
Expect(1, 6320, '\p{^Block=		mongolian}', "");
Expect(1, 6320, '\P{Block=		mongolian}', "");
Expect(0, 6320, '\P{^Block=		mongolian}', "");
Error('\p{Blk=/a/mongolian}');
Error('\P{Blk=/a/mongolian}');
Expect(1, 6319, '\p{Blk=mongolian}', "");
Expect(0, 6319, '\p{^Blk=mongolian}', "");
Expect(0, 6319, '\P{Blk=mongolian}', "");
Expect(1, 6319, '\P{^Blk=mongolian}', "");
Expect(0, 6320, '\p{Blk=mongolian}', "");
Expect(1, 6320, '\p{^Blk=mongolian}', "");
Expect(1, 6320, '\P{Blk=mongolian}', "");
Expect(0, 6320, '\P{^Blk=mongolian}', "");
Expect(1, 6319, '\p{Blk= Mongolian}', "");
Expect(0, 6319, '\p{^Blk= Mongolian}', "");
Expect(0, 6319, '\P{Blk= Mongolian}', "");
Expect(1, 6319, '\P{^Blk= Mongolian}', "");
Expect(0, 6320, '\p{Blk= Mongolian}', "");
Expect(1, 6320, '\p{^Blk= Mongolian}', "");
Expect(1, 6320, '\P{Blk= Mongolian}', "");
Expect(0, 6320, '\P{^Blk= Mongolian}', "");
Error('\p{Is_Block:	-	Mongolian/a/}');
Error('\P{Is_Block:	-	Mongolian/a/}');
Expect(1, 6319, '\p{Is_Block=mongolian}', "");
Expect(0, 6319, '\p{^Is_Block=mongolian}', "");
Expect(0, 6319, '\P{Is_Block=mongolian}', "");
Expect(1, 6319, '\P{^Is_Block=mongolian}', "");
Expect(0, 6320, '\p{Is_Block=mongolian}', "");
Expect(1, 6320, '\p{^Is_Block=mongolian}', "");
Expect(1, 6320, '\P{Is_Block=mongolian}', "");
Expect(0, 6320, '\P{^Is_Block=mongolian}', "");
Expect(1, 6319, '\p{Is_Block=	-Mongolian}', "");
Expect(0, 6319, '\p{^Is_Block=	-Mongolian}', "");
Expect(0, 6319, '\P{Is_Block=	-Mongolian}', "");
Expect(1, 6319, '\P{^Is_Block=	-Mongolian}', "");
Expect(0, 6320, '\p{Is_Block=	-Mongolian}', "");
Expect(1, 6320, '\p{^Is_Block=	-Mongolian}', "");
Expect(1, 6320, '\P{Is_Block=	-Mongolian}', "");
Expect(0, 6320, '\P{^Is_Block=	-Mongolian}', "");
Error('\p{Is_Blk=:=mongolian}');
Error('\P{Is_Blk=:=mongolian}');
Expect(1, 6319, '\p{Is_Blk=mongolian}', "");
Expect(0, 6319, '\p{^Is_Blk=mongolian}', "");
Expect(0, 6319, '\P{Is_Blk=mongolian}', "");
Expect(1, 6319, '\P{^Is_Blk=mongolian}', "");
Expect(0, 6320, '\p{Is_Blk=mongolian}', "");
Expect(1, 6320, '\p{^Is_Blk=mongolian}', "");
Expect(1, 6320, '\P{Is_Blk=mongolian}', "");
Expect(0, 6320, '\P{^Is_Blk=mongolian}', "");
Expect(1, 6319, '\p{Is_Blk=	_mongolian}', "");
Expect(0, 6319, '\p{^Is_Blk=	_mongolian}', "");
Expect(0, 6319, '\P{Is_Blk=	_mongolian}', "");
Expect(1, 6319, '\P{^Is_Blk=	_mongolian}', "");
Expect(0, 6320, '\p{Is_Blk=	_mongolian}', "");
Expect(1, 6320, '\p{^Is_Blk=	_mongolian}', "");
Expect(1, 6320, '\P{Is_Blk=	_mongolian}', "");
Expect(0, 6320, '\P{^Is_Blk=	_mongolian}', "");
Error('\p{Block=:=MUSICAL_Symbols}');
Error('\P{Block=:=MUSICAL_Symbols}');
Expect(1, 119295, '\p{Block=musicalsymbols}', "");
Expect(0, 119295, '\p{^Block=musicalsymbols}', "");
Expect(0, 119295, '\P{Block=musicalsymbols}', "");
Expect(1, 119295, '\P{^Block=musicalsymbols}', "");
Expect(0, 119296, '\p{Block=musicalsymbols}', "");
Expect(1, 119296, '\p{^Block=musicalsymbols}', "");
Expect(1, 119296, '\P{Block=musicalsymbols}', "");
Expect(0, 119296, '\P{^Block=musicalsymbols}', "");
Expect(1, 119295, '\p{Block:	 _musical_symbols}', "");
Expect(0, 119295, '\p{^Block:	 _musical_symbols}', "");
Expect(0, 119295, '\P{Block:	 _musical_symbols}', "");
Expect(1, 119295, '\P{^Block:	 _musical_symbols}', "");
Expect(0, 119296, '\p{Block:	 _musical_symbols}', "");
Expect(1, 119296, '\p{^Block:	 _musical_symbols}', "");
Expect(1, 119296, '\P{Block:	 _musical_symbols}', "");
Expect(0, 119296, '\P{^Block:	 _musical_symbols}', "");
Error('\p{Blk=/a/  Music}');
Error('\P{Blk=/a/  Music}');
Expect(1, 119295, '\p{Blk=music}', "");
Expect(0, 119295, '\p{^Blk=music}', "");
Expect(0, 119295, '\P{Blk=music}', "");
Expect(1, 119295, '\P{^Blk=music}', "");
Expect(0, 119296, '\p{Blk=music}', "");
Expect(1, 119296, '\p{^Blk=music}', "");
Expect(1, 119296, '\P{Blk=music}', "");
Expect(0, 119296, '\P{^Blk=music}', "");
Expect(1, 119295, '\p{Blk=	-MUSIC}', "");
Expect(0, 119295, '\p{^Blk=	-MUSIC}', "");
Expect(0, 119295, '\P{Blk=	-MUSIC}', "");
Expect(1, 119295, '\P{^Blk=	-MUSIC}', "");
Expect(0, 119296, '\p{Blk=	-MUSIC}', "");
Expect(1, 119296, '\p{^Blk=	-MUSIC}', "");
Expect(1, 119296, '\P{Blk=	-MUSIC}', "");
Expect(0, 119296, '\P{^Blk=	-MUSIC}', "");
Error('\p{Is_Block=:=	_MUSICAL_Symbols}');
Error('\P{Is_Block=:=	_MUSICAL_Symbols}');
Expect(1, 119295, '\p{Is_Block:   musicalsymbols}', "");
Expect(0, 119295, '\p{^Is_Block:   musicalsymbols}', "");
Expect(0, 119295, '\P{Is_Block:   musicalsymbols}', "");
Expect(1, 119295, '\P{^Is_Block:   musicalsymbols}', "");
Expect(0, 119296, '\p{Is_Block:   musicalsymbols}', "");
Expect(1, 119296, '\p{^Is_Block:   musicalsymbols}', "");
Expect(1, 119296, '\P{Is_Block:   musicalsymbols}', "");
Expect(0, 119296, '\P{^Is_Block:   musicalsymbols}', "");
Expect(1, 119295, '\p{Is_Block=-MUSICAL_SYMBOLS}', "");
Expect(0, 119295, '\p{^Is_Block=-MUSICAL_SYMBOLS}', "");
Expect(0, 119295, '\P{Is_Block=-MUSICAL_SYMBOLS}', "");
Expect(1, 119295, '\P{^Is_Block=-MUSICAL_SYMBOLS}', "");
Expect(0, 119296, '\p{Is_Block=-MUSICAL_SYMBOLS}', "");
Expect(1, 119296, '\p{^Is_Block=-MUSICAL_SYMBOLS}', "");
Expect(1, 119296, '\P{Is_Block=-MUSICAL_SYMBOLS}', "");
Expect(0, 119296, '\P{^Is_Block=-MUSICAL_SYMBOLS}', "");
Error('\p{Is_Blk=/a/	-music}');
Error('\P{Is_Blk=/a/	-music}');
Expect(1, 119295, '\p{Is_Blk=music}', "");
Expect(0, 119295, '\p{^Is_Blk=music}', "");
Expect(0, 119295, '\P{Is_Blk=music}', "");
Expect(1, 119295, '\P{^Is_Blk=music}', "");
Expect(0, 119296, '\p{Is_Blk=music}', "");
Expect(1, 119296, '\p{^Is_Blk=music}', "");
Expect(1, 119296, '\P{Is_Blk=music}', "");
Expect(0, 119296, '\P{^Is_Blk=music}', "");
Expect(1, 119295, '\p{Is_Blk:   _ Music}', "");
Expect(0, 119295, '\p{^Is_Blk:   _ Music}', "");
Expect(0, 119295, '\P{Is_Blk:   _ Music}', "");
Expect(1, 119295, '\P{^Is_Blk:   _ Music}', "");
Expect(0, 119296, '\p{Is_Blk:   _ Music}', "");
Expect(1, 119296, '\p{^Is_Blk:   _ Music}', "");
Expect(1, 119296, '\P{Is_Blk:   _ Music}', "");
Expect(0, 119296, '\P{^Is_Blk:   _ Music}', "");
Error('\p{Block=	Myanmar/a/}');
Error('\P{Block=	Myanmar/a/}');
Expect(1, 4255, '\p{Block=myanmar}', "");
Expect(0, 4255, '\p{^Block=myanmar}', "");
Expect(0, 4255, '\P{Block=myanmar}', "");
Expect(1, 4255, '\P{^Block=myanmar}', "");
Expect(0, 4256, '\p{Block=myanmar}', "");
Expect(1, 4256, '\p{^Block=myanmar}', "");
Expect(1, 4256, '\P{Block=myanmar}', "");
Expect(0, 4256, '\P{^Block=myanmar}', "");
Expect(1, 4255, '\p{Block= MYANMAR}', "");
Expect(0, 4255, '\p{^Block= MYANMAR}', "");
Expect(0, 4255, '\P{Block= MYANMAR}', "");
Expect(1, 4255, '\P{^Block= MYANMAR}', "");
Expect(0, 4256, '\p{Block= MYANMAR}', "");
Expect(1, 4256, '\p{^Block= MYANMAR}', "");
Expect(1, 4256, '\P{Block= MYANMAR}', "");
Expect(0, 4256, '\P{^Block= MYANMAR}', "");
Error('\p{Blk::=	 Myanmar}');
Error('\P{Blk::=	 Myanmar}');
Expect(1, 4255, '\p{Blk=myanmar}', "");
Expect(0, 4255, '\p{^Blk=myanmar}', "");
Expect(0, 4255, '\P{Blk=myanmar}', "");
Expect(1, 4255, '\P{^Blk=myanmar}', "");
Expect(0, 4256, '\p{Blk=myanmar}', "");
Expect(1, 4256, '\p{^Blk=myanmar}', "");
Expect(1, 4256, '\P{Blk=myanmar}', "");
Expect(0, 4256, '\P{^Blk=myanmar}', "");
Expect(1, 4255, '\p{Blk:  Myanmar}', "");
Expect(0, 4255, '\p{^Blk:  Myanmar}', "");
Expect(0, 4255, '\P{Blk:  Myanmar}', "");
Expect(1, 4255, '\P{^Blk:  Myanmar}', "");
Expect(0, 4256, '\p{Blk:  Myanmar}', "");
Expect(1, 4256, '\p{^Blk:  Myanmar}', "");
Expect(1, 4256, '\P{Blk:  Myanmar}', "");
Expect(0, 4256, '\P{^Blk:  Myanmar}', "");
Error('\p{Is_Block=	-myanmar/a/}');
Error('\P{Is_Block=	-myanmar/a/}');
Expect(1, 4255, '\p{Is_Block=myanmar}', "");
Expect(0, 4255, '\p{^Is_Block=myanmar}', "");
Expect(0, 4255, '\P{Is_Block=myanmar}', "");
Expect(1, 4255, '\P{^Is_Block=myanmar}', "");
Expect(0, 4256, '\p{Is_Block=myanmar}', "");
Expect(1, 4256, '\p{^Is_Block=myanmar}', "");
Expect(1, 4256, '\P{Is_Block=myanmar}', "");
Expect(0, 4256, '\P{^Is_Block=myanmar}', "");
Expect(1, 4255, '\p{Is_Block=  myanmar}', "");
Expect(0, 4255, '\p{^Is_Block=  myanmar}', "");
Expect(0, 4255, '\P{Is_Block=  myanmar}', "");
Expect(1, 4255, '\P{^Is_Block=  myanmar}', "");
Expect(0, 4256, '\p{Is_Block=  myanmar}', "");
Expect(1, 4256, '\p{^Is_Block=  myanmar}', "");
Expect(1, 4256, '\P{Is_Block=  myanmar}', "");
Expect(0, 4256, '\P{^Is_Block=  myanmar}', "");
Error('\p{Is_Blk:	--myanmar/a/}');
Error('\P{Is_Blk:	--myanmar/a/}');
Expect(1, 4255, '\p{Is_Blk=myanmar}', "");
Expect(0, 4255, '\p{^Is_Blk=myanmar}', "");
Expect(0, 4255, '\P{Is_Blk=myanmar}', "");
Expect(1, 4255, '\P{^Is_Blk=myanmar}', "");
Expect(0, 4256, '\p{Is_Blk=myanmar}', "");
Expect(1, 4256, '\p{^Is_Blk=myanmar}', "");
Expect(1, 4256, '\P{Is_Blk=myanmar}', "");
Expect(0, 4256, '\P{^Is_Blk=myanmar}', "");
Expect(1, 4255, '\p{Is_Blk=_-Myanmar}', "");
Expect(0, 4255, '\p{^Is_Blk=_-Myanmar}', "");
Expect(0, 4255, '\P{Is_Blk=_-Myanmar}', "");
Expect(1, 4255, '\P{^Is_Blk=_-Myanmar}', "");
Expect(0, 4256, '\p{Is_Blk=_-Myanmar}', "");
Expect(1, 4256, '\p{^Is_Blk=_-Myanmar}', "");
Expect(1, 4256, '\P{Is_Blk=_-Myanmar}', "");
Expect(0, 4256, '\P{^Is_Blk=_-Myanmar}', "");
Error('\p{Block=	/a/Myanmar_Extended_A}');
Error('\P{Block=	/a/Myanmar_Extended_A}');
Expect(1, 43647, '\p{Block=myanmarextendeda}', "");
Expect(0, 43647, '\p{^Block=myanmarextendeda}', "");
Expect(0, 43647, '\P{Block=myanmarextendeda}', "");
Expect(1, 43647, '\P{^Block=myanmarextendeda}', "");
Expect(0, 43648, '\p{Block=myanmarextendeda}', "");
Expect(1, 43648, '\p{^Block=myanmarextendeda}', "");
Expect(1, 43648, '\P{Block=myanmarextendeda}', "");
Expect(0, 43648, '\P{^Block=myanmarextendeda}', "");
Expect(1, 43647, '\p{Block=--MYANMAR_EXTENDED_A}', "");
Expect(0, 43647, '\p{^Block=--MYANMAR_EXTENDED_A}', "");
Expect(0, 43647, '\P{Block=--MYANMAR_EXTENDED_A}', "");
Expect(1, 43647, '\P{^Block=--MYANMAR_EXTENDED_A}', "");
Expect(0, 43648, '\p{Block=--MYANMAR_EXTENDED_A}', "");
Expect(1, 43648, '\p{^Block=--MYANMAR_EXTENDED_A}', "");
Expect(1, 43648, '\P{Block=--MYANMAR_EXTENDED_A}', "");
Expect(0, 43648, '\P{^Block=--MYANMAR_EXTENDED_A}', "");
Error('\p{Blk=/a/Myanmar_EXT_A}');
Error('\P{Blk=/a/Myanmar_EXT_A}');
Expect(1, 43647, '\p{Blk=myanmarexta}', "");
Expect(0, 43647, '\p{^Blk=myanmarexta}', "");
Expect(0, 43647, '\P{Blk=myanmarexta}', "");
Expect(1, 43647, '\P{^Blk=myanmarexta}', "");
Expect(0, 43648, '\p{Blk=myanmarexta}', "");
Expect(1, 43648, '\p{^Blk=myanmarexta}', "");
Expect(1, 43648, '\P{Blk=myanmarexta}', "");
Expect(0, 43648, '\P{^Blk=myanmarexta}', "");
Expect(1, 43647, '\p{Blk=_ Myanmar_Ext_A}', "");
Expect(0, 43647, '\p{^Blk=_ Myanmar_Ext_A}', "");
Expect(0, 43647, '\P{Blk=_ Myanmar_Ext_A}', "");
Expect(1, 43647, '\P{^Blk=_ Myanmar_Ext_A}', "");
Expect(0, 43648, '\p{Blk=_ Myanmar_Ext_A}', "");
Expect(1, 43648, '\p{^Blk=_ Myanmar_Ext_A}', "");
Expect(1, 43648, '\P{Blk=_ Myanmar_Ext_A}', "");
Expect(0, 43648, '\P{^Blk=_ Myanmar_Ext_A}', "");
Error('\p{Is_Block:    -myanmar_EXTENDED_a:=}');
Error('\P{Is_Block:    -myanmar_EXTENDED_a:=}');
Expect(1, 43647, '\p{Is_Block=myanmarextendeda}', "");
Expect(0, 43647, '\p{^Is_Block=myanmarextendeda}', "");
Expect(0, 43647, '\P{Is_Block=myanmarextendeda}', "");
Expect(1, 43647, '\P{^Is_Block=myanmarextendeda}', "");
Expect(0, 43648, '\p{Is_Block=myanmarextendeda}', "");
Expect(1, 43648, '\p{^Is_Block=myanmarextendeda}', "");
Expect(1, 43648, '\P{Is_Block=myanmarextendeda}', "");
Expect(0, 43648, '\P{^Is_Block=myanmarextendeda}', "");
Expect(1, 43647, '\p{Is_Block=-	Myanmar_extended_a}', "");
Expect(0, 43647, '\p{^Is_Block=-	Myanmar_extended_a}', "");
Expect(0, 43647, '\P{Is_Block=-	Myanmar_extended_a}', "");
Expect(1, 43647, '\P{^Is_Block=-	Myanmar_extended_a}', "");
Expect(0, 43648, '\p{Is_Block=-	Myanmar_extended_a}', "");
Expect(1, 43648, '\p{^Is_Block=-	Myanmar_extended_a}', "");
Expect(1, 43648, '\P{Is_Block=-	Myanmar_extended_a}', "");
Expect(0, 43648, '\P{^Is_Block=-	Myanmar_extended_a}', "");
Error('\p{Is_Blk=:= Myanmar_Ext_A}');
Error('\P{Is_Blk=:= Myanmar_Ext_A}');
Expect(1, 43647, '\p{Is_Blk=myanmarexta}', "");
Expect(0, 43647, '\p{^Is_Blk=myanmarexta}', "");
Expect(0, 43647, '\P{Is_Blk=myanmarexta}', "");
Expect(1, 43647, '\P{^Is_Blk=myanmarexta}', "");
Expect(0, 43648, '\p{Is_Blk=myanmarexta}', "");
Expect(1, 43648, '\p{^Is_Blk=myanmarexta}', "");
Expect(1, 43648, '\P{Is_Blk=myanmarexta}', "");
Expect(0, 43648, '\P{^Is_Blk=myanmarexta}', "");
Expect(1, 43647, '\p{Is_Blk=		Myanmar_EXT_A}', "");
Expect(0, 43647, '\p{^Is_Blk=		Myanmar_EXT_A}', "");
Expect(0, 43647, '\P{Is_Blk=		Myanmar_EXT_A}', "");
Expect(1, 43647, '\P{^Is_Blk=		Myanmar_EXT_A}', "");
Expect(0, 43648, '\p{Is_Blk=		Myanmar_EXT_A}', "");
Expect(1, 43648, '\p{^Is_Blk=		Myanmar_EXT_A}', "");
Expect(1, 43648, '\P{Is_Blk=		Myanmar_EXT_A}', "");
Expect(0, 43648, '\P{^Is_Blk=		Myanmar_EXT_A}', "");
Error('\p{Block=:= -No_block}');
Error('\P{Block=:= -No_block}');
Expect(1, 918000, '\p{Block=noblock}', "");
Expect(0, 918000, '\p{^Block=noblock}', "");
Expect(0, 918000, '\P{Block=noblock}', "");
Expect(1, 918000, '\P{^Block=noblock}', "");
Expect(0, 983040, '\p{Block=noblock}', "");
Expect(1, 983040, '\p{^Block=noblock}', "");
Expect(1, 983040, '\P{Block=noblock}', "");
Expect(0, 983040, '\P{^Block=noblock}', "");
Expect(1, 918000, '\p{Block= _No_Block}', "");
Expect(0, 918000, '\p{^Block= _No_Block}', "");
Expect(0, 918000, '\P{Block= _No_Block}', "");
Expect(1, 918000, '\P{^Block= _No_Block}', "");
Expect(0, 983040, '\p{Block= _No_Block}', "");
Expect(1, 983040, '\p{^Block= _No_Block}', "");
Expect(1, 983040, '\P{Block= _No_Block}', "");
Expect(0, 983040, '\P{^Block= _No_Block}', "");
Error('\p{Blk= 	nb/a/}');
Error('\P{Blk= 	nb/a/}');
Expect(1, 918000, '\p{Blk=nb}', "");
Expect(0, 918000, '\p{^Blk=nb}', "");
Expect(0, 918000, '\P{Blk=nb}', "");
Expect(1, 918000, '\P{^Blk=nb}', "");
Expect(0, 983040, '\p{Blk=nb}', "");
Expect(1, 983040, '\p{^Blk=nb}', "");
Expect(1, 983040, '\P{Blk=nb}', "");
Expect(0, 983040, '\P{^Blk=nb}', "");
Expect(1, 918000, '\p{Blk=_nb}', "");
Expect(0, 918000, '\p{^Blk=_nb}', "");
Expect(0, 918000, '\P{Blk=_nb}', "");
Expect(1, 918000, '\P{^Blk=_nb}', "");
Expect(0, 983040, '\p{Blk=_nb}', "");
Expect(1, 983040, '\p{^Blk=_nb}', "");
Expect(1, 983040, '\P{Blk=_nb}', "");
Expect(0, 983040, '\P{^Blk=_nb}', "");
Error('\p{Is_Block=	/a/No_BLOCK}');
Error('\P{Is_Block=	/a/No_BLOCK}');
Expect(1, 918000, '\p{Is_Block=noblock}', "");
Expect(0, 918000, '\p{^Is_Block=noblock}', "");
Expect(0, 918000, '\P{Is_Block=noblock}', "");
Expect(1, 918000, '\P{^Is_Block=noblock}', "");
Expect(0, 983040, '\p{Is_Block=noblock}', "");
Expect(1, 983040, '\p{^Is_Block=noblock}', "");
Expect(1, 983040, '\P{Is_Block=noblock}', "");
Expect(0, 983040, '\P{^Is_Block=noblock}', "");
Expect(1, 918000, '\p{Is_Block: 		NO_Block}', "");
Expect(0, 918000, '\p{^Is_Block: 		NO_Block}', "");
Expect(0, 918000, '\P{Is_Block: 		NO_Block}', "");
Expect(1, 918000, '\P{^Is_Block: 		NO_Block}', "");
Expect(0, 983040, '\p{Is_Block: 		NO_Block}', "");
Expect(1, 983040, '\p{^Is_Block: 		NO_Block}', "");
Expect(1, 983040, '\P{Is_Block: 		NO_Block}', "");
Expect(0, 983040, '\P{^Is_Block: 		NO_Block}', "");
Error('\p{Is_Blk= :=NB}');
Error('\P{Is_Blk= :=NB}');
Expect(1, 918000, '\p{Is_Blk=nb}', "");
Expect(0, 918000, '\p{^Is_Blk=nb}', "");
Expect(0, 918000, '\P{Is_Blk=nb}', "");
Expect(1, 918000, '\P{^Is_Blk=nb}', "");
Expect(0, 983040, '\p{Is_Blk=nb}', "");
Expect(1, 983040, '\p{^Is_Blk=nb}', "");
Expect(1, 983040, '\P{Is_Blk=nb}', "");
Expect(0, 983040, '\P{^Is_Blk=nb}', "");
Expect(1, 918000, '\p{Is_Blk=_-NB}', "");
Expect(0, 918000, '\p{^Is_Blk=_-NB}', "");
Expect(0, 918000, '\P{Is_Blk=_-NB}', "");
Expect(1, 918000, '\P{^Is_Blk=_-NB}', "");
Expect(0, 983040, '\p{Is_Blk=_-NB}', "");
Expect(1, 983040, '\p{^Is_Blk=_-NB}', "");
Expect(1, 983040, '\P{Is_Blk=_-NB}', "");
Expect(0, 983040, '\P{^Is_Blk=_-NB}', "");
Error('\p{Block=:=_ NKo}');
Error('\P{Block=:=_ NKo}');
Expect(1, 2047, '\p{Block=nko}', "");
Expect(0, 2047, '\p{^Block=nko}', "");
Expect(0, 2047, '\P{Block=nko}', "");
Expect(1, 2047, '\P{^Block=nko}', "");
Expect(0, 2048, '\p{Block=nko}', "");
Expect(1, 2048, '\p{^Block=nko}', "");
Expect(1, 2048, '\P{Block=nko}', "");
Expect(0, 2048, '\P{^Block=nko}', "");
Expect(1, 2047, '\p{Block=-NKo}', "");
Expect(0, 2047, '\p{^Block=-NKo}', "");
Expect(0, 2047, '\P{Block=-NKo}', "");
Expect(1, 2047, '\P{^Block=-NKo}', "");
Expect(0, 2048, '\p{Block=-NKo}', "");
Expect(1, 2048, '\p{^Block=-NKo}', "");
Expect(1, 2048, '\P{Block=-NKo}', "");
Expect(0, 2048, '\P{^Block=-NKo}', "");
Error('\p{Blk=_NKO/a/}');
Error('\P{Blk=_NKO/a/}');
Expect(1, 2047, '\p{Blk:nko}', "");
Expect(0, 2047, '\p{^Blk:nko}', "");
Expect(0, 2047, '\P{Blk:nko}', "");
Expect(1, 2047, '\P{^Blk:nko}', "");
Expect(0, 2048, '\p{Blk:nko}', "");
Expect(1, 2048, '\p{^Blk:nko}', "");
Expect(1, 2048, '\P{Blk:nko}', "");
Expect(0, 2048, '\P{^Blk:nko}', "");
Expect(1, 2047, '\p{Blk=  NKo}', "");
Expect(0, 2047, '\p{^Blk=  NKo}', "");
Expect(0, 2047, '\P{Blk=  NKo}', "");
Expect(1, 2047, '\P{^Blk=  NKo}', "");
Expect(0, 2048, '\p{Blk=  NKo}', "");
Expect(1, 2048, '\p{^Blk=  NKo}', "");
Expect(1, 2048, '\P{Blk=  NKo}', "");
Expect(0, 2048, '\P{^Blk=  NKo}', "");
Error('\p{Is_Block= -NKo/a/}');
Error('\P{Is_Block= -NKo/a/}');
Expect(1, 2047, '\p{Is_Block=nko}', "");
Expect(0, 2047, '\p{^Is_Block=nko}', "");
Expect(0, 2047, '\P{Is_Block=nko}', "");
Expect(1, 2047, '\P{^Is_Block=nko}', "");
Expect(0, 2048, '\p{Is_Block=nko}', "");
Expect(1, 2048, '\p{^Is_Block=nko}', "");
Expect(1, 2048, '\P{Is_Block=nko}', "");
Expect(0, 2048, '\P{^Is_Block=nko}', "");
Expect(1, 2047, '\p{Is_Block=	 NKo}', "");
Expect(0, 2047, '\p{^Is_Block=	 NKo}', "");
Expect(0, 2047, '\P{Is_Block=	 NKo}', "");
Expect(1, 2047, '\P{^Is_Block=	 NKo}', "");
Expect(0, 2048, '\p{Is_Block=	 NKo}', "");
Expect(1, 2048, '\p{^Is_Block=	 NKo}', "");
Expect(1, 2048, '\P{Is_Block=	 NKo}', "");
Expect(0, 2048, '\P{^Is_Block=	 NKo}', "");
Error('\p{Is_Blk=/a/ 	NKo}');
Error('\P{Is_Blk=/a/ 	NKo}');
Expect(1, 2047, '\p{Is_Blk: nko}', "");
Expect(0, 2047, '\p{^Is_Blk: nko}', "");
Expect(0, 2047, '\P{Is_Blk: nko}', "");
Expect(1, 2047, '\P{^Is_Blk: nko}', "");
Expect(0, 2048, '\p{Is_Blk: nko}', "");
Expect(1, 2048, '\p{^Is_Blk: nko}', "");
Expect(1, 2048, '\P{Is_Blk: nko}', "");
Expect(0, 2048, '\P{^Is_Blk: nko}', "");
Expect(1, 2047, '\p{Is_Blk=-nko}', "");
Expect(0, 2047, '\p{^Is_Blk=-nko}', "");
Expect(0, 2047, '\P{Is_Blk=-nko}', "");
Expect(1, 2047, '\P{^Is_Blk=-nko}', "");
Expect(0, 2048, '\p{Is_Blk=-nko}', "");
Expect(1, 2048, '\p{^Is_Blk=-nko}', "");
Expect(1, 2048, '\P{Is_Blk=-nko}', "");
Expect(0, 2048, '\P{^Is_Blk=-nko}', "");
Error('\p{Block=-new_Tai_Lue/a/}');
Error('\P{Block=-new_Tai_Lue/a/}');
Expect(1, 6623, '\p{Block=newtailue}', "");
Expect(0, 6623, '\p{^Block=newtailue}', "");
Expect(0, 6623, '\P{Block=newtailue}', "");
Expect(1, 6623, '\P{^Block=newtailue}', "");
Expect(0, 6624, '\p{Block=newtailue}', "");
Expect(1, 6624, '\p{^Block=newtailue}', "");
Expect(1, 6624, '\P{Block=newtailue}', "");
Expect(0, 6624, '\P{^Block=newtailue}', "");
Expect(1, 6623, '\p{Block=- new_tai_lue}', "");
Expect(0, 6623, '\p{^Block=- new_tai_lue}', "");
Expect(0, 6623, '\P{Block=- new_tai_lue}', "");
Expect(1, 6623, '\P{^Block=- new_tai_lue}', "");
Expect(0, 6624, '\p{Block=- new_tai_lue}', "");
Expect(1, 6624, '\p{^Block=- new_tai_lue}', "");
Expect(1, 6624, '\P{Block=- new_tai_lue}', "");
Expect(0, 6624, '\P{^Block=- new_tai_lue}', "");
Error('\p{Blk=	_New_TAI_lue/a/}');
Error('\P{Blk=	_New_TAI_lue/a/}');
Expect(1, 6623, '\p{Blk=newtailue}', "");
Expect(0, 6623, '\p{^Blk=newtailue}', "");
Expect(0, 6623, '\P{Blk=newtailue}', "");
Expect(1, 6623, '\P{^Blk=newtailue}', "");
Expect(0, 6624, '\p{Blk=newtailue}', "");
Expect(1, 6624, '\p{^Blk=newtailue}', "");
Expect(1, 6624, '\P{Blk=newtailue}', "");
Expect(0, 6624, '\P{^Blk=newtailue}', "");
Expect(1, 6623, '\p{Blk=new_tai_Lue}', "");
Expect(0, 6623, '\p{^Blk=new_tai_Lue}', "");
Expect(0, 6623, '\P{Blk=new_tai_Lue}', "");
Expect(1, 6623, '\P{^Blk=new_tai_Lue}', "");
Expect(0, 6624, '\p{Blk=new_tai_Lue}', "");
Expect(1, 6624, '\p{^Blk=new_tai_Lue}', "");
Expect(1, 6624, '\P{Blk=new_tai_Lue}', "");
Expect(0, 6624, '\P{^Blk=new_tai_Lue}', "");
Error('\p{Is_Block=:=New_tai_LUE}');
Error('\P{Is_Block=:=New_tai_LUE}');
Expect(1, 6623, '\p{Is_Block=newtailue}', "");
Expect(0, 6623, '\p{^Is_Block=newtailue}', "");
Expect(0, 6623, '\P{Is_Block=newtailue}', "");
Expect(1, 6623, '\P{^Is_Block=newtailue}', "");
Expect(0, 6624, '\p{Is_Block=newtailue}', "");
Expect(1, 6624, '\p{^Is_Block=newtailue}', "");
Expect(1, 6624, '\P{Is_Block=newtailue}', "");
Expect(0, 6624, '\P{^Is_Block=newtailue}', "");
Expect(1, 6623, '\p{Is_Block=	-New_Tai_Lue}', "");
Expect(0, 6623, '\p{^Is_Block=	-New_Tai_Lue}', "");
Expect(0, 6623, '\P{Is_Block=	-New_Tai_Lue}', "");
Expect(1, 6623, '\P{^Is_Block=	-New_Tai_Lue}', "");
Expect(0, 6624, '\p{Is_Block=	-New_Tai_Lue}', "");
Expect(1, 6624, '\p{^Is_Block=	-New_Tai_Lue}', "");
Expect(1, 6624, '\P{Is_Block=	-New_Tai_Lue}', "");
Expect(0, 6624, '\P{^Is_Block=	-New_Tai_Lue}', "");
Error('\p{Is_Blk:  /a/New_Tai_lue}');
Error('\P{Is_Blk:  /a/New_Tai_lue}');
Expect(1, 6623, '\p{Is_Blk=newtailue}', "");
Expect(0, 6623, '\p{^Is_Blk=newtailue}', "");
Expect(0, 6623, '\P{Is_Blk=newtailue}', "");
Expect(1, 6623, '\P{^Is_Blk=newtailue}', "");
Expect(0, 6624, '\p{Is_Blk=newtailue}', "");
Expect(1, 6624, '\p{^Is_Blk=newtailue}', "");
Expect(1, 6624, '\P{Is_Blk=newtailue}', "");
Expect(0, 6624, '\P{^Is_Blk=newtailue}', "");
Expect(1, 6623, '\p{Is_Blk= _NEW_TAI_Lue}', "");
Expect(0, 6623, '\p{^Is_Blk= _NEW_TAI_Lue}', "");
Expect(0, 6623, '\P{Is_Blk= _NEW_TAI_Lue}', "");
Expect(1, 6623, '\P{^Is_Blk= _NEW_TAI_Lue}', "");
Expect(0, 6624, '\p{Is_Blk= _NEW_TAI_Lue}', "");
Expect(1, 6624, '\p{^Is_Blk= _NEW_TAI_Lue}', "");
Expect(1, 6624, '\P{Is_Blk= _NEW_TAI_Lue}', "");
Expect(0, 6624, '\P{^Is_Blk= _NEW_TAI_Lue}', "");
Error('\p{Block=:=-	number_forms}');
Error('\P{Block=:=-	number_forms}');
Expect(1, 8591, '\p{Block=numberforms}', "");
Expect(0, 8591, '\p{^Block=numberforms}', "");
Expect(0, 8591, '\P{Block=numberforms}', "");
Expect(1, 8591, '\P{^Block=numberforms}', "");
Expect(0, 8592, '\p{Block=numberforms}', "");
Expect(1, 8592, '\p{^Block=numberforms}', "");
Expect(1, 8592, '\P{Block=numberforms}', "");
Expect(0, 8592, '\P{^Block=numberforms}', "");
Expect(1, 8591, '\p{Block=- number_Forms}', "");
Expect(0, 8591, '\p{^Block=- number_Forms}', "");
Expect(0, 8591, '\P{Block=- number_Forms}', "");
Expect(1, 8591, '\P{^Block=- number_Forms}', "");
Expect(0, 8592, '\p{Block=- number_Forms}', "");
Expect(1, 8592, '\p{^Block=- number_Forms}', "");
Expect(1, 8592, '\P{Block=- number_Forms}', "");
Expect(0, 8592, '\P{^Block=- number_Forms}', "");
Error('\p{Blk=:=-Number_Forms}');
Error('\P{Blk=:=-Number_Forms}');
Expect(1, 8591, '\p{Blk=numberforms}', "");
Expect(0, 8591, '\p{^Blk=numberforms}', "");
Expect(0, 8591, '\P{Blk=numberforms}', "");
Expect(1, 8591, '\P{^Blk=numberforms}', "");
Expect(0, 8592, '\p{Blk=numberforms}', "");
Expect(1, 8592, '\p{^Blk=numberforms}', "");
Expect(1, 8592, '\P{Blk=numberforms}', "");
Expect(0, 8592, '\P{^Blk=numberforms}', "");
Expect(1, 8591, '\p{Blk=	-NUMBER_FORMS}', "");
Expect(0, 8591, '\p{^Blk=	-NUMBER_FORMS}', "");
Expect(0, 8591, '\P{Blk=	-NUMBER_FORMS}', "");
Expect(1, 8591, '\P{^Blk=	-NUMBER_FORMS}', "");
Expect(0, 8592, '\p{Blk=	-NUMBER_FORMS}', "");
Expect(1, 8592, '\p{^Blk=	-NUMBER_FORMS}', "");
Expect(1, 8592, '\P{Blk=	-NUMBER_FORMS}', "");
Expect(0, 8592, '\P{^Blk=	-NUMBER_FORMS}', "");
Error('\p{Is_Block= :=Number_FORMS}');
Error('\P{Is_Block= :=Number_FORMS}');
Expect(1, 8591, '\p{Is_Block=numberforms}', "");
Expect(0, 8591, '\p{^Is_Block=numberforms}', "");
Expect(0, 8591, '\P{Is_Block=numberforms}', "");
Expect(1, 8591, '\P{^Is_Block=numberforms}', "");
Expect(0, 8592, '\p{Is_Block=numberforms}', "");
Expect(1, 8592, '\p{^Is_Block=numberforms}', "");
Expect(1, 8592, '\P{Is_Block=numberforms}', "");
Expect(0, 8592, '\P{^Is_Block=numberforms}', "");
Expect(1, 8591, '\p{Is_Block:	Number_FORMS}', "");
Expect(0, 8591, '\p{^Is_Block:	Number_FORMS}', "");
Expect(0, 8591, '\P{Is_Block:	Number_FORMS}', "");
Expect(1, 8591, '\P{^Is_Block:	Number_FORMS}', "");
Expect(0, 8592, '\p{Is_Block:	Number_FORMS}', "");
Expect(1, 8592, '\p{^Is_Block:	Number_FORMS}', "");
Expect(1, 8592, '\P{Is_Block:	Number_FORMS}', "");
Expect(0, 8592, '\P{^Is_Block:	Number_FORMS}', "");
Error('\p{Is_Blk=	number_FORMS:=}');
Error('\P{Is_Blk=	number_FORMS:=}');
Expect(1, 8591, '\p{Is_Blk=numberforms}', "");
Expect(0, 8591, '\p{^Is_Blk=numberforms}', "");
Expect(0, 8591, '\P{Is_Blk=numberforms}', "");
Expect(1, 8591, '\P{^Is_Blk=numberforms}', "");
Expect(0, 8592, '\p{Is_Blk=numberforms}', "");
Expect(1, 8592, '\p{^Is_Blk=numberforms}', "");
Expect(1, 8592, '\P{Is_Blk=numberforms}', "");
Expect(0, 8592, '\P{^Is_Blk=numberforms}', "");
Expect(1, 8591, '\p{Is_Blk: 		NUMBER_FORMS}', "");
Expect(0, 8591, '\p{^Is_Blk: 		NUMBER_FORMS}', "");
Expect(0, 8591, '\P{Is_Blk: 		NUMBER_FORMS}', "");
Expect(1, 8591, '\P{^Is_Blk: 		NUMBER_FORMS}', "");
Expect(0, 8592, '\p{Is_Blk: 		NUMBER_FORMS}', "");
Expect(1, 8592, '\p{^Is_Blk: 		NUMBER_FORMS}', "");
Expect(1, 8592, '\P{Is_Blk: 		NUMBER_FORMS}', "");
Expect(0, 8592, '\P{^Is_Blk: 		NUMBER_FORMS}', "");
Error('\p{Block=/a/	Optical_character_Recognition}');
Error('\P{Block=/a/	Optical_character_Recognition}');
Expect(1, 9311, '\p{Block=opticalcharacterrecognition}', "");
Expect(0, 9311, '\p{^Block=opticalcharacterrecognition}', "");
Expect(0, 9311, '\P{Block=opticalcharacterrecognition}', "");
Expect(1, 9311, '\P{^Block=opticalcharacterrecognition}', "");
Expect(0, 9312, '\p{Block=opticalcharacterrecognition}', "");
Expect(1, 9312, '\p{^Block=opticalcharacterrecognition}', "");
Expect(1, 9312, '\P{Block=opticalcharacterrecognition}', "");
Expect(0, 9312, '\P{^Block=opticalcharacterrecognition}', "");
Expect(1, 9311, '\p{Block=-	Optical_CHARACTER_recognition}', "");
Expect(0, 9311, '\p{^Block=-	Optical_CHARACTER_recognition}', "");
Expect(0, 9311, '\P{Block=-	Optical_CHARACTER_recognition}', "");
Expect(1, 9311, '\P{^Block=-	Optical_CHARACTER_recognition}', "");
Expect(0, 9312, '\p{Block=-	Optical_CHARACTER_recognition}', "");
Expect(1, 9312, '\p{^Block=-	Optical_CHARACTER_recognition}', "");
Expect(1, 9312, '\P{Block=-	Optical_CHARACTER_recognition}', "");
Expect(0, 9312, '\P{^Block=-	Optical_CHARACTER_recognition}', "");
Error('\p{Blk=:=_ OCR}');
Error('\P{Blk=:=_ OCR}');
Expect(1, 9311, '\p{Blk=ocr}', "");
Expect(0, 9311, '\p{^Blk=ocr}', "");
Expect(0, 9311, '\P{Blk=ocr}', "");
Expect(1, 9311, '\P{^Blk=ocr}', "");
Expect(0, 9312, '\p{Blk=ocr}', "");
Expect(1, 9312, '\p{^Blk=ocr}', "");
Expect(1, 9312, '\P{Blk=ocr}', "");
Expect(0, 9312, '\P{^Blk=ocr}', "");
Expect(1, 9311, '\p{Blk= OCR}', "");
Expect(0, 9311, '\p{^Blk= OCR}', "");
Expect(0, 9311, '\P{Blk= OCR}', "");
Expect(1, 9311, '\P{^Blk= OCR}', "");
Expect(0, 9312, '\p{Blk= OCR}', "");
Expect(1, 9312, '\p{^Blk= OCR}', "");
Expect(1, 9312, '\P{Blk= OCR}', "");
Expect(0, 9312, '\P{^Blk= OCR}', "");
Error('\p{Is_Block=-/a/Optical_CHARACTER_Recognition}');
Error('\P{Is_Block=-/a/Optical_CHARACTER_Recognition}');
Expect(1, 9311, '\p{Is_Block=opticalcharacterrecognition}', "");
Expect(0, 9311, '\p{^Is_Block=opticalcharacterrecognition}', "");
Expect(0, 9311, '\P{Is_Block=opticalcharacterrecognition}', "");
Expect(1, 9311, '\P{^Is_Block=opticalcharacterrecognition}', "");
Expect(0, 9312, '\p{Is_Block=opticalcharacterrecognition}', "");
Expect(1, 9312, '\p{^Is_Block=opticalcharacterrecognition}', "");
Expect(1, 9312, '\P{Is_Block=opticalcharacterrecognition}', "");
Expect(0, 9312, '\P{^Is_Block=opticalcharacterrecognition}', "");
Expect(1, 9311, '\p{Is_Block:	 -Optical_CHARACTER_Recognition}', "");
Expect(0, 9311, '\p{^Is_Block:	 -Optical_CHARACTER_Recognition}', "");
Expect(0, 9311, '\P{Is_Block:	 -Optical_CHARACTER_Recognition}', "");
Expect(1, 9311, '\P{^Is_Block:	 -Optical_CHARACTER_Recognition}', "");
Expect(0, 9312, '\p{Is_Block:	 -Optical_CHARACTER_Recognition}', "");
Expect(1, 9312, '\p{^Is_Block:	 -Optical_CHARACTER_Recognition}', "");
Expect(1, 9312, '\P{Is_Block:	 -Optical_CHARACTER_Recognition}', "");
Expect(0, 9312, '\P{^Is_Block:	 -Optical_CHARACTER_Recognition}', "");
Error('\p{Is_Blk=/a/OCR}');
Error('\P{Is_Blk=/a/OCR}');
Expect(1, 9311, '\p{Is_Blk=ocr}', "");
Expect(0, 9311, '\p{^Is_Blk=ocr}', "");
Expect(0, 9311, '\P{Is_Blk=ocr}', "");
Expect(1, 9311, '\P{^Is_Blk=ocr}', "");
Expect(0, 9312, '\p{Is_Blk=ocr}', "");
Expect(1, 9312, '\p{^Is_Blk=ocr}', "");
Expect(1, 9312, '\P{Is_Blk=ocr}', "");
Expect(0, 9312, '\P{^Is_Blk=ocr}', "");
Expect(1, 9311, '\p{Is_Blk= OCR}', "");
Expect(0, 9311, '\p{^Is_Blk= OCR}', "");
Expect(0, 9311, '\P{Is_Blk= OCR}', "");
Expect(1, 9311, '\P{^Is_Blk= OCR}', "");
Expect(0, 9312, '\p{Is_Blk= OCR}', "");
Expect(1, 9312, '\p{^Is_Blk= OCR}', "");
Expect(1, 9312, '\P{Is_Blk= OCR}', "");
Expect(0, 9312, '\P{^Is_Blk= OCR}', "");
Error('\p{Block=	 OGHAM/a/}');
Error('\P{Block=	 OGHAM/a/}');
Expect(1, 5791, '\p{Block=ogham}', "");
Expect(0, 5791, '\p{^Block=ogham}', "");
Expect(0, 5791, '\P{Block=ogham}', "");
Expect(1, 5791, '\P{^Block=ogham}', "");
Expect(0, 5792, '\p{Block=ogham}', "");
Expect(1, 5792, '\p{^Block=ogham}', "");
Expect(1, 5792, '\P{Block=ogham}', "");
Expect(0, 5792, '\P{^Block=ogham}', "");
Expect(1, 5791, '\p{Block=_Ogham}', "");
Expect(0, 5791, '\p{^Block=_Ogham}', "");
Expect(0, 5791, '\P{Block=_Ogham}', "");
Expect(1, 5791, '\P{^Block=_Ogham}', "");
Expect(0, 5792, '\p{Block=_Ogham}', "");
Expect(1, 5792, '\p{^Block=_Ogham}', "");
Expect(1, 5792, '\P{Block=_Ogham}', "");
Expect(0, 5792, '\P{^Block=_Ogham}', "");
Error('\p{Blk=:=OGHAM}');
Error('\P{Blk=:=OGHAM}');
Expect(1, 5791, '\p{Blk=ogham}', "");
Expect(0, 5791, '\p{^Blk=ogham}', "");
Expect(0, 5791, '\P{Blk=ogham}', "");
Expect(1, 5791, '\P{^Blk=ogham}', "");
Expect(0, 5792, '\p{Blk=ogham}', "");
Expect(1, 5792, '\p{^Blk=ogham}', "");
Expect(1, 5792, '\P{Blk=ogham}', "");
Expect(0, 5792, '\P{^Blk=ogham}', "");
Expect(1, 5791, '\p{Blk= ogham}', "");
Expect(0, 5791, '\p{^Blk= ogham}', "");
Expect(0, 5791, '\P{Blk= ogham}', "");
Expect(1, 5791, '\P{^Blk= ogham}', "");
Expect(0, 5792, '\p{Blk= ogham}', "");
Expect(1, 5792, '\p{^Blk= ogham}', "");
Expect(1, 5792, '\P{Blk= ogham}', "");
Expect(0, 5792, '\P{^Blk= ogham}', "");
Error('\p{Is_Block=--Ogham/a/}');
Error('\P{Is_Block=--Ogham/a/}');
Expect(1, 5791, '\p{Is_Block=ogham}', "");
Expect(0, 5791, '\p{^Is_Block=ogham}', "");
Expect(0, 5791, '\P{Is_Block=ogham}', "");
Expect(1, 5791, '\P{^Is_Block=ogham}', "");
Expect(0, 5792, '\p{Is_Block=ogham}', "");
Expect(1, 5792, '\p{^Is_Block=ogham}', "");
Expect(1, 5792, '\P{Is_Block=ogham}', "");
Expect(0, 5792, '\P{^Is_Block=ogham}', "");
Expect(1, 5791, '\p{Is_Block=_-OGHAM}', "");
Expect(0, 5791, '\p{^Is_Block=_-OGHAM}', "");
Expect(0, 5791, '\P{Is_Block=_-OGHAM}', "");
Expect(1, 5791, '\P{^Is_Block=_-OGHAM}', "");
Expect(0, 5792, '\p{Is_Block=_-OGHAM}', "");
Expect(1, 5792, '\p{^Is_Block=_-OGHAM}', "");
Expect(1, 5792, '\P{Is_Block=_-OGHAM}', "");
Expect(0, 5792, '\P{^Is_Block=_-OGHAM}', "");
Error('\p{Is_Blk=:=  OGHAM}');
Error('\P{Is_Blk=:=  OGHAM}');
Expect(1, 5791, '\p{Is_Blk=ogham}', "");
Expect(0, 5791, '\p{^Is_Blk=ogham}', "");
Expect(0, 5791, '\P{Is_Blk=ogham}', "");
Expect(1, 5791, '\P{^Is_Blk=ogham}', "");
Expect(0, 5792, '\p{Is_Blk=ogham}', "");
Expect(1, 5792, '\p{^Is_Blk=ogham}', "");
Expect(1, 5792, '\P{Is_Blk=ogham}', "");
Expect(0, 5792, '\P{^Is_Blk=ogham}', "");
Expect(1, 5791, '\p{Is_Blk=-_Ogham}', "");
Expect(0, 5791, '\p{^Is_Blk=-_Ogham}', "");
Expect(0, 5791, '\P{Is_Blk=-_Ogham}', "");
Expect(1, 5791, '\P{^Is_Blk=-_Ogham}', "");
Expect(0, 5792, '\p{Is_Blk=-_Ogham}', "");
Expect(1, 5792, '\p{^Is_Blk=-_Ogham}', "");
Expect(1, 5792, '\P{Is_Blk=-_Ogham}', "");
Expect(0, 5792, '\P{^Is_Blk=-_Ogham}', "");
Error('\p{Block=	Ol_CHIKI:=}');
Error('\P{Block=	Ol_CHIKI:=}');
Expect(1, 7295, '\p{Block=olchiki}', "");
Expect(0, 7295, '\p{^Block=olchiki}', "");
Expect(0, 7295, '\P{Block=olchiki}', "");
Expect(1, 7295, '\P{^Block=olchiki}', "");
Expect(0, 7296, '\p{Block=olchiki}', "");
Expect(1, 7296, '\p{^Block=olchiki}', "");
Expect(1, 7296, '\P{Block=olchiki}', "");
Expect(0, 7296, '\P{^Block=olchiki}', "");
Expect(1, 7295, '\p{Block=	-OL_CHIKI}', "");
Expect(0, 7295, '\p{^Block=	-OL_CHIKI}', "");
Expect(0, 7295, '\P{Block=	-OL_CHIKI}', "");
Expect(1, 7295, '\P{^Block=	-OL_CHIKI}', "");
Expect(0, 7296, '\p{Block=	-OL_CHIKI}', "");
Expect(1, 7296, '\p{^Block=	-OL_CHIKI}', "");
Expect(1, 7296, '\P{Block=	-OL_CHIKI}', "");
Expect(0, 7296, '\P{^Block=	-OL_CHIKI}', "");
Error('\p{Blk=/a/ Ol_Chiki}');
Error('\P{Blk=/a/ Ol_Chiki}');
Expect(1, 7295, '\p{Blk=olchiki}', "");
Expect(0, 7295, '\p{^Blk=olchiki}', "");
Expect(0, 7295, '\P{Blk=olchiki}', "");
Expect(1, 7295, '\P{^Blk=olchiki}', "");
Expect(0, 7296, '\p{Blk=olchiki}', "");
Expect(1, 7296, '\p{^Blk=olchiki}', "");
Expect(1, 7296, '\P{Blk=olchiki}', "");
Expect(0, 7296, '\P{^Blk=olchiki}', "");
Expect(1, 7295, '\p{Blk: - ol_CHIKI}', "");
Expect(0, 7295, '\p{^Blk: - ol_CHIKI}', "");
Expect(0, 7295, '\P{Blk: - ol_CHIKI}', "");
Expect(1, 7295, '\P{^Blk: - ol_CHIKI}', "");
Expect(0, 7296, '\p{Blk: - ol_CHIKI}', "");
Expect(1, 7296, '\p{^Blk: - ol_CHIKI}', "");
Expect(1, 7296, '\P{Blk: - ol_CHIKI}', "");
Expect(0, 7296, '\P{^Blk: - ol_CHIKI}', "");
Error('\p{Is_Block=/a/  OL_chiki}');
Error('\P{Is_Block=/a/  OL_chiki}');
Expect(1, 7295, '\p{Is_Block=olchiki}', "");
Expect(0, 7295, '\p{^Is_Block=olchiki}', "");
Expect(0, 7295, '\P{Is_Block=olchiki}', "");
Expect(1, 7295, '\P{^Is_Block=olchiki}', "");
Expect(0, 7296, '\p{Is_Block=olchiki}', "");
Expect(1, 7296, '\p{^Is_Block=olchiki}', "");
Expect(1, 7296, '\P{Is_Block=olchiki}', "");
Expect(0, 7296, '\P{^Is_Block=olchiki}', "");
Expect(1, 7295, '\p{Is_Block=		Ol_chiki}', "");
Expect(0, 7295, '\p{^Is_Block=		Ol_chiki}', "");
Expect(0, 7295, '\P{Is_Block=		Ol_chiki}', "");
Expect(1, 7295, '\P{^Is_Block=		Ol_chiki}', "");
Expect(0, 7296, '\p{Is_Block=		Ol_chiki}', "");
Expect(1, 7296, '\p{^Is_Block=		Ol_chiki}', "");
Expect(1, 7296, '\P{Is_Block=		Ol_chiki}', "");
Expect(0, 7296, '\P{^Is_Block=		Ol_chiki}', "");
Error('\p{Is_Blk=	-Ol_Chiki/a/}');
Error('\P{Is_Blk=	-Ol_Chiki/a/}');
Expect(1, 7295, '\p{Is_Blk=olchiki}', "");
Expect(0, 7295, '\p{^Is_Blk=olchiki}', "");
Expect(0, 7295, '\P{Is_Blk=olchiki}', "");
Expect(1, 7295, '\P{^Is_Blk=olchiki}', "");
Expect(0, 7296, '\p{Is_Blk=olchiki}', "");
Expect(1, 7296, '\p{^Is_Blk=olchiki}', "");
Expect(1, 7296, '\P{Is_Blk=olchiki}', "");
Expect(0, 7296, '\P{^Is_Blk=olchiki}', "");
Expect(1, 7295, '\p{Is_Blk: _ol_CHIKI}', "");
Expect(0, 7295, '\p{^Is_Blk: _ol_CHIKI}', "");
Expect(0, 7295, '\P{Is_Blk: _ol_CHIKI}', "");
Expect(1, 7295, '\P{^Is_Blk: _ol_CHIKI}', "");
Expect(0, 7296, '\p{Is_Blk: _ol_CHIKI}', "");
Expect(1, 7296, '\p{^Is_Blk: _ol_CHIKI}', "");
Expect(1, 7296, '\P{Is_Blk: _ol_CHIKI}', "");
Expect(0, 7296, '\P{^Is_Blk: _ol_CHIKI}', "");
Error('\p{Block=	 old_ITALIC/a/}');
Error('\P{Block=	 old_ITALIC/a/}');
Expect(1, 66351, '\p{Block=olditalic}', "");
Expect(0, 66351, '\p{^Block=olditalic}', "");
Expect(0, 66351, '\P{Block=olditalic}', "");
Expect(1, 66351, '\P{^Block=olditalic}', "");
Expect(0, 66352, '\p{Block=olditalic}', "");
Expect(1, 66352, '\p{^Block=olditalic}', "");
Expect(1, 66352, '\P{Block=olditalic}', "");
Expect(0, 66352, '\P{^Block=olditalic}', "");
Expect(1, 66351, '\p{Block:- old_Italic}', "");
Expect(0, 66351, '\p{^Block:- old_Italic}', "");
Expect(0, 66351, '\P{Block:- old_Italic}', "");
Expect(1, 66351, '\P{^Block:- old_Italic}', "");
Expect(0, 66352, '\p{Block:- old_Italic}', "");
Expect(1, 66352, '\p{^Block:- old_Italic}', "");
Expect(1, 66352, '\P{Block:- old_Italic}', "");
Expect(0, 66352, '\P{^Block:- old_Italic}', "");
Error('\p{Blk=_/a/Old_Italic}');
Error('\P{Blk=_/a/Old_Italic}');
Expect(1, 66351, '\p{Blk=olditalic}', "");
Expect(0, 66351, '\p{^Blk=olditalic}', "");
Expect(0, 66351, '\P{Blk=olditalic}', "");
Expect(1, 66351, '\P{^Blk=olditalic}', "");
Expect(0, 66352, '\p{Blk=olditalic}', "");
Expect(1, 66352, '\p{^Blk=olditalic}', "");
Expect(1, 66352, '\P{Blk=olditalic}', "");
Expect(0, 66352, '\P{^Blk=olditalic}', "");
Expect(1, 66351, '\p{Blk=	Old_Italic}', "");
Expect(0, 66351, '\p{^Blk=	Old_Italic}', "");
Expect(0, 66351, '\P{Blk=	Old_Italic}', "");
Expect(1, 66351, '\P{^Blk=	Old_Italic}', "");
Expect(0, 66352, '\p{Blk=	Old_Italic}', "");
Expect(1, 66352, '\p{^Blk=	Old_Italic}', "");
Expect(1, 66352, '\P{Blk=	Old_Italic}', "");
Expect(0, 66352, '\P{^Blk=	Old_Italic}', "");
Error('\p{Is_Block=	:=Old_ITALIC}');
Error('\P{Is_Block=	:=Old_ITALIC}');
Expect(1, 66351, '\p{Is_Block: olditalic}', "");
Expect(0, 66351, '\p{^Is_Block: olditalic}', "");
Expect(0, 66351, '\P{Is_Block: olditalic}', "");
Expect(1, 66351, '\P{^Is_Block: olditalic}', "");
Expect(0, 66352, '\p{Is_Block: olditalic}', "");
Expect(1, 66352, '\p{^Is_Block: olditalic}', "");
Expect(1, 66352, '\P{Is_Block: olditalic}', "");
Expect(0, 66352, '\P{^Is_Block: olditalic}', "");
Expect(1, 66351, '\p{Is_Block= 	Old_Italic}', "");
Expect(0, 66351, '\p{^Is_Block= 	Old_Italic}', "");
Expect(0, 66351, '\P{Is_Block= 	Old_Italic}', "");
Expect(1, 66351, '\P{^Is_Block= 	Old_Italic}', "");
Expect(0, 66352, '\p{Is_Block= 	Old_Italic}', "");
Expect(1, 66352, '\p{^Is_Block= 	Old_Italic}', "");
Expect(1, 66352, '\P{Is_Block= 	Old_Italic}', "");
Expect(0, 66352, '\P{^Is_Block= 	Old_Italic}', "");
Error('\p{Is_Blk=:=	Old_italic}');
Error('\P{Is_Blk=:=	Old_italic}');
Expect(1, 66351, '\p{Is_Blk=olditalic}', "");
Expect(0, 66351, '\p{^Is_Blk=olditalic}', "");
Expect(0, 66351, '\P{Is_Blk=olditalic}', "");
Expect(1, 66351, '\P{^Is_Blk=olditalic}', "");
Expect(0, 66352, '\p{Is_Blk=olditalic}', "");
Expect(1, 66352, '\p{^Is_Blk=olditalic}', "");
Expect(1, 66352, '\P{Is_Blk=olditalic}', "");
Expect(0, 66352, '\P{^Is_Blk=olditalic}', "");
Expect(1, 66351, '\p{Is_Blk=_-OLD_Italic}', "");
Expect(0, 66351, '\p{^Is_Blk=_-OLD_Italic}', "");
Expect(0, 66351, '\P{Is_Blk=_-OLD_Italic}', "");
Expect(1, 66351, '\P{^Is_Blk=_-OLD_Italic}', "");
Expect(0, 66352, '\p{Is_Blk=_-OLD_Italic}', "");
Expect(1, 66352, '\p{^Is_Blk=_-OLD_Italic}', "");
Expect(1, 66352, '\P{Is_Blk=_-OLD_Italic}', "");
Expect(0, 66352, '\P{^Is_Blk=_-OLD_Italic}', "");
Error('\p{Block=-:=Old_Persian}');
Error('\P{Block=-:=Old_Persian}');
Expect(1, 66527, '\p{Block=oldpersian}', "");
Expect(0, 66527, '\p{^Block=oldpersian}', "");
Expect(0, 66527, '\P{Block=oldpersian}', "");
Expect(1, 66527, '\P{^Block=oldpersian}', "");
Expect(0, 66528, '\p{Block=oldpersian}', "");
Expect(1, 66528, '\p{^Block=oldpersian}', "");
Expect(1, 66528, '\P{Block=oldpersian}', "");
Expect(0, 66528, '\P{^Block=oldpersian}', "");
Expect(1, 66527, '\p{Block=	 Old_Persian}', "");
Expect(0, 66527, '\p{^Block=	 Old_Persian}', "");
Expect(0, 66527, '\P{Block=	 Old_Persian}', "");
Expect(1, 66527, '\P{^Block=	 Old_Persian}', "");
Expect(0, 66528, '\p{Block=	 Old_Persian}', "");
Expect(1, 66528, '\p{^Block=	 Old_Persian}', "");
Expect(1, 66528, '\P{Block=	 Old_Persian}', "");
Expect(0, 66528, '\P{^Block=	 Old_Persian}', "");
Error('\p{Blk=:=	_Old_PERSIAN}');
Error('\P{Blk=:=	_Old_PERSIAN}');
Expect(1, 66527, '\p{Blk=oldpersian}', "");
Expect(0, 66527, '\p{^Blk=oldpersian}', "");
Expect(0, 66527, '\P{Blk=oldpersian}', "");
Expect(1, 66527, '\P{^Blk=oldpersian}', "");
Expect(0, 66528, '\p{Blk=oldpersian}', "");
Expect(1, 66528, '\p{^Blk=oldpersian}', "");
Expect(1, 66528, '\P{Blk=oldpersian}', "");
Expect(0, 66528, '\P{^Blk=oldpersian}', "");
Expect(1, 66527, '\p{Blk=	-Old_persian}', "");
Expect(0, 66527, '\p{^Blk=	-Old_persian}', "");
Expect(0, 66527, '\P{Blk=	-Old_persian}', "");
Expect(1, 66527, '\P{^Blk=	-Old_persian}', "");
Expect(0, 66528, '\p{Blk=	-Old_persian}', "");
Expect(1, 66528, '\p{^Blk=	-Old_persian}', "");
Expect(1, 66528, '\P{Blk=	-Old_persian}', "");
Expect(0, 66528, '\P{^Blk=	-Old_persian}', "");
Error('\p{Is_Block=:=	-OLD_PERSIAN}');
Error('\P{Is_Block=:=	-OLD_PERSIAN}');
Expect(1, 66527, '\p{Is_Block: oldpersian}', "");
Expect(0, 66527, '\p{^Is_Block: oldpersian}', "");
Expect(0, 66527, '\P{Is_Block: oldpersian}', "");
Expect(1, 66527, '\P{^Is_Block: oldpersian}', "");
Expect(0, 66528, '\p{Is_Block: oldpersian}', "");
Expect(1, 66528, '\p{^Is_Block: oldpersian}', "");
Expect(1, 66528, '\P{Is_Block: oldpersian}', "");
Expect(0, 66528, '\P{^Is_Block: oldpersian}', "");
Expect(1, 66527, '\p{Is_Block=-	Old_Persian}', "");
Expect(0, 66527, '\p{^Is_Block=-	Old_Persian}', "");
Expect(0, 66527, '\P{Is_Block=-	Old_Persian}', "");
Expect(1, 66527, '\P{^Is_Block=-	Old_Persian}', "");
Expect(0, 66528, '\p{Is_Block=-	Old_Persian}', "");
Expect(1, 66528, '\p{^Is_Block=-	Old_Persian}', "");
Expect(1, 66528, '\P{Is_Block=-	Old_Persian}', "");
Expect(0, 66528, '\P{^Is_Block=-	Old_Persian}', "");
Error('\p{Is_Blk=:= -Old_persian}');
Error('\P{Is_Blk=:= -Old_persian}');
Expect(1, 66527, '\p{Is_Blk=oldpersian}', "");
Expect(0, 66527, '\p{^Is_Blk=oldpersian}', "");
Expect(0, 66527, '\P{Is_Blk=oldpersian}', "");
Expect(1, 66527, '\P{^Is_Blk=oldpersian}', "");
Expect(0, 66528, '\p{Is_Blk=oldpersian}', "");
Expect(1, 66528, '\p{^Is_Blk=oldpersian}', "");
Expect(1, 66528, '\P{Is_Blk=oldpersian}', "");
Expect(0, 66528, '\P{^Is_Blk=oldpersian}', "");
Expect(1, 66527, '\p{Is_Blk: _ Old_PERSIAN}', "");
Expect(0, 66527, '\p{^Is_Blk: _ Old_PERSIAN}', "");
Expect(0, 66527, '\P{Is_Blk: _ Old_PERSIAN}', "");
Expect(1, 66527, '\P{^Is_Blk: _ Old_PERSIAN}', "");
Expect(0, 66528, '\p{Is_Blk: _ Old_PERSIAN}', "");
Expect(1, 66528, '\p{^Is_Blk: _ Old_PERSIAN}', "");
Expect(1, 66528, '\P{Is_Blk: _ Old_PERSIAN}', "");
Expect(0, 66528, '\P{^Is_Blk: _ Old_PERSIAN}', "");
Error('\p{Block=-:=Old_South_Arabian}');
Error('\P{Block=-:=Old_South_Arabian}');
Expect(1, 68223, '\p{Block=oldsoutharabian}', "");
Expect(0, 68223, '\p{^Block=oldsoutharabian}', "");
Expect(0, 68223, '\P{Block=oldsoutharabian}', "");
Expect(1, 68223, '\P{^Block=oldsoutharabian}', "");
Expect(0, 68224, '\p{Block=oldsoutharabian}', "");
Expect(1, 68224, '\p{^Block=oldsoutharabian}', "");
Expect(1, 68224, '\P{Block=oldsoutharabian}', "");
Expect(0, 68224, '\P{^Block=oldsoutharabian}', "");
Expect(1, 68223, '\p{Block=_old_South_ARABIAN}', "");
Expect(0, 68223, '\p{^Block=_old_South_ARABIAN}', "");
Expect(0, 68223, '\P{Block=_old_South_ARABIAN}', "");
Expect(1, 68223, '\P{^Block=_old_South_ARABIAN}', "");
Expect(0, 68224, '\p{Block=_old_South_ARABIAN}', "");
Expect(1, 68224, '\p{^Block=_old_South_ARABIAN}', "");
Expect(1, 68224, '\P{Block=_old_South_ARABIAN}', "");
Expect(0, 68224, '\P{^Block=_old_South_ARABIAN}', "");
Error('\p{Blk=/a/	Old_SOUTH_ARABIAN}');
Error('\P{Blk=/a/	Old_SOUTH_ARABIAN}');
Expect(1, 68223, '\p{Blk=oldsoutharabian}', "");
Expect(0, 68223, '\p{^Blk=oldsoutharabian}', "");
Expect(0, 68223, '\P{Blk=oldsoutharabian}', "");
Expect(1, 68223, '\P{^Blk=oldsoutharabian}', "");
Expect(0, 68224, '\p{Blk=oldsoutharabian}', "");
Expect(1, 68224, '\p{^Blk=oldsoutharabian}', "");
Expect(1, 68224, '\P{Blk=oldsoutharabian}', "");
Expect(0, 68224, '\P{^Blk=oldsoutharabian}', "");
Expect(1, 68223, '\p{Blk= _old_South_Arabian}', "");
Expect(0, 68223, '\p{^Blk= _old_South_Arabian}', "");
Expect(0, 68223, '\P{Blk= _old_South_Arabian}', "");
Expect(1, 68223, '\P{^Blk= _old_South_Arabian}', "");
Expect(0, 68224, '\p{Blk= _old_South_Arabian}', "");
Expect(1, 68224, '\p{^Blk= _old_South_Arabian}', "");
Expect(1, 68224, '\P{Blk= _old_South_Arabian}', "");
Expect(0, 68224, '\P{^Blk= _old_South_Arabian}', "");
Error('\p{Is_Block=/a/_old_south_arabian}');
Error('\P{Is_Block=/a/_old_south_arabian}');
Expect(1, 68223, '\p{Is_Block=oldsoutharabian}', "");
Expect(0, 68223, '\p{^Is_Block=oldsoutharabian}', "");
Expect(0, 68223, '\P{Is_Block=oldsoutharabian}', "");
Expect(1, 68223, '\P{^Is_Block=oldsoutharabian}', "");
Expect(0, 68224, '\p{Is_Block=oldsoutharabian}', "");
Expect(1, 68224, '\p{^Is_Block=oldsoutharabian}', "");
Expect(1, 68224, '\P{Is_Block=oldsoutharabian}', "");
Expect(0, 68224, '\P{^Is_Block=oldsoutharabian}', "");
Expect(1, 68223, '\p{Is_Block=_-Old_South_ARABIAN}', "");
Expect(0, 68223, '\p{^Is_Block=_-Old_South_ARABIAN}', "");
Expect(0, 68223, '\P{Is_Block=_-Old_South_ARABIAN}', "");
Expect(1, 68223, '\P{^Is_Block=_-Old_South_ARABIAN}', "");
Expect(0, 68224, '\p{Is_Block=_-Old_South_ARABIAN}', "");
Expect(1, 68224, '\p{^Is_Block=_-Old_South_ARABIAN}', "");
Expect(1, 68224, '\P{Is_Block=_-Old_South_ARABIAN}', "");
Expect(0, 68224, '\P{^Is_Block=_-Old_South_ARABIAN}', "");
Error('\p{Is_Blk=	-OLD_south_ARABIAN/a/}');
Error('\P{Is_Blk=	-OLD_south_ARABIAN/a/}');
Expect(1, 68223, '\p{Is_Blk=oldsoutharabian}', "");
Expect(0, 68223, '\p{^Is_Blk=oldsoutharabian}', "");
Expect(0, 68223, '\P{Is_Blk=oldsoutharabian}', "");
Expect(1, 68223, '\P{^Is_Blk=oldsoutharabian}', "");
Expect(0, 68224, '\p{Is_Blk=oldsoutharabian}', "");
Expect(1, 68224, '\p{^Is_Blk=oldsoutharabian}', "");
Expect(1, 68224, '\P{Is_Blk=oldsoutharabian}', "");
Expect(0, 68224, '\P{^Is_Blk=oldsoutharabian}', "");
Expect(1, 68223, '\p{Is_Blk=	Old_SOUTH_arabian}', "");
Expect(0, 68223, '\p{^Is_Blk=	Old_SOUTH_arabian}', "");
Expect(0, 68223, '\P{Is_Blk=	Old_SOUTH_arabian}', "");
Expect(1, 68223, '\P{^Is_Blk=	Old_SOUTH_arabian}', "");
Expect(0, 68224, '\p{Is_Blk=	Old_SOUTH_arabian}', "");
Expect(1, 68224, '\p{^Is_Blk=	Old_SOUTH_arabian}', "");
Expect(1, 68224, '\P{Is_Blk=	Old_SOUTH_arabian}', "");
Expect(0, 68224, '\P{^Is_Blk=	Old_SOUTH_arabian}', "");
Error('\p{Block=		Old_turkic:=}');
Error('\P{Block=		Old_turkic:=}');
Expect(1, 68687, '\p{Block=oldturkic}', "");
Expect(0, 68687, '\p{^Block=oldturkic}', "");
Expect(0, 68687, '\P{Block=oldturkic}', "");
Expect(1, 68687, '\P{^Block=oldturkic}', "");
Expect(0, 68688, '\p{Block=oldturkic}', "");
Expect(1, 68688, '\p{^Block=oldturkic}', "");
Expect(1, 68688, '\P{Block=oldturkic}', "");
Expect(0, 68688, '\P{^Block=oldturkic}', "");
Expect(1, 68687, '\p{Block=		OLD_turkic}', "");
Expect(0, 68687, '\p{^Block=		OLD_turkic}', "");
Expect(0, 68687, '\P{Block=		OLD_turkic}', "");
Expect(1, 68687, '\P{^Block=		OLD_turkic}', "");
Expect(0, 68688, '\p{Block=		OLD_turkic}', "");
Expect(1, 68688, '\p{^Block=		OLD_turkic}', "");
Expect(1, 68688, '\P{Block=		OLD_turkic}', "");
Expect(0, 68688, '\P{^Block=		OLD_turkic}', "");
Error('\p{Blk=/a/ 	Old_turkic}');
Error('\P{Blk=/a/ 	Old_turkic}');
Expect(1, 68687, '\p{Blk:   oldturkic}', "");
Expect(0, 68687, '\p{^Blk:   oldturkic}', "");
Expect(0, 68687, '\P{Blk:   oldturkic}', "");
Expect(1, 68687, '\P{^Blk:   oldturkic}', "");
Expect(0, 68688, '\p{Blk:   oldturkic}', "");
Expect(1, 68688, '\p{^Blk:   oldturkic}', "");
Expect(1, 68688, '\P{Blk:   oldturkic}', "");
Expect(0, 68688, '\P{^Blk:   oldturkic}', "");
Expect(1, 68687, '\p{Blk=_Old_Turkic}', "");
Expect(0, 68687, '\p{^Blk=_Old_Turkic}', "");
Expect(0, 68687, '\P{Blk=_Old_Turkic}', "");
Expect(1, 68687, '\P{^Blk=_Old_Turkic}', "");
Expect(0, 68688, '\p{Blk=_Old_Turkic}', "");
Expect(1, 68688, '\p{^Blk=_Old_Turkic}', "");
Expect(1, 68688, '\P{Blk=_Old_Turkic}', "");
Expect(0, 68688, '\P{^Blk=_Old_Turkic}', "");
Error('\p{Is_Block=	-Old_turkic:=}');
Error('\P{Is_Block=	-Old_turkic:=}');
Expect(1, 68687, '\p{Is_Block=oldturkic}', "");
Expect(0, 68687, '\p{^Is_Block=oldturkic}', "");
Expect(0, 68687, '\P{Is_Block=oldturkic}', "");
Expect(1, 68687, '\P{^Is_Block=oldturkic}', "");
Expect(0, 68688, '\p{Is_Block=oldturkic}', "");
Expect(1, 68688, '\p{^Is_Block=oldturkic}', "");
Expect(1, 68688, '\P{Is_Block=oldturkic}', "");
Expect(0, 68688, '\P{^Is_Block=oldturkic}', "");
Expect(1, 68687, '\p{Is_Block=--Old_turkic}', "");
Expect(0, 68687, '\p{^Is_Block=--Old_turkic}', "");
Expect(0, 68687, '\P{Is_Block=--Old_turkic}', "");
Expect(1, 68687, '\P{^Is_Block=--Old_turkic}', "");
Expect(0, 68688, '\p{Is_Block=--Old_turkic}', "");
Expect(1, 68688, '\p{^Is_Block=--Old_turkic}', "");
Expect(1, 68688, '\P{Is_Block=--Old_turkic}', "");
Expect(0, 68688, '\P{^Is_Block=--Old_turkic}', "");
Error('\p{Is_Blk=/a/  Old_TURKIC}');
Error('\P{Is_Blk=/a/  Old_TURKIC}');
Expect(1, 68687, '\p{Is_Blk=oldturkic}', "");
Expect(0, 68687, '\p{^Is_Blk=oldturkic}', "");
Expect(0, 68687, '\P{Is_Blk=oldturkic}', "");
Expect(1, 68687, '\P{^Is_Blk=oldturkic}', "");
Expect(0, 68688, '\p{Is_Blk=oldturkic}', "");
Expect(1, 68688, '\p{^Is_Blk=oldturkic}', "");
Expect(1, 68688, '\P{Is_Blk=oldturkic}', "");
Expect(0, 68688, '\P{^Is_Blk=oldturkic}', "");
Expect(1, 68687, '\p{Is_Blk= Old_Turkic}', "");
Expect(0, 68687, '\p{^Is_Blk= Old_Turkic}', "");
Expect(0, 68687, '\P{Is_Blk= Old_Turkic}', "");
Expect(1, 68687, '\P{^Is_Blk= Old_Turkic}', "");
Expect(0, 68688, '\p{Is_Blk= Old_Turkic}', "");
Expect(1, 68688, '\p{^Is_Blk= Old_Turkic}', "");
Expect(1, 68688, '\P{Is_Blk= Old_Turkic}', "");
Expect(0, 68688, '\P{^Is_Blk= Old_Turkic}', "");
Error('\p{Block=_/a/ORIYA}');
Error('\P{Block=_/a/ORIYA}');
Expect(1, 2943, '\p{Block=oriya}', "");
Expect(0, 2943, '\p{^Block=oriya}', "");
Expect(0, 2943, '\P{Block=oriya}', "");
Expect(1, 2943, '\P{^Block=oriya}', "");
Expect(0, 2944, '\p{Block=oriya}', "");
Expect(1, 2944, '\p{^Block=oriya}', "");
Expect(1, 2944, '\P{Block=oriya}', "");
Expect(0, 2944, '\P{^Block=oriya}', "");
Expect(1, 2943, '\p{Block=--Oriya}', "");
Expect(0, 2943, '\p{^Block=--Oriya}', "");
Expect(0, 2943, '\P{Block=--Oriya}', "");
Expect(1, 2943, '\P{^Block=--Oriya}', "");
Expect(0, 2944, '\p{Block=--Oriya}', "");
Expect(1, 2944, '\p{^Block=--Oriya}', "");
Expect(1, 2944, '\P{Block=--Oriya}', "");
Expect(0, 2944, '\P{^Block=--Oriya}', "");
Error('\p{Blk: 	Oriya/a/}');
Error('\P{Blk: 	Oriya/a/}');
Expect(1, 2943, '\p{Blk=oriya}', "");
Expect(0, 2943, '\p{^Blk=oriya}', "");
Expect(0, 2943, '\P{Blk=oriya}', "");
Expect(1, 2943, '\P{^Blk=oriya}', "");
Expect(0, 2944, '\p{Blk=oriya}', "");
Expect(1, 2944, '\p{^Blk=oriya}', "");
Expect(1, 2944, '\P{Blk=oriya}', "");
Expect(0, 2944, '\P{^Blk=oriya}', "");
Expect(1, 2943, '\p{Blk=_	ORIYA}', "");
Expect(0, 2943, '\p{^Blk=_	ORIYA}', "");
Expect(0, 2943, '\P{Blk=_	ORIYA}', "");
Expect(1, 2943, '\P{^Blk=_	ORIYA}', "");
Expect(0, 2944, '\p{Blk=_	ORIYA}', "");
Expect(1, 2944, '\p{^Blk=_	ORIYA}', "");
Expect(1, 2944, '\P{Blk=_	ORIYA}', "");
Expect(0, 2944, '\P{^Blk=_	ORIYA}', "");
Error('\p{Is_Block=_:=ORIYA}');
Error('\P{Is_Block=_:=ORIYA}');
Expect(1, 2943, '\p{Is_Block=oriya}', "");
Expect(0, 2943, '\p{^Is_Block=oriya}', "");
Expect(0, 2943, '\P{Is_Block=oriya}', "");
Expect(1, 2943, '\P{^Is_Block=oriya}', "");
Expect(0, 2944, '\p{Is_Block=oriya}', "");
Expect(1, 2944, '\p{^Is_Block=oriya}', "");
Expect(1, 2944, '\P{Is_Block=oriya}', "");
Expect(0, 2944, '\P{^Is_Block=oriya}', "");
Expect(1, 2943, '\p{Is_Block= oriya}', "");
Expect(0, 2943, '\p{^Is_Block= oriya}', "");
Expect(0, 2943, '\P{Is_Block= oriya}', "");
Expect(1, 2943, '\P{^Is_Block= oriya}', "");
Expect(0, 2944, '\p{Is_Block= oriya}', "");
Expect(1, 2944, '\p{^Is_Block= oriya}', "");
Expect(1, 2944, '\P{Is_Block= oriya}', "");
Expect(0, 2944, '\P{^Is_Block= oriya}', "");
Error('\p{Is_Blk=/a/Oriya}');
Error('\P{Is_Blk=/a/Oriya}');
Expect(1, 2943, '\p{Is_Blk=oriya}', "");
Expect(0, 2943, '\p{^Is_Blk=oriya}', "");
Expect(0, 2943, '\P{Is_Blk=oriya}', "");
Expect(1, 2943, '\P{^Is_Blk=oriya}', "");
Expect(0, 2944, '\p{Is_Blk=oriya}', "");
Expect(1, 2944, '\p{^Is_Blk=oriya}', "");
Expect(1, 2944, '\P{Is_Blk=oriya}', "");
Expect(0, 2944, '\P{^Is_Blk=oriya}', "");
Expect(1, 2943, '\p{Is_Blk=_	ORIYA}', "");
Expect(0, 2943, '\p{^Is_Blk=_	ORIYA}', "");
Expect(0, 2943, '\P{Is_Blk=_	ORIYA}', "");
Expect(1, 2943, '\P{^Is_Blk=_	ORIYA}', "");
Expect(0, 2944, '\p{Is_Blk=_	ORIYA}', "");
Expect(1, 2944, '\p{^Is_Blk=_	ORIYA}', "");
Expect(1, 2944, '\P{Is_Blk=_	ORIYA}', "");
Expect(0, 2944, '\P{^Is_Blk=_	ORIYA}', "");
Error('\p{Block=	/a/Osmanya}');
Error('\P{Block=	/a/Osmanya}');
Expect(1, 66735, '\p{Block=osmanya}', "");
Expect(0, 66735, '\p{^Block=osmanya}', "");
Expect(0, 66735, '\P{Block=osmanya}', "");
Expect(1, 66735, '\P{^Block=osmanya}', "");
Expect(0, 66736, '\p{Block=osmanya}', "");
Expect(1, 66736, '\p{^Block=osmanya}', "");
Expect(1, 66736, '\P{Block=osmanya}', "");
Expect(0, 66736, '\P{^Block=osmanya}', "");
Expect(1, 66735, '\p{Block=	 Osmanya}', "");
Expect(0, 66735, '\p{^Block=	 Osmanya}', "");
Expect(0, 66735, '\P{Block=	 Osmanya}', "");
Expect(1, 66735, '\P{^Block=	 Osmanya}', "");
Expect(0, 66736, '\p{Block=	 Osmanya}', "");
Expect(1, 66736, '\p{^Block=	 Osmanya}', "");
Expect(1, 66736, '\P{Block=	 Osmanya}', "");
Expect(0, 66736, '\P{^Block=	 Osmanya}', "");
Error('\p{Blk=/a/-	OSMANYA}');
Error('\P{Blk=/a/-	OSMANYA}');
Expect(1, 66735, '\p{Blk:   osmanya}', "");
Expect(0, 66735, '\p{^Blk:   osmanya}', "");
Expect(0, 66735, '\P{Blk:   osmanya}', "");
Expect(1, 66735, '\P{^Blk:   osmanya}', "");
Expect(0, 66736, '\p{Blk:   osmanya}', "");
Expect(1, 66736, '\p{^Blk:   osmanya}', "");
Expect(1, 66736, '\P{Blk:   osmanya}', "");
Expect(0, 66736, '\P{^Blk:   osmanya}', "");
Expect(1, 66735, '\p{Blk=_osmanya}', "");
Expect(0, 66735, '\p{^Blk=_osmanya}', "");
Expect(0, 66735, '\P{Blk=_osmanya}', "");
Expect(1, 66735, '\P{^Blk=_osmanya}', "");
Expect(0, 66736, '\p{Blk=_osmanya}', "");
Expect(1, 66736, '\p{^Blk=_osmanya}', "");
Expect(1, 66736, '\P{Blk=_osmanya}', "");
Expect(0, 66736, '\P{^Blk=_osmanya}', "");
Error('\p{Is_Block=:=_ osmanya}');
Error('\P{Is_Block=:=_ osmanya}');
Expect(1, 66735, '\p{Is_Block=osmanya}', "");
Expect(0, 66735, '\p{^Is_Block=osmanya}', "");
Expect(0, 66735, '\P{Is_Block=osmanya}', "");
Expect(1, 66735, '\P{^Is_Block=osmanya}', "");
Expect(0, 66736, '\p{Is_Block=osmanya}', "");
Expect(1, 66736, '\p{^Is_Block=osmanya}', "");
Expect(1, 66736, '\P{Is_Block=osmanya}', "");
Expect(0, 66736, '\P{^Is_Block=osmanya}', "");
Expect(1, 66735, '\p{Is_Block=	-OSMANYA}', "");
Expect(0, 66735, '\p{^Is_Block=	-OSMANYA}', "");
Expect(0, 66735, '\P{Is_Block=	-OSMANYA}', "");
Expect(1, 66735, '\P{^Is_Block=	-OSMANYA}', "");
Expect(0, 66736, '\p{Is_Block=	-OSMANYA}', "");
Expect(1, 66736, '\p{^Is_Block=	-OSMANYA}', "");
Expect(1, 66736, '\P{Is_Block=	-OSMANYA}', "");
Expect(0, 66736, '\P{^Is_Block=	-OSMANYA}', "");
Error('\p{Is_Blk=Osmanya:=}');
Error('\P{Is_Blk=Osmanya:=}');
Expect(1, 66735, '\p{Is_Blk=osmanya}', "");
Expect(0, 66735, '\p{^Is_Blk=osmanya}', "");
Expect(0, 66735, '\P{Is_Blk=osmanya}', "");
Expect(1, 66735, '\P{^Is_Blk=osmanya}', "");
Expect(0, 66736, '\p{Is_Blk=osmanya}', "");
Expect(1, 66736, '\p{^Is_Blk=osmanya}', "");
Expect(1, 66736, '\P{Is_Blk=osmanya}', "");
Expect(0, 66736, '\P{^Is_Blk=osmanya}', "");
Expect(1, 66735, '\p{Is_Blk=_osmanya}', "");
Expect(0, 66735, '\p{^Is_Blk=_osmanya}', "");
Expect(0, 66735, '\P{Is_Blk=_osmanya}', "");
Expect(1, 66735, '\P{^Is_Blk=_osmanya}', "");
Expect(0, 66736, '\p{Is_Blk=_osmanya}', "");
Expect(1, 66736, '\p{^Is_Blk=_osmanya}', "");
Expect(1, 66736, '\P{Is_Blk=_osmanya}', "");
Expect(0, 66736, '\P{^Is_Blk=_osmanya}', "");
Error('\p{Block=:=-_private_Use_area}');
Error('\P{Block=:=-_private_Use_area}');
Expect(1, 63743, '\p{Block=privateusearea}', "");
Expect(0, 63743, '\p{^Block=privateusearea}', "");
Expect(0, 63743, '\P{Block=privateusearea}', "");
Expect(1, 63743, '\P{^Block=privateusearea}', "");
Expect(0, 63744, '\p{Block=privateusearea}', "");
Expect(1, 63744, '\p{^Block=privateusearea}', "");
Expect(1, 63744, '\P{Block=privateusearea}', "");
Expect(0, 63744, '\P{^Block=privateusearea}', "");
Expect(1, 63743, '\p{Block=_private_use_AREA}', "");
Expect(0, 63743, '\p{^Block=_private_use_AREA}', "");
Expect(0, 63743, '\P{Block=_private_use_AREA}', "");
Expect(1, 63743, '\P{^Block=_private_use_AREA}', "");
Expect(0, 63744, '\p{Block=_private_use_AREA}', "");
Expect(1, 63744, '\p{^Block=_private_use_AREA}', "");
Expect(1, 63744, '\P{Block=_private_use_AREA}', "");
Expect(0, 63744, '\P{^Block=_private_use_AREA}', "");
Error('\p{Blk=	 pua:=}');
Error('\P{Blk=	 pua:=}');
Expect(1, 63743, '\p{Blk=pua}', "");
Expect(0, 63743, '\p{^Blk=pua}', "");
Expect(0, 63743, '\P{Blk=pua}', "");
Expect(1, 63743, '\P{^Blk=pua}', "");
Expect(0, 63744, '\p{Blk=pua}', "");
Expect(1, 63744, '\p{^Blk=pua}', "");
Expect(1, 63744, '\P{Blk=pua}', "");
Expect(0, 63744, '\P{^Blk=pua}', "");
Expect(1, 63743, '\p{Blk:_	PUA}', "");
Expect(0, 63743, '\p{^Blk:_	PUA}', "");
Expect(0, 63743, '\P{Blk:_	PUA}', "");
Expect(1, 63743, '\P{^Blk:_	PUA}', "");
Expect(0, 63744, '\p{Blk:_	PUA}', "");
Expect(1, 63744, '\p{^Blk:_	PUA}', "");
Expect(1, 63744, '\P{Blk:_	PUA}', "");
Expect(0, 63744, '\P{^Blk:_	PUA}', "");
Error('\p{Is_Block=	/a/private_Use}');
Error('\P{Is_Block=	/a/private_Use}');
Expect(1, 63743, '\p{Is_Block=privateuse}', "");
Expect(0, 63743, '\p{^Is_Block=privateuse}', "");
Expect(0, 63743, '\P{Is_Block=privateuse}', "");
Expect(1, 63743, '\P{^Is_Block=privateuse}', "");
Expect(0, 63744, '\p{Is_Block=privateuse}', "");
Expect(1, 63744, '\p{^Is_Block=privateuse}', "");
Expect(1, 63744, '\P{Is_Block=privateuse}', "");
Expect(0, 63744, '\P{^Is_Block=privateuse}', "");
Expect(1, 63743, '\p{Is_Block=	-PRIVATE_Use}', "");
Expect(0, 63743, '\p{^Is_Block=	-PRIVATE_Use}', "");
Expect(0, 63743, '\P{Is_Block=	-PRIVATE_Use}', "");
Expect(1, 63743, '\P{^Is_Block=	-PRIVATE_Use}', "");
Expect(0, 63744, '\p{Is_Block=	-PRIVATE_Use}', "");
Expect(1, 63744, '\p{^Is_Block=	-PRIVATE_Use}', "");
Expect(1, 63744, '\P{Is_Block=	-PRIVATE_Use}', "");
Expect(0, 63744, '\P{^Is_Block=	-PRIVATE_Use}', "");
Error('\p{Is_Blk=-:=Private_use_area}');
Error('\P{Is_Blk=-:=Private_use_area}');
Expect(1, 63743, '\p{Is_Blk=privateusearea}', "");
Expect(0, 63743, '\p{^Is_Blk=privateusearea}', "");
Expect(0, 63743, '\P{Is_Blk=privateusearea}', "");
Expect(1, 63743, '\P{^Is_Blk=privateusearea}', "");
Expect(0, 63744, '\p{Is_Blk=privateusearea}', "");
Expect(1, 63744, '\p{^Is_Blk=privateusearea}', "");
Expect(1, 63744, '\P{Is_Blk=privateusearea}', "");
Expect(0, 63744, '\P{^Is_Blk=privateusearea}', "");
Expect(1, 63743, '\p{Is_Blk=  PRIVATE_use_Area}', "");
Expect(0, 63743, '\p{^Is_Blk=  PRIVATE_use_Area}', "");
Expect(0, 63743, '\P{Is_Blk=  PRIVATE_use_Area}', "");
Expect(1, 63743, '\P{^Is_Blk=  PRIVATE_use_Area}', "");
Expect(0, 63744, '\p{Is_Blk=  PRIVATE_use_Area}', "");
Expect(1, 63744, '\p{^Is_Blk=  PRIVATE_use_Area}', "");
Expect(1, 63744, '\P{Is_Blk=  PRIVATE_use_Area}', "");
Expect(0, 63744, '\P{^Is_Blk=  PRIVATE_use_Area}', "");
Error('\p{Block=		Phags_Pa:=}');
Error('\P{Block=		Phags_Pa:=}');
Expect(1, 43135, '\p{Block=phagspa}', "");
Expect(0, 43135, '\p{^Block=phagspa}', "");
Expect(0, 43135, '\P{Block=phagspa}', "");
Expect(1, 43135, '\P{^Block=phagspa}', "");
Expect(0, 43136, '\p{Block=phagspa}', "");
Expect(1, 43136, '\p{^Block=phagspa}', "");
Expect(1, 43136, '\P{Block=phagspa}', "");
Expect(0, 43136, '\P{^Block=phagspa}', "");
Expect(1, 43135, '\p{Block= Phags_PA}', "");
Expect(0, 43135, '\p{^Block= Phags_PA}', "");
Expect(0, 43135, '\P{Block= Phags_PA}', "");
Expect(1, 43135, '\P{^Block= Phags_PA}', "");
Expect(0, 43136, '\p{Block= Phags_PA}', "");
Expect(1, 43136, '\p{^Block= Phags_PA}', "");
Expect(1, 43136, '\P{Block= Phags_PA}', "");
Expect(0, 43136, '\P{^Block= Phags_PA}', "");
Error('\p{Blk=	PHAGS_Pa/a/}');
Error('\P{Blk=	PHAGS_Pa/a/}');
Expect(1, 43135, '\p{Blk=phagspa}', "");
Expect(0, 43135, '\p{^Blk=phagspa}', "");
Expect(0, 43135, '\P{Blk=phagspa}', "");
Expect(1, 43135, '\P{^Blk=phagspa}', "");
Expect(0, 43136, '\p{Blk=phagspa}', "");
Expect(1, 43136, '\p{^Blk=phagspa}', "");
Expect(1, 43136, '\P{Blk=phagspa}', "");
Expect(0, 43136, '\P{^Blk=phagspa}', "");
Expect(1, 43135, '\p{Blk=	Phags_Pa}', "");
Expect(0, 43135, '\p{^Blk=	Phags_Pa}', "");
Expect(0, 43135, '\P{Blk=	Phags_Pa}', "");
Expect(1, 43135, '\P{^Blk=	Phags_Pa}', "");
Expect(0, 43136, '\p{Blk=	Phags_Pa}', "");
Expect(1, 43136, '\p{^Blk=	Phags_Pa}', "");
Expect(1, 43136, '\P{Blk=	Phags_Pa}', "");
Expect(0, 43136, '\P{^Blk=	Phags_Pa}', "");
Error('\p{Is_Block=	:=PHAGS_PA}');
Error('\P{Is_Block=	:=PHAGS_PA}');
Expect(1, 43135, '\p{Is_Block=phagspa}', "");
Expect(0, 43135, '\p{^Is_Block=phagspa}', "");
Expect(0, 43135, '\P{Is_Block=phagspa}', "");
Expect(1, 43135, '\P{^Is_Block=phagspa}', "");
Expect(0, 43136, '\p{Is_Block=phagspa}', "");
Expect(1, 43136, '\p{^Is_Block=phagspa}', "");
Expect(1, 43136, '\P{Is_Block=phagspa}', "");
Expect(0, 43136, '\P{^Is_Block=phagspa}', "");
Expect(1, 43135, '\p{Is_Block:  	phags_Pa}', "");
Expect(0, 43135, '\p{^Is_Block:  	phags_Pa}', "");
Expect(0, 43135, '\P{Is_Block:  	phags_Pa}', "");
Expect(1, 43135, '\P{^Is_Block:  	phags_Pa}', "");
Expect(0, 43136, '\p{Is_Block:  	phags_Pa}', "");
Expect(1, 43136, '\p{^Is_Block:  	phags_Pa}', "");
Expect(1, 43136, '\P{Is_Block:  	phags_Pa}', "");
Expect(0, 43136, '\P{^Is_Block:  	phags_Pa}', "");
Error('\p{Is_Blk=:=Phags_pa}');
Error('\P{Is_Blk=:=Phags_pa}');
Expect(1, 43135, '\p{Is_Blk=phagspa}', "");
Expect(0, 43135, '\p{^Is_Blk=phagspa}', "");
Expect(0, 43135, '\P{Is_Blk=phagspa}', "");
Expect(1, 43135, '\P{^Is_Blk=phagspa}', "");
Expect(0, 43136, '\p{Is_Blk=phagspa}', "");
Expect(1, 43136, '\p{^Is_Blk=phagspa}', "");
Expect(1, 43136, '\P{Is_Blk=phagspa}', "");
Expect(0, 43136, '\P{^Is_Blk=phagspa}', "");
Expect(1, 43135, '\p{Is_Blk=	PHAGS_Pa}', "");
Expect(0, 43135, '\p{^Is_Blk=	PHAGS_Pa}', "");
Expect(0, 43135, '\P{Is_Blk=	PHAGS_Pa}', "");
Expect(1, 43135, '\P{^Is_Blk=	PHAGS_Pa}', "");
Expect(0, 43136, '\p{Is_Blk=	PHAGS_Pa}', "");
Expect(1, 43136, '\p{^Is_Blk=	PHAGS_Pa}', "");
Expect(1, 43136, '\P{Is_Blk=	PHAGS_Pa}', "");
Expect(0, 43136, '\P{^Is_Blk=	PHAGS_Pa}', "");
Error('\p{Block=/a/__Phaistos_DISC}');
Error('\P{Block=/a/__Phaistos_DISC}');
Expect(1, 66047, '\p{Block=phaistosdisc}', "");
Expect(0, 66047, '\p{^Block=phaistosdisc}', "");
Expect(0, 66047, '\P{Block=phaistosdisc}', "");
Expect(1, 66047, '\P{^Block=phaistosdisc}', "");
Expect(0, 66048, '\p{Block=phaistosdisc}', "");
Expect(1, 66048, '\p{^Block=phaistosdisc}', "");
Expect(1, 66048, '\P{Block=phaistosdisc}', "");
Expect(0, 66048, '\P{^Block=phaistosdisc}', "");
Expect(1, 66047, '\p{Block=	-PHAISTOS_DISC}', "");
Expect(0, 66047, '\p{^Block=	-PHAISTOS_DISC}', "");
Expect(0, 66047, '\P{Block=	-PHAISTOS_DISC}', "");
Expect(1, 66047, '\P{^Block=	-PHAISTOS_DISC}', "");
Expect(0, 66048, '\p{Block=	-PHAISTOS_DISC}', "");
Expect(1, 66048, '\p{^Block=	-PHAISTOS_DISC}', "");
Expect(1, 66048, '\P{Block=	-PHAISTOS_DISC}', "");
Expect(0, 66048, '\P{^Block=	-PHAISTOS_DISC}', "");
Error('\p{Blk=:=Phaistos}');
Error('\P{Blk=:=Phaistos}');
Expect(1, 66047, '\p{Blk=phaistos}', "");
Expect(0, 66047, '\p{^Blk=phaistos}', "");
Expect(0, 66047, '\P{Blk=phaistos}', "");
Expect(1, 66047, '\P{^Blk=phaistos}', "");
Expect(0, 66048, '\p{Blk=phaistos}', "");
Expect(1, 66048, '\p{^Blk=phaistos}', "");
Expect(1, 66048, '\P{Blk=phaistos}', "");
Expect(0, 66048, '\P{^Blk=phaistos}', "");
Expect(1, 66047, '\p{Blk=	-Phaistos}', "");
Expect(0, 66047, '\p{^Blk=	-Phaistos}', "");
Expect(0, 66047, '\P{Blk=	-Phaistos}', "");
Expect(1, 66047, '\P{^Blk=	-Phaistos}', "");
Expect(0, 66048, '\p{Blk=	-Phaistos}', "");
Expect(1, 66048, '\p{^Blk=	-Phaistos}', "");
Expect(1, 66048, '\P{Blk=	-Phaistos}', "");
Expect(0, 66048, '\P{^Blk=	-Phaistos}', "");
Error('\p{Is_Block=-_Phaistos_DISC/a/}');
Error('\P{Is_Block=-_Phaistos_DISC/a/}');
Expect(1, 66047, '\p{Is_Block: phaistosdisc}', "");
Expect(0, 66047, '\p{^Is_Block: phaistosdisc}', "");
Expect(0, 66047, '\P{Is_Block: phaistosdisc}', "");
Expect(1, 66047, '\P{^Is_Block: phaistosdisc}', "");
Expect(0, 66048, '\p{Is_Block: phaistosdisc}', "");
Expect(1, 66048, '\p{^Is_Block: phaistosdisc}', "");
Expect(1, 66048, '\P{Is_Block: phaistosdisc}', "");
Expect(0, 66048, '\P{^Is_Block: phaistosdisc}', "");
Expect(1, 66047, '\p{Is_Block=__PHAISTOS_Disc}', "");
Expect(0, 66047, '\p{^Is_Block=__PHAISTOS_Disc}', "");
Expect(0, 66047, '\P{Is_Block=__PHAISTOS_Disc}', "");
Expect(1, 66047, '\P{^Is_Block=__PHAISTOS_Disc}', "");
Expect(0, 66048, '\p{Is_Block=__PHAISTOS_Disc}', "");
Expect(1, 66048, '\p{^Is_Block=__PHAISTOS_Disc}', "");
Expect(1, 66048, '\P{Is_Block=__PHAISTOS_Disc}', "");
Expect(0, 66048, '\P{^Is_Block=__PHAISTOS_Disc}', "");
Error('\p{Is_Blk=-Phaistos:=}');
Error('\P{Is_Blk=-Phaistos:=}');
Expect(1, 66047, '\p{Is_Blk=phaistos}', "");
Expect(0, 66047, '\p{^Is_Blk=phaistos}', "");
Expect(0, 66047, '\P{Is_Blk=phaistos}', "");
Expect(1, 66047, '\P{^Is_Blk=phaistos}', "");
Expect(0, 66048, '\p{Is_Blk=phaistos}', "");
Expect(1, 66048, '\p{^Is_Blk=phaistos}', "");
Expect(1, 66048, '\P{Is_Blk=phaistos}', "");
Expect(0, 66048, '\P{^Is_Blk=phaistos}', "");
Expect(1, 66047, '\p{Is_Blk= -Phaistos}', "");
Expect(0, 66047, '\p{^Is_Blk= -Phaistos}', "");
Expect(0, 66047, '\P{Is_Blk= -Phaistos}', "");
Expect(1, 66047, '\P{^Is_Blk= -Phaistos}', "");
Expect(0, 66048, '\p{Is_Blk= -Phaistos}', "");
Expect(1, 66048, '\p{^Is_Blk= -Phaistos}', "");
Expect(1, 66048, '\P{Is_Blk= -Phaistos}', "");
Expect(0, 66048, '\P{^Is_Blk= -Phaistos}', "");
Error('\p{Block=-/a/phoenician}');
Error('\P{Block=-/a/phoenician}');
Expect(1, 67871, '\p{Block=phoenician}', "");
Expect(0, 67871, '\p{^Block=phoenician}', "");
Expect(0, 67871, '\P{Block=phoenician}', "");
Expect(1, 67871, '\P{^Block=phoenician}', "");
Expect(0, 67872, '\p{Block=phoenician}', "");
Expect(1, 67872, '\p{^Block=phoenician}', "");
Expect(1, 67872, '\P{Block=phoenician}', "");
Expect(0, 67872, '\P{^Block=phoenician}', "");
Expect(1, 67871, '\p{Block: _ phoenician}', "");
Expect(0, 67871, '\p{^Block: _ phoenician}', "");
Expect(0, 67871, '\P{Block: _ phoenician}', "");
Expect(1, 67871, '\P{^Block: _ phoenician}', "");
Expect(0, 67872, '\p{Block: _ phoenician}', "");
Expect(1, 67872, '\p{^Block: _ phoenician}', "");
Expect(1, 67872, '\P{Block: _ phoenician}', "");
Expect(0, 67872, '\P{^Block: _ phoenician}', "");
Error('\p{Blk=-	Phoenician/a/}');
Error('\P{Blk=-	Phoenician/a/}');
Expect(1, 67871, '\p{Blk=phoenician}', "");
Expect(0, 67871, '\p{^Blk=phoenician}', "");
Expect(0, 67871, '\P{Blk=phoenician}', "");
Expect(1, 67871, '\P{^Blk=phoenician}', "");
Expect(0, 67872, '\p{Blk=phoenician}', "");
Expect(1, 67872, '\p{^Blk=phoenician}', "");
Expect(1, 67872, '\P{Blk=phoenician}', "");
Expect(0, 67872, '\P{^Blk=phoenician}', "");
Expect(1, 67871, '\p{Blk= -Phoenician}', "");
Expect(0, 67871, '\p{^Blk= -Phoenician}', "");
Expect(0, 67871, '\P{Blk= -Phoenician}', "");
Expect(1, 67871, '\P{^Blk= -Phoenician}', "");
Expect(0, 67872, '\p{Blk= -Phoenician}', "");
Expect(1, 67872, '\p{^Blk= -Phoenician}', "");
Expect(1, 67872, '\P{Blk= -Phoenician}', "");
Expect(0, 67872, '\P{^Blk= -Phoenician}', "");
Error('\p{Is_Block=_:=PHOENICIAN}');
Error('\P{Is_Block=_:=PHOENICIAN}');
Expect(1, 67871, '\p{Is_Block=phoenician}', "");
Expect(0, 67871, '\p{^Is_Block=phoenician}', "");
Expect(0, 67871, '\P{Is_Block=phoenician}', "");
Expect(1, 67871, '\P{^Is_Block=phoenician}', "");
Expect(0, 67872, '\p{Is_Block=phoenician}', "");
Expect(1, 67872, '\p{^Is_Block=phoenician}', "");
Expect(1, 67872, '\P{Is_Block=phoenician}', "");
Expect(0, 67872, '\P{^Is_Block=phoenician}', "");
Expect(1, 67871, '\p{Is_Block=	-phoenician}', "");
Expect(0, 67871, '\p{^Is_Block=	-phoenician}', "");
Expect(0, 67871, '\P{Is_Block=	-phoenician}', "");
Expect(1, 67871, '\P{^Is_Block=	-phoenician}', "");
Expect(0, 67872, '\p{Is_Block=	-phoenician}', "");
Expect(1, 67872, '\p{^Is_Block=	-phoenician}', "");
Expect(1, 67872, '\P{Is_Block=	-phoenician}', "");
Expect(0, 67872, '\P{^Is_Block=	-phoenician}', "");
Error('\p{Is_Blk=:=_ Phoenician}');
Error('\P{Is_Blk=:=_ Phoenician}');
Expect(1, 67871, '\p{Is_Blk=phoenician}', "");
Expect(0, 67871, '\p{^Is_Blk=phoenician}', "");
Expect(0, 67871, '\P{Is_Blk=phoenician}', "");
Expect(1, 67871, '\P{^Is_Blk=phoenician}', "");
Expect(0, 67872, '\p{Is_Blk=phoenician}', "");
Expect(1, 67872, '\p{^Is_Blk=phoenician}', "");
Expect(1, 67872, '\P{Is_Blk=phoenician}', "");
Expect(0, 67872, '\P{^Is_Blk=phoenician}', "");
Expect(1, 67871, '\p{Is_Blk= -Phoenician}', "");
Expect(0, 67871, '\p{^Is_Blk= -Phoenician}', "");
Expect(0, 67871, '\P{Is_Blk= -Phoenician}', "");
Expect(1, 67871, '\P{^Is_Blk= -Phoenician}', "");
Expect(0, 67872, '\p{Is_Blk= -Phoenician}', "");
Expect(1, 67872, '\p{^Is_Blk= -Phoenician}', "");
Expect(1, 67872, '\P{Is_Blk= -Phoenician}', "");
Expect(0, 67872, '\P{^Is_Blk= -Phoenician}', "");
Error('\p{Block=--Phonetic_extensions/a/}');
Error('\P{Block=--Phonetic_extensions/a/}');
Expect(1, 7551, '\p{Block=phoneticextensions}', "");
Expect(0, 7551, '\p{^Block=phoneticextensions}', "");
Expect(0, 7551, '\P{Block=phoneticextensions}', "");
Expect(1, 7551, '\P{^Block=phoneticextensions}', "");
Expect(0, 7552, '\p{Block=phoneticextensions}', "");
Expect(1, 7552, '\p{^Block=phoneticextensions}', "");
Expect(1, 7552, '\P{Block=phoneticextensions}', "");
Expect(0, 7552, '\P{^Block=phoneticextensions}', "");
Expect(1, 7551, '\p{Block=	phonetic_Extensions}', "");
Expect(0, 7551, '\p{^Block=	phonetic_Extensions}', "");
Expect(0, 7551, '\P{Block=	phonetic_Extensions}', "");
Expect(1, 7551, '\P{^Block=	phonetic_Extensions}', "");
Expect(0, 7552, '\p{Block=	phonetic_Extensions}', "");
Expect(1, 7552, '\p{^Block=	phonetic_Extensions}', "");
Expect(1, 7552, '\P{Block=	phonetic_Extensions}', "");
Expect(0, 7552, '\P{^Block=	phonetic_Extensions}', "");
Error('\p{Blk: :=	 phonetic_Ext}');
Error('\P{Blk: :=	 phonetic_Ext}');
Expect(1, 7551, '\p{Blk=phoneticext}', "");
Expect(0, 7551, '\p{^Blk=phoneticext}', "");
Expect(0, 7551, '\P{Blk=phoneticext}', "");
Expect(1, 7551, '\P{^Blk=phoneticext}', "");
Expect(0, 7552, '\p{Blk=phoneticext}', "");
Expect(1, 7552, '\p{^Blk=phoneticext}', "");
Expect(1, 7552, '\P{Blk=phoneticext}', "");
Expect(0, 7552, '\P{^Blk=phoneticext}', "");
Expect(1, 7551, '\p{Blk= _PHONETIC_ext}', "");
Expect(0, 7551, '\p{^Blk= _PHONETIC_ext}', "");
Expect(0, 7551, '\P{Blk= _PHONETIC_ext}', "");
Expect(1, 7551, '\P{^Blk= _PHONETIC_ext}', "");
Expect(0, 7552, '\p{Blk= _PHONETIC_ext}', "");
Expect(1, 7552, '\p{^Blk= _PHONETIC_ext}', "");
Expect(1, 7552, '\P{Blk= _PHONETIC_ext}', "");
Expect(0, 7552, '\P{^Blk= _PHONETIC_ext}', "");
Error('\p{Is_Block=:=	PHONETIC_extensions}');
Error('\P{Is_Block=:=	PHONETIC_extensions}');
Expect(1, 7551, '\p{Is_Block=phoneticextensions}', "");
Expect(0, 7551, '\p{^Is_Block=phoneticextensions}', "");
Expect(0, 7551, '\P{Is_Block=phoneticextensions}', "");
Expect(1, 7551, '\P{^Is_Block=phoneticextensions}', "");
Expect(0, 7552, '\p{Is_Block=phoneticextensions}', "");
Expect(1, 7552, '\p{^Is_Block=phoneticextensions}', "");
Expect(1, 7552, '\P{Is_Block=phoneticextensions}', "");
Expect(0, 7552, '\P{^Is_Block=phoneticextensions}', "");
Expect(1, 7551, '\p{Is_Block:	_Phonetic_extensions}', "");
Expect(0, 7551, '\p{^Is_Block:	_Phonetic_extensions}', "");
Expect(0, 7551, '\P{Is_Block:	_Phonetic_extensions}', "");
Expect(1, 7551, '\P{^Is_Block:	_Phonetic_extensions}', "");
Expect(0, 7552, '\p{Is_Block:	_Phonetic_extensions}', "");
Expect(1, 7552, '\p{^Is_Block:	_Phonetic_extensions}', "");
Expect(1, 7552, '\P{Is_Block:	_Phonetic_extensions}', "");
Expect(0, 7552, '\P{^Is_Block:	_Phonetic_extensions}', "");
Error('\p{Is_Blk:	_-phonetic_Ext/a/}');
Error('\P{Is_Blk:	_-phonetic_Ext/a/}');
Expect(1, 7551, '\p{Is_Blk=phoneticext}', "");
Expect(0, 7551, '\p{^Is_Blk=phoneticext}', "");
Expect(0, 7551, '\P{Is_Blk=phoneticext}', "");
Expect(1, 7551, '\P{^Is_Blk=phoneticext}', "");
Expect(0, 7552, '\p{Is_Blk=phoneticext}', "");
Expect(1, 7552, '\p{^Is_Blk=phoneticext}', "");
Expect(1, 7552, '\P{Is_Blk=phoneticext}', "");
Expect(0, 7552, '\P{^Is_Blk=phoneticext}', "");
Expect(1, 7551, '\p{Is_Blk=_PHONETIC_ext}', "");
Expect(0, 7551, '\p{^Is_Blk=_PHONETIC_ext}', "");
Expect(0, 7551, '\P{Is_Blk=_PHONETIC_ext}', "");
Expect(1, 7551, '\P{^Is_Blk=_PHONETIC_ext}', "");
Expect(0, 7552, '\p{Is_Blk=_PHONETIC_ext}', "");
Expect(1, 7552, '\p{^Is_Blk=_PHONETIC_ext}', "");
Expect(1, 7552, '\P{Is_Blk=_PHONETIC_ext}', "");
Expect(0, 7552, '\P{^Is_Blk=_PHONETIC_ext}', "");
Error('\p{Block=_/a/PHONETIC_extensions_Supplement}');
Error('\P{Block=_/a/PHONETIC_extensions_Supplement}');
Expect(1, 7615, '\p{Block=phoneticextensionssupplement}', "");
Expect(0, 7615, '\p{^Block=phoneticextensionssupplement}', "");
Expect(0, 7615, '\P{Block=phoneticextensionssupplement}', "");
Expect(1, 7615, '\P{^Block=phoneticextensionssupplement}', "");
Expect(0, 7616, '\p{Block=phoneticextensionssupplement}', "");
Expect(1, 7616, '\p{^Block=phoneticextensionssupplement}', "");
Expect(1, 7616, '\P{Block=phoneticextensionssupplement}', "");
Expect(0, 7616, '\P{^Block=phoneticextensionssupplement}', "");
Expect(1, 7615, '\p{Block= PHONETIC_extensions_supplement}', "");
Expect(0, 7615, '\p{^Block= PHONETIC_extensions_supplement}', "");
Expect(0, 7615, '\P{Block= PHONETIC_extensions_supplement}', "");
Expect(1, 7615, '\P{^Block= PHONETIC_extensions_supplement}', "");
Expect(0, 7616, '\p{Block= PHONETIC_extensions_supplement}', "");
Expect(1, 7616, '\p{^Block= PHONETIC_extensions_supplement}', "");
Expect(1, 7616, '\P{Block= PHONETIC_extensions_supplement}', "");
Expect(0, 7616, '\P{^Block= PHONETIC_extensions_supplement}', "");
Error('\p{Blk= 	phonetic_Ext_Sup/a/}');
Error('\P{Blk= 	phonetic_Ext_Sup/a/}');
Expect(1, 7615, '\p{Blk=phoneticextsup}', "");
Expect(0, 7615, '\p{^Blk=phoneticextsup}', "");
Expect(0, 7615, '\P{Blk=phoneticextsup}', "");
Expect(1, 7615, '\P{^Blk=phoneticextsup}', "");
Expect(0, 7616, '\p{Blk=phoneticextsup}', "");
Expect(1, 7616, '\p{^Blk=phoneticextsup}', "");
Expect(1, 7616, '\P{Blk=phoneticextsup}', "");
Expect(0, 7616, '\P{^Blk=phoneticextsup}', "");
Expect(1, 7615, '\p{Blk=-PHONETIC_ext_sup}', "");
Expect(0, 7615, '\p{^Blk=-PHONETIC_ext_sup}', "");
Expect(0, 7615, '\P{Blk=-PHONETIC_ext_sup}', "");
Expect(1, 7615, '\P{^Blk=-PHONETIC_ext_sup}', "");
Expect(0, 7616, '\p{Blk=-PHONETIC_ext_sup}', "");
Expect(1, 7616, '\p{^Blk=-PHONETIC_ext_sup}', "");
Expect(1, 7616, '\P{Blk=-PHONETIC_ext_sup}', "");
Expect(0, 7616, '\P{^Blk=-PHONETIC_ext_sup}', "");
Error('\p{Is_Block=:=  phonetic_EXTENSIONS_Supplement}');
Error('\P{Is_Block=:=  phonetic_EXTENSIONS_Supplement}');
Expect(1, 7615, '\p{Is_Block=phoneticextensionssupplement}', "");
Expect(0, 7615, '\p{^Is_Block=phoneticextensionssupplement}', "");
Expect(0, 7615, '\P{Is_Block=phoneticextensionssupplement}', "");
Expect(1, 7615, '\P{^Is_Block=phoneticextensionssupplement}', "");
Expect(0, 7616, '\p{Is_Block=phoneticextensionssupplement}', "");
Expect(1, 7616, '\p{^Is_Block=phoneticextensionssupplement}', "");
Expect(1, 7616, '\P{Is_Block=phoneticextensionssupplement}', "");
Expect(0, 7616, '\P{^Is_Block=phoneticextensionssupplement}', "");
Expect(1, 7615, '\p{Is_Block=-Phonetic_Extensions_SUPPLEMENT}', "");
Expect(0, 7615, '\p{^Is_Block=-Phonetic_Extensions_SUPPLEMENT}', "");
Expect(0, 7615, '\P{Is_Block=-Phonetic_Extensions_SUPPLEMENT}', "");
Expect(1, 7615, '\P{^Is_Block=-Phonetic_Extensions_SUPPLEMENT}', "");
Expect(0, 7616, '\p{Is_Block=-Phonetic_Extensions_SUPPLEMENT}', "");
Expect(1, 7616, '\p{^Is_Block=-Phonetic_Extensions_SUPPLEMENT}', "");
Expect(1, 7616, '\P{Is_Block=-Phonetic_Extensions_SUPPLEMENT}', "");
Expect(0, 7616, '\P{^Is_Block=-Phonetic_Extensions_SUPPLEMENT}', "");
Error('\p{Is_Blk=_PHONETIC_Ext_sup/a/}');
Error('\P{Is_Blk=_PHONETIC_Ext_sup/a/}');
Expect(1, 7615, '\p{Is_Blk=phoneticextsup}', "");
Expect(0, 7615, '\p{^Is_Blk=phoneticextsup}', "");
Expect(0, 7615, '\P{Is_Blk=phoneticextsup}', "");
Expect(1, 7615, '\P{^Is_Blk=phoneticextsup}', "");
Expect(0, 7616, '\p{Is_Blk=phoneticextsup}', "");
Expect(1, 7616, '\p{^Is_Blk=phoneticextsup}', "");
Expect(1, 7616, '\P{Is_Blk=phoneticextsup}', "");
Expect(0, 7616, '\P{^Is_Blk=phoneticextsup}', "");
Expect(1, 7615, '\p{Is_Blk=--Phonetic_Ext_Sup}', "");
Expect(0, 7615, '\p{^Is_Blk=--Phonetic_Ext_Sup}', "");
Expect(0, 7615, '\P{Is_Blk=--Phonetic_Ext_Sup}', "");
Expect(1, 7615, '\P{^Is_Blk=--Phonetic_Ext_Sup}', "");
Expect(0, 7616, '\p{Is_Blk=--Phonetic_Ext_Sup}', "");
Expect(1, 7616, '\p{^Is_Blk=--Phonetic_Ext_Sup}', "");
Expect(1, 7616, '\P{Is_Blk=--Phonetic_Ext_Sup}', "");
Expect(0, 7616, '\P{^Is_Blk=--Phonetic_Ext_Sup}', "");
Error('\p{Block= /a/Playing_cards}');
Error('\P{Block= /a/Playing_cards}');
Expect(1, 127231, '\p{Block:playingcards}', "");
Expect(0, 127231, '\p{^Block:playingcards}', "");
Expect(0, 127231, '\P{Block:playingcards}', "");
Expect(1, 127231, '\P{^Block:playingcards}', "");
Expect(0, 127232, '\p{Block:playingcards}', "");
Expect(1, 127232, '\p{^Block:playingcards}', "");
Expect(1, 127232, '\P{Block:playingcards}', "");
Expect(0, 127232, '\P{^Block:playingcards}', "");
Expect(1, 127231, '\p{Block: 	-PLAYING_Cards}', "");
Expect(0, 127231, '\p{^Block: 	-PLAYING_Cards}', "");
Expect(0, 127231, '\P{Block: 	-PLAYING_Cards}', "");
Expect(1, 127231, '\P{^Block: 	-PLAYING_Cards}', "");
Expect(0, 127232, '\p{Block: 	-PLAYING_Cards}', "");
Expect(1, 127232, '\p{^Block: 	-PLAYING_Cards}', "");
Expect(1, 127232, '\P{Block: 	-PLAYING_Cards}', "");
Expect(0, 127232, '\P{^Block: 	-PLAYING_Cards}', "");
Error('\p{Blk=	Playing_Cards:=}');
Error('\P{Blk=	Playing_Cards:=}');
Expect(1, 127231, '\p{Blk=playingcards}', "");
Expect(0, 127231, '\p{^Blk=playingcards}', "");
Expect(0, 127231, '\P{Blk=playingcards}', "");
Expect(1, 127231, '\P{^Blk=playingcards}', "");
Expect(0, 127232, '\p{Blk=playingcards}', "");
Expect(1, 127232, '\p{^Blk=playingcards}', "");
Expect(1, 127232, '\P{Blk=playingcards}', "");
Expect(0, 127232, '\P{^Blk=playingcards}', "");
Expect(1, 127231, '\p{Blk: --Playing_CARDS}', "");
Expect(0, 127231, '\p{^Blk: --Playing_CARDS}', "");
Expect(0, 127231, '\P{Blk: --Playing_CARDS}', "");
Expect(1, 127231, '\P{^Blk: --Playing_CARDS}', "");
Expect(0, 127232, '\p{Blk: --Playing_CARDS}', "");
Expect(1, 127232, '\p{^Blk: --Playing_CARDS}', "");
Expect(1, 127232, '\P{Blk: --Playing_CARDS}', "");
Expect(0, 127232, '\P{^Blk: --Playing_CARDS}', "");
Error('\p{Is_Block=-	Playing_CARDS:=}');
Error('\P{Is_Block=-	Playing_CARDS:=}');
Expect(1, 127231, '\p{Is_Block=playingcards}', "");
Expect(0, 127231, '\p{^Is_Block=playingcards}', "");
Expect(0, 127231, '\P{Is_Block=playingcards}', "");
Expect(1, 127231, '\P{^Is_Block=playingcards}', "");
Expect(0, 127232, '\p{Is_Block=playingcards}', "");
Expect(1, 127232, '\p{^Is_Block=playingcards}', "");
Expect(1, 127232, '\P{Is_Block=playingcards}', "");
Expect(0, 127232, '\P{^Is_Block=playingcards}', "");
Expect(1, 127231, '\p{Is_Block:	 -PLAYING_cards}', "");
Expect(0, 127231, '\p{^Is_Block:	 -PLAYING_cards}', "");
Expect(0, 127231, '\P{Is_Block:	 -PLAYING_cards}', "");
Expect(1, 127231, '\P{^Is_Block:	 -PLAYING_cards}', "");
Expect(0, 127232, '\p{Is_Block:	 -PLAYING_cards}', "");
Expect(1, 127232, '\p{^Is_Block:	 -PLAYING_cards}', "");
Expect(1, 127232, '\P{Is_Block:	 -PLAYING_cards}', "");
Expect(0, 127232, '\P{^Is_Block:	 -PLAYING_cards}', "");
Error('\p{Is_Blk=	/a/Playing_Cards}');
Error('\P{Is_Blk=	/a/Playing_Cards}');
Expect(1, 127231, '\p{Is_Blk=playingcards}', "");
Expect(0, 127231, '\p{^Is_Blk=playingcards}', "");
Expect(0, 127231, '\P{Is_Blk=playingcards}', "");
Expect(1, 127231, '\P{^Is_Blk=playingcards}', "");
Expect(0, 127232, '\p{Is_Blk=playingcards}', "");
Expect(1, 127232, '\p{^Is_Blk=playingcards}', "");
Expect(1, 127232, '\P{Is_Blk=playingcards}', "");
Expect(0, 127232, '\P{^Is_Blk=playingcards}', "");
Expect(1, 127231, '\p{Is_Blk=--Playing_cards}', "");
Expect(0, 127231, '\p{^Is_Blk=--Playing_cards}', "");
Expect(0, 127231, '\P{Is_Blk=--Playing_cards}', "");
Expect(1, 127231, '\P{^Is_Blk=--Playing_cards}', "");
Expect(0, 127232, '\p{Is_Blk=--Playing_cards}', "");
Expect(1, 127232, '\p{^Is_Blk=--Playing_cards}', "");
Expect(1, 127232, '\P{Is_Blk=--Playing_cards}', "");
Expect(0, 127232, '\P{^Is_Blk=--Playing_cards}', "");
Error('\p{Block=	/a/General_Punctuation}');
Error('\P{Block=	/a/General_Punctuation}');
Expect(1, 8303, '\p{Block=generalpunctuation}', "");
Expect(0, 8303, '\p{^Block=generalpunctuation}', "");
Expect(0, 8303, '\P{Block=generalpunctuation}', "");
Expect(1, 8303, '\P{^Block=generalpunctuation}', "");
Expect(0, 8304, '\p{Block=generalpunctuation}', "");
Expect(1, 8304, '\p{^Block=generalpunctuation}', "");
Expect(1, 8304, '\P{Block=generalpunctuation}', "");
Expect(0, 8304, '\P{^Block=generalpunctuation}', "");
Expect(1, 8303, '\p{Block=-General_Punctuation}', "");
Expect(0, 8303, '\p{^Block=-General_Punctuation}', "");
Expect(0, 8303, '\P{Block=-General_Punctuation}', "");
Expect(1, 8303, '\P{^Block=-General_Punctuation}', "");
Expect(0, 8304, '\p{Block=-General_Punctuation}', "");
Expect(1, 8304, '\p{^Block=-General_Punctuation}', "");
Expect(1, 8304, '\P{Block=-General_Punctuation}', "");
Expect(0, 8304, '\P{^Block=-General_Punctuation}', "");
Error('\p{Blk=/a/ -Punctuation}');
Error('\P{Blk=/a/ -Punctuation}');
Expect(1, 8303, '\p{Blk=punctuation}', "");
Expect(0, 8303, '\p{^Blk=punctuation}', "");
Expect(0, 8303, '\P{Blk=punctuation}', "");
Expect(1, 8303, '\P{^Blk=punctuation}', "");
Expect(0, 8304, '\p{Blk=punctuation}', "");
Expect(1, 8304, '\p{^Blk=punctuation}', "");
Expect(1, 8304, '\P{Blk=punctuation}', "");
Expect(0, 8304, '\P{^Blk=punctuation}', "");
Expect(1, 8303, '\p{Blk=_Punctuation}', "");
Expect(0, 8303, '\p{^Blk=_Punctuation}', "");
Expect(0, 8303, '\P{Blk=_Punctuation}', "");
Expect(1, 8303, '\P{^Blk=_Punctuation}', "");
Expect(0, 8304, '\p{Blk=_Punctuation}', "");
Expect(1, 8304, '\p{^Blk=_Punctuation}', "");
Expect(1, 8304, '\P{Blk=_Punctuation}', "");
Expect(0, 8304, '\P{^Blk=_Punctuation}', "");
Error('\p{Is_Block=-:=General_PUNCTUATION}');
Error('\P{Is_Block=-:=General_PUNCTUATION}');
Expect(1, 8303, '\p{Is_Block: generalpunctuation}', "");
Expect(0, 8303, '\p{^Is_Block: generalpunctuation}', "");
Expect(0, 8303, '\P{Is_Block: generalpunctuation}', "");
Expect(1, 8303, '\P{^Is_Block: generalpunctuation}', "");
Expect(0, 8304, '\p{Is_Block: generalpunctuation}', "");
Expect(1, 8304, '\p{^Is_Block: generalpunctuation}', "");
Expect(1, 8304, '\P{Is_Block: generalpunctuation}', "");
Expect(0, 8304, '\P{^Is_Block: generalpunctuation}', "");
Expect(1, 8303, '\p{Is_Block=		general_PUNCTUATION}', "");
Expect(0, 8303, '\p{^Is_Block=		general_PUNCTUATION}', "");
Expect(0, 8303, '\P{Is_Block=		general_PUNCTUATION}', "");
Expect(1, 8303, '\P{^Is_Block=		general_PUNCTUATION}', "");
Expect(0, 8304, '\p{Is_Block=		general_PUNCTUATION}', "");
Expect(1, 8304, '\p{^Is_Block=		general_PUNCTUATION}', "");
Expect(1, 8304, '\P{Is_Block=		general_PUNCTUATION}', "");
Expect(0, 8304, '\P{^Is_Block=		general_PUNCTUATION}', "");
Error('\p{Is_Blk=-/a/Punctuation}');
Error('\P{Is_Blk=-/a/Punctuation}');
Expect(1, 8303, '\p{Is_Blk=punctuation}', "");
Expect(0, 8303, '\p{^Is_Blk=punctuation}', "");
Expect(0, 8303, '\P{Is_Blk=punctuation}', "");
Expect(1, 8303, '\P{^Is_Blk=punctuation}', "");
Expect(0, 8304, '\p{Is_Blk=punctuation}', "");
Expect(1, 8304, '\p{^Is_Blk=punctuation}', "");
Expect(1, 8304, '\P{Is_Blk=punctuation}', "");
Expect(0, 8304, '\P{^Is_Blk=punctuation}', "");
Expect(1, 8303, '\p{Is_Blk=-_Punctuation}', "");
Expect(0, 8303, '\p{^Is_Blk=-_Punctuation}', "");
Expect(0, 8303, '\P{Is_Blk=-_Punctuation}', "");
Expect(1, 8303, '\P{^Is_Blk=-_Punctuation}', "");
Expect(0, 8304, '\p{Is_Blk=-_Punctuation}', "");
Expect(1, 8304, '\p{^Is_Blk=-_Punctuation}', "");
Expect(1, 8304, '\P{Is_Blk=-_Punctuation}', "");
Expect(0, 8304, '\P{^Is_Blk=-_Punctuation}', "");
Error('\p{Block=  rejang/a/}');
Error('\P{Block=  rejang/a/}');
Expect(1, 43359, '\p{Block=rejang}', "");
Expect(0, 43359, '\p{^Block=rejang}', "");
Expect(0, 43359, '\P{Block=rejang}', "");
Expect(1, 43359, '\P{^Block=rejang}', "");
Expect(0, 43360, '\p{Block=rejang}', "");
Expect(1, 43360, '\p{^Block=rejang}', "");
Expect(1, 43360, '\P{Block=rejang}', "");
Expect(0, 43360, '\P{^Block=rejang}', "");
Expect(1, 43359, '\p{Block= _rejang}', "");
Expect(0, 43359, '\p{^Block= _rejang}', "");
Expect(0, 43359, '\P{Block= _rejang}', "");
Expect(1, 43359, '\P{^Block= _rejang}', "");
Expect(0, 43360, '\p{Block= _rejang}', "");
Expect(1, 43360, '\p{^Block= _rejang}', "");
Expect(1, 43360, '\P{Block= _rejang}', "");
Expect(0, 43360, '\P{^Block= _rejang}', "");
Error('\p{Blk=:=rejang}');
Error('\P{Blk=:=rejang}');
Expect(1, 43359, '\p{Blk=rejang}', "");
Expect(0, 43359, '\p{^Blk=rejang}', "");
Expect(0, 43359, '\P{Blk=rejang}', "");
Expect(1, 43359, '\P{^Blk=rejang}', "");
Expect(0, 43360, '\p{Blk=rejang}', "");
Expect(1, 43360, '\p{^Blk=rejang}', "");
Expect(1, 43360, '\P{Blk=rejang}', "");
Expect(0, 43360, '\P{^Blk=rejang}', "");
Expect(1, 43359, '\p{Blk=	_REJANG}', "");
Expect(0, 43359, '\p{^Blk=	_REJANG}', "");
Expect(0, 43359, '\P{Blk=	_REJANG}', "");
Expect(1, 43359, '\P{^Blk=	_REJANG}', "");
Expect(0, 43360, '\p{Blk=	_REJANG}', "");
Expect(1, 43360, '\p{^Blk=	_REJANG}', "");
Expect(1, 43360, '\P{Blk=	_REJANG}', "");
Expect(0, 43360, '\P{^Blk=	_REJANG}', "");
Error('\p{Is_Block=:=_Rejang}');
Error('\P{Is_Block=:=_Rejang}');
Expect(1, 43359, '\p{Is_Block=rejang}', "");
Expect(0, 43359, '\p{^Is_Block=rejang}', "");
Expect(0, 43359, '\P{Is_Block=rejang}', "");
Expect(1, 43359, '\P{^Is_Block=rejang}', "");
Expect(0, 43360, '\p{Is_Block=rejang}', "");
Expect(1, 43360, '\p{^Is_Block=rejang}', "");
Expect(1, 43360, '\P{Is_Block=rejang}', "");
Expect(0, 43360, '\P{^Is_Block=rejang}', "");
Expect(1, 43359, '\p{Is_Block=_ Rejang}', "");
Expect(0, 43359, '\p{^Is_Block=_ Rejang}', "");
Expect(0, 43359, '\P{Is_Block=_ Rejang}', "");
Expect(1, 43359, '\P{^Is_Block=_ Rejang}', "");
Expect(0, 43360, '\p{Is_Block=_ Rejang}', "");
Expect(1, 43360, '\p{^Is_Block=_ Rejang}', "");
Expect(1, 43360, '\P{Is_Block=_ Rejang}', "");
Expect(0, 43360, '\P{^Is_Block=_ Rejang}', "");
Error('\p{Is_Blk=:=Rejang}');
Error('\P{Is_Blk=:=Rejang}');
Expect(1, 43359, '\p{Is_Blk=rejang}', "");
Expect(0, 43359, '\p{^Is_Blk=rejang}', "");
Expect(0, 43359, '\P{Is_Blk=rejang}', "");
Expect(1, 43359, '\P{^Is_Blk=rejang}', "");
Expect(0, 43360, '\p{Is_Blk=rejang}', "");
Expect(1, 43360, '\p{^Is_Blk=rejang}', "");
Expect(1, 43360, '\P{Is_Blk=rejang}', "");
Expect(0, 43360, '\P{^Is_Blk=rejang}', "");
Expect(1, 43359, '\p{Is_Blk=	 Rejang}', "");
Expect(0, 43359, '\p{^Is_Blk=	 Rejang}', "");
Expect(0, 43359, '\P{Is_Blk=	 Rejang}', "");
Expect(1, 43359, '\P{^Is_Blk=	 Rejang}', "");
Expect(0, 43360, '\p{Is_Blk=	 Rejang}', "");
Expect(1, 43360, '\p{^Is_Blk=	 Rejang}', "");
Expect(1, 43360, '\P{Is_Blk=	 Rejang}', "");
Expect(0, 43360, '\P{^Is_Blk=	 Rejang}', "");
Error('\p{Block= RUMI_Numeral_Symbols/a/}');
Error('\P{Block= RUMI_Numeral_Symbols/a/}');
Expect(1, 69247, '\p{Block=ruminumeralsymbols}', "");
Expect(0, 69247, '\p{^Block=ruminumeralsymbols}', "");
Expect(0, 69247, '\P{Block=ruminumeralsymbols}', "");
Expect(1, 69247, '\P{^Block=ruminumeralsymbols}', "");
Expect(0, 69248, '\p{Block=ruminumeralsymbols}', "");
Expect(1, 69248, '\p{^Block=ruminumeralsymbols}', "");
Expect(1, 69248, '\P{Block=ruminumeralsymbols}', "");
Expect(0, 69248, '\P{^Block=ruminumeralsymbols}', "");
Expect(1, 69247, '\p{Block=_Rumi_numeral_SYMBOLS}', "");
Expect(0, 69247, '\p{^Block=_Rumi_numeral_SYMBOLS}', "");
Expect(0, 69247, '\P{Block=_Rumi_numeral_SYMBOLS}', "");
Expect(1, 69247, '\P{^Block=_Rumi_numeral_SYMBOLS}', "");
Expect(0, 69248, '\p{Block=_Rumi_numeral_SYMBOLS}', "");
Expect(1, 69248, '\p{^Block=_Rumi_numeral_SYMBOLS}', "");
Expect(1, 69248, '\P{Block=_Rumi_numeral_SYMBOLS}', "");
Expect(0, 69248, '\P{^Block=_Rumi_numeral_SYMBOLS}', "");
Error('\p{Blk:	:= -RUMI}');
Error('\P{Blk:	:= -RUMI}');
Expect(1, 69247, '\p{Blk=rumi}', "");
Expect(0, 69247, '\p{^Blk=rumi}', "");
Expect(0, 69247, '\P{Blk=rumi}', "");
Expect(1, 69247, '\P{^Blk=rumi}', "");
Expect(0, 69248, '\p{Blk=rumi}', "");
Expect(1, 69248, '\p{^Blk=rumi}', "");
Expect(1, 69248, '\P{Blk=rumi}', "");
Expect(0, 69248, '\P{^Blk=rumi}', "");
Expect(1, 69247, '\p{Blk= _RUMI}', "");
Expect(0, 69247, '\p{^Blk= _RUMI}', "");
Expect(0, 69247, '\P{Blk= _RUMI}', "");
Expect(1, 69247, '\P{^Blk= _RUMI}', "");
Expect(0, 69248, '\p{Blk= _RUMI}', "");
Expect(1, 69248, '\p{^Blk= _RUMI}', "");
Expect(1, 69248, '\P{Blk= _RUMI}', "");
Expect(0, 69248, '\P{^Blk= _RUMI}', "");
Error('\p{Is_Block=_Rumi_Numeral_symbols:=}');
Error('\P{Is_Block=_Rumi_Numeral_symbols:=}');
Expect(1, 69247, '\p{Is_Block=ruminumeralsymbols}', "");
Expect(0, 69247, '\p{^Is_Block=ruminumeralsymbols}', "");
Expect(0, 69247, '\P{Is_Block=ruminumeralsymbols}', "");
Expect(1, 69247, '\P{^Is_Block=ruminumeralsymbols}', "");
Expect(0, 69248, '\p{Is_Block=ruminumeralsymbols}', "");
Expect(1, 69248, '\p{^Is_Block=ruminumeralsymbols}', "");
Expect(1, 69248, '\P{Is_Block=ruminumeralsymbols}', "");
Expect(0, 69248, '\P{^Is_Block=ruminumeralsymbols}', "");
Expect(1, 69247, '\p{Is_Block= rumi_numeral_symbols}', "");
Expect(0, 69247, '\p{^Is_Block= rumi_numeral_symbols}', "");
Expect(0, 69247, '\P{Is_Block= rumi_numeral_symbols}', "");
Expect(1, 69247, '\P{^Is_Block= rumi_numeral_symbols}', "");
Expect(0, 69248, '\p{Is_Block= rumi_numeral_symbols}', "");
Expect(1, 69248, '\p{^Is_Block= rumi_numeral_symbols}', "");
Expect(1, 69248, '\P{Is_Block= rumi_numeral_symbols}', "");
Expect(0, 69248, '\P{^Is_Block= rumi_numeral_symbols}', "");
Error('\p{Is_Blk=:=- rumi}');
Error('\P{Is_Blk=:=- rumi}');
Expect(1, 69247, '\p{Is_Blk=rumi}', "");
Expect(0, 69247, '\p{^Is_Blk=rumi}', "");
Expect(0, 69247, '\P{Is_Blk=rumi}', "");
Expect(1, 69247, '\P{^Is_Blk=rumi}', "");
Expect(0, 69248, '\p{Is_Blk=rumi}', "");
Expect(1, 69248, '\p{^Is_Blk=rumi}', "");
Expect(1, 69248, '\P{Is_Blk=rumi}', "");
Expect(0, 69248, '\P{^Is_Blk=rumi}', "");
Expect(1, 69247, '\p{Is_Blk:   	 Rumi}', "");
Expect(0, 69247, '\p{^Is_Blk:   	 Rumi}', "");
Expect(0, 69247, '\P{Is_Blk:   	 Rumi}', "");
Expect(1, 69247, '\P{^Is_Blk:   	 Rumi}', "");
Expect(0, 69248, '\p{Is_Blk:   	 Rumi}', "");
Expect(1, 69248, '\p{^Is_Blk:   	 Rumi}', "");
Expect(1, 69248, '\P{Is_Blk:   	 Rumi}', "");
Expect(0, 69248, '\P{^Is_Blk:   	 Rumi}', "");
Error('\p{Block=_/a/RUNIC}');
Error('\P{Block=_/a/RUNIC}');
Expect(1, 5887, '\p{Block=runic}', "");
Expect(0, 5887, '\p{^Block=runic}', "");
Expect(0, 5887, '\P{Block=runic}', "");
Expect(1, 5887, '\P{^Block=runic}', "");
Expect(0, 5888, '\p{Block=runic}', "");
Expect(1, 5888, '\p{^Block=runic}', "");
Expect(1, 5888, '\P{Block=runic}', "");
Expect(0, 5888, '\P{^Block=runic}', "");
Expect(1, 5887, '\p{Block=- Runic}', "");
Expect(0, 5887, '\p{^Block=- Runic}', "");
Expect(0, 5887, '\P{Block=- Runic}', "");
Expect(1, 5887, '\P{^Block=- Runic}', "");
Expect(0, 5888, '\p{Block=- Runic}', "");
Expect(1, 5888, '\p{^Block=- Runic}', "");
Expect(1, 5888, '\P{Block=- Runic}', "");
Expect(0, 5888, '\P{^Block=- Runic}', "");
Error('\p{Blk=:= Runic}');
Error('\P{Blk=:= Runic}');
Expect(1, 5887, '\p{Blk=runic}', "");
Expect(0, 5887, '\p{^Blk=runic}', "");
Expect(0, 5887, '\P{Blk=runic}', "");
Expect(1, 5887, '\P{^Blk=runic}', "");
Expect(0, 5888, '\p{Blk=runic}', "");
Expect(1, 5888, '\p{^Blk=runic}', "");
Expect(1, 5888, '\P{Blk=runic}', "");
Expect(0, 5888, '\P{^Blk=runic}', "");
Expect(1, 5887, '\p{Blk=_runic}', "");
Expect(0, 5887, '\p{^Blk=_runic}', "");
Expect(0, 5887, '\P{Blk=_runic}', "");
Expect(1, 5887, '\P{^Blk=_runic}', "");
Expect(0, 5888, '\p{Blk=_runic}', "");
Expect(1, 5888, '\p{^Blk=_runic}', "");
Expect(1, 5888, '\P{Blk=_runic}', "");
Expect(0, 5888, '\P{^Blk=_runic}', "");
Error('\p{Is_Block=/a/  RUNIC}');
Error('\P{Is_Block=/a/  RUNIC}');
Expect(1, 5887, '\p{Is_Block=runic}', "");
Expect(0, 5887, '\p{^Is_Block=runic}', "");
Expect(0, 5887, '\P{Is_Block=runic}', "");
Expect(1, 5887, '\P{^Is_Block=runic}', "");
Expect(0, 5888, '\p{Is_Block=runic}', "");
Expect(1, 5888, '\p{^Is_Block=runic}', "");
Expect(1, 5888, '\P{Is_Block=runic}', "");
Expect(0, 5888, '\P{^Is_Block=runic}', "");
Expect(1, 5887, '\p{Is_Block=-runic}', "");
Expect(0, 5887, '\p{^Is_Block=-runic}', "");
Expect(0, 5887, '\P{Is_Block=-runic}', "");
Expect(1, 5887, '\P{^Is_Block=-runic}', "");
Expect(0, 5888, '\p{Is_Block=-runic}', "");
Expect(1, 5888, '\p{^Is_Block=-runic}', "");
Expect(1, 5888, '\P{Is_Block=-runic}', "");
Expect(0, 5888, '\P{^Is_Block=-runic}', "");
Error('\p{Is_Blk=/a/ Runic}');
Error('\P{Is_Blk=/a/ Runic}');
Expect(1, 5887, '\p{Is_Blk=runic}', "");
Expect(0, 5887, '\p{^Is_Blk=runic}', "");
Expect(0, 5887, '\P{Is_Blk=runic}', "");
Expect(1, 5887, '\P{^Is_Blk=runic}', "");
Expect(0, 5888, '\p{Is_Blk=runic}', "");
Expect(1, 5888, '\p{^Is_Blk=runic}', "");
Expect(1, 5888, '\P{Is_Blk=runic}', "");
Expect(0, 5888, '\P{^Is_Blk=runic}', "");
Expect(1, 5887, '\p{Is_Blk= -Runic}', "");
Expect(0, 5887, '\p{^Is_Blk= -Runic}', "");
Expect(0, 5887, '\P{Is_Blk= -Runic}', "");
Expect(1, 5887, '\P{^Is_Blk= -Runic}', "");
Expect(0, 5888, '\p{Is_Blk= -Runic}', "");
Expect(1, 5888, '\p{^Is_Blk= -Runic}', "");
Expect(1, 5888, '\P{Is_Blk= -Runic}', "");
Expect(0, 5888, '\P{^Is_Blk= -Runic}', "");
Error('\p{Block=_:=samaritan}');
Error('\P{Block=_:=samaritan}');
Expect(1, 2111, '\p{Block=samaritan}', "");
Expect(0, 2111, '\p{^Block=samaritan}', "");
Expect(0, 2111, '\P{Block=samaritan}', "");
Expect(1, 2111, '\P{^Block=samaritan}', "");
Expect(0, 2112, '\p{Block=samaritan}', "");
Expect(1, 2112, '\p{^Block=samaritan}', "");
Expect(1, 2112, '\P{Block=samaritan}', "");
Expect(0, 2112, '\P{^Block=samaritan}', "");
Expect(1, 2111, '\p{Block:   -Samaritan}', "");
Expect(0, 2111, '\p{^Block:   -Samaritan}', "");
Expect(0, 2111, '\P{Block:   -Samaritan}', "");
Expect(1, 2111, '\P{^Block:   -Samaritan}', "");
Expect(0, 2112, '\p{Block:   -Samaritan}', "");
Expect(1, 2112, '\p{^Block:   -Samaritan}', "");
Expect(1, 2112, '\P{Block:   -Samaritan}', "");
Expect(0, 2112, '\P{^Block:   -Samaritan}', "");
Error('\p{Blk= /a/Samaritan}');
Error('\P{Blk= /a/Samaritan}');
Expect(1, 2111, '\p{Blk=samaritan}', "");
Expect(0, 2111, '\p{^Blk=samaritan}', "");
Expect(0, 2111, '\P{Blk=samaritan}', "");
Expect(1, 2111, '\P{^Blk=samaritan}', "");
Expect(0, 2112, '\p{Blk=samaritan}', "");
Expect(1, 2112, '\p{^Blk=samaritan}', "");
Expect(1, 2112, '\P{Blk=samaritan}', "");
Expect(0, 2112, '\P{^Blk=samaritan}', "");
Expect(1, 2111, '\p{Blk=--SAMARITAN}', "");
Expect(0, 2111, '\p{^Blk=--SAMARITAN}', "");
Expect(0, 2111, '\P{Blk=--SAMARITAN}', "");
Expect(1, 2111, '\P{^Blk=--SAMARITAN}', "");
Expect(0, 2112, '\p{Blk=--SAMARITAN}', "");
Expect(1, 2112, '\p{^Blk=--SAMARITAN}', "");
Expect(1, 2112, '\P{Blk=--SAMARITAN}', "");
Expect(0, 2112, '\P{^Blk=--SAMARITAN}', "");
Error('\p{Is_Block=	:=Samaritan}');
Error('\P{Is_Block=	:=Samaritan}');
Expect(1, 2111, '\p{Is_Block=samaritan}', "");
Expect(0, 2111, '\p{^Is_Block=samaritan}', "");
Expect(0, 2111, '\P{Is_Block=samaritan}', "");
Expect(1, 2111, '\P{^Is_Block=samaritan}', "");
Expect(0, 2112, '\p{Is_Block=samaritan}', "");
Expect(1, 2112, '\p{^Is_Block=samaritan}', "");
Expect(1, 2112, '\P{Is_Block=samaritan}', "");
Expect(0, 2112, '\P{^Is_Block=samaritan}', "");
Expect(1, 2111, '\p{Is_Block=	_samaritan}', "");
Expect(0, 2111, '\p{^Is_Block=	_samaritan}', "");
Expect(0, 2111, '\P{Is_Block=	_samaritan}', "");
Expect(1, 2111, '\P{^Is_Block=	_samaritan}', "");
Expect(0, 2112, '\p{Is_Block=	_samaritan}', "");
Expect(1, 2112, '\p{^Is_Block=	_samaritan}', "");
Expect(1, 2112, '\P{Is_Block=	_samaritan}', "");
Expect(0, 2112, '\P{^Is_Block=	_samaritan}', "");
Error('\p{Is_Blk=/a/_ Samaritan}');
Error('\P{Is_Blk=/a/_ Samaritan}');
Expect(1, 2111, '\p{Is_Blk=samaritan}', "");
Expect(0, 2111, '\p{^Is_Blk=samaritan}', "");
Expect(0, 2111, '\P{Is_Blk=samaritan}', "");
Expect(1, 2111, '\P{^Is_Blk=samaritan}', "");
Expect(0, 2112, '\p{Is_Blk=samaritan}', "");
Expect(1, 2112, '\p{^Is_Blk=samaritan}', "");
Expect(1, 2112, '\P{Is_Blk=samaritan}', "");
Expect(0, 2112, '\P{^Is_Blk=samaritan}', "");
Expect(1, 2111, '\p{Is_Blk=-samaritan}', "");
Expect(0, 2111, '\p{^Is_Blk=-samaritan}', "");
Expect(0, 2111, '\P{Is_Blk=-samaritan}', "");
Expect(1, 2111, '\P{^Is_Blk=-samaritan}', "");
Expect(0, 2112, '\p{Is_Blk=-samaritan}', "");
Expect(1, 2112, '\p{^Is_Blk=-samaritan}', "");
Expect(1, 2112, '\P{Is_Blk=-samaritan}', "");
Expect(0, 2112, '\P{^Is_Blk=-samaritan}', "");
Error('\p{Block:	_/a/SAURASHTRA}');
Error('\P{Block:	_/a/SAURASHTRA}');
Expect(1, 43231, '\p{Block:   saurashtra}', "");
Expect(0, 43231, '\p{^Block:   saurashtra}', "");
Expect(0, 43231, '\P{Block:   saurashtra}', "");
Expect(1, 43231, '\P{^Block:   saurashtra}', "");
Expect(0, 43232, '\p{Block:   saurashtra}', "");
Expect(1, 43232, '\p{^Block:   saurashtra}', "");
Expect(1, 43232, '\P{Block:   saurashtra}', "");
Expect(0, 43232, '\P{^Block:   saurashtra}', "");
Expect(1, 43231, '\p{Block= saurashtra}', "");
Expect(0, 43231, '\p{^Block= saurashtra}', "");
Expect(0, 43231, '\P{Block= saurashtra}', "");
Expect(1, 43231, '\P{^Block= saurashtra}', "");
Expect(0, 43232, '\p{Block= saurashtra}', "");
Expect(1, 43232, '\p{^Block= saurashtra}', "");
Expect(1, 43232, '\P{Block= saurashtra}', "");
Expect(0, 43232, '\P{^Block= saurashtra}', "");
Error('\p{Blk=:=Saurashtra}');
Error('\P{Blk=:=Saurashtra}');
Expect(1, 43231, '\p{Blk=saurashtra}', "");
Expect(0, 43231, '\p{^Blk=saurashtra}', "");
Expect(0, 43231, '\P{Blk=saurashtra}', "");
Expect(1, 43231, '\P{^Blk=saurashtra}', "");
Expect(0, 43232, '\p{Blk=saurashtra}', "");
Expect(1, 43232, '\p{^Blk=saurashtra}', "");
Expect(1, 43232, '\P{Blk=saurashtra}', "");
Expect(0, 43232, '\P{^Blk=saurashtra}', "");
Expect(1, 43231, '\p{Blk=_	Saurashtra}', "");
Expect(0, 43231, '\p{^Blk=_	Saurashtra}', "");
Expect(0, 43231, '\P{Blk=_	Saurashtra}', "");
Expect(1, 43231, '\P{^Blk=_	Saurashtra}', "");
Expect(0, 43232, '\p{Blk=_	Saurashtra}', "");
Expect(1, 43232, '\p{^Blk=_	Saurashtra}', "");
Expect(1, 43232, '\P{Blk=_	Saurashtra}', "");
Expect(0, 43232, '\P{^Blk=_	Saurashtra}', "");
Error('\p{Is_Block=/a/SAURASHTRA}');
Error('\P{Is_Block=/a/SAURASHTRA}');
Expect(1, 43231, '\p{Is_Block=saurashtra}', "");
Expect(0, 43231, '\p{^Is_Block=saurashtra}', "");
Expect(0, 43231, '\P{Is_Block=saurashtra}', "");
Expect(1, 43231, '\P{^Is_Block=saurashtra}', "");
Expect(0, 43232, '\p{Is_Block=saurashtra}', "");
Expect(1, 43232, '\p{^Is_Block=saurashtra}', "");
Expect(1, 43232, '\P{Is_Block=saurashtra}', "");
Expect(0, 43232, '\P{^Is_Block=saurashtra}', "");
Expect(1, 43231, '\p{Is_Block= 	Saurashtra}', "");
Expect(0, 43231, '\p{^Is_Block= 	Saurashtra}', "");
Expect(0, 43231, '\P{Is_Block= 	Saurashtra}', "");
Expect(1, 43231, '\P{^Is_Block= 	Saurashtra}', "");
Expect(0, 43232, '\p{Is_Block= 	Saurashtra}', "");
Expect(1, 43232, '\p{^Is_Block= 	Saurashtra}', "");
Expect(1, 43232, '\P{Is_Block= 	Saurashtra}', "");
Expect(0, 43232, '\P{^Is_Block= 	Saurashtra}', "");
Error('\p{Is_Blk=:=-	saurashtra}');
Error('\P{Is_Blk=:=-	saurashtra}');
Expect(1, 43231, '\p{Is_Blk:	saurashtra}', "");
Expect(0, 43231, '\p{^Is_Blk:	saurashtra}', "");
Expect(0, 43231, '\P{Is_Blk:	saurashtra}', "");
Expect(1, 43231, '\P{^Is_Blk:	saurashtra}', "");
Expect(0, 43232, '\p{Is_Blk:	saurashtra}', "");
Expect(1, 43232, '\p{^Is_Blk:	saurashtra}', "");
Expect(1, 43232, '\P{Is_Blk:	saurashtra}', "");
Expect(0, 43232, '\P{^Is_Blk:	saurashtra}', "");
Expect(1, 43231, '\p{Is_Blk=	SAURASHTRA}', "");
Expect(0, 43231, '\p{^Is_Blk=	SAURASHTRA}', "");
Expect(0, 43231, '\P{Is_Blk=	SAURASHTRA}', "");
Expect(1, 43231, '\P{^Is_Blk=	SAURASHTRA}', "");
Expect(0, 43232, '\p{Is_Blk=	SAURASHTRA}', "");
Expect(1, 43232, '\p{^Is_Blk=	SAURASHTRA}', "");
Expect(1, 43232, '\P{Is_Blk=	SAURASHTRA}', "");
Expect(0, 43232, '\P{^Is_Blk=	SAURASHTRA}', "");
Error('\p{Block=/a/_Sharada}');
Error('\P{Block=/a/_Sharada}');
Expect(1, 70111, '\p{Block=sharada}', "");
Expect(0, 70111, '\p{^Block=sharada}', "");
Expect(0, 70111, '\P{Block=sharada}', "");
Expect(1, 70111, '\P{^Block=sharada}', "");
Expect(0, 70112, '\p{Block=sharada}', "");
Expect(1, 70112, '\p{^Block=sharada}', "");
Expect(1, 70112, '\P{Block=sharada}', "");
Expect(0, 70112, '\P{^Block=sharada}', "");
Expect(1, 70111, '\p{Block= Sharada}', "");
Expect(0, 70111, '\p{^Block= Sharada}', "");
Expect(0, 70111, '\P{Block= Sharada}', "");
Expect(1, 70111, '\P{^Block= Sharada}', "");
Expect(0, 70112, '\p{Block= Sharada}', "");
Expect(1, 70112, '\p{^Block= Sharada}', "");
Expect(1, 70112, '\P{Block= Sharada}', "");
Expect(0, 70112, '\P{^Block= Sharada}', "");
Error('\p{Blk=_ SHARADA/a/}');
Error('\P{Blk=_ SHARADA/a/}');
Expect(1, 70111, '\p{Blk=sharada}', "");
Expect(0, 70111, '\p{^Blk=sharada}', "");
Expect(0, 70111, '\P{Blk=sharada}', "");
Expect(1, 70111, '\P{^Blk=sharada}', "");
Expect(0, 70112, '\p{Blk=sharada}', "");
Expect(1, 70112, '\p{^Blk=sharada}', "");
Expect(1, 70112, '\P{Blk=sharada}', "");
Expect(0, 70112, '\P{^Blk=sharada}', "");
Expect(1, 70111, '\p{Blk=__Sharada}', "");
Expect(0, 70111, '\p{^Blk=__Sharada}', "");
Expect(0, 70111, '\P{Blk=__Sharada}', "");
Expect(1, 70111, '\P{^Blk=__Sharada}', "");
Expect(0, 70112, '\p{Blk=__Sharada}', "");
Expect(1, 70112, '\p{^Blk=__Sharada}', "");
Expect(1, 70112, '\P{Blk=__Sharada}', "");
Expect(0, 70112, '\P{^Blk=__Sharada}', "");
Error('\p{Is_Block=	/a/SHARADA}');
Error('\P{Is_Block=	/a/SHARADA}');
Expect(1, 70111, '\p{Is_Block=sharada}', "");
Expect(0, 70111, '\p{^Is_Block=sharada}', "");
Expect(0, 70111, '\P{Is_Block=sharada}', "");
Expect(1, 70111, '\P{^Is_Block=sharada}', "");
Expect(0, 70112, '\p{Is_Block=sharada}', "");
Expect(1, 70112, '\p{^Is_Block=sharada}', "");
Expect(1, 70112, '\P{Is_Block=sharada}', "");
Expect(0, 70112, '\P{^Is_Block=sharada}', "");
Expect(1, 70111, '\p{Is_Block= 	Sharada}', "");
Expect(0, 70111, '\p{^Is_Block= 	Sharada}', "");
Expect(0, 70111, '\P{Is_Block= 	Sharada}', "");
Expect(1, 70111, '\P{^Is_Block= 	Sharada}', "");
Expect(0, 70112, '\p{Is_Block= 	Sharada}', "");
Expect(1, 70112, '\p{^Is_Block= 	Sharada}', "");
Expect(1, 70112, '\P{Is_Block= 	Sharada}', "");
Expect(0, 70112, '\P{^Is_Block= 	Sharada}', "");
Error('\p{Is_Blk= Sharada/a/}');
Error('\P{Is_Blk= Sharada/a/}');
Expect(1, 70111, '\p{Is_Blk=sharada}', "");
Expect(0, 70111, '\p{^Is_Blk=sharada}', "");
Expect(0, 70111, '\P{Is_Blk=sharada}', "");
Expect(1, 70111, '\P{^Is_Blk=sharada}', "");
Expect(0, 70112, '\p{Is_Blk=sharada}', "");
Expect(1, 70112, '\p{^Is_Blk=sharada}', "");
Expect(1, 70112, '\P{Is_Blk=sharada}', "");
Expect(0, 70112, '\P{^Is_Blk=sharada}', "");
Error('\p{Block=	_Shavian/a/}');
Error('\P{Block=	_Shavian/a/}');
Expect(1, 66687, '\p{Block=shavian}', "");
Expect(0, 66687, '\p{^Block=shavian}', "");
Expect(0, 66687, '\P{Block=shavian}', "");
Expect(1, 66687, '\P{^Block=shavian}', "");
Expect(0, 66688, '\p{Block=shavian}', "");
Expect(1, 66688, '\p{^Block=shavian}', "");
Expect(1, 66688, '\P{Block=shavian}', "");
Expect(0, 66688, '\P{^Block=shavian}', "");
Expect(1, 66687, '\p{Block= shavian}', "");
Expect(0, 66687, '\p{^Block= shavian}', "");
Expect(0, 66687, '\P{Block= shavian}', "");
Expect(1, 66687, '\P{^Block= shavian}', "");
Expect(0, 66688, '\p{Block= shavian}', "");
Expect(1, 66688, '\p{^Block= shavian}', "");
Expect(1, 66688, '\P{Block= shavian}', "");
Expect(0, 66688, '\P{^Block= shavian}', "");
Error('\p{Blk=	/a/Shavian}');
Error('\P{Blk=	/a/Shavian}');
Expect(1, 66687, '\p{Blk=shavian}', "");
Expect(0, 66687, '\p{^Blk=shavian}', "");
Expect(0, 66687, '\P{Blk=shavian}', "");
Expect(1, 66687, '\P{^Blk=shavian}', "");
Expect(0, 66688, '\p{Blk=shavian}', "");
Expect(1, 66688, '\p{^Blk=shavian}', "");
Expect(1, 66688, '\P{Blk=shavian}', "");
Expect(0, 66688, '\P{^Blk=shavian}', "");
Expect(1, 66687, '\p{Blk=_SHAVIAN}', "");
Expect(0, 66687, '\p{^Blk=_SHAVIAN}', "");
Expect(0, 66687, '\P{Blk=_SHAVIAN}', "");
Expect(1, 66687, '\P{^Blk=_SHAVIAN}', "");
Expect(0, 66688, '\p{Blk=_SHAVIAN}', "");
Expect(1, 66688, '\p{^Blk=_SHAVIAN}', "");
Expect(1, 66688, '\P{Blk=_SHAVIAN}', "");
Expect(0, 66688, '\P{^Blk=_SHAVIAN}', "");
Error('\p{Is_Block= -Shavian:=}');
Error('\P{Is_Block= -Shavian:=}');
Expect(1, 66687, '\p{Is_Block:	shavian}', "");
Expect(0, 66687, '\p{^Is_Block:	shavian}', "");
Expect(0, 66687, '\P{Is_Block:	shavian}', "");
Expect(1, 66687, '\P{^Is_Block:	shavian}', "");
Expect(0, 66688, '\p{Is_Block:	shavian}', "");
Expect(1, 66688, '\p{^Is_Block:	shavian}', "");
Expect(1, 66688, '\P{Is_Block:	shavian}', "");
Expect(0, 66688, '\P{^Is_Block:	shavian}', "");
Expect(1, 66687, '\p{Is_Block=	_Shavian}', "");
Expect(0, 66687, '\p{^Is_Block=	_Shavian}', "");
Expect(0, 66687, '\P{Is_Block=	_Shavian}', "");
Expect(1, 66687, '\P{^Is_Block=	_Shavian}', "");
Expect(0, 66688, '\p{Is_Block=	_Shavian}', "");
Expect(1, 66688, '\p{^Is_Block=	_Shavian}', "");
Expect(1, 66688, '\P{Is_Block=	_Shavian}', "");
Expect(0, 66688, '\P{^Is_Block=	_Shavian}', "");
Error('\p{Is_Blk=-_Shavian/a/}');
Error('\P{Is_Blk=-_Shavian/a/}');
Expect(1, 66687, '\p{Is_Blk=shavian}', "");
Expect(0, 66687, '\p{^Is_Blk=shavian}', "");
Expect(0, 66687, '\P{Is_Blk=shavian}', "");
Expect(1, 66687, '\P{^Is_Blk=shavian}', "");
Expect(0, 66688, '\p{Is_Blk=shavian}', "");
Expect(1, 66688, '\p{^Is_Blk=shavian}', "");
Expect(1, 66688, '\P{Is_Blk=shavian}', "");
Expect(0, 66688, '\P{^Is_Blk=shavian}', "");
Expect(1, 66687, '\p{Is_Blk=	 SHAVIAN}', "");
Expect(0, 66687, '\p{^Is_Blk=	 SHAVIAN}', "");
Expect(0, 66687, '\P{Is_Blk=	 SHAVIAN}', "");
Expect(1, 66687, '\P{^Is_Blk=	 SHAVIAN}', "");
Expect(0, 66688, '\p{Is_Blk=	 SHAVIAN}', "");
Expect(1, 66688, '\p{^Is_Blk=	 SHAVIAN}', "");
Expect(1, 66688, '\P{Is_Blk=	 SHAVIAN}', "");
Expect(0, 66688, '\P{^Is_Blk=	 SHAVIAN}', "");
Error('\p{Block=_Sinhala:=}');
Error('\P{Block=_Sinhala:=}');
Expect(1, 3583, '\p{Block=sinhala}', "");
Expect(0, 3583, '\p{^Block=sinhala}', "");
Expect(0, 3583, '\P{Block=sinhala}', "");
Expect(1, 3583, '\P{^Block=sinhala}', "");
Expect(0, 3584, '\p{Block=sinhala}', "");
Expect(1, 3584, '\p{^Block=sinhala}', "");
Expect(1, 3584, '\P{Block=sinhala}', "");
Expect(0, 3584, '\P{^Block=sinhala}', "");
Expect(1, 3583, '\p{Block: -_sinhala}', "");
Expect(0, 3583, '\p{^Block: -_sinhala}', "");
Expect(0, 3583, '\P{Block: -_sinhala}', "");
Expect(1, 3583, '\P{^Block: -_sinhala}', "");
Expect(0, 3584, '\p{Block: -_sinhala}', "");
Expect(1, 3584, '\p{^Block: -_sinhala}', "");
Expect(1, 3584, '\P{Block: -_sinhala}', "");
Expect(0, 3584, '\P{^Block: -_sinhala}', "");
Error('\p{Blk: _:=SINHALA}');
Error('\P{Blk: _:=SINHALA}');
Expect(1, 3583, '\p{Blk=sinhala}', "");
Expect(0, 3583, '\p{^Blk=sinhala}', "");
Expect(0, 3583, '\P{Blk=sinhala}', "");
Expect(1, 3583, '\P{^Blk=sinhala}', "");
Expect(0, 3584, '\p{Blk=sinhala}', "");
Expect(1, 3584, '\p{^Blk=sinhala}', "");
Expect(1, 3584, '\P{Blk=sinhala}', "");
Expect(0, 3584, '\P{^Blk=sinhala}', "");
Expect(1, 3583, '\p{Blk= Sinhala}', "");
Expect(0, 3583, '\p{^Blk= Sinhala}', "");
Expect(0, 3583, '\P{Blk= Sinhala}', "");
Expect(1, 3583, '\P{^Blk= Sinhala}', "");
Expect(0, 3584, '\p{Blk= Sinhala}', "");
Expect(1, 3584, '\p{^Blk= Sinhala}', "");
Expect(1, 3584, '\P{Blk= Sinhala}', "");
Expect(0, 3584, '\P{^Blk= Sinhala}', "");
Error('\p{Is_Block=- Sinhala:=}');
Error('\P{Is_Block=- Sinhala:=}');
Expect(1, 3583, '\p{Is_Block=sinhala}', "");
Expect(0, 3583, '\p{^Is_Block=sinhala}', "");
Expect(0, 3583, '\P{Is_Block=sinhala}', "");
Expect(1, 3583, '\P{^Is_Block=sinhala}', "");
Expect(0, 3584, '\p{Is_Block=sinhala}', "");
Expect(1, 3584, '\p{^Is_Block=sinhala}', "");
Expect(1, 3584, '\P{Is_Block=sinhala}', "");
Expect(0, 3584, '\P{^Is_Block=sinhala}', "");
Expect(1, 3583, '\p{Is_Block=		sinhala}', "");
Expect(0, 3583, '\p{^Is_Block=		sinhala}', "");
Expect(0, 3583, '\P{Is_Block=		sinhala}', "");
Expect(1, 3583, '\P{^Is_Block=		sinhala}', "");
Expect(0, 3584, '\p{Is_Block=		sinhala}', "");
Expect(1, 3584, '\p{^Is_Block=		sinhala}', "");
Expect(1, 3584, '\P{Is_Block=		sinhala}', "");
Expect(0, 3584, '\P{^Is_Block=		sinhala}', "");
Error('\p{Is_Blk=:= -SINHALA}');
Error('\P{Is_Blk=:= -SINHALA}');
Expect(1, 3583, '\p{Is_Blk=sinhala}', "");
Expect(0, 3583, '\p{^Is_Blk=sinhala}', "");
Expect(0, 3583, '\P{Is_Blk=sinhala}', "");
Expect(1, 3583, '\P{^Is_Blk=sinhala}', "");
Expect(0, 3584, '\p{Is_Blk=sinhala}', "");
Expect(1, 3584, '\p{^Is_Blk=sinhala}', "");
Expect(1, 3584, '\P{Is_Blk=sinhala}', "");
Expect(0, 3584, '\P{^Is_Blk=sinhala}', "");
Expect(1, 3583, '\p{Is_Blk=	_sinhala}', "");
Expect(0, 3583, '\p{^Is_Blk=	_sinhala}', "");
Expect(0, 3583, '\P{Is_Blk=	_sinhala}', "");
Expect(1, 3583, '\P{^Is_Blk=	_sinhala}', "");
Expect(0, 3584, '\p{Is_Blk=	_sinhala}', "");
Expect(1, 3584, '\p{^Is_Blk=	_sinhala}', "");
Expect(1, 3584, '\P{Is_Blk=	_sinhala}', "");
Expect(0, 3584, '\P{^Is_Blk=	_sinhala}', "");
Error('\p{Block=-/a/SMALL_FORM_VARIANTS}');
Error('\P{Block=-/a/SMALL_FORM_VARIANTS}');
Expect(1, 65135, '\p{Block=smallformvariants}', "");
Expect(0, 65135, '\p{^Block=smallformvariants}', "");
Expect(0, 65135, '\P{Block=smallformvariants}', "");
Expect(1, 65135, '\P{^Block=smallformvariants}', "");
Expect(0, 65136, '\p{Block=smallformvariants}', "");
Expect(1, 65136, '\p{^Block=smallformvariants}', "");
Expect(1, 65136, '\P{Block=smallformvariants}', "");
Expect(0, 65136, '\P{^Block=smallformvariants}', "");
Expect(1, 65135, '\p{Block:small_Form_VARIANTS}', "");
Expect(0, 65135, '\p{^Block:small_Form_VARIANTS}', "");
Expect(0, 65135, '\P{Block:small_Form_VARIANTS}', "");
Expect(1, 65135, '\P{^Block:small_Form_VARIANTS}', "");
Expect(0, 65136, '\p{Block:small_Form_VARIANTS}', "");
Expect(1, 65136, '\p{^Block:small_Form_VARIANTS}', "");
Expect(1, 65136, '\P{Block:small_Form_VARIANTS}', "");
Expect(0, 65136, '\P{^Block:small_Form_VARIANTS}', "");
Error('\p{Blk=_:=Small_FORMS}');
Error('\P{Blk=_:=Small_FORMS}');
Expect(1, 65135, '\p{Blk=smallforms}', "");
Expect(0, 65135, '\p{^Blk=smallforms}', "");
Expect(0, 65135, '\P{Blk=smallforms}', "");
Expect(1, 65135, '\P{^Blk=smallforms}', "");
Expect(0, 65136, '\p{Blk=smallforms}', "");
Expect(1, 65136, '\p{^Blk=smallforms}', "");
Expect(1, 65136, '\P{Blk=smallforms}', "");
Expect(0, 65136, '\P{^Blk=smallforms}', "");
Expect(1, 65135, '\p{Blk:  small_forms}', "");
Expect(0, 65135, '\p{^Blk:  small_forms}', "");
Expect(0, 65135, '\P{Blk:  small_forms}', "");
Expect(1, 65135, '\P{^Blk:  small_forms}', "");
Expect(0, 65136, '\p{Blk:  small_forms}', "");
Expect(1, 65136, '\p{^Blk:  small_forms}', "");
Expect(1, 65136, '\P{Blk:  small_forms}', "");
Expect(0, 65136, '\P{^Blk:  small_forms}', "");
Error('\p{Is_Block=:=Small_form_variants}');
Error('\P{Is_Block=:=Small_form_variants}');
Expect(1, 65135, '\p{Is_Block=smallformvariants}', "");
Expect(0, 65135, '\p{^Is_Block=smallformvariants}', "");
Expect(0, 65135, '\P{Is_Block=smallformvariants}', "");
Expect(1, 65135, '\P{^Is_Block=smallformvariants}', "");
Expect(0, 65136, '\p{Is_Block=smallformvariants}', "");
Expect(1, 65136, '\p{^Is_Block=smallformvariants}', "");
Expect(1, 65136, '\P{Is_Block=smallformvariants}', "");
Expect(0, 65136, '\P{^Is_Block=smallformvariants}', "");
Expect(1, 65135, '\p{Is_Block=  Small_form_Variants}', "");
Expect(0, 65135, '\p{^Is_Block=  Small_form_Variants}', "");
Expect(0, 65135, '\P{Is_Block=  Small_form_Variants}', "");
Expect(1, 65135, '\P{^Is_Block=  Small_form_Variants}', "");
Expect(0, 65136, '\p{Is_Block=  Small_form_Variants}', "");
Expect(1, 65136, '\p{^Is_Block=  Small_form_Variants}', "");
Expect(1, 65136, '\P{Is_Block=  Small_form_Variants}', "");
Expect(0, 65136, '\P{^Is_Block=  Small_form_Variants}', "");
Error('\p{Is_Blk= :=Small_Forms}');
Error('\P{Is_Blk= :=Small_Forms}');
Expect(1, 65135, '\p{Is_Blk=smallforms}', "");
Expect(0, 65135, '\p{^Is_Blk=smallforms}', "");
Expect(0, 65135, '\P{Is_Blk=smallforms}', "");
Expect(1, 65135, '\P{^Is_Blk=smallforms}', "");
Expect(0, 65136, '\p{Is_Blk=smallforms}', "");
Expect(1, 65136, '\p{^Is_Blk=smallforms}', "");
Expect(1, 65136, '\P{Is_Blk=smallforms}', "");
Expect(0, 65136, '\P{^Is_Blk=smallforms}', "");
Expect(1, 65135, '\p{Is_Blk=-	SMALL_FORMS}', "");
Expect(0, 65135, '\p{^Is_Blk=-	SMALL_FORMS}', "");
Expect(0, 65135, '\P{Is_Blk=-	SMALL_FORMS}', "");
Expect(1, 65135, '\P{^Is_Blk=-	SMALL_FORMS}', "");
Expect(0, 65136, '\p{Is_Blk=-	SMALL_FORMS}', "");
Expect(1, 65136, '\p{^Is_Blk=-	SMALL_FORMS}', "");
Expect(1, 65136, '\P{Is_Blk=-	SMALL_FORMS}', "");
Expect(0, 65136, '\P{^Is_Blk=-	SMALL_FORMS}', "");
Error('\p{Block=:=_sora_sompeng}');
Error('\P{Block=:=_sora_sompeng}');
Expect(1, 69887, '\p{Block=sorasompeng}', "");
Expect(0, 69887, '\p{^Block=sorasompeng}', "");
Expect(0, 69887, '\P{Block=sorasompeng}', "");
Expect(1, 69887, '\P{^Block=sorasompeng}', "");
Expect(0, 69888, '\p{Block=sorasompeng}', "");
Expect(1, 69888, '\p{^Block=sorasompeng}', "");
Expect(1, 69888, '\P{Block=sorasompeng}', "");
Expect(0, 69888, '\P{^Block=sorasompeng}', "");
Expect(1, 69887, '\p{Block=_	sora_Sompeng}', "");
Expect(0, 69887, '\p{^Block=_	sora_Sompeng}', "");
Expect(0, 69887, '\P{Block=_	sora_Sompeng}', "");
Expect(1, 69887, '\P{^Block=_	sora_Sompeng}', "");
Expect(0, 69888, '\p{Block=_	sora_Sompeng}', "");
Expect(1, 69888, '\p{^Block=_	sora_Sompeng}', "");
Expect(1, 69888, '\P{Block=_	sora_Sompeng}', "");
Expect(0, 69888, '\P{^Block=_	sora_Sompeng}', "");
Error('\p{Blk=:=Sora_SOMPENG}');
Error('\P{Blk=:=Sora_SOMPENG}');
Expect(1, 69887, '\p{Blk=sorasompeng}', "");
Expect(0, 69887, '\p{^Blk=sorasompeng}', "");
Expect(0, 69887, '\P{Blk=sorasompeng}', "");
Expect(1, 69887, '\P{^Blk=sorasompeng}', "");
Expect(0, 69888, '\p{Blk=sorasompeng}', "");
Expect(1, 69888, '\p{^Blk=sorasompeng}', "");
Expect(1, 69888, '\P{Blk=sorasompeng}', "");
Expect(0, 69888, '\P{^Blk=sorasompeng}', "");
Expect(1, 69887, '\p{Blk=-_Sora_SOMPENG}', "");
Expect(0, 69887, '\p{^Blk=-_Sora_SOMPENG}', "");
Expect(0, 69887, '\P{Blk=-_Sora_SOMPENG}', "");
Expect(1, 69887, '\P{^Blk=-_Sora_SOMPENG}', "");
Expect(0, 69888, '\p{Blk=-_Sora_SOMPENG}', "");
Expect(1, 69888, '\p{^Blk=-_Sora_SOMPENG}', "");
Expect(1, 69888, '\P{Blk=-_Sora_SOMPENG}', "");
Expect(0, 69888, '\P{^Blk=-_Sora_SOMPENG}', "");
Error('\p{Is_Block:   := _SORA_SOMPENG}');
Error('\P{Is_Block:   := _SORA_SOMPENG}');
Expect(1, 69887, '\p{Is_Block=sorasompeng}', "");
Expect(0, 69887, '\p{^Is_Block=sorasompeng}', "");
Expect(0, 69887, '\P{Is_Block=sorasompeng}', "");
Expect(1, 69887, '\P{^Is_Block=sorasompeng}', "");
Expect(0, 69888, '\p{Is_Block=sorasompeng}', "");
Expect(1, 69888, '\p{^Is_Block=sorasompeng}', "");
Expect(1, 69888, '\P{Is_Block=sorasompeng}', "");
Expect(0, 69888, '\P{^Is_Block=sorasompeng}', "");
Expect(1, 69887, '\p{Is_Block=_-Sora_Sompeng}', "");
Expect(0, 69887, '\p{^Is_Block=_-Sora_Sompeng}', "");
Expect(0, 69887, '\P{Is_Block=_-Sora_Sompeng}', "");
Expect(1, 69887, '\P{^Is_Block=_-Sora_Sompeng}', "");
Expect(0, 69888, '\p{Is_Block=_-Sora_Sompeng}', "");
Expect(1, 69888, '\p{^Is_Block=_-Sora_Sompeng}', "");
Expect(1, 69888, '\P{Is_Block=_-Sora_Sompeng}', "");
Expect(0, 69888, '\P{^Is_Block=_-Sora_Sompeng}', "");
Error('\p{Is_Blk=:=-SORA_Sompeng}');
Error('\P{Is_Blk=:=-SORA_Sompeng}');
Expect(1, 69887, '\p{Is_Blk=sorasompeng}', "");
Expect(0, 69887, '\p{^Is_Blk=sorasompeng}', "");
Expect(0, 69887, '\P{Is_Blk=sorasompeng}', "");
Expect(1, 69887, '\P{^Is_Blk=sorasompeng}', "");
Expect(0, 69888, '\p{Is_Blk=sorasompeng}', "");
Expect(1, 69888, '\p{^Is_Blk=sorasompeng}', "");
Expect(1, 69888, '\P{Is_Blk=sorasompeng}', "");
Expect(0, 69888, '\P{^Is_Blk=sorasompeng}', "");
Expect(1, 69887, '\p{Is_Blk=_Sora_Sompeng}', "");
Expect(0, 69887, '\p{^Is_Blk=_Sora_Sompeng}', "");
Expect(0, 69887, '\P{Is_Blk=_Sora_Sompeng}', "");
Expect(1, 69887, '\P{^Is_Blk=_Sora_Sompeng}', "");
Expect(0, 69888, '\p{Is_Blk=_Sora_Sompeng}', "");
Expect(1, 69888, '\p{^Is_Blk=_Sora_Sompeng}', "");
Expect(1, 69888, '\P{Is_Blk=_Sora_Sompeng}', "");
Expect(0, 69888, '\P{^Is_Blk=_Sora_Sompeng}', "");
Error('\p{Block::=-Specials}');
Error('\P{Block::=-Specials}');
Expect(1, 65520, '\p{Block=specials}', "");
Expect(0, 65520, '\p{^Block=specials}', "");
Expect(0, 65520, '\P{Block=specials}', "");
Expect(1, 65520, '\P{^Block=specials}', "");
Expect(0, 65536, '\p{Block=specials}', "");
Expect(1, 65536, '\p{^Block=specials}', "");
Expect(1, 65536, '\P{Block=specials}', "");
Expect(0, 65536, '\P{^Block=specials}', "");
Expect(1, 65520, '\p{Block=Specials}', "");
Expect(0, 65520, '\p{^Block=Specials}', "");
Expect(0, 65520, '\P{Block=Specials}', "");
Expect(1, 65520, '\P{^Block=Specials}', "");
Expect(0, 65536, '\p{Block=Specials}', "");
Expect(1, 65536, '\p{^Block=Specials}', "");
Expect(1, 65536, '\P{Block=Specials}', "");
Expect(0, 65536, '\P{^Block=Specials}', "");
Error('\p{Blk=_specials/a/}');
Error('\P{Blk=_specials/a/}');
Expect(1, 65520, '\p{Blk=specials}', "");
Expect(0, 65520, '\p{^Blk=specials}', "");
Expect(0, 65520, '\P{Blk=specials}', "");
Expect(1, 65520, '\P{^Blk=specials}', "");
Expect(0, 65536, '\p{Blk=specials}', "");
Expect(1, 65536, '\p{^Blk=specials}', "");
Expect(1, 65536, '\P{Blk=specials}', "");
Expect(0, 65536, '\P{^Blk=specials}', "");
Expect(1, 65520, '\p{Blk=__Specials}', "");
Expect(0, 65520, '\p{^Blk=__Specials}', "");
Expect(0, 65520, '\P{Blk=__Specials}', "");
Expect(1, 65520, '\P{^Blk=__Specials}', "");
Expect(0, 65536, '\p{Blk=__Specials}', "");
Expect(1, 65536, '\p{^Blk=__Specials}', "");
Expect(1, 65536, '\P{Blk=__Specials}', "");
Expect(0, 65536, '\P{^Blk=__Specials}', "");
Error('\p{Is_Block=--specials:=}');
Error('\P{Is_Block=--specials:=}');
Expect(1, 65520, '\p{Is_Block=specials}', "");
Expect(0, 65520, '\p{^Is_Block=specials}', "");
Expect(0, 65520, '\P{Is_Block=specials}', "");
Expect(1, 65520, '\P{^Is_Block=specials}', "");
Expect(0, 65536, '\p{Is_Block=specials}', "");
Expect(1, 65536, '\p{^Is_Block=specials}', "");
Expect(1, 65536, '\P{Is_Block=specials}', "");
Expect(0, 65536, '\P{^Is_Block=specials}', "");
Expect(1, 65520, '\p{Is_Block=		specials}', "");
Expect(0, 65520, '\p{^Is_Block=		specials}', "");
Expect(0, 65520, '\P{Is_Block=		specials}', "");
Expect(1, 65520, '\P{^Is_Block=		specials}', "");
Expect(0, 65536, '\p{Is_Block=		specials}', "");
Expect(1, 65536, '\p{^Is_Block=		specials}', "");
Expect(1, 65536, '\P{Is_Block=		specials}', "");
Expect(0, 65536, '\P{^Is_Block=		specials}', "");
Error('\p{Is_Blk=/a/-Specials}');
Error('\P{Is_Blk=/a/-Specials}');
Expect(1, 65520, '\p{Is_Blk=specials}', "");
Expect(0, 65520, '\p{^Is_Blk=specials}', "");
Expect(0, 65520, '\P{Is_Blk=specials}', "");
Expect(1, 65520, '\P{^Is_Blk=specials}', "");
Expect(0, 65536, '\p{Is_Blk=specials}', "");
Expect(1, 65536, '\p{^Is_Blk=specials}', "");
Expect(1, 65536, '\P{Is_Blk=specials}', "");
Expect(0, 65536, '\P{^Is_Blk=specials}', "");
Expect(1, 65520, '\p{Is_Blk=-Specials}', "");
Expect(0, 65520, '\p{^Is_Blk=-Specials}', "");
Expect(0, 65520, '\P{Is_Blk=-Specials}', "");
Expect(1, 65520, '\P{^Is_Blk=-Specials}', "");
Expect(0, 65536, '\p{Is_Blk=-Specials}', "");
Expect(1, 65536, '\p{^Is_Blk=-Specials}', "");
Expect(1, 65536, '\P{Is_Blk=-Specials}', "");
Expect(0, 65536, '\P{^Is_Blk=-Specials}', "");
Error('\p{Block=/a/	SUNDANESE}');
Error('\P{Block=/a/	SUNDANESE}');
Expect(1, 7103, '\p{Block=sundanese}', "");
Expect(0, 7103, '\p{^Block=sundanese}', "");
Expect(0, 7103, '\P{Block=sundanese}', "");
Expect(1, 7103, '\P{^Block=sundanese}', "");
Expect(0, 7104, '\p{Block=sundanese}', "");
Expect(1, 7104, '\p{^Block=sundanese}', "");
Expect(1, 7104, '\P{Block=sundanese}', "");
Expect(0, 7104, '\P{^Block=sundanese}', "");
Error('\p{Blk=/a/-	sundanese}');
Error('\P{Blk=/a/-	sundanese}');
Expect(1, 7103, '\p{Blk=sundanese}', "");
Expect(0, 7103, '\p{^Blk=sundanese}', "");
Expect(0, 7103, '\P{Blk=sundanese}', "");
Expect(1, 7103, '\P{^Blk=sundanese}', "");
Expect(0, 7104, '\p{Blk=sundanese}', "");
Expect(1, 7104, '\p{^Blk=sundanese}', "");
Expect(1, 7104, '\P{Blk=sundanese}', "");
Expect(0, 7104, '\P{^Blk=sundanese}', "");
Expect(1, 7103, '\p{Blk=__sundanese}', "");
Expect(0, 7103, '\p{^Blk=__sundanese}', "");
Expect(0, 7103, '\P{Blk=__sundanese}', "");
Expect(1, 7103, '\P{^Blk=__sundanese}', "");
Expect(0, 7104, '\p{Blk=__sundanese}', "");
Expect(1, 7104, '\p{^Blk=__sundanese}', "");
Expect(1, 7104, '\P{Blk=__sundanese}', "");
Expect(0, 7104, '\P{^Blk=__sundanese}', "");
Error('\p{Is_Block=/a/sundanese}');
Error('\P{Is_Block=/a/sundanese}');
Expect(1, 7103, '\p{Is_Block=sundanese}', "");
Expect(0, 7103, '\p{^Is_Block=sundanese}', "");
Expect(0, 7103, '\P{Is_Block=sundanese}', "");
Expect(1, 7103, '\P{^Is_Block=sundanese}', "");
Expect(0, 7104, '\p{Is_Block=sundanese}', "");
Expect(1, 7104, '\p{^Is_Block=sundanese}', "");
Expect(1, 7104, '\P{Is_Block=sundanese}', "");
Expect(0, 7104, '\P{^Is_Block=sundanese}', "");
Expect(1, 7103, '\p{Is_Block=_	sundanese}', "");
Expect(0, 7103, '\p{^Is_Block=_	sundanese}', "");
Expect(0, 7103, '\P{Is_Block=_	sundanese}', "");
Expect(1, 7103, '\P{^Is_Block=_	sundanese}', "");
Expect(0, 7104, '\p{Is_Block=_	sundanese}', "");
Expect(1, 7104, '\p{^Is_Block=_	sundanese}', "");
Expect(1, 7104, '\P{Is_Block=_	sundanese}', "");
Expect(0, 7104, '\P{^Is_Block=_	sundanese}', "");
Error('\p{Is_Blk=_:=SUNDANESE}');
Error('\P{Is_Blk=_:=SUNDANESE}');
Expect(1, 7103, '\p{Is_Blk=sundanese}', "");
Expect(0, 7103, '\p{^Is_Blk=sundanese}', "");
Expect(0, 7103, '\P{Is_Blk=sundanese}', "");
Expect(1, 7103, '\P{^Is_Blk=sundanese}', "");
Expect(0, 7104, '\p{Is_Blk=sundanese}', "");
Expect(1, 7104, '\p{^Is_Blk=sundanese}', "");
Expect(1, 7104, '\P{Is_Blk=sundanese}', "");
Expect(0, 7104, '\P{^Is_Blk=sundanese}', "");
Expect(1, 7103, '\p{Is_Blk=-	SUNDANESE}', "");
Expect(0, 7103, '\p{^Is_Blk=-	SUNDANESE}', "");
Expect(0, 7103, '\P{Is_Blk=-	SUNDANESE}', "");
Expect(1, 7103, '\P{^Is_Blk=-	SUNDANESE}', "");
Expect(0, 7104, '\p{Is_Blk=-	SUNDANESE}', "");
Expect(1, 7104, '\p{^Is_Blk=-	SUNDANESE}', "");
Expect(1, 7104, '\P{Is_Blk=-	SUNDANESE}', "");
Expect(0, 7104, '\P{^Is_Blk=-	SUNDANESE}', "");
Error('\p{Block=:=_ Sundanese_Supplement}');
Error('\P{Block=:=_ Sundanese_Supplement}');
Expect(1, 7375, '\p{Block=sundanesesupplement}', "");
Expect(0, 7375, '\p{^Block=sundanesesupplement}', "");
Expect(0, 7375, '\P{Block=sundanesesupplement}', "");
Expect(1, 7375, '\P{^Block=sundanesesupplement}', "");
Expect(0, 7376, '\p{Block=sundanesesupplement}', "");
Expect(1, 7376, '\p{^Block=sundanesesupplement}', "");
Expect(1, 7376, '\P{Block=sundanesesupplement}', "");
Expect(0, 7376, '\P{^Block=sundanesesupplement}', "");
Expect(1, 7375, '\p{Block=_-Sundanese_SUPPLEMENT}', "");
Expect(0, 7375, '\p{^Block=_-Sundanese_SUPPLEMENT}', "");
Expect(0, 7375, '\P{Block=_-Sundanese_SUPPLEMENT}', "");
Expect(1, 7375, '\P{^Block=_-Sundanese_SUPPLEMENT}', "");
Expect(0, 7376, '\p{Block=_-Sundanese_SUPPLEMENT}', "");
Expect(1, 7376, '\p{^Block=_-Sundanese_SUPPLEMENT}', "");
Expect(1, 7376, '\P{Block=_-Sundanese_SUPPLEMENT}', "");
Expect(0, 7376, '\P{^Block=_-Sundanese_SUPPLEMENT}', "");
Error('\p{Blk=-/a/sundanese_sup}');
Error('\P{Blk=-/a/sundanese_sup}');
Expect(1, 7375, '\p{Blk:	sundanesesup}', "");
Expect(0, 7375, '\p{^Blk:	sundanesesup}', "");
Expect(0, 7375, '\P{Blk:	sundanesesup}', "");
Expect(1, 7375, '\P{^Blk:	sundanesesup}', "");
Expect(0, 7376, '\p{Blk:	sundanesesup}', "");
Expect(1, 7376, '\p{^Blk:	sundanesesup}', "");
Expect(1, 7376, '\P{Blk:	sundanesesup}', "");
Expect(0, 7376, '\P{^Blk:	sundanesesup}', "");
Expect(1, 7375, '\p{Blk=- Sundanese_Sup}', "");
Expect(0, 7375, '\p{^Blk=- Sundanese_Sup}', "");
Expect(0, 7375, '\P{Blk=- Sundanese_Sup}', "");
Expect(1, 7375, '\P{^Blk=- Sundanese_Sup}', "");
Expect(0, 7376, '\p{Blk=- Sundanese_Sup}', "");
Expect(1, 7376, '\p{^Blk=- Sundanese_Sup}', "");
Expect(1, 7376, '\P{Blk=- Sundanese_Sup}', "");
Expect(0, 7376, '\P{^Blk=- Sundanese_Sup}', "");
Error('\p{Is_Block:		sundanese_Supplement/a/}');
Error('\P{Is_Block:		sundanese_Supplement/a/}');
Expect(1, 7375, '\p{Is_Block=sundanesesupplement}', "");
Expect(0, 7375, '\p{^Is_Block=sundanesesupplement}', "");
Expect(0, 7375, '\P{Is_Block=sundanesesupplement}', "");
Expect(1, 7375, '\P{^Is_Block=sundanesesupplement}', "");
Expect(0, 7376, '\p{Is_Block=sundanesesupplement}', "");
Expect(1, 7376, '\p{^Is_Block=sundanesesupplement}', "");
Expect(1, 7376, '\P{Is_Block=sundanesesupplement}', "");
Expect(0, 7376, '\P{^Is_Block=sundanesesupplement}', "");
Expect(1, 7375, '\p{Is_Block=_-Sundanese_Supplement}', "");
Expect(0, 7375, '\p{^Is_Block=_-Sundanese_Supplement}', "");
Expect(0, 7375, '\P{Is_Block=_-Sundanese_Supplement}', "");
Expect(1, 7375, '\P{^Is_Block=_-Sundanese_Supplement}', "");
Expect(0, 7376, '\p{Is_Block=_-Sundanese_Supplement}', "");
Expect(1, 7376, '\p{^Is_Block=_-Sundanese_Supplement}', "");
Expect(1, 7376, '\P{Is_Block=_-Sundanese_Supplement}', "");
Expect(0, 7376, '\P{^Is_Block=_-Sundanese_Supplement}', "");
Error('\p{Is_Blk=/a/_Sundanese_SUP}');
Error('\P{Is_Blk=/a/_Sundanese_SUP}');
Expect(1, 7375, '\p{Is_Blk=sundanesesup}', "");
Expect(0, 7375, '\p{^Is_Blk=sundanesesup}', "");
Expect(0, 7375, '\P{Is_Blk=sundanesesup}', "");
Expect(1, 7375, '\P{^Is_Blk=sundanesesup}', "");
Expect(0, 7376, '\p{Is_Blk=sundanesesup}', "");
Expect(1, 7376, '\p{^Is_Blk=sundanesesup}', "");
Expect(1, 7376, '\P{Is_Blk=sundanesesup}', "");
Expect(0, 7376, '\P{^Is_Blk=sundanesesup}', "");
Expect(1, 7375, '\p{Is_Blk= Sundanese_Sup}', "");
Expect(0, 7375, '\p{^Is_Blk= Sundanese_Sup}', "");
Expect(0, 7375, '\P{Is_Blk= Sundanese_Sup}', "");
Expect(1, 7375, '\P{^Is_Blk= Sundanese_Sup}', "");
Expect(0, 7376, '\p{Is_Blk= Sundanese_Sup}', "");
Expect(1, 7376, '\p{^Is_Blk= Sundanese_Sup}', "");
Expect(1, 7376, '\P{Is_Blk= Sundanese_Sup}', "");
Expect(0, 7376, '\P{^Is_Blk= Sundanese_Sup}', "");
Error('\p{Block=:=SUPPLEMENTAL_Arrows_A}');
Error('\P{Block=:=SUPPLEMENTAL_Arrows_A}');
Expect(1, 10239, '\p{Block=supplementalarrowsa}', "");
Expect(0, 10239, '\p{^Block=supplementalarrowsa}', "");
Expect(0, 10239, '\P{Block=supplementalarrowsa}', "");
Expect(1, 10239, '\P{^Block=supplementalarrowsa}', "");
Expect(0, 10240, '\p{Block=supplementalarrowsa}', "");
Expect(1, 10240, '\p{^Block=supplementalarrowsa}', "");
Expect(1, 10240, '\P{Block=supplementalarrowsa}', "");
Expect(0, 10240, '\P{^Block=supplementalarrowsa}', "");
Expect(1, 10239, '\p{Block=_	Supplemental_Arrows_A}', "");
Expect(0, 10239, '\p{^Block=_	Supplemental_Arrows_A}', "");
Expect(0, 10239, '\P{Block=_	Supplemental_Arrows_A}', "");
Expect(1, 10239, '\P{^Block=_	Supplemental_Arrows_A}', "");
Expect(0, 10240, '\p{Block=_	Supplemental_Arrows_A}', "");
Expect(1, 10240, '\p{^Block=_	Supplemental_Arrows_A}', "");
Expect(1, 10240, '\P{Block=_	Supplemental_Arrows_A}', "");
Expect(0, 10240, '\P{^Block=_	Supplemental_Arrows_A}', "");
Error('\p{Blk=  Sup_Arrows_a:=}');
Error('\P{Blk=  Sup_Arrows_a:=}');
Expect(1, 10239, '\p{Blk=suparrowsa}', "");
Expect(0, 10239, '\p{^Blk=suparrowsa}', "");
Expect(0, 10239, '\P{Blk=suparrowsa}', "");
Expect(1, 10239, '\P{^Blk=suparrowsa}', "");
Expect(0, 10240, '\p{Blk=suparrowsa}', "");
Expect(1, 10240, '\p{^Blk=suparrowsa}', "");
Expect(1, 10240, '\P{Blk=suparrowsa}', "");
Expect(0, 10240, '\P{^Blk=suparrowsa}', "");
Expect(1, 10239, '\p{Blk=	SUP_Arrows_a}', "");
Expect(0, 10239, '\p{^Blk=	SUP_Arrows_a}', "");
Expect(0, 10239, '\P{Blk=	SUP_Arrows_a}', "");
Expect(1, 10239, '\P{^Blk=	SUP_Arrows_a}', "");
Expect(0, 10240, '\p{Blk=	SUP_Arrows_a}', "");
Expect(1, 10240, '\p{^Blk=	SUP_Arrows_a}', "");
Expect(1, 10240, '\P{Blk=	SUP_Arrows_a}', "");
Expect(0, 10240, '\P{^Blk=	SUP_Arrows_a}', "");
Error('\p{Is_Block=	:=Supplemental_Arrows_A}');
Error('\P{Is_Block=	:=Supplemental_Arrows_A}');
Expect(1, 10239, '\p{Is_Block=supplementalarrowsa}', "");
Expect(0, 10239, '\p{^Is_Block=supplementalarrowsa}', "");
Expect(0, 10239, '\P{Is_Block=supplementalarrowsa}', "");
Expect(1, 10239, '\P{^Is_Block=supplementalarrowsa}', "");
Expect(0, 10240, '\p{Is_Block=supplementalarrowsa}', "");
Expect(1, 10240, '\p{^Is_Block=supplementalarrowsa}', "");
Expect(1, 10240, '\P{Is_Block=supplementalarrowsa}', "");
Expect(0, 10240, '\P{^Is_Block=supplementalarrowsa}', "");
Expect(1, 10239, '\p{Is_Block: --SUPPLEMENTAL_ARROWS_A}', "");
Expect(0, 10239, '\p{^Is_Block: --SUPPLEMENTAL_ARROWS_A}', "");
Expect(0, 10239, '\P{Is_Block: --SUPPLEMENTAL_ARROWS_A}', "");
Expect(1, 10239, '\P{^Is_Block: --SUPPLEMENTAL_ARROWS_A}', "");
Expect(0, 10240, '\p{Is_Block: --SUPPLEMENTAL_ARROWS_A}', "");
Expect(1, 10240, '\p{^Is_Block: --SUPPLEMENTAL_ARROWS_A}', "");
Expect(1, 10240, '\P{Is_Block: --SUPPLEMENTAL_ARROWS_A}', "");
Expect(0, 10240, '\P{^Is_Block: --SUPPLEMENTAL_ARROWS_A}', "");
Error('\p{Is_Blk= _SUP_Arrows_A/a/}');
Error('\P{Is_Blk= _SUP_Arrows_A/a/}');
Expect(1, 10239, '\p{Is_Blk=suparrowsa}', "");
Expect(0, 10239, '\p{^Is_Blk=suparrowsa}', "");
Expect(0, 10239, '\P{Is_Blk=suparrowsa}', "");
Expect(1, 10239, '\P{^Is_Blk=suparrowsa}', "");
Expect(0, 10240, '\p{Is_Blk=suparrowsa}', "");
Expect(1, 10240, '\p{^Is_Blk=suparrowsa}', "");
Expect(1, 10240, '\P{Is_Blk=suparrowsa}', "");
Expect(0, 10240, '\P{^Is_Blk=suparrowsa}', "");
Expect(1, 10239, '\p{Is_Blk= _Sup_Arrows_A}', "");
Expect(0, 10239, '\p{^Is_Blk= _Sup_Arrows_A}', "");
Expect(0, 10239, '\P{Is_Blk= _Sup_Arrows_A}', "");
Expect(1, 10239, '\P{^Is_Blk= _Sup_Arrows_A}', "");
Expect(0, 10240, '\p{Is_Blk= _Sup_Arrows_A}', "");
Expect(1, 10240, '\p{^Is_Blk= _Sup_Arrows_A}', "");
Expect(1, 10240, '\P{Is_Blk= _Sup_Arrows_A}', "");
Expect(0, 10240, '\P{^Is_Blk= _Sup_Arrows_A}', "");
Error('\p{Block=:=		Supplemental_Arrows_B}');
Error('\P{Block=:=		Supplemental_Arrows_B}');
Expect(1, 10623, '\p{Block=supplementalarrowsb}', "");
Expect(0, 10623, '\p{^Block=supplementalarrowsb}', "");
Expect(0, 10623, '\P{Block=supplementalarrowsb}', "");
Expect(1, 10623, '\P{^Block=supplementalarrowsb}', "");
Expect(0, 10624, '\p{Block=supplementalarrowsb}', "");
Expect(1, 10624, '\p{^Block=supplementalarrowsb}', "");
Expect(1, 10624, '\P{Block=supplementalarrowsb}', "");
Expect(0, 10624, '\P{^Block=supplementalarrowsb}', "");
Expect(1, 10623, '\p{Block=	supplemental_Arrows_B}', "");
Expect(0, 10623, '\p{^Block=	supplemental_Arrows_B}', "");
Expect(0, 10623, '\P{Block=	supplemental_Arrows_B}', "");
Expect(1, 10623, '\P{^Block=	supplemental_Arrows_B}', "");
Expect(0, 10624, '\p{Block=	supplemental_Arrows_B}', "");
Expect(1, 10624, '\p{^Block=	supplemental_Arrows_B}', "");
Expect(1, 10624, '\P{Block=	supplemental_Arrows_B}', "");
Expect(0, 10624, '\P{^Block=	supplemental_Arrows_B}', "");
Error('\p{Blk=-/a/Sup_ARROWS_B}');
Error('\P{Blk=-/a/Sup_ARROWS_B}');
Expect(1, 10623, '\p{Blk=suparrowsb}', "");
Expect(0, 10623, '\p{^Blk=suparrowsb}', "");
Expect(0, 10623, '\P{Blk=suparrowsb}', "");
Expect(1, 10623, '\P{^Blk=suparrowsb}', "");
Expect(0, 10624, '\p{Blk=suparrowsb}', "");
Expect(1, 10624, '\p{^Blk=suparrowsb}', "");
Expect(1, 10624, '\P{Blk=suparrowsb}', "");
Expect(0, 10624, '\P{^Blk=suparrowsb}', "");
Expect(1, 10623, '\p{Blk= Sup_Arrows_B}', "");
Expect(0, 10623, '\p{^Blk= Sup_Arrows_B}', "");
Expect(0, 10623, '\P{Blk= Sup_Arrows_B}', "");
Expect(1, 10623, '\P{^Blk= Sup_Arrows_B}', "");
Expect(0, 10624, '\p{Blk= Sup_Arrows_B}', "");
Expect(1, 10624, '\p{^Blk= Sup_Arrows_B}', "");
Expect(1, 10624, '\P{Blk= Sup_Arrows_B}', "");
Expect(0, 10624, '\P{^Blk= Sup_Arrows_B}', "");
Error('\p{Is_Block=:=--Supplemental_Arrows_B}');
Error('\P{Is_Block=:=--Supplemental_Arrows_B}');
Expect(1, 10623, '\p{Is_Block=supplementalarrowsb}', "");
Expect(0, 10623, '\p{^Is_Block=supplementalarrowsb}', "");
Expect(0, 10623, '\P{Is_Block=supplementalarrowsb}', "");
Expect(1, 10623, '\P{^Is_Block=supplementalarrowsb}', "");
Expect(0, 10624, '\p{Is_Block=supplementalarrowsb}', "");
Expect(1, 10624, '\p{^Is_Block=supplementalarrowsb}', "");
Expect(1, 10624, '\P{Is_Block=supplementalarrowsb}', "");
Expect(0, 10624, '\P{^Is_Block=supplementalarrowsb}', "");
Expect(1, 10623, '\p{Is_Block:-supplemental_arrows_B}', "");
Expect(0, 10623, '\p{^Is_Block:-supplemental_arrows_B}', "");
Expect(0, 10623, '\P{Is_Block:-supplemental_arrows_B}', "");
Expect(1, 10623, '\P{^Is_Block:-supplemental_arrows_B}', "");
Expect(0, 10624, '\p{Is_Block:-supplemental_arrows_B}', "");
Expect(1, 10624, '\p{^Is_Block:-supplemental_arrows_B}', "");
Expect(1, 10624, '\P{Is_Block:-supplemental_arrows_B}', "");
Expect(0, 10624, '\P{^Is_Block:-supplemental_arrows_B}', "");
Error('\p{Is_Blk=	:=SUP_Arrows_B}');
Error('\P{Is_Blk=	:=SUP_Arrows_B}');
Expect(1, 10623, '\p{Is_Blk=suparrowsb}', "");
Expect(0, 10623, '\p{^Is_Blk=suparrowsb}', "");
Expect(0, 10623, '\P{Is_Blk=suparrowsb}', "");
Expect(1, 10623, '\P{^Is_Blk=suparrowsb}', "");
Expect(0, 10624, '\p{Is_Blk=suparrowsb}', "");
Expect(1, 10624, '\p{^Is_Blk=suparrowsb}', "");
Expect(1, 10624, '\P{Is_Blk=suparrowsb}', "");
Expect(0, 10624, '\P{^Is_Blk=suparrowsb}', "");
Expect(1, 10623, '\p{Is_Blk=-	Sup_arrows_B}', "");
Expect(0, 10623, '\p{^Is_Blk=-	Sup_arrows_B}', "");
Expect(0, 10623, '\P{Is_Blk=-	Sup_arrows_B}', "");
Expect(1, 10623, '\P{^Is_Blk=-	Sup_arrows_B}', "");
Expect(0, 10624, '\p{Is_Blk=-	Sup_arrows_B}', "");
Expect(1, 10624, '\p{^Is_Blk=-	Sup_arrows_B}', "");
Expect(1, 10624, '\P{Is_Blk=-	Sup_arrows_B}', "");
Expect(0, 10624, '\P{^Is_Blk=-	Sup_arrows_B}', "");
Error('\p{Block=_ supplemental_Mathematical_Operators/a/}');
Error('\P{Block=_ supplemental_Mathematical_Operators/a/}');
Expect(1, 11007, '\p{Block:	supplementalmathematicaloperators}', "");
Expect(0, 11007, '\p{^Block:	supplementalmathematicaloperators}', "");
Expect(0, 11007, '\P{Block:	supplementalmathematicaloperators}', "");
Expect(1, 11007, '\P{^Block:	supplementalmathematicaloperators}', "");
Expect(0, 11008, '\p{Block:	supplementalmathematicaloperators}', "");
Expect(1, 11008, '\p{^Block:	supplementalmathematicaloperators}', "");
Expect(1, 11008, '\P{Block:	supplementalmathematicaloperators}', "");
Expect(0, 11008, '\P{^Block:	supplementalmathematicaloperators}', "");
Expect(1, 11007, '\p{Block=	_supplemental_MATHEMATICAL_Operators}', "");
Expect(0, 11007, '\p{^Block=	_supplemental_MATHEMATICAL_Operators}', "");
Expect(0, 11007, '\P{Block=	_supplemental_MATHEMATICAL_Operators}', "");
Expect(1, 11007, '\P{^Block=	_supplemental_MATHEMATICAL_Operators}', "");
Expect(0, 11008, '\p{Block=	_supplemental_MATHEMATICAL_Operators}', "");
Expect(1, 11008, '\p{^Block=	_supplemental_MATHEMATICAL_Operators}', "");
Expect(1, 11008, '\P{Block=	_supplemental_MATHEMATICAL_Operators}', "");
Expect(0, 11008, '\P{^Block=	_supplemental_MATHEMATICAL_Operators}', "");
Error('\p{Blk=:=-_SUP_MATH_operators}');
Error('\P{Blk=:=-_SUP_MATH_operators}');
Expect(1, 11007, '\p{Blk=supmathoperators}', "");
Expect(0, 11007, '\p{^Blk=supmathoperators}', "");
Expect(0, 11007, '\P{Blk=supmathoperators}', "");
Expect(1, 11007, '\P{^Blk=supmathoperators}', "");
Expect(0, 11008, '\p{Blk=supmathoperators}', "");
Expect(1, 11008, '\p{^Blk=supmathoperators}', "");
Expect(1, 11008, '\P{Blk=supmathoperators}', "");
Expect(0, 11008, '\P{^Blk=supmathoperators}', "");
Expect(1, 11007, '\p{Blk=		Sup_Math_Operators}', "");
Expect(0, 11007, '\p{^Blk=		Sup_Math_Operators}', "");
Expect(0, 11007, '\P{Blk=		Sup_Math_Operators}', "");
Expect(1, 11007, '\P{^Blk=		Sup_Math_Operators}', "");
Expect(0, 11008, '\p{Blk=		Sup_Math_Operators}', "");
Expect(1, 11008, '\p{^Blk=		Sup_Math_Operators}', "");
Expect(1, 11008, '\P{Blk=		Sup_Math_Operators}', "");
Expect(0, 11008, '\P{^Blk=		Sup_Math_Operators}', "");
Error('\p{Is_Block=-:=supplemental_Mathematical_OPERATORS}');
Error('\P{Is_Block=-:=supplemental_Mathematical_OPERATORS}');
Expect(1, 11007, '\p{Is_Block=supplementalmathematicaloperators}', "");
Expect(0, 11007, '\p{^Is_Block=supplementalmathematicaloperators}', "");
Expect(0, 11007, '\P{Is_Block=supplementalmathematicaloperators}', "");
Expect(1, 11007, '\P{^Is_Block=supplementalmathematicaloperators}', "");
Expect(0, 11008, '\p{Is_Block=supplementalmathematicaloperators}', "");
Expect(1, 11008, '\p{^Is_Block=supplementalmathematicaloperators}', "");
Expect(1, 11008, '\P{Is_Block=supplementalmathematicaloperators}', "");
Expect(0, 11008, '\P{^Is_Block=supplementalmathematicaloperators}', "");
Expect(1, 11007, '\p{Is_Block=__supplemental_Mathematical_Operators}', "");
Expect(0, 11007, '\p{^Is_Block=__supplemental_Mathematical_Operators}', "");
Expect(0, 11007, '\P{Is_Block=__supplemental_Mathematical_Operators}', "");
Expect(1, 11007, '\P{^Is_Block=__supplemental_Mathematical_Operators}', "");
Expect(0, 11008, '\p{Is_Block=__supplemental_Mathematical_Operators}', "");
Expect(1, 11008, '\p{^Is_Block=__supplemental_Mathematical_Operators}', "");
Expect(1, 11008, '\P{Is_Block=__supplemental_Mathematical_Operators}', "");
Expect(0, 11008, '\P{^Is_Block=__supplemental_Mathematical_Operators}', "");
Error('\p{Is_Blk=	:=Sup_MATH_Operators}');
Error('\P{Is_Blk=	:=Sup_MATH_Operators}');
Expect(1, 11007, '\p{Is_Blk=supmathoperators}', "");
Expect(0, 11007, '\p{^Is_Blk=supmathoperators}', "");
Expect(0, 11007, '\P{Is_Blk=supmathoperators}', "");
Expect(1, 11007, '\P{^Is_Blk=supmathoperators}', "");
Expect(0, 11008, '\p{Is_Blk=supmathoperators}', "");
Expect(1, 11008, '\p{^Is_Blk=supmathoperators}', "");
Expect(1, 11008, '\P{Is_Blk=supmathoperators}', "");
Expect(0, 11008, '\P{^Is_Blk=supmathoperators}', "");
Expect(1, 11007, '\p{Is_Blk=	_sup_Math_Operators}', "");
Expect(0, 11007, '\p{^Is_Blk=	_sup_Math_Operators}', "");
Expect(0, 11007, '\P{Is_Blk=	_sup_Math_Operators}', "");
Expect(1, 11007, '\P{^Is_Blk=	_sup_Math_Operators}', "");
Expect(0, 11008, '\p{Is_Blk=	_sup_Math_Operators}', "");
Expect(1, 11008, '\p{^Is_Blk=	_sup_Math_Operators}', "");
Expect(1, 11008, '\P{Is_Blk=	_sup_Math_Operators}', "");
Expect(0, 11008, '\P{^Is_Blk=	_sup_Math_Operators}', "");
Error('\p{Block=-:=SUPPLEMENTARY_Private_USE_Area_A}');
Error('\P{Block=-:=SUPPLEMENTARY_Private_USE_Area_A}');
Expect(1, 983040, '\p{Block=supplementaryprivateuseareaa}', "");
Expect(0, 983040, '\p{^Block=supplementaryprivateuseareaa}', "");
Expect(0, 983040, '\P{Block=supplementaryprivateuseareaa}', "");
Expect(1, 983040, '\P{^Block=supplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\p{Block=supplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\p{^Block=supplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\P{Block=supplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\P{^Block=supplementaryprivateuseareaa}', "");
Expect(1, 983040, '\p{Block=_	Supplementary_private_Use_Area_a}', "");
Expect(0, 983040, '\p{^Block=_	Supplementary_private_Use_Area_a}', "");
Expect(0, 983040, '\P{Block=_	Supplementary_private_Use_Area_a}', "");
Expect(1, 983040, '\P{^Block=_	Supplementary_private_Use_Area_a}', "");
Expect(0, 1048576, '\p{Block=_	Supplementary_private_Use_Area_a}', "");
Expect(1, 1048576, '\p{^Block=_	Supplementary_private_Use_Area_a}', "");
Expect(1, 1048576, '\P{Block=_	Supplementary_private_Use_Area_a}', "");
Expect(0, 1048576, '\P{^Block=_	Supplementary_private_Use_Area_a}', "");
Error('\p{Blk=_ Sup_PUA_A/a/}');
Error('\P{Blk=_ Sup_PUA_A/a/}');
Expect(1, 983040, '\p{Blk:suppuaa}', "");
Expect(0, 983040, '\p{^Blk:suppuaa}', "");
Expect(0, 983040, '\P{Blk:suppuaa}', "");
Expect(1, 983040, '\P{^Blk:suppuaa}', "");
Expect(0, 1048576, '\p{Blk:suppuaa}', "");
Expect(1, 1048576, '\p{^Blk:suppuaa}', "");
Expect(1, 1048576, '\P{Blk:suppuaa}', "");
Expect(0, 1048576, '\P{^Blk:suppuaa}', "");
Expect(1, 983040, '\p{Blk= SUP_PUA_a}', "");
Expect(0, 983040, '\p{^Blk= SUP_PUA_a}', "");
Expect(0, 983040, '\P{Blk= SUP_PUA_a}', "");
Expect(1, 983040, '\P{^Blk= SUP_PUA_a}', "");
Expect(0, 1048576, '\p{Blk= SUP_PUA_a}', "");
Expect(1, 1048576, '\p{^Blk= SUP_PUA_a}', "");
Expect(1, 1048576, '\P{Blk= SUP_PUA_a}', "");
Expect(0, 1048576, '\P{^Blk= SUP_PUA_a}', "");
Error('\p{Is_Block=-/a/supplementary_PRIVATE_Use_Area_A}');
Error('\P{Is_Block=-/a/supplementary_PRIVATE_Use_Area_A}');
Expect(1, 983040, '\p{Is_Block=supplementaryprivateuseareaa}', "");
Expect(0, 983040, '\p{^Is_Block=supplementaryprivateuseareaa}', "");
Expect(0, 983040, '\P{Is_Block=supplementaryprivateuseareaa}', "");
Expect(1, 983040, '\P{^Is_Block=supplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\p{Is_Block=supplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\p{^Is_Block=supplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\P{Is_Block=supplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\P{^Is_Block=supplementaryprivateuseareaa}', "");
Expect(1, 983040, '\p{Is_Block= SUPPLEMENTARY_PRIVATE_Use_Area_A}', "");
Expect(0, 983040, '\p{^Is_Block= SUPPLEMENTARY_PRIVATE_Use_Area_A}', "");
Expect(0, 983040, '\P{Is_Block= SUPPLEMENTARY_PRIVATE_Use_Area_A}', "");
Expect(1, 983040, '\P{^Is_Block= SUPPLEMENTARY_PRIVATE_Use_Area_A}', "");
Expect(0, 1048576, '\p{Is_Block= SUPPLEMENTARY_PRIVATE_Use_Area_A}', "");
Expect(1, 1048576, '\p{^Is_Block= SUPPLEMENTARY_PRIVATE_Use_Area_A}', "");
Expect(1, 1048576, '\P{Is_Block= SUPPLEMENTARY_PRIVATE_Use_Area_A}', "");
Expect(0, 1048576, '\P{^Is_Block= SUPPLEMENTARY_PRIVATE_Use_Area_A}', "");
Error('\p{Is_Blk:   :=Sup_PUA_A}');
Error('\P{Is_Blk:   :=Sup_PUA_A}');
Expect(1, 983040, '\p{Is_Blk=suppuaa}', "");
Expect(0, 983040, '\p{^Is_Blk=suppuaa}', "");
Expect(0, 983040, '\P{Is_Blk=suppuaa}', "");
Expect(1, 983040, '\P{^Is_Blk=suppuaa}', "");
Expect(0, 1048576, '\p{Is_Blk=suppuaa}', "");
Expect(1, 1048576, '\p{^Is_Blk=suppuaa}', "");
Expect(1, 1048576, '\P{Is_Blk=suppuaa}', "");
Expect(0, 1048576, '\P{^Is_Blk=suppuaa}', "");
Expect(1, 983040, '\p{Is_Blk=	_Sup_pua_a}', "");
Expect(0, 983040, '\p{^Is_Blk=	_Sup_pua_a}', "");
Expect(0, 983040, '\P{Is_Blk=	_Sup_pua_a}', "");
Expect(1, 983040, '\P{^Is_Blk=	_Sup_pua_a}', "");
Expect(0, 1048576, '\p{Is_Blk=	_Sup_pua_a}', "");
Expect(1, 1048576, '\p{^Is_Blk=	_Sup_pua_a}', "");
Expect(1, 1048576, '\P{Is_Blk=	_Sup_pua_a}', "");
Expect(0, 1048576, '\P{^Is_Blk=	_Sup_pua_a}', "");
Error('\p{Block=:=-	supplementary_private_USE_Area_B}');
Error('\P{Block=:=-	supplementary_private_USE_Area_B}');
Expect(1, 1048576, '\p{Block=supplementaryprivateuseareab}', "");
Expect(0, 1048576, '\p{^Block=supplementaryprivateuseareab}', "");
Expect(0, 1048576, '\P{Block=supplementaryprivateuseareab}', "");
Expect(1, 1048576, '\P{^Block=supplementaryprivateuseareab}', "");
Expect(0, 1, '\p{Block=supplementaryprivateuseareab}', "");
Expect(1, 1, '\p{^Block=supplementaryprivateuseareab}', "");
Expect(1, 1, '\P{Block=supplementaryprivateuseareab}', "");
Expect(0, 1, '\P{^Block=supplementaryprivateuseareab}', "");
Expect(1, 1048576, '\p{Block=	Supplementary_PRIVATE_Use_area_B}', "");
Expect(0, 1048576, '\p{^Block=	Supplementary_PRIVATE_Use_area_B}', "");
Expect(0, 1048576, '\P{Block=	Supplementary_PRIVATE_Use_area_B}', "");
Expect(1, 1048576, '\P{^Block=	Supplementary_PRIVATE_Use_area_B}', "");
Expect(0, 1, '\p{Block=	Supplementary_PRIVATE_Use_area_B}', "");
Expect(1, 1, '\p{^Block=	Supplementary_PRIVATE_Use_area_B}', "");
Expect(1, 1, '\P{Block=	Supplementary_PRIVATE_Use_area_B}', "");
Expect(0, 1, '\P{^Block=	Supplementary_PRIVATE_Use_area_B}', "");
Error('\p{Blk=:=-sup_PUA_b}');
Error('\P{Blk=:=-sup_PUA_b}');
Expect(1, 1048576, '\p{Blk=suppuab}', "");
Expect(0, 1048576, '\p{^Blk=suppuab}', "");
Expect(0, 1048576, '\P{Blk=suppuab}', "");
Expect(1, 1048576, '\P{^Blk=suppuab}', "");
Expect(0, 1, '\p{Blk=suppuab}', "");
Expect(1, 1, '\p{^Blk=suppuab}', "");
Expect(1, 1, '\P{Blk=suppuab}', "");
Expect(0, 1, '\P{^Blk=suppuab}', "");
Expect(1, 1048576, '\p{Blk=- SUP_pua_B}', "");
Expect(0, 1048576, '\p{^Blk=- SUP_pua_B}', "");
Expect(0, 1048576, '\P{Blk=- SUP_pua_B}', "");
Expect(1, 1048576, '\P{^Blk=- SUP_pua_B}', "");
Expect(0, 1, '\p{Blk=- SUP_pua_B}', "");
Expect(1, 1, '\p{^Blk=- SUP_pua_B}', "");
Expect(1, 1, '\P{Blk=- SUP_pua_B}', "");
Expect(0, 1, '\P{^Blk=- SUP_pua_B}', "");
Error('\p{Is_Block=	/a/Supplementary_Private_USE_AREA_B}');
Error('\P{Is_Block=	/a/Supplementary_Private_USE_AREA_B}');
Expect(1, 1048576, '\p{Is_Block=supplementaryprivateuseareab}', "");
Expect(0, 1048576, '\p{^Is_Block=supplementaryprivateuseareab}', "");
Expect(0, 1048576, '\P{Is_Block=supplementaryprivateuseareab}', "");
Expect(1, 1048576, '\P{^Is_Block=supplementaryprivateuseareab}', "");
Expect(0, 1, '\p{Is_Block=supplementaryprivateuseareab}', "");
Expect(1, 1, '\p{^Is_Block=supplementaryprivateuseareab}', "");
Expect(1, 1, '\P{Is_Block=supplementaryprivateuseareab}', "");
Expect(0, 1, '\P{^Is_Block=supplementaryprivateuseareab}', "");
Expect(1, 1048576, '\p{Is_Block=	_Supplementary_Private_Use_Area_B}', "");
Expect(0, 1048576, '\p{^Is_Block=	_Supplementary_Private_Use_Area_B}', "");
Expect(0, 1048576, '\P{Is_Block=	_Supplementary_Private_Use_Area_B}', "");
Expect(1, 1048576, '\P{^Is_Block=	_Supplementary_Private_Use_Area_B}', "");
Expect(0, 1, '\p{Is_Block=	_Supplementary_Private_Use_Area_B}', "");
Expect(1, 1, '\p{^Is_Block=	_Supplementary_Private_Use_Area_B}', "");
Expect(1, 1, '\P{Is_Block=	_Supplementary_Private_Use_Area_B}', "");
Expect(0, 1, '\P{^Is_Block=	_Supplementary_Private_Use_Area_B}', "");
Error('\p{Is_Blk=/a/	-Sup_PUA_B}');
Error('\P{Is_Blk=/a/	-Sup_PUA_B}');
Expect(1, 1048576, '\p{Is_Blk=suppuab}', "");
Expect(0, 1048576, '\p{^Is_Blk=suppuab}', "");
Expect(0, 1048576, '\P{Is_Blk=suppuab}', "");
Expect(1, 1048576, '\P{^Is_Blk=suppuab}', "");
Expect(0, 1, '\p{Is_Blk=suppuab}', "");
Expect(1, 1, '\p{^Is_Blk=suppuab}', "");
Expect(1, 1, '\P{Is_Blk=suppuab}', "");
Expect(0, 1, '\P{^Is_Blk=suppuab}', "");
Expect(1, 1048576, '\p{Is_Blk= sup_PUA_b}', "");
Expect(0, 1048576, '\p{^Is_Blk= sup_PUA_b}', "");
Expect(0, 1048576, '\P{Is_Blk= sup_PUA_b}', "");
Expect(1, 1048576, '\P{^Is_Blk= sup_PUA_b}', "");
Expect(0, 1, '\p{Is_Blk= sup_PUA_b}', "");
Expect(1, 1, '\p{^Is_Blk= sup_PUA_b}', "");
Expect(1, 1, '\P{Is_Blk= sup_PUA_b}', "");
Expect(0, 1, '\P{^Is_Blk= sup_PUA_b}', "");
Error('\p{Block:	:= _SUPPLEMENTAL_PUNCTUATION}');
Error('\P{Block:	:= _SUPPLEMENTAL_PUNCTUATION}');
Expect(1, 11903, '\p{Block=supplementalpunctuation}', "");
Expect(0, 11903, '\p{^Block=supplementalpunctuation}', "");
Expect(0, 11903, '\P{Block=supplementalpunctuation}', "");
Expect(1, 11903, '\P{^Block=supplementalpunctuation}', "");
Expect(0, 11904, '\p{Block=supplementalpunctuation}', "");
Expect(1, 11904, '\p{^Block=supplementalpunctuation}', "");
Expect(1, 11904, '\P{Block=supplementalpunctuation}', "");
Expect(0, 11904, '\P{^Block=supplementalpunctuation}', "");
Expect(1, 11903, '\p{Block= SUPPLEMENTAL_Punctuation}', "");
Expect(0, 11903, '\p{^Block= SUPPLEMENTAL_Punctuation}', "");
Expect(0, 11903, '\P{Block= SUPPLEMENTAL_Punctuation}', "");
Expect(1, 11903, '\P{^Block= SUPPLEMENTAL_Punctuation}', "");
Expect(0, 11904, '\p{Block= SUPPLEMENTAL_Punctuation}', "");
Expect(1, 11904, '\p{^Block= SUPPLEMENTAL_Punctuation}', "");
Expect(1, 11904, '\P{Block= SUPPLEMENTAL_Punctuation}', "");
Expect(0, 11904, '\P{^Block= SUPPLEMENTAL_Punctuation}', "");
Error('\p{Blk=__sup_Punctuation/a/}');
Error('\P{Blk=__sup_Punctuation/a/}');
Expect(1, 11903, '\p{Blk=suppunctuation}', "");
Expect(0, 11903, '\p{^Blk=suppunctuation}', "");
Expect(0, 11903, '\P{Blk=suppunctuation}', "");
Expect(1, 11903, '\P{^Blk=suppunctuation}', "");
Expect(0, 11904, '\p{Blk=suppunctuation}', "");
Expect(1, 11904, '\p{^Blk=suppunctuation}', "");
Expect(1, 11904, '\P{Blk=suppunctuation}', "");
Expect(0, 11904, '\P{^Blk=suppunctuation}', "");
Expect(1, 11903, '\p{Blk=		Sup_punctuation}', "");
Expect(0, 11903, '\p{^Blk=		Sup_punctuation}', "");
Expect(0, 11903, '\P{Blk=		Sup_punctuation}', "");
Expect(1, 11903, '\P{^Blk=		Sup_punctuation}', "");
Expect(0, 11904, '\p{Blk=		Sup_punctuation}', "");
Expect(1, 11904, '\p{^Blk=		Sup_punctuation}', "");
Expect(1, 11904, '\P{Blk=		Sup_punctuation}', "");
Expect(0, 11904, '\P{^Blk=		Sup_punctuation}', "");
Error('\p{Is_Block=_	Supplemental_PUNCTUATION:=}');
Error('\P{Is_Block=_	Supplemental_PUNCTUATION:=}');
Expect(1, 11903, '\p{Is_Block=supplementalpunctuation}', "");
Expect(0, 11903, '\p{^Is_Block=supplementalpunctuation}', "");
Expect(0, 11903, '\P{Is_Block=supplementalpunctuation}', "");
Expect(1, 11903, '\P{^Is_Block=supplementalpunctuation}', "");
Expect(0, 11904, '\p{Is_Block=supplementalpunctuation}', "");
Expect(1, 11904, '\p{^Is_Block=supplementalpunctuation}', "");
Expect(1, 11904, '\P{Is_Block=supplementalpunctuation}', "");
Expect(0, 11904, '\P{^Is_Block=supplementalpunctuation}', "");
Expect(1, 11903, '\p{Is_Block=-supplemental_punctuation}', "");
Expect(0, 11903, '\p{^Is_Block=-supplemental_punctuation}', "");
Expect(0, 11903, '\P{Is_Block=-supplemental_punctuation}', "");
Expect(1, 11903, '\P{^Is_Block=-supplemental_punctuation}', "");
Expect(0, 11904, '\p{Is_Block=-supplemental_punctuation}', "");
Expect(1, 11904, '\p{^Is_Block=-supplemental_punctuation}', "");
Expect(1, 11904, '\P{Is_Block=-supplemental_punctuation}', "");
Expect(0, 11904, '\P{^Is_Block=-supplemental_punctuation}', "");
Error('\p{Is_Blk=Sup_Punctuation:=}');
Error('\P{Is_Blk=Sup_Punctuation:=}');
Expect(1, 11903, '\p{Is_Blk=suppunctuation}', "");
Expect(0, 11903, '\p{^Is_Blk=suppunctuation}', "");
Expect(0, 11903, '\P{Is_Blk=suppunctuation}', "");
Expect(1, 11903, '\P{^Is_Blk=suppunctuation}', "");
Expect(0, 11904, '\p{Is_Blk=suppunctuation}', "");
Expect(1, 11904, '\p{^Is_Blk=suppunctuation}', "");
Expect(1, 11904, '\P{Is_Blk=suppunctuation}', "");
Expect(0, 11904, '\P{^Is_Blk=suppunctuation}', "");
Expect(1, 11903, '\p{Is_Blk= SUP_PUNCTUATION}', "");
Expect(0, 11903, '\p{^Is_Blk= SUP_PUNCTUATION}', "");
Expect(0, 11903, '\P{Is_Blk= SUP_PUNCTUATION}', "");
Expect(1, 11903, '\P{^Is_Blk= SUP_PUNCTUATION}', "");
Expect(0, 11904, '\p{Is_Blk= SUP_PUNCTUATION}', "");
Expect(1, 11904, '\p{^Is_Blk= SUP_PUNCTUATION}', "");
Expect(1, 11904, '\P{Is_Blk= SUP_PUNCTUATION}', "");
Expect(0, 11904, '\P{^Is_Blk= SUP_PUNCTUATION}', "");
Error('\p{Block= /a/SUPERSCRIPTS_and_Subscripts}');
Error('\P{Block= /a/SUPERSCRIPTS_and_Subscripts}');
Expect(1, 8351, '\p{Block=superscriptsandsubscripts}', "");
Expect(0, 8351, '\p{^Block=superscriptsandsubscripts}', "");
Expect(0, 8351, '\P{Block=superscriptsandsubscripts}', "");
Expect(1, 8351, '\P{^Block=superscriptsandsubscripts}', "");
Expect(0, 8352, '\p{Block=superscriptsandsubscripts}', "");
Expect(1, 8352, '\p{^Block=superscriptsandsubscripts}', "");
Expect(1, 8352, '\P{Block=superscriptsandsubscripts}', "");
Expect(0, 8352, '\P{^Block=superscriptsandsubscripts}', "");
Expect(1, 8351, '\p{Block=_superscripts_And_SUBSCRIPTS}', "");
Expect(0, 8351, '\p{^Block=_superscripts_And_SUBSCRIPTS}', "");
Expect(0, 8351, '\P{Block=_superscripts_And_SUBSCRIPTS}', "");
Expect(1, 8351, '\P{^Block=_superscripts_And_SUBSCRIPTS}', "");
Expect(0, 8352, '\p{Block=_superscripts_And_SUBSCRIPTS}', "");
Expect(1, 8352, '\p{^Block=_superscripts_And_SUBSCRIPTS}', "");
Expect(1, 8352, '\P{Block=_superscripts_And_SUBSCRIPTS}', "");
Expect(0, 8352, '\P{^Block=_superscripts_And_SUBSCRIPTS}', "");
Error('\p{Blk=/a/__Super_And_Sub}');
Error('\P{Blk=/a/__Super_And_Sub}');
Expect(1, 8351, '\p{Blk=superandsub}', "");
Expect(0, 8351, '\p{^Blk=superandsub}', "");
Expect(0, 8351, '\P{Blk=superandsub}', "");
Expect(1, 8351, '\P{^Blk=superandsub}', "");
Expect(0, 8352, '\p{Blk=superandsub}', "");
Expect(1, 8352, '\p{^Blk=superandsub}', "");
Expect(1, 8352, '\P{Blk=superandsub}', "");
Expect(0, 8352, '\P{^Blk=superandsub}', "");
Expect(1, 8351, '\p{Blk=-super_AND_Sub}', "");
Expect(0, 8351, '\p{^Blk=-super_AND_Sub}', "");
Expect(0, 8351, '\P{Blk=-super_AND_Sub}', "");
Expect(1, 8351, '\P{^Blk=-super_AND_Sub}', "");
Expect(0, 8352, '\p{Blk=-super_AND_Sub}', "");
Expect(1, 8352, '\p{^Blk=-super_AND_Sub}', "");
Expect(1, 8352, '\P{Blk=-super_AND_Sub}', "");
Expect(0, 8352, '\P{^Blk=-super_AND_Sub}', "");
Error('\p{Is_Block=:=_Superscripts_And_Subscripts}');
Error('\P{Is_Block=:=_Superscripts_And_Subscripts}');
Expect(1, 8351, '\p{Is_Block=superscriptsandsubscripts}', "");
Expect(0, 8351, '\p{^Is_Block=superscriptsandsubscripts}', "");
Expect(0, 8351, '\P{Is_Block=superscriptsandsubscripts}', "");
Expect(1, 8351, '\P{^Is_Block=superscriptsandsubscripts}', "");
Expect(0, 8352, '\p{Is_Block=superscriptsandsubscripts}', "");
Expect(1, 8352, '\p{^Is_Block=superscriptsandsubscripts}', "");
Expect(1, 8352, '\P{Is_Block=superscriptsandsubscripts}', "");
Expect(0, 8352, '\P{^Is_Block=superscriptsandsubscripts}', "");
Expect(1, 8351, '\p{Is_Block=-superscripts_AND_SUBSCRIPTS}', "");
Expect(0, 8351, '\p{^Is_Block=-superscripts_AND_SUBSCRIPTS}', "");
Expect(0, 8351, '\P{Is_Block=-superscripts_AND_SUBSCRIPTS}', "");
Expect(1, 8351, '\P{^Is_Block=-superscripts_AND_SUBSCRIPTS}', "");
Expect(0, 8352, '\p{Is_Block=-superscripts_AND_SUBSCRIPTS}', "");
Expect(1, 8352, '\p{^Is_Block=-superscripts_AND_SUBSCRIPTS}', "");
Expect(1, 8352, '\P{Is_Block=-superscripts_AND_SUBSCRIPTS}', "");
Expect(0, 8352, '\P{^Is_Block=-superscripts_AND_SUBSCRIPTS}', "");
Error('\p{Is_Blk: :=_	Super_AND_Sub}');
Error('\P{Is_Blk: :=_	Super_AND_Sub}');
Expect(1, 8351, '\p{Is_Blk=superandsub}', "");
Expect(0, 8351, '\p{^Is_Blk=superandsub}', "");
Expect(0, 8351, '\P{Is_Blk=superandsub}', "");
Expect(1, 8351, '\P{^Is_Blk=superandsub}', "");
Expect(0, 8352, '\p{Is_Blk=superandsub}', "");
Expect(1, 8352, '\p{^Is_Blk=superandsub}', "");
Expect(1, 8352, '\P{Is_Blk=superandsub}', "");
Expect(0, 8352, '\P{^Is_Blk=superandsub}', "");
Expect(1, 8351, '\p{Is_Blk=  Super_And_sub}', "");
Expect(0, 8351, '\p{^Is_Blk=  Super_And_sub}', "");
Expect(0, 8351, '\P{Is_Blk=  Super_And_sub}', "");
Expect(1, 8351, '\P{^Is_Blk=  Super_And_sub}', "");
Expect(0, 8352, '\p{Is_Blk=  Super_And_sub}', "");
Expect(1, 8352, '\p{^Is_Blk=  Super_And_sub}', "");
Expect(1, 8352, '\P{Is_Blk=  Super_And_sub}', "");
Expect(0, 8352, '\P{^Is_Blk=  Super_And_sub}', "");
Error('\p{Block=/a/__Syloti_Nagri}');
Error('\P{Block=/a/__Syloti_Nagri}');
Expect(1, 43055, '\p{Block=sylotinagri}', "");
Expect(0, 43055, '\p{^Block=sylotinagri}', "");
Expect(0, 43055, '\P{Block=sylotinagri}', "");
Expect(1, 43055, '\P{^Block=sylotinagri}', "");
Expect(0, 43056, '\p{Block=sylotinagri}', "");
Expect(1, 43056, '\p{^Block=sylotinagri}', "");
Expect(1, 43056, '\P{Block=sylotinagri}', "");
Expect(0, 43056, '\P{^Block=sylotinagri}', "");
Expect(1, 43055, '\p{Block=-Syloti_nagri}', "");
Expect(0, 43055, '\p{^Block=-Syloti_nagri}', "");
Expect(0, 43055, '\P{Block=-Syloti_nagri}', "");
Expect(1, 43055, '\P{^Block=-Syloti_nagri}', "");
Expect(0, 43056, '\p{Block=-Syloti_nagri}', "");
Expect(1, 43056, '\p{^Block=-Syloti_nagri}', "");
Expect(1, 43056, '\P{Block=-Syloti_nagri}', "");
Expect(0, 43056, '\P{^Block=-Syloti_nagri}', "");
Error('\p{Blk=:= 	Syloti_nagri}');
Error('\P{Blk=:= 	Syloti_nagri}');
Expect(1, 43055, '\p{Blk=sylotinagri}', "");
Expect(0, 43055, '\p{^Blk=sylotinagri}', "");
Expect(0, 43055, '\P{Blk=sylotinagri}', "");
Expect(1, 43055, '\P{^Blk=sylotinagri}', "");
Expect(0, 43056, '\p{Blk=sylotinagri}', "");
Expect(1, 43056, '\p{^Blk=sylotinagri}', "");
Expect(1, 43056, '\P{Blk=sylotinagri}', "");
Expect(0, 43056, '\P{^Blk=sylotinagri}', "");
Expect(1, 43055, '\p{Blk: 		SYLOTI_NAGRI}', "");
Expect(0, 43055, '\p{^Blk: 		SYLOTI_NAGRI}', "");
Expect(0, 43055, '\P{Blk: 		SYLOTI_NAGRI}', "");
Expect(1, 43055, '\P{^Blk: 		SYLOTI_NAGRI}', "");
Expect(0, 43056, '\p{Blk: 		SYLOTI_NAGRI}', "");
Expect(1, 43056, '\p{^Blk: 		SYLOTI_NAGRI}', "");
Expect(1, 43056, '\P{Blk: 		SYLOTI_NAGRI}', "");
Expect(0, 43056, '\P{^Blk: 		SYLOTI_NAGRI}', "");
Error('\p{Is_Block=:= Syloti_NAGRI}');
Error('\P{Is_Block=:= Syloti_NAGRI}');
Expect(1, 43055, '\p{Is_Block=sylotinagri}', "");
Expect(0, 43055, '\p{^Is_Block=sylotinagri}', "");
Expect(0, 43055, '\P{Is_Block=sylotinagri}', "");
Expect(1, 43055, '\P{^Is_Block=sylotinagri}', "");
Expect(0, 43056, '\p{Is_Block=sylotinagri}', "");
Expect(1, 43056, '\p{^Is_Block=sylotinagri}', "");
Expect(1, 43056, '\P{Is_Block=sylotinagri}', "");
Expect(0, 43056, '\P{^Is_Block=sylotinagri}', "");
Expect(1, 43055, '\p{Is_Block=_-Syloti_NAGRI}', "");
Expect(0, 43055, '\p{^Is_Block=_-Syloti_NAGRI}', "");
Expect(0, 43055, '\P{Is_Block=_-Syloti_NAGRI}', "");
Expect(1, 43055, '\P{^Is_Block=_-Syloti_NAGRI}', "");
Expect(0, 43056, '\p{Is_Block=_-Syloti_NAGRI}', "");
Expect(1, 43056, '\p{^Is_Block=_-Syloti_NAGRI}', "");
Expect(1, 43056, '\P{Is_Block=_-Syloti_NAGRI}', "");
Expect(0, 43056, '\P{^Is_Block=_-Syloti_NAGRI}', "");
Error('\p{Is_Blk=- SYLOTI_Nagri:=}');
Error('\P{Is_Blk=- SYLOTI_Nagri:=}');
Expect(1, 43055, '\p{Is_Blk=sylotinagri}', "");
Expect(0, 43055, '\p{^Is_Blk=sylotinagri}', "");
Expect(0, 43055, '\P{Is_Blk=sylotinagri}', "");
Expect(1, 43055, '\P{^Is_Blk=sylotinagri}', "");
Expect(0, 43056, '\p{Is_Blk=sylotinagri}', "");
Expect(1, 43056, '\p{^Is_Blk=sylotinagri}', "");
Expect(1, 43056, '\P{Is_Blk=sylotinagri}', "");
Expect(0, 43056, '\P{^Is_Blk=sylotinagri}', "");
Expect(1, 43055, '\p{Is_Blk=_Syloti_Nagri}', "");
Expect(0, 43055, '\p{^Is_Blk=_Syloti_Nagri}', "");
Expect(0, 43055, '\P{Is_Blk=_Syloti_Nagri}', "");
Expect(1, 43055, '\P{^Is_Blk=_Syloti_Nagri}', "");
Expect(0, 43056, '\p{Is_Blk=_Syloti_Nagri}', "");
Expect(1, 43056, '\p{^Is_Blk=_Syloti_Nagri}', "");
Expect(1, 43056, '\P{Is_Blk=_Syloti_Nagri}', "");
Expect(0, 43056, '\P{^Is_Blk=_Syloti_Nagri}', "");
Error('\p{Block=-SYRIAC/a/}');
Error('\P{Block=-SYRIAC/a/}');
Expect(1, 1871, '\p{Block=syriac}', "");
Expect(0, 1871, '\p{^Block=syriac}', "");
Expect(0, 1871, '\P{Block=syriac}', "");
Expect(1, 1871, '\P{^Block=syriac}', "");
Expect(0, 1872, '\p{Block=syriac}', "");
Expect(1, 1872, '\p{^Block=syriac}', "");
Expect(1, 1872, '\P{Block=syriac}', "");
Expect(0, 1872, '\P{^Block=syriac}', "");
Expect(1, 1871, '\p{Block=-	syriac}', "");
Expect(0, 1871, '\p{^Block=-	syriac}', "");
Expect(0, 1871, '\P{Block=-	syriac}', "");
Expect(1, 1871, '\P{^Block=-	syriac}', "");
Expect(0, 1872, '\p{Block=-	syriac}', "");
Expect(1, 1872, '\p{^Block=-	syriac}', "");
Expect(1, 1872, '\P{Block=-	syriac}', "");
Expect(0, 1872, '\P{^Block=-	syriac}', "");
Error('\p{Blk=-syriac/a/}');
Error('\P{Blk=-syriac/a/}');
Expect(1, 1871, '\p{Blk=syriac}', "");
Expect(0, 1871, '\p{^Blk=syriac}', "");
Expect(0, 1871, '\P{Blk=syriac}', "");
Expect(1, 1871, '\P{^Blk=syriac}', "");
Expect(0, 1872, '\p{Blk=syriac}', "");
Expect(1, 1872, '\p{^Blk=syriac}', "");
Expect(1, 1872, '\P{Blk=syriac}', "");
Expect(0, 1872, '\P{^Blk=syriac}', "");
Expect(1, 1871, '\p{Blk=--Syriac}', "");
Expect(0, 1871, '\p{^Blk=--Syriac}', "");
Expect(0, 1871, '\P{Blk=--Syriac}', "");
Expect(1, 1871, '\P{^Blk=--Syriac}', "");
Expect(0, 1872, '\p{Blk=--Syriac}', "");
Expect(1, 1872, '\p{^Blk=--Syriac}', "");
Expect(1, 1872, '\P{Blk=--Syriac}', "");
Expect(0, 1872, '\P{^Blk=--Syriac}', "");
Error('\p{Is_Block= 	Syriac:=}');
Error('\P{Is_Block= 	Syriac:=}');
Expect(1, 1871, '\p{Is_Block=syriac}', "");
Expect(0, 1871, '\p{^Is_Block=syriac}', "");
Expect(0, 1871, '\P{Is_Block=syriac}', "");
Expect(1, 1871, '\P{^Is_Block=syriac}', "");
Expect(0, 1872, '\p{Is_Block=syriac}', "");
Expect(1, 1872, '\p{^Is_Block=syriac}', "");
Expect(1, 1872, '\P{Is_Block=syriac}', "");
Expect(0, 1872, '\P{^Is_Block=syriac}', "");
Expect(1, 1871, '\p{Is_Block= _Syriac}', "");
Expect(0, 1871, '\p{^Is_Block= _Syriac}', "");
Expect(0, 1871, '\P{Is_Block= _Syriac}', "");
Expect(1, 1871, '\P{^Is_Block= _Syriac}', "");
Expect(0, 1872, '\p{Is_Block= _Syriac}', "");
Expect(1, 1872, '\p{^Is_Block= _Syriac}', "");
Expect(1, 1872, '\P{Is_Block= _Syriac}', "");
Expect(0, 1872, '\P{^Is_Block= _Syriac}', "");
Error('\p{Is_Blk:   _	Syriac:=}');
Error('\P{Is_Blk:   _	Syriac:=}');
Expect(1, 1871, '\p{Is_Blk:	syriac}', "");
Expect(0, 1871, '\p{^Is_Blk:	syriac}', "");
Expect(0, 1871, '\P{Is_Blk:	syriac}', "");
Expect(1, 1871, '\P{^Is_Blk:	syriac}', "");
Expect(0, 1872, '\p{Is_Blk:	syriac}', "");
Expect(1, 1872, '\p{^Is_Blk:	syriac}', "");
Expect(1, 1872, '\P{Is_Blk:	syriac}', "");
Expect(0, 1872, '\P{^Is_Blk:	syriac}', "");
Expect(1, 1871, '\p{Is_Blk=_ Syriac}', "");
Expect(0, 1871, '\p{^Is_Blk=_ Syriac}', "");
Expect(0, 1871, '\P{Is_Blk=_ Syriac}', "");
Expect(1, 1871, '\P{^Is_Blk=_ Syriac}', "");
Expect(0, 1872, '\p{Is_Blk=_ Syriac}', "");
Expect(1, 1872, '\p{^Is_Blk=_ Syriac}', "");
Expect(1, 1872, '\P{Is_Blk=_ Syriac}', "");
Expect(0, 1872, '\P{^Is_Blk=_ Syriac}', "");
Error('\p{Block=_/a/Tagalog}');
Error('\P{Block=_/a/Tagalog}');
Expect(1, 5919, '\p{Block=tagalog}', "");
Expect(0, 5919, '\p{^Block=tagalog}', "");
Expect(0, 5919, '\P{Block=tagalog}', "");
Expect(1, 5919, '\P{^Block=tagalog}', "");
Expect(0, 5920, '\p{Block=tagalog}', "");
Expect(1, 5920, '\p{^Block=tagalog}', "");
Expect(1, 5920, '\P{Block=tagalog}', "");
Expect(0, 5920, '\P{^Block=tagalog}', "");
Expect(1, 5919, '\p{Block= 	tagalog}', "");
Expect(0, 5919, '\p{^Block= 	tagalog}', "");
Expect(0, 5919, '\P{Block= 	tagalog}', "");
Expect(1, 5919, '\P{^Block= 	tagalog}', "");
Expect(0, 5920, '\p{Block= 	tagalog}', "");
Expect(1, 5920, '\p{^Block= 	tagalog}', "");
Expect(1, 5920, '\P{Block= 	tagalog}', "");
Expect(0, 5920, '\P{^Block= 	tagalog}', "");
Error('\p{Blk=	Tagalog/a/}');
Error('\P{Blk=	Tagalog/a/}');
Expect(1, 5919, '\p{Blk=tagalog}', "");
Expect(0, 5919, '\p{^Blk=tagalog}', "");
Expect(0, 5919, '\P{Blk=tagalog}', "");
Expect(1, 5919, '\P{^Blk=tagalog}', "");
Expect(0, 5920, '\p{Blk=tagalog}', "");
Expect(1, 5920, '\p{^Blk=tagalog}', "");
Expect(1, 5920, '\P{Blk=tagalog}', "");
Expect(0, 5920, '\P{^Blk=tagalog}', "");
Expect(1, 5919, '\p{Blk=_ tagalog}', "");
Expect(0, 5919, '\p{^Blk=_ tagalog}', "");
Expect(0, 5919, '\P{Blk=_ tagalog}', "");
Expect(1, 5919, '\P{^Blk=_ tagalog}', "");
Expect(0, 5920, '\p{Blk=_ tagalog}', "");
Expect(1, 5920, '\p{^Blk=_ tagalog}', "");
Expect(1, 5920, '\P{Blk=_ tagalog}', "");
Expect(0, 5920, '\P{^Blk=_ tagalog}', "");
Error('\p{Is_Block= _tagalog/a/}');
Error('\P{Is_Block= _tagalog/a/}');
Expect(1, 5919, '\p{Is_Block=tagalog}', "");
Expect(0, 5919, '\p{^Is_Block=tagalog}', "");
Expect(0, 5919, '\P{Is_Block=tagalog}', "");
Expect(1, 5919, '\P{^Is_Block=tagalog}', "");
Expect(0, 5920, '\p{Is_Block=tagalog}', "");
Expect(1, 5920, '\p{^Is_Block=tagalog}', "");
Expect(1, 5920, '\P{Is_Block=tagalog}', "");
Expect(0, 5920, '\P{^Is_Block=tagalog}', "");
Expect(1, 5919, '\p{Is_Block= Tagalog}', "");
Expect(0, 5919, '\p{^Is_Block= Tagalog}', "");
Expect(0, 5919, '\P{Is_Block= Tagalog}', "");
Expect(1, 5919, '\P{^Is_Block= Tagalog}', "");
Expect(0, 5920, '\p{Is_Block= Tagalog}', "");
Expect(1, 5920, '\p{^Is_Block= Tagalog}', "");
Expect(1, 5920, '\P{Is_Block= Tagalog}', "");
Expect(0, 5920, '\P{^Is_Block= Tagalog}', "");
Error('\p{Is_Blk:	-_Tagalog:=}');
Error('\P{Is_Blk:	-_Tagalog:=}');
Expect(1, 5919, '\p{Is_Blk=tagalog}', "");
Expect(0, 5919, '\p{^Is_Blk=tagalog}', "");
Expect(0, 5919, '\P{Is_Blk=tagalog}', "");
Expect(1, 5919, '\P{^Is_Blk=tagalog}', "");
Expect(0, 5920, '\p{Is_Blk=tagalog}', "");
Expect(1, 5920, '\p{^Is_Blk=tagalog}', "");
Expect(1, 5920, '\P{Is_Blk=tagalog}', "");
Expect(0, 5920, '\P{^Is_Blk=tagalog}', "");
Expect(1, 5919, '\p{Is_Blk=		Tagalog}', "");
Expect(0, 5919, '\p{^Is_Blk=		Tagalog}', "");
Expect(0, 5919, '\P{Is_Blk=		Tagalog}', "");
Expect(1, 5919, '\P{^Is_Blk=		Tagalog}', "");
Expect(0, 5920, '\p{Is_Blk=		Tagalog}', "");
Expect(1, 5920, '\p{^Is_Blk=		Tagalog}', "");
Expect(1, 5920, '\P{Is_Blk=		Tagalog}', "");
Expect(0, 5920, '\P{^Is_Blk=		Tagalog}', "");
Error('\p{Block=/a/ _Tagbanwa}');
Error('\P{Block=/a/ _Tagbanwa}');
Expect(1, 6015, '\p{Block:tagbanwa}', "");
Expect(0, 6015, '\p{^Block:tagbanwa}', "");
Expect(0, 6015, '\P{Block:tagbanwa}', "");
Expect(1, 6015, '\P{^Block:tagbanwa}', "");
Expect(0, 6016, '\p{Block:tagbanwa}', "");
Expect(1, 6016, '\p{^Block:tagbanwa}', "");
Expect(1, 6016, '\P{Block:tagbanwa}', "");
Expect(0, 6016, '\P{^Block:tagbanwa}', "");
Expect(1, 6015, '\p{Block= -TAGBANWA}', "");
Expect(0, 6015, '\p{^Block= -TAGBANWA}', "");
Expect(0, 6015, '\P{Block= -TAGBANWA}', "");
Expect(1, 6015, '\P{^Block= -TAGBANWA}', "");
Expect(0, 6016, '\p{Block= -TAGBANWA}', "");
Expect(1, 6016, '\p{^Block= -TAGBANWA}', "");
Expect(1, 6016, '\P{Block= -TAGBANWA}', "");
Expect(0, 6016, '\P{^Block= -TAGBANWA}', "");
Error('\p{Blk=/a/ _Tagbanwa}');
Error('\P{Blk=/a/ _Tagbanwa}');
Expect(1, 6015, '\p{Blk:	tagbanwa}', "");
Expect(0, 6015, '\p{^Blk:	tagbanwa}', "");
Expect(0, 6015, '\P{Blk:	tagbanwa}', "");
Expect(1, 6015, '\P{^Blk:	tagbanwa}', "");
Expect(0, 6016, '\p{Blk:	tagbanwa}', "");
Expect(1, 6016, '\p{^Blk:	tagbanwa}', "");
Expect(1, 6016, '\P{Blk:	tagbanwa}', "");
Expect(0, 6016, '\P{^Blk:	tagbanwa}', "");
Expect(1, 6015, '\p{Blk=-_TAGBANWA}', "");
Expect(0, 6015, '\p{^Blk=-_TAGBANWA}', "");
Expect(0, 6015, '\P{Blk=-_TAGBANWA}', "");
Expect(1, 6015, '\P{^Blk=-_TAGBANWA}', "");
Expect(0, 6016, '\p{Blk=-_TAGBANWA}', "");
Expect(1, 6016, '\p{^Blk=-_TAGBANWA}', "");
Expect(1, 6016, '\P{Blk=-_TAGBANWA}', "");
Expect(0, 6016, '\P{^Blk=-_TAGBANWA}', "");
Error('\p{Is_Block:  	tagbanwa/a/}');
Error('\P{Is_Block:  	tagbanwa/a/}');
Expect(1, 6015, '\p{Is_Block=tagbanwa}', "");
Expect(0, 6015, '\p{^Is_Block=tagbanwa}', "");
Expect(0, 6015, '\P{Is_Block=tagbanwa}', "");
Expect(1, 6015, '\P{^Is_Block=tagbanwa}', "");
Expect(0, 6016, '\p{Is_Block=tagbanwa}', "");
Expect(1, 6016, '\p{^Is_Block=tagbanwa}', "");
Expect(1, 6016, '\P{Is_Block=tagbanwa}', "");
Expect(0, 6016, '\P{^Is_Block=tagbanwa}', "");
Expect(1, 6015, '\p{Is_Block=_Tagbanwa}', "");
Expect(0, 6015, '\p{^Is_Block=_Tagbanwa}', "");
Expect(0, 6015, '\P{Is_Block=_Tagbanwa}', "");
Expect(1, 6015, '\P{^Is_Block=_Tagbanwa}', "");
Expect(0, 6016, '\p{Is_Block=_Tagbanwa}', "");
Expect(1, 6016, '\p{^Is_Block=_Tagbanwa}', "");
Expect(1, 6016, '\P{Is_Block=_Tagbanwa}', "");
Expect(0, 6016, '\P{^Is_Block=_Tagbanwa}', "");
Error('\p{Is_Blk=:=		tagbanwa}');
Error('\P{Is_Blk=:=		tagbanwa}');
Expect(1, 6015, '\p{Is_Blk=tagbanwa}', "");
Expect(0, 6015, '\p{^Is_Blk=tagbanwa}', "");
Expect(0, 6015, '\P{Is_Blk=tagbanwa}', "");
Expect(1, 6015, '\P{^Is_Blk=tagbanwa}', "");
Expect(0, 6016, '\p{Is_Blk=tagbanwa}', "");
Expect(1, 6016, '\p{^Is_Blk=tagbanwa}', "");
Expect(1, 6016, '\P{Is_Blk=tagbanwa}', "");
Expect(0, 6016, '\P{^Is_Blk=tagbanwa}', "");
Expect(1, 6015, '\p{Is_Blk=_	tagbanwa}', "");
Expect(0, 6015, '\p{^Is_Blk=_	tagbanwa}', "");
Expect(0, 6015, '\P{Is_Blk=_	tagbanwa}', "");
Expect(1, 6015, '\P{^Is_Blk=_	tagbanwa}', "");
Expect(0, 6016, '\p{Is_Blk=_	tagbanwa}', "");
Expect(1, 6016, '\p{^Is_Blk=_	tagbanwa}', "");
Expect(1, 6016, '\P{Is_Blk=_	tagbanwa}', "");
Expect(0, 6016, '\P{^Is_Blk=_	tagbanwa}', "");
Error('\p{Block: /a/Tags}');
Error('\P{Block: /a/Tags}');
Expect(1, 917631, '\p{Block=tags}', "");
Expect(0, 917631, '\p{^Block=tags}', "");
Expect(0, 917631, '\P{Block=tags}', "");
Expect(1, 917631, '\P{^Block=tags}', "");
Expect(0, 917632, '\p{Block=tags}', "");
Expect(1, 917632, '\p{^Block=tags}', "");
Expect(1, 917632, '\P{Block=tags}', "");
Expect(0, 917632, '\P{^Block=tags}', "");
Expect(1, 917631, '\p{Block=-	Tags}', "");
Expect(0, 917631, '\p{^Block=-	Tags}', "");
Expect(0, 917631, '\P{Block=-	Tags}', "");
Expect(1, 917631, '\P{^Block=-	Tags}', "");
Expect(0, 917632, '\p{Block=-	Tags}', "");
Expect(1, 917632, '\p{^Block=-	Tags}', "");
Expect(1, 917632, '\P{Block=-	Tags}', "");
Expect(0, 917632, '\P{^Block=-	Tags}', "");
Error('\p{Blk= Tags/a/}');
Error('\P{Blk= Tags/a/}');
Expect(1, 917631, '\p{Blk=tags}', "");
Expect(0, 917631, '\p{^Blk=tags}', "");
Expect(0, 917631, '\P{Blk=tags}', "");
Expect(1, 917631, '\P{^Blk=tags}', "");
Expect(0, 917632, '\p{Blk=tags}', "");
Expect(1, 917632, '\p{^Blk=tags}', "");
Expect(1, 917632, '\P{Blk=tags}', "");
Expect(0, 917632, '\P{^Blk=tags}', "");
Expect(1, 917631, '\p{Blk:	_TAGS}', "");
Expect(0, 917631, '\p{^Blk:	_TAGS}', "");
Expect(0, 917631, '\P{Blk:	_TAGS}', "");
Expect(1, 917631, '\P{^Blk:	_TAGS}', "");
Expect(0, 917632, '\p{Blk:	_TAGS}', "");
Expect(1, 917632, '\p{^Blk:	_TAGS}', "");
Expect(1, 917632, '\P{Blk:	_TAGS}', "");
Expect(0, 917632, '\P{^Blk:	_TAGS}', "");
Error('\p{Is_Block=-:=Tags}');
Error('\P{Is_Block=-:=Tags}');
Expect(1, 917631, '\p{Is_Block:   tags}', "");
Expect(0, 917631, '\p{^Is_Block:   tags}', "");
Expect(0, 917631, '\P{Is_Block:   tags}', "");
Expect(1, 917631, '\P{^Is_Block:   tags}', "");
Expect(0, 917632, '\p{Is_Block:   tags}', "");
Expect(1, 917632, '\p{^Is_Block:   tags}', "");
Expect(1, 917632, '\P{Is_Block:   tags}', "");
Expect(0, 917632, '\P{^Is_Block:   tags}', "");
Expect(1, 917631, '\p{Is_Block=  Tags}', "");
Expect(0, 917631, '\p{^Is_Block=  Tags}', "");
Expect(0, 917631, '\P{Is_Block=  Tags}', "");
Expect(1, 917631, '\P{^Is_Block=  Tags}', "");
Expect(0, 917632, '\p{Is_Block=  Tags}', "");
Expect(1, 917632, '\p{^Is_Block=  Tags}', "");
Expect(1, 917632, '\P{Is_Block=  Tags}', "");
Expect(0, 917632, '\P{^Is_Block=  Tags}', "");
Error('\p{Is_Blk=Tags:=}');
Error('\P{Is_Blk=Tags:=}');
Expect(1, 917631, '\p{Is_Blk:	tags}', "");
Expect(0, 917631, '\p{^Is_Blk:	tags}', "");
Expect(0, 917631, '\P{Is_Blk:	tags}', "");
Expect(1, 917631, '\P{^Is_Blk:	tags}', "");
Expect(0, 917632, '\p{Is_Blk:	tags}', "");
Expect(1, 917632, '\p{^Is_Blk:	tags}', "");
Expect(1, 917632, '\P{Is_Blk:	tags}', "");
Expect(0, 917632, '\P{^Is_Blk:	tags}', "");
Expect(1, 917631, '\p{Is_Blk=- tags}', "");
Expect(0, 917631, '\p{^Is_Blk=- tags}', "");
Expect(0, 917631, '\P{Is_Blk=- tags}', "");
Expect(1, 917631, '\P{^Is_Blk=- tags}', "");
Expect(0, 917632, '\p{Is_Blk=- tags}', "");
Expect(1, 917632, '\p{^Is_Blk=- tags}', "");
Expect(1, 917632, '\P{Is_Blk=- tags}', "");
Expect(0, 917632, '\P{^Is_Blk=- tags}', "");
Error('\p{Block=:=Tai_Le}');
Error('\P{Block=:=Tai_Le}');
Expect(1, 6527, '\p{Block:   taile}', "");
Expect(0, 6527, '\p{^Block:   taile}', "");
Expect(0, 6527, '\P{Block:   taile}', "");
Expect(1, 6527, '\P{^Block:   taile}', "");
Expect(0, 6528, '\p{Block:   taile}', "");
Expect(1, 6528, '\p{^Block:   taile}', "");
Expect(1, 6528, '\P{Block:   taile}', "");
Expect(0, 6528, '\P{^Block:   taile}', "");
Expect(1, 6527, '\p{Block= -tai_LE}', "");
Expect(0, 6527, '\p{^Block= -tai_LE}', "");
Expect(0, 6527, '\P{Block= -tai_LE}', "");
Expect(1, 6527, '\P{^Block= -tai_LE}', "");
Expect(0, 6528, '\p{Block= -tai_LE}', "");
Expect(1, 6528, '\p{^Block= -tai_LE}', "");
Expect(1, 6528, '\P{Block= -tai_LE}', "");
Expect(0, 6528, '\P{^Block= -tai_LE}', "");
Error('\p{Blk=	:=TAI_Le}');
Error('\P{Blk=	:=TAI_Le}');
Expect(1, 6527, '\p{Blk=taile}', "");
Expect(0, 6527, '\p{^Blk=taile}', "");
Expect(0, 6527, '\P{Blk=taile}', "");
Expect(1, 6527, '\P{^Blk=taile}', "");
Expect(0, 6528, '\p{Blk=taile}', "");
Expect(1, 6528, '\p{^Blk=taile}', "");
Expect(1, 6528, '\P{Blk=taile}', "");
Expect(0, 6528, '\P{^Blk=taile}', "");
Expect(1, 6527, '\p{Blk=  Tai_Le}', "");
Expect(0, 6527, '\p{^Blk=  Tai_Le}', "");
Expect(0, 6527, '\P{Blk=  Tai_Le}', "");
Expect(1, 6527, '\P{^Blk=  Tai_Le}', "");
Expect(0, 6528, '\p{Blk=  Tai_Le}', "");
Expect(1, 6528, '\p{^Blk=  Tai_Le}', "");
Expect(1, 6528, '\P{Blk=  Tai_Le}', "");
Expect(0, 6528, '\P{^Blk=  Tai_Le}', "");
Error('\p{Is_Block=-_TAI_Le/a/}');
Error('\P{Is_Block=-_TAI_Le/a/}');
Expect(1, 6527, '\p{Is_Block=taile}', "");
Expect(0, 6527, '\p{^Is_Block=taile}', "");
Expect(0, 6527, '\P{Is_Block=taile}', "");
Expect(1, 6527, '\P{^Is_Block=taile}', "");
Expect(0, 6528, '\p{Is_Block=taile}', "");
Expect(1, 6528, '\p{^Is_Block=taile}', "");
Expect(1, 6528, '\P{Is_Block=taile}', "");
Expect(0, 6528, '\P{^Is_Block=taile}', "");
Expect(1, 6527, '\p{Is_Block= TAI_Le}', "");
Expect(0, 6527, '\p{^Is_Block= TAI_Le}', "");
Expect(0, 6527, '\P{Is_Block= TAI_Le}', "");
Expect(1, 6527, '\P{^Is_Block= TAI_Le}', "");
Expect(0, 6528, '\p{Is_Block= TAI_Le}', "");
Expect(1, 6528, '\p{^Is_Block= TAI_Le}', "");
Expect(1, 6528, '\P{Is_Block= TAI_Le}', "");
Expect(0, 6528, '\P{^Is_Block= TAI_Le}', "");
Error('\p{Is_Blk=:=	_Tai_Le}');
Error('\P{Is_Blk=:=	_Tai_Le}');
Expect(1, 6527, '\p{Is_Blk=taile}', "");
Expect(0, 6527, '\p{^Is_Blk=taile}', "");
Expect(0, 6527, '\P{Is_Blk=taile}', "");
Expect(1, 6527, '\P{^Is_Blk=taile}', "");
Expect(0, 6528, '\p{Is_Blk=taile}', "");
Expect(1, 6528, '\p{^Is_Blk=taile}', "");
Expect(1, 6528, '\P{Is_Blk=taile}', "");
Expect(0, 6528, '\P{^Is_Blk=taile}', "");
Expect(1, 6527, '\p{Is_Blk= -Tai_Le}', "");
Expect(0, 6527, '\p{^Is_Blk= -Tai_Le}', "");
Expect(0, 6527, '\P{Is_Blk= -Tai_Le}', "");
Expect(1, 6527, '\P{^Is_Blk= -Tai_Le}', "");
Expect(0, 6528, '\p{Is_Blk= -Tai_Le}', "");
Expect(1, 6528, '\p{^Is_Blk= -Tai_Le}', "");
Expect(1, 6528, '\P{Is_Blk= -Tai_Le}', "");
Expect(0, 6528, '\P{^Is_Blk= -Tai_Le}', "");
Error('\p{Block=:=	-Tai_Tham}');
Error('\P{Block=:=	-Tai_Tham}');
Expect(1, 6831, '\p{Block=taitham}', "");
Expect(0, 6831, '\p{^Block=taitham}', "");
Expect(0, 6831, '\P{Block=taitham}', "");
Expect(1, 6831, '\P{^Block=taitham}', "");
Expect(0, 6832, '\p{Block=taitham}', "");
Expect(1, 6832, '\p{^Block=taitham}', "");
Expect(1, 6832, '\P{Block=taitham}', "");
Expect(0, 6832, '\P{^Block=taitham}', "");
Expect(1, 6831, '\p{Block: tai_tham}', "");
Expect(0, 6831, '\p{^Block: tai_tham}', "");
Expect(0, 6831, '\P{Block: tai_tham}', "");
Expect(1, 6831, '\P{^Block: tai_tham}', "");
Expect(0, 6832, '\p{Block: tai_tham}', "");
Expect(1, 6832, '\p{^Block: tai_tham}', "");
Expect(1, 6832, '\P{Block: tai_tham}', "");
Expect(0, 6832, '\P{^Block: tai_tham}', "");
Error('\p{Blk=/a/__Tai_Tham}');
Error('\P{Blk=/a/__Tai_Tham}');
Expect(1, 6831, '\p{Blk=taitham}', "");
Expect(0, 6831, '\p{^Blk=taitham}', "");
Expect(0, 6831, '\P{Blk=taitham}', "");
Expect(1, 6831, '\P{^Blk=taitham}', "");
Expect(0, 6832, '\p{Blk=taitham}', "");
Expect(1, 6832, '\p{^Blk=taitham}', "");
Expect(1, 6832, '\P{Blk=taitham}', "");
Expect(0, 6832, '\P{^Blk=taitham}', "");
Expect(1, 6831, '\p{Blk=-TAI_Tham}', "");
Expect(0, 6831, '\p{^Blk=-TAI_Tham}', "");
Expect(0, 6831, '\P{Blk=-TAI_Tham}', "");
Expect(1, 6831, '\P{^Blk=-TAI_Tham}', "");
Expect(0, 6832, '\p{Blk=-TAI_Tham}', "");
Expect(1, 6832, '\p{^Blk=-TAI_Tham}', "");
Expect(1, 6832, '\P{Blk=-TAI_Tham}', "");
Expect(0, 6832, '\P{^Blk=-TAI_Tham}', "");
Error('\p{Is_Block: _/a/Tai_Tham}');
Error('\P{Is_Block: _/a/Tai_Tham}');
Expect(1, 6831, '\p{Is_Block=taitham}', "");
Expect(0, 6831, '\p{^Is_Block=taitham}', "");
Expect(0, 6831, '\P{Is_Block=taitham}', "");
Expect(1, 6831, '\P{^Is_Block=taitham}', "");
Expect(0, 6832, '\p{Is_Block=taitham}', "");
Expect(1, 6832, '\p{^Is_Block=taitham}', "");
Expect(1, 6832, '\P{Is_Block=taitham}', "");
Expect(0, 6832, '\P{^Is_Block=taitham}', "");
Expect(1, 6831, '\p{Is_Block=	 TAI_tham}', "");
Expect(0, 6831, '\p{^Is_Block=	 TAI_tham}', "");
Expect(0, 6831, '\P{Is_Block=	 TAI_tham}', "");
Expect(1, 6831, '\P{^Is_Block=	 TAI_tham}', "");
Expect(0, 6832, '\p{Is_Block=	 TAI_tham}', "");
Expect(1, 6832, '\p{^Is_Block=	 TAI_tham}', "");
Expect(1, 6832, '\P{Is_Block=	 TAI_tham}', "");
Expect(0, 6832, '\P{^Is_Block=	 TAI_tham}', "");
Error('\p{Is_Blk:  TAI_THAM:=}');
Error('\P{Is_Blk:  TAI_THAM:=}');
Expect(1, 6831, '\p{Is_Blk=taitham}', "");
Expect(0, 6831, '\p{^Is_Blk=taitham}', "");
Expect(0, 6831, '\P{Is_Blk=taitham}', "");
Expect(1, 6831, '\P{^Is_Blk=taitham}', "");
Expect(0, 6832, '\p{Is_Blk=taitham}', "");
Expect(1, 6832, '\p{^Is_Blk=taitham}', "");
Expect(1, 6832, '\P{Is_Blk=taitham}', "");
Expect(0, 6832, '\P{^Is_Blk=taitham}', "");
Expect(1, 6831, '\p{Is_Blk=_-Tai_Tham}', "");
Expect(0, 6831, '\p{^Is_Blk=_-Tai_Tham}', "");
Expect(0, 6831, '\P{Is_Blk=_-Tai_Tham}', "");
Expect(1, 6831, '\P{^Is_Blk=_-Tai_Tham}', "");
Expect(0, 6832, '\p{Is_Blk=_-Tai_Tham}', "");
Expect(1, 6832, '\p{^Is_Blk=_-Tai_Tham}', "");
Expect(1, 6832, '\P{Is_Blk=_-Tai_Tham}', "");
Expect(0, 6832, '\P{^Is_Blk=_-Tai_Tham}', "");
Error('\p{Block= 	Tai_Viet/a/}');
Error('\P{Block= 	Tai_Viet/a/}');
Expect(1, 43743, '\p{Block=taiviet}', "");
Expect(0, 43743, '\p{^Block=taiviet}', "");
Expect(0, 43743, '\P{Block=taiviet}', "");
Expect(1, 43743, '\P{^Block=taiviet}', "");
Expect(0, 43744, '\p{Block=taiviet}', "");
Expect(1, 43744, '\p{^Block=taiviet}', "");
Expect(1, 43744, '\P{Block=taiviet}', "");
Expect(0, 43744, '\P{^Block=taiviet}', "");
Expect(1, 43743, '\p{Block=	_Tai_VIET}', "");
Expect(0, 43743, '\p{^Block=	_Tai_VIET}', "");
Expect(0, 43743, '\P{Block=	_Tai_VIET}', "");
Expect(1, 43743, '\P{^Block=	_Tai_VIET}', "");
Expect(0, 43744, '\p{Block=	_Tai_VIET}', "");
Expect(1, 43744, '\p{^Block=	_Tai_VIET}', "");
Expect(1, 43744, '\P{Block=	_Tai_VIET}', "");
Expect(0, 43744, '\P{^Block=	_Tai_VIET}', "");
Error('\p{Blk=_-tai_viet/a/}');
Error('\P{Blk=_-tai_viet/a/}');
Expect(1, 43743, '\p{Blk=taiviet}', "");
Expect(0, 43743, '\p{^Blk=taiviet}', "");
Expect(0, 43743, '\P{Blk=taiviet}', "");
Expect(1, 43743, '\P{^Blk=taiviet}', "");
Expect(0, 43744, '\p{Blk=taiviet}', "");
Expect(1, 43744, '\p{^Blk=taiviet}', "");
Expect(1, 43744, '\P{Blk=taiviet}', "");
Expect(0, 43744, '\P{^Blk=taiviet}', "");
Expect(1, 43743, '\p{Blk=_-tai_Viet}', "");
Expect(0, 43743, '\p{^Blk=_-tai_Viet}', "");
Expect(0, 43743, '\P{Blk=_-tai_Viet}', "");
Expect(1, 43743, '\P{^Blk=_-tai_Viet}', "");
Expect(0, 43744, '\p{Blk=_-tai_Viet}', "");
Expect(1, 43744, '\p{^Blk=_-tai_Viet}', "");
Expect(1, 43744, '\P{Blk=_-tai_Viet}', "");
Expect(0, 43744, '\P{^Blk=_-tai_Viet}', "");
Error('\p{Is_Block=_tai_VIET:=}');
Error('\P{Is_Block=_tai_VIET:=}');
Expect(1, 43743, '\p{Is_Block=taiviet}', "");
Expect(0, 43743, '\p{^Is_Block=taiviet}', "");
Expect(0, 43743, '\P{Is_Block=taiviet}', "");
Expect(1, 43743, '\P{^Is_Block=taiviet}', "");
Expect(0, 43744, '\p{Is_Block=taiviet}', "");
Expect(1, 43744, '\p{^Is_Block=taiviet}', "");
Expect(1, 43744, '\P{Is_Block=taiviet}', "");
Expect(0, 43744, '\P{^Is_Block=taiviet}', "");
Expect(1, 43743, '\p{Is_Block=__Tai_Viet}', "");
Expect(0, 43743, '\p{^Is_Block=__Tai_Viet}', "");
Expect(0, 43743, '\P{Is_Block=__Tai_Viet}', "");
Expect(1, 43743, '\P{^Is_Block=__Tai_Viet}', "");
Expect(0, 43744, '\p{Is_Block=__Tai_Viet}', "");
Expect(1, 43744, '\p{^Is_Block=__Tai_Viet}', "");
Expect(1, 43744, '\P{Is_Block=__Tai_Viet}', "");
Expect(0, 43744, '\P{^Is_Block=__Tai_Viet}', "");
Error('\p{Is_Blk=	/a/Tai_Viet}');
Error('\P{Is_Blk=	/a/Tai_Viet}');
Expect(1, 43743, '\p{Is_Blk=taiviet}', "");
Expect(0, 43743, '\p{^Is_Blk=taiviet}', "");
Expect(0, 43743, '\P{Is_Blk=taiviet}', "");
Expect(1, 43743, '\P{^Is_Blk=taiviet}', "");
Expect(0, 43744, '\p{Is_Blk=taiviet}', "");
Expect(1, 43744, '\p{^Is_Blk=taiviet}', "");
Expect(1, 43744, '\P{Is_Blk=taiviet}', "");
Expect(0, 43744, '\P{^Is_Blk=taiviet}', "");
Expect(1, 43743, '\p{Is_Blk=-_tai_Viet}', "");
Expect(0, 43743, '\p{^Is_Blk=-_tai_Viet}', "");
Expect(0, 43743, '\P{Is_Blk=-_tai_Viet}', "");
Expect(1, 43743, '\P{^Is_Blk=-_tai_Viet}', "");
Expect(0, 43744, '\p{Is_Blk=-_tai_Viet}', "");
Expect(1, 43744, '\p{^Is_Blk=-_tai_Viet}', "");
Expect(1, 43744, '\P{Is_Blk=-_tai_Viet}', "");
Expect(0, 43744, '\P{^Is_Blk=-_tai_Viet}', "");
Error('\p{Block=- Tai_Xuan_jing_Symbols/a/}');
Error('\P{Block=- Tai_Xuan_jing_Symbols/a/}');
Expect(1, 119647, '\p{Block:taixuanjingsymbols}', "");
Expect(0, 119647, '\p{^Block:taixuanjingsymbols}', "");
Expect(0, 119647, '\P{Block:taixuanjingsymbols}', "");
Expect(1, 119647, '\P{^Block:taixuanjingsymbols}', "");
Expect(0, 119648, '\p{Block:taixuanjingsymbols}', "");
Expect(1, 119648, '\p{^Block:taixuanjingsymbols}', "");
Expect(1, 119648, '\P{Block:taixuanjingsymbols}', "");
Expect(0, 119648, '\P{^Block:taixuanjingsymbols}', "");
Expect(1, 119647, '\p{Block=_	tai_Xuan_JING_Symbols}', "");
Expect(0, 119647, '\p{^Block=_	tai_Xuan_JING_Symbols}', "");
Expect(0, 119647, '\P{Block=_	tai_Xuan_JING_Symbols}', "");
Expect(1, 119647, '\P{^Block=_	tai_Xuan_JING_Symbols}', "");
Expect(0, 119648, '\p{Block=_	tai_Xuan_JING_Symbols}', "");
Expect(1, 119648, '\p{^Block=_	tai_Xuan_JING_Symbols}', "");
Expect(1, 119648, '\P{Block=_	tai_Xuan_JING_Symbols}', "");
Expect(0, 119648, '\P{^Block=_	tai_Xuan_JING_Symbols}', "");
Error('\p{Blk= :=Tai_Xuan_jing}');
Error('\P{Blk= :=Tai_Xuan_jing}');
Expect(1, 119647, '\p{Blk=taixuanjing}', "");
Expect(0, 119647, '\p{^Blk=taixuanjing}', "");
Expect(0, 119647, '\P{Blk=taixuanjing}', "");
Expect(1, 119647, '\P{^Blk=taixuanjing}', "");
Expect(0, 119648, '\p{Blk=taixuanjing}', "");
Expect(1, 119648, '\p{^Blk=taixuanjing}', "");
Expect(1, 119648, '\P{Blk=taixuanjing}', "");
Expect(0, 119648, '\P{^Blk=taixuanjing}', "");
Expect(1, 119647, '\p{Blk=	 tai_XUAN_Jing}', "");
Expect(0, 119647, '\p{^Blk=	 tai_XUAN_Jing}', "");
Expect(0, 119647, '\P{Blk=	 tai_XUAN_Jing}', "");
Expect(1, 119647, '\P{^Blk=	 tai_XUAN_Jing}', "");
Expect(0, 119648, '\p{Blk=	 tai_XUAN_Jing}', "");
Expect(1, 119648, '\p{^Blk=	 tai_XUAN_Jing}', "");
Expect(1, 119648, '\P{Blk=	 tai_XUAN_Jing}', "");
Expect(0, 119648, '\P{^Blk=	 tai_XUAN_Jing}', "");
Error('\p{Is_Block=/a/ tai_XUAN_jing_symbols}');
Error('\P{Is_Block=/a/ tai_XUAN_jing_symbols}');
Expect(1, 119647, '\p{Is_Block=taixuanjingsymbols}', "");
Expect(0, 119647, '\p{^Is_Block=taixuanjingsymbols}', "");
Expect(0, 119647, '\P{Is_Block=taixuanjingsymbols}', "");
Expect(1, 119647, '\P{^Is_Block=taixuanjingsymbols}', "");
Expect(0, 119648, '\p{Is_Block=taixuanjingsymbols}', "");
Expect(1, 119648, '\p{^Is_Block=taixuanjingsymbols}', "");
Expect(1, 119648, '\P{Is_Block=taixuanjingsymbols}', "");
Expect(0, 119648, '\P{^Is_Block=taixuanjingsymbols}', "");
Expect(1, 119647, '\p{Is_Block=tai_Xuan_Jing_symbols}', "");
Expect(0, 119647, '\p{^Is_Block=tai_Xuan_Jing_symbols}', "");
Expect(0, 119647, '\P{Is_Block=tai_Xuan_Jing_symbols}', "");
Expect(1, 119647, '\P{^Is_Block=tai_Xuan_Jing_symbols}', "");
Expect(0, 119648, '\p{Is_Block=tai_Xuan_Jing_symbols}', "");
Expect(1, 119648, '\p{^Is_Block=tai_Xuan_Jing_symbols}', "");
Expect(1, 119648, '\P{Is_Block=tai_Xuan_Jing_symbols}', "");
Expect(0, 119648, '\P{^Is_Block=tai_Xuan_Jing_symbols}', "");
Error('\p{Is_Blk=:= Tai_xuan_JING}');
Error('\P{Is_Blk=:= Tai_xuan_JING}');
Expect(1, 119647, '\p{Is_Blk=taixuanjing}', "");
Expect(0, 119647, '\p{^Is_Blk=taixuanjing}', "");
Expect(0, 119647, '\P{Is_Blk=taixuanjing}', "");
Expect(1, 119647, '\P{^Is_Blk=taixuanjing}', "");
Expect(0, 119648, '\p{Is_Blk=taixuanjing}', "");
Expect(1, 119648, '\p{^Is_Blk=taixuanjing}', "");
Expect(1, 119648, '\P{Is_Blk=taixuanjing}', "");
Expect(0, 119648, '\P{^Is_Blk=taixuanjing}', "");
Expect(1, 119647, '\p{Is_Blk=tai_XUAN_jing}', "");
Expect(0, 119647, '\p{^Is_Blk=tai_XUAN_jing}', "");
Expect(0, 119647, '\P{Is_Blk=tai_XUAN_jing}', "");
Expect(1, 119647, '\P{^Is_Blk=tai_XUAN_jing}', "");
Expect(0, 119648, '\p{Is_Blk=tai_XUAN_jing}', "");
Expect(1, 119648, '\p{^Is_Blk=tai_XUAN_jing}', "");
Expect(1, 119648, '\P{Is_Blk=tai_XUAN_jing}', "");
Expect(0, 119648, '\P{^Is_Blk=tai_XUAN_jing}', "");
Error('\p{Block= :=Takri}');
Error('\P{Block= :=Takri}');
Expect(1, 71375, '\p{Block=takri}', "");
Expect(0, 71375, '\p{^Block=takri}', "");
Expect(0, 71375, '\P{Block=takri}', "");
Expect(1, 71375, '\P{^Block=takri}', "");
Expect(0, 71376, '\p{Block=takri}', "");
Expect(1, 71376, '\p{^Block=takri}', "");
Expect(1, 71376, '\P{Block=takri}', "");
Expect(0, 71376, '\P{^Block=takri}', "");
Expect(1, 71375, '\p{Block= Takri}', "");
Expect(0, 71375, '\p{^Block= Takri}', "");
Expect(0, 71375, '\P{Block= Takri}', "");
Expect(1, 71375, '\P{^Block= Takri}', "");
Expect(0, 71376, '\p{Block= Takri}', "");
Expect(1, 71376, '\p{^Block= Takri}', "");
Expect(1, 71376, '\P{Block= Takri}', "");
Expect(0, 71376, '\P{^Block= Takri}', "");
Error('\p{Blk=/a/  TAKRI}');
Error('\P{Blk=/a/  TAKRI}');
Expect(1, 71375, '\p{Blk:   takri}', "");
Expect(0, 71375, '\p{^Blk:   takri}', "");
Expect(0, 71375, '\P{Blk:   takri}', "");
Expect(1, 71375, '\P{^Blk:   takri}', "");
Expect(0, 71376, '\p{Blk:   takri}', "");
Expect(1, 71376, '\p{^Blk:   takri}', "");
Expect(1, 71376, '\P{Blk:   takri}', "");
Expect(0, 71376, '\P{^Blk:   takri}', "");
Expect(1, 71375, '\p{Blk:-	Takri}', "");
Expect(0, 71375, '\p{^Blk:-	Takri}', "");
Expect(0, 71375, '\P{Blk:-	Takri}', "");
Expect(1, 71375, '\P{^Blk:-	Takri}', "");
Expect(0, 71376, '\p{Blk:-	Takri}', "");
Expect(1, 71376, '\p{^Blk:-	Takri}', "");
Expect(1, 71376, '\P{Blk:-	Takri}', "");
Expect(0, 71376, '\P{^Blk:-	Takri}', "");
Error('\p{Is_Block=:=-	Takri}');
Error('\P{Is_Block=:=-	Takri}');
Expect(1, 71375, '\p{Is_Block=takri}', "");
Expect(0, 71375, '\p{^Is_Block=takri}', "");
Expect(0, 71375, '\P{Is_Block=takri}', "");
Expect(1, 71375, '\P{^Is_Block=takri}', "");
Expect(0, 71376, '\p{Is_Block=takri}', "");
Expect(1, 71376, '\p{^Is_Block=takri}', "");
Expect(1, 71376, '\P{Is_Block=takri}', "");
Expect(0, 71376, '\P{^Is_Block=takri}', "");
Expect(1, 71375, '\p{Is_Block= Takri}', "");
Expect(0, 71375, '\p{^Is_Block= Takri}', "");
Expect(0, 71375, '\P{Is_Block= Takri}', "");
Expect(1, 71375, '\P{^Is_Block= Takri}', "");
Expect(0, 71376, '\p{Is_Block= Takri}', "");
Expect(1, 71376, '\p{^Is_Block= Takri}', "");
Expect(1, 71376, '\P{Is_Block= Takri}', "");
Expect(0, 71376, '\P{^Is_Block= Takri}', "");
Error('\p{Is_Blk=_:=Takri}');
Error('\P{Is_Blk=_:=Takri}');
Expect(1, 71375, '\p{Is_Blk: takri}', "");
Expect(0, 71375, '\p{^Is_Blk: takri}', "");
Expect(0, 71375, '\P{Is_Blk: takri}', "");
Expect(1, 71375, '\P{^Is_Blk: takri}', "");
Expect(0, 71376, '\p{Is_Blk: takri}', "");
Expect(1, 71376, '\p{^Is_Blk: takri}', "");
Expect(1, 71376, '\P{Is_Blk: takri}', "");
Expect(0, 71376, '\P{^Is_Blk: takri}', "");
Expect(1, 71375, '\p{Is_Blk:		TAKRI}', "");
Expect(0, 71375, '\p{^Is_Blk:		TAKRI}', "");
Expect(0, 71375, '\P{Is_Blk:		TAKRI}', "");
Expect(1, 71375, '\P{^Is_Blk:		TAKRI}', "");
Expect(0, 71376, '\p{Is_Blk:		TAKRI}', "");
Expect(1, 71376, '\p{^Is_Blk:		TAKRI}', "");
Expect(1, 71376, '\P{Is_Blk:		TAKRI}', "");
Expect(0, 71376, '\P{^Is_Blk:		TAKRI}', "");
Error('\p{Block=		Tamil/a/}');
Error('\P{Block=		Tamil/a/}');
Expect(1, 3071, '\p{Block=tamil}', "");
Expect(0, 3071, '\p{^Block=tamil}', "");
Expect(0, 3071, '\P{Block=tamil}', "");
Expect(1, 3071, '\P{^Block=tamil}', "");
Expect(0, 3072, '\p{Block=tamil}', "");
Expect(1, 3072, '\p{^Block=tamil}', "");
Expect(1, 3072, '\P{Block=tamil}', "");
Expect(0, 3072, '\P{^Block=tamil}', "");
Expect(1, 3071, '\p{Block=_ TAMIL}', "");
Expect(0, 3071, '\p{^Block=_ TAMIL}', "");
Expect(0, 3071, '\P{Block=_ TAMIL}', "");
Expect(1, 3071, '\P{^Block=_ TAMIL}', "");
Expect(0, 3072, '\p{Block=_ TAMIL}', "");
Expect(1, 3072, '\p{^Block=_ TAMIL}', "");
Expect(1, 3072, '\P{Block=_ TAMIL}', "");
Expect(0, 3072, '\P{^Block=_ TAMIL}', "");
Error('\p{Blk=/a/-tamil}');
Error('\P{Blk=/a/-tamil}');
Expect(1, 3071, '\p{Blk:	tamil}', "");
Expect(0, 3071, '\p{^Blk:	tamil}', "");
Expect(0, 3071, '\P{Blk:	tamil}', "");
Expect(1, 3071, '\P{^Blk:	tamil}', "");
Expect(0, 3072, '\p{Blk:	tamil}', "");
Expect(1, 3072, '\p{^Blk:	tamil}', "");
Expect(1, 3072, '\P{Blk:	tamil}', "");
Expect(0, 3072, '\P{^Blk:	tamil}', "");
Expect(1, 3071, '\p{Blk=_TAMIL}', "");
Expect(0, 3071, '\p{^Blk=_TAMIL}', "");
Expect(0, 3071, '\P{Blk=_TAMIL}', "");
Expect(1, 3071, '\P{^Blk=_TAMIL}', "");
Expect(0, 3072, '\p{Blk=_TAMIL}', "");
Expect(1, 3072, '\p{^Blk=_TAMIL}', "");
Expect(1, 3072, '\P{Blk=_TAMIL}', "");
Expect(0, 3072, '\P{^Blk=_TAMIL}', "");
Error('\p{Is_Block=_:=Tamil}');
Error('\P{Is_Block=_:=Tamil}');
Expect(1, 3071, '\p{Is_Block=tamil}', "");
Expect(0, 3071, '\p{^Is_Block=tamil}', "");
Expect(0, 3071, '\P{Is_Block=tamil}', "");
Expect(1, 3071, '\P{^Is_Block=tamil}', "");
Expect(0, 3072, '\p{Is_Block=tamil}', "");
Expect(1, 3072, '\p{^Is_Block=tamil}', "");
Expect(1, 3072, '\P{Is_Block=tamil}', "");
Expect(0, 3072, '\P{^Is_Block=tamil}', "");
Expect(1, 3071, '\p{Is_Block= 	TAMIL}', "");
Expect(0, 3071, '\p{^Is_Block= 	TAMIL}', "");
Expect(0, 3071, '\P{Is_Block= 	TAMIL}', "");
Expect(1, 3071, '\P{^Is_Block= 	TAMIL}', "");
Expect(0, 3072, '\p{Is_Block= 	TAMIL}', "");
Expect(1, 3072, '\p{^Is_Block= 	TAMIL}', "");
Expect(1, 3072, '\P{Is_Block= 	TAMIL}', "");
Expect(0, 3072, '\P{^Is_Block= 	TAMIL}', "");
Error('\p{Is_Blk= tamil/a/}');
Error('\P{Is_Blk= tamil/a/}');
Expect(1, 3071, '\p{Is_Blk=tamil}', "");
Expect(0, 3071, '\p{^Is_Blk=tamil}', "");
Expect(0, 3071, '\P{Is_Blk=tamil}', "");
Expect(1, 3071, '\P{^Is_Blk=tamil}', "");
Expect(0, 3072, '\p{Is_Blk=tamil}', "");
Expect(1, 3072, '\p{^Is_Blk=tamil}', "");
Expect(1, 3072, '\P{Is_Blk=tamil}', "");
Expect(0, 3072, '\P{^Is_Blk=tamil}', "");
Expect(1, 3071, '\p{Is_Blk= Tamil}', "");
Expect(0, 3071, '\p{^Is_Blk= Tamil}', "");
Expect(0, 3071, '\P{Is_Blk= Tamil}', "");
Expect(1, 3071, '\P{^Is_Blk= Tamil}', "");
Expect(0, 3072, '\p{Is_Blk= Tamil}', "");
Expect(1, 3072, '\p{^Is_Blk= Tamil}', "");
Expect(1, 3072, '\P{Is_Blk= Tamil}', "");
Expect(0, 3072, '\P{^Is_Blk= Tamil}', "");
Error('\p{Block=/a/_telugu}');
Error('\P{Block=/a/_telugu}');
Expect(1, 3199, '\p{Block:   telugu}', "");
Expect(0, 3199, '\p{^Block:   telugu}', "");
Expect(0, 3199, '\P{Block:   telugu}', "");
Expect(1, 3199, '\P{^Block:   telugu}', "");
Expect(0, 3200, '\p{Block:   telugu}', "");
Expect(1, 3200, '\p{^Block:   telugu}', "");
Expect(1, 3200, '\P{Block:   telugu}', "");
Expect(0, 3200, '\P{^Block:   telugu}', "");
Expect(1, 3199, '\p{Block=-_Telugu}', "");
Expect(0, 3199, '\p{^Block=-_Telugu}', "");
Expect(0, 3199, '\P{Block=-_Telugu}', "");
Expect(1, 3199, '\P{^Block=-_Telugu}', "");
Expect(0, 3200, '\p{Block=-_Telugu}', "");
Expect(1, 3200, '\p{^Block=-_Telugu}', "");
Expect(1, 3200, '\P{Block=-_Telugu}', "");
Expect(0, 3200, '\P{^Block=-_Telugu}', "");
Error('\p{Blk=	TELUGU:=}');
Error('\P{Blk=	TELUGU:=}');
Expect(1, 3199, '\p{Blk=telugu}', "");
Expect(0, 3199, '\p{^Blk=telugu}', "");
Expect(0, 3199, '\P{Blk=telugu}', "");
Expect(1, 3199, '\P{^Blk=telugu}', "");
Expect(0, 3200, '\p{Blk=telugu}', "");
Expect(1, 3200, '\p{^Blk=telugu}', "");
Expect(1, 3200, '\P{Blk=telugu}', "");
Expect(0, 3200, '\P{^Blk=telugu}', "");
Expect(1, 3199, '\p{Blk=_	TELUGU}', "");
Expect(0, 3199, '\p{^Blk=_	TELUGU}', "");
Expect(0, 3199, '\P{Blk=_	TELUGU}', "");
Expect(1, 3199, '\P{^Blk=_	TELUGU}', "");
Expect(0, 3200, '\p{Blk=_	TELUGU}', "");
Expect(1, 3200, '\p{^Blk=_	TELUGU}', "");
Expect(1, 3200, '\P{Blk=_	TELUGU}', "");
Expect(0, 3200, '\P{^Blk=_	TELUGU}', "");
Error('\p{Is_Block=/a/-Telugu}');
Error('\P{Is_Block=/a/-Telugu}');
Expect(1, 3199, '\p{Is_Block=telugu}', "");
Expect(0, 3199, '\p{^Is_Block=telugu}', "");
Expect(0, 3199, '\P{Is_Block=telugu}', "");
Expect(1, 3199, '\P{^Is_Block=telugu}', "");
Expect(0, 3200, '\p{Is_Block=telugu}', "");
Expect(1, 3200, '\p{^Is_Block=telugu}', "");
Expect(1, 3200, '\P{Is_Block=telugu}', "");
Expect(0, 3200, '\P{^Is_Block=telugu}', "");
Expect(1, 3199, '\p{Is_Block=_-telugu}', "");
Expect(0, 3199, '\p{^Is_Block=_-telugu}', "");
Expect(0, 3199, '\P{Is_Block=_-telugu}', "");
Expect(1, 3199, '\P{^Is_Block=_-telugu}', "");
Expect(0, 3200, '\p{Is_Block=_-telugu}', "");
Expect(1, 3200, '\p{^Is_Block=_-telugu}', "");
Expect(1, 3200, '\P{Is_Block=_-telugu}', "");
Expect(0, 3200, '\P{^Is_Block=_-telugu}', "");
Error('\p{Is_Blk= -telugu/a/}');
Error('\P{Is_Blk= -telugu/a/}');
Expect(1, 3199, '\p{Is_Blk=telugu}', "");
Expect(0, 3199, '\p{^Is_Blk=telugu}', "");
Expect(0, 3199, '\P{Is_Blk=telugu}', "");
Expect(1, 3199, '\P{^Is_Blk=telugu}', "");
Expect(0, 3200, '\p{Is_Blk=telugu}', "");
Expect(1, 3200, '\p{^Is_Blk=telugu}', "");
Expect(1, 3200, '\P{Is_Blk=telugu}', "");
Expect(0, 3200, '\P{^Is_Blk=telugu}', "");
Expect(1, 3199, '\p{Is_Blk=_Telugu}', "");
Expect(0, 3199, '\p{^Is_Blk=_Telugu}', "");
Expect(0, 3199, '\P{Is_Blk=_Telugu}', "");
Expect(1, 3199, '\P{^Is_Blk=_Telugu}', "");
Expect(0, 3200, '\p{Is_Blk=_Telugu}', "");
Expect(1, 3200, '\p{^Is_Blk=_Telugu}', "");
Expect(1, 3200, '\P{Is_Blk=_Telugu}', "");
Expect(0, 3200, '\P{^Is_Blk=_Telugu}', "");
Error('\p{Block= :=thaana}');
Error('\P{Block= :=thaana}');
Expect(1, 1983, '\p{Block=thaana}', "");
Expect(0, 1983, '\p{^Block=thaana}', "");
Expect(0, 1983, '\P{Block=thaana}', "");
Expect(1, 1983, '\P{^Block=thaana}', "");
Expect(0, 1984, '\p{Block=thaana}', "");
Expect(1, 1984, '\p{^Block=thaana}', "");
Expect(1, 1984, '\P{Block=thaana}', "");
Expect(0, 1984, '\P{^Block=thaana}', "");
Expect(1, 1983, '\p{Block= _Thaana}', "");
Expect(0, 1983, '\p{^Block= _Thaana}', "");
Expect(0, 1983, '\P{Block= _Thaana}', "");
Expect(1, 1983, '\P{^Block= _Thaana}', "");
Expect(0, 1984, '\p{Block= _Thaana}', "");
Expect(1, 1984, '\p{^Block= _Thaana}', "");
Expect(1, 1984, '\P{Block= _Thaana}', "");
Expect(0, 1984, '\P{^Block= _Thaana}', "");
Error('\p{Blk=:=	_Thaana}');
Error('\P{Blk=:=	_Thaana}');
Expect(1, 1983, '\p{Blk=thaana}', "");
Expect(0, 1983, '\p{^Blk=thaana}', "");
Expect(0, 1983, '\P{Blk=thaana}', "");
Expect(1, 1983, '\P{^Blk=thaana}', "");
Expect(0, 1984, '\p{Blk=thaana}', "");
Expect(1, 1984, '\p{^Blk=thaana}', "");
Expect(1, 1984, '\P{Blk=thaana}', "");
Expect(0, 1984, '\P{^Blk=thaana}', "");
Expect(1, 1983, '\p{Blk=_	thaana}', "");
Expect(0, 1983, '\p{^Blk=_	thaana}', "");
Expect(0, 1983, '\P{Blk=_	thaana}', "");
Expect(1, 1983, '\P{^Blk=_	thaana}', "");
Expect(0, 1984, '\p{Blk=_	thaana}', "");
Expect(1, 1984, '\p{^Blk=_	thaana}', "");
Expect(1, 1984, '\P{Blk=_	thaana}', "");
Expect(0, 1984, '\P{^Blk=_	thaana}', "");
Error('\p{Is_Block= thaana:=}');
Error('\P{Is_Block= thaana:=}');
Expect(1, 1983, '\p{Is_Block=thaana}', "");
Expect(0, 1983, '\p{^Is_Block=thaana}', "");
Expect(0, 1983, '\P{Is_Block=thaana}', "");
Expect(1, 1983, '\P{^Is_Block=thaana}', "");
Expect(0, 1984, '\p{Is_Block=thaana}', "");
Expect(1, 1984, '\p{^Is_Block=thaana}', "");
Expect(1, 1984, '\P{Is_Block=thaana}', "");
Expect(0, 1984, '\P{^Is_Block=thaana}', "");
Expect(1, 1983, '\p{Is_Block:  	Thaana}', "");
Expect(0, 1983, '\p{^Is_Block:  	Thaana}', "");
Expect(0, 1983, '\P{Is_Block:  	Thaana}', "");
Expect(1, 1983, '\P{^Is_Block:  	Thaana}', "");
Expect(0, 1984, '\p{Is_Block:  	Thaana}', "");
Expect(1, 1984, '\p{^Is_Block:  	Thaana}', "");
Expect(1, 1984, '\P{Is_Block:  	Thaana}', "");
Expect(0, 1984, '\P{^Is_Block:  	Thaana}', "");
Error('\p{Is_Blk=-_Thaana/a/}');
Error('\P{Is_Blk=-_Thaana/a/}');
Expect(1, 1983, '\p{Is_Blk=thaana}', "");
Expect(0, 1983, '\p{^Is_Blk=thaana}', "");
Expect(0, 1983, '\P{Is_Blk=thaana}', "");
Expect(1, 1983, '\P{^Is_Blk=thaana}', "");
Expect(0, 1984, '\p{Is_Blk=thaana}', "");
Expect(1, 1984, '\p{^Is_Blk=thaana}', "");
Expect(1, 1984, '\P{Is_Blk=thaana}', "");
Expect(0, 1984, '\P{^Is_Blk=thaana}', "");
Expect(1, 1983, '\p{Is_Blk= 	thaana}', "");
Expect(0, 1983, '\p{^Is_Blk= 	thaana}', "");
Expect(0, 1983, '\P{Is_Blk= 	thaana}', "");
Expect(1, 1983, '\P{^Is_Blk= 	thaana}', "");
Expect(0, 1984, '\p{Is_Blk= 	thaana}', "");
Expect(1, 1984, '\p{^Is_Blk= 	thaana}', "");
Expect(1, 1984, '\P{Is_Blk= 	thaana}', "");
Expect(0, 1984, '\P{^Is_Blk= 	thaana}', "");
Error('\p{Block=_:=Thai}');
Error('\P{Block=_:=Thai}');
Expect(1, 3711, '\p{Block=thai}', "");
Expect(0, 3711, '\p{^Block=thai}', "");
Expect(0, 3711, '\P{Block=thai}', "");
Expect(1, 3711, '\P{^Block=thai}', "");
Expect(0, 3712, '\p{Block=thai}', "");
Expect(1, 3712, '\p{^Block=thai}', "");
Expect(1, 3712, '\P{Block=thai}', "");
Expect(0, 3712, '\P{^Block=thai}', "");
Expect(1, 3711, '\p{Block:   	thai}', "");
Expect(0, 3711, '\p{^Block:   	thai}', "");
Expect(0, 3711, '\P{Block:   	thai}', "");
Expect(1, 3711, '\P{^Block:   	thai}', "");
Expect(0, 3712, '\p{Block:   	thai}', "");
Expect(1, 3712, '\p{^Block:   	thai}', "");
Expect(1, 3712, '\P{Block:   	thai}', "");
Expect(0, 3712, '\P{^Block:   	thai}', "");
Error('\p{Blk=-/a/THAI}');
Error('\P{Blk=-/a/THAI}');
Expect(1, 3711, '\p{Blk=thai}', "");
Expect(0, 3711, '\p{^Blk=thai}', "");
Expect(0, 3711, '\P{Blk=thai}', "");
Expect(1, 3711, '\P{^Blk=thai}', "");
Expect(0, 3712, '\p{Blk=thai}', "");
Expect(1, 3712, '\p{^Blk=thai}', "");
Expect(1, 3712, '\P{Blk=thai}', "");
Expect(0, 3712, '\P{^Blk=thai}', "");
Expect(1, 3711, '\p{Blk=_Thai}', "");
Expect(0, 3711, '\p{^Blk=_Thai}', "");
Expect(0, 3711, '\P{Blk=_Thai}', "");
Expect(1, 3711, '\P{^Blk=_Thai}', "");
Expect(0, 3712, '\p{Blk=_Thai}', "");
Expect(1, 3712, '\p{^Blk=_Thai}', "");
Expect(1, 3712, '\P{Blk=_Thai}', "");
Expect(0, 3712, '\P{^Blk=_Thai}', "");
Error('\p{Is_Block::=__THAI}');
Error('\P{Is_Block::=__THAI}');
Expect(1, 3711, '\p{Is_Block=thai}', "");
Expect(0, 3711, '\p{^Is_Block=thai}', "");
Expect(0, 3711, '\P{Is_Block=thai}', "");
Expect(1, 3711, '\P{^Is_Block=thai}', "");
Expect(0, 3712, '\p{Is_Block=thai}', "");
Expect(1, 3712, '\p{^Is_Block=thai}', "");
Expect(1, 3712, '\P{Is_Block=thai}', "");
Expect(0, 3712, '\P{^Is_Block=thai}', "");
Expect(1, 3711, '\p{Is_Block:     thai}', "");
Expect(0, 3711, '\p{^Is_Block:     thai}', "");
Expect(0, 3711, '\P{Is_Block:     thai}', "");
Expect(1, 3711, '\P{^Is_Block:     thai}', "");
Expect(0, 3712, '\p{Is_Block:     thai}', "");
Expect(1, 3712, '\p{^Is_Block:     thai}', "");
Expect(1, 3712, '\P{Is_Block:     thai}', "");
Expect(0, 3712, '\P{^Is_Block:     thai}', "");
Error('\p{Is_Blk=		Thai:=}');
Error('\P{Is_Blk=		Thai:=}');
Expect(1, 3711, '\p{Is_Blk=thai}', "");
Expect(0, 3711, '\p{^Is_Blk=thai}', "");
Expect(0, 3711, '\P{Is_Blk=thai}', "");
Expect(1, 3711, '\P{^Is_Blk=thai}', "");
Expect(0, 3712, '\p{Is_Blk=thai}', "");
Expect(1, 3712, '\p{^Is_Blk=thai}', "");
Expect(1, 3712, '\P{Is_Blk=thai}', "");
Expect(0, 3712, '\P{^Is_Blk=thai}', "");
Expect(1, 3711, '\p{Is_Blk: _Thai}', "");
Expect(0, 3711, '\p{^Is_Blk: _Thai}', "");
Expect(0, 3711, '\P{Is_Blk: _Thai}', "");
Expect(1, 3711, '\P{^Is_Blk: _Thai}', "");
Expect(0, 3712, '\p{Is_Blk: _Thai}', "");
Expect(1, 3712, '\p{^Is_Blk: _Thai}', "");
Expect(1, 3712, '\P{Is_Blk: _Thai}', "");
Expect(0, 3712, '\P{^Is_Blk: _Thai}', "");
Error('\p{Block=TIBETAN:=}');
Error('\P{Block=TIBETAN:=}');
Expect(1, 4095, '\p{Block=tibetan}', "");
Expect(0, 4095, '\p{^Block=tibetan}', "");
Expect(0, 4095, '\P{Block=tibetan}', "");
Expect(1, 4095, '\P{^Block=tibetan}', "");
Expect(0, 4096, '\p{Block=tibetan}', "");
Expect(1, 4096, '\p{^Block=tibetan}', "");
Expect(1, 4096, '\P{Block=tibetan}', "");
Expect(0, 4096, '\P{^Block=tibetan}', "");
Expect(1, 4095, '\p{Block=	 Tibetan}', "");
Expect(0, 4095, '\p{^Block=	 Tibetan}', "");
Expect(0, 4095, '\P{Block=	 Tibetan}', "");
Expect(1, 4095, '\P{^Block=	 Tibetan}', "");
Expect(0, 4096, '\p{Block=	 Tibetan}', "");
Expect(1, 4096, '\p{^Block=	 Tibetan}', "");
Expect(1, 4096, '\P{Block=	 Tibetan}', "");
Expect(0, 4096, '\P{^Block=	 Tibetan}', "");
Error('\p{Blk=	-Tibetan:=}');
Error('\P{Blk=	-Tibetan:=}');
Expect(1, 4095, '\p{Blk=tibetan}', "");
Expect(0, 4095, '\p{^Blk=tibetan}', "");
Expect(0, 4095, '\P{Blk=tibetan}', "");
Expect(1, 4095, '\P{^Blk=tibetan}', "");
Expect(0, 4096, '\p{Blk=tibetan}', "");
Expect(1, 4096, '\p{^Blk=tibetan}', "");
Expect(1, 4096, '\P{Blk=tibetan}', "");
Expect(0, 4096, '\P{^Blk=tibetan}', "");
Expect(1, 4095, '\p{Blk=-TIBETAN}', "");
Expect(0, 4095, '\p{^Blk=-TIBETAN}', "");
Expect(0, 4095, '\P{Blk=-TIBETAN}', "");
Expect(1, 4095, '\P{^Blk=-TIBETAN}', "");
Expect(0, 4096, '\p{Blk=-TIBETAN}', "");
Expect(1, 4096, '\p{^Blk=-TIBETAN}', "");
Expect(1, 4096, '\P{Blk=-TIBETAN}', "");
Expect(0, 4096, '\P{^Blk=-TIBETAN}', "");
Error('\p{Is_Block=_	TIBETAN/a/}');
Error('\P{Is_Block=_	TIBETAN/a/}');
Expect(1, 4095, '\p{Is_Block=tibetan}', "");
Expect(0, 4095, '\p{^Is_Block=tibetan}', "");
Expect(0, 4095, '\P{Is_Block=tibetan}', "");
Expect(1, 4095, '\P{^Is_Block=tibetan}', "");
Expect(0, 4096, '\p{Is_Block=tibetan}', "");
Expect(1, 4096, '\p{^Is_Block=tibetan}', "");
Expect(1, 4096, '\P{Is_Block=tibetan}', "");
Expect(0, 4096, '\P{^Is_Block=tibetan}', "");
Expect(1, 4095, '\p{Is_Block=-Tibetan}', "");
Expect(0, 4095, '\p{^Is_Block=-Tibetan}', "");
Expect(0, 4095, '\P{Is_Block=-Tibetan}', "");
Expect(1, 4095, '\P{^Is_Block=-Tibetan}', "");
Expect(0, 4096, '\p{Is_Block=-Tibetan}', "");
Expect(1, 4096, '\p{^Is_Block=-Tibetan}', "");
Expect(1, 4096, '\P{Is_Block=-Tibetan}', "");
Expect(0, 4096, '\P{^Is_Block=-Tibetan}', "");
Error('\p{Is_Blk=/a/-	tibetan}');
Error('\P{Is_Blk=/a/-	tibetan}');
Expect(1, 4095, '\p{Is_Blk=tibetan}', "");
Expect(0, 4095, '\p{^Is_Blk=tibetan}', "");
Expect(0, 4095, '\P{Is_Blk=tibetan}', "");
Expect(1, 4095, '\P{^Is_Blk=tibetan}', "");
Expect(0, 4096, '\p{Is_Blk=tibetan}', "");
Expect(1, 4096, '\p{^Is_Blk=tibetan}', "");
Expect(1, 4096, '\P{Is_Blk=tibetan}', "");
Expect(0, 4096, '\P{^Is_Blk=tibetan}', "");
Expect(1, 4095, '\p{Is_Blk=	 Tibetan}', "");
Expect(0, 4095, '\p{^Is_Blk=	 Tibetan}', "");
Expect(0, 4095, '\P{Is_Blk=	 Tibetan}', "");
Expect(1, 4095, '\P{^Is_Blk=	 Tibetan}', "");
Expect(0, 4096, '\p{Is_Blk=	 Tibetan}', "");
Expect(1, 4096, '\p{^Is_Blk=	 Tibetan}', "");
Expect(1, 4096, '\P{Is_Blk=	 Tibetan}', "");
Expect(0, 4096, '\P{^Is_Blk=	 Tibetan}', "");
Error('\p{Block=/a/	 Tifinagh}');
Error('\P{Block=/a/	 Tifinagh}');
Expect(1, 11647, '\p{Block=tifinagh}', "");
Expect(0, 11647, '\p{^Block=tifinagh}', "");
Expect(0, 11647, '\P{Block=tifinagh}', "");
Expect(1, 11647, '\P{^Block=tifinagh}', "");
Expect(0, 11648, '\p{Block=tifinagh}', "");
Expect(1, 11648, '\p{^Block=tifinagh}', "");
Expect(1, 11648, '\P{Block=tifinagh}', "");
Expect(0, 11648, '\P{^Block=tifinagh}', "");
Expect(1, 11647, '\p{Block:   _	Tifinagh}', "");
Expect(0, 11647, '\p{^Block:   _	Tifinagh}', "");
Expect(0, 11647, '\P{Block:   _	Tifinagh}', "");
Expect(1, 11647, '\P{^Block:   _	Tifinagh}', "");
Expect(0, 11648, '\p{Block:   _	Tifinagh}', "");
Expect(1, 11648, '\p{^Block:   _	Tifinagh}', "");
Expect(1, 11648, '\P{Block:   _	Tifinagh}', "");
Expect(0, 11648, '\P{^Block:   _	Tifinagh}', "");
Error('\p{Blk:-	TIFINAGH:=}');
Error('\P{Blk:-	TIFINAGH:=}');
Expect(1, 11647, '\p{Blk=tifinagh}', "");
Expect(0, 11647, '\p{^Blk=tifinagh}', "");
Expect(0, 11647, '\P{Blk=tifinagh}', "");
Expect(1, 11647, '\P{^Blk=tifinagh}', "");
Expect(0, 11648, '\p{Blk=tifinagh}', "");
Expect(1, 11648, '\p{^Blk=tifinagh}', "");
Expect(1, 11648, '\P{Blk=tifinagh}', "");
Expect(0, 11648, '\P{^Blk=tifinagh}', "");
Expect(1, 11647, '\p{Blk=_Tifinagh}', "");
Expect(0, 11647, '\p{^Blk=_Tifinagh}', "");
Expect(0, 11647, '\P{Blk=_Tifinagh}', "");
Expect(1, 11647, '\P{^Blk=_Tifinagh}', "");
Expect(0, 11648, '\p{Blk=_Tifinagh}', "");
Expect(1, 11648, '\p{^Blk=_Tifinagh}', "");
Expect(1, 11648, '\P{Blk=_Tifinagh}', "");
Expect(0, 11648, '\P{^Blk=_Tifinagh}', "");
Error('\p{Is_Block=:=		tifinagh}');
Error('\P{Is_Block=:=		tifinagh}');
Expect(1, 11647, '\p{Is_Block:tifinagh}', "");
Expect(0, 11647, '\p{^Is_Block:tifinagh}', "");
Expect(0, 11647, '\P{Is_Block:tifinagh}', "");
Expect(1, 11647, '\P{^Is_Block:tifinagh}', "");
Expect(0, 11648, '\p{Is_Block:tifinagh}', "");
Expect(1, 11648, '\p{^Is_Block:tifinagh}', "");
Expect(1, 11648, '\P{Is_Block:tifinagh}', "");
Expect(0, 11648, '\P{^Is_Block:tifinagh}', "");
Expect(1, 11647, '\p{Is_Block=	 Tifinagh}', "");
Expect(0, 11647, '\p{^Is_Block=	 Tifinagh}', "");
Expect(0, 11647, '\P{Is_Block=	 Tifinagh}', "");
Expect(1, 11647, '\P{^Is_Block=	 Tifinagh}', "");
Expect(0, 11648, '\p{Is_Block=	 Tifinagh}', "");
Expect(1, 11648, '\p{^Is_Block=	 Tifinagh}', "");
Expect(1, 11648, '\P{Is_Block=	 Tifinagh}', "");
Expect(0, 11648, '\P{^Is_Block=	 Tifinagh}', "");
Error('\p{Is_Blk=_ TIFINAGH/a/}');
Error('\P{Is_Blk=_ TIFINAGH/a/}');
Expect(1, 11647, '\p{Is_Blk: tifinagh}', "");
Expect(0, 11647, '\p{^Is_Blk: tifinagh}', "");
Expect(0, 11647, '\P{Is_Blk: tifinagh}', "");
Expect(1, 11647, '\P{^Is_Blk: tifinagh}', "");
Expect(0, 11648, '\p{Is_Blk: tifinagh}', "");
Expect(1, 11648, '\p{^Is_Blk: tifinagh}', "");
Expect(1, 11648, '\P{Is_Blk: tifinagh}', "");
Expect(0, 11648, '\P{^Is_Blk: tifinagh}', "");
Expect(1, 11647, '\p{Is_Blk=_	Tifinagh}', "");
Expect(0, 11647, '\p{^Is_Blk=_	Tifinagh}', "");
Expect(0, 11647, '\P{Is_Blk=_	Tifinagh}', "");
Expect(1, 11647, '\P{^Is_Blk=_	Tifinagh}', "");
Expect(0, 11648, '\p{Is_Blk=_	Tifinagh}', "");
Expect(1, 11648, '\p{^Is_Blk=_	Tifinagh}', "");
Expect(1, 11648, '\P{Is_Blk=_	Tifinagh}', "");
Expect(0, 11648, '\P{^Is_Blk=_	Tifinagh}', "");
Error('\p{Block:   := TRANSPORT_And_MAP_Symbols}');
Error('\P{Block:   := TRANSPORT_And_MAP_Symbols}');
Expect(1, 128767, '\p{Block=transportandmapsymbols}', "");
Expect(0, 128767, '\p{^Block=transportandmapsymbols}', "");
Expect(0, 128767, '\P{Block=transportandmapsymbols}', "");
Expect(1, 128767, '\P{^Block=transportandmapsymbols}', "");
Expect(0, 128768, '\p{Block=transportandmapsymbols}', "");
Expect(1, 128768, '\p{^Block=transportandmapsymbols}', "");
Expect(1, 128768, '\P{Block=transportandmapsymbols}', "");
Expect(0, 128768, '\P{^Block=transportandmapsymbols}', "");
Expect(1, 128767, '\p{Block= -transport_AND_map_symbols}', "");
Expect(0, 128767, '\p{^Block= -transport_AND_map_symbols}', "");
Expect(0, 128767, '\P{Block= -transport_AND_map_symbols}', "");
Expect(1, 128767, '\P{^Block= -transport_AND_map_symbols}', "");
Expect(0, 128768, '\p{Block= -transport_AND_map_symbols}', "");
Expect(1, 128768, '\p{^Block= -transport_AND_map_symbols}', "");
Expect(1, 128768, '\P{Block= -transport_AND_map_symbols}', "");
Expect(0, 128768, '\P{^Block= -transport_AND_map_symbols}', "");
Error('\p{Blk=:=--TRANSPORT_AND_map}');
Error('\P{Blk=:=--TRANSPORT_AND_map}');
Expect(1, 128767, '\p{Blk=transportandmap}', "");
Expect(0, 128767, '\p{^Blk=transportandmap}', "");
Expect(0, 128767, '\P{Blk=transportandmap}', "");
Expect(1, 128767, '\P{^Blk=transportandmap}', "");
Expect(0, 128768, '\p{Blk=transportandmap}', "");
Expect(1, 128768, '\p{^Blk=transportandmap}', "");
Expect(1, 128768, '\P{Blk=transportandmap}', "");
Expect(0, 128768, '\P{^Blk=transportandmap}', "");
Expect(1, 128767, '\p{Blk=_	TRANSPORT_AND_Map}', "");
Expect(0, 128767, '\p{^Blk=_	TRANSPORT_AND_Map}', "");
Expect(0, 128767, '\P{Blk=_	TRANSPORT_AND_Map}', "");
Expect(1, 128767, '\P{^Blk=_	TRANSPORT_AND_Map}', "");
Expect(0, 128768, '\p{Blk=_	TRANSPORT_AND_Map}', "");
Expect(1, 128768, '\p{^Blk=_	TRANSPORT_AND_Map}', "");
Expect(1, 128768, '\P{Blk=_	TRANSPORT_AND_Map}', "");
Expect(0, 128768, '\P{^Blk=_	TRANSPORT_AND_Map}', "");
Error('\p{Is_Block=/a/	-transport_AND_Map_SYMBOLS}');
Error('\P{Is_Block=/a/	-transport_AND_Map_SYMBOLS}');
Expect(1, 128767, '\p{Is_Block=transportandmapsymbols}', "");
Expect(0, 128767, '\p{^Is_Block=transportandmapsymbols}', "");
Expect(0, 128767, '\P{Is_Block=transportandmapsymbols}', "");
Expect(1, 128767, '\P{^Is_Block=transportandmapsymbols}', "");
Expect(0, 128768, '\p{Is_Block=transportandmapsymbols}', "");
Expect(1, 128768, '\p{^Is_Block=transportandmapsymbols}', "");
Expect(1, 128768, '\P{Is_Block=transportandmapsymbols}', "");
Expect(0, 128768, '\P{^Is_Block=transportandmapsymbols}', "");
Expect(1, 128767, '\p{Is_Block=	_transport_And_Map_SYMBOLS}', "");
Expect(0, 128767, '\p{^Is_Block=	_transport_And_Map_SYMBOLS}', "");
Expect(0, 128767, '\P{Is_Block=	_transport_And_Map_SYMBOLS}', "");
Expect(1, 128767, '\P{^Is_Block=	_transport_And_Map_SYMBOLS}', "");
Expect(0, 128768, '\p{Is_Block=	_transport_And_Map_SYMBOLS}', "");
Expect(1, 128768, '\p{^Is_Block=	_transport_And_Map_SYMBOLS}', "");
Expect(1, 128768, '\P{Is_Block=	_transport_And_Map_SYMBOLS}', "");
Expect(0, 128768, '\P{^Is_Block=	_transport_And_Map_SYMBOLS}', "");
Error('\p{Is_Blk=_/a/Transport_And_Map}');
Error('\P{Is_Blk=_/a/Transport_And_Map}');
Expect(1, 128767, '\p{Is_Blk=transportandmap}', "");
Expect(0, 128767, '\p{^Is_Blk=transportandmap}', "");
Expect(0, 128767, '\P{Is_Blk=transportandmap}', "");
Expect(1, 128767, '\P{^Is_Blk=transportandmap}', "");
Expect(0, 128768, '\p{Is_Blk=transportandmap}', "");
Expect(1, 128768, '\p{^Is_Blk=transportandmap}', "");
Expect(1, 128768, '\P{Is_Blk=transportandmap}', "");
Expect(0, 128768, '\P{^Is_Blk=transportandmap}', "");
Expect(1, 128767, '\p{Is_Blk=-_Transport_And_Map}', "");
Expect(0, 128767, '\p{^Is_Blk=-_Transport_And_Map}', "");
Expect(0, 128767, '\P{Is_Blk=-_Transport_And_Map}', "");
Expect(1, 128767, '\P{^Is_Blk=-_Transport_And_Map}', "");
Expect(0, 128768, '\p{Is_Blk=-_Transport_And_Map}', "");
Expect(1, 128768, '\p{^Is_Blk=-_Transport_And_Map}', "");
Expect(1, 128768, '\P{Is_Blk=-_Transport_And_Map}', "");
Expect(0, 128768, '\P{^Is_Blk=-_Transport_And_Map}', "");
Error('\p{Block=:=-unified_Canadian_aboriginal_Syllabics}');
Error('\P{Block=:=-unified_Canadian_aboriginal_Syllabics}');
Expect(1, 5759, '\p{Block=unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\p{^Block=unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\P{Block=unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\P{^Block=unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\p{Block=unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\p{^Block=unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\P{Block=unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\P{^Block=unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\p{Block= -Unified_Canadian_Aboriginal_Syllabics}', "");
Expect(0, 5759, '\p{^Block= -Unified_Canadian_Aboriginal_Syllabics}', "");
Expect(0, 5759, '\P{Block= -Unified_Canadian_Aboriginal_Syllabics}', "");
Expect(1, 5759, '\P{^Block= -Unified_Canadian_Aboriginal_Syllabics}', "");
Expect(0, 5760, '\p{Block= -Unified_Canadian_Aboriginal_Syllabics}', "");
Expect(1, 5760, '\p{^Block= -Unified_Canadian_Aboriginal_Syllabics}', "");
Expect(1, 5760, '\P{Block= -Unified_Canadian_Aboriginal_Syllabics}', "");
Expect(0, 5760, '\P{^Block= -Unified_Canadian_Aboriginal_Syllabics}', "");
Error('\p{Blk=:=	UCAS}');
Error('\P{Blk=:=	UCAS}');
Expect(1, 5759, '\p{Blk=ucas}', "");
Expect(0, 5759, '\p{^Blk=ucas}', "");
Expect(0, 5759, '\P{Blk=ucas}', "");
Expect(1, 5759, '\P{^Blk=ucas}', "");
Expect(0, 5760, '\p{Blk=ucas}', "");
Expect(1, 5760, '\p{^Blk=ucas}', "");
Expect(1, 5760, '\P{Blk=ucas}', "");
Expect(0, 5760, '\P{^Blk=ucas}', "");
Expect(1, 5759, '\p{Blk=-_UCAS}', "");
Expect(0, 5759, '\p{^Blk=-_UCAS}', "");
Expect(0, 5759, '\P{Blk=-_UCAS}', "");
Expect(1, 5759, '\P{^Blk=-_UCAS}', "");
Expect(0, 5760, '\p{Blk=-_UCAS}', "");
Expect(1, 5760, '\p{^Blk=-_UCAS}', "");
Expect(1, 5760, '\P{Blk=-_UCAS}', "");
Expect(0, 5760, '\P{^Blk=-_UCAS}', "");
Error('\p{Is_Block=/a/-	canadian_syllabics}');
Error('\P{Is_Block=/a/-	canadian_syllabics}');
Expect(1, 5759, '\p{Is_Block=canadiansyllabics}', "");
Expect(0, 5759, '\p{^Is_Block=canadiansyllabics}', "");
Expect(0, 5759, '\P{Is_Block=canadiansyllabics}', "");
Expect(1, 5759, '\P{^Is_Block=canadiansyllabics}', "");
Expect(0, 5760, '\p{Is_Block=canadiansyllabics}', "");
Expect(1, 5760, '\p{^Is_Block=canadiansyllabics}', "");
Expect(1, 5760, '\P{Is_Block=canadiansyllabics}', "");
Expect(0, 5760, '\P{^Is_Block=canadiansyllabics}', "");
Expect(1, 5759, '\p{Is_Block= Canadian_Syllabics}', "");
Expect(0, 5759, '\p{^Is_Block= Canadian_Syllabics}', "");
Expect(0, 5759, '\P{Is_Block= Canadian_Syllabics}', "");
Expect(1, 5759, '\P{^Is_Block= Canadian_Syllabics}', "");
Expect(0, 5760, '\p{Is_Block= Canadian_Syllabics}', "");
Expect(1, 5760, '\p{^Is_Block= Canadian_Syllabics}', "");
Expect(1, 5760, '\P{Is_Block= Canadian_Syllabics}', "");
Expect(0, 5760, '\P{^Is_Block= Canadian_Syllabics}', "");
Error('\p{Is_Blk= :=Unified_Canadian_aboriginal_SYLLABICS}');
Error('\P{Is_Blk= :=Unified_Canadian_aboriginal_SYLLABICS}');
Expect(1, 5759, '\p{Is_Blk=unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\p{^Is_Blk=unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\P{Is_Blk=unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\P{^Is_Blk=unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\p{Is_Blk=unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\p{^Is_Blk=unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\P{Is_Blk=unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\P{^Is_Blk=unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\p{Is_Blk=-_unified_Canadian_Aboriginal_Syllabics}', "");
Expect(0, 5759, '\p{^Is_Blk=-_unified_Canadian_Aboriginal_Syllabics}', "");
Expect(0, 5759, '\P{Is_Blk=-_unified_Canadian_Aboriginal_Syllabics}', "");
Expect(1, 5759, '\P{^Is_Blk=-_unified_Canadian_Aboriginal_Syllabics}', "");
Expect(0, 5760, '\p{Is_Blk=-_unified_Canadian_Aboriginal_Syllabics}', "");
Expect(1, 5760, '\p{^Is_Blk=-_unified_Canadian_Aboriginal_Syllabics}', "");
Expect(1, 5760, '\P{Is_Blk=-_unified_Canadian_Aboriginal_Syllabics}', "");
Expect(0, 5760, '\P{^Is_Blk=-_unified_Canadian_Aboriginal_Syllabics}', "");
Error('\p{Block=_	Unified_CANADIAN_aboriginal_Syllabics_extended:=}');
Error('\P{Block=_	Unified_CANADIAN_aboriginal_Syllabics_extended:=}');
Expect(1, 6399, '\p{Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\p{^Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\P{Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\P{^Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\p{Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\p{^Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\P{Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\P{^Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\p{Block=-	Unified_canadian_Aboriginal_SYLLABICS_EXTENDED}', "");
Expect(0, 6399, '\p{^Block=-	Unified_canadian_Aboriginal_SYLLABICS_EXTENDED}', "");
Expect(0, 6399, '\P{Block=-	Unified_canadian_Aboriginal_SYLLABICS_EXTENDED}', "");
Expect(1, 6399, '\P{^Block=-	Unified_canadian_Aboriginal_SYLLABICS_EXTENDED}', "");
Expect(0, 6400, '\p{Block=-	Unified_canadian_Aboriginal_SYLLABICS_EXTENDED}', "");
Expect(1, 6400, '\p{^Block=-	Unified_canadian_Aboriginal_SYLLABICS_EXTENDED}', "");
Expect(1, 6400, '\P{Block=-	Unified_canadian_Aboriginal_SYLLABICS_EXTENDED}', "");
Expect(0, 6400, '\P{^Block=-	Unified_canadian_Aboriginal_SYLLABICS_EXTENDED}', "");
Error('\p{Blk=:=  UCAS_Ext}');
Error('\P{Blk=:=  UCAS_Ext}');
Expect(1, 6399, '\p{Blk=ucasext}', "");
Expect(0, 6399, '\p{^Blk=ucasext}', "");
Expect(0, 6399, '\P{Blk=ucasext}', "");
Expect(1, 6399, '\P{^Blk=ucasext}', "");
Expect(0, 6400, '\p{Blk=ucasext}', "");
Expect(1, 6400, '\p{^Blk=ucasext}', "");
Expect(1, 6400, '\P{Blk=ucasext}', "");
Expect(0, 6400, '\P{^Blk=ucasext}', "");
Expect(1, 6399, '\p{Blk=-_UCAS_Ext}', "");
Expect(0, 6399, '\p{^Blk=-_UCAS_Ext}', "");
Expect(0, 6399, '\P{Blk=-_UCAS_Ext}', "");
Expect(1, 6399, '\P{^Blk=-_UCAS_Ext}', "");
Expect(0, 6400, '\p{Blk=-_UCAS_Ext}', "");
Expect(1, 6400, '\p{^Blk=-_UCAS_Ext}', "");
Expect(1, 6400, '\P{Blk=-_UCAS_Ext}', "");
Expect(0, 6400, '\P{^Blk=-_UCAS_Ext}', "");
Error('\p{Is_Block=:=unified_CANADIAN_Aboriginal_Syllabics_Extended}');
Error('\P{Is_Block=:=unified_CANADIAN_Aboriginal_Syllabics_Extended}');
Expect(1, 6399, '\p{Is_Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\p{^Is_Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\P{Is_Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\P{^Is_Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\p{Is_Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\p{^Is_Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\P{Is_Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\P{^Is_Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\p{Is_Block:_ Unified_Canadian_aboriginal_Syllabics_EXTENDED}', "");
Expect(0, 6399, '\p{^Is_Block:_ Unified_Canadian_aboriginal_Syllabics_EXTENDED}', "");
Expect(0, 6399, '\P{Is_Block:_ Unified_Canadian_aboriginal_Syllabics_EXTENDED}', "");
Expect(1, 6399, '\P{^Is_Block:_ Unified_Canadian_aboriginal_Syllabics_EXTENDED}', "");
Expect(0, 6400, '\p{Is_Block:_ Unified_Canadian_aboriginal_Syllabics_EXTENDED}', "");
Expect(1, 6400, '\p{^Is_Block:_ Unified_Canadian_aboriginal_Syllabics_EXTENDED}', "");
Expect(1, 6400, '\P{Is_Block:_ Unified_Canadian_aboriginal_Syllabics_EXTENDED}', "");
Expect(0, 6400, '\P{^Is_Block:_ Unified_Canadian_aboriginal_Syllabics_EXTENDED}', "");
Error('\p{Is_Blk:   /a/_-UCAS_EXT}');
Error('\P{Is_Blk:   /a/_-UCAS_EXT}');
Expect(1, 6399, '\p{Is_Blk=ucasext}', "");
Expect(0, 6399, '\p{^Is_Blk=ucasext}', "");
Expect(0, 6399, '\P{Is_Blk=ucasext}', "");
Expect(1, 6399, '\P{^Is_Blk=ucasext}', "");
Expect(0, 6400, '\p{Is_Blk=ucasext}', "");
Expect(1, 6400, '\p{^Is_Blk=ucasext}', "");
Expect(1, 6400, '\P{Is_Blk=ucasext}', "");
Expect(0, 6400, '\P{^Is_Blk=ucasext}', "");
Expect(1, 6399, '\p{Is_Blk=-UCAS_EXT}', "");
Expect(0, 6399, '\p{^Is_Blk=-UCAS_EXT}', "");
Expect(0, 6399, '\P{Is_Blk=-UCAS_EXT}', "");
Expect(1, 6399, '\P{^Is_Blk=-UCAS_EXT}', "");
Expect(0, 6400, '\p{Is_Blk=-UCAS_EXT}', "");
Expect(1, 6400, '\p{^Is_Blk=-UCAS_EXT}', "");
Expect(1, 6400, '\P{Is_Blk=-UCAS_EXT}', "");
Expect(0, 6400, '\P{^Is_Blk=-UCAS_EXT}', "");
Error('\p{Block=	/a/UGARITIC}');
Error('\P{Block=	/a/UGARITIC}');
Expect(1, 66463, '\p{Block=ugaritic}', "");
Expect(0, 66463, '\p{^Block=ugaritic}', "");
Expect(0, 66463, '\P{Block=ugaritic}', "");
Expect(1, 66463, '\P{^Block=ugaritic}', "");
Expect(0, 66464, '\p{Block=ugaritic}', "");
Expect(1, 66464, '\p{^Block=ugaritic}', "");
Expect(1, 66464, '\P{Block=ugaritic}', "");
Expect(0, 66464, '\P{^Block=ugaritic}', "");
Expect(1, 66463, '\p{Block=-_Ugaritic}', "");
Expect(0, 66463, '\p{^Block=-_Ugaritic}', "");
Expect(0, 66463, '\P{Block=-_Ugaritic}', "");
Expect(1, 66463, '\P{^Block=-_Ugaritic}', "");
Expect(0, 66464, '\p{Block=-_Ugaritic}', "");
Expect(1, 66464, '\p{^Block=-_Ugaritic}', "");
Expect(1, 66464, '\P{Block=-_Ugaritic}', "");
Expect(0, 66464, '\P{^Block=-_Ugaritic}', "");
Error('\p{Blk=/a/_-Ugaritic}');
Error('\P{Blk=/a/_-Ugaritic}');
Expect(1, 66463, '\p{Blk=ugaritic}', "");
Expect(0, 66463, '\p{^Blk=ugaritic}', "");
Expect(0, 66463, '\P{Blk=ugaritic}', "");
Expect(1, 66463, '\P{^Blk=ugaritic}', "");
Expect(0, 66464, '\p{Blk=ugaritic}', "");
Expect(1, 66464, '\p{^Blk=ugaritic}', "");
Expect(1, 66464, '\P{Blk=ugaritic}', "");
Expect(0, 66464, '\P{^Blk=ugaritic}', "");
Expect(1, 66463, '\p{Blk=--ugaritic}', "");
Expect(0, 66463, '\p{^Blk=--ugaritic}', "");
Expect(0, 66463, '\P{Blk=--ugaritic}', "");
Expect(1, 66463, '\P{^Blk=--ugaritic}', "");
Expect(0, 66464, '\p{Blk=--ugaritic}', "");
Expect(1, 66464, '\p{^Blk=--ugaritic}', "");
Expect(1, 66464, '\P{Blk=--ugaritic}', "");
Expect(0, 66464, '\P{^Blk=--ugaritic}', "");
Error('\p{Is_Block=:=UGARITIC}');
Error('\P{Is_Block=:=UGARITIC}');
Expect(1, 66463, '\p{Is_Block=ugaritic}', "");
Expect(0, 66463, '\p{^Is_Block=ugaritic}', "");
Expect(0, 66463, '\P{Is_Block=ugaritic}', "");
Expect(1, 66463, '\P{^Is_Block=ugaritic}', "");
Expect(0, 66464, '\p{Is_Block=ugaritic}', "");
Expect(1, 66464, '\p{^Is_Block=ugaritic}', "");
Expect(1, 66464, '\P{Is_Block=ugaritic}', "");
Expect(0, 66464, '\P{^Is_Block=ugaritic}', "");
Expect(1, 66463, '\p{Is_Block=_	Ugaritic}', "");
Expect(0, 66463, '\p{^Is_Block=_	Ugaritic}', "");
Expect(0, 66463, '\P{Is_Block=_	Ugaritic}', "");
Expect(1, 66463, '\P{^Is_Block=_	Ugaritic}', "");
Expect(0, 66464, '\p{Is_Block=_	Ugaritic}', "");
Expect(1, 66464, '\p{^Is_Block=_	Ugaritic}', "");
Expect(1, 66464, '\P{Is_Block=_	Ugaritic}', "");
Expect(0, 66464, '\P{^Is_Block=_	Ugaritic}', "");
Error('\p{Is_Blk= Ugaritic:=}');
Error('\P{Is_Blk= Ugaritic:=}');
Expect(1, 66463, '\p{Is_Blk=ugaritic}', "");
Expect(0, 66463, '\p{^Is_Blk=ugaritic}', "");
Expect(0, 66463, '\P{Is_Blk=ugaritic}', "");
Expect(1, 66463, '\P{^Is_Blk=ugaritic}', "");
Expect(0, 66464, '\p{Is_Blk=ugaritic}', "");
Expect(1, 66464, '\p{^Is_Blk=ugaritic}', "");
Expect(1, 66464, '\P{Is_Blk=ugaritic}', "");
Expect(0, 66464, '\P{^Is_Blk=ugaritic}', "");
Expect(1, 66463, '\p{Is_Blk=Ugaritic}', "");
Expect(0, 66463, '\p{^Is_Blk=Ugaritic}', "");
Expect(0, 66463, '\P{Is_Blk=Ugaritic}', "");
Expect(1, 66463, '\P{^Is_Blk=Ugaritic}', "");
Expect(0, 66464, '\p{Is_Blk=Ugaritic}', "");
Expect(1, 66464, '\p{^Is_Blk=Ugaritic}', "");
Expect(1, 66464, '\P{Is_Blk=Ugaritic}', "");
Expect(0, 66464, '\P{^Is_Blk=Ugaritic}', "");
Error('\p{Block=	/a/VARIATION_selectors}');
Error('\P{Block=	/a/VARIATION_selectors}');
Expect(1, 65039, '\p{Block=variationselectors}', "");
Expect(0, 65039, '\p{^Block=variationselectors}', "");
Expect(0, 65039, '\P{Block=variationselectors}', "");
Expect(1, 65039, '\P{^Block=variationselectors}', "");
Expect(0, 65040, '\p{Block=variationselectors}', "");
Expect(1, 65040, '\p{^Block=variationselectors}', "");
Expect(1, 65040, '\P{Block=variationselectors}', "");
Expect(0, 65040, '\P{^Block=variationselectors}', "");
Expect(1, 65039, '\p{Block=-variation_Selectors}', "");
Expect(0, 65039, '\p{^Block=-variation_Selectors}', "");
Expect(0, 65039, '\P{Block=-variation_Selectors}', "");
Expect(1, 65039, '\P{^Block=-variation_Selectors}', "");
Expect(0, 65040, '\p{Block=-variation_Selectors}', "");
Expect(1, 65040, '\p{^Block=-variation_Selectors}', "");
Expect(1, 65040, '\P{Block=-variation_Selectors}', "");
Expect(0, 65040, '\P{^Block=-variation_Selectors}', "");
Error('\p{Blk=-VS:=}');
Error('\P{Blk=-VS:=}');
Expect(1, 65039, '\p{Blk=vs}', "");
Expect(0, 65039, '\p{^Blk=vs}', "");
Expect(0, 65039, '\P{Blk=vs}', "");
Expect(1, 65039, '\P{^Blk=vs}', "");
Expect(0, 65040, '\p{Blk=vs}', "");
Expect(1, 65040, '\p{^Blk=vs}', "");
Expect(1, 65040, '\P{Blk=vs}', "");
Expect(0, 65040, '\P{^Blk=vs}', "");
Expect(1, 65039, '\p{Blk=- VS}', "");
Expect(0, 65039, '\p{^Blk=- VS}', "");
Expect(0, 65039, '\P{Blk=- VS}', "");
Expect(1, 65039, '\P{^Blk=- VS}', "");
Expect(0, 65040, '\p{Blk=- VS}', "");
Expect(1, 65040, '\p{^Blk=- VS}', "");
Expect(1, 65040, '\P{Blk=- VS}', "");
Expect(0, 65040, '\P{^Blk=- VS}', "");
Error('\p{Is_Block:		/a/Variation_SELECTORS}');
Error('\P{Is_Block:		/a/Variation_SELECTORS}');
Expect(1, 65039, '\p{Is_Block=variationselectors}', "");
Expect(0, 65039, '\p{^Is_Block=variationselectors}', "");
Expect(0, 65039, '\P{Is_Block=variationselectors}', "");
Expect(1, 65039, '\P{^Is_Block=variationselectors}', "");
Expect(0, 65040, '\p{Is_Block=variationselectors}', "");
Expect(1, 65040, '\p{^Is_Block=variationselectors}', "");
Expect(1, 65040, '\P{Is_Block=variationselectors}', "");
Expect(0, 65040, '\P{^Is_Block=variationselectors}', "");
Expect(1, 65039, '\p{Is_Block=-_VARIATION_SELECTORS}', "");
Expect(0, 65039, '\p{^Is_Block=-_VARIATION_SELECTORS}', "");
Expect(0, 65039, '\P{Is_Block=-_VARIATION_SELECTORS}', "");
Expect(1, 65039, '\P{^Is_Block=-_VARIATION_SELECTORS}', "");
Expect(0, 65040, '\p{Is_Block=-_VARIATION_SELECTORS}', "");
Expect(1, 65040, '\p{^Is_Block=-_VARIATION_SELECTORS}', "");
Expect(1, 65040, '\P{Is_Block=-_VARIATION_SELECTORS}', "");
Expect(0, 65040, '\P{^Is_Block=-_VARIATION_SELECTORS}', "");
Error('\p{Is_Blk=_:=VS}');
Error('\P{Is_Blk=_:=VS}');
Expect(1, 65039, '\p{Is_Blk=vs}', "");
Expect(0, 65039, '\p{^Is_Blk=vs}', "");
Expect(0, 65039, '\P{Is_Blk=vs}', "");
Expect(1, 65039, '\P{^Is_Blk=vs}', "");
Expect(0, 65040, '\p{Is_Blk=vs}', "");
Expect(1, 65040, '\p{^Is_Blk=vs}', "");
Expect(1, 65040, '\P{Is_Blk=vs}', "");
Expect(0, 65040, '\P{^Is_Blk=vs}', "");
Expect(1, 65039, '\p{Is_Blk=_	vs}', "");
Expect(0, 65039, '\p{^Is_Blk=_	vs}', "");
Expect(0, 65039, '\P{Is_Blk=_	vs}', "");
Expect(1, 65039, '\P{^Is_Blk=_	vs}', "");
Expect(0, 65040, '\p{Is_Blk=_	vs}', "");
Expect(1, 65040, '\p{^Is_Blk=_	vs}', "");
Expect(1, 65040, '\P{Is_Blk=_	vs}', "");
Expect(0, 65040, '\P{^Is_Blk=_	vs}', "");
Error('\p{Block= :=VARIATION_Selectors_supplement}');
Error('\P{Block= :=VARIATION_Selectors_supplement}');
Expect(1, 917999, '\p{Block:   variationselectorssupplement}', "");
Expect(0, 917999, '\p{^Block:   variationselectorssupplement}', "");
Expect(0, 917999, '\P{Block:   variationselectorssupplement}', "");
Expect(1, 917999, '\P{^Block:   variationselectorssupplement}', "");
Expect(0, 918000, '\p{Block:   variationselectorssupplement}', "");
Expect(1, 918000, '\p{^Block:   variationselectorssupplement}', "");
Expect(1, 918000, '\P{Block:   variationselectorssupplement}', "");
Expect(0, 918000, '\P{^Block:   variationselectorssupplement}', "");
Expect(1, 917999, '\p{Block=	Variation_Selectors_Supplement}', "");
Expect(0, 917999, '\p{^Block=	Variation_Selectors_Supplement}', "");
Expect(0, 917999, '\P{Block=	Variation_Selectors_Supplement}', "");
Expect(1, 917999, '\P{^Block=	Variation_Selectors_Supplement}', "");
Expect(0, 918000, '\p{Block=	Variation_Selectors_Supplement}', "");
Expect(1, 918000, '\p{^Block=	Variation_Selectors_Supplement}', "");
Expect(1, 918000, '\P{Block=	Variation_Selectors_Supplement}', "");
Expect(0, 918000, '\P{^Block=	Variation_Selectors_Supplement}', "");
Error('\p{Blk=/a/ VS_sup}');
Error('\P{Blk=/a/ VS_sup}');
Expect(1, 917999, '\p{Blk=vssup}', "");
Expect(0, 917999, '\p{^Blk=vssup}', "");
Expect(0, 917999, '\P{Blk=vssup}', "");
Expect(1, 917999, '\P{^Blk=vssup}', "");
Expect(0, 918000, '\p{Blk=vssup}', "");
Expect(1, 918000, '\p{^Blk=vssup}', "");
Expect(1, 918000, '\P{Blk=vssup}', "");
Expect(0, 918000, '\P{^Blk=vssup}', "");
Expect(1, 917999, '\p{Blk= -VS_SUP}', "");
Expect(0, 917999, '\p{^Blk= -VS_SUP}', "");
Expect(0, 917999, '\P{Blk= -VS_SUP}', "");
Expect(1, 917999, '\P{^Blk= -VS_SUP}', "");
Expect(0, 918000, '\p{Blk= -VS_SUP}', "");
Expect(1, 918000, '\p{^Blk= -VS_SUP}', "");
Expect(1, 918000, '\P{Blk= -VS_SUP}', "");
Expect(0, 918000, '\P{^Blk= -VS_SUP}', "");
Error('\p{Is_Block=/a/_Variation_selectors_Supplement}');
Error('\P{Is_Block=/a/_Variation_selectors_Supplement}');
Expect(1, 917999, '\p{Is_Block=variationselectorssupplement}', "");
Expect(0, 917999, '\p{^Is_Block=variationselectorssupplement}', "");
Expect(0, 917999, '\P{Is_Block=variationselectorssupplement}', "");
Expect(1, 917999, '\P{^Is_Block=variationselectorssupplement}', "");
Expect(0, 918000, '\p{Is_Block=variationselectorssupplement}', "");
Expect(1, 918000, '\p{^Is_Block=variationselectorssupplement}', "");
Expect(1, 918000, '\P{Is_Block=variationselectorssupplement}', "");
Expect(0, 918000, '\P{^Is_Block=variationselectorssupplement}', "");
Expect(1, 917999, '\p{Is_Block:__Variation_Selectors_Supplement}', "");
Expect(0, 917999, '\p{^Is_Block:__Variation_Selectors_Supplement}', "");
Expect(0, 917999, '\P{Is_Block:__Variation_Selectors_Supplement}', "");
Expect(1, 917999, '\P{^Is_Block:__Variation_Selectors_Supplement}', "");
Expect(0, 918000, '\p{Is_Block:__Variation_Selectors_Supplement}', "");
Expect(1, 918000, '\p{^Is_Block:__Variation_Selectors_Supplement}', "");
Expect(1, 918000, '\P{Is_Block:__Variation_Selectors_Supplement}', "");
Expect(0, 918000, '\P{^Is_Block:__Variation_Selectors_Supplement}', "");
Error('\p{Is_Blk= vs_Sup/a/}');
Error('\P{Is_Blk= vs_Sup/a/}');
Expect(1, 917999, '\p{Is_Blk=vssup}', "");
Expect(0, 917999, '\p{^Is_Blk=vssup}', "");
Expect(0, 917999, '\P{Is_Blk=vssup}', "");
Expect(1, 917999, '\P{^Is_Blk=vssup}', "");
Expect(0, 918000, '\p{Is_Blk=vssup}', "");
Expect(1, 918000, '\p{^Is_Blk=vssup}', "");
Expect(1, 918000, '\P{Is_Blk=vssup}', "");
Expect(0, 918000, '\P{^Is_Blk=vssup}', "");
Expect(1, 917999, '\p{Is_Blk=	VS_Sup}', "");
Expect(0, 917999, '\p{^Is_Blk=	VS_Sup}', "");
Expect(0, 917999, '\P{Is_Blk=	VS_Sup}', "");
Expect(1, 917999, '\P{^Is_Blk=	VS_Sup}', "");
Expect(0, 918000, '\p{Is_Blk=	VS_Sup}', "");
Expect(1, 918000, '\p{^Is_Blk=	VS_Sup}', "");
Expect(1, 918000, '\P{Is_Blk=	VS_Sup}', "");
Expect(0, 918000, '\P{^Is_Blk=	VS_Sup}', "");
Error('\p{Block=/a/	 vai}');
Error('\P{Block=/a/	 vai}');
Expect(1, 42559, '\p{Block=vai}', "");
Expect(0, 42559, '\p{^Block=vai}', "");
Expect(0, 42559, '\P{Block=vai}', "");
Expect(1, 42559, '\P{^Block=vai}', "");
Expect(0, 42560, '\p{Block=vai}', "");
Expect(1, 42560, '\p{^Block=vai}', "");
Expect(1, 42560, '\P{Block=vai}', "");
Expect(0, 42560, '\P{^Block=vai}', "");
Expect(1, 42559, '\p{Block= 	Vai}', "");
Expect(0, 42559, '\p{^Block= 	Vai}', "");
Expect(0, 42559, '\P{Block= 	Vai}', "");
Expect(1, 42559, '\P{^Block= 	Vai}', "");
Expect(0, 42560, '\p{Block= 	Vai}', "");
Expect(1, 42560, '\p{^Block= 	Vai}', "");
Expect(1, 42560, '\P{Block= 	Vai}', "");
Expect(0, 42560, '\P{^Block= 	Vai}', "");
Error('\p{Blk: :=VAI}');
Error('\P{Blk: :=VAI}');
Expect(1, 42559, '\p{Blk:vai}', "");
Expect(0, 42559, '\p{^Blk:vai}', "");
Expect(0, 42559, '\P{Blk:vai}', "");
Expect(1, 42559, '\P{^Blk:vai}', "");
Expect(0, 42560, '\p{Blk:vai}', "");
Expect(1, 42560, '\p{^Blk:vai}', "");
Expect(1, 42560, '\P{Blk:vai}', "");
Expect(0, 42560, '\P{^Blk:vai}', "");
Expect(1, 42559, '\p{Blk=	-VAI}', "");
Expect(0, 42559, '\p{^Blk=	-VAI}', "");
Expect(0, 42559, '\P{Blk=	-VAI}', "");
Expect(1, 42559, '\P{^Blk=	-VAI}', "");
Expect(0, 42560, '\p{Blk=	-VAI}', "");
Expect(1, 42560, '\p{^Blk=	-VAI}', "");
Expect(1, 42560, '\P{Blk=	-VAI}', "");
Expect(0, 42560, '\P{^Blk=	-VAI}', "");
Error('\p{Is_Block=	-Vai/a/}');
Error('\P{Is_Block=	-Vai/a/}');
Expect(1, 42559, '\p{Is_Block=vai}', "");
Expect(0, 42559, '\p{^Is_Block=vai}', "");
Expect(0, 42559, '\P{Is_Block=vai}', "");
Expect(1, 42559, '\P{^Is_Block=vai}', "");
Expect(0, 42560, '\p{Is_Block=vai}', "");
Expect(1, 42560, '\p{^Is_Block=vai}', "");
Expect(1, 42560, '\P{Is_Block=vai}', "");
Expect(0, 42560, '\P{^Is_Block=vai}', "");
Expect(1, 42559, '\p{Is_Block=  vai}', "");
Expect(0, 42559, '\p{^Is_Block=  vai}', "");
Expect(0, 42559, '\P{Is_Block=  vai}', "");
Expect(1, 42559, '\P{^Is_Block=  vai}', "");
Expect(0, 42560, '\p{Is_Block=  vai}', "");
Expect(1, 42560, '\p{^Is_Block=  vai}', "");
Expect(1, 42560, '\P{Is_Block=  vai}', "");
Expect(0, 42560, '\P{^Is_Block=  vai}', "");
Error('\p{Is_Blk=_Vai/a/}');
Error('\P{Is_Blk=_Vai/a/}');
Expect(1, 42559, '\p{Is_Blk=vai}', "");
Expect(0, 42559, '\p{^Is_Blk=vai}', "");
Expect(0, 42559, '\P{Is_Blk=vai}', "");
Expect(1, 42559, '\P{^Is_Blk=vai}', "");
Expect(0, 42560, '\p{Is_Blk=vai}', "");
Expect(1, 42560, '\p{^Is_Blk=vai}', "");
Expect(1, 42560, '\P{Is_Blk=vai}', "");
Expect(0, 42560, '\P{^Is_Blk=vai}', "");
Expect(1, 42559, '\p{Is_Blk=-vai}', "");
Expect(0, 42559, '\p{^Is_Blk=-vai}', "");
Expect(0, 42559, '\P{Is_Blk=-vai}', "");
Expect(1, 42559, '\P{^Is_Blk=-vai}', "");
Expect(0, 42560, '\p{Is_Blk=-vai}', "");
Expect(1, 42560, '\p{^Is_Blk=-vai}', "");
Expect(1, 42560, '\P{Is_Blk=-vai}', "");
Expect(0, 42560, '\P{^Is_Blk=-vai}', "");
Error('\p{Block=:= Vedic_EXTENSIONS}');
Error('\P{Block=:= Vedic_EXTENSIONS}');
Expect(1, 7423, '\p{Block=vedicextensions}', "");
Expect(0, 7423, '\p{^Block=vedicextensions}', "");
Expect(0, 7423, '\P{Block=vedicextensions}', "");
Expect(1, 7423, '\P{^Block=vedicextensions}', "");
Expect(0, 7424, '\p{Block=vedicextensions}', "");
Expect(1, 7424, '\p{^Block=vedicextensions}', "");
Expect(1, 7424, '\P{Block=vedicextensions}', "");
Expect(0, 7424, '\P{^Block=vedicextensions}', "");
Expect(1, 7423, '\p{Block:   -_vedic_Extensions}', "");
Expect(0, 7423, '\p{^Block:   -_vedic_Extensions}', "");
Expect(0, 7423, '\P{Block:   -_vedic_Extensions}', "");
Expect(1, 7423, '\P{^Block:   -_vedic_Extensions}', "");
Expect(0, 7424, '\p{Block:   -_vedic_Extensions}', "");
Expect(1, 7424, '\p{^Block:   -_vedic_Extensions}', "");
Expect(1, 7424, '\P{Block:   -_vedic_Extensions}', "");
Expect(0, 7424, '\P{^Block:   -_vedic_Extensions}', "");
Error('\p{Blk=--Vedic_Ext:=}');
Error('\P{Blk=--Vedic_Ext:=}');
Expect(1, 7423, '\p{Blk=vedicext}', "");
Expect(0, 7423, '\p{^Blk=vedicext}', "");
Expect(0, 7423, '\P{Blk=vedicext}', "");
Expect(1, 7423, '\P{^Blk=vedicext}', "");
Expect(0, 7424, '\p{Blk=vedicext}', "");
Expect(1, 7424, '\p{^Blk=vedicext}', "");
Expect(1, 7424, '\P{Blk=vedicext}', "");
Expect(0, 7424, '\P{^Blk=vedicext}', "");
Expect(1, 7423, '\p{Blk=		Vedic_EXT}', "");
Expect(0, 7423, '\p{^Blk=		Vedic_EXT}', "");
Expect(0, 7423, '\P{Blk=		Vedic_EXT}', "");
Expect(1, 7423, '\P{^Blk=		Vedic_EXT}', "");
Expect(0, 7424, '\p{Blk=		Vedic_EXT}', "");
Expect(1, 7424, '\p{^Blk=		Vedic_EXT}', "");
Expect(1, 7424, '\P{Blk=		Vedic_EXT}', "");
Expect(0, 7424, '\P{^Blk=		Vedic_EXT}', "");
Error('\p{Is_Block=/a/Vedic_Extensions}');
Error('\P{Is_Block=/a/Vedic_Extensions}');
Expect(1, 7423, '\p{Is_Block=vedicextensions}', "");
Expect(0, 7423, '\p{^Is_Block=vedicextensions}', "");
Expect(0, 7423, '\P{Is_Block=vedicextensions}', "");
Expect(1, 7423, '\P{^Is_Block=vedicextensions}', "");
Expect(0, 7424, '\p{Is_Block=vedicextensions}', "");
Expect(1, 7424, '\p{^Is_Block=vedicextensions}', "");
Expect(1, 7424, '\P{Is_Block=vedicextensions}', "");
Expect(0, 7424, '\P{^Is_Block=vedicextensions}', "");
Expect(1, 7423, '\p{Is_Block= VEDIC_extensions}', "");
Expect(0, 7423, '\p{^Is_Block= VEDIC_extensions}', "");
Expect(0, 7423, '\P{Is_Block= VEDIC_extensions}', "");
Expect(1, 7423, '\P{^Is_Block= VEDIC_extensions}', "");
Expect(0, 7424, '\p{Is_Block= VEDIC_extensions}', "");
Expect(1, 7424, '\p{^Is_Block= VEDIC_extensions}', "");
Expect(1, 7424, '\P{Is_Block= VEDIC_extensions}', "");
Expect(0, 7424, '\P{^Is_Block= VEDIC_extensions}', "");
Error('\p{Is_Blk=_-vedic_Ext:=}');
Error('\P{Is_Blk=_-vedic_Ext:=}');
Expect(1, 7423, '\p{Is_Blk=vedicext}', "");
Expect(0, 7423, '\p{^Is_Blk=vedicext}', "");
Expect(0, 7423, '\P{Is_Blk=vedicext}', "");
Expect(1, 7423, '\P{^Is_Blk=vedicext}', "");
Expect(0, 7424, '\p{Is_Blk=vedicext}', "");
Expect(1, 7424, '\p{^Is_Blk=vedicext}', "");
Expect(1, 7424, '\P{Is_Blk=vedicext}', "");
Expect(0, 7424, '\P{^Is_Blk=vedicext}', "");
Expect(1, 7423, '\p{Is_Blk=  Vedic_Ext}', "");
Expect(0, 7423, '\p{^Is_Blk=  Vedic_Ext}', "");
Expect(0, 7423, '\P{Is_Blk=  Vedic_Ext}', "");
Expect(1, 7423, '\P{^Is_Blk=  Vedic_Ext}', "");
Expect(0, 7424, '\p{Is_Blk=  Vedic_Ext}', "");
Expect(1, 7424, '\p{^Is_Blk=  Vedic_Ext}', "");
Expect(1, 7424, '\P{Is_Blk=  Vedic_Ext}', "");
Expect(0, 7424, '\P{^Is_Blk=  Vedic_Ext}', "");
Error('\p{Block=-:=Vertical_Forms}');
Error('\P{Block=-:=Vertical_Forms}');
Expect(1, 65055, '\p{Block=verticalforms}', "");
Expect(0, 65055, '\p{^Block=verticalforms}', "");
Expect(0, 65055, '\P{Block=verticalforms}', "");
Expect(1, 65055, '\P{^Block=verticalforms}', "");
Expect(0, 65056, '\p{Block=verticalforms}', "");
Expect(1, 65056, '\p{^Block=verticalforms}', "");
Expect(1, 65056, '\P{Block=verticalforms}', "");
Expect(0, 65056, '\P{^Block=verticalforms}', "");
Expect(1, 65055, '\p{Block=Vertical_FORMS}', "");
Expect(0, 65055, '\p{^Block=Vertical_FORMS}', "");
Expect(0, 65055, '\P{Block=Vertical_FORMS}', "");
Expect(1, 65055, '\P{^Block=Vertical_FORMS}', "");
Expect(0, 65056, '\p{Block=Vertical_FORMS}', "");
Expect(1, 65056, '\p{^Block=Vertical_FORMS}', "");
Expect(1, 65056, '\P{Block=Vertical_FORMS}', "");
Expect(0, 65056, '\P{^Block=Vertical_FORMS}', "");
Error('\p{Blk=	Vertical_Forms/a/}');
Error('\P{Blk=	Vertical_Forms/a/}');
Expect(1, 65055, '\p{Blk=verticalforms}', "");
Expect(0, 65055, '\p{^Blk=verticalforms}', "");
Expect(0, 65055, '\P{Blk=verticalforms}', "");
Expect(1, 65055, '\P{^Blk=verticalforms}', "");
Expect(0, 65056, '\p{Blk=verticalforms}', "");
Expect(1, 65056, '\p{^Blk=verticalforms}', "");
Expect(1, 65056, '\P{Blk=verticalforms}', "");
Expect(0, 65056, '\P{^Blk=verticalforms}', "");
Expect(1, 65055, '\p{Blk=-_vertical_Forms}', "");
Expect(0, 65055, '\p{^Blk=-_vertical_Forms}', "");
Expect(0, 65055, '\P{Blk=-_vertical_Forms}', "");
Expect(1, 65055, '\P{^Blk=-_vertical_Forms}', "");
Expect(0, 65056, '\p{Blk=-_vertical_Forms}', "");
Expect(1, 65056, '\p{^Blk=-_vertical_Forms}', "");
Expect(1, 65056, '\P{Blk=-_vertical_Forms}', "");
Expect(0, 65056, '\P{^Blk=-_vertical_Forms}', "");
Error('\p{Is_Block=-Vertical_FORMS:=}');
Error('\P{Is_Block=-Vertical_FORMS:=}');
Expect(1, 65055, '\p{Is_Block=verticalforms}', "");
Expect(0, 65055, '\p{^Is_Block=verticalforms}', "");
Expect(0, 65055, '\P{Is_Block=verticalforms}', "");
Expect(1, 65055, '\P{^Is_Block=verticalforms}', "");
Expect(0, 65056, '\p{Is_Block=verticalforms}', "");
Expect(1, 65056, '\p{^Is_Block=verticalforms}', "");
Expect(1, 65056, '\P{Is_Block=verticalforms}', "");
Expect(0, 65056, '\P{^Is_Block=verticalforms}', "");
Expect(1, 65055, '\p{Is_Block=	-VERTICAL_Forms}', "");
Expect(0, 65055, '\p{^Is_Block=	-VERTICAL_Forms}', "");
Expect(0, 65055, '\P{Is_Block=	-VERTICAL_Forms}', "");
Expect(1, 65055, '\P{^Is_Block=	-VERTICAL_Forms}', "");
Expect(0, 65056, '\p{Is_Block=	-VERTICAL_Forms}', "");
Expect(1, 65056, '\p{^Is_Block=	-VERTICAL_Forms}', "");
Expect(1, 65056, '\P{Is_Block=	-VERTICAL_Forms}', "");
Expect(0, 65056, '\P{^Is_Block=	-VERTICAL_Forms}', "");
Error('\p{Is_Blk= /a/Vertical_FORMS}');
Error('\P{Is_Blk= /a/Vertical_FORMS}');
Expect(1, 65055, '\p{Is_Blk=verticalforms}', "");
Expect(0, 65055, '\p{^Is_Blk=verticalforms}', "");
Expect(0, 65055, '\P{Is_Blk=verticalforms}', "");
Expect(1, 65055, '\P{^Is_Blk=verticalforms}', "");
Expect(0, 65056, '\p{Is_Blk=verticalforms}', "");
Expect(1, 65056, '\p{^Is_Blk=verticalforms}', "");
Expect(1, 65056, '\P{Is_Blk=verticalforms}', "");
Expect(0, 65056, '\P{^Is_Blk=verticalforms}', "");
Expect(1, 65055, '\p{Is_Blk=- Vertical_FORMS}', "");
Expect(0, 65055, '\p{^Is_Blk=- Vertical_FORMS}', "");
Expect(0, 65055, '\P{Is_Blk=- Vertical_FORMS}', "");
Expect(1, 65055, '\P{^Is_Blk=- Vertical_FORMS}', "");
Expect(0, 65056, '\p{Is_Blk=- Vertical_FORMS}', "");
Expect(1, 65056, '\p{^Is_Blk=- Vertical_FORMS}', "");
Expect(1, 65056, '\P{Is_Blk=- Vertical_FORMS}', "");
Expect(0, 65056, '\P{^Is_Blk=- Vertical_FORMS}', "");
Error('\p{Block=/a/	_Yi_RADICALS}');
Error('\P{Block=/a/	_Yi_RADICALS}');
Expect(1, 42191, '\p{Block=yiradicals}', "");
Expect(0, 42191, '\p{^Block=yiradicals}', "");
Expect(0, 42191, '\P{Block=yiradicals}', "");
Expect(1, 42191, '\P{^Block=yiradicals}', "");
Expect(0, 42192, '\p{Block=yiradicals}', "");
Expect(1, 42192, '\p{^Block=yiradicals}', "");
Expect(1, 42192, '\P{Block=yiradicals}', "");
Expect(0, 42192, '\P{^Block=yiradicals}', "");
Expect(1, 42191, '\p{Block=_yi_radicals}', "");
Expect(0, 42191, '\p{^Block=_yi_radicals}', "");
Expect(0, 42191, '\P{Block=_yi_radicals}', "");
Expect(1, 42191, '\P{^Block=_yi_radicals}', "");
Expect(0, 42192, '\p{Block=_yi_radicals}', "");
Expect(1, 42192, '\p{^Block=_yi_radicals}', "");
Expect(1, 42192, '\P{Block=_yi_radicals}', "");
Expect(0, 42192, '\P{^Block=_yi_radicals}', "");
Error('\p{Blk:	/a/ _Yi_Radicals}');
Error('\P{Blk:	/a/ _Yi_Radicals}');
Expect(1, 42191, '\p{Blk=yiradicals}', "");
Expect(0, 42191, '\p{^Blk=yiradicals}', "");
Expect(0, 42191, '\P{Blk=yiradicals}', "");
Expect(1, 42191, '\P{^Blk=yiradicals}', "");
Expect(0, 42192, '\p{Blk=yiradicals}', "");
Expect(1, 42192, '\p{^Blk=yiradicals}', "");
Expect(1, 42192, '\P{Blk=yiradicals}', "");
Expect(0, 42192, '\P{^Blk=yiradicals}', "");
Expect(1, 42191, '\p{Blk=_-Yi_RADICALS}', "");
Expect(0, 42191, '\p{^Blk=_-Yi_RADICALS}', "");
Expect(0, 42191, '\P{Blk=_-Yi_RADICALS}', "");
Expect(1, 42191, '\P{^Blk=_-Yi_RADICALS}', "");
Expect(0, 42192, '\p{Blk=_-Yi_RADICALS}', "");
Expect(1, 42192, '\p{^Blk=_-Yi_RADICALS}', "");
Expect(1, 42192, '\P{Blk=_-Yi_RADICALS}', "");
Expect(0, 42192, '\P{^Blk=_-Yi_RADICALS}', "");
Error('\p{Is_Block=__Yi_Radicals:=}');
Error('\P{Is_Block=__Yi_Radicals:=}');
Expect(1, 42191, '\p{Is_Block=yiradicals}', "");
Expect(0, 42191, '\p{^Is_Block=yiradicals}', "");
Expect(0, 42191, '\P{Is_Block=yiradicals}', "");
Expect(1, 42191, '\P{^Is_Block=yiradicals}', "");
Expect(0, 42192, '\p{Is_Block=yiradicals}', "");
Expect(1, 42192, '\p{^Is_Block=yiradicals}', "");
Expect(1, 42192, '\P{Is_Block=yiradicals}', "");
Expect(0, 42192, '\P{^Is_Block=yiradicals}', "");
Expect(1, 42191, '\p{Is_Block= 	yi_Radicals}', "");
Expect(0, 42191, '\p{^Is_Block= 	yi_Radicals}', "");
Expect(0, 42191, '\P{Is_Block= 	yi_Radicals}', "");
Expect(1, 42191, '\P{^Is_Block= 	yi_Radicals}', "");
Expect(0, 42192, '\p{Is_Block= 	yi_Radicals}', "");
Expect(1, 42192, '\p{^Is_Block= 	yi_Radicals}', "");
Expect(1, 42192, '\P{Is_Block= 	yi_Radicals}', "");
Expect(0, 42192, '\P{^Is_Block= 	yi_Radicals}', "");
Error('\p{Is_Blk:   _/a/Yi_Radicals}');
Error('\P{Is_Blk:   _/a/Yi_Radicals}');
Expect(1, 42191, '\p{Is_Blk=yiradicals}', "");
Expect(0, 42191, '\p{^Is_Blk=yiradicals}', "");
Expect(0, 42191, '\P{Is_Blk=yiradicals}', "");
Expect(1, 42191, '\P{^Is_Blk=yiradicals}', "");
Expect(0, 42192, '\p{Is_Blk=yiradicals}', "");
Expect(1, 42192, '\p{^Is_Blk=yiradicals}', "");
Expect(1, 42192, '\P{Is_Blk=yiradicals}', "");
Expect(0, 42192, '\P{^Is_Blk=yiradicals}', "");
Expect(1, 42191, '\p{Is_Blk: 	yi_radicals}', "");
Expect(0, 42191, '\p{^Is_Blk: 	yi_radicals}', "");
Expect(0, 42191, '\P{Is_Blk: 	yi_radicals}', "");
Expect(1, 42191, '\P{^Is_Blk: 	yi_radicals}', "");
Expect(0, 42192, '\p{Is_Blk: 	yi_radicals}', "");
Expect(1, 42192, '\p{^Is_Blk: 	yi_radicals}', "");
Expect(1, 42192, '\P{Is_Blk: 	yi_radicals}', "");
Expect(0, 42192, '\P{^Is_Blk: 	yi_radicals}', "");
Error('\p{Block=/a/-_Yi_Syllables}');
Error('\P{Block=/a/-_Yi_Syllables}');
Expect(1, 42127, '\p{Block=yisyllables}', "");
Expect(0, 42127, '\p{^Block=yisyllables}', "");
Expect(0, 42127, '\P{Block=yisyllables}', "");
Expect(1, 42127, '\P{^Block=yisyllables}', "");
Expect(0, 42128, '\p{Block=yisyllables}', "");
Expect(1, 42128, '\p{^Block=yisyllables}', "");
Expect(1, 42128, '\P{Block=yisyllables}', "");
Expect(0, 42128, '\P{^Block=yisyllables}', "");
Expect(1, 42127, '\p{Block: -yi_Syllables}', "");
Expect(0, 42127, '\p{^Block: -yi_Syllables}', "");
Expect(0, 42127, '\P{Block: -yi_Syllables}', "");
Expect(1, 42127, '\P{^Block: -yi_Syllables}', "");
Expect(0, 42128, '\p{Block: -yi_Syllables}', "");
Expect(1, 42128, '\p{^Block: -yi_Syllables}', "");
Expect(1, 42128, '\P{Block: -yi_Syllables}', "");
Expect(0, 42128, '\P{^Block: -yi_Syllables}', "");
Error('\p{Blk=	Yi_SYLLABLES/a/}');
Error('\P{Blk=	Yi_SYLLABLES/a/}');
Expect(1, 42127, '\p{Blk=yisyllables}', "");
Expect(0, 42127, '\p{^Blk=yisyllables}', "");
Expect(0, 42127, '\P{Blk=yisyllables}', "");
Expect(1, 42127, '\P{^Blk=yisyllables}', "");
Expect(0, 42128, '\p{Blk=yisyllables}', "");
Expect(1, 42128, '\p{^Blk=yisyllables}', "");
Expect(1, 42128, '\P{Blk=yisyllables}', "");
Expect(0, 42128, '\P{^Blk=yisyllables}', "");
Expect(1, 42127, '\p{Blk=  Yi_SYLLABLES}', "");
Expect(0, 42127, '\p{^Blk=  Yi_SYLLABLES}', "");
Expect(0, 42127, '\P{Blk=  Yi_SYLLABLES}', "");
Expect(1, 42127, '\P{^Blk=  Yi_SYLLABLES}', "");
Expect(0, 42128, '\p{Blk=  Yi_SYLLABLES}', "");
Expect(1, 42128, '\p{^Blk=  Yi_SYLLABLES}', "");
Expect(1, 42128, '\P{Blk=  Yi_SYLLABLES}', "");
Expect(0, 42128, '\P{^Blk=  Yi_SYLLABLES}', "");
Error('\p{Is_Block=_YI_syllables/a/}');
Error('\P{Is_Block=_YI_syllables/a/}');
Expect(1, 42127, '\p{Is_Block=yisyllables}', "");
Expect(0, 42127, '\p{^Is_Block=yisyllables}', "");
Expect(0, 42127, '\P{Is_Block=yisyllables}', "");
Expect(1, 42127, '\P{^Is_Block=yisyllables}', "");
Expect(0, 42128, '\p{Is_Block=yisyllables}', "");
Expect(1, 42128, '\p{^Is_Block=yisyllables}', "");
Expect(1, 42128, '\P{Is_Block=yisyllables}', "");
Expect(0, 42128, '\P{^Is_Block=yisyllables}', "");
Expect(1, 42127, '\p{Is_Block: __YI_Syllables}', "");
Expect(0, 42127, '\p{^Is_Block: __YI_Syllables}', "");
Expect(0, 42127, '\P{Is_Block: __YI_Syllables}', "");
Expect(1, 42127, '\P{^Is_Block: __YI_Syllables}', "");
Expect(0, 42128, '\p{Is_Block: __YI_Syllables}', "");
Expect(1, 42128, '\p{^Is_Block: __YI_Syllables}', "");
Expect(1, 42128, '\P{Is_Block: __YI_Syllables}', "");
Expect(0, 42128, '\P{^Is_Block: __YI_Syllables}', "");
Error('\p{Is_Blk=		Yi_Syllables/a/}');
Error('\P{Is_Blk=		Yi_Syllables/a/}');
Expect(1, 42127, '\p{Is_Blk=yisyllables}', "");
Expect(0, 42127, '\p{^Is_Blk=yisyllables}', "");
Expect(0, 42127, '\P{Is_Blk=yisyllables}', "");
Expect(1, 42127, '\P{^Is_Blk=yisyllables}', "");
Expect(0, 42128, '\p{Is_Blk=yisyllables}', "");
Expect(1, 42128, '\p{^Is_Blk=yisyllables}', "");
Expect(1, 42128, '\P{Is_Blk=yisyllables}', "");
Expect(0, 42128, '\P{^Is_Blk=yisyllables}', "");
Expect(1, 42127, '\p{Is_Blk=-_YI_Syllables}', "");
Expect(0, 42127, '\p{^Is_Blk=-_YI_Syllables}', "");
Expect(0, 42127, '\P{Is_Blk=-_YI_Syllables}', "");
Expect(1, 42127, '\P{^Is_Blk=-_YI_Syllables}', "");
Expect(0, 42128, '\p{Is_Blk=-_YI_Syllables}', "");
Expect(1, 42128, '\p{^Is_Blk=-_YI_Syllables}', "");
Expect(1, 42128, '\P{Is_Blk=-_YI_Syllables}', "");
Expect(0, 42128, '\P{^Is_Blk=-_YI_Syllables}', "");
Error('\p{Block= /a/YIJING_Hexagram_Symbols}');
Error('\P{Block= /a/YIJING_Hexagram_Symbols}');
Expect(1, 19967, '\p{Block=yijinghexagramsymbols}', "");
Expect(0, 19967, '\p{^Block=yijinghexagramsymbols}', "");
Expect(0, 19967, '\P{Block=yijinghexagramsymbols}', "");
Expect(1, 19967, '\P{^Block=yijinghexagramsymbols}', "");
Expect(0, 19968, '\p{Block=yijinghexagramsymbols}', "");
Expect(1, 19968, '\p{^Block=yijinghexagramsymbols}', "");
Expect(1, 19968, '\P{Block=yijinghexagramsymbols}', "");
Expect(0, 19968, '\P{^Block=yijinghexagramsymbols}', "");
Expect(1, 19967, '\p{Block=YIJING_HEXAGRAM_Symbols}', "");
Expect(0, 19967, '\p{^Block=YIJING_HEXAGRAM_Symbols}', "");
Expect(0, 19967, '\P{Block=YIJING_HEXAGRAM_Symbols}', "");
Expect(1, 19967, '\P{^Block=YIJING_HEXAGRAM_Symbols}', "");
Expect(0, 19968, '\p{Block=YIJING_HEXAGRAM_Symbols}', "");
Expect(1, 19968, '\p{^Block=YIJING_HEXAGRAM_Symbols}', "");
Expect(1, 19968, '\P{Block=YIJING_HEXAGRAM_Symbols}', "");
Expect(0, 19968, '\P{^Block=YIJING_HEXAGRAM_Symbols}', "");
Error('\p{Blk=_Yijing:=}');
Error('\P{Blk=_Yijing:=}');
Expect(1, 19967, '\p{Blk=yijing}', "");
Expect(0, 19967, '\p{^Blk=yijing}', "");
Expect(0, 19967, '\P{Blk=yijing}', "");
Expect(1, 19967, '\P{^Blk=yijing}', "");
Expect(0, 19968, '\p{Blk=yijing}', "");
Expect(1, 19968, '\p{^Blk=yijing}', "");
Expect(1, 19968, '\P{Blk=yijing}', "");
Expect(0, 19968, '\P{^Blk=yijing}', "");
Expect(1, 19967, '\p{Blk=_-YIJING}', "");
Expect(0, 19967, '\p{^Blk=_-YIJING}', "");
Expect(0, 19967, '\P{Blk=_-YIJING}', "");
Expect(1, 19967, '\P{^Blk=_-YIJING}', "");
Expect(0, 19968, '\p{Blk=_-YIJING}', "");
Expect(1, 19968, '\p{^Blk=_-YIJING}', "");
Expect(1, 19968, '\P{Blk=_-YIJING}', "");
Expect(0, 19968, '\P{^Blk=_-YIJING}', "");
Error('\p{Is_Block=/a/yijing_Hexagram_Symbols}');
Error('\P{Is_Block=/a/yijing_Hexagram_Symbols}');
Expect(1, 19967, '\p{Is_Block=yijinghexagramsymbols}', "");
Expect(0, 19967, '\p{^Is_Block=yijinghexagramsymbols}', "");
Expect(0, 19967, '\P{Is_Block=yijinghexagramsymbols}', "");
Expect(1, 19967, '\P{^Is_Block=yijinghexagramsymbols}', "");
Expect(0, 19968, '\p{Is_Block=yijinghexagramsymbols}', "");
Expect(1, 19968, '\p{^Is_Block=yijinghexagramsymbols}', "");
Expect(1, 19968, '\P{Is_Block=yijinghexagramsymbols}', "");
Expect(0, 19968, '\P{^Is_Block=yijinghexagramsymbols}', "");
Expect(1, 19967, '\p{Is_Block=- Yijing_hexagram_Symbols}', "");
Expect(0, 19967, '\p{^Is_Block=- Yijing_hexagram_Symbols}', "");
Expect(0, 19967, '\P{Is_Block=- Yijing_hexagram_Symbols}', "");
Expect(1, 19967, '\P{^Is_Block=- Yijing_hexagram_Symbols}', "");
Expect(0, 19968, '\p{Is_Block=- Yijing_hexagram_Symbols}', "");
Expect(1, 19968, '\p{^Is_Block=- Yijing_hexagram_Symbols}', "");
Expect(1, 19968, '\P{Is_Block=- Yijing_hexagram_Symbols}', "");
Expect(0, 19968, '\P{^Is_Block=- Yijing_hexagram_Symbols}', "");
Error('\p{Is_Blk= yijing/a/}');
Error('\P{Is_Blk= yijing/a/}');
Expect(1, 19967, '\p{Is_Blk:yijing}', "");
Expect(0, 19967, '\p{^Is_Blk:yijing}', "");
Expect(0, 19967, '\P{Is_Blk:yijing}', "");
Expect(1, 19967, '\P{^Is_Blk:yijing}', "");
Expect(0, 19968, '\p{Is_Blk:yijing}', "");
Expect(1, 19968, '\p{^Is_Blk:yijing}', "");
Expect(1, 19968, '\P{Is_Blk:yijing}', "");
Expect(0, 19968, '\P{^Is_Blk:yijing}', "");
Expect(1, 19967, '\p{Is_Blk=		YIJING}', "");
Expect(0, 19967, '\p{^Is_Blk=		YIJING}', "");
Expect(0, 19967, '\P{Is_Blk=		YIJING}', "");
Expect(1, 19967, '\P{^Is_Blk=		YIJING}', "");
Expect(0, 19968, '\p{Is_Blk=		YIJING}', "");
Expect(1, 19968, '\p{^Is_Blk=		YIJING}', "");
Expect(1, 19968, '\P{Is_Blk=		YIJING}', "");
Expect(0, 19968, '\P{^Is_Blk=		YIJING}', "");
Error('\p{Bidi_Paired_Bracket_Type=/a/CLOSE}');
Error('\P{Bidi_Paired_Bracket_Type=/a/CLOSE}');
Expect(1, 65379, '\p{Bidi_Paired_Bracket_Type=close}', "");
Expect(0, 65379, '\p{^Bidi_Paired_Bracket_Type=close}', "");
Expect(0, 65379, '\P{Bidi_Paired_Bracket_Type=close}', "");
Expect(1, 65379, '\P{^Bidi_Paired_Bracket_Type=close}', "");
Expect(0, 65380, '\p{Bidi_Paired_Bracket_Type=close}', "");
Expect(1, 65380, '\p{^Bidi_Paired_Bracket_Type=close}', "");
Expect(1, 65380, '\P{Bidi_Paired_Bracket_Type=close}', "");
Expect(0, 65380, '\P{^Bidi_Paired_Bracket_Type=close}', "");
Expect(1, 65379, '\p{Bidi_Paired_Bracket_Type=  close}', "");
Expect(0, 65379, '\p{^Bidi_Paired_Bracket_Type=  close}', "");
Expect(0, 65379, '\P{Bidi_Paired_Bracket_Type=  close}', "");
Expect(1, 65379, '\P{^Bidi_Paired_Bracket_Type=  close}', "");
Expect(0, 65380, '\p{Bidi_Paired_Bracket_Type=  close}', "");
Expect(1, 65380, '\p{^Bidi_Paired_Bracket_Type=  close}', "");
Expect(1, 65380, '\P{Bidi_Paired_Bracket_Type=  close}', "");
Expect(0, 65380, '\P{^Bidi_Paired_Bracket_Type=  close}', "");
Error('\p{Bpt=/a/--c}');
Error('\P{Bpt=/a/--c}');
Expect(1, 65379, '\p{Bpt=c}', "");
Expect(0, 65379, '\p{^Bpt=c}', "");
Expect(0, 65379, '\P{Bpt=c}', "");
Expect(1, 65379, '\P{^Bpt=c}', "");
Expect(0, 65380, '\p{Bpt=c}', "");
Expect(1, 65380, '\p{^Bpt=c}', "");
Expect(1, 65380, '\P{Bpt=c}', "");
Expect(0, 65380, '\P{^Bpt=c}', "");
Expect(1, 65379, '\p{Bpt=	C}', "");
Expect(0, 65379, '\p{^Bpt=	C}', "");
Expect(0, 65379, '\P{Bpt=	C}', "");
Expect(1, 65379, '\P{^Bpt=	C}', "");
Expect(0, 65380, '\p{Bpt=	C}', "");
Expect(1, 65380, '\p{^Bpt=	C}', "");
Expect(1, 65380, '\P{Bpt=	C}', "");
Expect(0, 65380, '\P{^Bpt=	C}', "");
Error('\p{Is_Bidi_Paired_Bracket_Type=/a/	-Close}');
Error('\P{Is_Bidi_Paired_Bracket_Type=/a/	-Close}');
Expect(1, 65379, '\p{Is_Bidi_Paired_Bracket_Type=close}', "");
Expect(0, 65379, '\p{^Is_Bidi_Paired_Bracket_Type=close}', "");
Expect(0, 65379, '\P{Is_Bidi_Paired_Bracket_Type=close}', "");
Expect(1, 65379, '\P{^Is_Bidi_Paired_Bracket_Type=close}', "");
Expect(0, 65380, '\p{Is_Bidi_Paired_Bracket_Type=close}', "");
Expect(1, 65380, '\p{^Is_Bidi_Paired_Bracket_Type=close}', "");
Expect(1, 65380, '\P{Is_Bidi_Paired_Bracket_Type=close}', "");
Expect(0, 65380, '\P{^Is_Bidi_Paired_Bracket_Type=close}', "");
Expect(1, 65379, '\p{Is_Bidi_Paired_Bracket_Type=		Close}', "");
Expect(0, 65379, '\p{^Is_Bidi_Paired_Bracket_Type=		Close}', "");
Expect(0, 65379, '\P{Is_Bidi_Paired_Bracket_Type=		Close}', "");
Expect(1, 65379, '\P{^Is_Bidi_Paired_Bracket_Type=		Close}', "");
Expect(0, 65380, '\p{Is_Bidi_Paired_Bracket_Type=		Close}', "");
Expect(1, 65380, '\p{^Is_Bidi_Paired_Bracket_Type=		Close}', "");
Expect(1, 65380, '\P{Is_Bidi_Paired_Bracket_Type=		Close}', "");
Expect(0, 65380, '\P{^Is_Bidi_Paired_Bracket_Type=		Close}', "");
Error('\p{Is_Bpt=/a/-_c}');
Error('\P{Is_Bpt=/a/-_c}');
Expect(1, 65379, '\p{Is_Bpt=c}', "");
Expect(0, 65379, '\p{^Is_Bpt=c}', "");
Expect(0, 65379, '\P{Is_Bpt=c}', "");
Expect(1, 65379, '\P{^Is_Bpt=c}', "");
Expect(0, 65380, '\p{Is_Bpt=c}', "");
Expect(1, 65380, '\p{^Is_Bpt=c}', "");
Expect(1, 65380, '\P{Is_Bpt=c}', "");
Expect(0, 65380, '\P{^Is_Bpt=c}', "");
Expect(1, 65379, '\p{Is_Bpt=	_C}', "");
Expect(0, 65379, '\p{^Is_Bpt=	_C}', "");
Expect(0, 65379, '\P{Is_Bpt=	_C}', "");
Expect(1, 65379, '\P{^Is_Bpt=	_C}', "");
Expect(0, 65380, '\p{Is_Bpt=	_C}', "");
Expect(1, 65380, '\p{^Is_Bpt=	_C}', "");
Expect(1, 65380, '\P{Is_Bpt=	_C}', "");
Expect(0, 65380, '\P{^Is_Bpt=	_C}', "");
Error('\p{Bidi_Paired_Bracket_Type=_	None:=}');
Error('\P{Bidi_Paired_Bracket_Type=_	None:=}');
Expect(1, 65380, '\p{Bidi_Paired_Bracket_Type: none}', "");
Expect(0, 65380, '\p{^Bidi_Paired_Bracket_Type: none}', "");
Expect(0, 65380, '\P{Bidi_Paired_Bracket_Type: none}', "");
Expect(1, 65380, '\P{^Bidi_Paired_Bracket_Type: none}', "");
Expect(0, 65379, '\p{Bidi_Paired_Bracket_Type: none}', "");
Expect(1, 65379, '\p{^Bidi_Paired_Bracket_Type: none}', "");
Expect(1, 65379, '\P{Bidi_Paired_Bracket_Type: none}', "");
Expect(0, 65379, '\P{^Bidi_Paired_Bracket_Type: none}', "");
Expect(1, 65380, '\p{Bidi_Paired_Bracket_Type:-NONE}', "");
Expect(0, 65380, '\p{^Bidi_Paired_Bracket_Type:-NONE}', "");
Expect(0, 65380, '\P{Bidi_Paired_Bracket_Type:-NONE}', "");
Expect(1, 65380, '\P{^Bidi_Paired_Bracket_Type:-NONE}', "");
Expect(0, 65379, '\p{Bidi_Paired_Bracket_Type:-NONE}', "");
Expect(1, 65379, '\p{^Bidi_Paired_Bracket_Type:-NONE}', "");
Expect(1, 65379, '\P{Bidi_Paired_Bracket_Type:-NONE}', "");
Expect(0, 65379, '\P{^Bidi_Paired_Bracket_Type:-NONE}', "");
Error('\p{Bpt= /a/N}');
Error('\P{Bpt= /a/N}');
Expect(1, 65380, '\p{Bpt=n}', "");
Expect(0, 65380, '\p{^Bpt=n}', "");
Expect(0, 65380, '\P{Bpt=n}', "");
Expect(1, 65380, '\P{^Bpt=n}', "");
Expect(0, 65379, '\p{Bpt=n}', "");
Expect(1, 65379, '\p{^Bpt=n}', "");
Expect(1, 65379, '\P{Bpt=n}', "");
Expect(0, 65379, '\P{^Bpt=n}', "");
Expect(1, 65380, '\p{Bpt=_n}', "");
Expect(0, 65380, '\p{^Bpt=_n}', "");
Expect(0, 65380, '\P{Bpt=_n}', "");
Expect(1, 65380, '\P{^Bpt=_n}', "");
Expect(0, 65379, '\p{Bpt=_n}', "");
Expect(1, 65379, '\p{^Bpt=_n}', "");
Expect(1, 65379, '\P{Bpt=_n}', "");
Expect(0, 65379, '\P{^Bpt=_n}', "");
Error('\p{Is_Bidi_Paired_Bracket_Type=/a/__none}');
Error('\P{Is_Bidi_Paired_Bracket_Type=/a/__none}');
Expect(1, 65380, '\p{Is_Bidi_Paired_Bracket_Type=none}', "");
Expect(0, 65380, '\p{^Is_Bidi_Paired_Bracket_Type=none}', "");
Expect(0, 65380, '\P{Is_Bidi_Paired_Bracket_Type=none}', "");
Expect(1, 65380, '\P{^Is_Bidi_Paired_Bracket_Type=none}', "");
Expect(0, 65379, '\p{Is_Bidi_Paired_Bracket_Type=none}', "");
Expect(1, 65379, '\p{^Is_Bidi_Paired_Bracket_Type=none}', "");
Expect(1, 65379, '\P{Is_Bidi_Paired_Bracket_Type=none}', "");
Expect(0, 65379, '\P{^Is_Bidi_Paired_Bracket_Type=none}', "");
Expect(1, 65380, '\p{Is_Bidi_Paired_Bracket_Type=  none}', "");
Expect(0, 65380, '\p{^Is_Bidi_Paired_Bracket_Type=  none}', "");
Expect(0, 65380, '\P{Is_Bidi_Paired_Bracket_Type=  none}', "");
Expect(1, 65380, '\P{^Is_Bidi_Paired_Bracket_Type=  none}', "");
Expect(0, 65379, '\p{Is_Bidi_Paired_Bracket_Type=  none}', "");
Expect(1, 65379, '\p{^Is_Bidi_Paired_Bracket_Type=  none}', "");
Expect(1, 65379, '\P{Is_Bidi_Paired_Bracket_Type=  none}', "");
Expect(0, 65379, '\P{^Is_Bidi_Paired_Bracket_Type=  none}', "");
Error('\p{Is_Bpt=--N/a/}');
Error('\P{Is_Bpt=--N/a/}');
Expect(1, 65380, '\p{Is_Bpt=n}', "");
Expect(0, 65380, '\p{^Is_Bpt=n}', "");
Expect(0, 65380, '\P{Is_Bpt=n}', "");
Expect(1, 65380, '\P{^Is_Bpt=n}', "");
Expect(0, 65379, '\p{Is_Bpt=n}', "");
Expect(1, 65379, '\p{^Is_Bpt=n}', "");
Expect(1, 65379, '\P{Is_Bpt=n}', "");
Expect(0, 65379, '\P{^Is_Bpt=n}', "");
Expect(1, 65380, '\p{Is_Bpt=_N}', "");
Expect(0, 65380, '\p{^Is_Bpt=_N}', "");
Expect(0, 65380, '\P{Is_Bpt=_N}', "");
Expect(1, 65380, '\P{^Is_Bpt=_N}', "");
Expect(0, 65379, '\p{Is_Bpt=_N}', "");
Expect(1, 65379, '\p{^Is_Bpt=_N}', "");
Expect(1, 65379, '\P{Is_Bpt=_N}', "");
Expect(0, 65379, '\P{^Is_Bpt=_N}', "");
Error('\p{Bidi_Paired_Bracket_Type:/a/	Open}');
Error('\P{Bidi_Paired_Bracket_Type:/a/	Open}');
Expect(1, 65378, '\p{Bidi_Paired_Bracket_Type=open}', "");
Expect(0, 65378, '\p{^Bidi_Paired_Bracket_Type=open}', "");
Expect(0, 65378, '\P{Bidi_Paired_Bracket_Type=open}', "");
Expect(1, 65378, '\P{^Bidi_Paired_Bracket_Type=open}', "");
Expect(0, 65379, '\p{Bidi_Paired_Bracket_Type=open}', "");
Expect(1, 65379, '\p{^Bidi_Paired_Bracket_Type=open}', "");
Expect(1, 65379, '\P{Bidi_Paired_Bracket_Type=open}', "");
Expect(0, 65379, '\P{^Bidi_Paired_Bracket_Type=open}', "");
Expect(1, 65378, '\p{Bidi_Paired_Bracket_Type=	_open}', "");
Expect(0, 65378, '\p{^Bidi_Paired_Bracket_Type=	_open}', "");
Expect(0, 65378, '\P{Bidi_Paired_Bracket_Type=	_open}', "");
Expect(1, 65378, '\P{^Bidi_Paired_Bracket_Type=	_open}', "");
Expect(0, 65379, '\p{Bidi_Paired_Bracket_Type=	_open}', "");
Expect(1, 65379, '\p{^Bidi_Paired_Bracket_Type=	_open}', "");
Expect(1, 65379, '\P{Bidi_Paired_Bracket_Type=	_open}', "");
Expect(0, 65379, '\P{^Bidi_Paired_Bracket_Type=	_open}', "");
Error('\p{Bpt=:=		O}');
Error('\P{Bpt=:=		O}');
Expect(1, 65378, '\p{Bpt=o}', "");
Expect(0, 65378, '\p{^Bpt=o}', "");
Expect(0, 65378, '\P{Bpt=o}', "");
Expect(1, 65378, '\P{^Bpt=o}', "");
Expect(0, 65379, '\p{Bpt=o}', "");
Expect(1, 65379, '\p{^Bpt=o}', "");
Expect(1, 65379, '\P{Bpt=o}', "");
Expect(0, 65379, '\P{^Bpt=o}', "");
Expect(1, 65378, '\p{Bpt=- O}', "");
Expect(0, 65378, '\p{^Bpt=- O}', "");
Expect(0, 65378, '\P{Bpt=- O}', "");
Expect(1, 65378, '\P{^Bpt=- O}', "");
Expect(0, 65379, '\p{Bpt=- O}', "");
Expect(1, 65379, '\p{^Bpt=- O}', "");
Expect(1, 65379, '\P{Bpt=- O}', "");
Expect(0, 65379, '\P{^Bpt=- O}', "");
Error('\p{Is_Bidi_Paired_Bracket_Type= /a/open}');
Error('\P{Is_Bidi_Paired_Bracket_Type= /a/open}');
Expect(1, 65378, '\p{Is_Bidi_Paired_Bracket_Type=open}', "");
Expect(0, 65378, '\p{^Is_Bidi_Paired_Bracket_Type=open}', "");
Expect(0, 65378, '\P{Is_Bidi_Paired_Bracket_Type=open}', "");
Expect(1, 65378, '\P{^Is_Bidi_Paired_Bracket_Type=open}', "");
Expect(0, 65379, '\p{Is_Bidi_Paired_Bracket_Type=open}', "");
Expect(1, 65379, '\p{^Is_Bidi_Paired_Bracket_Type=open}', "");
Expect(1, 65379, '\P{Is_Bidi_Paired_Bracket_Type=open}', "");
Expect(0, 65379, '\P{^Is_Bidi_Paired_Bracket_Type=open}', "");
Expect(1, 65378, '\p{Is_Bidi_Paired_Bracket_Type=		Open}', "");
Expect(0, 65378, '\p{^Is_Bidi_Paired_Bracket_Type=		Open}', "");
Expect(0, 65378, '\P{Is_Bidi_Paired_Bracket_Type=		Open}', "");
Expect(1, 65378, '\P{^Is_Bidi_Paired_Bracket_Type=		Open}', "");
Expect(0, 65379, '\p{Is_Bidi_Paired_Bracket_Type=		Open}', "");
Expect(1, 65379, '\p{^Is_Bidi_Paired_Bracket_Type=		Open}', "");
Expect(1, 65379, '\P{Is_Bidi_Paired_Bracket_Type=		Open}', "");
Expect(0, 65379, '\P{^Is_Bidi_Paired_Bracket_Type=		Open}', "");
Error('\p{Is_Bpt=	/a/o}');
Error('\P{Is_Bpt=	/a/o}');
Expect(1, 65378, '\p{Is_Bpt=o}', "");
Expect(0, 65378, '\p{^Is_Bpt=o}', "");
Expect(0, 65378, '\P{Is_Bpt=o}', "");
Expect(1, 65378, '\P{^Is_Bpt=o}', "");
Expect(0, 65379, '\p{Is_Bpt=o}', "");
Expect(1, 65379, '\p{^Is_Bpt=o}', "");
Expect(1, 65379, '\P{Is_Bpt=o}', "");
Expect(0, 65379, '\P{^Is_Bpt=o}', "");
Expect(1, 65378, '\p{Is_Bpt=-O}', "");
Expect(0, 65378, '\p{^Is_Bpt=-O}', "");
Expect(0, 65378, '\P{Is_Bpt=-O}', "");
Expect(1, 65378, '\P{^Is_Bpt=-O}', "");
Expect(0, 65379, '\p{Is_Bpt=-O}', "");
Expect(1, 65379, '\p{^Is_Bpt=-O}', "");
Expect(1, 65379, '\P{Is_Bpt=-O}', "");
Expect(0, 65379, '\P{^Is_Bpt=-O}', "");
Error('\p{Canonical_Combining_Class=/a/- Above}');
Error('\P{Canonical_Combining_Class=/a/- Above}');
Expect(1, 119364, '\p{Canonical_Combining_Class=above}', "");
Expect(0, 119364, '\p{^Canonical_Combining_Class=above}', "");
Expect(0, 119364, '\P{Canonical_Combining_Class=above}', "");
Expect(1, 119364, '\P{^Canonical_Combining_Class=above}', "");
Expect(0, 119365, '\p{Canonical_Combining_Class=above}', "");
Expect(1, 119365, '\p{^Canonical_Combining_Class=above}', "");
Expect(1, 119365, '\P{Canonical_Combining_Class=above}', "");
Expect(0, 119365, '\P{^Canonical_Combining_Class=above}', "");
Expect(1, 119364, '\p{Canonical_Combining_Class= _Above}', "");
Expect(0, 119364, '\p{^Canonical_Combining_Class= _Above}', "");
Expect(0, 119364, '\P{Canonical_Combining_Class= _Above}', "");
Expect(1, 119364, '\P{^Canonical_Combining_Class= _Above}', "");
Expect(0, 119365, '\p{Canonical_Combining_Class= _Above}', "");
Expect(1, 119365, '\p{^Canonical_Combining_Class= _Above}', "");
Expect(1, 119365, '\P{Canonical_Combining_Class= _Above}', "");
Expect(0, 119365, '\P{^Canonical_Combining_Class= _Above}', "");
Error('\p{Ccc=:=_-A}');
Error('\P{Ccc=:=_-A}');
Expect(1, 119364, '\p{Ccc=a}', "");
Expect(0, 119364, '\p{^Ccc=a}', "");
Expect(0, 119364, '\P{Ccc=a}', "");
Expect(1, 119364, '\P{^Ccc=a}', "");
Expect(0, 119365, '\p{Ccc=a}', "");
Expect(1, 119365, '\p{^Ccc=a}', "");
Expect(1, 119365, '\P{Ccc=a}', "");
Expect(0, 119365, '\P{^Ccc=a}', "");
Expect(1, 119364, '\p{Ccc=-A}', "");
Expect(0, 119364, '\p{^Ccc=-A}', "");
Expect(0, 119364, '\P{Ccc=-A}', "");
Expect(1, 119364, '\P{^Ccc=-A}', "");
Expect(0, 119365, '\p{Ccc=-A}', "");
Expect(1, 119365, '\p{^Ccc=-A}', "");
Expect(1, 119365, '\P{Ccc=-A}', "");
Expect(0, 119365, '\P{^Ccc=-A}', "");
Error('\p{Is_Canonical_Combining_Class=_000000000230/a/}');
Error('\P{Is_Canonical_Combining_Class=_000000000230/a/}');
Expect(1, 119364, '\p{Is_Canonical_Combining_Class:   000000000230}', "");
Expect(0, 119364, '\p{^Is_Canonical_Combining_Class:   000000000230}', "");
Expect(0, 119364, '\P{Is_Canonical_Combining_Class:   000000000230}', "");
Expect(1, 119364, '\P{^Is_Canonical_Combining_Class:   000000000230}', "");
Expect(0, 119365, '\p{Is_Canonical_Combining_Class:   000000000230}', "");
Expect(1, 119365, '\p{^Is_Canonical_Combining_Class:   000000000230}', "");
Expect(1, 119365, '\P{Is_Canonical_Combining_Class:   000000000230}', "");
Expect(0, 119365, '\P{^Is_Canonical_Combining_Class:   000000000230}', "");
Error('\p{Is_Ccc=_above:=}');
Error('\P{Is_Ccc=_above:=}');
Expect(1, 119364, '\p{Is_Ccc=above}', "");
Expect(0, 119364, '\p{^Is_Ccc=above}', "");
Expect(0, 119364, '\P{Is_Ccc=above}', "");
Expect(1, 119364, '\P{^Is_Ccc=above}', "");
Expect(0, 119365, '\p{Is_Ccc=above}', "");
Expect(1, 119365, '\p{^Is_Ccc=above}', "");
Expect(1, 119365, '\P{Is_Ccc=above}', "");
Expect(0, 119365, '\P{^Is_Ccc=above}', "");
Expect(1, 119364, '\p{Is_Ccc=_	above}', "");
Expect(0, 119364, '\p{^Is_Ccc=_	above}', "");
Expect(0, 119364, '\P{Is_Ccc=_	above}', "");
Expect(1, 119364, '\P{^Is_Ccc=_	above}', "");
Expect(0, 119365, '\p{Is_Ccc=_	above}', "");
Expect(1, 119365, '\p{^Is_Ccc=_	above}', "");
Expect(1, 119365, '\P{Is_Ccc=_	above}', "");
Expect(0, 119365, '\P{^Is_Ccc=_	above}', "");
Error('\p{Canonical_Combining_Class= -above_LEFT:=}');
Error('\P{Canonical_Combining_Class= -above_LEFT:=}');
Expect(1, 12331, '\p{Canonical_Combining_Class=aboveleft}', "");
Expect(0, 12331, '\p{^Canonical_Combining_Class=aboveleft}', "");
Expect(0, 12331, '\P{Canonical_Combining_Class=aboveleft}', "");
Expect(1, 12331, '\P{^Canonical_Combining_Class=aboveleft}', "");
Expect(0, 12332, '\p{Canonical_Combining_Class=aboveleft}', "");
Expect(1, 12332, '\p{^Canonical_Combining_Class=aboveleft}', "");
Expect(1, 12332, '\P{Canonical_Combining_Class=aboveleft}', "");
Expect(0, 12332, '\P{^Canonical_Combining_Class=aboveleft}', "");
Expect(1, 12331, '\p{Canonical_Combining_Class= _ABOVE_Left}', "");
Expect(0, 12331, '\p{^Canonical_Combining_Class= _ABOVE_Left}', "");
Expect(0, 12331, '\P{Canonical_Combining_Class= _ABOVE_Left}', "");
Expect(1, 12331, '\P{^Canonical_Combining_Class= _ABOVE_Left}', "");
Expect(0, 12332, '\p{Canonical_Combining_Class= _ABOVE_Left}', "");
Expect(1, 12332, '\p{^Canonical_Combining_Class= _ABOVE_Left}', "");
Expect(1, 12332, '\P{Canonical_Combining_Class= _ABOVE_Left}', "");
Expect(0, 12332, '\P{^Canonical_Combining_Class= _ABOVE_Left}', "");
Error('\p{Ccc=:=	AL}');
Error('\P{Ccc=:=	AL}');
Expect(1, 12331, '\p{Ccc=al}', "");
Expect(0, 12331, '\p{^Ccc=al}', "");
Expect(0, 12331, '\P{Ccc=al}', "");
Expect(1, 12331, '\P{^Ccc=al}', "");
Expect(0, 12332, '\p{Ccc=al}', "");
Expect(1, 12332, '\p{^Ccc=al}', "");
Expect(1, 12332, '\P{Ccc=al}', "");
Expect(0, 12332, '\P{^Ccc=al}', "");
Expect(1, 12331, '\p{Ccc=	AL}', "");
Expect(0, 12331, '\p{^Ccc=	AL}', "");
Expect(0, 12331, '\P{Ccc=	AL}', "");
Expect(1, 12331, '\P{^Ccc=	AL}', "");
Expect(0, 12332, '\p{Ccc=	AL}', "");
Expect(1, 12332, '\p{^Ccc=	AL}', "");
Expect(1, 12332, '\P{Ccc=	AL}', "");
Expect(0, 12332, '\P{^Ccc=	AL}', "");
Error('\p{Is_Canonical_Combining_Class=-_0_0_0_0_0_0_0_0228:=}');
Error('\P{Is_Canonical_Combining_Class=-_0_0_0_0_0_0_0_0228:=}');
Expect(1, 12331, '\p{Is_Canonical_Combining_Class:   +000000000228}', "");
Expect(0, 12331, '\p{^Is_Canonical_Combining_Class:   +000000000228}', "");
Expect(0, 12331, '\P{Is_Canonical_Combining_Class:   +000000000228}', "");
Expect(1, 12331, '\P{^Is_Canonical_Combining_Class:   +000000000228}', "");
Expect(0, 12332, '\p{Is_Canonical_Combining_Class:   +000000000228}', "");
Expect(1, 12332, '\p{^Is_Canonical_Combining_Class:   +000000000228}', "");
Expect(1, 12332, '\P{Is_Canonical_Combining_Class:   +000000000228}', "");
Expect(0, 12332, '\P{^Is_Canonical_Combining_Class:   +000000000228}', "");
Error('\p{Is_Ccc=	_above_LEFT/a/}');
Error('\P{Is_Ccc=	_above_LEFT/a/}');
Expect(1, 12331, '\p{Is_Ccc: aboveleft}', "");
Expect(0, 12331, '\p{^Is_Ccc: aboveleft}', "");
Expect(0, 12331, '\P{Is_Ccc: aboveleft}', "");
Expect(1, 12331, '\P{^Is_Ccc: aboveleft}', "");
Expect(0, 12332, '\p{Is_Ccc: aboveleft}', "");
Expect(1, 12332, '\p{^Is_Ccc: aboveleft}', "");
Expect(1, 12332, '\P{Is_Ccc: aboveleft}', "");
Expect(0, 12332, '\P{^Is_Ccc: aboveleft}', "");
Expect(1, 12331, '\p{Is_Ccc=	 above_left}', "");
Expect(0, 12331, '\p{^Is_Ccc=	 above_left}', "");
Expect(0, 12331, '\P{Is_Ccc=	 above_left}', "");
Expect(1, 12331, '\P{^Is_Ccc=	 above_left}', "");
Expect(0, 12332, '\p{Is_Ccc=	 above_left}', "");
Expect(1, 12332, '\p{^Is_Ccc=	 above_left}', "");
Expect(1, 12332, '\P{Is_Ccc=	 above_left}', "");
Expect(0, 12332, '\P{^Is_Ccc=	 above_left}', "");
Error('\p{Canonical_Combining_Class= above_Right:=}');
Error('\P{Canonical_Combining_Class= above_Right:=}');
Expect(1, 12332, '\p{Canonical_Combining_Class=aboveright}', "");
Expect(0, 12332, '\p{^Canonical_Combining_Class=aboveright}', "");
Expect(0, 12332, '\P{Canonical_Combining_Class=aboveright}', "");
Expect(1, 12332, '\P{^Canonical_Combining_Class=aboveright}', "");
Expect(0, 12333, '\p{Canonical_Combining_Class=aboveright}', "");
Expect(1, 12333, '\p{^Canonical_Combining_Class=aboveright}', "");
Expect(1, 12333, '\P{Canonical_Combining_Class=aboveright}', "");
Expect(0, 12333, '\P{^Canonical_Combining_Class=aboveright}', "");
Expect(1, 12332, '\p{Canonical_Combining_Class=-ABOVE_Right}', "");
Expect(0, 12332, '\p{^Canonical_Combining_Class=-ABOVE_Right}', "");
Expect(0, 12332, '\P{Canonical_Combining_Class=-ABOVE_Right}', "");
Expect(1, 12332, '\P{^Canonical_Combining_Class=-ABOVE_Right}', "");
Expect(0, 12333, '\p{Canonical_Combining_Class=-ABOVE_Right}', "");
Expect(1, 12333, '\p{^Canonical_Combining_Class=-ABOVE_Right}', "");
Expect(1, 12333, '\P{Canonical_Combining_Class=-ABOVE_Right}', "");
Expect(0, 12333, '\P{^Canonical_Combining_Class=-ABOVE_Right}', "");
Error('\p{Ccc=_:=AR}');
Error('\P{Ccc=_:=AR}');
Expect(1, 12332, '\p{Ccc=ar}', "");
Expect(0, 12332, '\p{^Ccc=ar}', "");
Expect(0, 12332, '\P{Ccc=ar}', "");
Expect(1, 12332, '\P{^Ccc=ar}', "");
Expect(0, 12333, '\p{Ccc=ar}', "");
Expect(1, 12333, '\p{^Ccc=ar}', "");
Expect(1, 12333, '\P{Ccc=ar}', "");
Expect(0, 12333, '\P{^Ccc=ar}', "");
Expect(1, 12332, '\p{Ccc=	ar}', "");
Expect(0, 12332, '\p{^Ccc=	ar}', "");
Expect(0, 12332, '\P{Ccc=	ar}', "");
Expect(1, 12332, '\P{^Ccc=	ar}', "");
Expect(0, 12333, '\p{Ccc=	ar}', "");
Expect(1, 12333, '\p{^Ccc=	ar}', "");
Expect(1, 12333, '\P{Ccc=	ar}', "");
Expect(0, 12333, '\P{^Ccc=	ar}', "");
Error('\p{Is_Canonical_Combining_Class= _000232:=}');
Error('\P{Is_Canonical_Combining_Class= _000232:=}');
Expect(1, 12332, '\p{Is_Canonical_Combining_Class=+000232}', "");
Expect(0, 12332, '\p{^Is_Canonical_Combining_Class=+000232}', "");
Expect(0, 12332, '\P{Is_Canonical_Combining_Class=+000232}', "");
Expect(1, 12332, '\P{^Is_Canonical_Combining_Class=+000232}', "");
Expect(0, 12333, '\p{Is_Canonical_Combining_Class=+000232}', "");
Expect(1, 12333, '\p{^Is_Canonical_Combining_Class=+000232}', "");
Expect(1, 12333, '\P{Is_Canonical_Combining_Class=+000232}', "");
Expect(0, 12333, '\P{^Is_Canonical_Combining_Class=+000232}', "");
Error('\p{Is_Ccc= Above_Right/a/}');
Error('\P{Is_Ccc= Above_Right/a/}');
Expect(1, 12332, '\p{Is_Ccc=aboveright}', "");
Expect(0, 12332, '\p{^Is_Ccc=aboveright}', "");
Expect(0, 12332, '\P{Is_Ccc=aboveright}', "");
Expect(1, 12332, '\P{^Is_Ccc=aboveright}', "");
Expect(0, 12333, '\p{Is_Ccc=aboveright}', "");
Expect(1, 12333, '\p{^Is_Ccc=aboveright}', "");
Expect(1, 12333, '\P{Is_Ccc=aboveright}', "");
Expect(0, 12333, '\P{^Is_Ccc=aboveright}', "");
Expect(1, 12332, '\p{Is_Ccc= -Above_Right}', "");
Expect(0, 12332, '\p{^Is_Ccc= -Above_Right}', "");
Expect(0, 12332, '\P{Is_Ccc= -Above_Right}', "");
Expect(1, 12332, '\P{^Is_Ccc= -Above_Right}', "");
Expect(0, 12333, '\p{Is_Ccc= -Above_Right}', "");
Expect(1, 12333, '\p{^Is_Ccc= -Above_Right}', "");
Expect(1, 12333, '\P{Is_Ccc= -Above_Right}', "");
Expect(0, 12333, '\P{^Is_Ccc= -Above_Right}', "");
Error('\p{Canonical_Combining_Class:   -_Attached_above:=}');
Error('\P{Canonical_Combining_Class:   -_Attached_above:=}');
Expect(1, 7630, '\p{Canonical_Combining_Class:	attachedabove}', "");
Expect(0, 7630, '\p{^Canonical_Combining_Class:	attachedabove}', "");
Expect(0, 7630, '\P{Canonical_Combining_Class:	attachedabove}', "");
Expect(1, 7630, '\P{^Canonical_Combining_Class:	attachedabove}', "");
Expect(0, 7631, '\p{Canonical_Combining_Class:	attachedabove}', "");
Expect(1, 7631, '\p{^Canonical_Combining_Class:	attachedabove}', "");
Expect(1, 7631, '\P{Canonical_Combining_Class:	attachedabove}', "");
Expect(0, 7631, '\P{^Canonical_Combining_Class:	attachedabove}', "");
Expect(1, 7630, '\p{Canonical_Combining_Class=	 ATTACHED_ABOVE}', "");
Expect(0, 7630, '\p{^Canonical_Combining_Class=	 ATTACHED_ABOVE}', "");
Expect(0, 7630, '\P{Canonical_Combining_Class=	 ATTACHED_ABOVE}', "");
Expect(1, 7630, '\P{^Canonical_Combining_Class=	 ATTACHED_ABOVE}', "");
Expect(0, 7631, '\p{Canonical_Combining_Class=	 ATTACHED_ABOVE}', "");
Expect(1, 7631, '\p{^Canonical_Combining_Class=	 ATTACHED_ABOVE}', "");
Expect(1, 7631, '\P{Canonical_Combining_Class=	 ATTACHED_ABOVE}', "");
Expect(0, 7631, '\P{^Canonical_Combining_Class=	 ATTACHED_ABOVE}', "");
Error('\p{Ccc=/a/-	ATA}');
Error('\P{Ccc=/a/-	ATA}');
Expect(1, 7630, '\p{Ccc=ata}', "");
Expect(0, 7630, '\p{^Ccc=ata}', "");
Expect(0, 7630, '\P{Ccc=ata}', "");
Expect(1, 7630, '\P{^Ccc=ata}', "");
Expect(0, 7631, '\p{Ccc=ata}', "");
Expect(1, 7631, '\p{^Ccc=ata}', "");
Expect(1, 7631, '\P{Ccc=ata}', "");
Expect(0, 7631, '\P{^Ccc=ata}', "");
Expect(1, 7630, '\p{Ccc=-ATA}', "");
Expect(0, 7630, '\p{^Ccc=-ATA}', "");
Expect(0, 7630, '\P{Ccc=-ATA}', "");
Expect(1, 7630, '\P{^Ccc=-ATA}', "");
Expect(0, 7631, '\p{Ccc=-ATA}', "");
Expect(1, 7631, '\p{^Ccc=-ATA}', "");
Expect(1, 7631, '\P{Ccc=-ATA}', "");
Expect(0, 7631, '\P{^Ccc=-ATA}', "");
Error('\p{Is_Canonical_Combining_Class=_ 00000_00021_4/a/}');
Error('\P{Is_Canonical_Combining_Class=_ 00000_00021_4/a/}');
Expect(1, 7630, '\p{Is_Canonical_Combining_Class=+00000000214}', "");
Expect(0, 7630, '\p{^Is_Canonical_Combining_Class=+00000000214}', "");
Expect(0, 7630, '\P{Is_Canonical_Combining_Class=+00000000214}', "");
Expect(1, 7630, '\P{^Is_Canonical_Combining_Class=+00000000214}', "");
Expect(0, 7631, '\p{Is_Canonical_Combining_Class=+00000000214}', "");
Expect(1, 7631, '\p{^Is_Canonical_Combining_Class=+00000000214}', "");
Expect(1, 7631, '\P{Is_Canonical_Combining_Class=+00000000214}', "");
Expect(0, 7631, '\P{^Is_Canonical_Combining_Class=+00000000214}', "");
Error('\p{Is_Ccc:		Attached_ABOVE:=}');
Error('\P{Is_Ccc:		Attached_ABOVE:=}');
Expect(1, 7630, '\p{Is_Ccc=attachedabove}', "");
Expect(0, 7630, '\p{^Is_Ccc=attachedabove}', "");
Expect(0, 7630, '\P{Is_Ccc=attachedabove}', "");
Expect(1, 7630, '\P{^Is_Ccc=attachedabove}', "");
Expect(0, 7631, '\p{Is_Ccc=attachedabove}', "");
Expect(1, 7631, '\p{^Is_Ccc=attachedabove}', "");
Expect(1, 7631, '\P{Is_Ccc=attachedabove}', "");
Expect(0, 7631, '\P{^Is_Ccc=attachedabove}', "");
Expect(1, 7630, '\p{Is_Ccc=_	Attached_Above}', "");
Expect(0, 7630, '\p{^Is_Ccc=_	Attached_Above}', "");
Expect(0, 7630, '\P{Is_Ccc=_	Attached_Above}', "");
Expect(1, 7630, '\P{^Is_Ccc=_	Attached_Above}', "");
Expect(0, 7631, '\p{Is_Ccc=_	Attached_Above}', "");
Expect(1, 7631, '\p{^Is_Ccc=_	Attached_Above}', "");
Expect(1, 7631, '\P{Is_Ccc=_	Attached_Above}', "");
Expect(0, 7631, '\P{^Is_Ccc=_	Attached_Above}', "");
Error('\p{Canonical_Combining_Class:   /a/attached_Above_Right}');
Error('\P{Canonical_Combining_Class:   /a/attached_Above_Right}');
Expect(1, 119154, '\p{Canonical_Combining_Class=attachedaboveright}', "");
Expect(0, 119154, '\p{^Canonical_Combining_Class=attachedaboveright}', "");
Expect(0, 119154, '\P{Canonical_Combining_Class=attachedaboveright}', "");
Expect(1, 119154, '\P{^Canonical_Combining_Class=attachedaboveright}', "");
Expect(0, 119155, '\p{Canonical_Combining_Class=attachedaboveright}', "");
Expect(1, 119155, '\p{^Canonical_Combining_Class=attachedaboveright}', "");
Expect(1, 119155, '\P{Canonical_Combining_Class=attachedaboveright}', "");
Expect(0, 119155, '\P{^Canonical_Combining_Class=attachedaboveright}', "");
Expect(1, 119154, '\p{Canonical_Combining_Class=		attached_ABOVE_right}', "");
Expect(0, 119154, '\p{^Canonical_Combining_Class=		attached_ABOVE_right}', "");
Expect(0, 119154, '\P{Canonical_Combining_Class=		attached_ABOVE_right}', "");
Expect(1, 119154, '\P{^Canonical_Combining_Class=		attached_ABOVE_right}', "");
Expect(0, 119155, '\p{Canonical_Combining_Class=		attached_ABOVE_right}', "");
Expect(1, 119155, '\p{^Canonical_Combining_Class=		attached_ABOVE_right}', "");
Expect(1, 119155, '\P{Canonical_Combining_Class=		attached_ABOVE_right}', "");
Expect(0, 119155, '\P{^Canonical_Combining_Class=		attached_ABOVE_right}', "");
Error('\p{Ccc=	:=ATAR}');
Error('\P{Ccc=	:=ATAR}');
Expect(1, 119154, '\p{Ccc=atar}', "");
Expect(0, 119154, '\p{^Ccc=atar}', "");
Expect(0, 119154, '\P{Ccc=atar}', "");
Expect(1, 119154, '\P{^Ccc=atar}', "");
Expect(0, 119155, '\p{Ccc=atar}', "");
Expect(1, 119155, '\p{^Ccc=atar}', "");
Expect(1, 119155, '\P{Ccc=atar}', "");
Expect(0, 119155, '\P{^Ccc=atar}', "");
Expect(1, 119154, '\p{Ccc=		ATAR}', "");
Expect(0, 119154, '\p{^Ccc=		ATAR}', "");
Expect(0, 119154, '\P{Ccc=		ATAR}', "");
Expect(1, 119154, '\P{^Ccc=		ATAR}', "");
Expect(0, 119155, '\p{Ccc=		ATAR}', "");
Expect(1, 119155, '\p{^Ccc=		ATAR}', "");
Expect(1, 119155, '\P{Ccc=		ATAR}', "");
Expect(0, 119155, '\P{^Ccc=		ATAR}', "");
Error('\p{Is_Canonical_Combining_Class=  000000216/a/}');
Error('\P{Is_Canonical_Combining_Class=  000000216/a/}');
Expect(1, 119154, '\p{Is_Canonical_Combining_Class=+00_02_16}', "");
Expect(0, 119154, '\p{^Is_Canonical_Combining_Class=+00_02_16}', "");
Expect(0, 119154, '\P{Is_Canonical_Combining_Class=+00_02_16}', "");
Expect(1, 119154, '\P{^Is_Canonical_Combining_Class=+00_02_16}', "");
Expect(0, 119155, '\p{Is_Canonical_Combining_Class=+00_02_16}', "");
Expect(1, 119155, '\p{^Is_Canonical_Combining_Class=+00_02_16}', "");
Expect(1, 119155, '\P{Is_Canonical_Combining_Class=+00_02_16}', "");
Expect(0, 119155, '\P{^Is_Canonical_Combining_Class=+00_02_16}', "");
Error('\p{Is_Ccc=_:=Attached_ABOVE_Right}');
Error('\P{Is_Ccc=_:=Attached_ABOVE_Right}');
Expect(1, 119154, '\p{Is_Ccc=attachedaboveright}', "");
Expect(0, 119154, '\p{^Is_Ccc=attachedaboveright}', "");
Expect(0, 119154, '\P{Is_Ccc=attachedaboveright}', "");
Expect(1, 119154, '\P{^Is_Ccc=attachedaboveright}', "");
Expect(0, 119155, '\p{Is_Ccc=attachedaboveright}', "");
Expect(1, 119155, '\p{^Is_Ccc=attachedaboveright}', "");
Expect(1, 119155, '\P{Is_Ccc=attachedaboveright}', "");
Expect(0, 119155, '\P{^Is_Ccc=attachedaboveright}', "");
Expect(1, 119154, '\p{Is_Ccc:		-attached_ABOVE_Right}', "");
Expect(0, 119154, '\p{^Is_Ccc:		-attached_ABOVE_Right}', "");
Expect(0, 119154, '\P{Is_Ccc:		-attached_ABOVE_Right}', "");
Expect(1, 119154, '\P{^Is_Ccc:		-attached_ABOVE_Right}', "");
Expect(0, 119155, '\p{Is_Ccc:		-attached_ABOVE_Right}', "");
Expect(1, 119155, '\p{^Is_Ccc:		-attached_ABOVE_Right}', "");
Expect(1, 119155, '\P{Is_Ccc:		-attached_ABOVE_Right}', "");
Expect(0, 119155, '\P{^Is_Ccc:		-attached_ABOVE_Right}', "");
Error('\p{Canonical_Combining_Class=/a/-	ATTACHED_Below}');
Error('\P{Canonical_Combining_Class=/a/-	ATTACHED_Below}');
Expect(1, 7632, '\p{Canonical_Combining_Class=attachedbelow}', "");
Expect(0, 7632, '\p{^Canonical_Combining_Class=attachedbelow}', "");
Expect(0, 7632, '\P{Canonical_Combining_Class=attachedbelow}', "");
Expect(1, 7632, '\P{^Canonical_Combining_Class=attachedbelow}', "");
Expect(0, 7633, '\p{Canonical_Combining_Class=attachedbelow}', "");
Expect(1, 7633, '\p{^Canonical_Combining_Class=attachedbelow}', "");
Expect(1, 7633, '\P{Canonical_Combining_Class=attachedbelow}', "");
Expect(0, 7633, '\P{^Canonical_Combining_Class=attachedbelow}', "");
Expect(1, 7632, '\p{Canonical_Combining_Class=-_Attached_BELOW}', "");
Expect(0, 7632, '\p{^Canonical_Combining_Class=-_Attached_BELOW}', "");
Expect(0, 7632, '\P{Canonical_Combining_Class=-_Attached_BELOW}', "");
Expect(1, 7632, '\P{^Canonical_Combining_Class=-_Attached_BELOW}', "");
Expect(0, 7633, '\p{Canonical_Combining_Class=-_Attached_BELOW}', "");
Expect(1, 7633, '\p{^Canonical_Combining_Class=-_Attached_BELOW}', "");
Expect(1, 7633, '\P{Canonical_Combining_Class=-_Attached_BELOW}', "");
Expect(0, 7633, '\P{^Canonical_Combining_Class=-_Attached_BELOW}', "");
Error('\p{Ccc=/a/ -ATB}');
Error('\P{Ccc=/a/ -ATB}');
Expect(1, 7632, '\p{Ccc=atb}', "");
Expect(0, 7632, '\p{^Ccc=atb}', "");
Expect(0, 7632, '\P{Ccc=atb}', "");
Expect(1, 7632, '\P{^Ccc=atb}', "");
Expect(0, 7633, '\p{Ccc=atb}', "");
Expect(1, 7633, '\p{^Ccc=atb}', "");
Expect(1, 7633, '\P{Ccc=atb}', "");
Expect(0, 7633, '\P{^Ccc=atb}', "");
Expect(1, 7632, '\p{Ccc=--ATB}', "");
Expect(0, 7632, '\p{^Ccc=--ATB}', "");
Expect(0, 7632, '\P{Ccc=--ATB}', "");
Expect(1, 7632, '\P{^Ccc=--ATB}', "");
Expect(0, 7633, '\p{Ccc=--ATB}', "");
Expect(1, 7633, '\p{^Ccc=--ATB}', "");
Expect(1, 7633, '\P{Ccc=--ATB}', "");
Expect(0, 7633, '\P{^Ccc=--ATB}', "");
Error('\p{Is_Canonical_Combining_Class=	:=+00_20_2}');
Error('\P{Is_Canonical_Combining_Class=	:=+00_20_2}');
Expect(1, 7632, '\p{Is_Canonical_Combining_Class=0000000202}', "");
Expect(0, 7632, '\p{^Is_Canonical_Combining_Class=0000000202}', "");
Expect(0, 7632, '\P{Is_Canonical_Combining_Class=0000000202}', "");
Expect(1, 7632, '\P{^Is_Canonical_Combining_Class=0000000202}', "");
Expect(0, 7633, '\p{Is_Canonical_Combining_Class=0000000202}', "");
Expect(1, 7633, '\p{^Is_Canonical_Combining_Class=0000000202}', "");
Expect(1, 7633, '\P{Is_Canonical_Combining_Class=0000000202}', "");
Expect(0, 7633, '\P{^Is_Canonical_Combining_Class=0000000202}', "");
Error('\p{Is_Ccc=	/a/attached_BELOW}');
Error('\P{Is_Ccc=	/a/attached_BELOW}');
Expect(1, 7632, '\p{Is_Ccc=attachedbelow}', "");
Expect(0, 7632, '\p{^Is_Ccc=attachedbelow}', "");
Expect(0, 7632, '\P{Is_Ccc=attachedbelow}', "");
Expect(1, 7632, '\P{^Is_Ccc=attachedbelow}', "");
Expect(0, 7633, '\p{Is_Ccc=attachedbelow}', "");
Expect(1, 7633, '\p{^Is_Ccc=attachedbelow}', "");
Expect(1, 7633, '\P{Is_Ccc=attachedbelow}', "");
Expect(0, 7633, '\P{^Is_Ccc=attachedbelow}', "");
Expect(1, 7632, '\p{Is_Ccc= 	Attached_BELOW}', "");
Expect(0, 7632, '\p{^Is_Ccc= 	Attached_BELOW}', "");
Expect(0, 7632, '\P{Is_Ccc= 	Attached_BELOW}', "");
Expect(1, 7632, '\P{^Is_Ccc= 	Attached_BELOW}', "");
Expect(0, 7633, '\p{Is_Ccc= 	Attached_BELOW}', "");
Expect(1, 7633, '\p{^Is_Ccc= 	Attached_BELOW}', "");
Expect(1, 7633, '\P{Is_Ccc= 	Attached_BELOW}', "");
Expect(0, 7633, '\P{^Is_Ccc= 	Attached_BELOW}', "");
Error('\p{Canonical_Combining_Class=_:=Attached_BELOW_left}');
Error('\P{Canonical_Combining_Class=_:=Attached_BELOW_left}');
Expect(0, 1, '\p{Canonical_Combining_Class=attachedbelowleft}', "");
Expect(1, 1, '\p{^Canonical_Combining_Class=attachedbelowleft}', "");
Expect(1, 1, '\P{Canonical_Combining_Class=attachedbelowleft}', "");
Expect(0, 1, '\P{^Canonical_Combining_Class=attachedbelowleft}', "");
Expect(0, 1, '\p{Canonical_Combining_Class: -Attached_Below_Left}', "");
Expect(1, 1, '\p{^Canonical_Combining_Class: -Attached_Below_Left}', "");
Expect(1, 1, '\P{Canonical_Combining_Class: -Attached_Below_Left}', "");
Expect(0, 1, '\P{^Canonical_Combining_Class: -Attached_Below_Left}', "");
Error('\p{Ccc= _ATBL:=}');
Error('\P{Ccc= _ATBL:=}');
Expect(0, 1, '\p{Ccc=atbl}', "");
Expect(1, 1, '\p{^Ccc=atbl}', "");
Expect(1, 1, '\P{Ccc=atbl}', "");
Expect(0, 1, '\P{^Ccc=atbl}', "");
Expect(0, 1, '\p{Ccc= 	ATBL}', "");
Expect(1, 1, '\p{^Ccc= 	ATBL}', "");
Expect(1, 1, '\P{Ccc= 	ATBL}', "");
Expect(0, 1, '\P{^Ccc= 	ATBL}', "");
Error('\p{Is_Canonical_Combining_Class= /a/0_0_0_0_200}');
Error('\P{Is_Canonical_Combining_Class= /a/0_0_0_0_200}');
Expect(0, 1, '\p{Is_Canonical_Combining_Class=+000020_0}', "");
Expect(1, 1, '\p{^Is_Canonical_Combining_Class=+000020_0}', "");
Expect(1, 1, '\P{Is_Canonical_Combining_Class=+000020_0}', "");
Expect(0, 1, '\P{^Is_Canonical_Combining_Class=+000020_0}', "");
Error('\p{Is_Ccc=_ Attached_Below_Left:=}');
Error('\P{Is_Ccc=_ Attached_Below_Left:=}');
Expect(0, 1, '\p{Is_Ccc=attachedbelowleft}', "");
Expect(1, 1, '\p{^Is_Ccc=attachedbelowleft}', "");
Expect(1, 1, '\P{Is_Ccc=attachedbelowleft}', "");
Expect(0, 1, '\P{^Is_Ccc=attachedbelowleft}', "");
Expect(0, 1, '\p{Is_Ccc=-Attached_Below_LEFT}', "");
Expect(1, 1, '\p{^Is_Ccc=-Attached_Below_LEFT}', "");
Expect(1, 1, '\P{Is_Ccc=-Attached_Below_LEFT}', "");
Expect(0, 1, '\P{^Is_Ccc=-Attached_Below_LEFT}', "");
Error('\p{Canonical_Combining_Class=-_Below:=}');
Error('\P{Canonical_Combining_Class=-_Below:=}');
Expect(1, 119179, '\p{Canonical_Combining_Class=below}', "");
Expect(0, 119179, '\p{^Canonical_Combining_Class=below}', "");
Expect(0, 119179, '\P{Canonical_Combining_Class=below}', "");
Expect(1, 119179, '\P{^Canonical_Combining_Class=below}', "");
Expect(0, 119180, '\p{Canonical_Combining_Class=below}', "");
Expect(1, 119180, '\p{^Canonical_Combining_Class=below}', "");
Expect(1, 119180, '\P{Canonical_Combining_Class=below}', "");
Expect(0, 119180, '\P{^Canonical_Combining_Class=below}', "");
Expect(1, 119179, '\p{Canonical_Combining_Class=--below}', "");
Expect(0, 119179, '\p{^Canonical_Combining_Class=--below}', "");
Expect(0, 119179, '\P{Canonical_Combining_Class=--below}', "");
Expect(1, 119179, '\P{^Canonical_Combining_Class=--below}', "");
Expect(0, 119180, '\p{Canonical_Combining_Class=--below}', "");
Expect(1, 119180, '\p{^Canonical_Combining_Class=--below}', "");
Expect(1, 119180, '\P{Canonical_Combining_Class=--below}', "");
Expect(0, 119180, '\P{^Canonical_Combining_Class=--below}', "");
Error('\p{Ccc= B/a/}');
Error('\P{Ccc= B/a/}');
Expect(1, 119179, '\p{Ccc=b}', "");
Expect(0, 119179, '\p{^Ccc=b}', "");
Expect(0, 119179, '\P{Ccc=b}', "");
Expect(1, 119179, '\P{^Ccc=b}', "");
Expect(0, 119180, '\p{Ccc=b}', "");
Expect(1, 119180, '\p{^Ccc=b}', "");
Expect(1, 119180, '\P{Ccc=b}', "");
Expect(0, 119180, '\P{^Ccc=b}', "");
Expect(1, 119179, '\p{Ccc=B}', "");
Expect(0, 119179, '\p{^Ccc=B}', "");
Expect(0, 119179, '\P{Ccc=B}', "");
Expect(1, 119179, '\P{^Ccc=B}', "");
Expect(0, 119180, '\p{Ccc=B}', "");
Expect(1, 119180, '\p{^Ccc=B}', "");
Expect(1, 119180, '\P{Ccc=B}', "");
Expect(0, 119180, '\P{^Ccc=B}', "");
Error('\p{Is_Canonical_Combining_Class=	+0_0_2_20/a/}');
Error('\P{Is_Canonical_Combining_Class=	+0_0_2_20/a/}');
Expect(1, 119179, '\p{Is_Canonical_Combining_Class=0220}', "");
Expect(0, 119179, '\p{^Is_Canonical_Combining_Class=0220}', "");
Expect(0, 119179, '\P{Is_Canonical_Combining_Class=0220}', "");
Expect(1, 119179, '\P{^Is_Canonical_Combining_Class=0220}', "");
Expect(0, 119180, '\p{Is_Canonical_Combining_Class=0220}', "");
Expect(1, 119180, '\p{^Is_Canonical_Combining_Class=0220}', "");
Expect(1, 119180, '\P{Is_Canonical_Combining_Class=0220}', "");
Expect(0, 119180, '\P{^Is_Canonical_Combining_Class=0220}', "");
Error('\p{Is_Ccc=:= 	Below}');
Error('\P{Is_Ccc=:= 	Below}');
Expect(1, 119179, '\p{Is_Ccc=below}', "");
Expect(0, 119179, '\p{^Is_Ccc=below}', "");
Expect(0, 119179, '\P{Is_Ccc=below}', "");
Expect(1, 119179, '\P{^Is_Ccc=below}', "");
Expect(0, 119180, '\p{Is_Ccc=below}', "");
Expect(1, 119180, '\p{^Is_Ccc=below}', "");
Expect(1, 119180, '\P{Is_Ccc=below}', "");
Expect(0, 119180, '\P{^Is_Ccc=below}', "");
Expect(1, 119179, '\p{Is_Ccc= 	Below}', "");
Expect(0, 119179, '\p{^Is_Ccc= 	Below}', "");
Expect(0, 119179, '\P{Is_Ccc= 	Below}', "");
Expect(1, 119179, '\P{^Is_Ccc= 	Below}', "");
Expect(0, 119180, '\p{Is_Ccc= 	Below}', "");
Expect(1, 119180, '\p{^Is_Ccc= 	Below}', "");
Expect(1, 119180, '\P{Is_Ccc= 	Below}', "");
Expect(0, 119180, '\P{^Is_Ccc= 	Below}', "");
Error('\p{Canonical_Combining_Class= /a/Below_left}');
Error('\P{Canonical_Combining_Class= /a/Below_left}');
Expect(1, 12330, '\p{Canonical_Combining_Class=belowleft}', "");
Expect(0, 12330, '\p{^Canonical_Combining_Class=belowleft}', "");
Expect(0, 12330, '\P{Canonical_Combining_Class=belowleft}', "");
Expect(1, 12330, '\P{^Canonical_Combining_Class=belowleft}', "");
Expect(0, 12331, '\p{Canonical_Combining_Class=belowleft}', "");
Expect(1, 12331, '\p{^Canonical_Combining_Class=belowleft}', "");
Expect(1, 12331, '\P{Canonical_Combining_Class=belowleft}', "");
Expect(0, 12331, '\P{^Canonical_Combining_Class=belowleft}', "");
Expect(1, 12330, '\p{Canonical_Combining_Class=		Below_Left}', "");
Expect(0, 12330, '\p{^Canonical_Combining_Class=		Below_Left}', "");
Expect(0, 12330, '\P{Canonical_Combining_Class=		Below_Left}', "");
Expect(1, 12330, '\P{^Canonical_Combining_Class=		Below_Left}', "");
Expect(0, 12331, '\p{Canonical_Combining_Class=		Below_Left}', "");
Expect(1, 12331, '\p{^Canonical_Combining_Class=		Below_Left}', "");
Expect(1, 12331, '\P{Canonical_Combining_Class=		Below_Left}', "");
Expect(0, 12331, '\P{^Canonical_Combining_Class=		Below_Left}', "");
Error('\p{Ccc=		BL:=}');
Error('\P{Ccc=		BL:=}');
Expect(1, 12330, '\p{Ccc=bl}', "");
Expect(0, 12330, '\p{^Ccc=bl}', "");
Expect(0, 12330, '\P{Ccc=bl}', "");
Expect(1, 12330, '\P{^Ccc=bl}', "");
Expect(0, 12331, '\p{Ccc=bl}', "");
Expect(1, 12331, '\p{^Ccc=bl}', "");
Expect(1, 12331, '\P{Ccc=bl}', "");
Expect(0, 12331, '\P{^Ccc=bl}', "");
Expect(1, 12330, '\p{Ccc=	BL}', "");
Expect(0, 12330, '\p{^Ccc=	BL}', "");
Expect(0, 12330, '\P{Ccc=	BL}', "");
Expect(1, 12330, '\P{^Ccc=	BL}', "");
Expect(0, 12331, '\p{Ccc=	BL}', "");
Expect(1, 12331, '\p{^Ccc=	BL}', "");
Expect(1, 12331, '\P{Ccc=	BL}', "");
Expect(0, 12331, '\P{^Ccc=	BL}', "");
Error('\p{Is_Canonical_Combining_Class=:=	-0000218}');
Error('\P{Is_Canonical_Combining_Class=:=	-0000218}');
Expect(1, 12330, '\p{Is_Canonical_Combining_Class=00000_00002_18}', "");
Expect(0, 12330, '\p{^Is_Canonical_Combining_Class=00000_00002_18}', "");
Expect(0, 12330, '\P{Is_Canonical_Combining_Class=00000_00002_18}', "");
Expect(1, 12330, '\P{^Is_Canonical_Combining_Class=00000_00002_18}', "");
Expect(0, 12331, '\p{Is_Canonical_Combining_Class=00000_00002_18}', "");
Expect(1, 12331, '\p{^Is_Canonical_Combining_Class=00000_00002_18}', "");
Expect(1, 12331, '\P{Is_Canonical_Combining_Class=00000_00002_18}', "");
Expect(0, 12331, '\P{^Is_Canonical_Combining_Class=00000_00002_18}', "");
Error('\p{Is_Ccc=/a/Below_Left}');
Error('\P{Is_Ccc=/a/Below_Left}');
Expect(1, 12330, '\p{Is_Ccc=belowleft}', "");
Expect(0, 12330, '\p{^Is_Ccc=belowleft}', "");
Expect(0, 12330, '\P{Is_Ccc=belowleft}', "");
Expect(1, 12330, '\P{^Is_Ccc=belowleft}', "");
Expect(0, 12331, '\p{Is_Ccc=belowleft}', "");
Expect(1, 12331, '\p{^Is_Ccc=belowleft}', "");
Expect(1, 12331, '\P{Is_Ccc=belowleft}', "");
Expect(0, 12331, '\P{^Is_Ccc=belowleft}', "");
Expect(1, 12330, '\p{Is_Ccc=_BELOW_Left}', "");
Expect(0, 12330, '\p{^Is_Ccc=_BELOW_Left}', "");
Expect(0, 12330, '\P{Is_Ccc=_BELOW_Left}', "");
Expect(1, 12330, '\P{^Is_Ccc=_BELOW_Left}', "");
Expect(0, 12331, '\p{Is_Ccc=_BELOW_Left}', "");
Expect(1, 12331, '\p{^Is_Ccc=_BELOW_Left}', "");
Expect(1, 12331, '\P{Is_Ccc=_BELOW_Left}', "");
Expect(0, 12331, '\P{^Is_Ccc=_BELOW_Left}', "");
Error('\p{Canonical_Combining_Class=/a/  BELOW_Right}');
Error('\P{Canonical_Combining_Class=/a/  BELOW_Right}');
Expect(1, 12333, '\p{Canonical_Combining_Class=belowright}', "");
Expect(0, 12333, '\p{^Canonical_Combining_Class=belowright}', "");
Expect(0, 12333, '\P{Canonical_Combining_Class=belowright}', "");
Expect(1, 12333, '\P{^Canonical_Combining_Class=belowright}', "");
Expect(0, 12334, '\p{Canonical_Combining_Class=belowright}', "");
Expect(1, 12334, '\p{^Canonical_Combining_Class=belowright}', "");
Expect(1, 12334, '\P{Canonical_Combining_Class=belowright}', "");
Expect(0, 12334, '\P{^Canonical_Combining_Class=belowright}', "");
Expect(1, 12333, '\p{Canonical_Combining_Class= _Below_RIGHT}', "");
Expect(0, 12333, '\p{^Canonical_Combining_Class= _Below_RIGHT}', "");
Expect(0, 12333, '\P{Canonical_Combining_Class= _Below_RIGHT}', "");
Expect(1, 12333, '\P{^Canonical_Combining_Class= _Below_RIGHT}', "");
Expect(0, 12334, '\p{Canonical_Combining_Class= _Below_RIGHT}', "");
Expect(1, 12334, '\p{^Canonical_Combining_Class= _Below_RIGHT}', "");
Expect(1, 12334, '\P{Canonical_Combining_Class= _Below_RIGHT}', "");
Expect(0, 12334, '\P{^Canonical_Combining_Class= _Below_RIGHT}', "");
Error('\p{Ccc=_/a/BR}');
Error('\P{Ccc=_/a/BR}');
Expect(1, 12333, '\p{Ccc=br}', "");
Expect(0, 12333, '\p{^Ccc=br}', "");
Expect(0, 12333, '\P{Ccc=br}', "");
Expect(1, 12333, '\P{^Ccc=br}', "");
Expect(0, 12334, '\p{Ccc=br}', "");
Expect(1, 12334, '\p{^Ccc=br}', "");
Expect(1, 12334, '\P{Ccc=br}', "");
Expect(0, 12334, '\P{^Ccc=br}', "");
Expect(1, 12333, '\p{Ccc=--br}', "");
Expect(0, 12333, '\p{^Ccc=--br}', "");
Expect(0, 12333, '\P{Ccc=--br}', "");
Expect(1, 12333, '\P{^Ccc=--br}', "");
Expect(0, 12334, '\p{Ccc=--br}', "");
Expect(1, 12334, '\p{^Ccc=--br}', "");
Expect(1, 12334, '\P{Ccc=--br}', "");
Expect(0, 12334, '\P{^Ccc=--br}', "");
Error('\p{Is_Canonical_Combining_Class=_-+0222:=}');
Error('\P{Is_Canonical_Combining_Class=_-+0222:=}');
Expect(1, 12333, '\p{Is_Canonical_Combining_Class=0222}', "");
Expect(0, 12333, '\p{^Is_Canonical_Combining_Class=0222}', "");
Expect(0, 12333, '\P{Is_Canonical_Combining_Class=0222}', "");
Expect(1, 12333, '\P{^Is_Canonical_Combining_Class=0222}', "");
Expect(0, 12334, '\p{Is_Canonical_Combining_Class=0222}', "");
Expect(1, 12334, '\p{^Is_Canonical_Combining_Class=0222}', "");
Expect(1, 12334, '\P{Is_Canonical_Combining_Class=0222}', "");
Expect(0, 12334, '\P{^Is_Canonical_Combining_Class=0222}', "");
Error('\p{Is_Ccc=:=Below_right}');
Error('\P{Is_Ccc=:=Below_right}');
Expect(1, 12333, '\p{Is_Ccc=belowright}', "");
Expect(0, 12333, '\p{^Is_Ccc=belowright}', "");
Expect(0, 12333, '\P{Is_Ccc=belowright}', "");
Expect(1, 12333, '\P{^Is_Ccc=belowright}', "");
Expect(0, 12334, '\p{Is_Ccc=belowright}', "");
Expect(1, 12334, '\p{^Is_Ccc=belowright}', "");
Expect(1, 12334, '\P{Is_Ccc=belowright}', "");
Expect(0, 12334, '\P{^Is_Ccc=belowright}', "");
Expect(1, 12333, '\p{Is_Ccc=	-below_right}', "");
Expect(0, 12333, '\p{^Is_Ccc=	-below_right}', "");
Expect(0, 12333, '\P{Is_Ccc=	-below_right}', "");
Expect(1, 12333, '\P{^Is_Ccc=	-below_right}', "");
Expect(0, 12334, '\p{Is_Ccc=	-below_right}', "");
Expect(1, 12334, '\p{^Is_Ccc=	-below_right}', "");
Expect(1, 12334, '\P{Is_Ccc=	-below_right}', "");
Expect(0, 12334, '\P{^Is_Ccc=	-below_right}', "");
Error('\p{Canonical_Combining_Class= _ccc10/a/}');
Error('\P{Canonical_Combining_Class= _ccc10/a/}');
Expect(1, 1456, '\p{Canonical_Combining_Class=ccc10}', "");
Expect(0, 1456, '\p{^Canonical_Combining_Class=ccc10}', "");
Expect(0, 1456, '\P{Canonical_Combining_Class=ccc10}', "");
Expect(1, 1456, '\P{^Canonical_Combining_Class=ccc10}', "");
Expect(0, 1457, '\p{Canonical_Combining_Class=ccc10}', "");
Expect(1, 1457, '\p{^Canonical_Combining_Class=ccc10}', "");
Expect(1, 1457, '\P{Canonical_Combining_Class=ccc10}', "");
Expect(0, 1457, '\P{^Canonical_Combining_Class=ccc10}', "");
Expect(1, 1456, '\p{Canonical_Combining_Class=	ccc10}', "");
Expect(0, 1456, '\p{^Canonical_Combining_Class=	ccc10}', "");
Expect(0, 1456, '\P{Canonical_Combining_Class=	ccc10}', "");
Expect(1, 1456, '\P{^Canonical_Combining_Class=	ccc10}', "");
Expect(0, 1457, '\p{Canonical_Combining_Class=	ccc10}', "");
Expect(1, 1457, '\p{^Canonical_Combining_Class=	ccc10}', "");
Expect(1, 1457, '\P{Canonical_Combining_Class=	ccc10}', "");
Expect(0, 1457, '\P{^Canonical_Combining_Class=	ccc10}', "");
Error('\p{Ccc= /a/+00_00_10}');
Error('\P{Ccc= /a/+00_00_10}');
Expect(1, 1456, '\p{Ccc=0_0_10}', "");
Expect(0, 1456, '\p{^Ccc=0_0_10}', "");
Expect(0, 1456, '\P{Ccc=0_0_10}', "");
Expect(1, 1456, '\P{^Ccc=0_0_10}', "");
Expect(0, 1457, '\p{Ccc=0_0_10}', "");
Expect(1, 1457, '\p{^Ccc=0_0_10}', "");
Expect(1, 1457, '\P{Ccc=0_0_10}', "");
Expect(0, 1457, '\P{^Ccc=0_0_10}', "");
Error('\p{Is_Canonical_Combining_Class= /a/CCC10}');
Error('\P{Is_Canonical_Combining_Class= /a/CCC10}');
Expect(1, 1456, '\p{Is_Canonical_Combining_Class=ccc10}', "");
Expect(0, 1456, '\p{^Is_Canonical_Combining_Class=ccc10}', "");
Expect(0, 1456, '\P{Is_Canonical_Combining_Class=ccc10}', "");
Expect(1, 1456, '\P{^Is_Canonical_Combining_Class=ccc10}', "");
Expect(0, 1457, '\p{Is_Canonical_Combining_Class=ccc10}', "");
Expect(1, 1457, '\p{^Is_Canonical_Combining_Class=ccc10}', "");
Expect(1, 1457, '\P{Is_Canonical_Combining_Class=ccc10}', "");
Expect(0, 1457, '\P{^Is_Canonical_Combining_Class=ccc10}', "");
Expect(1, 1456, '\p{Is_Canonical_Combining_Class=  CCC10}', "");
Expect(0, 1456, '\p{^Is_Canonical_Combining_Class=  CCC10}', "");
Expect(0, 1456, '\P{Is_Canonical_Combining_Class=  CCC10}', "");
Expect(1, 1456, '\P{^Is_Canonical_Combining_Class=  CCC10}', "");
Expect(0, 1457, '\p{Is_Canonical_Combining_Class=  CCC10}', "");
Expect(1, 1457, '\p{^Is_Canonical_Combining_Class=  CCC10}', "");
Expect(1, 1457, '\P{Is_Canonical_Combining_Class=  CCC10}', "");
Expect(0, 1457, '\P{^Is_Canonical_Combining_Class=  CCC10}', "");
Error('\p{Is_Ccc=/a/	+001_0}');
Error('\P{Is_Ccc=/a/	+001_0}');
Expect(1, 1456, '\p{Is_Ccc=0000000010}', "");
Expect(0, 1456, '\p{^Is_Ccc=0000000010}', "");
Expect(0, 1456, '\P{Is_Ccc=0000000010}', "");
Expect(1, 1456, '\P{^Is_Ccc=0000000010}', "");
Expect(0, 1457, '\p{Is_Ccc=0000000010}', "");
Expect(1, 1457, '\p{^Is_Ccc=0000000010}', "");
Expect(1, 1457, '\P{Is_Ccc=0000000010}', "");
Expect(0, 1457, '\P{^Is_Ccc=0000000010}', "");
Error('\p{Canonical_Combining_Class=-	CCC103:=}');
Error('\P{Canonical_Combining_Class=-	CCC103:=}');
Expect(1, 3641, '\p{Canonical_Combining_Class=ccc103}', "");
Expect(0, 3641, '\p{^Canonical_Combining_Class=ccc103}', "");
Expect(0, 3641, '\P{Canonical_Combining_Class=ccc103}', "");
Expect(1, 3641, '\P{^Canonical_Combining_Class=ccc103}', "");
Expect(0, 3642, '\p{Canonical_Combining_Class=ccc103}', "");
Expect(1, 3642, '\p{^Canonical_Combining_Class=ccc103}', "");
Expect(1, 3642, '\P{Canonical_Combining_Class=ccc103}', "");
Expect(0, 3642, '\P{^Canonical_Combining_Class=ccc103}', "");
Expect(1, 3641, '\p{Canonical_Combining_Class=  ccc103}', "");
Expect(0, 3641, '\p{^Canonical_Combining_Class=  ccc103}', "");
Expect(0, 3641, '\P{Canonical_Combining_Class=  ccc103}', "");
Expect(1, 3641, '\P{^Canonical_Combining_Class=  ccc103}', "");
Expect(0, 3642, '\p{Canonical_Combining_Class=  ccc103}', "");
Expect(1, 3642, '\p{^Canonical_Combining_Class=  ccc103}', "");
Expect(1, 3642, '\P{Canonical_Combining_Class=  ccc103}', "");
Expect(0, 3642, '\P{^Canonical_Combining_Class=  ccc103}', "");
Error('\p{Ccc=/a/- +0000000103}');
Error('\P{Ccc=/a/- +0000000103}');
Expect(1, 3641, '\p{Ccc=0_0_0_0_0_0_0_1_03}', "");
Expect(0, 3641, '\p{^Ccc=0_0_0_0_0_0_0_1_03}', "");
Expect(0, 3641, '\P{Ccc=0_0_0_0_0_0_0_1_03}', "");
Expect(1, 3641, '\P{^Ccc=0_0_0_0_0_0_0_1_03}', "");
Expect(0, 3642, '\p{Ccc=0_0_0_0_0_0_0_1_03}', "");
Expect(1, 3642, '\p{^Ccc=0_0_0_0_0_0_0_1_03}', "");
Expect(1, 3642, '\P{Ccc=0_0_0_0_0_0_0_1_03}', "");
Expect(0, 3642, '\P{^Ccc=0_0_0_0_0_0_0_1_03}', "");
Error('\p{Is_Canonical_Combining_Class=/a/ -CCC103}');
Error('\P{Is_Canonical_Combining_Class=/a/ -CCC103}');
Expect(1, 3641, '\p{Is_Canonical_Combining_Class=ccc103}', "");
Expect(0, 3641, '\p{^Is_Canonical_Combining_Class=ccc103}', "");
Expect(0, 3641, '\P{Is_Canonical_Combining_Class=ccc103}', "");
Expect(1, 3641, '\P{^Is_Canonical_Combining_Class=ccc103}', "");
Expect(0, 3642, '\p{Is_Canonical_Combining_Class=ccc103}', "");
Expect(1, 3642, '\p{^Is_Canonical_Combining_Class=ccc103}', "");
Expect(1, 3642, '\P{Is_Canonical_Combining_Class=ccc103}', "");
Expect(0, 3642, '\P{^Is_Canonical_Combining_Class=ccc103}', "");
Expect(1, 3641, '\p{Is_Canonical_Combining_Class= -CCC103}', "");
Expect(0, 3641, '\p{^Is_Canonical_Combining_Class= -CCC103}', "");
Expect(0, 3641, '\P{Is_Canonical_Combining_Class= -CCC103}', "");
Expect(1, 3641, '\P{^Is_Canonical_Combining_Class= -CCC103}', "");
Expect(0, 3642, '\p{Is_Canonical_Combining_Class= -CCC103}', "");
Expect(1, 3642, '\p{^Is_Canonical_Combining_Class= -CCC103}', "");
Expect(1, 3642, '\P{Is_Canonical_Combining_Class= -CCC103}', "");
Expect(0, 3642, '\P{^Is_Canonical_Combining_Class= -CCC103}', "");
Error('\p{Is_Ccc=:=	 000103}');
Error('\P{Is_Ccc=:=	 000103}');
Expect(1, 3641, '\p{Is_Ccc=0000103}', "");
Expect(0, 3641, '\p{^Is_Ccc=0000103}', "");
Expect(0, 3641, '\P{Is_Ccc=0000103}', "");
Expect(1, 3641, '\P{^Is_Ccc=0000103}', "");
Expect(0, 3642, '\p{Is_Ccc=0000103}', "");
Expect(1, 3642, '\p{^Is_Ccc=0000103}', "");
Expect(1, 3642, '\P{Is_Ccc=0000103}', "");
Expect(0, 3642, '\P{^Is_Ccc=0000103}', "");
Error('\p{Canonical_Combining_Class=:= -ccc107}');
Error('\P{Canonical_Combining_Class=:= -ccc107}');
Expect(1, 3659, '\p{Canonical_Combining_Class=ccc107}', "");
Expect(0, 3659, '\p{^Canonical_Combining_Class=ccc107}', "");
Expect(0, 3659, '\P{Canonical_Combining_Class=ccc107}', "");
Expect(1, 3659, '\P{^Canonical_Combining_Class=ccc107}', "");
Expect(0, 3660, '\p{Canonical_Combining_Class=ccc107}', "");
Expect(1, 3660, '\p{^Canonical_Combining_Class=ccc107}', "");
Expect(1, 3660, '\P{Canonical_Combining_Class=ccc107}', "");
Expect(0, 3660, '\P{^Canonical_Combining_Class=ccc107}', "");
Expect(1, 3659, '\p{Canonical_Combining_Class:		_ccc107}', "");
Expect(0, 3659, '\p{^Canonical_Combining_Class:		_ccc107}', "");
Expect(0, 3659, '\P{Canonical_Combining_Class:		_ccc107}', "");
Expect(1, 3659, '\P{^Canonical_Combining_Class:		_ccc107}', "");
Expect(0, 3660, '\p{Canonical_Combining_Class:		_ccc107}', "");
Expect(1, 3660, '\p{^Canonical_Combining_Class:		_ccc107}', "");
Expect(1, 3660, '\P{Canonical_Combining_Class:		_ccc107}', "");
Expect(0, 3660, '\P{^Canonical_Combining_Class:		_ccc107}', "");
Error('\p{Ccc=:=- +000_001_07}');
Error('\P{Ccc=:=- +000_001_07}');
Expect(1, 3659, '\p{Ccc=0_0_0_0_0_0_0_0_0_1_07}', "");
Expect(0, 3659, '\p{^Ccc=0_0_0_0_0_0_0_0_0_1_07}', "");
Expect(0, 3659, '\P{Ccc=0_0_0_0_0_0_0_0_0_1_07}', "");
Expect(1, 3659, '\P{^Ccc=0_0_0_0_0_0_0_0_0_1_07}', "");
Expect(0, 3660, '\p{Ccc=0_0_0_0_0_0_0_0_0_1_07}', "");
Expect(1, 3660, '\p{^Ccc=0_0_0_0_0_0_0_0_0_1_07}', "");
Expect(1, 3660, '\P{Ccc=0_0_0_0_0_0_0_0_0_1_07}', "");
Expect(0, 3660, '\P{^Ccc=0_0_0_0_0_0_0_0_0_1_07}', "");
Error('\p{Is_Canonical_Combining_Class=_:=CCC107}');
Error('\P{Is_Canonical_Combining_Class=_:=CCC107}');
Expect(1, 3659, '\p{Is_Canonical_Combining_Class=ccc107}', "");
Expect(0, 3659, '\p{^Is_Canonical_Combining_Class=ccc107}', "");
Expect(0, 3659, '\P{Is_Canonical_Combining_Class=ccc107}', "");
Expect(1, 3659, '\P{^Is_Canonical_Combining_Class=ccc107}', "");
Expect(0, 3660, '\p{Is_Canonical_Combining_Class=ccc107}', "");
Expect(1, 3660, '\p{^Is_Canonical_Combining_Class=ccc107}', "");
Expect(1, 3660, '\P{Is_Canonical_Combining_Class=ccc107}', "");
Expect(0, 3660, '\P{^Is_Canonical_Combining_Class=ccc107}', "");
Expect(1, 3659, '\p{Is_Canonical_Combining_Class= -CCC107}', "");
Expect(0, 3659, '\p{^Is_Canonical_Combining_Class= -CCC107}', "");
Expect(0, 3659, '\P{Is_Canonical_Combining_Class= -CCC107}', "");
Expect(1, 3659, '\P{^Is_Canonical_Combining_Class= -CCC107}', "");
Expect(0, 3660, '\p{Is_Canonical_Combining_Class= -CCC107}', "");
Expect(1, 3660, '\p{^Is_Canonical_Combining_Class= -CCC107}', "");
Expect(1, 3660, '\P{Is_Canonical_Combining_Class= -CCC107}', "");
Expect(0, 3660, '\P{^Is_Canonical_Combining_Class= -CCC107}', "");
Error('\p{Is_Ccc=_	+107/a/}');
Error('\P{Is_Ccc=_	+107/a/}');
Expect(1, 3659, '\p{Is_Ccc: 010_7}', "");
Expect(0, 3659, '\p{^Is_Ccc: 010_7}', "");
Expect(0, 3659, '\P{Is_Ccc: 010_7}', "");
Expect(1, 3659, '\P{^Is_Ccc: 010_7}', "");
Expect(0, 3660, '\p{Is_Ccc: 010_7}', "");
Expect(1, 3660, '\p{^Is_Ccc: 010_7}', "");
Expect(1, 3660, '\P{Is_Ccc: 010_7}', "");
Expect(0, 3660, '\P{^Is_Ccc: 010_7}', "");
Error('\p{Canonical_Combining_Class=	CCC11:=}');
Error('\P{Canonical_Combining_Class=	CCC11:=}');
Expect(1, 1457, '\p{Canonical_Combining_Class=ccc11}', "");
Expect(0, 1457, '\p{^Canonical_Combining_Class=ccc11}', "");
Expect(0, 1457, '\P{Canonical_Combining_Class=ccc11}', "");
Expect(1, 1457, '\P{^Canonical_Combining_Class=ccc11}', "");
Expect(0, 1458, '\p{Canonical_Combining_Class=ccc11}', "");
Expect(1, 1458, '\p{^Canonical_Combining_Class=ccc11}', "");
Expect(1, 1458, '\P{Canonical_Combining_Class=ccc11}', "");
Expect(0, 1458, '\P{^Canonical_Combining_Class=ccc11}', "");
Expect(1, 1457, '\p{Canonical_Combining_Class=_CCC11}', "");
Expect(0, 1457, '\p{^Canonical_Combining_Class=_CCC11}', "");
Expect(0, 1457, '\P{Canonical_Combining_Class=_CCC11}', "");
Expect(1, 1457, '\P{^Canonical_Combining_Class=_CCC11}', "");
Expect(0, 1458, '\p{Canonical_Combining_Class=_CCC11}', "");
Expect(1, 1458, '\p{^Canonical_Combining_Class=_CCC11}', "");
Expect(1, 1458, '\P{Canonical_Combining_Class=_CCC11}', "");
Expect(0, 1458, '\P{^Canonical_Combining_Class=_CCC11}', "");
Error('\p{Ccc=_-0011/a/}');
Error('\P{Ccc=_-0011/a/}');
Expect(1, 1457, '\p{Ccc=1_1}', "");
Expect(0, 1457, '\p{^Ccc=1_1}', "");
Expect(0, 1457, '\P{Ccc=1_1}', "");
Expect(1, 1457, '\P{^Ccc=1_1}', "");
Expect(0, 1458, '\p{Ccc=1_1}', "");
Expect(1, 1458, '\p{^Ccc=1_1}', "");
Expect(1, 1458, '\P{Ccc=1_1}', "");
Expect(0, 1458, '\P{^Ccc=1_1}', "");
Error('\p{Is_Canonical_Combining_Class=-:=CCC11}');
Error('\P{Is_Canonical_Combining_Class=-:=CCC11}');
Expect(1, 1457, '\p{Is_Canonical_Combining_Class=ccc11}', "");
Expect(0, 1457, '\p{^Is_Canonical_Combining_Class=ccc11}', "");
Expect(0, 1457, '\P{Is_Canonical_Combining_Class=ccc11}', "");
Expect(1, 1457, '\P{^Is_Canonical_Combining_Class=ccc11}', "");
Expect(0, 1458, '\p{Is_Canonical_Combining_Class=ccc11}', "");
Expect(1, 1458, '\p{^Is_Canonical_Combining_Class=ccc11}', "");
Expect(1, 1458, '\P{Is_Canonical_Combining_Class=ccc11}', "");
Expect(0, 1458, '\P{^Is_Canonical_Combining_Class=ccc11}', "");
Expect(1, 1457, '\p{Is_Canonical_Combining_Class= 	CCC11}', "");
Expect(0, 1457, '\p{^Is_Canonical_Combining_Class= 	CCC11}', "");
Expect(0, 1457, '\P{Is_Canonical_Combining_Class= 	CCC11}', "");
Expect(1, 1457, '\P{^Is_Canonical_Combining_Class= 	CCC11}', "");
Expect(0, 1458, '\p{Is_Canonical_Combining_Class= 	CCC11}', "");
Expect(1, 1458, '\p{^Is_Canonical_Combining_Class= 	CCC11}', "");
Expect(1, 1458, '\P{Is_Canonical_Combining_Class= 	CCC11}', "");
Expect(0, 1458, '\P{^Is_Canonical_Combining_Class= 	CCC11}', "");
Error('\p{Is_Ccc=:=_0_0_0_0_0_0_0_011}');
Error('\P{Is_Ccc=:=_0_0_0_0_0_0_0_011}');
Expect(1, 1457, '\p{Is_Ccc=11}', "");
Expect(0, 1457, '\p{^Is_Ccc=11}', "");
Expect(0, 1457, '\P{Is_Ccc=11}', "");
Expect(1, 1457, '\P{^Is_Ccc=11}', "");
Expect(0, 1458, '\p{Is_Ccc=11}', "");
Expect(1, 1458, '\p{^Is_Ccc=11}', "");
Expect(1, 1458, '\P{Is_Ccc=11}', "");
Expect(0, 1458, '\P{^Is_Ccc=11}', "");
Error('\p{Canonical_Combining_Class=_-CCC118/a/}');
Error('\P{Canonical_Combining_Class=_-CCC118/a/}');
Expect(1, 3769, '\p{Canonical_Combining_Class=ccc118}', "");
Expect(0, 3769, '\p{^Canonical_Combining_Class=ccc118}', "");
Expect(0, 3769, '\P{Canonical_Combining_Class=ccc118}', "");
Expect(1, 3769, '\P{^Canonical_Combining_Class=ccc118}', "");
Expect(0, 3770, '\p{Canonical_Combining_Class=ccc118}', "");
Expect(1, 3770, '\p{^Canonical_Combining_Class=ccc118}', "");
Expect(1, 3770, '\P{Canonical_Combining_Class=ccc118}', "");
Expect(0, 3770, '\P{^Canonical_Combining_Class=ccc118}', "");
Expect(1, 3769, '\p{Canonical_Combining_Class=__CCC118}', "");
Expect(0, 3769, '\p{^Canonical_Combining_Class=__CCC118}', "");
Expect(0, 3769, '\P{Canonical_Combining_Class=__CCC118}', "");
Expect(1, 3769, '\P{^Canonical_Combining_Class=__CCC118}', "");
Expect(0, 3770, '\p{Canonical_Combining_Class=__CCC118}', "");
Expect(1, 3770, '\p{^Canonical_Combining_Class=__CCC118}', "");
Expect(1, 3770, '\P{Canonical_Combining_Class=__CCC118}', "");
Expect(0, 3770, '\P{^Canonical_Combining_Class=__CCC118}', "");
Error('\p{Ccc=	+0_0_0_0_0_0_0_0_1_18:=}');
Error('\P{Ccc=	+0_0_0_0_0_0_0_0_1_18:=}');
Expect(1, 3769, '\p{Ccc=00000118}', "");
Expect(0, 3769, '\p{^Ccc=00000118}', "");
Expect(0, 3769, '\P{Ccc=00000118}', "");
Expect(1, 3769, '\P{^Ccc=00000118}', "");
Expect(0, 3770, '\p{Ccc=00000118}', "");
Expect(1, 3770, '\p{^Ccc=00000118}', "");
Expect(1, 3770, '\P{Ccc=00000118}', "");
Expect(0, 3770, '\P{^Ccc=00000118}', "");
Error('\p{Is_Canonical_Combining_Class=/a/		CCC118}');
Error('\P{Is_Canonical_Combining_Class=/a/		CCC118}');
Expect(1, 3769, '\p{Is_Canonical_Combining_Class=ccc118}', "");
Expect(0, 3769, '\p{^Is_Canonical_Combining_Class=ccc118}', "");
Expect(0, 3769, '\P{Is_Canonical_Combining_Class=ccc118}', "");
Expect(1, 3769, '\P{^Is_Canonical_Combining_Class=ccc118}', "");
Expect(0, 3770, '\p{Is_Canonical_Combining_Class=ccc118}', "");
Expect(1, 3770, '\p{^Is_Canonical_Combining_Class=ccc118}', "");
Expect(1, 3770, '\P{Is_Canonical_Combining_Class=ccc118}', "");
Expect(0, 3770, '\P{^Is_Canonical_Combining_Class=ccc118}', "");
Expect(1, 3769, '\p{Is_Canonical_Combining_Class=__ccc118}', "");
Expect(0, 3769, '\p{^Is_Canonical_Combining_Class=__ccc118}', "");
Expect(0, 3769, '\P{Is_Canonical_Combining_Class=__ccc118}', "");
Expect(1, 3769, '\P{^Is_Canonical_Combining_Class=__ccc118}', "");
Expect(0, 3770, '\p{Is_Canonical_Combining_Class=__ccc118}', "");
Expect(1, 3770, '\p{^Is_Canonical_Combining_Class=__ccc118}', "");
Expect(1, 3770, '\P{Is_Canonical_Combining_Class=__ccc118}', "");
Expect(0, 3770, '\P{^Is_Canonical_Combining_Class=__ccc118}', "");
Error('\p{Is_Ccc=_-00000000118:=}');
Error('\P{Is_Ccc=_-00000000118:=}');
Expect(1, 3769, '\p{Is_Ccc=00000118}', "");
Expect(0, 3769, '\p{^Is_Ccc=00000118}', "");
Expect(0, 3769, '\P{Is_Ccc=00000118}', "");
Expect(1, 3769, '\P{^Is_Ccc=00000118}', "");
Expect(0, 3770, '\p{Is_Ccc=00000118}', "");
Expect(1, 3770, '\p{^Is_Ccc=00000118}', "");
Expect(1, 3770, '\P{Is_Ccc=00000118}', "");
Expect(0, 3770, '\P{^Is_Ccc=00000118}', "");
Error('\p{Canonical_Combining_Class: _	ccc12/a/}');
Error('\P{Canonical_Combining_Class: _	ccc12/a/}');
Expect(1, 1458, '\p{Canonical_Combining_Class=ccc12}', "");
Expect(0, 1458, '\p{^Canonical_Combining_Class=ccc12}', "");
Expect(0, 1458, '\P{Canonical_Combining_Class=ccc12}', "");
Expect(1, 1458, '\P{^Canonical_Combining_Class=ccc12}', "");
Expect(0, 1459, '\p{Canonical_Combining_Class=ccc12}', "");
Expect(1, 1459, '\p{^Canonical_Combining_Class=ccc12}', "");
Expect(1, 1459, '\P{Canonical_Combining_Class=ccc12}', "");
Expect(0, 1459, '\P{^Canonical_Combining_Class=ccc12}', "");
Expect(1, 1458, '\p{Canonical_Combining_Class:    -CCC12}', "");
Expect(0, 1458, '\p{^Canonical_Combining_Class:    -CCC12}', "");
Expect(0, 1458, '\P{Canonical_Combining_Class:    -CCC12}', "");
Expect(1, 1458, '\P{^Canonical_Combining_Class:    -CCC12}', "");
Expect(0, 1459, '\p{Canonical_Combining_Class:    -CCC12}', "");
Expect(1, 1459, '\p{^Canonical_Combining_Class:    -CCC12}', "");
Expect(1, 1459, '\P{Canonical_Combining_Class:    -CCC12}', "");
Expect(0, 1459, '\P{^Canonical_Combining_Class:    -CCC12}', "");
Error('\p{Ccc: 	000012/a/}');
Error('\P{Ccc: 	000012/a/}');
Expect(1, 1458, '\p{Ccc=0_0_0_0_0_0_0_0_012}', "");
Expect(0, 1458, '\p{^Ccc=0_0_0_0_0_0_0_0_012}', "");
Expect(0, 1458, '\P{Ccc=0_0_0_0_0_0_0_0_012}', "");
Expect(1, 1458, '\P{^Ccc=0_0_0_0_0_0_0_0_012}', "");
Expect(0, 1459, '\p{Ccc=0_0_0_0_0_0_0_0_012}', "");
Expect(1, 1459, '\p{^Ccc=0_0_0_0_0_0_0_0_012}', "");
Expect(1, 1459, '\P{Ccc=0_0_0_0_0_0_0_0_012}', "");
Expect(0, 1459, '\P{^Ccc=0_0_0_0_0_0_0_0_012}', "");
Error('\p{Is_Canonical_Combining_Class=-	CCC12:=}');
Error('\P{Is_Canonical_Combining_Class=-	CCC12:=}');
Expect(1, 1458, '\p{Is_Canonical_Combining_Class=ccc12}', "");
Expect(0, 1458, '\p{^Is_Canonical_Combining_Class=ccc12}', "");
Expect(0, 1458, '\P{Is_Canonical_Combining_Class=ccc12}', "");
Expect(1, 1458, '\P{^Is_Canonical_Combining_Class=ccc12}', "");
Expect(0, 1459, '\p{Is_Canonical_Combining_Class=ccc12}', "");
Expect(1, 1459, '\p{^Is_Canonical_Combining_Class=ccc12}', "");
Expect(1, 1459, '\P{Is_Canonical_Combining_Class=ccc12}', "");
Expect(0, 1459, '\P{^Is_Canonical_Combining_Class=ccc12}', "");
Expect(1, 1458, '\p{Is_Canonical_Combining_Class=  CCC12}', "");
Expect(0, 1458, '\p{^Is_Canonical_Combining_Class=  CCC12}', "");
Expect(0, 1458, '\P{Is_Canonical_Combining_Class=  CCC12}', "");
Expect(1, 1458, '\P{^Is_Canonical_Combining_Class=  CCC12}', "");
Expect(0, 1459, '\p{Is_Canonical_Combining_Class=  CCC12}', "");
Expect(1, 1459, '\p{^Is_Canonical_Combining_Class=  CCC12}', "");
Expect(1, 1459, '\P{Is_Canonical_Combining_Class=  CCC12}', "");
Expect(0, 1459, '\P{^Is_Canonical_Combining_Class=  CCC12}', "");
Error('\p{Is_Ccc=_00012/a/}');
Error('\P{Is_Ccc=_00012/a/}');
Expect(1, 1458, '\p{Is_Ccc=0000001_2}', "");
Expect(0, 1458, '\p{^Is_Ccc=0000001_2}', "");
Expect(0, 1458, '\P{Is_Ccc=0000001_2}', "");
Expect(1, 1458, '\P{^Is_Ccc=0000001_2}', "");
Expect(0, 1459, '\p{Is_Ccc=0000001_2}', "");
Expect(1, 1459, '\p{^Is_Ccc=0000001_2}', "");
Expect(1, 1459, '\P{Is_Ccc=0000001_2}', "");
Expect(0, 1459, '\P{^Is_Ccc=0000001_2}', "");
Error('\p{Canonical_Combining_Class=/a/  ccc122}');
Error('\P{Canonical_Combining_Class=/a/  ccc122}');
Expect(1, 3787, '\p{Canonical_Combining_Class=ccc122}', "");
Expect(0, 3787, '\p{^Canonical_Combining_Class=ccc122}', "");
Expect(0, 3787, '\P{Canonical_Combining_Class=ccc122}', "");
Expect(1, 3787, '\P{^Canonical_Combining_Class=ccc122}', "");
Expect(0, 3788, '\p{Canonical_Combining_Class=ccc122}', "");
Expect(1, 3788, '\p{^Canonical_Combining_Class=ccc122}', "");
Expect(1, 3788, '\P{Canonical_Combining_Class=ccc122}', "");
Expect(0, 3788, '\P{^Canonical_Combining_Class=ccc122}', "");
Expect(1, 3787, '\p{Canonical_Combining_Class: -_CCC122}', "");
Expect(0, 3787, '\p{^Canonical_Combining_Class: -_CCC122}', "");
Expect(0, 3787, '\P{Canonical_Combining_Class: -_CCC122}', "");
Expect(1, 3787, '\P{^Canonical_Combining_Class: -_CCC122}', "");
Expect(0, 3788, '\p{Canonical_Combining_Class: -_CCC122}', "");
Expect(1, 3788, '\p{^Canonical_Combining_Class: -_CCC122}', "");
Expect(1, 3788, '\P{Canonical_Combining_Class: -_CCC122}', "");
Expect(0, 3788, '\P{^Canonical_Combining_Class: -_CCC122}', "");
Error('\p{Ccc:   /a/-	0_0_0_0_0_1_22}');
Error('\P{Ccc:   /a/-	0_0_0_0_0_1_22}');
Expect(1, 3787, '\p{Ccc=+000_000_012_2}', "");
Expect(0, 3787, '\p{^Ccc=+000_000_012_2}', "");
Expect(0, 3787, '\P{Ccc=+000_000_012_2}', "");
Expect(1, 3787, '\P{^Ccc=+000_000_012_2}', "");
Expect(0, 3788, '\p{Ccc=+000_000_012_2}', "");
Expect(1, 3788, '\p{^Ccc=+000_000_012_2}', "");
Expect(1, 3788, '\P{Ccc=+000_000_012_2}', "");
Expect(0, 3788, '\P{^Ccc=+000_000_012_2}', "");
Error('\p{Is_Canonical_Combining_Class:   /a/__ccc122}');
Error('\P{Is_Canonical_Combining_Class:   /a/__ccc122}');
Expect(1, 3787, '\p{Is_Canonical_Combining_Class=ccc122}', "");
Expect(0, 3787, '\p{^Is_Canonical_Combining_Class=ccc122}', "");
Expect(0, 3787, '\P{Is_Canonical_Combining_Class=ccc122}', "");
Expect(1, 3787, '\P{^Is_Canonical_Combining_Class=ccc122}', "");
Expect(0, 3788, '\p{Is_Canonical_Combining_Class=ccc122}', "");
Expect(1, 3788, '\p{^Is_Canonical_Combining_Class=ccc122}', "");
Expect(1, 3788, '\P{Is_Canonical_Combining_Class=ccc122}', "");
Expect(0, 3788, '\P{^Is_Canonical_Combining_Class=ccc122}', "");
Expect(1, 3787, '\p{Is_Canonical_Combining_Class=_ CCC122}', "");
Expect(0, 3787, '\p{^Is_Canonical_Combining_Class=_ CCC122}', "");
Expect(0, 3787, '\P{Is_Canonical_Combining_Class=_ CCC122}', "");
Expect(1, 3787, '\P{^Is_Canonical_Combining_Class=_ CCC122}', "");
Expect(0, 3788, '\p{Is_Canonical_Combining_Class=_ CCC122}', "");
Expect(1, 3788, '\p{^Is_Canonical_Combining_Class=_ CCC122}', "");
Expect(1, 3788, '\P{Is_Canonical_Combining_Class=_ CCC122}', "");
Expect(0, 3788, '\P{^Is_Canonical_Combining_Class=_ CCC122}', "");
Error('\p{Is_Ccc=/a/__0000000012_2}');
Error('\P{Is_Ccc=/a/__0000000012_2}');
Expect(1, 3787, '\p{Is_Ccc=000000000122}', "");
Expect(0, 3787, '\p{^Is_Ccc=000000000122}', "");
Expect(0, 3787, '\P{Is_Ccc=000000000122}', "");
Expect(1, 3787, '\P{^Is_Ccc=000000000122}', "");
Expect(0, 3788, '\p{Is_Ccc=000000000122}', "");
Expect(1, 3788, '\p{^Is_Ccc=000000000122}', "");
Expect(1, 3788, '\P{Is_Ccc=000000000122}', "");
Expect(0, 3788, '\P{^Is_Ccc=000000000122}', "");
Error('\p{Canonical_Combining_Class=/a/		CCC129}');
Error('\P{Canonical_Combining_Class=/a/		CCC129}');
Expect(1, 3953, '\p{Canonical_Combining_Class=ccc129}', "");
Expect(0, 3953, '\p{^Canonical_Combining_Class=ccc129}', "");
Expect(0, 3953, '\P{Canonical_Combining_Class=ccc129}', "");
Expect(1, 3953, '\P{^Canonical_Combining_Class=ccc129}', "");
Expect(0, 3954, '\p{Canonical_Combining_Class=ccc129}', "");
Expect(1, 3954, '\p{^Canonical_Combining_Class=ccc129}', "");
Expect(1, 3954, '\P{Canonical_Combining_Class=ccc129}', "");
Expect(0, 3954, '\P{^Canonical_Combining_Class=ccc129}', "");
Expect(1, 3953, '\p{Canonical_Combining_Class=--CCC129}', "");
Expect(0, 3953, '\p{^Canonical_Combining_Class=--CCC129}', "");
Expect(0, 3953, '\P{Canonical_Combining_Class=--CCC129}', "");
Expect(1, 3953, '\P{^Canonical_Combining_Class=--CCC129}', "");
Expect(0, 3954, '\p{Canonical_Combining_Class=--CCC129}', "");
Expect(1, 3954, '\p{^Canonical_Combining_Class=--CCC129}', "");
Expect(1, 3954, '\P{Canonical_Combining_Class=--CCC129}', "");
Expect(0, 3954, '\P{^Canonical_Combining_Class=--CCC129}', "");
Error('\p{Ccc=:=  +0000_0012_9}');
Error('\P{Ccc=:=  +0000_0012_9}');
Expect(1, 3953, '\p{Ccc=0_0_0_0_0129}', "");
Expect(0, 3953, '\p{^Ccc=0_0_0_0_0129}', "");
Expect(0, 3953, '\P{Ccc=0_0_0_0_0129}', "");
Expect(1, 3953, '\P{^Ccc=0_0_0_0_0129}', "");
Expect(0, 3954, '\p{Ccc=0_0_0_0_0129}', "");
Expect(1, 3954, '\p{^Ccc=0_0_0_0_0129}', "");
Expect(1, 3954, '\P{Ccc=0_0_0_0_0129}', "");
Expect(0, 3954, '\P{^Ccc=0_0_0_0_0129}', "");
Error('\p{Is_Canonical_Combining_Class=/a/__ccc129}');
Error('\P{Is_Canonical_Combining_Class=/a/__ccc129}');
Expect(1, 3953, '\p{Is_Canonical_Combining_Class=ccc129}', "");
Expect(0, 3953, '\p{^Is_Canonical_Combining_Class=ccc129}', "");
Expect(0, 3953, '\P{Is_Canonical_Combining_Class=ccc129}', "");
Expect(1, 3953, '\P{^Is_Canonical_Combining_Class=ccc129}', "");
Expect(0, 3954, '\p{Is_Canonical_Combining_Class=ccc129}', "");
Expect(1, 3954, '\p{^Is_Canonical_Combining_Class=ccc129}', "");
Expect(1, 3954, '\P{Is_Canonical_Combining_Class=ccc129}', "");
Expect(0, 3954, '\P{^Is_Canonical_Combining_Class=ccc129}', "");
Expect(1, 3953, '\p{Is_Canonical_Combining_Class=-	CCC129}', "");
Expect(0, 3953, '\p{^Is_Canonical_Combining_Class=-	CCC129}', "");
Expect(0, 3953, '\P{Is_Canonical_Combining_Class=-	CCC129}', "");
Expect(1, 3953, '\P{^Is_Canonical_Combining_Class=-	CCC129}', "");
Expect(0, 3954, '\p{Is_Canonical_Combining_Class=-	CCC129}', "");
Expect(1, 3954, '\p{^Is_Canonical_Combining_Class=-	CCC129}', "");
Expect(1, 3954, '\P{Is_Canonical_Combining_Class=-	CCC129}', "");
Expect(0, 3954, '\P{^Is_Canonical_Combining_Class=-	CCC129}', "");
Error('\p{Is_Ccc:	/a/ 000000000129}');
Error('\P{Is_Ccc:	/a/ 000000000129}');
Expect(1, 3953, '\p{Is_Ccc=00129}', "");
Expect(0, 3953, '\p{^Is_Ccc=00129}', "");
Expect(0, 3953, '\P{Is_Ccc=00129}', "");
Expect(1, 3953, '\P{^Is_Ccc=00129}', "");
Expect(0, 3954, '\p{Is_Ccc=00129}', "");
Expect(1, 3954, '\p{^Is_Ccc=00129}', "");
Expect(1, 3954, '\P{Is_Ccc=00129}', "");
Expect(0, 3954, '\P{^Is_Ccc=00129}', "");
Error('\p{Canonical_Combining_Class=/a/	-CCC13}');
Error('\P{Canonical_Combining_Class=/a/	-CCC13}');
Expect(1, 1459, '\p{Canonical_Combining_Class=ccc13}', "");
Expect(0, 1459, '\p{^Canonical_Combining_Class=ccc13}', "");
Expect(0, 1459, '\P{Canonical_Combining_Class=ccc13}', "");
Expect(1, 1459, '\P{^Canonical_Combining_Class=ccc13}', "");
Expect(0, 1460, '\p{Canonical_Combining_Class=ccc13}', "");
Expect(1, 1460, '\p{^Canonical_Combining_Class=ccc13}', "");
Expect(1, 1460, '\P{Canonical_Combining_Class=ccc13}', "");
Expect(0, 1460, '\P{^Canonical_Combining_Class=ccc13}', "");
Expect(1, 1459, '\p{Canonical_Combining_Class=	CCC13}', "");
Expect(0, 1459, '\p{^Canonical_Combining_Class=	CCC13}', "");
Expect(0, 1459, '\P{Canonical_Combining_Class=	CCC13}', "");
Expect(1, 1459, '\P{^Canonical_Combining_Class=	CCC13}', "");
Expect(0, 1460, '\p{Canonical_Combining_Class=	CCC13}', "");
Expect(1, 1460, '\p{^Canonical_Combining_Class=	CCC13}', "");
Expect(1, 1460, '\P{Canonical_Combining_Class=	CCC13}', "");
Expect(0, 1460, '\P{^Canonical_Combining_Class=	CCC13}', "");
Error('\p{Ccc=/a/  +0_0_0_0_0_0_0013}');
Error('\P{Ccc=/a/  +0_0_0_0_0_0_0013}');
Expect(1, 1459, '\p{Ccc:	+0_0_0_0_0_0_0_0013}', "");
Expect(0, 1459, '\p{^Ccc:	+0_0_0_0_0_0_0_0013}', "");
Expect(0, 1459, '\P{Ccc:	+0_0_0_0_0_0_0_0013}', "");
Expect(1, 1459, '\P{^Ccc:	+0_0_0_0_0_0_0_0013}', "");
Expect(0, 1460, '\p{Ccc:	+0_0_0_0_0_0_0_0013}', "");
Expect(1, 1460, '\p{^Ccc:	+0_0_0_0_0_0_0_0013}', "");
Expect(1, 1460, '\P{Ccc:	+0_0_0_0_0_0_0_0013}', "");
Expect(0, 1460, '\P{^Ccc:	+0_0_0_0_0_0_0_0013}', "");
Error('\p{Is_Canonical_Combining_Class=-:=CCC13}');
Error('\P{Is_Canonical_Combining_Class=-:=CCC13}');
Expect(1, 1459, '\p{Is_Canonical_Combining_Class=ccc13}', "");
Expect(0, 1459, '\p{^Is_Canonical_Combining_Class=ccc13}', "");
Expect(0, 1459, '\P{Is_Canonical_Combining_Class=ccc13}', "");
Expect(1, 1459, '\P{^Is_Canonical_Combining_Class=ccc13}', "");
Expect(0, 1460, '\p{Is_Canonical_Combining_Class=ccc13}', "");
Expect(1, 1460, '\p{^Is_Canonical_Combining_Class=ccc13}', "");
Expect(1, 1460, '\P{Is_Canonical_Combining_Class=ccc13}', "");
Expect(0, 1460, '\P{^Is_Canonical_Combining_Class=ccc13}', "");
Expect(1, 1459, '\p{Is_Canonical_Combining_Class: 		CCC13}', "");
Expect(0, 1459, '\p{^Is_Canonical_Combining_Class: 		CCC13}', "");
Expect(0, 1459, '\P{Is_Canonical_Combining_Class: 		CCC13}', "");
Expect(1, 1459, '\P{^Is_Canonical_Combining_Class: 		CCC13}', "");
Expect(0, 1460, '\p{Is_Canonical_Combining_Class: 		CCC13}', "");
Expect(1, 1460, '\p{^Is_Canonical_Combining_Class: 		CCC13}', "");
Expect(1, 1460, '\P{Is_Canonical_Combining_Class: 		CCC13}', "");
Expect(0, 1460, '\P{^Is_Canonical_Combining_Class: 		CCC13}', "");
Error('\p{Is_Ccc=-_13:=}');
Error('\P{Is_Ccc=-_13:=}');
Expect(1, 1459, '\p{Is_Ccc=+0_0_0_0_0_0_00013}', "");
Expect(0, 1459, '\p{^Is_Ccc=+0_0_0_0_0_0_00013}', "");
Expect(0, 1459, '\P{Is_Ccc=+0_0_0_0_0_0_00013}', "");
Expect(1, 1459, '\P{^Is_Ccc=+0_0_0_0_0_0_00013}', "");
Expect(0, 1460, '\p{Is_Ccc=+0_0_0_0_0_0_00013}', "");
Expect(1, 1460, '\p{^Is_Ccc=+0_0_0_0_0_0_00013}', "");
Expect(1, 1460, '\P{Is_Ccc=+0_0_0_0_0_0_00013}', "");
Expect(0, 1460, '\P{^Is_Ccc=+0_0_0_0_0_0_00013}', "");
Error('\p{Canonical_Combining_Class=_:=CCC130}');
Error('\P{Canonical_Combining_Class=_:=CCC130}');
Expect(1, 3968, '\p{Canonical_Combining_Class=ccc130}', "");
Expect(0, 3968, '\p{^Canonical_Combining_Class=ccc130}', "");
Expect(0, 3968, '\P{Canonical_Combining_Class=ccc130}', "");
Expect(1, 3968, '\P{^Canonical_Combining_Class=ccc130}', "");
Expect(0, 3969, '\p{Canonical_Combining_Class=ccc130}', "");
Expect(1, 3969, '\p{^Canonical_Combining_Class=ccc130}', "");
Expect(1, 3969, '\P{Canonical_Combining_Class=ccc130}', "");
Expect(0, 3969, '\P{^Canonical_Combining_Class=ccc130}', "");
Expect(1, 3968, '\p{Canonical_Combining_Class=- CCC130}', "");
Expect(0, 3968, '\p{^Canonical_Combining_Class=- CCC130}', "");
Expect(0, 3968, '\P{Canonical_Combining_Class=- CCC130}', "");
Expect(1, 3968, '\P{^Canonical_Combining_Class=- CCC130}', "");
Expect(0, 3969, '\p{Canonical_Combining_Class=- CCC130}', "");
Expect(1, 3969, '\p{^Canonical_Combining_Class=- CCC130}', "");
Expect(1, 3969, '\P{Canonical_Combining_Class=- CCC130}', "");
Expect(0, 3969, '\P{^Canonical_Combining_Class=- CCC130}', "");
Error('\p{Ccc=-:=00000130}');
Error('\P{Ccc=-:=00000130}');
Expect(1, 3968, '\p{Ccc=00_00_00_130}', "");
Expect(0, 3968, '\p{^Ccc=00_00_00_130}', "");
Expect(0, 3968, '\P{Ccc=00_00_00_130}', "");
Expect(1, 3968, '\P{^Ccc=00_00_00_130}', "");
Expect(0, 3969, '\p{Ccc=00_00_00_130}', "");
Expect(1, 3969, '\p{^Ccc=00_00_00_130}', "");
Expect(1, 3969, '\P{Ccc=00_00_00_130}', "");
Expect(0, 3969, '\P{^Ccc=00_00_00_130}', "");
Error('\p{Is_Canonical_Combining_Class=/a/  CCC130}');
Error('\P{Is_Canonical_Combining_Class=/a/  CCC130}');
Expect(1, 3968, '\p{Is_Canonical_Combining_Class=ccc130}', "");
Expect(0, 3968, '\p{^Is_Canonical_Combining_Class=ccc130}', "");
Expect(0, 3968, '\P{Is_Canonical_Combining_Class=ccc130}', "");
Expect(1, 3968, '\P{^Is_Canonical_Combining_Class=ccc130}', "");
Expect(0, 3969, '\p{Is_Canonical_Combining_Class=ccc130}', "");
Expect(1, 3969, '\p{^Is_Canonical_Combining_Class=ccc130}', "");
Expect(1, 3969, '\P{Is_Canonical_Combining_Class=ccc130}', "");
Expect(0, 3969, '\P{^Is_Canonical_Combining_Class=ccc130}', "");
Expect(1, 3968, '\p{Is_Canonical_Combining_Class=	_CCC130}', "");
Expect(0, 3968, '\p{^Is_Canonical_Combining_Class=	_CCC130}', "");
Expect(0, 3968, '\P{Is_Canonical_Combining_Class=	_CCC130}', "");
Expect(1, 3968, '\P{^Is_Canonical_Combining_Class=	_CCC130}', "");
Expect(0, 3969, '\p{Is_Canonical_Combining_Class=	_CCC130}', "");
Expect(1, 3969, '\p{^Is_Canonical_Combining_Class=	_CCC130}', "");
Expect(1, 3969, '\P{Is_Canonical_Combining_Class=	_CCC130}', "");
Expect(0, 3969, '\P{^Is_Canonical_Combining_Class=	_CCC130}', "");
Error('\p{Is_Ccc::=	-00013_0}');
Error('\P{Is_Ccc::=	-00013_0}');
Expect(1, 3968, '\p{Is_Ccc=0000000130}', "");
Expect(0, 3968, '\p{^Is_Ccc=0000000130}', "");
Expect(0, 3968, '\P{Is_Ccc=0000000130}', "");
Expect(1, 3968, '\P{^Is_Ccc=0000000130}', "");
Expect(0, 3969, '\p{Is_Ccc=0000000130}', "");
Expect(1, 3969, '\p{^Is_Ccc=0000000130}', "");
Expect(1, 3969, '\P{Is_Ccc=0000000130}', "");
Expect(0, 3969, '\P{^Is_Ccc=0000000130}', "");
Error('\p{Canonical_Combining_Class=__CCC132:=}');
Error('\P{Canonical_Combining_Class=__CCC132:=}');
Expect(1, 3956, '\p{Canonical_Combining_Class=ccc132}', "");
Expect(0, 3956, '\p{^Canonical_Combining_Class=ccc132}', "");
Expect(0, 3956, '\P{Canonical_Combining_Class=ccc132}', "");
Expect(1, 3956, '\P{^Canonical_Combining_Class=ccc132}', "");
Expect(0, 3957, '\p{Canonical_Combining_Class=ccc132}', "");
Expect(1, 3957, '\p{^Canonical_Combining_Class=ccc132}', "");
Expect(1, 3957, '\P{Canonical_Combining_Class=ccc132}', "");
Expect(0, 3957, '\P{^Canonical_Combining_Class=ccc132}', "");
Expect(1, 3956, '\p{Canonical_Combining_Class=_CCC132}', "");
Expect(0, 3956, '\p{^Canonical_Combining_Class=_CCC132}', "");
Expect(0, 3956, '\P{Canonical_Combining_Class=_CCC132}', "");
Expect(1, 3956, '\P{^Canonical_Combining_Class=_CCC132}', "");
Expect(0, 3957, '\p{Canonical_Combining_Class=_CCC132}', "");
Expect(1, 3957, '\p{^Canonical_Combining_Class=_CCC132}', "");
Expect(1, 3957, '\P{Canonical_Combining_Class=_CCC132}', "");
Expect(0, 3957, '\P{^Canonical_Combining_Class=_CCC132}', "");
Error('\p{Ccc:   /a/_ +132}');
Error('\P{Ccc:   /a/_ +132}');
Expect(1, 3956, '\p{Ccc=13_2}', "");
Expect(0, 3956, '\p{^Ccc=13_2}', "");
Expect(0, 3956, '\P{Ccc=13_2}', "");
Expect(1, 3956, '\P{^Ccc=13_2}', "");
Expect(0, 3957, '\p{Ccc=13_2}', "");
Expect(1, 3957, '\p{^Ccc=13_2}', "");
Expect(1, 3957, '\P{Ccc=13_2}', "");
Expect(0, 3957, '\P{^Ccc=13_2}', "");
Error('\p{Is_Canonical_Combining_Class=/a/--CCC132}');
Error('\P{Is_Canonical_Combining_Class=/a/--CCC132}');
Expect(1, 3956, '\p{Is_Canonical_Combining_Class=ccc132}', "");
Expect(0, 3956, '\p{^Is_Canonical_Combining_Class=ccc132}', "");
Expect(0, 3956, '\P{Is_Canonical_Combining_Class=ccc132}', "");
Expect(1, 3956, '\P{^Is_Canonical_Combining_Class=ccc132}', "");
Expect(0, 3957, '\p{Is_Canonical_Combining_Class=ccc132}', "");
Expect(1, 3957, '\p{^Is_Canonical_Combining_Class=ccc132}', "");
Expect(1, 3957, '\P{Is_Canonical_Combining_Class=ccc132}', "");
Expect(0, 3957, '\P{^Is_Canonical_Combining_Class=ccc132}', "");
Expect(1, 3956, '\p{Is_Canonical_Combining_Class: __CCC132}', "");
Expect(0, 3956, '\p{^Is_Canonical_Combining_Class: __CCC132}', "");
Expect(0, 3956, '\P{Is_Canonical_Combining_Class: __CCC132}', "");
Expect(1, 3956, '\P{^Is_Canonical_Combining_Class: __CCC132}', "");
Expect(0, 3957, '\p{Is_Canonical_Combining_Class: __CCC132}', "");
Expect(1, 3957, '\p{^Is_Canonical_Combining_Class: __CCC132}', "");
Expect(1, 3957, '\P{Is_Canonical_Combining_Class: __CCC132}', "");
Expect(0, 3957, '\P{^Is_Canonical_Combining_Class: __CCC132}', "");
Error('\p{Is_Ccc=_:=0013_2}');
Error('\P{Is_Ccc=_:=0013_2}');
Expect(1, 3956, '\p{Is_Ccc=+013_2}', "");
Expect(0, 3956, '\p{^Is_Ccc=+013_2}', "");
Expect(0, 3956, '\P{Is_Ccc=+013_2}', "");
Expect(1, 3956, '\P{^Is_Ccc=+013_2}', "");
Expect(0, 3957, '\p{Is_Ccc=+013_2}', "");
Expect(1, 3957, '\p{^Is_Ccc=+013_2}', "");
Expect(1, 3957, '\P{Is_Ccc=+013_2}', "");
Expect(0, 3957, '\P{^Is_Ccc=+013_2}', "");
Error('\p{Canonical_Combining_Class=	CCC133:=}');
Error('\P{Canonical_Combining_Class=	CCC133:=}');
Expect(0, 1, '\p{Canonical_Combining_Class=ccc133}', "");
Expect(1, 1, '\p{^Canonical_Combining_Class=ccc133}', "");
Expect(1, 1, '\P{Canonical_Combining_Class=ccc133}', "");
Expect(0, 1, '\P{^Canonical_Combining_Class=ccc133}', "");
Expect(0, 1, '\p{Canonical_Combining_Class= CCC133}', "");
Expect(1, 1, '\p{^Canonical_Combining_Class= CCC133}', "");
Expect(1, 1, '\P{Canonical_Combining_Class= CCC133}', "");
Expect(0, 1, '\P{^Canonical_Combining_Class= CCC133}', "");
Error('\p{Ccc=	_00133:=}');
Error('\P{Ccc=	_00133:=}');
Expect(0, 1, '\p{Ccc=000000000133}', "");
Expect(1, 1, '\p{^Ccc=000000000133}', "");
Expect(1, 1, '\P{Ccc=000000000133}', "");
Expect(0, 1, '\P{^Ccc=000000000133}', "");
Error('\p{Is_Canonical_Combining_Class= /a/CCC133}');
Error('\P{Is_Canonical_Combining_Class= /a/CCC133}');
Expect(0, 1, '\p{Is_Canonical_Combining_Class:	ccc133}', "");
Expect(1, 1, '\p{^Is_Canonical_Combining_Class:	ccc133}', "");
Expect(1, 1, '\P{Is_Canonical_Combining_Class:	ccc133}', "");
Expect(0, 1, '\P{^Is_Canonical_Combining_Class:	ccc133}', "");
Expect(0, 1, '\p{Is_Canonical_Combining_Class= -ccc133}', "");
Expect(1, 1, '\p{^Is_Canonical_Combining_Class= -ccc133}', "");
Expect(1, 1, '\P{Is_Canonical_Combining_Class= -ccc133}', "");
Expect(0, 1, '\P{^Is_Canonical_Combining_Class= -ccc133}', "");
Error('\p{Is_Ccc=	-0_0_0_0_0_00133/a/}');
Error('\P{Is_Ccc=	-0_0_0_0_0_00133/a/}');
Expect(0, 1, '\p{Is_Ccc=0_0_0_0_0_0_000133}', "");
Expect(1, 1, '\p{^Is_Ccc=0_0_0_0_0_0_000133}', "");
Expect(1, 1, '\P{Is_Ccc=0_0_0_0_0_0_000133}', "");
Expect(0, 1, '\P{^Is_Ccc=0_0_0_0_0_0_000133}', "");
Error('\p{Canonical_Combining_Class=_/a/CCC14}');
Error('\P{Canonical_Combining_Class=_/a/CCC14}');
Expect(1, 1460, '\p{Canonical_Combining_Class=ccc14}', "");
Expect(0, 1460, '\p{^Canonical_Combining_Class=ccc14}', "");
Expect(0, 1460, '\P{Canonical_Combining_Class=ccc14}', "");
Expect(1, 1460, '\P{^Canonical_Combining_Class=ccc14}', "");
Expect(0, 1461, '\p{Canonical_Combining_Class=ccc14}', "");
Expect(1, 1461, '\p{^Canonical_Combining_Class=ccc14}', "");
Expect(1, 1461, '\P{Canonical_Combining_Class=ccc14}', "");
Expect(0, 1461, '\P{^Canonical_Combining_Class=ccc14}', "");
Expect(1, 1460, '\p{Canonical_Combining_Class:-_CCC14}', "");
Expect(0, 1460, '\p{^Canonical_Combining_Class:-_CCC14}', "");
Expect(0, 1460, '\P{Canonical_Combining_Class:-_CCC14}', "");
Expect(1, 1460, '\P{^Canonical_Combining_Class:-_CCC14}', "");
Expect(0, 1461, '\p{Canonical_Combining_Class:-_CCC14}', "");
Expect(1, 1461, '\p{^Canonical_Combining_Class:-_CCC14}', "");
Expect(1, 1461, '\P{Canonical_Combining_Class:-_CCC14}', "");
Expect(0, 1461, '\P{^Canonical_Combining_Class:-_CCC14}', "");
Error('\p{Ccc=_/a/+000000014}');
Error('\P{Ccc=_/a/+000000014}');
Expect(1, 1460, '\p{Ccc=00000014}', "");
Expect(0, 1460, '\p{^Ccc=00000014}', "");
Expect(0, 1460, '\P{Ccc=00000014}', "");
Expect(1, 1460, '\P{^Ccc=00000014}', "");
Expect(0, 1461, '\p{Ccc=00000014}', "");
Expect(1, 1461, '\p{^Ccc=00000014}', "");
Expect(1, 1461, '\P{Ccc=00000014}', "");
Expect(0, 1461, '\P{^Ccc=00000014}', "");
Error('\p{Is_Canonical_Combining_Class:	_ CCC14/a/}');
Error('\P{Is_Canonical_Combining_Class:	_ CCC14/a/}');
Expect(1, 1460, '\p{Is_Canonical_Combining_Class=ccc14}', "");
Expect(0, 1460, '\p{^Is_Canonical_Combining_Class=ccc14}', "");
Expect(0, 1460, '\P{Is_Canonical_Combining_Class=ccc14}', "");
Expect(1, 1460, '\P{^Is_Canonical_Combining_Class=ccc14}', "");
Expect(0, 1461, '\p{Is_Canonical_Combining_Class=ccc14}', "");
Expect(1, 1461, '\p{^Is_Canonical_Combining_Class=ccc14}', "");
Expect(1, 1461, '\P{Is_Canonical_Combining_Class=ccc14}', "");
Expect(0, 1461, '\P{^Is_Canonical_Combining_Class=ccc14}', "");
Expect(1, 1460, '\p{Is_Canonical_Combining_Class: 	 CCC14}', "");
Expect(0, 1460, '\p{^Is_Canonical_Combining_Class: 	 CCC14}', "");
Expect(0, 1460, '\P{Is_Canonical_Combining_Class: 	 CCC14}', "");
Expect(1, 1460, '\P{^Is_Canonical_Combining_Class: 	 CCC14}', "");
Expect(0, 1461, '\p{Is_Canonical_Combining_Class: 	 CCC14}', "");
Expect(1, 1461, '\p{^Is_Canonical_Combining_Class: 	 CCC14}', "");
Expect(1, 1461, '\P{Is_Canonical_Combining_Class: 	 CCC14}', "");
Expect(0, 1461, '\P{^Is_Canonical_Combining_Class: 	 CCC14}', "");
Error('\p{Is_Ccc=-_1_4/a/}');
Error('\P{Is_Ccc=-_1_4/a/}');
Expect(1, 1460, '\p{Is_Ccc=1_4}', "");
Expect(0, 1460, '\p{^Is_Ccc=1_4}', "");
Expect(0, 1460, '\P{Is_Ccc=1_4}', "");
Expect(1, 1460, '\P{^Is_Ccc=1_4}', "");
Expect(0, 1461, '\p{Is_Ccc=1_4}', "");
Expect(1, 1461, '\p{^Is_Ccc=1_4}', "");
Expect(1, 1461, '\P{Is_Ccc=1_4}', "");
Expect(0, 1461, '\P{^Is_Ccc=1_4}', "");
Error('\p{Canonical_Combining_Class=:= _CCC15}');
Error('\P{Canonical_Combining_Class=:= _CCC15}');
Expect(1, 1461, '\p{Canonical_Combining_Class=ccc15}', "");
Expect(0, 1461, '\p{^Canonical_Combining_Class=ccc15}', "");
Expect(0, 1461, '\P{Canonical_Combining_Class=ccc15}', "");
Expect(1, 1461, '\P{^Canonical_Combining_Class=ccc15}', "");
Expect(0, 1462, '\p{Canonical_Combining_Class=ccc15}', "");
Expect(1, 1462, '\p{^Canonical_Combining_Class=ccc15}', "");
Expect(1, 1462, '\P{Canonical_Combining_Class=ccc15}', "");
Expect(0, 1462, '\P{^Canonical_Combining_Class=ccc15}', "");
Expect(1, 1461, '\p{Canonical_Combining_Class=_CCC15}', "");
Expect(0, 1461, '\p{^Canonical_Combining_Class=_CCC15}', "");
Expect(0, 1461, '\P{Canonical_Combining_Class=_CCC15}', "");
Expect(1, 1461, '\P{^Canonical_Combining_Class=_CCC15}', "");
Expect(0, 1462, '\p{Canonical_Combining_Class=_CCC15}', "");
Expect(1, 1462, '\p{^Canonical_Combining_Class=_CCC15}', "");
Expect(1, 1462, '\P{Canonical_Combining_Class=_CCC15}', "");
Expect(0, 1462, '\P{^Canonical_Combining_Class=_CCC15}', "");
Error('\p{Ccc=/a/_ 015}');
Error('\P{Ccc=/a/_ 015}');
Expect(1, 1461, '\p{Ccc=+000000015}', "");
Expect(0, 1461, '\p{^Ccc=+000000015}', "");
Expect(0, 1461, '\P{Ccc=+000000015}', "");
Expect(1, 1461, '\P{^Ccc=+000000015}', "");
Expect(0, 1462, '\p{Ccc=+000000015}', "");
Expect(1, 1462, '\p{^Ccc=+000000015}', "");
Expect(1, 1462, '\P{Ccc=+000000015}', "");
Expect(0, 1462, '\P{^Ccc=+000000015}', "");
Error('\p{Is_Canonical_Combining_Class= CCC15/a/}');
Error('\P{Is_Canonical_Combining_Class= CCC15/a/}');
Expect(1, 1461, '\p{Is_Canonical_Combining_Class=ccc15}', "");
Expect(0, 1461, '\p{^Is_Canonical_Combining_Class=ccc15}', "");
Expect(0, 1461, '\P{Is_Canonical_Combining_Class=ccc15}', "");
Expect(1, 1461, '\P{^Is_Canonical_Combining_Class=ccc15}', "");
Expect(0, 1462, '\p{Is_Canonical_Combining_Class=ccc15}', "");
Expect(1, 1462, '\p{^Is_Canonical_Combining_Class=ccc15}', "");
Expect(1, 1462, '\P{Is_Canonical_Combining_Class=ccc15}', "");
Expect(0, 1462, '\P{^Is_Canonical_Combining_Class=ccc15}', "");
Expect(1, 1461, '\p{Is_Canonical_Combining_Class:		 CCC15}', "");
Expect(0, 1461, '\p{^Is_Canonical_Combining_Class:		 CCC15}', "");
Expect(0, 1461, '\P{Is_Canonical_Combining_Class:		 CCC15}', "");
Expect(1, 1461, '\P{^Is_Canonical_Combining_Class:		 CCC15}', "");
Expect(0, 1462, '\p{Is_Canonical_Combining_Class:		 CCC15}', "");
Expect(1, 1462, '\p{^Is_Canonical_Combining_Class:		 CCC15}', "");
Expect(1, 1462, '\P{Is_Canonical_Combining_Class:		 CCC15}', "");
Expect(0, 1462, '\P{^Is_Canonical_Combining_Class:		 CCC15}', "");
Error('\p{Is_Ccc::= -01_5}');
Error('\P{Is_Ccc::= -01_5}');
Expect(1, 1461, '\p{Is_Ccc=0015}', "");
Expect(0, 1461, '\p{^Is_Ccc=0015}', "");
Expect(0, 1461, '\P{Is_Ccc=0015}', "");
Expect(1, 1461, '\P{^Is_Ccc=0015}', "");
Expect(0, 1462, '\p{Is_Ccc=0015}', "");
Expect(1, 1462, '\p{^Is_Ccc=0015}', "");
Expect(1, 1462, '\P{Is_Ccc=0015}', "");
Expect(0, 1462, '\P{^Is_Ccc=0015}', "");
Error('\p{Canonical_Combining_Class=:=  CCC16}');
Error('\P{Canonical_Combining_Class=:=  CCC16}');
Expect(1, 1462, '\p{Canonical_Combining_Class=ccc16}', "");
Expect(0, 1462, '\p{^Canonical_Combining_Class=ccc16}', "");
Expect(0, 1462, '\P{Canonical_Combining_Class=ccc16}', "");
Expect(1, 1462, '\P{^Canonical_Combining_Class=ccc16}', "");
Expect(0, 1463, '\p{Canonical_Combining_Class=ccc16}', "");
Expect(1, 1463, '\p{^Canonical_Combining_Class=ccc16}', "");
Expect(1, 1463, '\P{Canonical_Combining_Class=ccc16}', "");
Expect(0, 1463, '\P{^Canonical_Combining_Class=ccc16}', "");
Expect(1, 1462, '\p{Canonical_Combining_Class=-_ccc16}', "");
Expect(0, 1462, '\p{^Canonical_Combining_Class=-_ccc16}', "");
Expect(0, 1462, '\P{Canonical_Combining_Class=-_ccc16}', "");
Expect(1, 1462, '\P{^Canonical_Combining_Class=-_ccc16}', "");
Expect(0, 1463, '\p{Canonical_Combining_Class=-_ccc16}', "");
Expect(1, 1463, '\p{^Canonical_Combining_Class=-_ccc16}', "");
Expect(1, 1463, '\P{Canonical_Combining_Class=-_ccc16}', "");
Expect(0, 1463, '\P{^Canonical_Combining_Class=-_ccc16}', "");
Error('\p{Ccc=:=-_16}');
Error('\P{Ccc=:=-_16}');
Expect(1, 1462, '\p{Ccc=00000016}', "");
Expect(0, 1462, '\p{^Ccc=00000016}', "");
Expect(0, 1462, '\P{Ccc=00000016}', "");
Expect(1, 1462, '\P{^Ccc=00000016}', "");
Expect(0, 1463, '\p{Ccc=00000016}', "");
Expect(1, 1463, '\p{^Ccc=00000016}', "");
Expect(1, 1463, '\P{Ccc=00000016}', "");
Expect(0, 1463, '\P{^Ccc=00000016}', "");
Error('\p{Is_Canonical_Combining_Class=/a/ccc16}');
Error('\P{Is_Canonical_Combining_Class=/a/ccc16}');
Expect(1, 1462, '\p{Is_Canonical_Combining_Class=ccc16}', "");
Expect(0, 1462, '\p{^Is_Canonical_Combining_Class=ccc16}', "");
Expect(0, 1462, '\P{Is_Canonical_Combining_Class=ccc16}', "");
Expect(1, 1462, '\P{^Is_Canonical_Combining_Class=ccc16}', "");
Expect(0, 1463, '\p{Is_Canonical_Combining_Class=ccc16}', "");
Expect(1, 1463, '\p{^Is_Canonical_Combining_Class=ccc16}', "");
Expect(1, 1463, '\P{Is_Canonical_Combining_Class=ccc16}', "");
Expect(0, 1463, '\P{^Is_Canonical_Combining_Class=ccc16}', "");
Expect(1, 1462, '\p{Is_Canonical_Combining_Class=_	ccc16}', "");
Expect(0, 1462, '\p{^Is_Canonical_Combining_Class=_	ccc16}', "");
Expect(0, 1462, '\P{Is_Canonical_Combining_Class=_	ccc16}', "");
Expect(1, 1462, '\P{^Is_Canonical_Combining_Class=_	ccc16}', "");
Expect(0, 1463, '\p{Is_Canonical_Combining_Class=_	ccc16}', "");
Expect(1, 1463, '\p{^Is_Canonical_Combining_Class=_	ccc16}', "");
Expect(1, 1463, '\P{Is_Canonical_Combining_Class=_	ccc16}', "");
Expect(0, 1463, '\P{^Is_Canonical_Combining_Class=_	ccc16}', "");
Error('\p{Is_Ccc:	__000000016:=}');
Error('\P{Is_Ccc:	__000000016:=}');
Expect(1, 1462, '\p{Is_Ccc=0000016}', "");
Expect(0, 1462, '\p{^Is_Ccc=0000016}', "");
Expect(0, 1462, '\P{Is_Ccc=0000016}', "");
Expect(1, 1462, '\P{^Is_Ccc=0000016}', "");
Expect(0, 1463, '\p{Is_Ccc=0000016}', "");
Expect(1, 1463, '\p{^Is_Ccc=0000016}', "");
Expect(1, 1463, '\P{Is_Ccc=0000016}', "");
Expect(0, 1463, '\P{^Is_Ccc=0000016}', "");
Error('\p{Canonical_Combining_Class= -CCC17/a/}');
Error('\P{Canonical_Combining_Class= -CCC17/a/}');
Expect(1, 1463, '\p{Canonical_Combining_Class=ccc17}', "");
Expect(0, 1463, '\p{^Canonical_Combining_Class=ccc17}', "");
Expect(0, 1463, '\P{Canonical_Combining_Class=ccc17}', "");
Expect(1, 1463, '\P{^Canonical_Combining_Class=ccc17}', "");
Expect(0, 1464, '\p{Canonical_Combining_Class=ccc17}', "");
Expect(1, 1464, '\p{^Canonical_Combining_Class=ccc17}', "");
Expect(1, 1464, '\P{Canonical_Combining_Class=ccc17}', "");
Expect(0, 1464, '\P{^Canonical_Combining_Class=ccc17}', "");
Expect(1, 1463, '\p{Canonical_Combining_Class=_ccc17}', "");
Expect(0, 1463, '\p{^Canonical_Combining_Class=_ccc17}', "");
Expect(0, 1463, '\P{Canonical_Combining_Class=_ccc17}', "");
Expect(1, 1463, '\P{^Canonical_Combining_Class=_ccc17}', "");
Expect(0, 1464, '\p{Canonical_Combining_Class=_ccc17}', "");
Expect(1, 1464, '\p{^Canonical_Combining_Class=_ccc17}', "");
Expect(1, 1464, '\P{Canonical_Combining_Class=_ccc17}', "");
Expect(0, 1464, '\P{^Canonical_Combining_Class=_ccc17}', "");
Error('\p{Ccc=0_0_0_017:=}');
Error('\P{Ccc=0_0_0_017:=}');
Expect(1, 1463, '\p{Ccc=+17}', "");
Expect(0, 1463, '\p{^Ccc=+17}', "");
Expect(0, 1463, '\P{Ccc=+17}', "");
Expect(1, 1463, '\P{^Ccc=+17}', "");
Expect(0, 1464, '\p{Ccc=+17}', "");
Expect(1, 1464, '\p{^Ccc=+17}', "");
Expect(1, 1464, '\P{Ccc=+17}', "");
Expect(0, 1464, '\P{^Ccc=+17}', "");
Error('\p{Is_Canonical_Combining_Class=:=-CCC17}');
Error('\P{Is_Canonical_Combining_Class=:=-CCC17}');
Expect(1, 1463, '\p{Is_Canonical_Combining_Class=ccc17}', "");
Expect(0, 1463, '\p{^Is_Canonical_Combining_Class=ccc17}', "");
Expect(0, 1463, '\P{Is_Canonical_Combining_Class=ccc17}', "");
Expect(1, 1463, '\P{^Is_Canonical_Combining_Class=ccc17}', "");
Expect(0, 1464, '\p{Is_Canonical_Combining_Class=ccc17}', "");
Expect(1, 1464, '\p{^Is_Canonical_Combining_Class=ccc17}', "");
Expect(1, 1464, '\P{Is_Canonical_Combining_Class=ccc17}', "");
Expect(0, 1464, '\P{^Is_Canonical_Combining_Class=ccc17}', "");
Expect(1, 1463, '\p{Is_Canonical_Combining_Class=	_CCC17}', "");
Expect(0, 1463, '\p{^Is_Canonical_Combining_Class=	_CCC17}', "");
Expect(0, 1463, '\P{Is_Canonical_Combining_Class=	_CCC17}', "");
Expect(1, 1463, '\P{^Is_Canonical_Combining_Class=	_CCC17}', "");
Expect(0, 1464, '\p{Is_Canonical_Combining_Class=	_CCC17}', "");
Expect(1, 1464, '\p{^Is_Canonical_Combining_Class=	_CCC17}', "");
Expect(1, 1464, '\P{Is_Canonical_Combining_Class=	_CCC17}', "");
Expect(0, 1464, '\P{^Is_Canonical_Combining_Class=	_CCC17}', "");
Error('\p{Is_Ccc=:= 0000001_7}');
Error('\P{Is_Ccc=:= 0000001_7}');
Expect(1, 1463, '\p{Is_Ccc=000017}', "");
Expect(0, 1463, '\p{^Is_Ccc=000017}', "");
Expect(0, 1463, '\P{Is_Ccc=000017}', "");
Expect(1, 1463, '\P{^Is_Ccc=000017}', "");
Expect(0, 1464, '\p{Is_Ccc=000017}', "");
Expect(1, 1464, '\p{^Is_Ccc=000017}', "");
Expect(1, 1464, '\P{Is_Ccc=000017}', "");
Expect(0, 1464, '\P{^Is_Ccc=000017}', "");
Error('\p{Canonical_Combining_Class=/a/_	CCC18}');
Error('\P{Canonical_Combining_Class=/a/_	CCC18}');
Expect(1, 1479, '\p{Canonical_Combining_Class=ccc18}', "");
Expect(0, 1479, '\p{^Canonical_Combining_Class=ccc18}', "");
Expect(0, 1479, '\P{Canonical_Combining_Class=ccc18}', "");
Expect(1, 1479, '\P{^Canonical_Combining_Class=ccc18}', "");
Expect(0, 1480, '\p{Canonical_Combining_Class=ccc18}', "");
Expect(1, 1480, '\p{^Canonical_Combining_Class=ccc18}', "");
Expect(1, 1480, '\P{Canonical_Combining_Class=ccc18}', "");
Expect(0, 1480, '\P{^Canonical_Combining_Class=ccc18}', "");
Expect(1, 1479, '\p{Canonical_Combining_Class=-	CCC18}', "");
Expect(0, 1479, '\p{^Canonical_Combining_Class=-	CCC18}', "");
Expect(0, 1479, '\P{Canonical_Combining_Class=-	CCC18}', "");
Expect(1, 1479, '\P{^Canonical_Combining_Class=-	CCC18}', "");
Expect(0, 1480, '\p{Canonical_Combining_Class=-	CCC18}', "");
Expect(1, 1480, '\p{^Canonical_Combining_Class=-	CCC18}', "");
Expect(1, 1480, '\P{Canonical_Combining_Class=-	CCC18}', "");
Expect(0, 1480, '\P{^Canonical_Combining_Class=-	CCC18}', "");
Error('\p{Ccc=	0018/a/}');
Error('\P{Ccc=	0018/a/}');
Expect(1, 1479, '\p{Ccc=000000018}', "");
Expect(0, 1479, '\p{^Ccc=000000018}', "");
Expect(0, 1479, '\P{Ccc=000000018}', "");
Expect(1, 1479, '\P{^Ccc=000000018}', "");
Expect(0, 1480, '\p{Ccc=000000018}', "");
Expect(1, 1480, '\p{^Ccc=000000018}', "");
Expect(1, 1480, '\P{Ccc=000000018}', "");
Expect(0, 1480, '\P{^Ccc=000000018}', "");
Error('\p{Is_Canonical_Combining_Class=-CCC18:=}');
Error('\P{Is_Canonical_Combining_Class=-CCC18:=}');
Expect(1, 1479, '\p{Is_Canonical_Combining_Class=ccc18}', "");
Expect(0, 1479, '\p{^Is_Canonical_Combining_Class=ccc18}', "");
Expect(0, 1479, '\P{Is_Canonical_Combining_Class=ccc18}', "");
Expect(1, 1479, '\P{^Is_Canonical_Combining_Class=ccc18}', "");
Expect(0, 1480, '\p{Is_Canonical_Combining_Class=ccc18}', "");
Expect(1, 1480, '\p{^Is_Canonical_Combining_Class=ccc18}', "");
Expect(1, 1480, '\P{Is_Canonical_Combining_Class=ccc18}', "");
Expect(0, 1480, '\P{^Is_Canonical_Combining_Class=ccc18}', "");
Expect(1, 1479, '\p{Is_Canonical_Combining_Class=	 ccc18}', "");
Expect(0, 1479, '\p{^Is_Canonical_Combining_Class=	 ccc18}', "");
Expect(0, 1479, '\P{Is_Canonical_Combining_Class=	 ccc18}', "");
Expect(1, 1479, '\P{^Is_Canonical_Combining_Class=	 ccc18}', "");
Expect(0, 1480, '\p{Is_Canonical_Combining_Class=	 ccc18}', "");
Expect(1, 1480, '\p{^Is_Canonical_Combining_Class=	 ccc18}', "");
Expect(1, 1480, '\P{Is_Canonical_Combining_Class=	 ccc18}', "");
Expect(0, 1480, '\P{^Is_Canonical_Combining_Class=	 ccc18}', "");
Error('\p{Is_Ccc=-:=+0000000018}');
Error('\P{Is_Ccc=-:=+0000000018}');
Expect(1, 1479, '\p{Is_Ccc=000000001_8}', "");
Expect(0, 1479, '\p{^Is_Ccc=000000001_8}', "");
Expect(0, 1479, '\P{Is_Ccc=000000001_8}', "");
Expect(1, 1479, '\P{^Is_Ccc=000000001_8}', "");
Expect(0, 1480, '\p{Is_Ccc=000000001_8}', "");
Expect(1, 1480, '\p{^Is_Ccc=000000001_8}', "");
Expect(1, 1480, '\P{Is_Ccc=000000001_8}', "");
Expect(0, 1480, '\P{^Is_Ccc=000000001_8}', "");
Error('\p{Canonical_Combining_Class=_:=CCC19}');
Error('\P{Canonical_Combining_Class=_:=CCC19}');
Expect(1, 1466, '\p{Canonical_Combining_Class=ccc19}', "");
Expect(0, 1466, '\p{^Canonical_Combining_Class=ccc19}', "");
Expect(0, 1466, '\P{Canonical_Combining_Class=ccc19}', "");
Expect(1, 1466, '\P{^Canonical_Combining_Class=ccc19}', "");
Expect(0, 1467, '\p{Canonical_Combining_Class=ccc19}', "");
Expect(1, 1467, '\p{^Canonical_Combining_Class=ccc19}', "");
Expect(1, 1467, '\P{Canonical_Combining_Class=ccc19}', "");
Expect(0, 1467, '\P{^Canonical_Combining_Class=ccc19}', "");
Expect(1, 1466, '\p{Canonical_Combining_Class=_ccc19}', "");
Expect(0, 1466, '\p{^Canonical_Combining_Class=_ccc19}', "");
Expect(0, 1466, '\P{Canonical_Combining_Class=_ccc19}', "");
Expect(1, 1466, '\P{^Canonical_Combining_Class=_ccc19}', "");
Expect(0, 1467, '\p{Canonical_Combining_Class=_ccc19}', "");
Expect(1, 1467, '\p{^Canonical_Combining_Class=_ccc19}', "");
Expect(1, 1467, '\P{Canonical_Combining_Class=_ccc19}', "");
Expect(0, 1467, '\P{^Canonical_Combining_Class=_ccc19}', "");
Error('\p{Ccc=	:=00000019}');
Error('\P{Ccc=	:=00000019}');
Expect(1, 1466, '\p{Ccc=1_9}', "");
Expect(0, 1466, '\p{^Ccc=1_9}', "");
Expect(0, 1466, '\P{Ccc=1_9}', "");
Expect(1, 1466, '\P{^Ccc=1_9}', "");
Expect(0, 1467, '\p{Ccc=1_9}', "");
Expect(1, 1467, '\p{^Ccc=1_9}', "");
Expect(1, 1467, '\P{Ccc=1_9}', "");
Expect(0, 1467, '\P{^Ccc=1_9}', "");
Error('\p{Is_Canonical_Combining_Class=:=	_CCC19}');
Error('\P{Is_Canonical_Combining_Class=:=	_CCC19}');
Expect(1, 1466, '\p{Is_Canonical_Combining_Class=ccc19}', "");
Expect(0, 1466, '\p{^Is_Canonical_Combining_Class=ccc19}', "");
Expect(0, 1466, '\P{Is_Canonical_Combining_Class=ccc19}', "");
Expect(1, 1466, '\P{^Is_Canonical_Combining_Class=ccc19}', "");
Expect(0, 1467, '\p{Is_Canonical_Combining_Class=ccc19}', "");
Expect(1, 1467, '\p{^Is_Canonical_Combining_Class=ccc19}', "");
Expect(1, 1467, '\P{Is_Canonical_Combining_Class=ccc19}', "");
Expect(0, 1467, '\P{^Is_Canonical_Combining_Class=ccc19}', "");
Expect(1, 1466, '\p{Is_Canonical_Combining_Class= _CCC19}', "");
Expect(0, 1466, '\p{^Is_Canonical_Combining_Class= _CCC19}', "");
Expect(0, 1466, '\P{Is_Canonical_Combining_Class= _CCC19}', "");
Expect(1, 1466, '\P{^Is_Canonical_Combining_Class= _CCC19}', "");
Expect(0, 1467, '\p{Is_Canonical_Combining_Class= _CCC19}', "");
Expect(1, 1467, '\p{^Is_Canonical_Combining_Class= _CCC19}', "");
Expect(1, 1467, '\P{Is_Canonical_Combining_Class= _CCC19}', "");
Expect(0, 1467, '\P{^Is_Canonical_Combining_Class= _CCC19}', "");
Error('\p{Is_Ccc= /a/+000000019}');
Error('\P{Is_Ccc= /a/+000000019}');
Expect(1, 1466, '\p{Is_Ccc=19}', "");
Expect(0, 1466, '\p{^Is_Ccc=19}', "");
Expect(0, 1466, '\P{Is_Ccc=19}', "");
Expect(1, 1466, '\P{^Is_Ccc=19}', "");
Expect(0, 1467, '\p{Is_Ccc=19}', "");
Expect(1, 1467, '\p{^Is_Ccc=19}', "");
Expect(1, 1467, '\P{Is_Ccc=19}', "");
Expect(0, 1467, '\P{^Is_Ccc=19}', "");
Error('\p{Canonical_Combining_Class=-	CCC20/a/}');
Error('\P{Canonical_Combining_Class=-	CCC20/a/}');
Expect(1, 1467, '\p{Canonical_Combining_Class=ccc20}', "");
Expect(0, 1467, '\p{^Canonical_Combining_Class=ccc20}', "");
Expect(0, 1467, '\P{Canonical_Combining_Class=ccc20}', "");
Expect(1, 1467, '\P{^Canonical_Combining_Class=ccc20}', "");
Expect(0, 1468, '\p{Canonical_Combining_Class=ccc20}', "");
Expect(1, 1468, '\p{^Canonical_Combining_Class=ccc20}', "");
Expect(1, 1468, '\P{Canonical_Combining_Class=ccc20}', "");
Expect(0, 1468, '\P{^Canonical_Combining_Class=ccc20}', "");
Expect(1, 1467, '\p{Canonical_Combining_Class=	CCC20}', "");
Expect(0, 1467, '\p{^Canonical_Combining_Class=	CCC20}', "");
Expect(0, 1467, '\P{Canonical_Combining_Class=	CCC20}', "");
Expect(1, 1467, '\P{^Canonical_Combining_Class=	CCC20}', "");
Expect(0, 1468, '\p{Canonical_Combining_Class=	CCC20}', "");
Expect(1, 1468, '\p{^Canonical_Combining_Class=	CCC20}', "");
Expect(1, 1468, '\P{Canonical_Combining_Class=	CCC20}', "");
Expect(0, 1468, '\P{^Canonical_Combining_Class=	CCC20}', "");
Error('\p{Ccc=-_0_0_0_0_0_0_00020:=}');
Error('\P{Ccc=-_0_0_0_0_0_0_00020:=}');
Expect(1, 1467, '\p{Ccc=0_0_0_0_0_0_0_0_020}', "");
Expect(0, 1467, '\p{^Ccc=0_0_0_0_0_0_0_0_020}', "");
Expect(0, 1467, '\P{Ccc=0_0_0_0_0_0_0_0_020}', "");
Expect(1, 1467, '\P{^Ccc=0_0_0_0_0_0_0_0_020}', "");
Expect(0, 1468, '\p{Ccc=0_0_0_0_0_0_0_0_020}', "");
Expect(1, 1468, '\p{^Ccc=0_0_0_0_0_0_0_0_020}', "");
Expect(1, 1468, '\P{Ccc=0_0_0_0_0_0_0_0_020}', "");
Expect(0, 1468, '\P{^Ccc=0_0_0_0_0_0_0_0_020}', "");
Error('\p{Is_Canonical_Combining_Class=_/a/CCC20}');
Error('\P{Is_Canonical_Combining_Class=_/a/CCC20}');
Expect(1, 1467, '\p{Is_Canonical_Combining_Class=ccc20}', "");
Expect(0, 1467, '\p{^Is_Canonical_Combining_Class=ccc20}', "");
Expect(0, 1467, '\P{Is_Canonical_Combining_Class=ccc20}', "");
Expect(1, 1467, '\P{^Is_Canonical_Combining_Class=ccc20}', "");
Expect(0, 1468, '\p{Is_Canonical_Combining_Class=ccc20}', "");
Expect(1, 1468, '\p{^Is_Canonical_Combining_Class=ccc20}', "");
Expect(1, 1468, '\P{Is_Canonical_Combining_Class=ccc20}', "");
Expect(0, 1468, '\P{^Is_Canonical_Combining_Class=ccc20}', "");
Expect(1, 1467, '\p{Is_Canonical_Combining_Class=- ccc20}', "");
Expect(0, 1467, '\p{^Is_Canonical_Combining_Class=- ccc20}', "");
Expect(0, 1467, '\P{Is_Canonical_Combining_Class=- ccc20}', "");
Expect(1, 1467, '\P{^Is_Canonical_Combining_Class=- ccc20}', "");
Expect(0, 1468, '\p{Is_Canonical_Combining_Class=- ccc20}', "");
Expect(1, 1468, '\p{^Is_Canonical_Combining_Class=- ccc20}', "");
Expect(1, 1468, '\P{Is_Canonical_Combining_Class=- ccc20}', "");
Expect(0, 1468, '\P{^Is_Canonical_Combining_Class=- ccc20}', "");
Error('\p{Is_Ccc=_000020:=}');
Error('\P{Is_Ccc=_000020:=}');
Expect(1, 1467, '\p{Is_Ccc: 0_0_0_0_020}', "");
Expect(0, 1467, '\p{^Is_Ccc: 0_0_0_0_020}', "");
Expect(0, 1467, '\P{Is_Ccc: 0_0_0_0_020}', "");
Expect(1, 1467, '\P{^Is_Ccc: 0_0_0_0_020}', "");
Expect(0, 1468, '\p{Is_Ccc: 0_0_0_0_020}', "");
Expect(1, 1468, '\p{^Is_Ccc: 0_0_0_0_020}', "");
Expect(1, 1468, '\P{Is_Ccc: 0_0_0_0_020}', "");
Expect(0, 1468, '\P{^Is_Ccc: 0_0_0_0_020}', "");
Error('\p{Canonical_Combining_Class=/a/ _ccc21}');
Error('\P{Canonical_Combining_Class=/a/ _ccc21}');
Expect(1, 1468, '\p{Canonical_Combining_Class=ccc21}', "");
Expect(0, 1468, '\p{^Canonical_Combining_Class=ccc21}', "");
Expect(0, 1468, '\P{Canonical_Combining_Class=ccc21}', "");
Expect(1, 1468, '\P{^Canonical_Combining_Class=ccc21}', "");
Expect(0, 1469, '\p{Canonical_Combining_Class=ccc21}', "");
Expect(1, 1469, '\p{^Canonical_Combining_Class=ccc21}', "");
Expect(1, 1469, '\P{Canonical_Combining_Class=ccc21}', "");
Expect(0, 1469, '\P{^Canonical_Combining_Class=ccc21}', "");
Expect(1, 1468, '\p{Canonical_Combining_Class=-	ccc21}', "");
Expect(0, 1468, '\p{^Canonical_Combining_Class=-	ccc21}', "");
Expect(0, 1468, '\P{Canonical_Combining_Class=-	ccc21}', "");
Expect(1, 1468, '\P{^Canonical_Combining_Class=-	ccc21}', "");
Expect(0, 1469, '\p{Canonical_Combining_Class=-	ccc21}', "");
Expect(1, 1469, '\p{^Canonical_Combining_Class=-	ccc21}', "");
Expect(1, 1469, '\P{Canonical_Combining_Class=-	ccc21}', "");
Expect(0, 1469, '\P{^Canonical_Combining_Class=-	ccc21}', "");
Error('\p{Ccc=	-00000000021/a/}');
Error('\P{Ccc=	-00000000021/a/}');
Expect(1, 1468, '\p{Ccc=+00000021}', "");
Expect(0, 1468, '\p{^Ccc=+00000021}', "");
Expect(0, 1468, '\P{Ccc=+00000021}', "");
Expect(1, 1468, '\P{^Ccc=+00000021}', "");
Expect(0, 1469, '\p{Ccc=+00000021}', "");
Expect(1, 1469, '\p{^Ccc=+00000021}', "");
Expect(1, 1469, '\P{Ccc=+00000021}', "");
Expect(0, 1469, '\P{^Ccc=+00000021}', "");
Error('\p{Is_Canonical_Combining_Class=:=	-CCC21}');
Error('\P{Is_Canonical_Combining_Class=:=	-CCC21}');
Expect(1, 1468, '\p{Is_Canonical_Combining_Class:ccc21}', "");
Expect(0, 1468, '\p{^Is_Canonical_Combining_Class:ccc21}', "");
Expect(0, 1468, '\P{Is_Canonical_Combining_Class:ccc21}', "");
Expect(1, 1468, '\P{^Is_Canonical_Combining_Class:ccc21}', "");
Expect(0, 1469, '\p{Is_Canonical_Combining_Class:ccc21}', "");
Expect(1, 1469, '\p{^Is_Canonical_Combining_Class:ccc21}', "");
Expect(1, 1469, '\P{Is_Canonical_Combining_Class:ccc21}', "");
Expect(0, 1469, '\P{^Is_Canonical_Combining_Class:ccc21}', "");
Expect(1, 1468, '\p{Is_Canonical_Combining_Class=_CCC21}', "");
Expect(0, 1468, '\p{^Is_Canonical_Combining_Class=_CCC21}', "");
Expect(0, 1468, '\P{Is_Canonical_Combining_Class=_CCC21}', "");
Expect(1, 1468, '\P{^Is_Canonical_Combining_Class=_CCC21}', "");
Expect(0, 1469, '\p{Is_Canonical_Combining_Class=_CCC21}', "");
Expect(1, 1469, '\p{^Is_Canonical_Combining_Class=_CCC21}', "");
Expect(1, 1469, '\P{Is_Canonical_Combining_Class=_CCC21}', "");
Expect(0, 1469, '\P{^Is_Canonical_Combining_Class=_CCC21}', "");
Error('\p{Is_Ccc:	:= 000021}');
Error('\P{Is_Ccc:	:= 000021}');
Expect(1, 1468, '\p{Is_Ccc=00000_00002_1}', "");
Expect(0, 1468, '\p{^Is_Ccc=00000_00002_1}', "");
Expect(0, 1468, '\P{Is_Ccc=00000_00002_1}', "");
Expect(1, 1468, '\P{^Is_Ccc=00000_00002_1}', "");
Expect(0, 1469, '\p{Is_Ccc=00000_00002_1}', "");
Expect(1, 1469, '\p{^Is_Ccc=00000_00002_1}', "");
Expect(1, 1469, '\P{Is_Ccc=00000_00002_1}', "");
Expect(0, 1469, '\P{^Is_Ccc=00000_00002_1}', "");
Error('\p{Canonical_Combining_Class=_CCC22/a/}');
Error('\P{Canonical_Combining_Class=_CCC22/a/}');
Expect(1, 1469, '\p{Canonical_Combining_Class=ccc22}', "");
Expect(0, 1469, '\p{^Canonical_Combining_Class=ccc22}', "");
Expect(0, 1469, '\P{Canonical_Combining_Class=ccc22}', "");
Expect(1, 1469, '\P{^Canonical_Combining_Class=ccc22}', "");
Expect(0, 1470, '\p{Canonical_Combining_Class=ccc22}', "");
Expect(1, 1470, '\p{^Canonical_Combining_Class=ccc22}', "");
Expect(1, 1470, '\P{Canonical_Combining_Class=ccc22}', "");
Expect(0, 1470, '\P{^Canonical_Combining_Class=ccc22}', "");
Expect(1, 1469, '\p{Canonical_Combining_Class=_ CCC22}', "");
Expect(0, 1469, '\p{^Canonical_Combining_Class=_ CCC22}', "");
Expect(0, 1469, '\P{Canonical_Combining_Class=_ CCC22}', "");
Expect(1, 1469, '\P{^Canonical_Combining_Class=_ CCC22}', "");
Expect(0, 1470, '\p{Canonical_Combining_Class=_ CCC22}', "");
Expect(1, 1470, '\p{^Canonical_Combining_Class=_ CCC22}', "");
Expect(1, 1470, '\P{Canonical_Combining_Class=_ CCC22}', "");
Expect(0, 1470, '\P{^Canonical_Combining_Class=_ CCC22}', "");
Error('\p{Ccc=/a/000000022}');
Error('\P{Ccc=/a/000000022}');
Expect(1, 1469, '\p{Ccc=0000000022}', "");
Expect(0, 1469, '\p{^Ccc=0000000022}', "");
Expect(0, 1469, '\P{Ccc=0000000022}', "");
Expect(1, 1469, '\P{^Ccc=0000000022}', "");
Expect(0, 1470, '\p{Ccc=0000000022}', "");
Expect(1, 1470, '\p{^Ccc=0000000022}', "");
Expect(1, 1470, '\P{Ccc=0000000022}', "");
Expect(0, 1470, '\P{^Ccc=0000000022}', "");
Error('\p{Is_Canonical_Combining_Class=/a/ccc22}');
Error('\P{Is_Canonical_Combining_Class=/a/ccc22}');
Expect(1, 1469, '\p{Is_Canonical_Combining_Class=ccc22}', "");
Expect(0, 1469, '\p{^Is_Canonical_Combining_Class=ccc22}', "");
Expect(0, 1469, '\P{Is_Canonical_Combining_Class=ccc22}', "");
Expect(1, 1469, '\P{^Is_Canonical_Combining_Class=ccc22}', "");
Expect(0, 1470, '\p{Is_Canonical_Combining_Class=ccc22}', "");
Expect(1, 1470, '\p{^Is_Canonical_Combining_Class=ccc22}', "");
Expect(1, 1470, '\P{Is_Canonical_Combining_Class=ccc22}', "");
Expect(0, 1470, '\P{^Is_Canonical_Combining_Class=ccc22}', "");
Expect(1, 1469, '\p{Is_Canonical_Combining_Class= -CCC22}', "");
Expect(0, 1469, '\p{^Is_Canonical_Combining_Class= -CCC22}', "");
Expect(0, 1469, '\P{Is_Canonical_Combining_Class= -CCC22}', "");
Expect(1, 1469, '\P{^Is_Canonical_Combining_Class= -CCC22}', "");
Expect(0, 1470, '\p{Is_Canonical_Combining_Class= -CCC22}', "");
Expect(1, 1470, '\p{^Is_Canonical_Combining_Class= -CCC22}', "");
Expect(1, 1470, '\P{Is_Canonical_Combining_Class= -CCC22}', "");
Expect(0, 1470, '\P{^Is_Canonical_Combining_Class= -CCC22}', "");
Error('\p{Is_Ccc=	000000022:=}');
Error('\P{Is_Ccc=	000000022:=}');
Expect(1, 1469, '\p{Is_Ccc:+02_2}', "");
Expect(0, 1469, '\p{^Is_Ccc:+02_2}', "");
Expect(0, 1469, '\P{Is_Ccc:+02_2}', "");
Expect(1, 1469, '\P{^Is_Ccc:+02_2}', "");
Expect(0, 1470, '\p{Is_Ccc:+02_2}', "");
Expect(1, 1470, '\p{^Is_Ccc:+02_2}', "");
Expect(1, 1470, '\P{Is_Ccc:+02_2}', "");
Expect(0, 1470, '\P{^Is_Ccc:+02_2}', "");
Error('\p{Canonical_Combining_Class=/a/CCC23}');
Error('\P{Canonical_Combining_Class=/a/CCC23}');
Expect(1, 1471, '\p{Canonical_Combining_Class=ccc23}', "");
Expect(0, 1471, '\p{^Canonical_Combining_Class=ccc23}', "");
Expect(0, 1471, '\P{Canonical_Combining_Class=ccc23}', "");
Expect(1, 1471, '\P{^Canonical_Combining_Class=ccc23}', "");
Expect(0, 1472, '\p{Canonical_Combining_Class=ccc23}', "");
Expect(1, 1472, '\p{^Canonical_Combining_Class=ccc23}', "");
Expect(1, 1472, '\P{Canonical_Combining_Class=ccc23}', "");
Expect(0, 1472, '\P{^Canonical_Combining_Class=ccc23}', "");
Expect(1, 1471, '\p{Canonical_Combining_Class=_ CCC23}', "");
Expect(0, 1471, '\p{^Canonical_Combining_Class=_ CCC23}', "");
Expect(0, 1471, '\P{Canonical_Combining_Class=_ CCC23}', "");
Expect(1, 1471, '\P{^Canonical_Combining_Class=_ CCC23}', "");
Expect(0, 1472, '\p{Canonical_Combining_Class=_ CCC23}', "");
Expect(1, 1472, '\p{^Canonical_Combining_Class=_ CCC23}', "");
Expect(1, 1472, '\P{Canonical_Combining_Class=_ CCC23}', "");
Expect(0, 1472, '\P{^Canonical_Combining_Class=_ CCC23}', "");
Error('\p{Ccc=/a/0_0_23}');
Error('\P{Ccc=/a/0_0_23}');
Expect(1, 1471, '\p{Ccc=0_0_0_23}', "");
Expect(0, 1471, '\p{^Ccc=0_0_0_23}', "");
Expect(0, 1471, '\P{Ccc=0_0_0_23}', "");
Expect(1, 1471, '\P{^Ccc=0_0_0_23}', "");
Expect(0, 1472, '\p{Ccc=0_0_0_23}', "");
Expect(1, 1472, '\p{^Ccc=0_0_0_23}', "");
Expect(1, 1472, '\P{Ccc=0_0_0_23}', "");
Expect(0, 1472, '\P{^Ccc=0_0_0_23}', "");
Error('\p{Is_Canonical_Combining_Class=__CCC23:=}');
Error('\P{Is_Canonical_Combining_Class=__CCC23:=}');
Expect(1, 1471, '\p{Is_Canonical_Combining_Class=ccc23}', "");
Expect(0, 1471, '\p{^Is_Canonical_Combining_Class=ccc23}', "");
Expect(0, 1471, '\P{Is_Canonical_Combining_Class=ccc23}', "");
Expect(1, 1471, '\P{^Is_Canonical_Combining_Class=ccc23}', "");
Expect(0, 1472, '\p{Is_Canonical_Combining_Class=ccc23}', "");
Expect(1, 1472, '\p{^Is_Canonical_Combining_Class=ccc23}', "");
Expect(1, 1472, '\P{Is_Canonical_Combining_Class=ccc23}', "");
Expect(0, 1472, '\P{^Is_Canonical_Combining_Class=ccc23}', "");
Expect(1, 1471, '\p{Is_Canonical_Combining_Class=--CCC23}', "");
Expect(0, 1471, '\p{^Is_Canonical_Combining_Class=--CCC23}', "");
Expect(0, 1471, '\P{Is_Canonical_Combining_Class=--CCC23}', "");
Expect(1, 1471, '\P{^Is_Canonical_Combining_Class=--CCC23}', "");
Expect(0, 1472, '\p{Is_Canonical_Combining_Class=--CCC23}', "");
Expect(1, 1472, '\p{^Is_Canonical_Combining_Class=--CCC23}', "");
Expect(1, 1472, '\P{Is_Canonical_Combining_Class=--CCC23}', "");
Expect(0, 1472, '\P{^Is_Canonical_Combining_Class=--CCC23}', "");
Error('\p{Is_Ccc=:=	_00000023}');
Error('\P{Is_Ccc=:=	_00000023}');
Expect(1, 1471, '\p{Is_Ccc=00023}', "");
Expect(0, 1471, '\p{^Is_Ccc=00023}', "");
Expect(0, 1471, '\P{Is_Ccc=00023}', "");
Expect(1, 1471, '\P{^Is_Ccc=00023}', "");
Expect(0, 1472, '\p{Is_Ccc=00023}', "");
Expect(1, 1472, '\p{^Is_Ccc=00023}', "");
Expect(1, 1472, '\P{Is_Ccc=00023}', "");
Expect(0, 1472, '\P{^Is_Ccc=00023}', "");
Error('\p{Canonical_Combining_Class= /a/CCC24}');
Error('\P{Canonical_Combining_Class= /a/CCC24}');
Expect(1, 1473, '\p{Canonical_Combining_Class=ccc24}', "");
Expect(0, 1473, '\p{^Canonical_Combining_Class=ccc24}', "");
Expect(0, 1473, '\P{Canonical_Combining_Class=ccc24}', "");
Expect(1, 1473, '\P{^Canonical_Combining_Class=ccc24}', "");
Expect(0, 1474, '\p{Canonical_Combining_Class=ccc24}', "");
Expect(1, 1474, '\p{^Canonical_Combining_Class=ccc24}', "");
Expect(1, 1474, '\P{Canonical_Combining_Class=ccc24}', "");
Expect(0, 1474, '\P{^Canonical_Combining_Class=ccc24}', "");
Expect(1, 1473, '\p{Canonical_Combining_Class=_-CCC24}', "");
Expect(0, 1473, '\p{^Canonical_Combining_Class=_-CCC24}', "");
Expect(0, 1473, '\P{Canonical_Combining_Class=_-CCC24}', "");
Expect(1, 1473, '\P{^Canonical_Combining_Class=_-CCC24}', "");
Expect(0, 1474, '\p{Canonical_Combining_Class=_-CCC24}', "");
Expect(1, 1474, '\p{^Canonical_Combining_Class=_-CCC24}', "");
Expect(1, 1474, '\P{Canonical_Combining_Class=_-CCC24}', "");
Expect(0, 1474, '\P{^Canonical_Combining_Class=_-CCC24}', "");
Error('\p{Ccc=_0000002_4/a/}');
Error('\P{Ccc=_0000002_4/a/}');
Expect(1, 1473, '\p{Ccc:   024}', "");
Expect(0, 1473, '\p{^Ccc:   024}', "");
Expect(0, 1473, '\P{Ccc:   024}', "");
Expect(1, 1473, '\P{^Ccc:   024}', "");
Expect(0, 1474, '\p{Ccc:   024}', "");
Expect(1, 1474, '\p{^Ccc:   024}', "");
Expect(1, 1474, '\P{Ccc:   024}', "");
Expect(0, 1474, '\P{^Ccc:   024}', "");
Error('\p{Is_Canonical_Combining_Class= _CCC24/a/}');
Error('\P{Is_Canonical_Combining_Class= _CCC24/a/}');
Expect(1, 1473, '\p{Is_Canonical_Combining_Class=ccc24}', "");
Expect(0, 1473, '\p{^Is_Canonical_Combining_Class=ccc24}', "");
Expect(0, 1473, '\P{Is_Canonical_Combining_Class=ccc24}', "");
Expect(1, 1473, '\P{^Is_Canonical_Combining_Class=ccc24}', "");
Expect(0, 1474, '\p{Is_Canonical_Combining_Class=ccc24}', "");
Expect(1, 1474, '\p{^Is_Canonical_Combining_Class=ccc24}', "");
Expect(1, 1474, '\P{Is_Canonical_Combining_Class=ccc24}', "");
Expect(0, 1474, '\P{^Is_Canonical_Combining_Class=ccc24}', "");
Expect(1, 1473, '\p{Is_Canonical_Combining_Class=-	CCC24}', "");
Expect(0, 1473, '\p{^Is_Canonical_Combining_Class=-	CCC24}', "");
Expect(0, 1473, '\P{Is_Canonical_Combining_Class=-	CCC24}', "");
Expect(1, 1473, '\P{^Is_Canonical_Combining_Class=-	CCC24}', "");
Expect(0, 1474, '\p{Is_Canonical_Combining_Class=-	CCC24}', "");
Expect(1, 1474, '\p{^Is_Canonical_Combining_Class=-	CCC24}', "");
Expect(1, 1474, '\P{Is_Canonical_Combining_Class=-	CCC24}', "");
Expect(0, 1474, '\P{^Is_Canonical_Combining_Class=-	CCC24}', "");
Error('\p{Is_Ccc= /a/0000000024}');
Error('\P{Is_Ccc= /a/0000000024}');
Expect(1, 1473, '\p{Is_Ccc: 000000024}', "");
Expect(0, 1473, '\p{^Is_Ccc: 000000024}', "");
Expect(0, 1473, '\P{Is_Ccc: 000000024}', "");
Expect(1, 1473, '\P{^Is_Ccc: 000000024}', "");
Expect(0, 1474, '\p{Is_Ccc: 000000024}', "");
Expect(1, 1474, '\p{^Is_Ccc: 000000024}', "");
Expect(1, 1474, '\P{Is_Ccc: 000000024}', "");
Expect(0, 1474, '\P{^Is_Ccc: 000000024}', "");
Error('\p{Canonical_Combining_Class=_ CCC25/a/}');
Error('\P{Canonical_Combining_Class=_ CCC25/a/}');
Expect(1, 1474, '\p{Canonical_Combining_Class=ccc25}', "");
Expect(0, 1474, '\p{^Canonical_Combining_Class=ccc25}', "");
Expect(0, 1474, '\P{Canonical_Combining_Class=ccc25}', "");
Expect(1, 1474, '\P{^Canonical_Combining_Class=ccc25}', "");
Expect(0, 1475, '\p{Canonical_Combining_Class=ccc25}', "");
Expect(1, 1475, '\p{^Canonical_Combining_Class=ccc25}', "");
Expect(1, 1475, '\P{Canonical_Combining_Class=ccc25}', "");
Expect(0, 1475, '\P{^Canonical_Combining_Class=ccc25}', "");
Expect(1, 1474, '\p{Canonical_Combining_Class=_-CCC25}', "");
Expect(0, 1474, '\p{^Canonical_Combining_Class=_-CCC25}', "");
Expect(0, 1474, '\P{Canonical_Combining_Class=_-CCC25}', "");
Expect(1, 1474, '\P{^Canonical_Combining_Class=_-CCC25}', "");
Expect(0, 1475, '\p{Canonical_Combining_Class=_-CCC25}', "");
Expect(1, 1475, '\p{^Canonical_Combining_Class=_-CCC25}', "");
Expect(1, 1475, '\P{Canonical_Combining_Class=_-CCC25}', "");
Expect(0, 1475, '\P{^Canonical_Combining_Class=_-CCC25}', "");
Error('\p{Ccc=:=- +0_0_0_0_0_0_0_0_025}');
Error('\P{Ccc=:=- +0_0_0_0_0_0_0_0_025}');
Expect(1, 1474, '\p{Ccc=+000_000_25}', "");
Expect(0, 1474, '\p{^Ccc=+000_000_25}', "");
Expect(0, 1474, '\P{Ccc=+000_000_25}', "");
Expect(1, 1474, '\P{^Ccc=+000_000_25}', "");
Expect(0, 1475, '\p{Ccc=+000_000_25}', "");
Expect(1, 1475, '\p{^Ccc=+000_000_25}', "");
Expect(1, 1475, '\P{Ccc=+000_000_25}', "");
Expect(0, 1475, '\P{^Ccc=+000_000_25}', "");
Error('\p{Is_Canonical_Combining_Class=/a/--CCC25}');
Error('\P{Is_Canonical_Combining_Class=/a/--CCC25}');
Expect(1, 1474, '\p{Is_Canonical_Combining_Class=ccc25}', "");
Expect(0, 1474, '\p{^Is_Canonical_Combining_Class=ccc25}', "");
Expect(0, 1474, '\P{Is_Canonical_Combining_Class=ccc25}', "");
Expect(1, 1474, '\P{^Is_Canonical_Combining_Class=ccc25}', "");
Expect(0, 1475, '\p{Is_Canonical_Combining_Class=ccc25}', "");
Expect(1, 1475, '\p{^Is_Canonical_Combining_Class=ccc25}', "");
Expect(1, 1475, '\P{Is_Canonical_Combining_Class=ccc25}', "");
Expect(0, 1475, '\P{^Is_Canonical_Combining_Class=ccc25}', "");
Expect(1, 1474, '\p{Is_Canonical_Combining_Class=_CCC25}', "");
Expect(0, 1474, '\p{^Is_Canonical_Combining_Class=_CCC25}', "");
Expect(0, 1474, '\P{Is_Canonical_Combining_Class=_CCC25}', "");
Expect(1, 1474, '\P{^Is_Canonical_Combining_Class=_CCC25}', "");
Expect(0, 1475, '\p{Is_Canonical_Combining_Class=_CCC25}', "");
Expect(1, 1475, '\p{^Is_Canonical_Combining_Class=_CCC25}', "");
Expect(1, 1475, '\P{Is_Canonical_Combining_Class=_CCC25}', "");
Expect(0, 1475, '\P{^Is_Canonical_Combining_Class=_CCC25}', "");
Error('\p{Is_Ccc=-+00000002_5:=}');
Error('\P{Is_Ccc=-+00000002_5:=}');
Expect(1, 1474, '\p{Is_Ccc=+025}', "");
Expect(0, 1474, '\p{^Is_Ccc=+025}', "");
Expect(0, 1474, '\P{Is_Ccc=+025}', "");
Expect(1, 1474, '\P{^Is_Ccc=+025}', "");
Expect(0, 1475, '\p{Is_Ccc=+025}', "");
Expect(1, 1475, '\p{^Is_Ccc=+025}', "");
Expect(1, 1475, '\P{Is_Ccc=+025}', "");
Expect(0, 1475, '\P{^Is_Ccc=+025}', "");
Error('\p{Canonical_Combining_Class=-/a/CCC26}');
Error('\P{Canonical_Combining_Class=-/a/CCC26}');
Expect(1, 64286, '\p{Canonical_Combining_Class=ccc26}', "");
Expect(0, 64286, '\p{^Canonical_Combining_Class=ccc26}', "");
Expect(0, 64286, '\P{Canonical_Combining_Class=ccc26}', "");
Expect(1, 64286, '\P{^Canonical_Combining_Class=ccc26}', "");
Expect(0, 64287, '\p{Canonical_Combining_Class=ccc26}', "");
Expect(1, 64287, '\p{^Canonical_Combining_Class=ccc26}', "");
Expect(1, 64287, '\P{Canonical_Combining_Class=ccc26}', "");
Expect(0, 64287, '\P{^Canonical_Combining_Class=ccc26}', "");
Expect(1, 64286, '\p{Canonical_Combining_Class=_	CCC26}', "");
Expect(0, 64286, '\p{^Canonical_Combining_Class=_	CCC26}', "");
Expect(0, 64286, '\P{Canonical_Combining_Class=_	CCC26}', "");
Expect(1, 64286, '\P{^Canonical_Combining_Class=_	CCC26}', "");
Expect(0, 64287, '\p{Canonical_Combining_Class=_	CCC26}', "");
Expect(1, 64287, '\p{^Canonical_Combining_Class=_	CCC26}', "");
Expect(1, 64287, '\P{Canonical_Combining_Class=_	CCC26}', "");
Expect(0, 64287, '\P{^Canonical_Combining_Class=_	CCC26}', "");
Error('\p{Ccc=:= 026}');
Error('\P{Ccc=:= 026}');
Expect(1, 64286, '\p{Ccc=0_0_0_0_0_00026}', "");
Expect(0, 64286, '\p{^Ccc=0_0_0_0_0_00026}', "");
Expect(0, 64286, '\P{Ccc=0_0_0_0_0_00026}', "");
Expect(1, 64286, '\P{^Ccc=0_0_0_0_0_00026}', "");
Expect(0, 64287, '\p{Ccc=0_0_0_0_0_00026}', "");
Expect(1, 64287, '\p{^Ccc=0_0_0_0_0_00026}', "");
Expect(1, 64287, '\P{Ccc=0_0_0_0_0_00026}', "");
Expect(0, 64287, '\P{^Ccc=0_0_0_0_0_00026}', "");
Error('\p{Is_Canonical_Combining_Class=_:=CCC26}');
Error('\P{Is_Canonical_Combining_Class=_:=CCC26}');
Expect(1, 64286, '\p{Is_Canonical_Combining_Class=ccc26}', "");
Expect(0, 64286, '\p{^Is_Canonical_Combining_Class=ccc26}', "");
Expect(0, 64286, '\P{Is_Canonical_Combining_Class=ccc26}', "");
Expect(1, 64286, '\P{^Is_Canonical_Combining_Class=ccc26}', "");
Expect(0, 64287, '\p{Is_Canonical_Combining_Class=ccc26}', "");
Expect(1, 64287, '\p{^Is_Canonical_Combining_Class=ccc26}', "");
Expect(1, 64287, '\P{Is_Canonical_Combining_Class=ccc26}', "");
Expect(0, 64287, '\P{^Is_Canonical_Combining_Class=ccc26}', "");
Expect(1, 64286, '\p{Is_Canonical_Combining_Class=-CCC26}', "");
Expect(0, 64286, '\p{^Is_Canonical_Combining_Class=-CCC26}', "");
Expect(0, 64286, '\P{Is_Canonical_Combining_Class=-CCC26}', "");
Expect(1, 64286, '\P{^Is_Canonical_Combining_Class=-CCC26}', "");
Expect(0, 64287, '\p{Is_Canonical_Combining_Class=-CCC26}', "");
Expect(1, 64287, '\p{^Is_Canonical_Combining_Class=-CCC26}', "");
Expect(1, 64287, '\P{Is_Canonical_Combining_Class=-CCC26}', "");
Expect(0, 64287, '\P{^Is_Canonical_Combining_Class=-CCC26}', "");
Error('\p{Is_Ccc=/a/	-00026}');
Error('\P{Is_Ccc=/a/	-00026}');
Expect(1, 64286, '\p{Is_Ccc=26}', "");
Expect(0, 64286, '\p{^Is_Ccc=26}', "");
Expect(0, 64286, '\P{Is_Ccc=26}', "");
Expect(1, 64286, '\P{^Is_Ccc=26}', "");
Expect(0, 64287, '\p{Is_Ccc=26}', "");
Expect(1, 64287, '\p{^Is_Ccc=26}', "");
Expect(1, 64287, '\P{Is_Ccc=26}', "");
Expect(0, 64287, '\P{^Is_Ccc=26}', "");
Error('\p{Canonical_Combining_Class=/a/	CCC27}');
Error('\P{Canonical_Combining_Class=/a/	CCC27}');
Expect(1, 2288, '\p{Canonical_Combining_Class=ccc27}', "");
Expect(0, 2288, '\p{^Canonical_Combining_Class=ccc27}', "");
Expect(0, 2288, '\P{Canonical_Combining_Class=ccc27}', "");
Expect(1, 2288, '\P{^Canonical_Combining_Class=ccc27}', "");
Expect(0, 2289, '\p{Canonical_Combining_Class=ccc27}', "");
Expect(1, 2289, '\p{^Canonical_Combining_Class=ccc27}', "");
Expect(1, 2289, '\P{Canonical_Combining_Class=ccc27}', "");
Expect(0, 2289, '\P{^Canonical_Combining_Class=ccc27}', "");
Expect(1, 2288, '\p{Canonical_Combining_Class=--CCC27}', "");
Expect(0, 2288, '\p{^Canonical_Combining_Class=--CCC27}', "");
Expect(0, 2288, '\P{Canonical_Combining_Class=--CCC27}', "");
Expect(1, 2288, '\P{^Canonical_Combining_Class=--CCC27}', "");
Expect(0, 2289, '\p{Canonical_Combining_Class=--CCC27}', "");
Expect(1, 2289, '\p{^Canonical_Combining_Class=--CCC27}', "");
Expect(1, 2289, '\P{Canonical_Combining_Class=--CCC27}', "");
Expect(0, 2289, '\P{^Canonical_Combining_Class=--CCC27}', "");
Error('\p{Ccc=:=00000000027}');
Error('\P{Ccc=:=00000000027}');
Expect(1, 2288, '\p{Ccc=+00_00_27}', "");
Expect(0, 2288, '\p{^Ccc=+00_00_27}', "");
Expect(0, 2288, '\P{Ccc=+00_00_27}', "");
Expect(1, 2288, '\P{^Ccc=+00_00_27}', "");
Expect(0, 2289, '\p{Ccc=+00_00_27}', "");
Expect(1, 2289, '\p{^Ccc=+00_00_27}', "");
Expect(1, 2289, '\P{Ccc=+00_00_27}', "");
Expect(0, 2289, '\P{^Ccc=+00_00_27}', "");
Error('\p{Is_Canonical_Combining_Class= _CCC27:=}');
Error('\P{Is_Canonical_Combining_Class= _CCC27:=}');
Expect(1, 2288, '\p{Is_Canonical_Combining_Class=ccc27}', "");
Expect(0, 2288, '\p{^Is_Canonical_Combining_Class=ccc27}', "");
Expect(0, 2288, '\P{Is_Canonical_Combining_Class=ccc27}', "");
Expect(1, 2288, '\P{^Is_Canonical_Combining_Class=ccc27}', "");
Expect(0, 2289, '\p{Is_Canonical_Combining_Class=ccc27}', "");
Expect(1, 2289, '\p{^Is_Canonical_Combining_Class=ccc27}', "");
Expect(1, 2289, '\P{Is_Canonical_Combining_Class=ccc27}', "");
Expect(0, 2289, '\P{^Is_Canonical_Combining_Class=ccc27}', "");
Expect(1, 2288, '\p{Is_Canonical_Combining_Class=	ccc27}', "");
Expect(0, 2288, '\p{^Is_Canonical_Combining_Class=	ccc27}', "");
Expect(0, 2288, '\P{Is_Canonical_Combining_Class=	ccc27}', "");
Expect(1, 2288, '\P{^Is_Canonical_Combining_Class=	ccc27}', "");
Expect(0, 2289, '\p{Is_Canonical_Combining_Class=	ccc27}', "");
Expect(1, 2289, '\p{^Is_Canonical_Combining_Class=	ccc27}', "");
Expect(1, 2289, '\P{Is_Canonical_Combining_Class=	ccc27}', "");
Expect(0, 2289, '\P{^Is_Canonical_Combining_Class=	ccc27}', "");
Error('\p{Is_Ccc=/a/  +00_02_7}');
Error('\P{Is_Ccc=/a/  +00_02_7}');
Expect(1, 2288, '\p{Is_Ccc:0027}', "");
Expect(0, 2288, '\p{^Is_Ccc:0027}', "");
Expect(0, 2288, '\P{Is_Ccc:0027}', "");
Expect(1, 2288, '\P{^Is_Ccc:0027}', "");
Expect(0, 2289, '\p{Is_Ccc:0027}', "");
Expect(1, 2289, '\p{^Is_Ccc:0027}', "");
Expect(1, 2289, '\P{Is_Ccc:0027}', "");
Expect(0, 2289, '\P{^Is_Ccc:0027}', "");
Error('\p{Canonical_Combining_Class=:=__CCC28}');
Error('\P{Canonical_Combining_Class=:=__CCC28}');
Expect(1, 2289, '\p{Canonical_Combining_Class=ccc28}', "");
Expect(0, 2289, '\p{^Canonical_Combining_Class=ccc28}', "");
Expect(0, 2289, '\P{Canonical_Combining_Class=ccc28}', "");
Expect(1, 2289, '\P{^Canonical_Combining_Class=ccc28}', "");
Expect(0, 2290, '\p{Canonical_Combining_Class=ccc28}', "");
Expect(1, 2290, '\p{^Canonical_Combining_Class=ccc28}', "");
Expect(1, 2290, '\P{Canonical_Combining_Class=ccc28}', "");
Expect(0, 2290, '\P{^Canonical_Combining_Class=ccc28}', "");
Expect(1, 2289, '\p{Canonical_Combining_Class=_CCC28}', "");
Expect(0, 2289, '\p{^Canonical_Combining_Class=_CCC28}', "");
Expect(0, 2289, '\P{Canonical_Combining_Class=_CCC28}', "");
Expect(1, 2289, '\P{^Canonical_Combining_Class=_CCC28}', "");
Expect(0, 2290, '\p{Canonical_Combining_Class=_CCC28}', "");
Expect(1, 2290, '\p{^Canonical_Combining_Class=_CCC28}', "");
Expect(1, 2290, '\P{Canonical_Combining_Class=_CCC28}', "");
Expect(0, 2290, '\P{^Canonical_Combining_Class=_CCC28}', "");
Error('\p{Ccc: __0028:=}');
Error('\P{Ccc: __0028:=}');
Expect(1, 2289, '\p{Ccc=028}', "");
Expect(0, 2289, '\p{^Ccc=028}', "");
Expect(0, 2289, '\P{Ccc=028}', "");
Expect(1, 2289, '\P{^Ccc=028}', "");
Expect(0, 2290, '\p{Ccc=028}', "");
Expect(1, 2290, '\p{^Ccc=028}', "");
Expect(1, 2290, '\P{Ccc=028}', "");
Expect(0, 2290, '\P{^Ccc=028}', "");
Error('\p{Is_Canonical_Combining_Class=/a/ CCC28}');
Error('\P{Is_Canonical_Combining_Class=/a/ CCC28}');
Expect(1, 2289, '\p{Is_Canonical_Combining_Class=ccc28}', "");
Expect(0, 2289, '\p{^Is_Canonical_Combining_Class=ccc28}', "");
Expect(0, 2289, '\P{Is_Canonical_Combining_Class=ccc28}', "");
Expect(1, 2289, '\P{^Is_Canonical_Combining_Class=ccc28}', "");
Expect(0, 2290, '\p{Is_Canonical_Combining_Class=ccc28}', "");
Expect(1, 2290, '\p{^Is_Canonical_Combining_Class=ccc28}', "");
Expect(1, 2290, '\P{Is_Canonical_Combining_Class=ccc28}', "");
Expect(0, 2290, '\P{^Is_Canonical_Combining_Class=ccc28}', "");
Expect(1, 2289, '\p{Is_Canonical_Combining_Class=--CCC28}', "");
Expect(0, 2289, '\p{^Is_Canonical_Combining_Class=--CCC28}', "");
Expect(0, 2289, '\P{Is_Canonical_Combining_Class=--CCC28}', "");
Expect(1, 2289, '\P{^Is_Canonical_Combining_Class=--CCC28}', "");
Expect(0, 2290, '\p{Is_Canonical_Combining_Class=--CCC28}', "");
Expect(1, 2290, '\p{^Is_Canonical_Combining_Class=--CCC28}', "");
Expect(1, 2290, '\P{Is_Canonical_Combining_Class=--CCC28}', "");
Expect(0, 2290, '\P{^Is_Canonical_Combining_Class=--CCC28}', "");
Error('\p{Is_Ccc=/a/_+000028}');
Error('\P{Is_Ccc=/a/_+000028}');
Expect(1, 2289, '\p{Is_Ccc=0000000028}', "");
Expect(0, 2289, '\p{^Is_Ccc=0000000028}', "");
Expect(0, 2289, '\P{Is_Ccc=0000000028}', "");
Expect(1, 2289, '\P{^Is_Ccc=0000000028}', "");
Expect(0, 2290, '\p{Is_Ccc=0000000028}', "");
Expect(1, 2290, '\p{^Is_Ccc=0000000028}', "");
Expect(1, 2290, '\P{Is_Ccc=0000000028}', "");
Expect(0, 2290, '\P{^Is_Ccc=0000000028}', "");
Error('\p{Canonical_Combining_Class=	CCC29/a/}');
Error('\P{Canonical_Combining_Class=	CCC29/a/}');
Expect(1, 2290, '\p{Canonical_Combining_Class=ccc29}', "");
Expect(0, 2290, '\p{^Canonical_Combining_Class=ccc29}', "");
Expect(0, 2290, '\P{Canonical_Combining_Class=ccc29}', "");
Expect(1, 2290, '\P{^Canonical_Combining_Class=ccc29}', "");
Expect(0, 2291, '\p{Canonical_Combining_Class=ccc29}', "");
Expect(1, 2291, '\p{^Canonical_Combining_Class=ccc29}', "");
Expect(1, 2291, '\P{Canonical_Combining_Class=ccc29}', "");
Expect(0, 2291, '\P{^Canonical_Combining_Class=ccc29}', "");
Expect(1, 2290, '\p{Canonical_Combining_Class=	ccc29}', "");
Expect(0, 2290, '\p{^Canonical_Combining_Class=	ccc29}', "");
Expect(0, 2290, '\P{Canonical_Combining_Class=	ccc29}', "");
Expect(1, 2290, '\P{^Canonical_Combining_Class=	ccc29}', "");
Expect(0, 2291, '\p{Canonical_Combining_Class=	ccc29}', "");
Expect(1, 2291, '\p{^Canonical_Combining_Class=	ccc29}', "");
Expect(1, 2291, '\P{Canonical_Combining_Class=	ccc29}', "");
Expect(0, 2291, '\P{^Canonical_Combining_Class=	ccc29}', "");
Error('\p{Ccc=--29:=}');
Error('\P{Ccc=--29:=}');
Expect(1, 2290, '\p{Ccc=0029}', "");
Expect(0, 2290, '\p{^Ccc=0029}', "");
Expect(0, 2290, '\P{Ccc=0029}', "");
Expect(1, 2290, '\P{^Ccc=0029}', "");
Expect(0, 2291, '\p{Ccc=0029}', "");
Expect(1, 2291, '\p{^Ccc=0029}', "");
Expect(1, 2291, '\P{Ccc=0029}', "");
Expect(0, 2291, '\P{^Ccc=0029}', "");
Error('\p{Is_Canonical_Combining_Class:	 	ccc29:=}');
Error('\P{Is_Canonical_Combining_Class:	 	ccc29:=}');
Expect(1, 2290, '\p{Is_Canonical_Combining_Class:	ccc29}', "");
Expect(0, 2290, '\p{^Is_Canonical_Combining_Class:	ccc29}', "");
Expect(0, 2290, '\P{Is_Canonical_Combining_Class:	ccc29}', "");
Expect(1, 2290, '\P{^Is_Canonical_Combining_Class:	ccc29}', "");
Expect(0, 2291, '\p{Is_Canonical_Combining_Class:	ccc29}', "");
Expect(1, 2291, '\p{^Is_Canonical_Combining_Class:	ccc29}', "");
Expect(1, 2291, '\P{Is_Canonical_Combining_Class:	ccc29}', "");
Expect(0, 2291, '\P{^Is_Canonical_Combining_Class:	ccc29}', "");
Expect(1, 2290, '\p{Is_Canonical_Combining_Class= _CCC29}', "");
Expect(0, 2290, '\p{^Is_Canonical_Combining_Class= _CCC29}', "");
Expect(0, 2290, '\P{Is_Canonical_Combining_Class= _CCC29}', "");
Expect(1, 2290, '\P{^Is_Canonical_Combining_Class= _CCC29}', "");
Expect(0, 2291, '\p{Is_Canonical_Combining_Class= _CCC29}', "");
Expect(1, 2291, '\p{^Is_Canonical_Combining_Class= _CCC29}', "");
Expect(1, 2291, '\P{Is_Canonical_Combining_Class= _CCC29}', "");
Expect(0, 2291, '\P{^Is_Canonical_Combining_Class= _CCC29}', "");
Error('\p{Is_Ccc=__+000000029:=}');
Error('\P{Is_Ccc=__+000000029:=}');
Expect(1, 2290, '\p{Is_Ccc=000002_9}', "");
Expect(0, 2290, '\p{^Is_Ccc=000002_9}', "");
Expect(0, 2290, '\P{Is_Ccc=000002_9}', "");
Expect(1, 2290, '\P{^Is_Ccc=000002_9}', "");
Expect(0, 2291, '\p{Is_Ccc=000002_9}', "");
Expect(1, 2291, '\p{^Is_Ccc=000002_9}', "");
Expect(1, 2291, '\P{Is_Ccc=000002_9}', "");
Expect(0, 2291, '\P{^Is_Ccc=000002_9}', "");
Error('\p{Canonical_Combining_Class=-CCC30/a/}');
Error('\P{Canonical_Combining_Class=-CCC30/a/}');
Expect(1, 1614, '\p{Canonical_Combining_Class:   ccc30}', "");
Expect(0, 1614, '\p{^Canonical_Combining_Class:   ccc30}', "");
Expect(0, 1614, '\P{Canonical_Combining_Class:   ccc30}', "");
Expect(1, 1614, '\P{^Canonical_Combining_Class:   ccc30}', "");
Expect(0, 1615, '\p{Canonical_Combining_Class:   ccc30}', "");
Expect(1, 1615, '\p{^Canonical_Combining_Class:   ccc30}', "");
Expect(1, 1615, '\P{Canonical_Combining_Class:   ccc30}', "");
Expect(0, 1615, '\P{^Canonical_Combining_Class:   ccc30}', "");
Expect(1, 1614, '\p{Canonical_Combining_Class= -CCC30}', "");
Expect(0, 1614, '\p{^Canonical_Combining_Class= -CCC30}', "");
Expect(0, 1614, '\P{Canonical_Combining_Class= -CCC30}', "");
Expect(1, 1614, '\P{^Canonical_Combining_Class= -CCC30}', "");
Expect(0, 1615, '\p{Canonical_Combining_Class= -CCC30}', "");
Expect(1, 1615, '\p{^Canonical_Combining_Class= -CCC30}', "");
Expect(1, 1615, '\P{Canonical_Combining_Class= -CCC30}', "");
Expect(0, 1615, '\P{^Canonical_Combining_Class= -CCC30}', "");
Error('\p{Ccc= 	+030/a/}');
Error('\P{Ccc= 	+030/a/}');
Expect(1, 1614, '\p{Ccc=+030}', "");
Expect(0, 1614, '\p{^Ccc=+030}', "");
Expect(0, 1614, '\P{Ccc=+030}', "");
Expect(1, 1614, '\P{^Ccc=+030}', "");
Expect(0, 1615, '\p{Ccc=+030}', "");
Expect(1, 1615, '\p{^Ccc=+030}', "");
Expect(1, 1615, '\P{Ccc=+030}', "");
Expect(0, 1615, '\P{^Ccc=+030}', "");
Error('\p{Is_Canonical_Combining_Class=/a/ CCC30}');
Error('\P{Is_Canonical_Combining_Class=/a/ CCC30}');
Expect(1, 1614, '\p{Is_Canonical_Combining_Class=ccc30}', "");
Expect(0, 1614, '\p{^Is_Canonical_Combining_Class=ccc30}', "");
Expect(0, 1614, '\P{Is_Canonical_Combining_Class=ccc30}', "");
Expect(1, 1614, '\P{^Is_Canonical_Combining_Class=ccc30}', "");
Expect(0, 1615, '\p{Is_Canonical_Combining_Class=ccc30}', "");
Expect(1, 1615, '\p{^Is_Canonical_Combining_Class=ccc30}', "");
Expect(1, 1615, '\P{Is_Canonical_Combining_Class=ccc30}', "");
Expect(0, 1615, '\P{^Is_Canonical_Combining_Class=ccc30}', "");
Expect(1, 1614, '\p{Is_Canonical_Combining_Class=  CCC30}', "");
Expect(0, 1614, '\p{^Is_Canonical_Combining_Class=  CCC30}', "");
Expect(0, 1614, '\P{Is_Canonical_Combining_Class=  CCC30}', "");
Expect(1, 1614, '\P{^Is_Canonical_Combining_Class=  CCC30}', "");
Expect(0, 1615, '\p{Is_Canonical_Combining_Class=  CCC30}', "");
Expect(1, 1615, '\p{^Is_Canonical_Combining_Class=  CCC30}', "");
Expect(1, 1615, '\P{Is_Canonical_Combining_Class=  CCC30}', "");
Expect(0, 1615, '\P{^Is_Canonical_Combining_Class=  CCC30}', "");
Error('\p{Is_Ccc=--0000000030:=}');
Error('\P{Is_Ccc=--0000000030:=}');
Expect(1, 1614, '\p{Is_Ccc=00000000030}', "");
Expect(0, 1614, '\p{^Is_Ccc=00000000030}', "");
Expect(0, 1614, '\P{Is_Ccc=00000000030}', "");
Expect(1, 1614, '\P{^Is_Ccc=00000000030}', "");
Expect(0, 1615, '\p{Is_Ccc=00000000030}', "");
Expect(1, 1615, '\p{^Is_Ccc=00000000030}', "");
Expect(1, 1615, '\P{Is_Ccc=00000000030}', "");
Expect(0, 1615, '\P{^Is_Ccc=00000000030}', "");
Error('\p{Canonical_Combining_Class=_:=CCC31}');
Error('\P{Canonical_Combining_Class=_:=CCC31}');
Expect(1, 1615, '\p{Canonical_Combining_Class=ccc31}', "");
Expect(0, 1615, '\p{^Canonical_Combining_Class=ccc31}', "");
Expect(0, 1615, '\P{Canonical_Combining_Class=ccc31}', "");
Expect(1, 1615, '\P{^Canonical_Combining_Class=ccc31}', "");
Expect(0, 1616, '\p{Canonical_Combining_Class=ccc31}', "");
Expect(1, 1616, '\p{^Canonical_Combining_Class=ccc31}', "");
Expect(1, 1616, '\P{Canonical_Combining_Class=ccc31}', "");
Expect(0, 1616, '\P{^Canonical_Combining_Class=ccc31}', "");
Expect(1, 1615, '\p{Canonical_Combining_Class= 	CCC31}', "");
Expect(0, 1615, '\p{^Canonical_Combining_Class= 	CCC31}', "");
Expect(0, 1615, '\P{Canonical_Combining_Class= 	CCC31}', "");
Expect(1, 1615, '\P{^Canonical_Combining_Class= 	CCC31}', "");
Expect(0, 1616, '\p{Canonical_Combining_Class= 	CCC31}', "");
Expect(1, 1616, '\p{^Canonical_Combining_Class= 	CCC31}', "");
Expect(1, 1616, '\P{Canonical_Combining_Class= 	CCC31}', "");
Expect(0, 1616, '\P{^Canonical_Combining_Class= 	CCC31}', "");
Error('\p{Ccc=  0_0_0_0_0_0_0031/a/}');
Error('\P{Ccc=  0_0_0_0_0_0_0031/a/}');
Expect(1, 1615, '\p{Ccc=000031}', "");
Expect(0, 1615, '\p{^Ccc=000031}', "");
Expect(0, 1615, '\P{Ccc=000031}', "");
Expect(1, 1615, '\P{^Ccc=000031}', "");
Expect(0, 1616, '\p{Ccc=000031}', "");
Expect(1, 1616, '\p{^Ccc=000031}', "");
Expect(1, 1616, '\P{Ccc=000031}', "");
Expect(0, 1616, '\P{^Ccc=000031}', "");
Error('\p{Is_Canonical_Combining_Class=:=CCC31}');
Error('\P{Is_Canonical_Combining_Class=:=CCC31}');
Expect(1, 1615, '\p{Is_Canonical_Combining_Class=ccc31}', "");
Expect(0, 1615, '\p{^Is_Canonical_Combining_Class=ccc31}', "");
Expect(0, 1615, '\P{Is_Canonical_Combining_Class=ccc31}', "");
Expect(1, 1615, '\P{^Is_Canonical_Combining_Class=ccc31}', "");
Expect(0, 1616, '\p{Is_Canonical_Combining_Class=ccc31}', "");
Expect(1, 1616, '\p{^Is_Canonical_Combining_Class=ccc31}', "");
Expect(1, 1616, '\P{Is_Canonical_Combining_Class=ccc31}', "");
Expect(0, 1616, '\P{^Is_Canonical_Combining_Class=ccc31}', "");
Expect(1, 1615, '\p{Is_Canonical_Combining_Class= 	CCC31}', "");
Expect(0, 1615, '\p{^Is_Canonical_Combining_Class= 	CCC31}', "");
Expect(0, 1615, '\P{Is_Canonical_Combining_Class= 	CCC31}', "");
Expect(1, 1615, '\P{^Is_Canonical_Combining_Class= 	CCC31}', "");
Expect(0, 1616, '\p{Is_Canonical_Combining_Class= 	CCC31}', "");
Expect(1, 1616, '\p{^Is_Canonical_Combining_Class= 	CCC31}', "");
Expect(1, 1616, '\P{Is_Canonical_Combining_Class= 	CCC31}', "");
Expect(0, 1616, '\P{^Is_Canonical_Combining_Class= 	CCC31}', "");
Error('\p{Is_Ccc=	:=0000000031}');
Error('\P{Is_Ccc=	:=0000000031}');
Expect(1, 1615, '\p{Is_Ccc=3_1}', "");
Expect(0, 1615, '\p{^Is_Ccc=3_1}', "");
Expect(0, 1615, '\P{Is_Ccc=3_1}', "");
Expect(1, 1615, '\P{^Is_Ccc=3_1}', "");
Expect(0, 1616, '\p{Is_Ccc=3_1}', "");
Expect(1, 1616, '\p{^Is_Ccc=3_1}', "");
Expect(1, 1616, '\P{Is_Ccc=3_1}', "");
Expect(0, 1616, '\P{^Is_Ccc=3_1}', "");
Error('\p{Canonical_Combining_Class=/a/		CCC32}');
Error('\P{Canonical_Combining_Class=/a/		CCC32}');
Expect(1, 1616, '\p{Canonical_Combining_Class=ccc32}', "");
Expect(0, 1616, '\p{^Canonical_Combining_Class=ccc32}', "");
Expect(0, 1616, '\P{Canonical_Combining_Class=ccc32}', "");
Expect(1, 1616, '\P{^Canonical_Combining_Class=ccc32}', "");
Expect(0, 1617, '\p{Canonical_Combining_Class=ccc32}', "");
Expect(1, 1617, '\p{^Canonical_Combining_Class=ccc32}', "");
Expect(1, 1617, '\P{Canonical_Combining_Class=ccc32}', "");
Expect(0, 1617, '\P{^Canonical_Combining_Class=ccc32}', "");
Expect(1, 1616, '\p{Canonical_Combining_Class=CCC32}', "");
Expect(0, 1616, '\p{^Canonical_Combining_Class=CCC32}', "");
Expect(0, 1616, '\P{Canonical_Combining_Class=CCC32}', "");
Expect(1, 1616, '\P{^Canonical_Combining_Class=CCC32}', "");
Expect(0, 1617, '\p{Canonical_Combining_Class=CCC32}', "");
Expect(1, 1617, '\p{^Canonical_Combining_Class=CCC32}', "");
Expect(1, 1617, '\P{Canonical_Combining_Class=CCC32}', "");
Expect(0, 1617, '\P{^Canonical_Combining_Class=CCC32}', "");
Error('\p{Ccc= :=32}');
Error('\P{Ccc= :=32}');
Expect(1, 1616, '\p{Ccc=003_2}', "");
Expect(0, 1616, '\p{^Ccc=003_2}', "");
Expect(0, 1616, '\P{Ccc=003_2}', "");
Expect(1, 1616, '\P{^Ccc=003_2}', "");
Expect(0, 1617, '\p{Ccc=003_2}', "");
Expect(1, 1617, '\p{^Ccc=003_2}', "");
Expect(1, 1617, '\P{Ccc=003_2}', "");
Expect(0, 1617, '\P{^Ccc=003_2}', "");
Error('\p{Is_Canonical_Combining_Class=:=CCC32}');
Error('\P{Is_Canonical_Combining_Class=:=CCC32}');
Expect(1, 1616, '\p{Is_Canonical_Combining_Class=ccc32}', "");
Expect(0, 1616, '\p{^Is_Canonical_Combining_Class=ccc32}', "");
Expect(0, 1616, '\P{Is_Canonical_Combining_Class=ccc32}', "");
Expect(1, 1616, '\P{^Is_Canonical_Combining_Class=ccc32}', "");
Expect(0, 1617, '\p{Is_Canonical_Combining_Class=ccc32}', "");
Expect(1, 1617, '\p{^Is_Canonical_Combining_Class=ccc32}', "");
Expect(1, 1617, '\P{Is_Canonical_Combining_Class=ccc32}', "");
Expect(0, 1617, '\P{^Is_Canonical_Combining_Class=ccc32}', "");
Expect(1, 1616, '\p{Is_Canonical_Combining_Class= CCC32}', "");
Expect(0, 1616, '\p{^Is_Canonical_Combining_Class= CCC32}', "");
Expect(0, 1616, '\P{Is_Canonical_Combining_Class= CCC32}', "");
Expect(1, 1616, '\P{^Is_Canonical_Combining_Class= CCC32}', "");
Expect(0, 1617, '\p{Is_Canonical_Combining_Class= CCC32}', "");
Expect(1, 1617, '\p{^Is_Canonical_Combining_Class= CCC32}', "");
Expect(1, 1617, '\P{Is_Canonical_Combining_Class= CCC32}', "");
Expect(0, 1617, '\P{^Is_Canonical_Combining_Class= CCC32}', "");
Error('\p{Is_Ccc=-/a/0003_2}');
Error('\P{Is_Ccc=-/a/0003_2}');
Expect(1, 1616, '\p{Is_Ccc=+00_00_00_00_032}', "");
Expect(0, 1616, '\p{^Is_Ccc=+00_00_00_00_032}', "");
Expect(0, 1616, '\P{Is_Ccc=+00_00_00_00_032}', "");
Expect(1, 1616, '\P{^Is_Ccc=+00_00_00_00_032}', "");
Expect(0, 1617, '\p{Is_Ccc=+00_00_00_00_032}', "");
Expect(1, 1617, '\p{^Is_Ccc=+00_00_00_00_032}', "");
Expect(1, 1617, '\P{Is_Ccc=+00_00_00_00_032}', "");
Expect(0, 1617, '\P{^Is_Ccc=+00_00_00_00_032}', "");
Error('\p{Canonical_Combining_Class=-/a/CCC33}');
Error('\P{Canonical_Combining_Class=-/a/CCC33}');
Expect(1, 1617, '\p{Canonical_Combining_Class:ccc33}', "");
Expect(0, 1617, '\p{^Canonical_Combining_Class:ccc33}', "");
Expect(0, 1617, '\P{Canonical_Combining_Class:ccc33}', "");
Expect(1, 1617, '\P{^Canonical_Combining_Class:ccc33}', "");
Expect(0, 1618, '\p{Canonical_Combining_Class:ccc33}', "");
Expect(1, 1618, '\p{^Canonical_Combining_Class:ccc33}', "");
Expect(1, 1618, '\P{Canonical_Combining_Class:ccc33}', "");
Expect(0, 1618, '\P{^Canonical_Combining_Class:ccc33}', "");
Expect(1, 1617, '\p{Canonical_Combining_Class=-_CCC33}', "");
Expect(0, 1617, '\p{^Canonical_Combining_Class=-_CCC33}', "");
Expect(0, 1617, '\P{Canonical_Combining_Class=-_CCC33}', "");
Expect(1, 1617, '\P{^Canonical_Combining_Class=-_CCC33}', "");
Expect(0, 1618, '\p{Canonical_Combining_Class=-_CCC33}', "");
Expect(1, 1618, '\p{^Canonical_Combining_Class=-_CCC33}', "");
Expect(1, 1618, '\P{Canonical_Combining_Class=-_CCC33}', "");
Expect(0, 1618, '\P{^Canonical_Combining_Class=-_CCC33}', "");
Error('\p{Ccc=:=_00000000033}');
Error('\P{Ccc=:=_00000000033}');
Expect(1, 1617, '\p{Ccc=000000033}', "");
Expect(0, 1617, '\p{^Ccc=000000033}', "");
Expect(0, 1617, '\P{Ccc=000000033}', "");
Expect(1, 1617, '\P{^Ccc=000000033}', "");
Expect(0, 1618, '\p{Ccc=000000033}', "");
Expect(1, 1618, '\p{^Ccc=000000033}', "");
Expect(1, 1618, '\P{Ccc=000000033}', "");
Expect(0, 1618, '\P{^Ccc=000000033}', "");
Error('\p{Is_Canonical_Combining_Class=-CCC33:=}');
Error('\P{Is_Canonical_Combining_Class=-CCC33:=}');
Expect(1, 1617, '\p{Is_Canonical_Combining_Class=ccc33}', "");
Expect(0, 1617, '\p{^Is_Canonical_Combining_Class=ccc33}', "");
Expect(0, 1617, '\P{Is_Canonical_Combining_Class=ccc33}', "");
Expect(1, 1617, '\P{^Is_Canonical_Combining_Class=ccc33}', "");
Expect(0, 1618, '\p{Is_Canonical_Combining_Class=ccc33}', "");
Expect(1, 1618, '\p{^Is_Canonical_Combining_Class=ccc33}', "");
Expect(1, 1618, '\P{Is_Canonical_Combining_Class=ccc33}', "");
Expect(0, 1618, '\P{^Is_Canonical_Combining_Class=ccc33}', "");
Expect(1, 1617, '\p{Is_Canonical_Combining_Class:    CCC33}', "");
Expect(0, 1617, '\p{^Is_Canonical_Combining_Class:    CCC33}', "");
Expect(0, 1617, '\P{Is_Canonical_Combining_Class:    CCC33}', "");
Expect(1, 1617, '\P{^Is_Canonical_Combining_Class:    CCC33}', "");
Expect(0, 1618, '\p{Is_Canonical_Combining_Class:    CCC33}', "");
Expect(1, 1618, '\p{^Is_Canonical_Combining_Class:    CCC33}', "");
Expect(1, 1618, '\P{Is_Canonical_Combining_Class:    CCC33}', "");
Expect(0, 1618, '\P{^Is_Canonical_Combining_Class:    CCC33}', "");
Error('\p{Is_Ccc=:=3_3}');
Error('\P{Is_Ccc=:=3_3}');
Expect(1, 1617, '\p{Is_Ccc: +0_0_0_0_033}', "");
Expect(0, 1617, '\p{^Is_Ccc: +0_0_0_0_033}', "");
Expect(0, 1617, '\P{Is_Ccc: +0_0_0_0_033}', "");
Expect(1, 1617, '\P{^Is_Ccc: +0_0_0_0_033}', "");
Expect(0, 1618, '\p{Is_Ccc: +0_0_0_0_033}', "");
Expect(1, 1618, '\p{^Is_Ccc: +0_0_0_0_033}', "");
Expect(1, 1618, '\P{Is_Ccc: +0_0_0_0_033}', "");
Expect(0, 1618, '\P{^Is_Ccc: +0_0_0_0_033}', "");
Error('\p{Canonical_Combining_Class=/a/-CCC34}');
Error('\P{Canonical_Combining_Class=/a/-CCC34}');
Expect(1, 1618, '\p{Canonical_Combining_Class=ccc34}', "");
Expect(0, 1618, '\p{^Canonical_Combining_Class=ccc34}', "");
Expect(0, 1618, '\P{Canonical_Combining_Class=ccc34}', "");
Expect(1, 1618, '\P{^Canonical_Combining_Class=ccc34}', "");
Expect(0, 1619, '\p{Canonical_Combining_Class=ccc34}', "");
Expect(1, 1619, '\p{^Canonical_Combining_Class=ccc34}', "");
Expect(1, 1619, '\P{Canonical_Combining_Class=ccc34}', "");
Expect(0, 1619, '\P{^Canonical_Combining_Class=ccc34}', "");
Expect(1, 1618, '\p{Canonical_Combining_Class=	CCC34}', "");
Expect(0, 1618, '\p{^Canonical_Combining_Class=	CCC34}', "");
Expect(0, 1618, '\P{Canonical_Combining_Class=	CCC34}', "");
Expect(1, 1618, '\P{^Canonical_Combining_Class=	CCC34}', "");
Expect(0, 1619, '\p{Canonical_Combining_Class=	CCC34}', "");
Expect(1, 1619, '\p{^Canonical_Combining_Class=	CCC34}', "");
Expect(1, 1619, '\P{Canonical_Combining_Class=	CCC34}', "");
Expect(0, 1619, '\P{^Canonical_Combining_Class=	CCC34}', "");
Error('\p{Ccc:   /a/__0000000034}');
Error('\P{Ccc:   /a/__0000000034}');
Expect(1, 1618, '\p{Ccc=34}', "");
Expect(0, 1618, '\p{^Ccc=34}', "");
Expect(0, 1618, '\P{Ccc=34}', "");
Expect(1, 1618, '\P{^Ccc=34}', "");
Expect(0, 1619, '\p{Ccc=34}', "");
Expect(1, 1619, '\p{^Ccc=34}', "");
Expect(1, 1619, '\P{Ccc=34}', "");
Expect(0, 1619, '\P{^Ccc=34}', "");
Error('\p{Is_Canonical_Combining_Class= :=ccc34}');
Error('\P{Is_Canonical_Combining_Class= :=ccc34}');
Expect(1, 1618, '\p{Is_Canonical_Combining_Class=ccc34}', "");
Expect(0, 1618, '\p{^Is_Canonical_Combining_Class=ccc34}', "");
Expect(0, 1618, '\P{Is_Canonical_Combining_Class=ccc34}', "");
Expect(1, 1618, '\P{^Is_Canonical_Combining_Class=ccc34}', "");
Expect(0, 1619, '\p{Is_Canonical_Combining_Class=ccc34}', "");
Expect(1, 1619, '\p{^Is_Canonical_Combining_Class=ccc34}', "");
Expect(1, 1619, '\P{Is_Canonical_Combining_Class=ccc34}', "");
Expect(0, 1619, '\P{^Is_Canonical_Combining_Class=ccc34}', "");
Expect(1, 1618, '\p{Is_Canonical_Combining_Class:	-CCC34}', "");
Expect(0, 1618, '\p{^Is_Canonical_Combining_Class:	-CCC34}', "");
Expect(0, 1618, '\P{Is_Canonical_Combining_Class:	-CCC34}', "");
Expect(1, 1618, '\P{^Is_Canonical_Combining_Class:	-CCC34}', "");
Expect(0, 1619, '\p{Is_Canonical_Combining_Class:	-CCC34}', "");
Expect(1, 1619, '\p{^Is_Canonical_Combining_Class:	-CCC34}', "");
Expect(1, 1619, '\P{Is_Canonical_Combining_Class:	-CCC34}', "");
Expect(0, 1619, '\P{^Is_Canonical_Combining_Class:	-CCC34}', "");
Error('\p{Is_Ccc:		_00003_4:=}');
Error('\P{Is_Ccc:		_00003_4:=}');
Expect(1, 1618, '\p{Is_Ccc=3_4}', "");
Expect(0, 1618, '\p{^Is_Ccc=3_4}', "");
Expect(0, 1618, '\P{Is_Ccc=3_4}', "");
Expect(1, 1618, '\P{^Is_Ccc=3_4}', "");
Expect(0, 1619, '\p{Is_Ccc=3_4}', "");
Expect(1, 1619, '\p{^Is_Ccc=3_4}', "");
Expect(1, 1619, '\P{Is_Ccc=3_4}', "");
Expect(0, 1619, '\P{^Is_Ccc=3_4}', "");
Error('\p{Canonical_Combining_Class= /a/CCC35}');
Error('\P{Canonical_Combining_Class= /a/CCC35}');
Expect(1, 1648, '\p{Canonical_Combining_Class=ccc35}', "");
Expect(0, 1648, '\p{^Canonical_Combining_Class=ccc35}', "");
Expect(0, 1648, '\P{Canonical_Combining_Class=ccc35}', "");
Expect(1, 1648, '\P{^Canonical_Combining_Class=ccc35}', "");
Expect(0, 1649, '\p{Canonical_Combining_Class=ccc35}', "");
Expect(1, 1649, '\p{^Canonical_Combining_Class=ccc35}', "");
Expect(1, 1649, '\P{Canonical_Combining_Class=ccc35}', "");
Expect(0, 1649, '\P{^Canonical_Combining_Class=ccc35}', "");
Expect(1, 1648, '\p{Canonical_Combining_Class=_CCC35}', "");
Expect(0, 1648, '\p{^Canonical_Combining_Class=_CCC35}', "");
Expect(0, 1648, '\P{Canonical_Combining_Class=_CCC35}', "");
Expect(1, 1648, '\P{^Canonical_Combining_Class=_CCC35}', "");
Expect(0, 1649, '\p{Canonical_Combining_Class=_CCC35}', "");
Expect(1, 1649, '\p{^Canonical_Combining_Class=_CCC35}', "");
Expect(1, 1649, '\P{Canonical_Combining_Class=_CCC35}', "");
Expect(0, 1649, '\P{^Canonical_Combining_Class=_CCC35}', "");
Error('\p{Ccc=	_000000035/a/}');
Error('\P{Ccc=	_000000035/a/}');
Expect(1, 1648, '\p{Ccc=000000035}', "");
Expect(0, 1648, '\p{^Ccc=000000035}', "");
Expect(0, 1648, '\P{Ccc=000000035}', "");
Expect(1, 1648, '\P{^Ccc=000000035}', "");
Expect(0, 1649, '\p{Ccc=000000035}', "");
Expect(1, 1649, '\p{^Ccc=000000035}', "");
Expect(1, 1649, '\P{Ccc=000000035}', "");
Expect(0, 1649, '\P{^Ccc=000000035}', "");
Error('\p{Is_Canonical_Combining_Class=	/a/CCC35}');
Error('\P{Is_Canonical_Combining_Class=	/a/CCC35}');
Expect(1, 1648, '\p{Is_Canonical_Combining_Class=ccc35}', "");
Expect(0, 1648, '\p{^Is_Canonical_Combining_Class=ccc35}', "");
Expect(0, 1648, '\P{Is_Canonical_Combining_Class=ccc35}', "");
Expect(1, 1648, '\P{^Is_Canonical_Combining_Class=ccc35}', "");
Expect(0, 1649, '\p{Is_Canonical_Combining_Class=ccc35}', "");
Expect(1, 1649, '\p{^Is_Canonical_Combining_Class=ccc35}', "");
Expect(1, 1649, '\P{Is_Canonical_Combining_Class=ccc35}', "");
Expect(0, 1649, '\P{^Is_Canonical_Combining_Class=ccc35}', "");
Expect(1, 1648, '\p{Is_Canonical_Combining_Class=_ CCC35}', "");
Expect(0, 1648, '\p{^Is_Canonical_Combining_Class=_ CCC35}', "");
Expect(0, 1648, '\P{Is_Canonical_Combining_Class=_ CCC35}', "");
Expect(1, 1648, '\P{^Is_Canonical_Combining_Class=_ CCC35}', "");
Expect(0, 1649, '\p{Is_Canonical_Combining_Class=_ CCC35}', "");
Expect(1, 1649, '\p{^Is_Canonical_Combining_Class=_ CCC35}', "");
Expect(1, 1649, '\P{Is_Canonical_Combining_Class=_ CCC35}', "");
Expect(0, 1649, '\P{^Is_Canonical_Combining_Class=_ CCC35}', "");
Error('\p{Is_Ccc=/a/ 	035}');
Error('\P{Is_Ccc=/a/ 	035}');
Expect(1, 1648, '\p{Is_Ccc=00000035}', "");
Expect(0, 1648, '\p{^Is_Ccc=00000035}', "");
Expect(0, 1648, '\P{Is_Ccc=00000035}', "");
Expect(1, 1648, '\P{^Is_Ccc=00000035}', "");
Expect(0, 1649, '\p{Is_Ccc=00000035}', "");
Expect(1, 1649, '\p{^Is_Ccc=00000035}', "");
Expect(1, 1649, '\P{Is_Ccc=00000035}', "");
Expect(0, 1649, '\P{^Is_Ccc=00000035}', "");
Error('\p{Canonical_Combining_Class=_ ccc36:=}');
Error('\P{Canonical_Combining_Class=_ ccc36:=}');
Expect(1, 1809, '\p{Canonical_Combining_Class=ccc36}', "");
Expect(0, 1809, '\p{^Canonical_Combining_Class=ccc36}', "");
Expect(0, 1809, '\P{Canonical_Combining_Class=ccc36}', "");
Expect(1, 1809, '\P{^Canonical_Combining_Class=ccc36}', "");
Expect(0, 1810, '\p{Canonical_Combining_Class=ccc36}', "");
Expect(1, 1810, '\p{^Canonical_Combining_Class=ccc36}', "");
Expect(1, 1810, '\P{Canonical_Combining_Class=ccc36}', "");
Expect(0, 1810, '\P{^Canonical_Combining_Class=ccc36}', "");
Expect(1, 1809, '\p{Canonical_Combining_Class= ccc36}', "");
Expect(0, 1809, '\p{^Canonical_Combining_Class= ccc36}', "");
Expect(0, 1809, '\P{Canonical_Combining_Class= ccc36}', "");
Expect(1, 1809, '\P{^Canonical_Combining_Class= ccc36}', "");
Expect(0, 1810, '\p{Canonical_Combining_Class= ccc36}', "");
Expect(1, 1810, '\p{^Canonical_Combining_Class= ccc36}', "");
Expect(1, 1810, '\P{Canonical_Combining_Class= ccc36}', "");
Expect(0, 1810, '\P{^Canonical_Combining_Class= ccc36}', "");
Error('\p{Ccc=:=  000036}');
Error('\P{Ccc=:=  000036}');
Expect(1, 1809, '\p{Ccc=3_6}', "");
Expect(0, 1809, '\p{^Ccc=3_6}', "");
Expect(0, 1809, '\P{Ccc=3_6}', "");
Expect(1, 1809, '\P{^Ccc=3_6}', "");
Expect(0, 1810, '\p{Ccc=3_6}', "");
Expect(1, 1810, '\p{^Ccc=3_6}', "");
Expect(1, 1810, '\P{Ccc=3_6}', "");
Expect(0, 1810, '\P{^Ccc=3_6}', "");
Error('\p{Is_Canonical_Combining_Class= CCC36:=}');
Error('\P{Is_Canonical_Combining_Class= CCC36:=}');
Expect(1, 1809, '\p{Is_Canonical_Combining_Class: ccc36}', "");
Expect(0, 1809, '\p{^Is_Canonical_Combining_Class: ccc36}', "");
Expect(0, 1809, '\P{Is_Canonical_Combining_Class: ccc36}', "");
Expect(1, 1809, '\P{^Is_Canonical_Combining_Class: ccc36}', "");
Expect(0, 1810, '\p{Is_Canonical_Combining_Class: ccc36}', "");
Expect(1, 1810, '\p{^Is_Canonical_Combining_Class: ccc36}', "");
Expect(1, 1810, '\P{Is_Canonical_Combining_Class: ccc36}', "");
Expect(0, 1810, '\P{^Is_Canonical_Combining_Class: ccc36}', "");
Expect(1, 1809, '\p{Is_Canonical_Combining_Class=__CCC36}', "");
Expect(0, 1809, '\p{^Is_Canonical_Combining_Class=__CCC36}', "");
Expect(0, 1809, '\P{Is_Canonical_Combining_Class=__CCC36}', "");
Expect(1, 1809, '\P{^Is_Canonical_Combining_Class=__CCC36}', "");
Expect(0, 1810, '\p{Is_Canonical_Combining_Class=__CCC36}', "");
Expect(1, 1810, '\p{^Is_Canonical_Combining_Class=__CCC36}', "");
Expect(1, 1810, '\P{Is_Canonical_Combining_Class=__CCC36}', "");
Expect(0, 1810, '\P{^Is_Canonical_Combining_Class=__CCC36}', "");
Error('\p{Is_Ccc= 	03_6/a/}');
Error('\P{Is_Ccc= 	03_6/a/}');
Expect(1, 1809, '\p{Is_Ccc=0_0_0_0_0036}', "");
Expect(0, 1809, '\p{^Is_Ccc=0_0_0_0_0036}', "");
Expect(0, 1809, '\P{Is_Ccc=0_0_0_0_0036}', "");
Expect(1, 1809, '\P{^Is_Ccc=0_0_0_0_0036}', "");
Expect(0, 1810, '\p{Is_Ccc=0_0_0_0_0036}', "");
Expect(1, 1810, '\p{^Is_Ccc=0_0_0_0_0036}', "");
Expect(1, 1810, '\P{Is_Ccc=0_0_0_0_0036}', "");
Expect(0, 1810, '\P{^Is_Ccc=0_0_0_0_0036}', "");
Error('\p{Canonical_Combining_Class=/a/-_CCC84}');
Error('\P{Canonical_Combining_Class=/a/-_CCC84}');
Expect(1, 3157, '\p{Canonical_Combining_Class=ccc84}', "");
Expect(0, 3157, '\p{^Canonical_Combining_Class=ccc84}', "");
Expect(0, 3157, '\P{Canonical_Combining_Class=ccc84}', "");
Expect(1, 3157, '\P{^Canonical_Combining_Class=ccc84}', "");
Expect(0, 3158, '\p{Canonical_Combining_Class=ccc84}', "");
Expect(1, 3158, '\p{^Canonical_Combining_Class=ccc84}', "");
Expect(1, 3158, '\P{Canonical_Combining_Class=ccc84}', "");
Expect(0, 3158, '\P{^Canonical_Combining_Class=ccc84}', "");
Expect(1, 3157, '\p{Canonical_Combining_Class=_-CCC84}', "");
Expect(0, 3157, '\p{^Canonical_Combining_Class=_-CCC84}', "");
Expect(0, 3157, '\P{Canonical_Combining_Class=_-CCC84}', "");
Expect(1, 3157, '\P{^Canonical_Combining_Class=_-CCC84}', "");
Expect(0, 3158, '\p{Canonical_Combining_Class=_-CCC84}', "");
Expect(1, 3158, '\p{^Canonical_Combining_Class=_-CCC84}', "");
Expect(1, 3158, '\P{Canonical_Combining_Class=_-CCC84}', "");
Expect(0, 3158, '\P{^Canonical_Combining_Class=_-CCC84}', "");
Error('\p{Ccc=:=- 0000084}');
Error('\P{Ccc=:=- 0000084}');
Expect(1, 3157, '\p{Ccc=+084}', "");
Expect(0, 3157, '\p{^Ccc=+084}', "");
Expect(0, 3157, '\P{Ccc=+084}', "");
Expect(1, 3157, '\P{^Ccc=+084}', "");
Expect(0, 3158, '\p{Ccc=+084}', "");
Expect(1, 3158, '\p{^Ccc=+084}', "");
Expect(1, 3158, '\P{Ccc=+084}', "");
Expect(0, 3158, '\P{^Ccc=+084}', "");
Error('\p{Is_Canonical_Combining_Class=/a/	ccc84}');
Error('\P{Is_Canonical_Combining_Class=/a/	ccc84}');
Expect(1, 3157, '\p{Is_Canonical_Combining_Class:   ccc84}', "");
Expect(0, 3157, '\p{^Is_Canonical_Combining_Class:   ccc84}', "");
Expect(0, 3157, '\P{Is_Canonical_Combining_Class:   ccc84}', "");
Expect(1, 3157, '\P{^Is_Canonical_Combining_Class:   ccc84}', "");
Expect(0, 3158, '\p{Is_Canonical_Combining_Class:   ccc84}', "");
Expect(1, 3158, '\p{^Is_Canonical_Combining_Class:   ccc84}', "");
Expect(1, 3158, '\P{Is_Canonical_Combining_Class:   ccc84}', "");
Expect(0, 3158, '\P{^Is_Canonical_Combining_Class:   ccc84}', "");
Expect(1, 3157, '\p{Is_Canonical_Combining_Class= CCC84}', "");
Expect(0, 3157, '\p{^Is_Canonical_Combining_Class= CCC84}', "");
Expect(0, 3157, '\P{Is_Canonical_Combining_Class= CCC84}', "");
Expect(1, 3157, '\P{^Is_Canonical_Combining_Class= CCC84}', "");
Expect(0, 3158, '\p{Is_Canonical_Combining_Class= CCC84}', "");
Expect(1, 3158, '\p{^Is_Canonical_Combining_Class= CCC84}', "");
Expect(1, 3158, '\P{Is_Canonical_Combining_Class= CCC84}', "");
Expect(0, 3158, '\P{^Is_Canonical_Combining_Class= CCC84}', "");
Error('\p{Is_Ccc=:=-00000084}');
Error('\P{Is_Ccc=:=-00000084}');
Expect(1, 3157, '\p{Is_Ccc=000084}', "");
Expect(0, 3157, '\p{^Is_Ccc=000084}', "");
Expect(0, 3157, '\P{Is_Ccc=000084}', "");
Expect(1, 3157, '\P{^Is_Ccc=000084}', "");
Expect(0, 3158, '\p{Is_Ccc=000084}', "");
Expect(1, 3158, '\p{^Is_Ccc=000084}', "");
Expect(1, 3158, '\P{Is_Ccc=000084}', "");
Expect(0, 3158, '\P{^Is_Ccc=000084}', "");
Error('\p{Canonical_Combining_Class=-/a/ccc91}');
Error('\P{Canonical_Combining_Class=-/a/ccc91}');
Expect(1, 3158, '\p{Canonical_Combining_Class=ccc91}', "");
Expect(0, 3158, '\p{^Canonical_Combining_Class=ccc91}', "");
Expect(0, 3158, '\P{Canonical_Combining_Class=ccc91}', "");
Expect(1, 3158, '\P{^Canonical_Combining_Class=ccc91}', "");
Expect(0, 3159, '\p{Canonical_Combining_Class=ccc91}', "");
Expect(1, 3159, '\p{^Canonical_Combining_Class=ccc91}', "");
Expect(1, 3159, '\P{Canonical_Combining_Class=ccc91}', "");
Expect(0, 3159, '\P{^Canonical_Combining_Class=ccc91}', "");
Expect(1, 3158, '\p{Canonical_Combining_Class=	 CCC91}', "");
Expect(0, 3158, '\p{^Canonical_Combining_Class=	 CCC91}', "");
Expect(0, 3158, '\P{Canonical_Combining_Class=	 CCC91}', "");
Expect(1, 3158, '\P{^Canonical_Combining_Class=	 CCC91}', "");
Expect(0, 3159, '\p{Canonical_Combining_Class=	 CCC91}', "");
Expect(1, 3159, '\p{^Canonical_Combining_Class=	 CCC91}', "");
Expect(1, 3159, '\P{Canonical_Combining_Class=	 CCC91}', "");
Expect(0, 3159, '\P{^Canonical_Combining_Class=	 CCC91}', "");
Error('\p{Ccc= :=0091}');
Error('\P{Ccc= :=0091}');
Expect(1, 3158, '\p{Ccc=0000000091}', "");
Expect(0, 3158, '\p{^Ccc=0000000091}', "");
Expect(0, 3158, '\P{Ccc=0000000091}', "");
Expect(1, 3158, '\P{^Ccc=0000000091}', "");
Expect(0, 3159, '\p{Ccc=0000000091}', "");
Expect(1, 3159, '\p{^Ccc=0000000091}', "");
Expect(1, 3159, '\P{Ccc=0000000091}', "");
Expect(0, 3159, '\P{^Ccc=0000000091}', "");
Error('\p{Is_Canonical_Combining_Class=/a/__CCC91}');
Error('\P{Is_Canonical_Combining_Class=/a/__CCC91}');
Expect(1, 3158, '\p{Is_Canonical_Combining_Class=ccc91}', "");
Expect(0, 3158, '\p{^Is_Canonical_Combining_Class=ccc91}', "");
Expect(0, 3158, '\P{Is_Canonical_Combining_Class=ccc91}', "");
Expect(1, 3158, '\P{^Is_Canonical_Combining_Class=ccc91}', "");
Expect(0, 3159, '\p{Is_Canonical_Combining_Class=ccc91}', "");
Expect(1, 3159, '\p{^Is_Canonical_Combining_Class=ccc91}', "");
Expect(1, 3159, '\P{Is_Canonical_Combining_Class=ccc91}', "");
Expect(0, 3159, '\P{^Is_Canonical_Combining_Class=ccc91}', "");
Expect(1, 3158, '\p{Is_Canonical_Combining_Class= -CCC91}', "");
Expect(0, 3158, '\p{^Is_Canonical_Combining_Class= -CCC91}', "");
Expect(0, 3158, '\P{Is_Canonical_Combining_Class= -CCC91}', "");
Expect(1, 3158, '\P{^Is_Canonical_Combining_Class= -CCC91}', "");
Expect(0, 3159, '\p{Is_Canonical_Combining_Class= -CCC91}', "");
Expect(1, 3159, '\p{^Is_Canonical_Combining_Class= -CCC91}', "");
Expect(1, 3159, '\P{Is_Canonical_Combining_Class= -CCC91}', "");
Expect(0, 3159, '\P{^Is_Canonical_Combining_Class= -CCC91}', "");
Error('\p{Is_Ccc=__0091/a/}');
Error('\P{Is_Ccc=__0091/a/}');
Expect(1, 3158, '\p{Is_Ccc=0000091}', "");
Expect(0, 3158, '\p{^Is_Ccc=0000091}', "");
Expect(0, 3158, '\P{Is_Ccc=0000091}', "");
Expect(1, 3158, '\P{^Is_Ccc=0000091}', "");
Expect(0, 3159, '\p{Is_Ccc=0000091}', "");
Expect(1, 3159, '\p{^Is_Ccc=0000091}', "");
Expect(1, 3159, '\P{Is_Ccc=0000091}', "");
Expect(0, 3159, '\P{^Is_Ccc=0000091}', "");
Error('\p{Canonical_Combining_Class=-_Double_Above:=}');
Error('\P{Canonical_Combining_Class=-_Double_Above:=}');
Expect(1, 7629, '\p{Canonical_Combining_Class=doubleabove}', "");
Expect(0, 7629, '\p{^Canonical_Combining_Class=doubleabove}', "");
Expect(0, 7629, '\P{Canonical_Combining_Class=doubleabove}', "");
Expect(1, 7629, '\P{^Canonical_Combining_Class=doubleabove}', "");
Expect(0, 7630, '\p{Canonical_Combining_Class=doubleabove}', "");
Expect(1, 7630, '\p{^Canonical_Combining_Class=doubleabove}', "");
Expect(1, 7630, '\P{Canonical_Combining_Class=doubleabove}', "");
Expect(0, 7630, '\P{^Canonical_Combining_Class=doubleabove}', "");
Expect(1, 7629, '\p{Canonical_Combining_Class=_ Double_Above}', "");
Expect(0, 7629, '\p{^Canonical_Combining_Class=_ Double_Above}', "");
Expect(0, 7629, '\P{Canonical_Combining_Class=_ Double_Above}', "");
Expect(1, 7629, '\P{^Canonical_Combining_Class=_ Double_Above}', "");
Expect(0, 7630, '\p{Canonical_Combining_Class=_ Double_Above}', "");
Expect(1, 7630, '\p{^Canonical_Combining_Class=_ Double_Above}', "");
Expect(1, 7630, '\P{Canonical_Combining_Class=_ Double_Above}', "");
Expect(0, 7630, '\P{^Canonical_Combining_Class=_ Double_Above}', "");
Error('\p{Ccc= :=DA}');
Error('\P{Ccc= :=DA}');
Expect(1, 7629, '\p{Ccc=da}', "");
Expect(0, 7629, '\p{^Ccc=da}', "");
Expect(0, 7629, '\P{Ccc=da}', "");
Expect(1, 7629, '\P{^Ccc=da}', "");
Expect(0, 7630, '\p{Ccc=da}', "");
Expect(1, 7630, '\p{^Ccc=da}', "");
Expect(1, 7630, '\P{Ccc=da}', "");
Expect(0, 7630, '\P{^Ccc=da}', "");
Expect(1, 7629, '\p{Ccc=	DA}', "");
Expect(0, 7629, '\p{^Ccc=	DA}', "");
Expect(0, 7629, '\P{Ccc=	DA}', "");
Expect(1, 7629, '\P{^Ccc=	DA}', "");
Expect(0, 7630, '\p{Ccc=	DA}', "");
Expect(1, 7630, '\p{^Ccc=	DA}', "");
Expect(1, 7630, '\P{Ccc=	DA}', "");
Expect(0, 7630, '\P{^Ccc=	DA}', "");
Error('\p{Is_Canonical_Combining_Class=-/a/0023_4}');
Error('\P{Is_Canonical_Combining_Class=-/a/0023_4}');
Expect(1, 7629, '\p{Is_Canonical_Combining_Class=+000000234}', "");
Expect(0, 7629, '\p{^Is_Canonical_Combining_Class=+000000234}', "");
Expect(0, 7629, '\P{Is_Canonical_Combining_Class=+000000234}', "");
Expect(1, 7629, '\P{^Is_Canonical_Combining_Class=+000000234}', "");
Expect(0, 7630, '\p{Is_Canonical_Combining_Class=+000000234}', "");
Expect(1, 7630, '\p{^Is_Canonical_Combining_Class=+000000234}', "");
Expect(1, 7630, '\P{Is_Canonical_Combining_Class=+000000234}', "");
Expect(0, 7630, '\P{^Is_Canonical_Combining_Class=+000000234}', "");
Error('\p{Is_Ccc=/a/- DOUBLE_above}');
Error('\P{Is_Ccc=/a/- DOUBLE_above}');
Expect(1, 7629, '\p{Is_Ccc:   doubleabove}', "");
Expect(0, 7629, '\p{^Is_Ccc:   doubleabove}', "");
Expect(0, 7629, '\P{Is_Ccc:   doubleabove}', "");
Expect(1, 7629, '\P{^Is_Ccc:   doubleabove}', "");
Expect(0, 7630, '\p{Is_Ccc:   doubleabove}', "");
Expect(1, 7630, '\p{^Is_Ccc:   doubleabove}', "");
Expect(1, 7630, '\P{Is_Ccc:   doubleabove}', "");
Expect(0, 7630, '\P{^Is_Ccc:   doubleabove}', "");
Expect(1, 7629, '\p{Is_Ccc=_ double_Above}', "");
Expect(0, 7629, '\p{^Is_Ccc=_ double_Above}', "");
Expect(0, 7629, '\P{Is_Ccc=_ double_Above}', "");
Expect(1, 7629, '\P{^Is_Ccc=_ double_Above}', "");
Expect(0, 7630, '\p{Is_Ccc=_ double_Above}', "");
Expect(1, 7630, '\p{^Is_Ccc=_ double_Above}', "");
Expect(1, 7630, '\P{Is_Ccc=_ double_Above}', "");
Expect(0, 7630, '\P{^Is_Ccc=_ double_Above}', "");
Error('\p{Canonical_Combining_Class=:=  DOUBLE_BELOW}');
Error('\P{Canonical_Combining_Class=:=  DOUBLE_BELOW}');
Expect(1, 7676, '\p{Canonical_Combining_Class=doublebelow}', "");
Expect(0, 7676, '\p{^Canonical_Combining_Class=doublebelow}', "");
Expect(0, 7676, '\P{Canonical_Combining_Class=doublebelow}', "");
Expect(1, 7676, '\P{^Canonical_Combining_Class=doublebelow}', "");
Expect(0, 7677, '\p{Canonical_Combining_Class=doublebelow}', "");
Expect(1, 7677, '\p{^Canonical_Combining_Class=doublebelow}', "");
Expect(1, 7677, '\P{Canonical_Combining_Class=doublebelow}', "");
Expect(0, 7677, '\P{^Canonical_Combining_Class=doublebelow}', "");
Expect(1, 7676, '\p{Canonical_Combining_Class=_-Double_below}', "");
Expect(0, 7676, '\p{^Canonical_Combining_Class=_-Double_below}', "");
Expect(0, 7676, '\P{Canonical_Combining_Class=_-Double_below}', "");
Expect(1, 7676, '\P{^Canonical_Combining_Class=_-Double_below}', "");
Expect(0, 7677, '\p{Canonical_Combining_Class=_-Double_below}', "");
Expect(1, 7677, '\p{^Canonical_Combining_Class=_-Double_below}', "");
Expect(1, 7677, '\P{Canonical_Combining_Class=_-Double_below}', "");
Expect(0, 7677, '\P{^Canonical_Combining_Class=_-Double_below}', "");
Error('\p{Ccc=:=_ DB}');
Error('\P{Ccc=:=_ DB}');
Expect(1, 7676, '\p{Ccc=db}', "");
Expect(0, 7676, '\p{^Ccc=db}', "");
Expect(0, 7676, '\P{Ccc=db}', "");
Expect(1, 7676, '\P{^Ccc=db}', "");
Expect(0, 7677, '\p{Ccc=db}', "");
Expect(1, 7677, '\p{^Ccc=db}', "");
Expect(1, 7677, '\P{Ccc=db}', "");
Expect(0, 7677, '\P{^Ccc=db}', "");
Expect(1, 7676, '\p{Ccc= _DB}', "");
Expect(0, 7676, '\p{^Ccc= _DB}', "");
Expect(0, 7676, '\P{Ccc= _DB}', "");
Expect(1, 7676, '\P{^Ccc= _DB}', "");
Expect(0, 7677, '\p{Ccc= _DB}', "");
Expect(1, 7677, '\p{^Ccc= _DB}', "");
Expect(1, 7677, '\P{Ccc= _DB}', "");
Expect(0, 7677, '\P{^Ccc= _DB}', "");
Error('\p{Is_Canonical_Combining_Class=:=_	0_0_0_0_0_0_0_0_0_2_33}');
Error('\P{Is_Canonical_Combining_Class=:=_	0_0_0_0_0_0_0_0_0_2_33}');
Expect(1, 7676, '\p{Is_Canonical_Combining_Class=000_002_33}', "");
Expect(0, 7676, '\p{^Is_Canonical_Combining_Class=000_002_33}', "");
Expect(0, 7676, '\P{Is_Canonical_Combining_Class=000_002_33}', "");
Expect(1, 7676, '\P{^Is_Canonical_Combining_Class=000_002_33}', "");
Expect(0, 7677, '\p{Is_Canonical_Combining_Class=000_002_33}', "");
Expect(1, 7677, '\p{^Is_Canonical_Combining_Class=000_002_33}', "");
Expect(1, 7677, '\P{Is_Canonical_Combining_Class=000_002_33}', "");
Expect(0, 7677, '\P{^Is_Canonical_Combining_Class=000_002_33}', "");
Error('\p{Is_Ccc:- Double_Below:=}');
Error('\P{Is_Ccc:- Double_Below:=}');
Expect(1, 7676, '\p{Is_Ccc=doublebelow}', "");
Expect(0, 7676, '\p{^Is_Ccc=doublebelow}', "");
Expect(0, 7676, '\P{Is_Ccc=doublebelow}', "");
Expect(1, 7676, '\P{^Is_Ccc=doublebelow}', "");
Expect(0, 7677, '\p{Is_Ccc=doublebelow}', "");
Expect(1, 7677, '\p{^Is_Ccc=doublebelow}', "");
Expect(1, 7677, '\P{Is_Ccc=doublebelow}', "");
Expect(0, 7677, '\P{^Is_Ccc=doublebelow}', "");
Expect(1, 7676, '\p{Is_Ccc=_Double_Below}', "");
Expect(0, 7676, '\p{^Is_Ccc=_Double_Below}', "");
Expect(0, 7676, '\P{Is_Ccc=_Double_Below}', "");
Expect(1, 7676, '\P{^Is_Ccc=_Double_Below}', "");
Expect(0, 7677, '\p{Is_Ccc=_Double_Below}', "");
Expect(1, 7677, '\p{^Is_Ccc=_Double_Below}', "");
Expect(1, 7677, '\P{Is_Ccc=_Double_Below}', "");
Expect(0, 7677, '\P{^Is_Ccc=_Double_Below}', "");
Error('\p{Canonical_Combining_Class=_-Iota_SUBSCRIPT:=}');
Error('\P{Canonical_Combining_Class=_-Iota_SUBSCRIPT:=}');
Expect(1, 837, '\p{Canonical_Combining_Class=iotasubscript}', "");
Expect(0, 837, '\p{^Canonical_Combining_Class=iotasubscript}', "");
Expect(0, 837, '\P{Canonical_Combining_Class=iotasubscript}', "");
Expect(1, 837, '\P{^Canonical_Combining_Class=iotasubscript}', "");
Expect(0, 838, '\p{Canonical_Combining_Class=iotasubscript}', "");
Expect(1, 838, '\p{^Canonical_Combining_Class=iotasubscript}', "");
Expect(1, 838, '\P{Canonical_Combining_Class=iotasubscript}', "");
Expect(0, 838, '\P{^Canonical_Combining_Class=iotasubscript}', "");
Expect(1, 837, '\p{Canonical_Combining_Class= IOTA_Subscript}', "");
Expect(0, 837, '\p{^Canonical_Combining_Class= IOTA_Subscript}', "");
Expect(0, 837, '\P{Canonical_Combining_Class= IOTA_Subscript}', "");
Expect(1, 837, '\P{^Canonical_Combining_Class= IOTA_Subscript}', "");
Expect(0, 838, '\p{Canonical_Combining_Class= IOTA_Subscript}', "");
Expect(1, 838, '\p{^Canonical_Combining_Class= IOTA_Subscript}', "");
Expect(1, 838, '\P{Canonical_Combining_Class= IOTA_Subscript}', "");
Expect(0, 838, '\P{^Canonical_Combining_Class= IOTA_Subscript}', "");
Error('\p{Ccc=-IS/a/}');
Error('\P{Ccc=-IS/a/}');
Expect(1, 837, '\p{Ccc=is}', "");
Expect(0, 837, '\p{^Ccc=is}', "");
Expect(0, 837, '\P{Ccc=is}', "");
Expect(1, 837, '\P{^Ccc=is}', "");
Expect(0, 838, '\p{Ccc=is}', "");
Expect(1, 838, '\p{^Ccc=is}', "");
Expect(1, 838, '\P{Ccc=is}', "");
Expect(0, 838, '\P{^Ccc=is}', "");
Expect(1, 837, '\p{Ccc=  IS}', "");
Expect(0, 837, '\p{^Ccc=  IS}', "");
Expect(0, 837, '\P{Ccc=  IS}', "");
Expect(1, 837, '\P{^Ccc=  IS}', "");
Expect(0, 838, '\p{Ccc=  IS}', "");
Expect(1, 838, '\p{^Ccc=  IS}', "");
Expect(1, 838, '\P{Ccc=  IS}', "");
Expect(0, 838, '\P{^Ccc=  IS}', "");
Error('\p{Is_Canonical_Combining_Class=/a/-24_0}');
Error('\P{Is_Canonical_Combining_Class=/a/-24_0}');
Expect(1, 837, '\p{Is_Canonical_Combining_Class=00_24_0}', "");
Expect(0, 837, '\p{^Is_Canonical_Combining_Class=00_24_0}', "");
Expect(0, 837, '\P{Is_Canonical_Combining_Class=00_24_0}', "");
Expect(1, 837, '\P{^Is_Canonical_Combining_Class=00_24_0}', "");
Expect(0, 838, '\p{Is_Canonical_Combining_Class=00_24_0}', "");
Expect(1, 838, '\p{^Is_Canonical_Combining_Class=00_24_0}', "");
Expect(1, 838, '\P{Is_Canonical_Combining_Class=00_24_0}', "");
Expect(0, 838, '\P{^Is_Canonical_Combining_Class=00_24_0}', "");
Error('\p{Is_Ccc=	/a/Iota_subscript}');
Error('\P{Is_Ccc=	/a/Iota_subscript}');
Expect(1, 837, '\p{Is_Ccc=iotasubscript}', "");
Expect(0, 837, '\p{^Is_Ccc=iotasubscript}', "");
Expect(0, 837, '\P{Is_Ccc=iotasubscript}', "");
Expect(1, 837, '\P{^Is_Ccc=iotasubscript}', "");
Expect(0, 838, '\p{Is_Ccc=iotasubscript}', "");
Expect(1, 838, '\p{^Is_Ccc=iotasubscript}', "");
Expect(1, 838, '\P{Is_Ccc=iotasubscript}', "");
Expect(0, 838, '\P{^Is_Ccc=iotasubscript}', "");
Expect(1, 837, '\p{Is_Ccc=iota_subscript}', "");
Expect(0, 837, '\p{^Is_Ccc=iota_subscript}', "");
Expect(0, 837, '\P{Is_Ccc=iota_subscript}', "");
Expect(1, 837, '\P{^Is_Ccc=iota_subscript}', "");
Expect(0, 838, '\p{Is_Ccc=iota_subscript}', "");
Expect(1, 838, '\p{^Is_Ccc=iota_subscript}', "");
Expect(1, 838, '\P{Is_Ccc=iota_subscript}', "");
Expect(0, 838, '\P{^Is_Ccc=iota_subscript}', "");
Error('\p{Canonical_Combining_Class=_	KANA_Voicing:=}');
Error('\P{Canonical_Combining_Class=_	KANA_Voicing:=}');
Expect(1, 12442, '\p{Canonical_Combining_Class=kanavoicing}', "");
Expect(0, 12442, '\p{^Canonical_Combining_Class=kanavoicing}', "");
Expect(0, 12442, '\P{Canonical_Combining_Class=kanavoicing}', "");
Expect(1, 12442, '\P{^Canonical_Combining_Class=kanavoicing}', "");
Expect(0, 12443, '\p{Canonical_Combining_Class=kanavoicing}', "");
Expect(1, 12443, '\p{^Canonical_Combining_Class=kanavoicing}', "");
Expect(1, 12443, '\P{Canonical_Combining_Class=kanavoicing}', "");
Expect(0, 12443, '\P{^Canonical_Combining_Class=kanavoicing}', "");
Expect(1, 12442, '\p{Canonical_Combining_Class=	_Kana_VOICING}', "");
Expect(0, 12442, '\p{^Canonical_Combining_Class=	_Kana_VOICING}', "");
Expect(0, 12442, '\P{Canonical_Combining_Class=	_Kana_VOICING}', "");
Expect(1, 12442, '\P{^Canonical_Combining_Class=	_Kana_VOICING}', "");
Expect(0, 12443, '\p{Canonical_Combining_Class=	_Kana_VOICING}', "");
Expect(1, 12443, '\p{^Canonical_Combining_Class=	_Kana_VOICING}', "");
Expect(1, 12443, '\P{Canonical_Combining_Class=	_Kana_VOICING}', "");
Expect(0, 12443, '\P{^Canonical_Combining_Class=	_Kana_VOICING}', "");
Error('\p{Ccc=-	kv:=}');
Error('\P{Ccc=-	kv:=}');
Expect(1, 12442, '\p{Ccc=kv}', "");
Expect(0, 12442, '\p{^Ccc=kv}', "");
Expect(0, 12442, '\P{Ccc=kv}', "");
Expect(1, 12442, '\P{^Ccc=kv}', "");
Expect(0, 12443, '\p{Ccc=kv}', "");
Expect(1, 12443, '\p{^Ccc=kv}', "");
Expect(1, 12443, '\P{Ccc=kv}', "");
Expect(0, 12443, '\P{^Ccc=kv}', "");
Expect(1, 12442, '\p{Ccc=	_KV}', "");
Expect(0, 12442, '\p{^Ccc=	_KV}', "");
Expect(0, 12442, '\P{Ccc=	_KV}', "");
Expect(1, 12442, '\P{^Ccc=	_KV}', "");
Expect(0, 12443, '\p{Ccc=	_KV}', "");
Expect(1, 12443, '\p{^Ccc=	_KV}', "");
Expect(1, 12443, '\P{Ccc=	_KV}', "");
Expect(0, 12443, '\P{^Ccc=	_KV}', "");
Error('\p{Is_Canonical_Combining_Class=/a/		+00_8}');
Error('\P{Is_Canonical_Combining_Class=/a/		+00_8}');
Expect(1, 12442, '\p{Is_Canonical_Combining_Class=0_0_08}', "");
Expect(0, 12442, '\p{^Is_Canonical_Combining_Class=0_0_08}', "");
Expect(0, 12442, '\P{Is_Canonical_Combining_Class=0_0_08}', "");
Expect(1, 12442, '\P{^Is_Canonical_Combining_Class=0_0_08}', "");
Expect(0, 12443, '\p{Is_Canonical_Combining_Class=0_0_08}', "");
Expect(1, 12443, '\p{^Is_Canonical_Combining_Class=0_0_08}', "");
Expect(1, 12443, '\P{Is_Canonical_Combining_Class=0_0_08}', "");
Expect(0, 12443, '\P{^Is_Canonical_Combining_Class=0_0_08}', "");
Error('\p{Is_Ccc=/a/  Kana_VOICING}');
Error('\P{Is_Ccc=/a/  Kana_VOICING}');
Expect(1, 12442, '\p{Is_Ccc=kanavoicing}', "");
Expect(0, 12442, '\p{^Is_Ccc=kanavoicing}', "");
Expect(0, 12442, '\P{Is_Ccc=kanavoicing}', "");
Expect(1, 12442, '\P{^Is_Ccc=kanavoicing}', "");
Expect(0, 12443, '\p{Is_Ccc=kanavoicing}', "");
Expect(1, 12443, '\p{^Is_Ccc=kanavoicing}', "");
Expect(1, 12443, '\P{Is_Ccc=kanavoicing}', "");
Expect(0, 12443, '\P{^Is_Ccc=kanavoicing}', "");
Expect(1, 12442, '\p{Is_Ccc=kana_voicing}', "");
Expect(0, 12442, '\p{^Is_Ccc=kana_voicing}', "");
Expect(0, 12442, '\P{Is_Ccc=kana_voicing}', "");
Expect(1, 12442, '\P{^Is_Ccc=kana_voicing}', "");
Expect(0, 12443, '\p{Is_Ccc=kana_voicing}', "");
Expect(1, 12443, '\p{^Is_Ccc=kana_voicing}', "");
Expect(1, 12443, '\P{Is_Ccc=kana_voicing}', "");
Expect(0, 12443, '\P{^Is_Ccc=kana_voicing}', "");
Error('\p{Canonical_Combining_Class::=_Left}');
Error('\P{Canonical_Combining_Class::=_Left}');
Expect(1, 12335, '\p{Canonical_Combining_Class=left}', "");
Expect(0, 12335, '\p{^Canonical_Combining_Class=left}', "");
Expect(0, 12335, '\P{Canonical_Combining_Class=left}', "");
Expect(1, 12335, '\P{^Canonical_Combining_Class=left}', "");
Expect(0, 12336, '\p{Canonical_Combining_Class=left}', "");
Expect(1, 12336, '\p{^Canonical_Combining_Class=left}', "");
Expect(1, 12336, '\P{Canonical_Combining_Class=left}', "");
Expect(0, 12336, '\P{^Canonical_Combining_Class=left}', "");
Expect(1, 12335, '\p{Canonical_Combining_Class=--Left}', "");
Expect(0, 12335, '\p{^Canonical_Combining_Class=--Left}', "");
Expect(0, 12335, '\P{Canonical_Combining_Class=--Left}', "");
Expect(1, 12335, '\P{^Canonical_Combining_Class=--Left}', "");
Expect(0, 12336, '\p{Canonical_Combining_Class=--Left}', "");
Expect(1, 12336, '\p{^Canonical_Combining_Class=--Left}', "");
Expect(1, 12336, '\P{Canonical_Combining_Class=--Left}', "");
Expect(0, 12336, '\P{^Canonical_Combining_Class=--Left}', "");
Error('\p{Ccc=_/a/L}');
Error('\P{Ccc=_/a/L}');
Expect(1, 12335, '\p{Ccc=l}', "");
Expect(0, 12335, '\p{^Ccc=l}', "");
Expect(0, 12335, '\P{Ccc=l}', "");
Expect(1, 12335, '\P{^Ccc=l}', "");
Expect(0, 12336, '\p{Ccc=l}', "");
Expect(1, 12336, '\p{^Ccc=l}', "");
Expect(1, 12336, '\P{Ccc=l}', "");
Expect(0, 12336, '\P{^Ccc=l}', "");
Expect(1, 12335, '\p{Ccc=--L}', "");
Expect(0, 12335, '\p{^Ccc=--L}', "");
Expect(0, 12335, '\P{Ccc=--L}', "");
Expect(1, 12335, '\P{^Ccc=--L}', "");
Expect(0, 12336, '\p{Ccc=--L}', "");
Expect(1, 12336, '\p{^Ccc=--L}', "");
Expect(1, 12336, '\P{Ccc=--L}', "");
Expect(0, 12336, '\P{^Ccc=--L}', "");
Error('\p{Is_Canonical_Combining_Class:   -0000224:=}');
Error('\P{Is_Canonical_Combining_Class:   -0000224:=}');
Expect(1, 12335, '\p{Is_Canonical_Combining_Class=0022_4}', "");
Expect(0, 12335, '\p{^Is_Canonical_Combining_Class=0022_4}', "");
Expect(0, 12335, '\P{Is_Canonical_Combining_Class=0022_4}', "");
Expect(1, 12335, '\P{^Is_Canonical_Combining_Class=0022_4}', "");
Expect(0, 12336, '\p{Is_Canonical_Combining_Class=0022_4}', "");
Expect(1, 12336, '\p{^Is_Canonical_Combining_Class=0022_4}', "");
Expect(1, 12336, '\P{Is_Canonical_Combining_Class=0022_4}', "");
Expect(0, 12336, '\P{^Is_Canonical_Combining_Class=0022_4}', "");
Error('\p{Is_Ccc:   -:=left}');
Error('\P{Is_Ccc:   -:=left}');
Expect(1, 12335, '\p{Is_Ccc=left}', "");
Expect(0, 12335, '\p{^Is_Ccc=left}', "");
Expect(0, 12335, '\P{Is_Ccc=left}', "");
Expect(1, 12335, '\P{^Is_Ccc=left}', "");
Expect(0, 12336, '\p{Is_Ccc=left}', "");
Expect(1, 12336, '\p{^Is_Ccc=left}', "");
Expect(1, 12336, '\P{Is_Ccc=left}', "");
Expect(0, 12336, '\P{^Is_Ccc=left}', "");
Expect(1, 12335, '\p{Is_Ccc=_LEFT}', "");
Expect(0, 12335, '\p{^Is_Ccc=_LEFT}', "");
Expect(0, 12335, '\P{Is_Ccc=_LEFT}', "");
Expect(1, 12335, '\P{^Is_Ccc=_LEFT}', "");
Expect(0, 12336, '\p{Is_Ccc=_LEFT}', "");
Expect(1, 12336, '\p{^Is_Ccc=_LEFT}', "");
Expect(1, 12336, '\P{Is_Ccc=_LEFT}', "");
Expect(0, 12336, '\P{^Is_Ccc=_LEFT}', "");
Error('\p{Canonical_Combining_Class= :=Nukta}');
Error('\P{Canonical_Combining_Class= :=Nukta}');
Expect(1, 71351, '\p{Canonical_Combining_Class=nukta}', "");
Expect(0, 71351, '\p{^Canonical_Combining_Class=nukta}', "");
Expect(0, 71351, '\P{Canonical_Combining_Class=nukta}', "");
Expect(1, 71351, '\P{^Canonical_Combining_Class=nukta}', "");
Expect(0, 71352, '\p{Canonical_Combining_Class=nukta}', "");
Expect(1, 71352, '\p{^Canonical_Combining_Class=nukta}', "");
Expect(1, 71352, '\P{Canonical_Combining_Class=nukta}', "");
Expect(0, 71352, '\P{^Canonical_Combining_Class=nukta}', "");
Expect(1, 71351, '\p{Canonical_Combining_Class=	-Nukta}', "");
Expect(0, 71351, '\p{^Canonical_Combining_Class=	-Nukta}', "");
Expect(0, 71351, '\P{Canonical_Combining_Class=	-Nukta}', "");
Expect(1, 71351, '\P{^Canonical_Combining_Class=	-Nukta}', "");
Expect(0, 71352, '\p{Canonical_Combining_Class=	-Nukta}', "");
Expect(1, 71352, '\p{^Canonical_Combining_Class=	-Nukta}', "");
Expect(1, 71352, '\P{Canonical_Combining_Class=	-Nukta}', "");
Expect(0, 71352, '\P{^Canonical_Combining_Class=	-Nukta}', "");
Error('\p{Ccc=/a/_ nk}');
Error('\P{Ccc=/a/_ nk}');
Expect(1, 71351, '\p{Ccc=nk}', "");
Expect(0, 71351, '\p{^Ccc=nk}', "");
Expect(0, 71351, '\P{Ccc=nk}', "");
Expect(1, 71351, '\P{^Ccc=nk}', "");
Expect(0, 71352, '\p{Ccc=nk}', "");
Expect(1, 71352, '\p{^Ccc=nk}', "");
Expect(1, 71352, '\P{Ccc=nk}', "");
Expect(0, 71352, '\P{^Ccc=nk}', "");
Expect(1, 71351, '\p{Ccc=_NK}', "");
Expect(0, 71351, '\p{^Ccc=_NK}', "");
Expect(0, 71351, '\P{Ccc=_NK}', "");
Expect(1, 71351, '\P{^Ccc=_NK}', "");
Expect(0, 71352, '\p{Ccc=_NK}', "");
Expect(1, 71352, '\p{^Ccc=_NK}', "");
Expect(1, 71352, '\P{Ccc=_NK}', "");
Expect(0, 71352, '\P{^Ccc=_NK}', "");
Error('\p{Is_Canonical_Combining_Class= -00007:=}');
Error('\P{Is_Canonical_Combining_Class= -00007:=}');
Expect(1, 71351, '\p{Is_Canonical_Combining_Class:+0_7}', "");
Expect(0, 71351, '\p{^Is_Canonical_Combining_Class:+0_7}', "");
Expect(0, 71351, '\P{Is_Canonical_Combining_Class:+0_7}', "");
Expect(1, 71351, '\P{^Is_Canonical_Combining_Class:+0_7}', "");
Expect(0, 71352, '\p{Is_Canonical_Combining_Class:+0_7}', "");
Expect(1, 71352, '\p{^Is_Canonical_Combining_Class:+0_7}', "");
Expect(1, 71352, '\P{Is_Canonical_Combining_Class:+0_7}', "");
Expect(0, 71352, '\P{^Is_Canonical_Combining_Class:+0_7}', "");
Error('\p{Is_Ccc=__nukta:=}');
Error('\P{Is_Ccc=__nukta:=}');
Expect(1, 71351, '\p{Is_Ccc=nukta}', "");
Expect(0, 71351, '\p{^Is_Ccc=nukta}', "");
Expect(0, 71351, '\P{Is_Ccc=nukta}', "");
Expect(1, 71351, '\P{^Is_Ccc=nukta}', "");
Expect(0, 71352, '\p{Is_Ccc=nukta}', "");
Expect(1, 71352, '\p{^Is_Ccc=nukta}', "");
Expect(1, 71352, '\P{Is_Ccc=nukta}', "");
Expect(0, 71352, '\P{^Is_Ccc=nukta}', "");
Expect(1, 71351, '\p{Is_Ccc:_Nukta}', "");
Expect(0, 71351, '\p{^Is_Ccc:_Nukta}', "");
Expect(0, 71351, '\P{Is_Ccc:_Nukta}', "");
Expect(1, 71351, '\P{^Is_Ccc:_Nukta}', "");
Expect(0, 71352, '\p{Is_Ccc:_Nukta}', "");
Expect(1, 71352, '\p{^Is_Ccc:_Nukta}', "");
Expect(1, 71352, '\P{Is_Ccc:_Nukta}', "");
Expect(0, 71352, '\P{^Is_Ccc:_Nukta}', "");
Error('\p{Canonical_Combining_Class=-/a/not_Reordered}');
Error('\P{Canonical_Combining_Class=-/a/not_Reordered}');
Expect(1, 119365, '\p{Canonical_Combining_Class=notreordered}', "");
Expect(0, 119365, '\p{^Canonical_Combining_Class=notreordered}', "");
Expect(0, 119365, '\P{Canonical_Combining_Class=notreordered}', "");
Expect(1, 119365, '\P{^Canonical_Combining_Class=notreordered}', "");
Expect(0, 119364, '\p{Canonical_Combining_Class=notreordered}', "");
Expect(1, 119364, '\p{^Canonical_Combining_Class=notreordered}', "");
Expect(1, 119364, '\P{Canonical_Combining_Class=notreordered}', "");
Expect(0, 119364, '\P{^Canonical_Combining_Class=notreordered}', "");
Expect(1, 119365, '\p{Canonical_Combining_Class=-not_REORDERED}', "");
Expect(0, 119365, '\p{^Canonical_Combining_Class=-not_REORDERED}', "");
Expect(0, 119365, '\P{Canonical_Combining_Class=-not_REORDERED}', "");
Expect(1, 119365, '\P{^Canonical_Combining_Class=-not_REORDERED}', "");
Expect(0, 119364, '\p{Canonical_Combining_Class=-not_REORDERED}', "");
Expect(1, 119364, '\p{^Canonical_Combining_Class=-not_REORDERED}', "");
Expect(1, 119364, '\P{Canonical_Combining_Class=-not_REORDERED}', "");
Expect(0, 119364, '\P{^Canonical_Combining_Class=-not_REORDERED}', "");
Error('\p{Ccc=	 nr:=}');
Error('\P{Ccc=	 nr:=}');
Expect(1, 119365, '\p{Ccc=nr}', "");
Expect(0, 119365, '\p{^Ccc=nr}', "");
Expect(0, 119365, '\P{Ccc=nr}', "");
Expect(1, 119365, '\P{^Ccc=nr}', "");
Expect(0, 119364, '\p{Ccc=nr}', "");
Expect(1, 119364, '\p{^Ccc=nr}', "");
Expect(1, 119364, '\P{Ccc=nr}', "");
Expect(0, 119364, '\P{^Ccc=nr}', "");
Expect(1, 119365, '\p{Ccc=	_NR}', "");
Expect(0, 119365, '\p{^Ccc=	_NR}', "");
Expect(0, 119365, '\P{Ccc=	_NR}', "");
Expect(1, 119365, '\P{^Ccc=	_NR}', "");
Expect(0, 119364, '\p{Ccc=	_NR}', "");
Expect(1, 119364, '\p{^Ccc=	_NR}', "");
Expect(1, 119364, '\P{Ccc=	_NR}', "");
Expect(0, 119364, '\P{^Ccc=	_NR}', "");
Error('\p{Is_Canonical_Combining_Class= _0_0_00/a/}');
Error('\P{Is_Canonical_Combining_Class= _0_0_00/a/}');
Expect(1, 119365, '\p{Is_Canonical_Combining_Class=0000_0}', "");
Expect(0, 119365, '\p{^Is_Canonical_Combining_Class=0000_0}', "");
Expect(0, 119365, '\P{Is_Canonical_Combining_Class=0000_0}', "");
Expect(1, 119365, '\P{^Is_Canonical_Combining_Class=0000_0}', "");
Expect(0, 119364, '\p{Is_Canonical_Combining_Class=0000_0}', "");
Expect(1, 119364, '\p{^Is_Canonical_Combining_Class=0000_0}', "");
Expect(1, 119364, '\P{Is_Canonical_Combining_Class=0000_0}', "");
Expect(0, 119364, '\P{^Is_Canonical_Combining_Class=0000_0}', "");
Error('\p{Is_Ccc=	NOT_Reordered:=}');
Error('\P{Is_Ccc=	NOT_Reordered:=}');
Expect(1, 119365, '\p{Is_Ccc=notreordered}', "");
Expect(0, 119365, '\p{^Is_Ccc=notreordered}', "");
Expect(0, 119365, '\P{Is_Ccc=notreordered}', "");
Expect(1, 119365, '\P{^Is_Ccc=notreordered}', "");
Expect(0, 119364, '\p{Is_Ccc=notreordered}', "");
Expect(1, 119364, '\p{^Is_Ccc=notreordered}', "");
Expect(1, 119364, '\P{Is_Ccc=notreordered}', "");
Expect(0, 119364, '\P{^Is_Ccc=notreordered}', "");
Expect(1, 119365, '\p{Is_Ccc=	not_Reordered}', "");
Expect(0, 119365, '\p{^Is_Ccc=	not_Reordered}', "");
Expect(0, 119365, '\P{Is_Ccc=	not_Reordered}', "");
Expect(1, 119365, '\P{^Is_Ccc=	not_Reordered}', "");
Expect(0, 119364, '\p{Is_Ccc=	not_Reordered}', "");
Expect(1, 119364, '\p{^Is_Ccc=	not_Reordered}', "");
Expect(1, 119364, '\P{Is_Ccc=	not_Reordered}', "");
Expect(0, 119364, '\P{^Is_Ccc=	not_Reordered}', "");
Error('\p{Canonical_Combining_Class=:=__Overlay}');
Error('\P{Canonical_Combining_Class=:=__Overlay}');
Expect(1, 119145, '\p{Canonical_Combining_Class=overlay}', "");
Expect(0, 119145, '\p{^Canonical_Combining_Class=overlay}', "");
Expect(0, 119145, '\P{Canonical_Combining_Class=overlay}', "");
Expect(1, 119145, '\P{^Canonical_Combining_Class=overlay}', "");
Expect(0, 119146, '\p{Canonical_Combining_Class=overlay}', "");
Expect(1, 119146, '\p{^Canonical_Combining_Class=overlay}', "");
Expect(1, 119146, '\P{Canonical_Combining_Class=overlay}', "");
Expect(0, 119146, '\P{^Canonical_Combining_Class=overlay}', "");
Expect(1, 119145, '\p{Canonical_Combining_Class:		Overlay}', "");
Expect(0, 119145, '\p{^Canonical_Combining_Class:		Overlay}', "");
Expect(0, 119145, '\P{Canonical_Combining_Class:		Overlay}', "");
Expect(1, 119145, '\P{^Canonical_Combining_Class:		Overlay}', "");
Expect(0, 119146, '\p{Canonical_Combining_Class:		Overlay}', "");
Expect(1, 119146, '\p{^Canonical_Combining_Class:		Overlay}', "");
Expect(1, 119146, '\P{Canonical_Combining_Class:		Overlay}', "");
Expect(0, 119146, '\P{^Canonical_Combining_Class:		Overlay}', "");
Error('\p{Ccc=/a/_OV}');
Error('\P{Ccc=/a/_OV}');
Expect(1, 119145, '\p{Ccc=ov}', "");
Expect(0, 119145, '\p{^Ccc=ov}', "");
Expect(0, 119145, '\P{Ccc=ov}', "");
Expect(1, 119145, '\P{^Ccc=ov}', "");
Expect(0, 119146, '\p{Ccc=ov}', "");
Expect(1, 119146, '\p{^Ccc=ov}', "");
Expect(1, 119146, '\P{Ccc=ov}', "");
Expect(0, 119146, '\P{^Ccc=ov}', "");
Expect(1, 119145, '\p{Ccc=__ov}', "");
Expect(0, 119145, '\p{^Ccc=__ov}', "");
Expect(0, 119145, '\P{Ccc=__ov}', "");
Expect(1, 119145, '\P{^Ccc=__ov}', "");
Expect(0, 119146, '\p{Ccc=__ov}', "");
Expect(1, 119146, '\p{^Ccc=__ov}', "");
Expect(1, 119146, '\P{Ccc=__ov}', "");
Expect(0, 119146, '\P{^Ccc=__ov}', "");
Error('\p{Is_Canonical_Combining_Class:_/a/00_00_01}');
Error('\P{Is_Canonical_Combining_Class:_/a/00_00_01}');
Expect(1, 119145, '\p{Is_Canonical_Combining_Class=1}', "");
Expect(0, 119145, '\p{^Is_Canonical_Combining_Class=1}', "");
Expect(0, 119145, '\P{Is_Canonical_Combining_Class=1}', "");
Expect(1, 119145, '\P{^Is_Canonical_Combining_Class=1}', "");
Expect(0, 119146, '\p{Is_Canonical_Combining_Class=1}', "");
Expect(1, 119146, '\p{^Is_Canonical_Combining_Class=1}', "");
Expect(1, 119146, '\P{Is_Canonical_Combining_Class=1}', "");
Expect(0, 119146, '\P{^Is_Canonical_Combining_Class=1}', "");
Error('\p{Is_Ccc:	_Overlay:=}');
Error('\P{Is_Ccc:	_Overlay:=}');
Expect(1, 119145, '\p{Is_Ccc=overlay}', "");
Expect(0, 119145, '\p{^Is_Ccc=overlay}', "");
Expect(0, 119145, '\P{Is_Ccc=overlay}', "");
Expect(1, 119145, '\P{^Is_Ccc=overlay}', "");
Expect(0, 119146, '\p{Is_Ccc=overlay}', "");
Expect(1, 119146, '\p{^Is_Ccc=overlay}', "");
Expect(1, 119146, '\P{Is_Ccc=overlay}', "");
Expect(0, 119146, '\P{^Is_Ccc=overlay}', "");
Expect(1, 119145, '\p{Is_Ccc:	_ Overlay}', "");
Expect(0, 119145, '\p{^Is_Ccc:	_ Overlay}', "");
Expect(0, 119145, '\P{Is_Ccc:	_ Overlay}', "");
Expect(1, 119145, '\P{^Is_Ccc:	_ Overlay}', "");
Expect(0, 119146, '\p{Is_Ccc:	_ Overlay}', "");
Expect(1, 119146, '\p{^Is_Ccc:	_ Overlay}', "");
Expect(1, 119146, '\P{Is_Ccc:	_ Overlay}', "");
Expect(0, 119146, '\P{^Is_Ccc:	_ Overlay}', "");
Error('\p{Canonical_Combining_Class=:=	-right}');
Error('\P{Canonical_Combining_Class=:=	-right}');
Expect(1, 119149, '\p{Canonical_Combining_Class=right}', "");
Expect(0, 119149, '\p{^Canonical_Combining_Class=right}', "");
Expect(0, 119149, '\P{Canonical_Combining_Class=right}', "");
Expect(1, 119149, '\P{^Canonical_Combining_Class=right}', "");
Expect(0, 119150, '\p{Canonical_Combining_Class=right}', "");
Expect(1, 119150, '\p{^Canonical_Combining_Class=right}', "");
Expect(1, 119150, '\P{Canonical_Combining_Class=right}', "");
Expect(0, 119150, '\P{^Canonical_Combining_Class=right}', "");
Expect(1, 119149, '\p{Canonical_Combining_Class=_right}', "");
Expect(0, 119149, '\p{^Canonical_Combining_Class=_right}', "");
Expect(0, 119149, '\P{Canonical_Combining_Class=_right}', "");
Expect(1, 119149, '\P{^Canonical_Combining_Class=_right}', "");
Expect(0, 119150, '\p{Canonical_Combining_Class=_right}', "");
Expect(1, 119150, '\p{^Canonical_Combining_Class=_right}', "");
Expect(1, 119150, '\P{Canonical_Combining_Class=_right}', "");
Expect(0, 119150, '\P{^Canonical_Combining_Class=_right}', "");
Error('\p{Ccc=/a/ -R}');
Error('\P{Ccc=/a/ -R}');
Expect(1, 119149, '\p{Ccc=r}', "");
Expect(0, 119149, '\p{^Ccc=r}', "");
Expect(0, 119149, '\P{Ccc=r}', "");
Expect(1, 119149, '\P{^Ccc=r}', "");
Expect(0, 119150, '\p{Ccc=r}', "");
Expect(1, 119150, '\p{^Ccc=r}', "");
Expect(1, 119150, '\P{Ccc=r}', "");
Expect(0, 119150, '\P{^Ccc=r}', "");
Expect(1, 119149, '\p{Ccc= R}', "");
Expect(0, 119149, '\p{^Ccc= R}', "");
Expect(0, 119149, '\P{Ccc= R}', "");
Expect(1, 119149, '\P{^Ccc= R}', "");
Expect(0, 119150, '\p{Ccc= R}', "");
Expect(1, 119150, '\p{^Ccc= R}', "");
Expect(1, 119150, '\P{Ccc= R}', "");
Expect(0, 119150, '\P{^Ccc= R}', "");
Error('\p{Is_Canonical_Combining_Class=-000_002_26:=}');
Error('\P{Is_Canonical_Combining_Class=-000_002_26:=}');
Expect(1, 119149, '\p{Is_Canonical_Combining_Class=+0_0_0_226}', "");
Expect(0, 119149, '\p{^Is_Canonical_Combining_Class=+0_0_0_226}', "");
Expect(0, 119149, '\P{Is_Canonical_Combining_Class=+0_0_0_226}', "");
Expect(1, 119149, '\P{^Is_Canonical_Combining_Class=+0_0_0_226}', "");
Expect(0, 119150, '\p{Is_Canonical_Combining_Class=+0_0_0_226}', "");
Expect(1, 119150, '\p{^Is_Canonical_Combining_Class=+0_0_0_226}', "");
Expect(1, 119150, '\P{Is_Canonical_Combining_Class=+0_0_0_226}', "");
Expect(0, 119150, '\P{^Is_Canonical_Combining_Class=+0_0_0_226}', "");
Error('\p{Is_Ccc=-/a/right}');
Error('\P{Is_Ccc=-/a/right}');
Expect(1, 119149, '\p{Is_Ccc=right}', "");
Expect(0, 119149, '\p{^Is_Ccc=right}', "");
Expect(0, 119149, '\P{Is_Ccc=right}', "");
Expect(1, 119149, '\P{^Is_Ccc=right}', "");
Expect(0, 119150, '\p{Is_Ccc=right}', "");
Expect(1, 119150, '\p{^Is_Ccc=right}', "");
Expect(1, 119150, '\P{Is_Ccc=right}', "");
Expect(0, 119150, '\P{^Is_Ccc=right}', "");
Expect(1, 119149, '\p{Is_Ccc=_RIGHT}', "");
Expect(0, 119149, '\p{^Is_Ccc=_RIGHT}', "");
Expect(0, 119149, '\P{Is_Ccc=_RIGHT}', "");
Expect(1, 119149, '\P{^Is_Ccc=_RIGHT}', "");
Expect(0, 119150, '\p{Is_Ccc=_RIGHT}', "");
Expect(1, 119150, '\p{^Is_Ccc=_RIGHT}', "");
Expect(1, 119150, '\P{Is_Ccc=_RIGHT}', "");
Expect(0, 119150, '\P{^Is_Ccc=_RIGHT}', "");
Error('\p{Canonical_Combining_Class:	:=	virama}');
Error('\P{Canonical_Combining_Class:	:=	virama}');
Expect(1, 71350, '\p{Canonical_Combining_Class=virama}', "");
Expect(0, 71350, '\p{^Canonical_Combining_Class=virama}', "");
Expect(0, 71350, '\P{Canonical_Combining_Class=virama}', "");
Expect(1, 71350, '\P{^Canonical_Combining_Class=virama}', "");
Expect(0, 71351, '\p{Canonical_Combining_Class=virama}', "");
Expect(1, 71351, '\p{^Canonical_Combining_Class=virama}', "");
Expect(1, 71351, '\P{Canonical_Combining_Class=virama}', "");
Expect(0, 71351, '\P{^Canonical_Combining_Class=virama}', "");
Expect(1, 71350, '\p{Canonical_Combining_Class=- virama}', "");
Expect(0, 71350, '\p{^Canonical_Combining_Class=- virama}', "");
Expect(0, 71350, '\P{Canonical_Combining_Class=- virama}', "");
Expect(1, 71350, '\P{^Canonical_Combining_Class=- virama}', "");
Expect(0, 71351, '\p{Canonical_Combining_Class=- virama}', "");
Expect(1, 71351, '\p{^Canonical_Combining_Class=- virama}', "");
Expect(1, 71351, '\P{Canonical_Combining_Class=- virama}', "");
Expect(0, 71351, '\P{^Canonical_Combining_Class=- virama}', "");
Error('\p{Ccc= 	VR/a/}');
Error('\P{Ccc= 	VR/a/}');
Expect(1, 71350, '\p{Ccc=vr}', "");
Expect(0, 71350, '\p{^Ccc=vr}', "");
Expect(0, 71350, '\P{Ccc=vr}', "");
Expect(1, 71350, '\P{^Ccc=vr}', "");
Expect(0, 71351, '\p{Ccc=vr}', "");
Expect(1, 71351, '\p{^Ccc=vr}', "");
Expect(1, 71351, '\P{Ccc=vr}', "");
Expect(0, 71351, '\P{^Ccc=vr}', "");
Expect(1, 71350, '\p{Ccc=-VR}', "");
Expect(0, 71350, '\p{^Ccc=-VR}', "");
Expect(0, 71350, '\P{Ccc=-VR}', "");
Expect(1, 71350, '\P{^Ccc=-VR}', "");
Expect(0, 71351, '\p{Ccc=-VR}', "");
Expect(1, 71351, '\p{^Ccc=-VR}', "");
Expect(1, 71351, '\P{Ccc=-VR}', "");
Expect(0, 71351, '\P{^Ccc=-VR}', "");
Error('\p{Is_Canonical_Combining_Class=-/a/000000_9}');
Error('\P{Is_Canonical_Combining_Class=-/a/000000_9}');
Expect(1, 71350, '\p{Is_Canonical_Combining_Class=9}', "");
Expect(0, 71350, '\p{^Is_Canonical_Combining_Class=9}', "");
Expect(0, 71350, '\P{Is_Canonical_Combining_Class=9}', "");
Expect(1, 71350, '\P{^Is_Canonical_Combining_Class=9}', "");
Expect(0, 71351, '\p{Is_Canonical_Combining_Class=9}', "");
Expect(1, 71351, '\p{^Is_Canonical_Combining_Class=9}', "");
Expect(1, 71351, '\P{Is_Canonical_Combining_Class=9}', "");
Expect(0, 71351, '\P{^Is_Canonical_Combining_Class=9}', "");
Error('\p{Is_Ccc=:=	-Virama}');
Error('\P{Is_Ccc=:=	-Virama}');
Expect(1, 71350, '\p{Is_Ccc=virama}', "");
Expect(0, 71350, '\p{^Is_Ccc=virama}', "");
Expect(0, 71350, '\P{Is_Ccc=virama}', "");
Expect(1, 71350, '\P{^Is_Ccc=virama}', "");
Expect(0, 71351, '\p{Is_Ccc=virama}', "");
Expect(1, 71351, '\p{^Is_Ccc=virama}', "");
Expect(1, 71351, '\P{Is_Ccc=virama}', "");
Expect(0, 71351, '\P{^Is_Ccc=virama}', "");
Expect(1, 71350, '\p{Is_Ccc=_ virama}', "");
Expect(0, 71350, '\p{^Is_Ccc=_ virama}', "");
Expect(0, 71350, '\P{Is_Ccc=_ virama}', "");
Expect(1, 71350, '\P{^Is_Ccc=_ virama}', "");
Expect(0, 71351, '\p{Is_Ccc=_ virama}', "");
Expect(1, 71351, '\p{^Is_Ccc=_ virama}', "");
Expect(1, 71351, '\P{Is_Ccc=_ virama}', "");
Expect(0, 71351, '\P{^Is_Ccc=_ virama}', "");
Error('\p{Decomposition_Type=--Canonical/a/}');
Error('\P{Decomposition_Type=--Canonical/a/}');
Expect(1, 195101, '\p{Decomposition_Type=canonical}', "");
Expect(0, 195101, '\p{^Decomposition_Type=canonical}', "");
Expect(0, 195101, '\P{Decomposition_Type=canonical}', "");
Expect(1, 195101, '\P{^Decomposition_Type=canonical}', "");
Expect(0, 195102, '\p{Decomposition_Type=canonical}', "");
Expect(1, 195102, '\p{^Decomposition_Type=canonical}', "");
Expect(1, 195102, '\P{Decomposition_Type=canonical}', "");
Expect(0, 195102, '\P{^Decomposition_Type=canonical}', "");
Expect(1, 195101, '\p{Decomposition_Type:   -_Canonical}', "");
Expect(0, 195101, '\p{^Decomposition_Type:   -_Canonical}', "");
Expect(0, 195101, '\P{Decomposition_Type:   -_Canonical}', "");
Expect(1, 195101, '\P{^Decomposition_Type:   -_Canonical}', "");
Expect(0, 195102, '\p{Decomposition_Type:   -_Canonical}', "");
Expect(1, 195102, '\p{^Decomposition_Type:   -_Canonical}', "");
Expect(1, 195102, '\P{Decomposition_Type:   -_Canonical}', "");
Expect(0, 195102, '\P{^Decomposition_Type:   -_Canonical}', "");
Error('\p{Dt=-Can/a/}');
Error('\P{Dt=-Can/a/}');
Expect(1, 195101, '\p{Dt=can}', "");
Expect(0, 195101, '\p{^Dt=can}', "");
Expect(0, 195101, '\P{Dt=can}', "");
Expect(1, 195101, '\P{^Dt=can}', "");
Expect(0, 195102, '\p{Dt=can}', "");
Expect(1, 195102, '\p{^Dt=can}', "");
Expect(1, 195102, '\P{Dt=can}', "");
Expect(0, 195102, '\P{^Dt=can}', "");
Expect(1, 195101, '\p{Dt=  Can}', "");
Expect(0, 195101, '\p{^Dt=  Can}', "");
Expect(0, 195101, '\P{Dt=  Can}', "");
Expect(1, 195101, '\P{^Dt=  Can}', "");
Expect(0, 195102, '\p{Dt=  Can}', "");
Expect(1, 195102, '\p{^Dt=  Can}', "");
Expect(1, 195102, '\P{Dt=  Can}', "");
Expect(0, 195102, '\P{^Dt=  Can}', "");
Error('\p{Is_Decomposition_Type=	Canonical:=}');
Error('\P{Is_Decomposition_Type=	Canonical:=}');
Expect(1, 195101, '\p{Is_Decomposition_Type=canonical}', "");
Expect(0, 195101, '\p{^Is_Decomposition_Type=canonical}', "");
Expect(0, 195101, '\P{Is_Decomposition_Type=canonical}', "");
Expect(1, 195101, '\P{^Is_Decomposition_Type=canonical}', "");
Expect(0, 195102, '\p{Is_Decomposition_Type=canonical}', "");
Expect(1, 195102, '\p{^Is_Decomposition_Type=canonical}', "");
Expect(1, 195102, '\P{Is_Decomposition_Type=canonical}', "");
Expect(0, 195102, '\P{^Is_Decomposition_Type=canonical}', "");
Expect(1, 195101, '\p{Is_Decomposition_Type= 	Canonical}', "");
Expect(0, 195101, '\p{^Is_Decomposition_Type= 	Canonical}', "");
Expect(0, 195101, '\P{Is_Decomposition_Type= 	Canonical}', "");
Expect(1, 195101, '\P{^Is_Decomposition_Type= 	Canonical}', "");
Expect(0, 195102, '\p{Is_Decomposition_Type= 	Canonical}', "");
Expect(1, 195102, '\p{^Is_Decomposition_Type= 	Canonical}', "");
Expect(1, 195102, '\P{Is_Decomposition_Type= 	Canonical}', "");
Expect(0, 195102, '\P{^Is_Decomposition_Type= 	Canonical}', "");
Error('\p{Is_Dt=/a/ CAN}');
Error('\P{Is_Dt=/a/ CAN}');
Expect(1, 195101, '\p{Is_Dt:can}', "");
Expect(0, 195101, '\p{^Is_Dt:can}', "");
Expect(0, 195101, '\P{Is_Dt:can}', "");
Expect(1, 195101, '\P{^Is_Dt:can}', "");
Expect(0, 195102, '\p{Is_Dt:can}', "");
Expect(1, 195102, '\p{^Is_Dt:can}', "");
Expect(1, 195102, '\P{Is_Dt:can}', "");
Expect(0, 195102, '\P{^Is_Dt:can}', "");
Expect(1, 195101, '\p{Is_Dt:    _Can}', "");
Expect(0, 195101, '\p{^Is_Dt:    _Can}', "");
Expect(0, 195101, '\P{Is_Dt:    _Can}', "");
Expect(1, 195101, '\P{^Is_Dt:    _Can}', "");
Expect(0, 195102, '\p{Is_Dt:    _Can}', "");
Expect(1, 195102, '\p{^Is_Dt:    _Can}', "");
Expect(1, 195102, '\P{Is_Dt:    _Can}', "");
Expect(0, 195102, '\P{^Is_Dt:    _Can}', "");
Error('\p{Decomposition_Type=:=  COMPAT}');
Error('\P{Decomposition_Type=:=  COMPAT}');
Expect(1, 127560, '\p{Decomposition_Type=compat}', "");
Expect(0, 127560, '\p{^Decomposition_Type=compat}', "");
Expect(0, 127560, '\P{Decomposition_Type=compat}', "");
Expect(1, 127560, '\P{^Decomposition_Type=compat}', "");
Expect(0, 127561, '\p{Decomposition_Type=compat}', "");
Expect(1, 127561, '\p{^Decomposition_Type=compat}', "");
Expect(1, 127561, '\P{Decomposition_Type=compat}', "");
Expect(0, 127561, '\P{^Decomposition_Type=compat}', "");
Expect(1, 127560, '\p{Decomposition_Type=-_Compat}', "");
Expect(0, 127560, '\p{^Decomposition_Type=-_Compat}', "");
Expect(0, 127560, '\P{Decomposition_Type=-_Compat}', "");
Expect(1, 127560, '\P{^Decomposition_Type=-_Compat}', "");
Expect(0, 127561, '\p{Decomposition_Type=-_Compat}', "");
Expect(1, 127561, '\p{^Decomposition_Type=-_Compat}', "");
Expect(1, 127561, '\P{Decomposition_Type=-_Compat}', "");
Expect(0, 127561, '\P{^Decomposition_Type=-_Compat}', "");
Error('\p{Dt: :=COM}');
Error('\P{Dt: :=COM}');
Expect(1, 127560, '\p{Dt=com}', "");
Expect(0, 127560, '\p{^Dt=com}', "");
Expect(0, 127560, '\P{Dt=com}', "");
Expect(1, 127560, '\P{^Dt=com}', "");
Expect(0, 127561, '\p{Dt=com}', "");
Expect(1, 127561, '\p{^Dt=com}', "");
Expect(1, 127561, '\P{Dt=com}', "");
Expect(0, 127561, '\P{^Dt=com}', "");
Expect(1, 127560, '\p{Dt:		 Com}', "");
Expect(0, 127560, '\p{^Dt:		 Com}', "");
Expect(0, 127560, '\P{Dt:		 Com}', "");
Expect(1, 127560, '\P{^Dt:		 Com}', "");
Expect(0, 127561, '\p{Dt:		 Com}', "");
Expect(1, 127561, '\p{^Dt:		 Com}', "");
Expect(1, 127561, '\P{Dt:		 Com}', "");
Expect(0, 127561, '\P{^Dt:		 Com}', "");
Error('\p{Is_Decomposition_Type=/a/ Compat}');
Error('\P{Is_Decomposition_Type=/a/ Compat}');
Expect(1, 127560, '\p{Is_Decomposition_Type=compat}', "");
Expect(0, 127560, '\p{^Is_Decomposition_Type=compat}', "");
Expect(0, 127560, '\P{Is_Decomposition_Type=compat}', "");
Expect(1, 127560, '\P{^Is_Decomposition_Type=compat}', "");
Expect(0, 127561, '\p{Is_Decomposition_Type=compat}', "");
Expect(1, 127561, '\p{^Is_Decomposition_Type=compat}', "");
Expect(1, 127561, '\P{Is_Decomposition_Type=compat}', "");
Expect(0, 127561, '\P{^Is_Decomposition_Type=compat}', "");
Expect(1, 127560, '\p{Is_Decomposition_Type= -Compat}', "");
Expect(0, 127560, '\p{^Is_Decomposition_Type= -Compat}', "");
Expect(0, 127560, '\P{Is_Decomposition_Type= -Compat}', "");
Expect(1, 127560, '\P{^Is_Decomposition_Type= -Compat}', "");
Expect(0, 127561, '\p{Is_Decomposition_Type= -Compat}', "");
Expect(1, 127561, '\p{^Is_Decomposition_Type= -Compat}', "");
Expect(1, 127561, '\P{Is_Decomposition_Type= -Compat}', "");
Expect(0, 127561, '\P{^Is_Decomposition_Type= -Compat}', "");
Error('\p{Is_Dt= :=com}');
Error('\P{Is_Dt= :=com}');
Expect(1, 127560, '\p{Is_Dt=com}', "");
Expect(0, 127560, '\p{^Is_Dt=com}', "");
Expect(0, 127560, '\P{Is_Dt=com}', "");
Expect(1, 127560, '\P{^Is_Dt=com}', "");
Expect(0, 127561, '\p{Is_Dt=com}', "");
Expect(1, 127561, '\p{^Is_Dt=com}', "");
Expect(1, 127561, '\P{Is_Dt=com}', "");
Expect(0, 127561, '\P{^Is_Dt=com}', "");
Expect(1, 127560, '\p{Is_Dt=	 Com}', "");
Expect(0, 127560, '\p{^Is_Dt=	 Com}', "");
Expect(0, 127560, '\P{Is_Dt=	 Com}', "");
Expect(1, 127560, '\P{^Is_Dt=	 Com}', "");
Expect(0, 127561, '\p{Is_Dt=	 Com}', "");
Expect(1, 127561, '\p{^Is_Dt=	 Com}', "");
Expect(1, 127561, '\P{Is_Dt=	 Com}', "");
Expect(0, 127561, '\P{^Is_Dt=	 Com}', "");
Error('\p{Decomposition_Type=_/a/CIRCLE}');
Error('\P{Decomposition_Type=_/a/CIRCLE}');
Expect(1, 127569, '\p{Decomposition_Type=circle}', "");
Expect(0, 127569, '\p{^Decomposition_Type=circle}', "");
Expect(0, 127569, '\P{Decomposition_Type=circle}', "");
Expect(1, 127569, '\P{^Decomposition_Type=circle}', "");
Expect(0, 127570, '\p{Decomposition_Type=circle}', "");
Expect(1, 127570, '\p{^Decomposition_Type=circle}', "");
Expect(1, 127570, '\P{Decomposition_Type=circle}', "");
Expect(0, 127570, '\P{^Decomposition_Type=circle}', "");
Expect(1, 127569, '\p{Decomposition_Type:  	circle}', "");
Expect(0, 127569, '\p{^Decomposition_Type:  	circle}', "");
Expect(0, 127569, '\P{Decomposition_Type:  	circle}', "");
Expect(1, 127569, '\P{^Decomposition_Type:  	circle}', "");
Expect(0, 127570, '\p{Decomposition_Type:  	circle}', "");
Expect(1, 127570, '\p{^Decomposition_Type:  	circle}', "");
Expect(1, 127570, '\P{Decomposition_Type:  	circle}', "");
Expect(0, 127570, '\P{^Decomposition_Type:  	circle}', "");
Error('\p{Dt=:=Enc}');
Error('\P{Dt=:=Enc}');
Expect(1, 127569, '\p{Dt=enc}', "");
Expect(0, 127569, '\p{^Dt=enc}', "");
Expect(0, 127569, '\P{Dt=enc}', "");
Expect(1, 127569, '\P{^Dt=enc}', "");
Expect(0, 127570, '\p{Dt=enc}', "");
Expect(1, 127570, '\p{^Dt=enc}', "");
Expect(1, 127570, '\P{Dt=enc}', "");
Expect(0, 127570, '\P{^Dt=enc}', "");
Expect(1, 127569, '\p{Dt:	 enc}', "");
Expect(0, 127569, '\p{^Dt:	 enc}', "");
Expect(0, 127569, '\P{Dt:	 enc}', "");
Expect(1, 127569, '\P{^Dt:	 enc}', "");
Expect(0, 127570, '\p{Dt:	 enc}', "");
Expect(1, 127570, '\p{^Dt:	 enc}', "");
Expect(1, 127570, '\P{Dt:	 enc}', "");
Expect(0, 127570, '\P{^Dt:	 enc}', "");
Error('\p{Is_Decomposition_Type= /a/Circle}');
Error('\P{Is_Decomposition_Type= /a/Circle}');
Expect(1, 127569, '\p{Is_Decomposition_Type=circle}', "");
Expect(0, 127569, '\p{^Is_Decomposition_Type=circle}', "");
Expect(0, 127569, '\P{Is_Decomposition_Type=circle}', "");
Expect(1, 127569, '\P{^Is_Decomposition_Type=circle}', "");
Expect(0, 127570, '\p{Is_Decomposition_Type=circle}', "");
Expect(1, 127570, '\p{^Is_Decomposition_Type=circle}', "");
Expect(1, 127570, '\P{Is_Decomposition_Type=circle}', "");
Expect(0, 127570, '\P{^Is_Decomposition_Type=circle}', "");
Expect(1, 127569, '\p{Is_Decomposition_Type=-_Circle}', "");
Expect(0, 127569, '\p{^Is_Decomposition_Type=-_Circle}', "");
Expect(0, 127569, '\P{Is_Decomposition_Type=-_Circle}', "");
Expect(1, 127569, '\P{^Is_Decomposition_Type=-_Circle}', "");
Expect(0, 127570, '\p{Is_Decomposition_Type=-_Circle}', "");
Expect(1, 127570, '\p{^Is_Decomposition_Type=-_Circle}', "");
Expect(1, 127570, '\P{Is_Decomposition_Type=-_Circle}', "");
Expect(0, 127570, '\P{^Is_Decomposition_Type=-_Circle}', "");
Error('\p{Is_Dt:/a/	 Enc}');
Error('\P{Is_Dt:/a/	 Enc}');
Expect(1, 127569, '\p{Is_Dt=enc}', "");
Expect(0, 127569, '\p{^Is_Dt=enc}', "");
Expect(0, 127569, '\P{Is_Dt=enc}', "");
Expect(1, 127569, '\P{^Is_Dt=enc}', "");
Expect(0, 127570, '\p{Is_Dt=enc}', "");
Expect(1, 127570, '\p{^Is_Dt=enc}', "");
Expect(1, 127570, '\P{Is_Dt=enc}', "");
Expect(0, 127570, '\P{^Is_Dt=enc}', "");
Expect(1, 127569, '\p{Is_Dt=	enc}', "");
Expect(0, 127569, '\p{^Is_Dt=	enc}', "");
Expect(0, 127569, '\P{Is_Dt=	enc}', "");
Expect(1, 127569, '\P{^Is_Dt=	enc}', "");
Expect(0, 127570, '\p{Is_Dt=	enc}', "");
Expect(1, 127570, '\p{^Is_Dt=	enc}', "");
Expect(1, 127570, '\P{Is_Dt=	enc}', "");
Expect(0, 127570, '\P{^Is_Dt=	enc}', "");
Error('\p{Decomposition_Type=FINAL/a/}');
Error('\P{Decomposition_Type=FINAL/a/}');
Expect(1, 65276, '\p{Decomposition_Type=final}', "");
Expect(0, 65276, '\p{^Decomposition_Type=final}', "");
Expect(0, 65276, '\P{Decomposition_Type=final}', "");
Expect(1, 65276, '\P{^Decomposition_Type=final}', "");
Expect(0, 65277, '\p{Decomposition_Type=final}', "");
Expect(1, 65277, '\p{^Decomposition_Type=final}', "");
Expect(1, 65277, '\P{Decomposition_Type=final}', "");
Expect(0, 65277, '\P{^Decomposition_Type=final}', "");
Expect(1, 65276, '\p{Decomposition_Type=_-Final}', "");
Expect(0, 65276, '\p{^Decomposition_Type=_-Final}', "");
Expect(0, 65276, '\P{Decomposition_Type=_-Final}', "");
Expect(1, 65276, '\P{^Decomposition_Type=_-Final}', "");
Expect(0, 65277, '\p{Decomposition_Type=_-Final}', "");
Expect(1, 65277, '\p{^Decomposition_Type=_-Final}', "");
Expect(1, 65277, '\P{Decomposition_Type=_-Final}', "");
Expect(0, 65277, '\P{^Decomposition_Type=_-Final}', "");
Error('\p{Dt=:=-	Fin}');
Error('\P{Dt=:=-	Fin}');
Expect(1, 65276, '\p{Dt=fin}', "");
Expect(0, 65276, '\p{^Dt=fin}', "");
Expect(0, 65276, '\P{Dt=fin}', "");
Expect(1, 65276, '\P{^Dt=fin}', "");
Expect(0, 65277, '\p{Dt=fin}', "");
Expect(1, 65277, '\p{^Dt=fin}', "");
Expect(1, 65277, '\P{Dt=fin}', "");
Expect(0, 65277, '\P{^Dt=fin}', "");
Expect(1, 65276, '\p{Dt:	_-fin}', "");
Expect(0, 65276, '\p{^Dt:	_-fin}', "");
Expect(0, 65276, '\P{Dt:	_-fin}', "");
Expect(1, 65276, '\P{^Dt:	_-fin}', "");
Expect(0, 65277, '\p{Dt:	_-fin}', "");
Expect(1, 65277, '\p{^Dt:	_-fin}', "");
Expect(1, 65277, '\P{Dt:	_-fin}', "");
Expect(0, 65277, '\P{^Dt:	_-fin}', "");
Error('\p{Is_Decomposition_Type=:=	-Final}');
Error('\P{Is_Decomposition_Type=:=	-Final}');
Expect(1, 65276, '\p{Is_Decomposition_Type=final}', "");
Expect(0, 65276, '\p{^Is_Decomposition_Type=final}', "");
Expect(0, 65276, '\P{Is_Decomposition_Type=final}', "");
Expect(1, 65276, '\P{^Is_Decomposition_Type=final}', "");
Expect(0, 65277, '\p{Is_Decomposition_Type=final}', "");
Expect(1, 65277, '\p{^Is_Decomposition_Type=final}', "");
Expect(1, 65277, '\P{Is_Decomposition_Type=final}', "");
Expect(0, 65277, '\P{^Is_Decomposition_Type=final}', "");
Expect(1, 65276, '\p{Is_Decomposition_Type=_-Final}', "");
Expect(0, 65276, '\p{^Is_Decomposition_Type=_-Final}', "");
Expect(0, 65276, '\P{Is_Decomposition_Type=_-Final}', "");
Expect(1, 65276, '\P{^Is_Decomposition_Type=_-Final}', "");
Expect(0, 65277, '\p{Is_Decomposition_Type=_-Final}', "");
Expect(1, 65277, '\p{^Is_Decomposition_Type=_-Final}', "");
Expect(1, 65277, '\P{Is_Decomposition_Type=_-Final}', "");
Expect(0, 65277, '\P{^Is_Decomposition_Type=_-Final}', "");
Error('\p{Is_Dt=_Fin/a/}');
Error('\P{Is_Dt=_Fin/a/}');
Expect(1, 65276, '\p{Is_Dt=fin}', "");
Expect(0, 65276, '\p{^Is_Dt=fin}', "");
Expect(0, 65276, '\P{Is_Dt=fin}', "");
Expect(1, 65276, '\P{^Is_Dt=fin}', "");
Expect(0, 65277, '\p{Is_Dt=fin}', "");
Expect(1, 65277, '\p{^Is_Dt=fin}', "");
Expect(1, 65277, '\P{Is_Dt=fin}', "");
Expect(0, 65277, '\P{^Is_Dt=fin}', "");
Expect(1, 65276, '\p{Is_Dt=	 fin}', "");
Expect(0, 65276, '\p{^Is_Dt=	 fin}', "");
Expect(0, 65276, '\P{Is_Dt=	 fin}', "");
Expect(1, 65276, '\P{^Is_Dt=	 fin}', "");
Expect(0, 65277, '\p{Is_Dt=	 fin}', "");
Expect(1, 65277, '\p{^Is_Dt=	 fin}', "");
Expect(1, 65277, '\P{Is_Dt=	 fin}', "");
Expect(0, 65277, '\P{^Is_Dt=	 fin}', "");
Error('\p{Decomposition_Type=/a/ Font}');
Error('\P{Decomposition_Type=/a/ Font}');
Expect(1, 126651, '\p{Decomposition_Type=font}', "");
Expect(0, 126651, '\p{^Decomposition_Type=font}', "");
Expect(0, 126651, '\P{Decomposition_Type=font}', "");
Expect(1, 126651, '\P{^Decomposition_Type=font}', "");
Expect(0, 126652, '\p{Decomposition_Type=font}', "");
Expect(1, 126652, '\p{^Decomposition_Type=font}', "");
Expect(1, 126652, '\P{Decomposition_Type=font}', "");
Expect(0, 126652, '\P{^Decomposition_Type=font}', "");
Expect(1, 126651, '\p{Decomposition_Type=  font}', "");
Expect(0, 126651, '\p{^Decomposition_Type=  font}', "");
Expect(0, 126651, '\P{Decomposition_Type=  font}', "");
Expect(1, 126651, '\P{^Decomposition_Type=  font}', "");
Expect(0, 126652, '\p{Decomposition_Type=  font}', "");
Expect(1, 126652, '\p{^Decomposition_Type=  font}', "");
Expect(1, 126652, '\P{Decomposition_Type=  font}', "");
Expect(0, 126652, '\P{^Decomposition_Type=  font}', "");
Error('\p{Dt=:=font}');
Error('\P{Dt=:=font}');
Expect(1, 126651, '\p{Dt=font}', "");
Expect(0, 126651, '\p{^Dt=font}', "");
Expect(0, 126651, '\P{Dt=font}', "");
Expect(1, 126651, '\P{^Dt=font}', "");
Expect(0, 126652, '\p{Dt=font}', "");
Expect(1, 126652, '\p{^Dt=font}', "");
Expect(1, 126652, '\P{Dt=font}', "");
Expect(0, 126652, '\P{^Dt=font}', "");
Expect(1, 126651, '\p{Dt=_-Font}', "");
Expect(0, 126651, '\p{^Dt=_-Font}', "");
Expect(0, 126651, '\P{Dt=_-Font}', "");
Expect(1, 126651, '\P{^Dt=_-Font}', "");
Expect(0, 126652, '\p{Dt=_-Font}', "");
Expect(1, 126652, '\p{^Dt=_-Font}', "");
Expect(1, 126652, '\P{Dt=_-Font}', "");
Expect(0, 126652, '\P{^Dt=_-Font}', "");
Error('\p{Is_Decomposition_Type=/a/ 	FONT}');
Error('\P{Is_Decomposition_Type=/a/ 	FONT}');
Expect(1, 126651, '\p{Is_Decomposition_Type=font}', "");
Expect(0, 126651, '\p{^Is_Decomposition_Type=font}', "");
Expect(0, 126651, '\P{Is_Decomposition_Type=font}', "");
Expect(1, 126651, '\P{^Is_Decomposition_Type=font}', "");
Expect(0, 126652, '\p{Is_Decomposition_Type=font}', "");
Expect(1, 126652, '\p{^Is_Decomposition_Type=font}', "");
Expect(1, 126652, '\P{Is_Decomposition_Type=font}', "");
Expect(0, 126652, '\P{^Is_Decomposition_Type=font}', "");
Expect(1, 126651, '\p{Is_Decomposition_Type=_-FONT}', "");
Expect(0, 126651, '\p{^Is_Decomposition_Type=_-FONT}', "");
Expect(0, 126651, '\P{Is_Decomposition_Type=_-FONT}', "");
Expect(1, 126651, '\P{^Is_Decomposition_Type=_-FONT}', "");
Expect(0, 126652, '\p{Is_Decomposition_Type=_-FONT}', "");
Expect(1, 126652, '\p{^Is_Decomposition_Type=_-FONT}', "");
Expect(1, 126652, '\P{Is_Decomposition_Type=_-FONT}', "");
Expect(0, 126652, '\P{^Is_Decomposition_Type=_-FONT}', "");
Error('\p{Is_Dt=_	Font:=}');
Error('\P{Is_Dt=_	Font:=}');
Expect(1, 126651, '\p{Is_Dt=font}', "");
Expect(0, 126651, '\p{^Is_Dt=font}', "");
Expect(0, 126651, '\P{Is_Dt=font}', "");
Expect(1, 126651, '\P{^Is_Dt=font}', "");
Expect(0, 126652, '\p{Is_Dt=font}', "");
Expect(1, 126652, '\p{^Is_Dt=font}', "");
Expect(1, 126652, '\P{Is_Dt=font}', "");
Expect(0, 126652, '\P{^Is_Dt=font}', "");
Expect(1, 126651, '\p{Is_Dt=__FONT}', "");
Expect(0, 126651, '\p{^Is_Dt=__FONT}', "");
Expect(0, 126651, '\P{Is_Dt=__FONT}', "");
Expect(1, 126651, '\P{^Is_Dt=__FONT}', "");
Expect(0, 126652, '\p{Is_Dt=__FONT}', "");
Expect(1, 126652, '\p{^Is_Dt=__FONT}', "");
Expect(1, 126652, '\P{Is_Dt=__FONT}', "");
Expect(0, 126652, '\P{^Is_Dt=__FONT}', "");
Error('\p{Decomposition_Type=/a/		Fraction}');
Error('\P{Decomposition_Type=/a/		Fraction}');
Expect(1, 8585, '\p{Decomposition_Type=fraction}', "");
Expect(0, 8585, '\p{^Decomposition_Type=fraction}', "");
Expect(0, 8585, '\P{Decomposition_Type=fraction}', "");
Expect(1, 8585, '\P{^Decomposition_Type=fraction}', "");
Expect(0, 8586, '\p{Decomposition_Type=fraction}', "");
Expect(1, 8586, '\p{^Decomposition_Type=fraction}', "");
Expect(1, 8586, '\P{Decomposition_Type=fraction}', "");
Expect(0, 8586, '\P{^Decomposition_Type=fraction}', "");
Expect(1, 8585, '\p{Decomposition_Type=	FRACTION}', "");
Expect(0, 8585, '\p{^Decomposition_Type=	FRACTION}', "");
Expect(0, 8585, '\P{Decomposition_Type=	FRACTION}', "");
Expect(1, 8585, '\P{^Decomposition_Type=	FRACTION}', "");
Expect(0, 8586, '\p{Decomposition_Type=	FRACTION}', "");
Expect(1, 8586, '\p{^Decomposition_Type=	FRACTION}', "");
Expect(1, 8586, '\P{Decomposition_Type=	FRACTION}', "");
Expect(0, 8586, '\P{^Decomposition_Type=	FRACTION}', "");
Error('\p{Dt=:=- FRA}');
Error('\P{Dt=:=- FRA}');
Expect(1, 8585, '\p{Dt=fra}', "");
Expect(0, 8585, '\p{^Dt=fra}', "");
Expect(0, 8585, '\P{Dt=fra}', "");
Expect(1, 8585, '\P{^Dt=fra}', "");
Expect(0, 8586, '\p{Dt=fra}', "");
Expect(1, 8586, '\p{^Dt=fra}', "");
Expect(1, 8586, '\P{Dt=fra}', "");
Expect(0, 8586, '\P{^Dt=fra}', "");
Expect(1, 8585, '\p{Dt=__fra}', "");
Expect(0, 8585, '\p{^Dt=__fra}', "");
Expect(0, 8585, '\P{Dt=__fra}', "");
Expect(1, 8585, '\P{^Dt=__fra}', "");
Expect(0, 8586, '\p{Dt=__fra}', "");
Expect(1, 8586, '\p{^Dt=__fra}', "");
Expect(1, 8586, '\P{Dt=__fra}', "");
Expect(0, 8586, '\P{^Dt=__fra}', "");
Error('\p{Is_Decomposition_Type=	:=fraction}');
Error('\P{Is_Decomposition_Type=	:=fraction}');
Expect(1, 8585, '\p{Is_Decomposition_Type:fraction}', "");
Expect(0, 8585, '\p{^Is_Decomposition_Type:fraction}', "");
Expect(0, 8585, '\P{Is_Decomposition_Type:fraction}', "");
Expect(1, 8585, '\P{^Is_Decomposition_Type:fraction}', "");
Expect(0, 8586, '\p{Is_Decomposition_Type:fraction}', "");
Expect(1, 8586, '\p{^Is_Decomposition_Type:fraction}', "");
Expect(1, 8586, '\P{Is_Decomposition_Type:fraction}', "");
Expect(0, 8586, '\P{^Is_Decomposition_Type:fraction}', "");
Expect(1, 8585, '\p{Is_Decomposition_Type=_	Fraction}', "");
Expect(0, 8585, '\p{^Is_Decomposition_Type=_	Fraction}', "");
Expect(0, 8585, '\P{Is_Decomposition_Type=_	Fraction}', "");
Expect(1, 8585, '\P{^Is_Decomposition_Type=_	Fraction}', "");
Expect(0, 8586, '\p{Is_Decomposition_Type=_	Fraction}', "");
Expect(1, 8586, '\p{^Is_Decomposition_Type=_	Fraction}', "");
Expect(1, 8586, '\P{Is_Decomposition_Type=_	Fraction}', "");
Expect(0, 8586, '\P{^Is_Decomposition_Type=_	Fraction}', "");
Error('\p{Is_Dt=:=		FRA}');
Error('\P{Is_Dt=:=		FRA}');
Expect(1, 8585, '\p{Is_Dt=fra}', "");
Expect(0, 8585, '\p{^Is_Dt=fra}', "");
Expect(0, 8585, '\P{Is_Dt=fra}', "");
Expect(1, 8585, '\P{^Is_Dt=fra}', "");
Expect(0, 8586, '\p{Is_Dt=fra}', "");
Expect(1, 8586, '\p{^Is_Dt=fra}', "");
Expect(1, 8586, '\P{Is_Dt=fra}', "");
Expect(0, 8586, '\P{^Is_Dt=fra}', "");
Expect(1, 8585, '\p{Is_Dt=_ FRA}', "");
Expect(0, 8585, '\p{^Is_Dt=_ FRA}', "");
Expect(0, 8585, '\P{Is_Dt=_ FRA}', "");
Expect(1, 8585, '\P{^Is_Dt=_ FRA}', "");
Expect(0, 8586, '\p{Is_Dt=_ FRA}', "");
Expect(1, 8586, '\p{^Is_Dt=_ FRA}', "");
Expect(1, 8586, '\P{Is_Dt=_ FRA}', "");
Expect(0, 8586, '\P{^Is_Dt=_ FRA}', "");
Error('\p{Decomposition_Type=:=_INITIAL}');
Error('\P{Decomposition_Type=:=_INITIAL}');
Expect(1, 65267, '\p{Decomposition_Type:   initial}', "");
Expect(0, 65267, '\p{^Decomposition_Type:   initial}', "");
Expect(0, 65267, '\P{Decomposition_Type:   initial}', "");
Expect(1, 65267, '\P{^Decomposition_Type:   initial}', "");
Expect(0, 65268, '\p{Decomposition_Type:   initial}', "");
Expect(1, 65268, '\p{^Decomposition_Type:   initial}', "");
Expect(1, 65268, '\P{Decomposition_Type:   initial}', "");
Expect(0, 65268, '\P{^Decomposition_Type:   initial}', "");
Expect(1, 65267, '\p{Decomposition_Type=	_INITIAL}', "");
Expect(0, 65267, '\p{^Decomposition_Type=	_INITIAL}', "");
Expect(0, 65267, '\P{Decomposition_Type=	_INITIAL}', "");
Expect(1, 65267, '\P{^Decomposition_Type=	_INITIAL}', "");
Expect(0, 65268, '\p{Decomposition_Type=	_INITIAL}', "");
Expect(1, 65268, '\p{^Decomposition_Type=	_INITIAL}', "");
Expect(1, 65268, '\P{Decomposition_Type=	_INITIAL}', "");
Expect(0, 65268, '\P{^Decomposition_Type=	_INITIAL}', "");
Error('\p{Dt=/a/	INIT}');
Error('\P{Dt=/a/	INIT}');
Expect(1, 65267, '\p{Dt=init}', "");
Expect(0, 65267, '\p{^Dt=init}', "");
Expect(0, 65267, '\P{Dt=init}', "");
Expect(1, 65267, '\P{^Dt=init}', "");
Expect(0, 65268, '\p{Dt=init}', "");
Expect(1, 65268, '\p{^Dt=init}', "");
Expect(1, 65268, '\P{Dt=init}', "");
Expect(0, 65268, '\P{^Dt=init}', "");
Expect(1, 65267, '\p{Dt=		Init}', "");
Expect(0, 65267, '\p{^Dt=		Init}', "");
Expect(0, 65267, '\P{Dt=		Init}', "");
Expect(1, 65267, '\P{^Dt=		Init}', "");
Expect(0, 65268, '\p{Dt=		Init}', "");
Expect(1, 65268, '\p{^Dt=		Init}', "");
Expect(1, 65268, '\P{Dt=		Init}', "");
Expect(0, 65268, '\P{^Dt=		Init}', "");
Error('\p{Is_Decomposition_Type=_INITIAL/a/}');
Error('\P{Is_Decomposition_Type=_INITIAL/a/}');
Expect(1, 65267, '\p{Is_Decomposition_Type=initial}', "");
Expect(0, 65267, '\p{^Is_Decomposition_Type=initial}', "");
Expect(0, 65267, '\P{Is_Decomposition_Type=initial}', "");
Expect(1, 65267, '\P{^Is_Decomposition_Type=initial}', "");
Expect(0, 65268, '\p{Is_Decomposition_Type=initial}', "");
Expect(1, 65268, '\p{^Is_Decomposition_Type=initial}', "");
Expect(1, 65268, '\P{Is_Decomposition_Type=initial}', "");
Expect(0, 65268, '\P{^Is_Decomposition_Type=initial}', "");
Expect(1, 65267, '\p{Is_Decomposition_Type=--initial}', "");
Expect(0, 65267, '\p{^Is_Decomposition_Type=--initial}', "");
Expect(0, 65267, '\P{Is_Decomposition_Type=--initial}', "");
Expect(1, 65267, '\P{^Is_Decomposition_Type=--initial}', "");
Expect(0, 65268, '\p{Is_Decomposition_Type=--initial}', "");
Expect(1, 65268, '\p{^Is_Decomposition_Type=--initial}', "");
Expect(1, 65268, '\P{Is_Decomposition_Type=--initial}', "");
Expect(0, 65268, '\P{^Is_Decomposition_Type=--initial}', "");
Error('\p{Is_Dt= Init:=}');
Error('\P{Is_Dt= Init:=}');
Expect(1, 65267, '\p{Is_Dt=init}', "");
Expect(0, 65267, '\p{^Is_Dt=init}', "");
Expect(0, 65267, '\P{Is_Dt=init}', "");
Expect(1, 65267, '\P{^Is_Dt=init}', "");
Expect(0, 65268, '\p{Is_Dt=init}', "");
Expect(1, 65268, '\p{^Is_Dt=init}', "");
Expect(1, 65268, '\P{Is_Dt=init}', "");
Expect(0, 65268, '\P{^Is_Dt=init}', "");
Expect(1, 65267, '\p{Is_Dt=_ INIT}', "");
Expect(0, 65267, '\p{^Is_Dt=_ INIT}', "");
Expect(0, 65267, '\P{Is_Dt=_ INIT}', "");
Expect(1, 65267, '\P{^Is_Dt=_ INIT}', "");
Expect(0, 65268, '\p{Is_Dt=_ INIT}', "");
Expect(1, 65268, '\p{^Is_Dt=_ INIT}', "");
Expect(1, 65268, '\P{Is_Dt=_ INIT}', "");
Expect(0, 65268, '\P{^Is_Dt=_ INIT}', "");
Error('\p{Decomposition_Type=:=- Isolated}');
Error('\P{Decomposition_Type=:=- Isolated}');
Expect(1, 65275, '\p{Decomposition_Type:   isolated}', "");
Expect(0, 65275, '\p{^Decomposition_Type:   isolated}', "");
Expect(0, 65275, '\P{Decomposition_Type:   isolated}', "");
Expect(1, 65275, '\P{^Decomposition_Type:   isolated}', "");
Expect(0, 65276, '\p{Decomposition_Type:   isolated}', "");
Expect(1, 65276, '\p{^Decomposition_Type:   isolated}', "");
Expect(1, 65276, '\P{Decomposition_Type:   isolated}', "");
Expect(0, 65276, '\P{^Decomposition_Type:   isolated}', "");
Expect(1, 65275, '\p{Decomposition_Type=	_ISOLATED}', "");
Expect(0, 65275, '\p{^Decomposition_Type=	_ISOLATED}', "");
Expect(0, 65275, '\P{Decomposition_Type=	_ISOLATED}', "");
Expect(1, 65275, '\P{^Decomposition_Type=	_ISOLATED}', "");
Expect(0, 65276, '\p{Decomposition_Type=	_ISOLATED}', "");
Expect(1, 65276, '\p{^Decomposition_Type=	_ISOLATED}', "");
Expect(1, 65276, '\P{Decomposition_Type=	_ISOLATED}', "");
Expect(0, 65276, '\P{^Decomposition_Type=	_ISOLATED}', "");
Error('\p{Dt= :=iso}');
Error('\P{Dt= :=iso}');
Expect(1, 65275, '\p{Dt=iso}', "");
Expect(0, 65275, '\p{^Dt=iso}', "");
Expect(0, 65275, '\P{Dt=iso}', "");
Expect(1, 65275, '\P{^Dt=iso}', "");
Expect(0, 65276, '\p{Dt=iso}', "");
Expect(1, 65276, '\p{^Dt=iso}', "");
Expect(1, 65276, '\P{Dt=iso}', "");
Expect(0, 65276, '\P{^Dt=iso}', "");
Expect(1, 65275, '\p{Dt: iso}', "");
Expect(0, 65275, '\p{^Dt: iso}', "");
Expect(0, 65275, '\P{Dt: iso}', "");
Expect(1, 65275, '\P{^Dt: iso}', "");
Expect(0, 65276, '\p{Dt: iso}', "");
Expect(1, 65276, '\p{^Dt: iso}', "");
Expect(1, 65276, '\P{Dt: iso}', "");
Expect(0, 65276, '\P{^Dt: iso}', "");
Error('\p{Is_Decomposition_Type:   _ISOLATED/a/}');
Error('\P{Is_Decomposition_Type:   _ISOLATED/a/}');
Expect(1, 65275, '\p{Is_Decomposition_Type=isolated}', "");
Expect(0, 65275, '\p{^Is_Decomposition_Type=isolated}', "");
Expect(0, 65275, '\P{Is_Decomposition_Type=isolated}', "");
Expect(1, 65275, '\P{^Is_Decomposition_Type=isolated}', "");
Expect(0, 65276, '\p{Is_Decomposition_Type=isolated}', "");
Expect(1, 65276, '\p{^Is_Decomposition_Type=isolated}', "");
Expect(1, 65276, '\P{Is_Decomposition_Type=isolated}', "");
Expect(0, 65276, '\P{^Is_Decomposition_Type=isolated}', "");
Expect(1, 65275, '\p{Is_Decomposition_Type= _Isolated}', "");
Expect(0, 65275, '\p{^Is_Decomposition_Type= _Isolated}', "");
Expect(0, 65275, '\P{Is_Decomposition_Type= _Isolated}', "");
Expect(1, 65275, '\P{^Is_Decomposition_Type= _Isolated}', "");
Expect(0, 65276, '\p{Is_Decomposition_Type= _Isolated}', "");
Expect(1, 65276, '\p{^Is_Decomposition_Type= _Isolated}', "");
Expect(1, 65276, '\P{Is_Decomposition_Type= _Isolated}', "");
Expect(0, 65276, '\P{^Is_Decomposition_Type= _Isolated}', "");
Error('\p{Is_Dt=:=_	iso}');
Error('\P{Is_Dt=:=_	iso}');
Expect(1, 65275, '\p{Is_Dt=iso}', "");
Expect(0, 65275, '\p{^Is_Dt=iso}', "");
Expect(0, 65275, '\P{Is_Dt=iso}', "");
Expect(1, 65275, '\P{^Is_Dt=iso}', "");
Expect(0, 65276, '\p{Is_Dt=iso}', "");
Expect(1, 65276, '\p{^Is_Dt=iso}', "");
Expect(1, 65276, '\P{Is_Dt=iso}', "");
Expect(0, 65276, '\P{^Is_Dt=iso}', "");
Expect(1, 65275, '\p{Is_Dt=__Iso}', "");
Expect(0, 65275, '\p{^Is_Dt=__Iso}', "");
Expect(0, 65275, '\P{Is_Dt=__Iso}', "");
Expect(1, 65275, '\P{^Is_Dt=__Iso}', "");
Expect(0, 65276, '\p{Is_Dt=__Iso}', "");
Expect(1, 65276, '\p{^Is_Dt=__Iso}', "");
Expect(1, 65276, '\P{Is_Dt=__Iso}', "");
Expect(0, 65276, '\P{^Is_Dt=__Iso}', "");
Error('\p{Decomposition_Type=/a/		Medial}');
Error('\P{Decomposition_Type=/a/		Medial}');
Expect(1, 65268, '\p{Decomposition_Type=medial}', "");
Expect(0, 65268, '\p{^Decomposition_Type=medial}', "");
Expect(0, 65268, '\P{Decomposition_Type=medial}', "");
Expect(1, 65268, '\P{^Decomposition_Type=medial}', "");
Expect(0, 65269, '\p{Decomposition_Type=medial}', "");
Expect(1, 65269, '\p{^Decomposition_Type=medial}', "");
Expect(1, 65269, '\P{Decomposition_Type=medial}', "");
Expect(0, 65269, '\P{^Decomposition_Type=medial}', "");
Expect(1, 65268, '\p{Decomposition_Type= _Medial}', "");
Expect(0, 65268, '\p{^Decomposition_Type= _Medial}', "");
Expect(0, 65268, '\P{Decomposition_Type= _Medial}', "");
Expect(1, 65268, '\P{^Decomposition_Type= _Medial}', "");
Expect(0, 65269, '\p{Decomposition_Type= _Medial}', "");
Expect(1, 65269, '\p{^Decomposition_Type= _Medial}', "");
Expect(1, 65269, '\P{Decomposition_Type= _Medial}', "");
Expect(0, 65269, '\P{^Decomposition_Type= _Medial}', "");
Error('\p{Dt=-:=MED}');
Error('\P{Dt=-:=MED}');
Expect(1, 65268, '\p{Dt=med}', "");
Expect(0, 65268, '\p{^Dt=med}', "");
Expect(0, 65268, '\P{Dt=med}', "");
Expect(1, 65268, '\P{^Dt=med}', "");
Expect(0, 65269, '\p{Dt=med}', "");
Expect(1, 65269, '\p{^Dt=med}', "");
Expect(1, 65269, '\P{Dt=med}', "");
Expect(0, 65269, '\P{^Dt=med}', "");
Expect(1, 65268, '\p{Dt=		Med}', "");
Expect(0, 65268, '\p{^Dt=		Med}', "");
Expect(0, 65268, '\P{Dt=		Med}', "");
Expect(1, 65268, '\P{^Dt=		Med}', "");
Expect(0, 65269, '\p{Dt=		Med}', "");
Expect(1, 65269, '\p{^Dt=		Med}', "");
Expect(1, 65269, '\P{Dt=		Med}', "");
Expect(0, 65269, '\P{^Dt=		Med}', "");
Error('\p{Is_Decomposition_Type=-	Medial:=}');
Error('\P{Is_Decomposition_Type=-	Medial:=}');
Expect(1, 65268, '\p{Is_Decomposition_Type=medial}', "");
Expect(0, 65268, '\p{^Is_Decomposition_Type=medial}', "");
Expect(0, 65268, '\P{Is_Decomposition_Type=medial}', "");
Expect(1, 65268, '\P{^Is_Decomposition_Type=medial}', "");
Expect(0, 65269, '\p{Is_Decomposition_Type=medial}', "");
Expect(1, 65269, '\p{^Is_Decomposition_Type=medial}', "");
Expect(1, 65269, '\P{Is_Decomposition_Type=medial}', "");
Expect(0, 65269, '\P{^Is_Decomposition_Type=medial}', "");
Expect(1, 65268, '\p{Is_Decomposition_Type=-medial}', "");
Expect(0, 65268, '\p{^Is_Decomposition_Type=-medial}', "");
Expect(0, 65268, '\P{Is_Decomposition_Type=-medial}', "");
Expect(1, 65268, '\P{^Is_Decomposition_Type=-medial}', "");
Expect(0, 65269, '\p{Is_Decomposition_Type=-medial}', "");
Expect(1, 65269, '\p{^Is_Decomposition_Type=-medial}', "");
Expect(1, 65269, '\P{Is_Decomposition_Type=-medial}', "");
Expect(0, 65269, '\P{^Is_Decomposition_Type=-medial}', "");
Error('\p{Is_Dt=:= MED}');
Error('\P{Is_Dt=:= MED}');
Expect(1, 65268, '\p{Is_Dt=med}', "");
Expect(0, 65268, '\p{^Is_Dt=med}', "");
Expect(0, 65268, '\P{Is_Dt=med}', "");
Expect(1, 65268, '\P{^Is_Dt=med}', "");
Expect(0, 65269, '\p{Is_Dt=med}', "");
Expect(1, 65269, '\p{^Is_Dt=med}', "");
Expect(1, 65269, '\P{Is_Dt=med}', "");
Expect(0, 65269, '\P{^Is_Dt=med}', "");
Expect(1, 65268, '\p{Is_Dt= Med}', "");
Expect(0, 65268, '\p{^Is_Dt= Med}', "");
Expect(0, 65268, '\P{Is_Dt= Med}', "");
Expect(1, 65268, '\P{^Is_Dt= Med}', "");
Expect(0, 65269, '\p{Is_Dt= Med}', "");
Expect(1, 65269, '\p{^Is_Dt= Med}', "");
Expect(1, 65269, '\P{Is_Dt= Med}', "");
Expect(0, 65269, '\P{^Is_Dt= Med}', "");
Error('\p{Decomposition_Type=_:=Narrow}');
Error('\P{Decomposition_Type=_:=Narrow}');
Expect(1, 65518, '\p{Decomposition_Type:narrow}', "");
Expect(0, 65518, '\p{^Decomposition_Type:narrow}', "");
Expect(0, 65518, '\P{Decomposition_Type:narrow}', "");
Expect(1, 65518, '\P{^Decomposition_Type:narrow}', "");
Expect(0, 65519, '\p{Decomposition_Type:narrow}', "");
Expect(1, 65519, '\p{^Decomposition_Type:narrow}', "");
Expect(1, 65519, '\P{Decomposition_Type:narrow}', "");
Expect(0, 65519, '\P{^Decomposition_Type:narrow}', "");
Expect(1, 65518, '\p{Decomposition_Type=-_Narrow}', "");
Expect(0, 65518, '\p{^Decomposition_Type=-_Narrow}', "");
Expect(0, 65518, '\P{Decomposition_Type=-_Narrow}', "");
Expect(1, 65518, '\P{^Decomposition_Type=-_Narrow}', "");
Expect(0, 65519, '\p{Decomposition_Type=-_Narrow}', "");
Expect(1, 65519, '\p{^Decomposition_Type=-_Narrow}', "");
Expect(1, 65519, '\P{Decomposition_Type=-_Narrow}', "");
Expect(0, 65519, '\P{^Decomposition_Type=-_Narrow}', "");
Error('\p{Dt=_:=NAR}');
Error('\P{Dt=_:=NAR}');
Expect(1, 65518, '\p{Dt:	nar}', "");
Expect(0, 65518, '\p{^Dt:	nar}', "");
Expect(0, 65518, '\P{Dt:	nar}', "");
Expect(1, 65518, '\P{^Dt:	nar}', "");
Expect(0, 65519, '\p{Dt:	nar}', "");
Expect(1, 65519, '\p{^Dt:	nar}', "");
Expect(1, 65519, '\P{Dt:	nar}', "");
Expect(0, 65519, '\P{^Dt:	nar}', "");
Expect(1, 65518, '\p{Dt=-	Nar}', "");
Expect(0, 65518, '\p{^Dt=-	Nar}', "");
Expect(0, 65518, '\P{Dt=-	Nar}', "");
Expect(1, 65518, '\P{^Dt=-	Nar}', "");
Expect(0, 65519, '\p{Dt=-	Nar}', "");
Expect(1, 65519, '\p{^Dt=-	Nar}', "");
Expect(1, 65519, '\P{Dt=-	Nar}', "");
Expect(0, 65519, '\P{^Dt=-	Nar}', "");
Error('\p{Is_Decomposition_Type:    :=Narrow}');
Error('\P{Is_Decomposition_Type:    :=Narrow}');
Expect(1, 65518, '\p{Is_Decomposition_Type=narrow}', "");
Expect(0, 65518, '\p{^Is_Decomposition_Type=narrow}', "");
Expect(0, 65518, '\P{Is_Decomposition_Type=narrow}', "");
Expect(1, 65518, '\P{^Is_Decomposition_Type=narrow}', "");
Expect(0, 65519, '\p{Is_Decomposition_Type=narrow}', "");
Expect(1, 65519, '\p{^Is_Decomposition_Type=narrow}', "");
Expect(1, 65519, '\P{Is_Decomposition_Type=narrow}', "");
Expect(0, 65519, '\P{^Is_Decomposition_Type=narrow}', "");
Expect(1, 65518, '\p{Is_Decomposition_Type=--Narrow}', "");
Expect(0, 65518, '\p{^Is_Decomposition_Type=--Narrow}', "");
Expect(0, 65518, '\P{Is_Decomposition_Type=--Narrow}', "");
Expect(1, 65518, '\P{^Is_Decomposition_Type=--Narrow}', "");
Expect(0, 65519, '\p{Is_Decomposition_Type=--Narrow}', "");
Expect(1, 65519, '\p{^Is_Decomposition_Type=--Narrow}', "");
Expect(1, 65519, '\P{Is_Decomposition_Type=--Narrow}', "");
Expect(0, 65519, '\P{^Is_Decomposition_Type=--Narrow}', "");
Error('\p{Is_Dt=:=	Nar}');
Error('\P{Is_Dt=:=	Nar}');
Expect(1, 65518, '\p{Is_Dt=nar}', "");
Expect(0, 65518, '\p{^Is_Dt=nar}', "");
Expect(0, 65518, '\P{Is_Dt=nar}', "");
Expect(1, 65518, '\P{^Is_Dt=nar}', "");
Expect(0, 65519, '\p{Is_Dt=nar}', "");
Expect(1, 65519, '\p{^Is_Dt=nar}', "");
Expect(1, 65519, '\P{Is_Dt=nar}', "");
Expect(0, 65519, '\P{^Is_Dt=nar}', "");
Expect(1, 65518, '\p{Is_Dt=--Nar}', "");
Expect(0, 65518, '\p{^Is_Dt=--Nar}', "");
Expect(0, 65518, '\P{Is_Dt=--Nar}', "");
Expect(1, 65518, '\P{^Is_Dt=--Nar}', "");
Expect(0, 65519, '\p{Is_Dt=--Nar}', "");
Expect(1, 65519, '\p{^Is_Dt=--Nar}', "");
Expect(1, 65519, '\P{Is_Dt=--Nar}', "");
Expect(0, 65519, '\P{^Is_Dt=--Nar}', "");
Error('\p{Decomposition_Type=:= 	nobreak}');
Error('\P{Decomposition_Type=:= 	nobreak}');
Expect(1, 8239, '\p{Decomposition_Type=nobreak}', "");
Expect(0, 8239, '\p{^Decomposition_Type=nobreak}', "");
Expect(0, 8239, '\P{Decomposition_Type=nobreak}', "");
Expect(1, 8239, '\P{^Decomposition_Type=nobreak}', "");
Expect(0, 8240, '\p{Decomposition_Type=nobreak}', "");
Expect(1, 8240, '\p{^Decomposition_Type=nobreak}', "");
Expect(1, 8240, '\P{Decomposition_Type=nobreak}', "");
Expect(0, 8240, '\P{^Decomposition_Type=nobreak}', "");
Expect(1, 8239, '\p{Decomposition_Type=--Nobreak}', "");
Expect(0, 8239, '\p{^Decomposition_Type=--Nobreak}', "");
Expect(0, 8239, '\P{Decomposition_Type=--Nobreak}', "");
Expect(1, 8239, '\P{^Decomposition_Type=--Nobreak}', "");
Expect(0, 8240, '\p{Decomposition_Type=--Nobreak}', "");
Expect(1, 8240, '\p{^Decomposition_Type=--Nobreak}', "");
Expect(1, 8240, '\P{Decomposition_Type=--Nobreak}', "");
Expect(0, 8240, '\P{^Decomposition_Type=--Nobreak}', "");
Error('\p{Dt=:=Nb}');
Error('\P{Dt=:=Nb}');
Expect(1, 8239, '\p{Dt:nb}', "");
Expect(0, 8239, '\p{^Dt:nb}', "");
Expect(0, 8239, '\P{Dt:nb}', "");
Expect(1, 8239, '\P{^Dt:nb}', "");
Expect(0, 8240, '\p{Dt:nb}', "");
Expect(1, 8240, '\p{^Dt:nb}', "");
Expect(1, 8240, '\P{Dt:nb}', "");
Expect(0, 8240, '\P{^Dt:nb}', "");
Expect(1, 8239, '\p{Dt=	-NB}', "");
Expect(0, 8239, '\p{^Dt=	-NB}', "");
Expect(0, 8239, '\P{Dt=	-NB}', "");
Expect(1, 8239, '\P{^Dt=	-NB}', "");
Expect(0, 8240, '\p{Dt=	-NB}', "");
Expect(1, 8240, '\p{^Dt=	-NB}', "");
Expect(1, 8240, '\P{Dt=	-NB}', "");
Expect(0, 8240, '\P{^Dt=	-NB}', "");
Error('\p{Is_Decomposition_Type=--nobreak:=}');
Error('\P{Is_Decomposition_Type=--nobreak:=}');
Expect(1, 8239, '\p{Is_Decomposition_Type=nobreak}', "");
Expect(0, 8239, '\p{^Is_Decomposition_Type=nobreak}', "");
Expect(0, 8239, '\P{Is_Decomposition_Type=nobreak}', "");
Expect(1, 8239, '\P{^Is_Decomposition_Type=nobreak}', "");
Expect(0, 8240, '\p{Is_Decomposition_Type=nobreak}', "");
Expect(1, 8240, '\p{^Is_Decomposition_Type=nobreak}', "");
Expect(1, 8240, '\P{Is_Decomposition_Type=nobreak}', "");
Expect(0, 8240, '\P{^Is_Decomposition_Type=nobreak}', "");
Expect(1, 8239, '\p{Is_Decomposition_Type=	-Nobreak}', "");
Expect(0, 8239, '\p{^Is_Decomposition_Type=	-Nobreak}', "");
Expect(0, 8239, '\P{Is_Decomposition_Type=	-Nobreak}', "");
Expect(1, 8239, '\P{^Is_Decomposition_Type=	-Nobreak}', "");
Expect(0, 8240, '\p{Is_Decomposition_Type=	-Nobreak}', "");
Expect(1, 8240, '\p{^Is_Decomposition_Type=	-Nobreak}', "");
Expect(1, 8240, '\P{Is_Decomposition_Type=	-Nobreak}', "");
Expect(0, 8240, '\P{^Is_Decomposition_Type=	-Nobreak}', "");
Error('\p{Is_Dt=/a/_	NB}');
Error('\P{Is_Dt=/a/_	NB}');
Expect(1, 8239, '\p{Is_Dt=nb}', "");
Expect(0, 8239, '\p{^Is_Dt=nb}', "");
Expect(0, 8239, '\P{Is_Dt=nb}', "");
Expect(1, 8239, '\P{^Is_Dt=nb}', "");
Expect(0, 8240, '\p{Is_Dt=nb}', "");
Expect(1, 8240, '\p{^Is_Dt=nb}', "");
Expect(1, 8240, '\P{Is_Dt=nb}', "");
Expect(0, 8240, '\P{^Is_Dt=nb}', "");
Expect(1, 8239, '\p{Is_Dt= _Nb}', "");
Expect(0, 8239, '\p{^Is_Dt= _Nb}', "");
Expect(0, 8239, '\P{Is_Dt= _Nb}', "");
Expect(1, 8239, '\P{^Is_Dt= _Nb}', "");
Expect(0, 8240, '\p{Is_Dt= _Nb}', "");
Expect(1, 8240, '\p{^Is_Dt= _Nb}', "");
Expect(1, 8240, '\P{Is_Dt= _Nb}', "");
Expect(0, 8240, '\P{^Is_Dt= _Nb}', "");
Error('\p{Decomposition_Type=	 Non_Canonical/a/}');
Error('\P{Decomposition_Type=	 Non_Canonical/a/}');
Expect(1, 127569, '\p{Decomposition_Type:   noncanonical}', "");
Expect(0, 127569, '\p{^Decomposition_Type:   noncanonical}', "");
Expect(0, 127569, '\P{Decomposition_Type:   noncanonical}', "");
Expect(1, 127569, '\P{^Decomposition_Type:   noncanonical}', "");
Expect(0, 127570, '\p{Decomposition_Type:   noncanonical}', "");
Expect(1, 127570, '\p{^Decomposition_Type:   noncanonical}', "");
Expect(1, 127570, '\P{Decomposition_Type:   noncanonical}', "");
Expect(0, 127570, '\P{^Decomposition_Type:   noncanonical}', "");
Expect(1, 127569, '\p{Decomposition_Type= -Non_Canonical}', "");
Expect(0, 127569, '\p{^Decomposition_Type= -Non_Canonical}', "");
Expect(0, 127569, '\P{Decomposition_Type= -Non_Canonical}', "");
Expect(1, 127569, '\P{^Decomposition_Type= -Non_Canonical}', "");
Expect(0, 127570, '\p{Decomposition_Type= -Non_Canonical}', "");
Expect(1, 127570, '\p{^Decomposition_Type= -Non_Canonical}', "");
Expect(1, 127570, '\P{Decomposition_Type= -Non_Canonical}', "");
Expect(0, 127570, '\P{^Decomposition_Type= -Non_Canonical}', "");
Error('\p{Dt=:= NON_CANON}');
Error('\P{Dt=:= NON_CANON}');
Expect(1, 127569, '\p{Dt=noncanon}', "");
Expect(0, 127569, '\p{^Dt=noncanon}', "");
Expect(0, 127569, '\P{Dt=noncanon}', "");
Expect(1, 127569, '\P{^Dt=noncanon}', "");
Expect(0, 127570, '\p{Dt=noncanon}', "");
Expect(1, 127570, '\p{^Dt=noncanon}', "");
Expect(1, 127570, '\P{Dt=noncanon}', "");
Expect(0, 127570, '\P{^Dt=noncanon}', "");
Expect(1, 127569, '\p{Dt=_Non_CANON}', "");
Expect(0, 127569, '\p{^Dt=_Non_CANON}', "");
Expect(0, 127569, '\P{Dt=_Non_CANON}', "");
Expect(1, 127569, '\P{^Dt=_Non_CANON}', "");
Expect(0, 127570, '\p{Dt=_Non_CANON}', "");
Expect(1, 127570, '\p{^Dt=_Non_CANON}', "");
Expect(1, 127570, '\P{Dt=_Non_CANON}', "");
Expect(0, 127570, '\P{^Dt=_Non_CANON}', "");
Error('\p{Is_Decomposition_Type=- Non_Canonical/a/}');
Error('\P{Is_Decomposition_Type=- Non_Canonical/a/}');
Expect(1, 127569, '\p{Is_Decomposition_Type:   noncanonical}', "");
Expect(0, 127569, '\p{^Is_Decomposition_Type:   noncanonical}', "");
Expect(0, 127569, '\P{Is_Decomposition_Type:   noncanonical}', "");
Expect(1, 127569, '\P{^Is_Decomposition_Type:   noncanonical}', "");
Expect(0, 127570, '\p{Is_Decomposition_Type:   noncanonical}', "");
Expect(1, 127570, '\p{^Is_Decomposition_Type:   noncanonical}', "");
Expect(1, 127570, '\P{Is_Decomposition_Type:   noncanonical}', "");
Expect(0, 127570, '\P{^Is_Decomposition_Type:   noncanonical}', "");
Expect(1, 127569, '\p{Is_Decomposition_Type= _Non_canonical}', "");
Expect(0, 127569, '\p{^Is_Decomposition_Type= _Non_canonical}', "");
Expect(0, 127569, '\P{Is_Decomposition_Type= _Non_canonical}', "");
Expect(1, 127569, '\P{^Is_Decomposition_Type= _Non_canonical}', "");
Expect(0, 127570, '\p{Is_Decomposition_Type= _Non_canonical}', "");
Expect(1, 127570, '\p{^Is_Decomposition_Type= _Non_canonical}', "");
Expect(1, 127570, '\P{Is_Decomposition_Type= _Non_canonical}', "");
Expect(0, 127570, '\P{^Is_Decomposition_Type= _Non_canonical}', "");
Error('\p{Is_Dt: _:=Non_Canon}');
Error('\P{Is_Dt: _:=Non_Canon}');
Expect(1, 127569, '\p{Is_Dt=noncanon}', "");
Expect(0, 127569, '\p{^Is_Dt=noncanon}', "");
Expect(0, 127569, '\P{Is_Dt=noncanon}', "");
Expect(1, 127569, '\P{^Is_Dt=noncanon}', "");
Expect(0, 127570, '\p{Is_Dt=noncanon}', "");
Expect(1, 127570, '\p{^Is_Dt=noncanon}', "");
Expect(1, 127570, '\P{Is_Dt=noncanon}', "");
Expect(0, 127570, '\P{^Is_Dt=noncanon}', "");
Expect(1, 127569, '\p{Is_Dt= NON_canon}', "");
Expect(0, 127569, '\p{^Is_Dt= NON_canon}', "");
Expect(0, 127569, '\P{Is_Dt= NON_canon}', "");
Expect(1, 127569, '\P{^Is_Dt= NON_canon}', "");
Expect(0, 127570, '\p{Is_Dt= NON_canon}', "");
Expect(1, 127570, '\p{^Is_Dt= NON_canon}', "");
Expect(1, 127570, '\P{Is_Dt= NON_canon}', "");
Expect(0, 127570, '\P{^Is_Dt= NON_canon}', "");
Error('\p{Decomposition_Type=:=NONE}');
Error('\P{Decomposition_Type=:=NONE}');
Expect(1, 195102, '\p{Decomposition_Type=none}', "");
Expect(0, 195102, '\p{^Decomposition_Type=none}', "");
Expect(0, 195102, '\P{Decomposition_Type=none}', "");
Expect(1, 195102, '\P{^Decomposition_Type=none}', "");
Expect(0, 195101, '\p{Decomposition_Type=none}', "");
Expect(1, 195101, '\p{^Decomposition_Type=none}', "");
Expect(1, 195101, '\P{Decomposition_Type=none}', "");
Expect(0, 195101, '\P{^Decomposition_Type=none}', "");
Expect(1, 195102, '\p{Decomposition_Type= 	None}', "");
Expect(0, 195102, '\p{^Decomposition_Type= 	None}', "");
Expect(0, 195102, '\P{Decomposition_Type= 	None}', "");
Expect(1, 195102, '\P{^Decomposition_Type= 	None}', "");
Expect(0, 195101, '\p{Decomposition_Type= 	None}', "");
Expect(1, 195101, '\p{^Decomposition_Type= 	None}', "");
Expect(1, 195101, '\P{Decomposition_Type= 	None}', "");
Expect(0, 195101, '\P{^Decomposition_Type= 	None}', "");
Error('\p{Dt=/a/-none}');
Error('\P{Dt=/a/-none}');
Expect(1, 195102, '\p{Dt=none}', "");
Expect(0, 195102, '\p{^Dt=none}', "");
Expect(0, 195102, '\P{Dt=none}', "");
Expect(1, 195102, '\P{^Dt=none}', "");
Expect(0, 195101, '\p{Dt=none}', "");
Expect(1, 195101, '\p{^Dt=none}', "");
Expect(1, 195101, '\P{Dt=none}', "");
Expect(0, 195101, '\P{^Dt=none}', "");
Expect(1, 195102, '\p{Dt=-None}', "");
Expect(0, 195102, '\p{^Dt=-None}', "");
Expect(0, 195102, '\P{Dt=-None}', "");
Expect(1, 195102, '\P{^Dt=-None}', "");
Expect(0, 195101, '\p{Dt=-None}', "");
Expect(1, 195101, '\p{^Dt=-None}', "");
Expect(1, 195101, '\P{Dt=-None}', "");
Expect(0, 195101, '\P{^Dt=-None}', "");
Error('\p{Is_Decomposition_Type:	--none/a/}');
Error('\P{Is_Decomposition_Type:	--none/a/}');
Expect(1, 195102, '\p{Is_Decomposition_Type=none}', "");
Expect(0, 195102, '\p{^Is_Decomposition_Type=none}', "");
Expect(0, 195102, '\P{Is_Decomposition_Type=none}', "");
Expect(1, 195102, '\P{^Is_Decomposition_Type=none}', "");
Expect(0, 195101, '\p{Is_Decomposition_Type=none}', "");
Expect(1, 195101, '\p{^Is_Decomposition_Type=none}', "");
Expect(1, 195101, '\P{Is_Decomposition_Type=none}', "");
Expect(0, 195101, '\P{^Is_Decomposition_Type=none}', "");
Expect(1, 195102, '\p{Is_Decomposition_Type=--None}', "");
Expect(0, 195102, '\p{^Is_Decomposition_Type=--None}', "");
Expect(0, 195102, '\P{Is_Decomposition_Type=--None}', "");
Expect(1, 195102, '\P{^Is_Decomposition_Type=--None}', "");
Expect(0, 195101, '\p{Is_Decomposition_Type=--None}', "");
Expect(1, 195101, '\p{^Is_Decomposition_Type=--None}', "");
Expect(1, 195101, '\P{Is_Decomposition_Type=--None}', "");
Expect(0, 195101, '\P{^Is_Decomposition_Type=--None}', "");
Error('\p{Is_Dt=/a/_ None}');
Error('\P{Is_Dt=/a/_ None}');
Expect(1, 195102, '\p{Is_Dt=none}', "");
Expect(0, 195102, '\p{^Is_Dt=none}', "");
Expect(0, 195102, '\P{Is_Dt=none}', "");
Expect(1, 195102, '\P{^Is_Dt=none}', "");
Expect(0, 195101, '\p{Is_Dt=none}', "");
Expect(1, 195101, '\p{^Is_Dt=none}', "");
Expect(1, 195101, '\P{Is_Dt=none}', "");
Expect(0, 195101, '\P{^Is_Dt=none}', "");
Expect(1, 195102, '\p{Is_Dt:   	_none}', "");
Expect(0, 195102, '\p{^Is_Dt:   	_none}', "");
Expect(0, 195102, '\P{Is_Dt:   	_none}', "");
Expect(1, 195102, '\P{^Is_Dt:   	_none}', "");
Expect(0, 195101, '\p{Is_Dt:   	_none}', "");
Expect(1, 195101, '\p{^Is_Dt:   	_none}', "");
Expect(1, 195101, '\P{Is_Dt:   	_none}', "");
Expect(0, 195101, '\P{^Is_Dt:   	_none}', "");
Error('\p{Decomposition_Type=:=	Small}');
Error('\P{Decomposition_Type=:=	Small}');
Expect(1, 65131, '\p{Decomposition_Type=small}', "");
Expect(0, 65131, '\p{^Decomposition_Type=small}', "");
Expect(0, 65131, '\P{Decomposition_Type=small}', "");
Expect(1, 65131, '\P{^Decomposition_Type=small}', "");
Expect(0, 65132, '\p{Decomposition_Type=small}', "");
Expect(1, 65132, '\p{^Decomposition_Type=small}', "");
Expect(1, 65132, '\P{Decomposition_Type=small}', "");
Expect(0, 65132, '\P{^Decomposition_Type=small}', "");
Expect(1, 65131, '\p{Decomposition_Type=_-SMALL}', "");
Expect(0, 65131, '\p{^Decomposition_Type=_-SMALL}', "");
Expect(0, 65131, '\P{Decomposition_Type=_-SMALL}', "");
Expect(1, 65131, '\P{^Decomposition_Type=_-SMALL}', "");
Expect(0, 65132, '\p{Decomposition_Type=_-SMALL}', "");
Expect(1, 65132, '\p{^Decomposition_Type=_-SMALL}', "");
Expect(1, 65132, '\P{Decomposition_Type=_-SMALL}', "");
Expect(0, 65132, '\P{^Decomposition_Type=_-SMALL}', "");
Error('\p{Dt= 	Sml/a/}');
Error('\P{Dt= 	Sml/a/}');
Expect(1, 65131, '\p{Dt=sml}', "");
Expect(0, 65131, '\p{^Dt=sml}', "");
Expect(0, 65131, '\P{Dt=sml}', "");
Expect(1, 65131, '\P{^Dt=sml}', "");
Expect(0, 65132, '\p{Dt=sml}', "");
Expect(1, 65132, '\p{^Dt=sml}', "");
Expect(1, 65132, '\P{Dt=sml}', "");
Expect(0, 65132, '\P{^Dt=sml}', "");
Expect(1, 65131, '\p{Dt= -Sml}', "");
Expect(0, 65131, '\p{^Dt= -Sml}', "");
Expect(0, 65131, '\P{Dt= -Sml}', "");
Expect(1, 65131, '\P{^Dt= -Sml}', "");
Expect(0, 65132, '\p{Dt= -Sml}', "");
Expect(1, 65132, '\p{^Dt= -Sml}', "");
Expect(1, 65132, '\P{Dt= -Sml}', "");
Expect(0, 65132, '\P{^Dt= -Sml}', "");
Error('\p{Is_Decomposition_Type:	/a/Small}');
Error('\P{Is_Decomposition_Type:	/a/Small}');
Expect(1, 65131, '\p{Is_Decomposition_Type=small}', "");
Expect(0, 65131, '\p{^Is_Decomposition_Type=small}', "");
Expect(0, 65131, '\P{Is_Decomposition_Type=small}', "");
Expect(1, 65131, '\P{^Is_Decomposition_Type=small}', "");
Expect(0, 65132, '\p{Is_Decomposition_Type=small}', "");
Expect(1, 65132, '\p{^Is_Decomposition_Type=small}', "");
Expect(1, 65132, '\P{Is_Decomposition_Type=small}', "");
Expect(0, 65132, '\P{^Is_Decomposition_Type=small}', "");
Expect(1, 65131, '\p{Is_Decomposition_Type=	 SMALL}', "");
Expect(0, 65131, '\p{^Is_Decomposition_Type=	 SMALL}', "");
Expect(0, 65131, '\P{Is_Decomposition_Type=	 SMALL}', "");
Expect(1, 65131, '\P{^Is_Decomposition_Type=	 SMALL}', "");
Expect(0, 65132, '\p{Is_Decomposition_Type=	 SMALL}', "");
Expect(1, 65132, '\p{^Is_Decomposition_Type=	 SMALL}', "");
Expect(1, 65132, '\P{Is_Decomposition_Type=	 SMALL}', "");
Expect(0, 65132, '\P{^Is_Decomposition_Type=	 SMALL}', "");
Error('\p{Is_Dt=/a/ sml}');
Error('\P{Is_Dt=/a/ sml}');
Expect(1, 65131, '\p{Is_Dt=sml}', "");
Expect(0, 65131, '\p{^Is_Dt=sml}', "");
Expect(0, 65131, '\P{Is_Dt=sml}', "");
Expect(1, 65131, '\P{^Is_Dt=sml}', "");
Expect(0, 65132, '\p{Is_Dt=sml}', "");
Expect(1, 65132, '\p{^Is_Dt=sml}', "");
Expect(1, 65132, '\P{Is_Dt=sml}', "");
Expect(0, 65132, '\P{^Is_Dt=sml}', "");
Expect(1, 65131, '\p{Is_Dt=  Sml}', "");
Expect(0, 65131, '\p{^Is_Dt=  Sml}', "");
Expect(0, 65131, '\P{Is_Dt=  Sml}', "");
Expect(1, 65131, '\P{^Is_Dt=  Sml}', "");
Expect(0, 65132, '\p{Is_Dt=  Sml}', "");
Expect(1, 65132, '\p{^Is_Dt=  Sml}', "");
Expect(1, 65132, '\P{Is_Dt=  Sml}', "");
Expect(0, 65132, '\P{^Is_Dt=  Sml}', "");
Error('\p{Decomposition_Type:   /a/_square}');
Error('\P{Decomposition_Type:   /a/_square}');
Expect(1, 127546, '\p{Decomposition_Type=square}', "");
Expect(0, 127546, '\p{^Decomposition_Type=square}', "");
Expect(0, 127546, '\P{Decomposition_Type=square}', "");
Expect(1, 127546, '\P{^Decomposition_Type=square}', "");
Expect(0, 127547, '\p{Decomposition_Type=square}', "");
Expect(1, 127547, '\p{^Decomposition_Type=square}', "");
Expect(1, 127547, '\P{Decomposition_Type=square}', "");
Expect(0, 127547, '\P{^Decomposition_Type=square}', "");
Expect(1, 127546, '\p{Decomposition_Type=	Square}', "");
Expect(0, 127546, '\p{^Decomposition_Type=	Square}', "");
Expect(0, 127546, '\P{Decomposition_Type=	Square}', "");
Expect(1, 127546, '\P{^Decomposition_Type=	Square}', "");
Expect(0, 127547, '\p{Decomposition_Type=	Square}', "");
Expect(1, 127547, '\p{^Decomposition_Type=	Square}', "");
Expect(1, 127547, '\P{Decomposition_Type=	Square}', "");
Expect(0, 127547, '\P{^Decomposition_Type=	Square}', "");
Error('\p{Dt=:=_sqr}');
Error('\P{Dt=:=_sqr}');
Expect(1, 127546, '\p{Dt=sqr}', "");
Expect(0, 127546, '\p{^Dt=sqr}', "");
Expect(0, 127546, '\P{Dt=sqr}', "");
Expect(1, 127546, '\P{^Dt=sqr}', "");
Expect(0, 127547, '\p{Dt=sqr}', "");
Expect(1, 127547, '\p{^Dt=sqr}', "");
Expect(1, 127547, '\P{Dt=sqr}', "");
Expect(0, 127547, '\P{^Dt=sqr}', "");
Expect(1, 127546, '\p{Dt=- Sqr}', "");
Expect(0, 127546, '\p{^Dt=- Sqr}', "");
Expect(0, 127546, '\P{Dt=- Sqr}', "");
Expect(1, 127546, '\P{^Dt=- Sqr}', "");
Expect(0, 127547, '\p{Dt=- Sqr}', "");
Expect(1, 127547, '\p{^Dt=- Sqr}', "");
Expect(1, 127547, '\P{Dt=- Sqr}', "");
Expect(0, 127547, '\P{^Dt=- Sqr}', "");
Error('\p{Is_Decomposition_Type= /a/SQUARE}');
Error('\P{Is_Decomposition_Type= /a/SQUARE}');
Expect(1, 127546, '\p{Is_Decomposition_Type=square}', "");
Expect(0, 127546, '\p{^Is_Decomposition_Type=square}', "");
Expect(0, 127546, '\P{Is_Decomposition_Type=square}', "");
Expect(1, 127546, '\P{^Is_Decomposition_Type=square}', "");
Expect(0, 127547, '\p{Is_Decomposition_Type=square}', "");
Expect(1, 127547, '\p{^Is_Decomposition_Type=square}', "");
Expect(1, 127547, '\P{Is_Decomposition_Type=square}', "");
Expect(0, 127547, '\P{^Is_Decomposition_Type=square}', "");
Expect(1, 127546, '\p{Is_Decomposition_Type=	SQUARE}', "");
Expect(0, 127546, '\p{^Is_Decomposition_Type=	SQUARE}', "");
Expect(0, 127546, '\P{Is_Decomposition_Type=	SQUARE}', "");
Expect(1, 127546, '\P{^Is_Decomposition_Type=	SQUARE}', "");
Expect(0, 127547, '\p{Is_Decomposition_Type=	SQUARE}', "");
Expect(1, 127547, '\p{^Is_Decomposition_Type=	SQUARE}', "");
Expect(1, 127547, '\P{Is_Decomposition_Type=	SQUARE}', "");
Expect(0, 127547, '\P{^Is_Decomposition_Type=	SQUARE}', "");
Error('\p{Is_Dt:	-_SQR:=}');
Error('\P{Is_Dt:	-_SQR:=}');
Expect(1, 127546, '\p{Is_Dt=sqr}', "");
Expect(0, 127546, '\p{^Is_Dt=sqr}', "");
Expect(0, 127546, '\P{Is_Dt=sqr}', "");
Expect(1, 127546, '\P{^Is_Dt=sqr}', "");
Expect(0, 127547, '\p{Is_Dt=sqr}', "");
Expect(1, 127547, '\p{^Is_Dt=sqr}', "");
Expect(1, 127547, '\P{Is_Dt=sqr}', "");
Expect(0, 127547, '\P{^Is_Dt=sqr}', "");
Expect(1, 127546, '\p{Is_Dt= SQR}', "");
Expect(0, 127546, '\p{^Is_Dt= SQR}', "");
Expect(0, 127546, '\P{Is_Dt= SQR}', "");
Expect(1, 127546, '\P{^Is_Dt= SQR}', "");
Expect(0, 127547, '\p{Is_Dt= SQR}', "");
Expect(1, 127547, '\p{^Is_Dt= SQR}', "");
Expect(1, 127547, '\P{Is_Dt= SQR}', "");
Expect(0, 127547, '\P{^Is_Dt= SQR}', "");
Error('\p{Decomposition_Type=/a/	Sub}');
Error('\P{Decomposition_Type=/a/	Sub}');
Expect(1, 11388, '\p{Decomposition_Type=sub}', "");
Expect(0, 11388, '\p{^Decomposition_Type=sub}', "");
Expect(0, 11388, '\P{Decomposition_Type=sub}', "");
Expect(1, 11388, '\P{^Decomposition_Type=sub}', "");
Expect(0, 11389, '\p{Decomposition_Type=sub}', "");
Expect(1, 11389, '\p{^Decomposition_Type=sub}', "");
Expect(1, 11389, '\P{Decomposition_Type=sub}', "");
Expect(0, 11389, '\P{^Decomposition_Type=sub}', "");
Expect(1, 11388, '\p{Decomposition_Type= 	SUB}', "");
Expect(0, 11388, '\p{^Decomposition_Type= 	SUB}', "");
Expect(0, 11388, '\P{Decomposition_Type= 	SUB}', "");
Expect(1, 11388, '\P{^Decomposition_Type= 	SUB}', "");
Expect(0, 11389, '\p{Decomposition_Type= 	SUB}', "");
Expect(1, 11389, '\p{^Decomposition_Type= 	SUB}', "");
Expect(1, 11389, '\P{Decomposition_Type= 	SUB}', "");
Expect(0, 11389, '\P{^Decomposition_Type= 	SUB}', "");
Error('\p{Dt=--Sub/a/}');
Error('\P{Dt=--Sub/a/}');
Expect(1, 11388, '\p{Dt=sub}', "");
Expect(0, 11388, '\p{^Dt=sub}', "");
Expect(0, 11388, '\P{Dt=sub}', "");
Expect(1, 11388, '\P{^Dt=sub}', "");
Expect(0, 11389, '\p{Dt=sub}', "");
Expect(1, 11389, '\p{^Dt=sub}', "");
Expect(1, 11389, '\P{Dt=sub}', "");
Expect(0, 11389, '\P{^Dt=sub}', "");
Expect(1, 11388, '\p{Dt=__Sub}', "");
Expect(0, 11388, '\p{^Dt=__Sub}', "");
Expect(0, 11388, '\P{Dt=__Sub}', "");
Expect(1, 11388, '\P{^Dt=__Sub}', "");
Expect(0, 11389, '\p{Dt=__Sub}', "");
Expect(1, 11389, '\p{^Dt=__Sub}', "");
Expect(1, 11389, '\P{Dt=__Sub}', "");
Expect(0, 11389, '\P{^Dt=__Sub}', "");
Error('\p{Is_Decomposition_Type=_ Sub:=}');
Error('\P{Is_Decomposition_Type=_ Sub:=}');
Expect(1, 11388, '\p{Is_Decomposition_Type=sub}', "");
Expect(0, 11388, '\p{^Is_Decomposition_Type=sub}', "");
Expect(0, 11388, '\P{Is_Decomposition_Type=sub}', "");
Expect(1, 11388, '\P{^Is_Decomposition_Type=sub}', "");
Expect(0, 11389, '\p{Is_Decomposition_Type=sub}', "");
Expect(1, 11389, '\p{^Is_Decomposition_Type=sub}', "");
Expect(1, 11389, '\P{Is_Decomposition_Type=sub}', "");
Expect(0, 11389, '\P{^Is_Decomposition_Type=sub}', "");
Expect(1, 11388, '\p{Is_Decomposition_Type=--SUB}', "");
Expect(0, 11388, '\p{^Is_Decomposition_Type=--SUB}', "");
Expect(0, 11388, '\P{Is_Decomposition_Type=--SUB}', "");
Expect(1, 11388, '\P{^Is_Decomposition_Type=--SUB}', "");
Expect(0, 11389, '\p{Is_Decomposition_Type=--SUB}', "");
Expect(1, 11389, '\p{^Is_Decomposition_Type=--SUB}', "");
Expect(1, 11389, '\P{Is_Decomposition_Type=--SUB}', "");
Expect(0, 11389, '\P{^Is_Decomposition_Type=--SUB}', "");
Error('\p{Is_Dt=		sub/a/}');
Error('\P{Is_Dt=		sub/a/}');
Expect(1, 11388, '\p{Is_Dt: sub}', "");
Expect(0, 11388, '\p{^Is_Dt: sub}', "");
Expect(0, 11388, '\P{Is_Dt: sub}', "");
Expect(1, 11388, '\P{^Is_Dt: sub}', "");
Expect(0, 11389, '\p{Is_Dt: sub}', "");
Expect(1, 11389, '\p{^Is_Dt: sub}', "");
Expect(1, 11389, '\P{Is_Dt: sub}', "");
Expect(0, 11389, '\P{^Is_Dt: sub}', "");
Expect(1, 11388, '\p{Is_Dt=	_sub}', "");
Expect(0, 11388, '\p{^Is_Dt=	_sub}', "");
Expect(0, 11388, '\P{Is_Dt=	_sub}', "");
Expect(1, 11388, '\P{^Is_Dt=	_sub}', "");
Expect(0, 11389, '\p{Is_Dt=	_sub}', "");
Expect(1, 11389, '\p{^Is_Dt=	_sub}', "");
Expect(1, 11389, '\P{Is_Dt=	_sub}', "");
Expect(0, 11389, '\P{^Is_Dt=	_sub}', "");
Error('\p{Decomposition_Type=- super/a/}');
Error('\P{Decomposition_Type=- super/a/}');
Expect(1, 127339, '\p{Decomposition_Type=super}', "");
Expect(0, 127339, '\p{^Decomposition_Type=super}', "");
Expect(0, 127339, '\P{Decomposition_Type=super}', "");
Expect(1, 127339, '\P{^Decomposition_Type=super}', "");
Expect(0, 127340, '\p{Decomposition_Type=super}', "");
Expect(1, 127340, '\p{^Decomposition_Type=super}', "");
Expect(1, 127340, '\P{Decomposition_Type=super}', "");
Expect(0, 127340, '\P{^Decomposition_Type=super}', "");
Expect(1, 127339, '\p{Decomposition_Type=	 SUPER}', "");
Expect(0, 127339, '\p{^Decomposition_Type=	 SUPER}', "");
Expect(0, 127339, '\P{Decomposition_Type=	 SUPER}', "");
Expect(1, 127339, '\P{^Decomposition_Type=	 SUPER}', "");
Expect(0, 127340, '\p{Decomposition_Type=	 SUPER}', "");
Expect(1, 127340, '\p{^Decomposition_Type=	 SUPER}', "");
Expect(1, 127340, '\P{Decomposition_Type=	 SUPER}', "");
Expect(0, 127340, '\P{^Decomposition_Type=	 SUPER}', "");
Error('\p{Dt=_Sup:=}');
Error('\P{Dt=_Sup:=}');
Expect(1, 127339, '\p{Dt=sup}', "");
Expect(0, 127339, '\p{^Dt=sup}', "");
Expect(0, 127339, '\P{Dt=sup}', "");
Expect(1, 127339, '\P{^Dt=sup}', "");
Expect(0, 127340, '\p{Dt=sup}', "");
Expect(1, 127340, '\p{^Dt=sup}', "");
Expect(1, 127340, '\P{Dt=sup}', "");
Expect(0, 127340, '\P{^Dt=sup}', "");
Expect(1, 127339, '\p{Dt=	Sup}', "");
Expect(0, 127339, '\p{^Dt=	Sup}', "");
Expect(0, 127339, '\P{Dt=	Sup}', "");
Expect(1, 127339, '\P{^Dt=	Sup}', "");
Expect(0, 127340, '\p{Dt=	Sup}', "");
Expect(1, 127340, '\p{^Dt=	Sup}', "");
Expect(1, 127340, '\P{Dt=	Sup}', "");
Expect(0, 127340, '\P{^Dt=	Sup}', "");
Error('\p{Is_Decomposition_Type=/a/	-Super}');
Error('\P{Is_Decomposition_Type=/a/	-Super}');
Expect(1, 127339, '\p{Is_Decomposition_Type=super}', "");
Expect(0, 127339, '\p{^Is_Decomposition_Type=super}', "");
Expect(0, 127339, '\P{Is_Decomposition_Type=super}', "");
Expect(1, 127339, '\P{^Is_Decomposition_Type=super}', "");
Expect(0, 127340, '\p{Is_Decomposition_Type=super}', "");
Expect(1, 127340, '\p{^Is_Decomposition_Type=super}', "");
Expect(1, 127340, '\P{Is_Decomposition_Type=super}', "");
Expect(0, 127340, '\P{^Is_Decomposition_Type=super}', "");
Expect(1, 127339, '\p{Is_Decomposition_Type=_ SUPER}', "");
Expect(0, 127339, '\p{^Is_Decomposition_Type=_ SUPER}', "");
Expect(0, 127339, '\P{Is_Decomposition_Type=_ SUPER}', "");
Expect(1, 127339, '\P{^Is_Decomposition_Type=_ SUPER}', "");
Expect(0, 127340, '\p{Is_Decomposition_Type=_ SUPER}', "");
Expect(1, 127340, '\p{^Is_Decomposition_Type=_ SUPER}', "");
Expect(1, 127340, '\P{Is_Decomposition_Type=_ SUPER}', "");
Expect(0, 127340, '\P{^Is_Decomposition_Type=_ SUPER}', "");
Error('\p{Is_Dt=/a/ Sup}');
Error('\P{Is_Dt=/a/ Sup}');
Expect(1, 127339, '\p{Is_Dt=sup}', "");
Expect(0, 127339, '\p{^Is_Dt=sup}', "");
Expect(0, 127339, '\P{Is_Dt=sup}', "");
Expect(1, 127339, '\P{^Is_Dt=sup}', "");
Expect(0, 127340, '\p{Is_Dt=sup}', "");
Expect(1, 127340, '\p{^Is_Dt=sup}', "");
Expect(1, 127340, '\P{Is_Dt=sup}', "");
Expect(0, 127340, '\P{^Is_Dt=sup}', "");
Expect(1, 127339, '\p{Is_Dt=		Sup}', "");
Expect(0, 127339, '\p{^Is_Dt=		Sup}', "");
Expect(0, 127339, '\P{Is_Dt=		Sup}', "");
Expect(1, 127339, '\P{^Is_Dt=		Sup}', "");
Expect(0, 127340, '\p{Is_Dt=		Sup}', "");
Expect(1, 127340, '\p{^Is_Dt=		Sup}', "");
Expect(1, 127340, '\P{Is_Dt=		Sup}', "");
Expect(0, 127340, '\P{^Is_Dt=		Sup}', "");
Error('\p{Decomposition_Type=/a/VERTICAL}');
Error('\P{Decomposition_Type=/a/VERTICAL}');
Expect(1, 65096, '\p{Decomposition_Type=vertical}', "");
Expect(0, 65096, '\p{^Decomposition_Type=vertical}', "");
Expect(0, 65096, '\P{Decomposition_Type=vertical}', "");
Expect(1, 65096, '\P{^Decomposition_Type=vertical}', "");
Expect(0, 65097, '\p{Decomposition_Type=vertical}', "");
Expect(1, 65097, '\p{^Decomposition_Type=vertical}', "");
Expect(1, 65097, '\P{Decomposition_Type=vertical}', "");
Expect(0, 65097, '\P{^Decomposition_Type=vertical}', "");
Expect(1, 65096, '\p{Decomposition_Type=-Vertical}', "");
Expect(0, 65096, '\p{^Decomposition_Type=-Vertical}', "");
Expect(0, 65096, '\P{Decomposition_Type=-Vertical}', "");
Expect(1, 65096, '\P{^Decomposition_Type=-Vertical}', "");
Expect(0, 65097, '\p{Decomposition_Type=-Vertical}', "");
Expect(1, 65097, '\p{^Decomposition_Type=-Vertical}', "");
Expect(1, 65097, '\P{Decomposition_Type=-Vertical}', "");
Expect(0, 65097, '\P{^Decomposition_Type=-Vertical}', "");
Error('\p{Dt=:=-	Vert}');
Error('\P{Dt=:=-	Vert}');
Expect(1, 65096, '\p{Dt=vert}', "");
Expect(0, 65096, '\p{^Dt=vert}', "");
Expect(0, 65096, '\P{Dt=vert}', "");
Expect(1, 65096, '\P{^Dt=vert}', "");
Expect(0, 65097, '\p{Dt=vert}', "");
Expect(1, 65097, '\p{^Dt=vert}', "");
Expect(1, 65097, '\P{Dt=vert}', "");
Expect(0, 65097, '\P{^Dt=vert}', "");
Expect(1, 65096, '\p{Dt=--vert}', "");
Expect(0, 65096, '\p{^Dt=--vert}', "");
Expect(0, 65096, '\P{Dt=--vert}', "");
Expect(1, 65096, '\P{^Dt=--vert}', "");
Expect(0, 65097, '\p{Dt=--vert}', "");
Expect(1, 65097, '\p{^Dt=--vert}', "");
Expect(1, 65097, '\P{Dt=--vert}', "");
Expect(0, 65097, '\P{^Dt=--vert}', "");
Error('\p{Is_Decomposition_Type= :=VERTICAL}');
Error('\P{Is_Decomposition_Type= :=VERTICAL}');
Expect(1, 65096, '\p{Is_Decomposition_Type:vertical}', "");
Expect(0, 65096, '\p{^Is_Decomposition_Type:vertical}', "");
Expect(0, 65096, '\P{Is_Decomposition_Type:vertical}', "");
Expect(1, 65096, '\P{^Is_Decomposition_Type:vertical}', "");
Expect(0, 65097, '\p{Is_Decomposition_Type:vertical}', "");
Expect(1, 65097, '\p{^Is_Decomposition_Type:vertical}', "");
Expect(1, 65097, '\P{Is_Decomposition_Type:vertical}', "");
Expect(0, 65097, '\P{^Is_Decomposition_Type:vertical}', "");
Expect(1, 65096, '\p{Is_Decomposition_Type=	 VERTICAL}', "");
Expect(0, 65096, '\p{^Is_Decomposition_Type=	 VERTICAL}', "");
Expect(0, 65096, '\P{Is_Decomposition_Type=	 VERTICAL}', "");
Expect(1, 65096, '\P{^Is_Decomposition_Type=	 VERTICAL}', "");
Expect(0, 65097, '\p{Is_Decomposition_Type=	 VERTICAL}', "");
Expect(1, 65097, '\p{^Is_Decomposition_Type=	 VERTICAL}', "");
Expect(1, 65097, '\P{Is_Decomposition_Type=	 VERTICAL}', "");
Expect(0, 65097, '\P{^Is_Decomposition_Type=	 VERTICAL}', "");
Error('\p{Is_Dt=	/a/vert}');
Error('\P{Is_Dt=	/a/vert}');
Expect(1, 65096, '\p{Is_Dt=vert}', "");
Expect(0, 65096, '\p{^Is_Dt=vert}', "");
Expect(0, 65096, '\P{Is_Dt=vert}', "");
Expect(1, 65096, '\P{^Is_Dt=vert}', "");
Expect(0, 65097, '\p{Is_Dt=vert}', "");
Expect(1, 65097, '\p{^Is_Dt=vert}', "");
Expect(1, 65097, '\P{Is_Dt=vert}', "");
Expect(0, 65097, '\P{^Is_Dt=vert}', "");
Expect(1, 65096, '\p{Is_Dt:--Vert}', "");
Expect(0, 65096, '\p{^Is_Dt:--Vert}', "");
Expect(0, 65096, '\P{Is_Dt:--Vert}', "");
Expect(1, 65096, '\P{^Is_Dt:--Vert}', "");
Expect(0, 65097, '\p{Is_Dt:--Vert}', "");
Expect(1, 65097, '\p{^Is_Dt:--Vert}', "");
Expect(1, 65097, '\P{Is_Dt:--Vert}', "");
Expect(0, 65097, '\P{^Is_Dt:--Vert}', "");
Error('\p{Decomposition_Type:    :=WIDE}');
Error('\P{Decomposition_Type:    :=WIDE}');
Expect(1, 65510, '\p{Decomposition_Type:   wide}', "");
Expect(0, 65510, '\p{^Decomposition_Type:   wide}', "");
Expect(0, 65510, '\P{Decomposition_Type:   wide}', "");
Expect(1, 65510, '\P{^Decomposition_Type:   wide}', "");
Expect(0, 65511, '\p{Decomposition_Type:   wide}', "");
Expect(1, 65511, '\p{^Decomposition_Type:   wide}', "");
Expect(1, 65511, '\P{Decomposition_Type:   wide}', "");
Expect(0, 65511, '\P{^Decomposition_Type:   wide}', "");
Expect(1, 65510, '\p{Decomposition_Type:   wide}', "");
Expect(0, 65510, '\p{^Decomposition_Type:   wide}', "");
Expect(0, 65510, '\P{Decomposition_Type:   wide}', "");
Expect(1, 65510, '\P{^Decomposition_Type:   wide}', "");
Expect(0, 65511, '\p{Decomposition_Type:   wide}', "");
Expect(1, 65511, '\p{^Decomposition_Type:   wide}', "");
Expect(1, 65511, '\P{Decomposition_Type:   wide}', "");
Expect(0, 65511, '\P{^Decomposition_Type:   wide}', "");
Error('\p{Dt=/a/	wide}');
Error('\P{Dt=/a/	wide}');
Expect(1, 65510, '\p{Dt=wide}', "");
Expect(0, 65510, '\p{^Dt=wide}', "");
Expect(0, 65510, '\P{Dt=wide}', "");
Expect(1, 65510, '\P{^Dt=wide}', "");
Expect(0, 65511, '\p{Dt=wide}', "");
Expect(1, 65511, '\p{^Dt=wide}', "");
Expect(1, 65511, '\P{Dt=wide}', "");
Expect(0, 65511, '\P{^Dt=wide}', "");
Expect(1, 65510, '\p{Dt=__WIDE}', "");
Expect(0, 65510, '\p{^Dt=__WIDE}', "");
Expect(0, 65510, '\P{Dt=__WIDE}', "");
Expect(1, 65510, '\P{^Dt=__WIDE}', "");
Expect(0, 65511, '\p{Dt=__WIDE}', "");
Expect(1, 65511, '\p{^Dt=__WIDE}', "");
Expect(1, 65511, '\P{Dt=__WIDE}', "");
Expect(0, 65511, '\P{^Dt=__WIDE}', "");
Error('\p{Is_Decomposition_Type=/a/wide}');
Error('\P{Is_Decomposition_Type=/a/wide}');
Expect(1, 65510, '\p{Is_Decomposition_Type=wide}', "");
Expect(0, 65510, '\p{^Is_Decomposition_Type=wide}', "");
Expect(0, 65510, '\P{Is_Decomposition_Type=wide}', "");
Expect(1, 65510, '\P{^Is_Decomposition_Type=wide}', "");
Expect(0, 65511, '\p{Is_Decomposition_Type=wide}', "");
Expect(1, 65511, '\p{^Is_Decomposition_Type=wide}', "");
Expect(1, 65511, '\P{Is_Decomposition_Type=wide}', "");
Expect(0, 65511, '\P{^Is_Decomposition_Type=wide}', "");
Expect(1, 65510, '\p{Is_Decomposition_Type=--WIDE}', "");
Expect(0, 65510, '\p{^Is_Decomposition_Type=--WIDE}', "");
Expect(0, 65510, '\P{Is_Decomposition_Type=--WIDE}', "");
Expect(1, 65510, '\P{^Is_Decomposition_Type=--WIDE}', "");
Expect(0, 65511, '\p{Is_Decomposition_Type=--WIDE}', "");
Expect(1, 65511, '\p{^Is_Decomposition_Type=--WIDE}', "");
Expect(1, 65511, '\P{Is_Decomposition_Type=--WIDE}', "");
Expect(0, 65511, '\P{^Is_Decomposition_Type=--WIDE}', "");
Error('\p{Is_Dt= 	wide/a/}');
Error('\P{Is_Dt= 	wide/a/}');
Expect(1, 65510, '\p{Is_Dt=wide}', "");
Expect(0, 65510, '\p{^Is_Dt=wide}', "");
Expect(0, 65510, '\P{Is_Dt=wide}', "");
Expect(1, 65510, '\P{^Is_Dt=wide}', "");
Expect(0, 65511, '\p{Is_Dt=wide}', "");
Expect(1, 65511, '\p{^Is_Dt=wide}', "");
Expect(1, 65511, '\P{Is_Dt=wide}', "");
Expect(0, 65511, '\P{^Is_Dt=wide}', "");
Expect(1, 65510, '\p{Is_Dt=_-wide}', "");
Expect(0, 65510, '\p{^Is_Dt=_-wide}', "");
Expect(0, 65510, '\P{Is_Dt=_-wide}', "");
Expect(1, 65510, '\P{^Is_Dt=_-wide}', "");
Expect(0, 65511, '\p{Is_Dt=_-wide}', "");
Expect(1, 65511, '\p{^Is_Dt=_-wide}', "");
Expect(1, 65511, '\P{Is_Dt=_-wide}', "");
Expect(0, 65511, '\P{^Is_Dt=_-wide}', "");
Error('\p{East_Asian_Width=-Ambiguous:=}');
Error('\P{East_Asian_Width=-Ambiguous:=}');
Expect(1, 1114109, '\p{East_Asian_Width=ambiguous}', "");
Expect(0, 1114109, '\p{^East_Asian_Width=ambiguous}', "");
Expect(0, 1114109, '\P{East_Asian_Width=ambiguous}', "");
Expect(1, 1114109, '\P{^East_Asian_Width=ambiguous}', "");
Expect(0, 918000, '\p{East_Asian_Width=ambiguous}', "");
Expect(1, 918000, '\p{^East_Asian_Width=ambiguous}', "");
Expect(1, 918000, '\P{East_Asian_Width=ambiguous}', "");
Expect(0, 918000, '\P{^East_Asian_Width=ambiguous}', "");
Expect(1, 1114109, '\p{East_Asian_Width=Ambiguous}', "");
Expect(0, 1114109, '\p{^East_Asian_Width=Ambiguous}', "");
Expect(0, 1114109, '\P{East_Asian_Width=Ambiguous}', "");
Expect(1, 1114109, '\P{^East_Asian_Width=Ambiguous}', "");
Expect(0, 918000, '\p{East_Asian_Width=Ambiguous}', "");
Expect(1, 918000, '\p{^East_Asian_Width=Ambiguous}', "");
Expect(1, 918000, '\P{East_Asian_Width=Ambiguous}', "");
Expect(0, 918000, '\P{^East_Asian_Width=Ambiguous}', "");
Error('\p{Ea=_ a/a/}');
Error('\P{Ea=_ a/a/}');
Expect(1, 1114109, '\p{Ea=a}', "");
Expect(0, 1114109, '\p{^Ea=a}', "");
Expect(0, 1114109, '\P{Ea=a}', "");
Expect(1, 1114109, '\P{^Ea=a}', "");
Expect(0, 918000, '\p{Ea=a}', "");
Expect(1, 918000, '\p{^Ea=a}', "");
Expect(1, 918000, '\P{Ea=a}', "");
Expect(0, 918000, '\P{^Ea=a}', "");
Expect(1, 1114109, '\p{Ea=  A}', "");
Expect(0, 1114109, '\p{^Ea=  A}', "");
Expect(0, 1114109, '\P{Ea=  A}', "");
Expect(1, 1114109, '\P{^Ea=  A}', "");
Expect(0, 918000, '\p{Ea=  A}', "");
Expect(1, 918000, '\p{^Ea=  A}', "");
Expect(1, 918000, '\P{Ea=  A}', "");
Expect(0, 918000, '\P{^Ea=  A}', "");
Error('\p{Is_East_Asian_Width=:=-Ambiguous}');
Error('\P{Is_East_Asian_Width=:=-Ambiguous}');
Expect(1, 1114109, '\p{Is_East_Asian_Width=ambiguous}', "");
Expect(0, 1114109, '\p{^Is_East_Asian_Width=ambiguous}', "");
Expect(0, 1114109, '\P{Is_East_Asian_Width=ambiguous}', "");
Expect(1, 1114109, '\P{^Is_East_Asian_Width=ambiguous}', "");
Expect(0, 918000, '\p{Is_East_Asian_Width=ambiguous}', "");
Expect(1, 918000, '\p{^Is_East_Asian_Width=ambiguous}', "");
Expect(1, 918000, '\P{Is_East_Asian_Width=ambiguous}', "");
Expect(0, 918000, '\P{^Is_East_Asian_Width=ambiguous}', "");
Expect(1, 1114109, '\p{Is_East_Asian_Width=-Ambiguous}', "");
Expect(0, 1114109, '\p{^Is_East_Asian_Width=-Ambiguous}', "");
Expect(0, 1114109, '\P{Is_East_Asian_Width=-Ambiguous}', "");
Expect(1, 1114109, '\P{^Is_East_Asian_Width=-Ambiguous}', "");
Expect(0, 918000, '\p{Is_East_Asian_Width=-Ambiguous}', "");
Expect(1, 918000, '\p{^Is_East_Asian_Width=-Ambiguous}', "");
Expect(1, 918000, '\P{Is_East_Asian_Width=-Ambiguous}', "");
Expect(0, 918000, '\P{^Is_East_Asian_Width=-Ambiguous}', "");
Error('\p{Is_Ea: A:=}');
Error('\P{Is_Ea: A:=}');
Expect(1, 1114109, '\p{Is_Ea=a}', "");
Expect(0, 1114109, '\p{^Is_Ea=a}', "");
Expect(0, 1114109, '\P{Is_Ea=a}', "");
Expect(1, 1114109, '\P{^Is_Ea=a}', "");
Expect(0, 918000, '\p{Is_Ea=a}', "");
Expect(1, 918000, '\p{^Is_Ea=a}', "");
Expect(1, 918000, '\P{Is_Ea=a}', "");
Expect(0, 918000, '\P{^Is_Ea=a}', "");
Expect(1, 1114109, '\p{Is_Ea=	A}', "");
Expect(0, 1114109, '\p{^Is_Ea=	A}', "");
Expect(0, 1114109, '\P{Is_Ea=	A}', "");
Expect(1, 1114109, '\P{^Is_Ea=	A}', "");
Expect(0, 918000, '\p{Is_Ea=	A}', "");
Expect(1, 918000, '\p{^Is_Ea=	A}', "");
Expect(1, 918000, '\P{Is_Ea=	A}', "");
Expect(0, 918000, '\P{^Is_Ea=	A}', "");
Error('\p{East_Asian_Width=/a/ FULLWIDTH}');
Error('\P{East_Asian_Width=/a/ FULLWIDTH}');
Expect(1, 65510, '\p{East_Asian_Width=fullwidth}', "");
Expect(0, 65510, '\p{^East_Asian_Width=fullwidth}', "");
Expect(0, 65510, '\P{East_Asian_Width=fullwidth}', "");
Expect(1, 65510, '\P{^East_Asian_Width=fullwidth}', "");
Expect(0, 65511, '\p{East_Asian_Width=fullwidth}', "");
Expect(1, 65511, '\p{^East_Asian_Width=fullwidth}', "");
Expect(1, 65511, '\P{East_Asian_Width=fullwidth}', "");
Expect(0, 65511, '\P{^East_Asian_Width=fullwidth}', "");
Expect(1, 65510, '\p{East_Asian_Width: -Fullwidth}', "");
Expect(0, 65510, '\p{^East_Asian_Width: -Fullwidth}', "");
Expect(0, 65510, '\P{East_Asian_Width: -Fullwidth}', "");
Expect(1, 65510, '\P{^East_Asian_Width: -Fullwidth}', "");
Expect(0, 65511, '\p{East_Asian_Width: -Fullwidth}', "");
Expect(1, 65511, '\p{^East_Asian_Width: -Fullwidth}', "");
Expect(1, 65511, '\P{East_Asian_Width: -Fullwidth}', "");
Expect(0, 65511, '\P{^East_Asian_Width: -Fullwidth}', "");
Error('\p{Ea= -F:=}');
Error('\P{Ea= -F:=}');
Expect(1, 65510, '\p{Ea=f}', "");
Expect(0, 65510, '\p{^Ea=f}', "");
Expect(0, 65510, '\P{Ea=f}', "");
Expect(1, 65510, '\P{^Ea=f}', "");
Expect(0, 65511, '\p{Ea=f}', "");
Expect(1, 65511, '\p{^Ea=f}', "");
Expect(1, 65511, '\P{Ea=f}', "");
Expect(0, 65511, '\P{^Ea=f}', "");
Expect(1, 65510, '\p{Ea=__F}', "");
Expect(0, 65510, '\p{^Ea=__F}', "");
Expect(0, 65510, '\P{Ea=__F}', "");
Expect(1, 65510, '\P{^Ea=__F}', "");
Expect(0, 65511, '\p{Ea=__F}', "");
Expect(1, 65511, '\p{^Ea=__F}', "");
Expect(1, 65511, '\P{Ea=__F}', "");
Expect(0, 65511, '\P{^Ea=__F}', "");
Error('\p{Is_East_Asian_Width=	Fullwidth/a/}');
Error('\P{Is_East_Asian_Width=	Fullwidth/a/}');
Expect(1, 65510, '\p{Is_East_Asian_Width=fullwidth}', "");
Expect(0, 65510, '\p{^Is_East_Asian_Width=fullwidth}', "");
Expect(0, 65510, '\P{Is_East_Asian_Width=fullwidth}', "");
Expect(1, 65510, '\P{^Is_East_Asian_Width=fullwidth}', "");
Expect(0, 65511, '\p{Is_East_Asian_Width=fullwidth}', "");
Expect(1, 65511, '\p{^Is_East_Asian_Width=fullwidth}', "");
Expect(1, 65511, '\P{Is_East_Asian_Width=fullwidth}', "");
Expect(0, 65511, '\P{^Is_East_Asian_Width=fullwidth}', "");
Expect(1, 65510, '\p{Is_East_Asian_Width=-Fullwidth}', "");
Expect(0, 65510, '\p{^Is_East_Asian_Width=-Fullwidth}', "");
Expect(0, 65510, '\P{Is_East_Asian_Width=-Fullwidth}', "");
Expect(1, 65510, '\P{^Is_East_Asian_Width=-Fullwidth}', "");
Expect(0, 65511, '\p{Is_East_Asian_Width=-Fullwidth}', "");
Expect(1, 65511, '\p{^Is_East_Asian_Width=-Fullwidth}', "");
Expect(1, 65511, '\P{Is_East_Asian_Width=-Fullwidth}', "");
Expect(0, 65511, '\P{^Is_East_Asian_Width=-Fullwidth}', "");
Error('\p{Is_Ea=_/a/F}');
Error('\P{Is_Ea=_/a/F}');
Expect(1, 65510, '\p{Is_Ea=f}', "");
Expect(0, 65510, '\p{^Is_Ea=f}', "");
Expect(0, 65510, '\P{Is_Ea=f}', "");
Expect(1, 65510, '\P{^Is_Ea=f}', "");
Expect(0, 65511, '\p{Is_Ea=f}', "");
Expect(1, 65511, '\p{^Is_Ea=f}', "");
Expect(1, 65511, '\P{Is_Ea=f}', "");
Expect(0, 65511, '\P{^Is_Ea=f}', "");
Expect(1, 65510, '\p{Is_Ea=- F}', "");
Expect(0, 65510, '\p{^Is_Ea=- F}', "");
Expect(0, 65510, '\P{Is_Ea=- F}', "");
Expect(1, 65510, '\P{^Is_Ea=- F}', "");
Expect(0, 65511, '\p{Is_Ea=- F}', "");
Expect(1, 65511, '\p{^Is_Ea=- F}', "");
Expect(1, 65511, '\P{Is_Ea=- F}', "");
Expect(0, 65511, '\P{^Is_Ea=- F}', "");
Error('\p{East_Asian_Width=_-HALFWIDTH:=}');
Error('\P{East_Asian_Width=_-HALFWIDTH:=}');
Expect(1, 65518, '\p{East_Asian_Width=halfwidth}', "");
Expect(0, 65518, '\p{^East_Asian_Width=halfwidth}', "");
Expect(0, 65518, '\P{East_Asian_Width=halfwidth}', "");
Expect(1, 65518, '\P{^East_Asian_Width=halfwidth}', "");
Expect(0, 65519, '\p{East_Asian_Width=halfwidth}', "");
Expect(1, 65519, '\p{^East_Asian_Width=halfwidth}', "");
Expect(1, 65519, '\P{East_Asian_Width=halfwidth}', "");
Expect(0, 65519, '\P{^East_Asian_Width=halfwidth}', "");
Expect(1, 65518, '\p{East_Asian_Width:- HALFWIDTH}', "");
Expect(0, 65518, '\p{^East_Asian_Width:- HALFWIDTH}', "");
Expect(0, 65518, '\P{East_Asian_Width:- HALFWIDTH}', "");
Expect(1, 65518, '\P{^East_Asian_Width:- HALFWIDTH}', "");
Expect(0, 65519, '\p{East_Asian_Width:- HALFWIDTH}', "");
Expect(1, 65519, '\p{^East_Asian_Width:- HALFWIDTH}', "");
Expect(1, 65519, '\P{East_Asian_Width:- HALFWIDTH}', "");
Expect(0, 65519, '\P{^East_Asian_Width:- HALFWIDTH}', "");
Error('\p{Ea=	/a/H}');
Error('\P{Ea=	/a/H}');
Expect(1, 65518, '\p{Ea:h}', "");
Expect(0, 65518, '\p{^Ea:h}', "");
Expect(0, 65518, '\P{Ea:h}', "");
Expect(1, 65518, '\P{^Ea:h}', "");
Expect(0, 65519, '\p{Ea:h}', "");
Expect(1, 65519, '\p{^Ea:h}', "");
Expect(1, 65519, '\P{Ea:h}', "");
Expect(0, 65519, '\P{^Ea:h}', "");
Expect(1, 65518, '\p{Ea=	_H}', "");
Expect(0, 65518, '\p{^Ea=	_H}', "");
Expect(0, 65518, '\P{Ea=	_H}', "");
Expect(1, 65518, '\P{^Ea=	_H}', "");
Expect(0, 65519, '\p{Ea=	_H}', "");
Expect(1, 65519, '\p{^Ea=	_H}', "");
Expect(1, 65519, '\P{Ea=	_H}', "");
Expect(0, 65519, '\P{^Ea=	_H}', "");
Error('\p{Is_East_Asian_Width= :=HALFWIDTH}');
Error('\P{Is_East_Asian_Width= :=HALFWIDTH}');
Expect(1, 65518, '\p{Is_East_Asian_Width: halfwidth}', "");
Expect(0, 65518, '\p{^Is_East_Asian_Width: halfwidth}', "");
Expect(0, 65518, '\P{Is_East_Asian_Width: halfwidth}', "");
Expect(1, 65518, '\P{^Is_East_Asian_Width: halfwidth}', "");
Expect(0, 65519, '\p{Is_East_Asian_Width: halfwidth}', "");
Expect(1, 65519, '\p{^Is_East_Asian_Width: halfwidth}', "");
Expect(1, 65519, '\P{Is_East_Asian_Width: halfwidth}', "");
Expect(0, 65519, '\P{^Is_East_Asian_Width: halfwidth}', "");
Expect(1, 65518, '\p{Is_East_Asian_Width=-	HALFWIDTH}', "");
Expect(0, 65518, '\p{^Is_East_Asian_Width=-	HALFWIDTH}', "");
Expect(0, 65518, '\P{Is_East_Asian_Width=-	HALFWIDTH}', "");
Expect(1, 65518, '\P{^Is_East_Asian_Width=-	HALFWIDTH}', "");
Expect(0, 65519, '\p{Is_East_Asian_Width=-	HALFWIDTH}', "");
Expect(1, 65519, '\p{^Is_East_Asian_Width=-	HALFWIDTH}', "");
Expect(1, 65519, '\P{Is_East_Asian_Width=-	HALFWIDTH}', "");
Expect(0, 65519, '\P{^Is_East_Asian_Width=-	HALFWIDTH}', "");
Error('\p{Is_Ea=-	H:=}');
Error('\P{Is_Ea=-	H:=}');
Expect(1, 65518, '\p{Is_Ea=h}', "");
Expect(0, 65518, '\p{^Is_Ea=h}', "");
Expect(0, 65518, '\P{Is_Ea=h}', "");
Expect(1, 65518, '\P{^Is_Ea=h}', "");
Expect(0, 65519, '\p{Is_Ea=h}', "");
Expect(1, 65519, '\p{^Is_Ea=h}', "");
Expect(1, 65519, '\P{Is_Ea=h}', "");
Expect(0, 65519, '\P{^Is_Ea=h}', "");
Expect(1, 65518, '\p{Is_Ea=_-H}', "");
Expect(0, 65518, '\p{^Is_Ea=_-H}', "");
Expect(0, 65518, '\P{Is_Ea=_-H}', "");
Expect(1, 65518, '\P{^Is_Ea=_-H}', "");
Expect(0, 65519, '\p{Is_Ea=_-H}', "");
Expect(1, 65519, '\p{^Is_Ea=_-H}', "");
Expect(1, 65519, '\P{Is_Ea=_-H}', "");
Expect(0, 65519, '\P{^Is_Ea=_-H}', "");
Error('\p{East_Asian_Width=/a/Neutral}');
Error('\P{East_Asian_Width=/a/Neutral}');
Expect(1, 918000, '\p{East_Asian_Width:	neutral}', "");
Expect(0, 918000, '\p{^East_Asian_Width:	neutral}', "");
Expect(0, 918000, '\P{East_Asian_Width:	neutral}', "");
Expect(1, 918000, '\P{^East_Asian_Width:	neutral}', "");
Expect(0, 1114109, '\p{East_Asian_Width:	neutral}', "");
Expect(1, 1114109, '\p{^East_Asian_Width:	neutral}', "");
Expect(1, 1114109, '\P{East_Asian_Width:	neutral}', "");
Expect(0, 1114109, '\P{^East_Asian_Width:	neutral}', "");
Expect(1, 918000, '\p{East_Asian_Width=_ neutral}', "");
Expect(0, 918000, '\p{^East_Asian_Width=_ neutral}', "");
Expect(0, 918000, '\P{East_Asian_Width=_ neutral}', "");
Expect(1, 918000, '\P{^East_Asian_Width=_ neutral}', "");
Expect(0, 1114109, '\p{East_Asian_Width=_ neutral}', "");
Expect(1, 1114109, '\p{^East_Asian_Width=_ neutral}', "");
Expect(1, 1114109, '\P{East_Asian_Width=_ neutral}', "");
Expect(0, 1114109, '\P{^East_Asian_Width=_ neutral}', "");
Error('\p{Ea=:=_ N}');
Error('\P{Ea=:=_ N}');
Expect(1, 918000, '\p{Ea=n}', "");
Expect(0, 918000, '\p{^Ea=n}', "");
Expect(0, 918000, '\P{Ea=n}', "");
Expect(1, 918000, '\P{^Ea=n}', "");
Expect(0, 1114109, '\p{Ea=n}', "");
Expect(1, 1114109, '\p{^Ea=n}', "");
Expect(1, 1114109, '\P{Ea=n}', "");
Expect(0, 1114109, '\P{^Ea=n}', "");
Expect(1, 918000, '\p{Ea:   	N}', "");
Expect(0, 918000, '\p{^Ea:   	N}', "");
Expect(0, 918000, '\P{Ea:   	N}', "");
Expect(1, 918000, '\P{^Ea:   	N}', "");
Expect(0, 1114109, '\p{Ea:   	N}', "");
Expect(1, 1114109, '\p{^Ea:   	N}', "");
Expect(1, 1114109, '\P{Ea:   	N}', "");
Expect(0, 1114109, '\P{^Ea:   	N}', "");
Error('\p{Is_East_Asian_Width=_/a/Neutral}');
Error('\P{Is_East_Asian_Width=_/a/Neutral}');
Expect(1, 918000, '\p{Is_East_Asian_Width=neutral}', "");
Expect(0, 918000, '\p{^Is_East_Asian_Width=neutral}', "");
Expect(0, 918000, '\P{Is_East_Asian_Width=neutral}', "");
Expect(1, 918000, '\P{^Is_East_Asian_Width=neutral}', "");
Expect(0, 1114109, '\p{Is_East_Asian_Width=neutral}', "");
Expect(1, 1114109, '\p{^Is_East_Asian_Width=neutral}', "");
Expect(1, 1114109, '\P{Is_East_Asian_Width=neutral}', "");
Expect(0, 1114109, '\P{^Is_East_Asian_Width=neutral}', "");
Expect(1, 918000, '\p{Is_East_Asian_Width= _Neutral}', "");
Expect(0, 918000, '\p{^Is_East_Asian_Width= _Neutral}', "");
Expect(0, 918000, '\P{Is_East_Asian_Width= _Neutral}', "");
Expect(1, 918000, '\P{^Is_East_Asian_Width= _Neutral}', "");
Expect(0, 1114109, '\p{Is_East_Asian_Width= _Neutral}', "");
Expect(1, 1114109, '\p{^Is_East_Asian_Width= _Neutral}', "");
Expect(1, 1114109, '\P{Is_East_Asian_Width= _Neutral}', "");
Expect(0, 1114109, '\P{^Is_East_Asian_Width= _Neutral}', "");
Error('\p{Is_Ea=:=__N}');
Error('\P{Is_Ea=:=__N}');
Expect(1, 918000, '\p{Is_Ea=n}', "");
Expect(0, 918000, '\p{^Is_Ea=n}', "");
Expect(0, 918000, '\P{Is_Ea=n}', "");
Expect(1, 918000, '\P{^Is_Ea=n}', "");
Expect(0, 1114109, '\p{Is_Ea=n}', "");
Expect(1, 1114109, '\p{^Is_Ea=n}', "");
Expect(1, 1114109, '\P{Is_Ea=n}', "");
Expect(0, 1114109, '\P{^Is_Ea=n}', "");
Expect(1, 918000, '\p{Is_Ea= N}', "");
Expect(0, 918000, '\p{^Is_Ea= N}', "");
Expect(0, 918000, '\P{Is_Ea= N}', "");
Expect(1, 918000, '\P{^Is_Ea= N}', "");
Expect(0, 1114109, '\p{Is_Ea= N}', "");
Expect(1, 1114109, '\p{^Is_Ea= N}', "");
Expect(1, 1114109, '\P{Is_Ea= N}', "");
Expect(0, 1114109, '\P{^Is_Ea= N}', "");
Error('\p{East_Asian_Width= /a/Narrow}');
Error('\P{East_Asian_Width= /a/Narrow}');
Expect(1, 10630, '\p{East_Asian_Width=narrow}', "");
Expect(0, 10630, '\p{^East_Asian_Width=narrow}', "");
Expect(0, 10630, '\P{East_Asian_Width=narrow}', "");
Expect(1, 10630, '\P{^East_Asian_Width=narrow}', "");
Expect(0, 10631, '\p{East_Asian_Width=narrow}', "");
Expect(1, 10631, '\p{^East_Asian_Width=narrow}', "");
Expect(1, 10631, '\P{East_Asian_Width=narrow}', "");
Expect(0, 10631, '\P{^East_Asian_Width=narrow}', "");
Expect(1, 10630, '\p{East_Asian_Width= _narrow}', "");
Expect(0, 10630, '\p{^East_Asian_Width= _narrow}', "");
Expect(0, 10630, '\P{East_Asian_Width= _narrow}', "");
Expect(1, 10630, '\P{^East_Asian_Width= _narrow}', "");
Expect(0, 10631, '\p{East_Asian_Width= _narrow}', "");
Expect(1, 10631, '\p{^East_Asian_Width= _narrow}', "");
Expect(1, 10631, '\P{East_Asian_Width= _narrow}', "");
Expect(0, 10631, '\P{^East_Asian_Width= _narrow}', "");
Error('\p{Ea=/a/- NA}');
Error('\P{Ea=/a/- NA}');
Expect(1, 10630, '\p{Ea=na}', "");
Expect(0, 10630, '\p{^Ea=na}', "");
Expect(0, 10630, '\P{Ea=na}', "");
Expect(1, 10630, '\P{^Ea=na}', "");
Expect(0, 10631, '\p{Ea=na}', "");
Expect(1, 10631, '\p{^Ea=na}', "");
Expect(1, 10631, '\P{Ea=na}', "");
Expect(0, 10631, '\P{^Ea=na}', "");
Expect(1, 10630, '\p{Ea= 	na}', "");
Expect(0, 10630, '\p{^Ea= 	na}', "");
Expect(0, 10630, '\P{Ea= 	na}', "");
Expect(1, 10630, '\P{^Ea= 	na}', "");
Expect(0, 10631, '\p{Ea= 	na}', "");
Expect(1, 10631, '\p{^Ea= 	na}', "");
Expect(1, 10631, '\P{Ea= 	na}', "");
Expect(0, 10631, '\P{^Ea= 	na}', "");
Error('\p{Is_East_Asian_Width= Narrow/a/}');
Error('\P{Is_East_Asian_Width= Narrow/a/}');
Expect(1, 10630, '\p{Is_East_Asian_Width=narrow}', "");
Expect(0, 10630, '\p{^Is_East_Asian_Width=narrow}', "");
Expect(0, 10630, '\P{Is_East_Asian_Width=narrow}', "");
Expect(1, 10630, '\P{^Is_East_Asian_Width=narrow}', "");
Expect(0, 10631, '\p{Is_East_Asian_Width=narrow}', "");
Expect(1, 10631, '\p{^Is_East_Asian_Width=narrow}', "");
Expect(1, 10631, '\P{Is_East_Asian_Width=narrow}', "");
Expect(0, 10631, '\P{^Is_East_Asian_Width=narrow}', "");
Expect(1, 10630, '\p{Is_East_Asian_Width=	Narrow}', "");
Expect(0, 10630, '\p{^Is_East_Asian_Width=	Narrow}', "");
Expect(0, 10630, '\P{Is_East_Asian_Width=	Narrow}', "");
Expect(1, 10630, '\P{^Is_East_Asian_Width=	Narrow}', "");
Expect(0, 10631, '\p{Is_East_Asian_Width=	Narrow}', "");
Expect(1, 10631, '\p{^Is_East_Asian_Width=	Narrow}', "");
Expect(1, 10631, '\P{Is_East_Asian_Width=	Narrow}', "");
Expect(0, 10631, '\P{^Is_East_Asian_Width=	Narrow}', "");
Error('\p{Is_Ea=	/a/Na}');
Error('\P{Is_Ea=	/a/Na}');
Expect(1, 10630, '\p{Is_Ea=na}', "");
Expect(0, 10630, '\p{^Is_Ea=na}', "");
Expect(0, 10630, '\P{Is_Ea=na}', "");
Expect(1, 10630, '\P{^Is_Ea=na}', "");
Expect(0, 10631, '\p{Is_Ea=na}', "");
Expect(1, 10631, '\p{^Is_Ea=na}', "");
Expect(1, 10631, '\P{Is_Ea=na}', "");
Expect(0, 10631, '\P{^Is_Ea=na}', "");
Expect(1, 10630, '\p{Is_Ea=		Na}', "");
Expect(0, 10630, '\p{^Is_Ea=		Na}', "");
Expect(0, 10630, '\P{Is_Ea=		Na}', "");
Expect(1, 10630, '\P{^Is_Ea=		Na}', "");
Expect(0, 10631, '\p{Is_Ea=		Na}', "");
Expect(1, 10631, '\p{^Is_Ea=		Na}', "");
Expect(1, 10631, '\P{Is_Ea=		Na}', "");
Expect(0, 10631, '\P{^Is_Ea=		Na}', "");
Error('\p{East_Asian_Width=_	Wide/a/}');
Error('\P{East_Asian_Width=_	Wide/a/}');
Expect(1, 262141, '\p{East_Asian_Width=wide}', "");
Expect(0, 262141, '\p{^East_Asian_Width=wide}', "");
Expect(0, 262141, '\P{East_Asian_Width=wide}', "");
Expect(1, 262141, '\P{^East_Asian_Width=wide}', "");
Expect(0, 262144, '\p{East_Asian_Width=wide}', "");
Expect(1, 262144, '\p{^East_Asian_Width=wide}', "");
Expect(1, 262144, '\P{East_Asian_Width=wide}', "");
Expect(0, 262144, '\P{^East_Asian_Width=wide}', "");
Expect(1, 262141, '\p{East_Asian_Width=_wide}', "");
Expect(0, 262141, '\p{^East_Asian_Width=_wide}', "");
Expect(0, 262141, '\P{East_Asian_Width=_wide}', "");
Expect(1, 262141, '\P{^East_Asian_Width=_wide}', "");
Expect(0, 262144, '\p{East_Asian_Width=_wide}', "");
Expect(1, 262144, '\p{^East_Asian_Width=_wide}', "");
Expect(1, 262144, '\P{East_Asian_Width=_wide}', "");
Expect(0, 262144, '\P{^East_Asian_Width=_wide}', "");
Error('\p{Ea= _W:=}');
Error('\P{Ea= _W:=}');
Expect(1, 262141, '\p{Ea=w}', "");
Expect(0, 262141, '\p{^Ea=w}', "");
Expect(0, 262141, '\P{Ea=w}', "");
Expect(1, 262141, '\P{^Ea=w}', "");
Expect(0, 262144, '\p{Ea=w}', "");
Expect(1, 262144, '\p{^Ea=w}', "");
Expect(1, 262144, '\P{Ea=w}', "");
Expect(0, 262144, '\P{^Ea=w}', "");
Expect(1, 262141, '\p{Ea:	  W}', "");
Expect(0, 262141, '\p{^Ea:	  W}', "");
Expect(0, 262141, '\P{Ea:	  W}', "");
Expect(1, 262141, '\P{^Ea:	  W}', "");
Expect(0, 262144, '\p{Ea:	  W}', "");
Expect(1, 262144, '\p{^Ea:	  W}', "");
Expect(1, 262144, '\P{Ea:	  W}', "");
Expect(0, 262144, '\P{^Ea:	  W}', "");
Error('\p{Is_East_Asian_Width=-/a/Wide}');
Error('\P{Is_East_Asian_Width=-/a/Wide}');
Expect(1, 262141, '\p{Is_East_Asian_Width=wide}', "");
Expect(0, 262141, '\p{^Is_East_Asian_Width=wide}', "");
Expect(0, 262141, '\P{Is_East_Asian_Width=wide}', "");
Expect(1, 262141, '\P{^Is_East_Asian_Width=wide}', "");
Expect(0, 262144, '\p{Is_East_Asian_Width=wide}', "");
Expect(1, 262144, '\p{^Is_East_Asian_Width=wide}', "");
Expect(1, 262144, '\P{Is_East_Asian_Width=wide}', "");
Expect(0, 262144, '\P{^Is_East_Asian_Width=wide}', "");
Expect(1, 262141, '\p{Is_East_Asian_Width= _wide}', "");
Expect(0, 262141, '\p{^Is_East_Asian_Width= _wide}', "");
Expect(0, 262141, '\P{Is_East_Asian_Width= _wide}', "");
Expect(1, 262141, '\P{^Is_East_Asian_Width= _wide}', "");
Expect(0, 262144, '\p{Is_East_Asian_Width= _wide}', "");
Expect(1, 262144, '\p{^Is_East_Asian_Width= _wide}', "");
Expect(1, 262144, '\P{Is_East_Asian_Width= _wide}', "");
Expect(0, 262144, '\P{^Is_East_Asian_Width= _wide}', "");
Error('\p{Is_Ea=w:=}');
Error('\P{Is_Ea=w:=}');
Expect(1, 262141, '\p{Is_Ea=w}', "");
Expect(0, 262141, '\p{^Is_Ea=w}', "");
Expect(0, 262141, '\P{Is_Ea=w}', "");
Expect(1, 262141, '\P{^Is_Ea=w}', "");
Expect(0, 262144, '\p{Is_Ea=w}', "");
Expect(1, 262144, '\p{^Is_Ea=w}', "");
Expect(1, 262144, '\P{Is_Ea=w}', "");
Expect(0, 262144, '\P{^Is_Ea=w}', "");
Expect(1, 262141, '\p{Is_Ea:_	W}', "");
Expect(0, 262141, '\p{^Is_Ea:_	W}', "");
Expect(0, 262141, '\P{Is_Ea:_	W}', "");
Expect(1, 262141, '\P{^Is_Ea:_	W}', "");
Expect(0, 262144, '\p{Is_Ea:_	W}', "");
Expect(1, 262144, '\p{^Is_Ea:_	W}', "");
Expect(1, 262144, '\P{Is_Ea:_	W}', "");
Expect(0, 262144, '\P{^Is_Ea:_	W}', "");
Error('\p{General_Category:_other/a/}');
Error('\P{General_Category:_other/a/}');
Expect(1, 918000, '\p{General_Category=other}', "");
Expect(0, 918000, '\p{^General_Category=other}', "");
Expect(0, 918000, '\P{General_Category=other}', "");
Expect(1, 918000, '\P{^General_Category=other}', "");
Expect(0, 917999, '\p{General_Category=other}', "");
Expect(1, 917999, '\p{^General_Category=other}', "");
Expect(1, 917999, '\P{General_Category=other}', "");
Expect(0, 917999, '\P{^General_Category=other}', "");
Expect(1, 918000, '\p{General_Category=	-Other}', "");
Expect(0, 918000, '\p{^General_Category=	-Other}', "");
Expect(0, 918000, '\P{General_Category=	-Other}', "");
Expect(1, 918000, '\P{^General_Category=	-Other}', "");
Expect(0, 917999, '\p{General_Category=	-Other}', "");
Expect(1, 917999, '\p{^General_Category=	-Other}', "");
Expect(1, 917999, '\P{General_Category=	-Other}', "");
Expect(0, 917999, '\P{^General_Category=	-Other}', "");
Error('\p{Gc=:= C}');
Error('\P{Gc=:= C}');
Expect(1, 918000, '\p{Gc=c}', "");
Expect(0, 918000, '\p{^Gc=c}', "");
Expect(0, 918000, '\P{Gc=c}', "");
Expect(1, 918000, '\P{^Gc=c}', "");
Expect(0, 917999, '\p{Gc=c}', "");
Expect(1, 917999, '\p{^Gc=c}', "");
Expect(1, 917999, '\P{Gc=c}', "");
Expect(0, 917999, '\P{^Gc=c}', "");
Expect(1, 918000, '\p{Gc=	 C}', "");
Expect(0, 918000, '\p{^Gc=	 C}', "");
Expect(0, 918000, '\P{Gc=	 C}', "");
Expect(1, 918000, '\P{^Gc=	 C}', "");
Expect(0, 917999, '\p{Gc=	 C}', "");
Expect(1, 917999, '\p{^Gc=	 C}', "");
Expect(1, 917999, '\P{Gc=	 C}', "");
Expect(0, 917999, '\P{^Gc=	 C}', "");
Error('\p{Category=/a/ Other}');
Error('\P{Category=/a/ Other}');
Expect(1, 918000, '\p{Category=other}', "");
Expect(0, 918000, '\p{^Category=other}', "");
Expect(0, 918000, '\P{Category=other}', "");
Expect(1, 918000, '\P{^Category=other}', "");
Expect(0, 917999, '\p{Category=other}', "");
Expect(1, 917999, '\p{^Category=other}', "");
Expect(1, 917999, '\P{Category=other}', "");
Expect(0, 917999, '\P{^Category=other}', "");
Expect(1, 918000, '\p{Category:	_other}', "");
Expect(0, 918000, '\p{^Category:	_other}', "");
Expect(0, 918000, '\P{Category:	_other}', "");
Expect(1, 918000, '\P{^Category:	_other}', "");
Expect(0, 917999, '\p{Category:	_other}', "");
Expect(1, 917999, '\p{^Category:	_other}', "");
Expect(1, 917999, '\P{Category:	_other}', "");
Expect(0, 917999, '\P{^Category:	_other}', "");
Error('\p{Is_General_Category=-/a/c}');
Error('\P{Is_General_Category=-/a/c}');
Expect(1, 918000, '\p{Is_General_Category=c}', "");
Expect(0, 918000, '\p{^Is_General_Category=c}', "");
Expect(0, 918000, '\P{Is_General_Category=c}', "");
Expect(1, 918000, '\P{^Is_General_Category=c}', "");
Expect(0, 917999, '\p{Is_General_Category=c}', "");
Expect(1, 917999, '\p{^Is_General_Category=c}', "");
Expect(1, 917999, '\P{Is_General_Category=c}', "");
Expect(0, 917999, '\P{^Is_General_Category=c}', "");
Expect(1, 918000, '\p{Is_General_Category=- c}', "");
Expect(0, 918000, '\p{^Is_General_Category=- c}', "");
Expect(0, 918000, '\P{Is_General_Category=- c}', "");
Expect(1, 918000, '\P{^Is_General_Category=- c}', "");
Expect(0, 917999, '\p{Is_General_Category=- c}', "");
Expect(1, 917999, '\p{^Is_General_Category=- c}', "");
Expect(1, 917999, '\P{Is_General_Category=- c}', "");
Expect(0, 917999, '\P{^Is_General_Category=- c}', "");
Error('\p{Is_Gc=-:=other}');
Error('\P{Is_Gc=-:=other}');
Expect(1, 918000, '\p{Is_Gc:	other}', "");
Expect(0, 918000, '\p{^Is_Gc:	other}', "");
Expect(0, 918000, '\P{Is_Gc:	other}', "");
Expect(1, 918000, '\P{^Is_Gc:	other}', "");
Expect(0, 917999, '\p{Is_Gc:	other}', "");
Expect(1, 917999, '\p{^Is_Gc:	other}', "");
Expect(1, 917999, '\P{Is_Gc:	other}', "");
Expect(0, 917999, '\P{^Is_Gc:	other}', "");
Expect(1, 918000, '\p{Is_Gc:   	OTHER}', "");
Expect(0, 918000, '\p{^Is_Gc:   	OTHER}', "");
Expect(0, 918000, '\P{Is_Gc:   	OTHER}', "");
Expect(1, 918000, '\P{^Is_Gc:   	OTHER}', "");
Expect(0, 917999, '\p{Is_Gc:   	OTHER}', "");
Expect(1, 917999, '\p{^Is_Gc:   	OTHER}', "");
Expect(1, 917999, '\P{Is_Gc:   	OTHER}', "");
Expect(0, 917999, '\P{^Is_Gc:   	OTHER}', "");
Error('\p{Is_Category=/a/ C}');
Error('\P{Is_Category=/a/ C}');
Expect(1, 918000, '\p{Is_Category=c}', "");
Expect(0, 918000, '\p{^Is_Category=c}', "");
Expect(0, 918000, '\P{Is_Category=c}', "");
Expect(1, 918000, '\P{^Is_Category=c}', "");
Expect(0, 917999, '\p{Is_Category=c}', "");
Expect(1, 917999, '\p{^Is_Category=c}', "");
Expect(1, 917999, '\P{Is_Category=c}', "");
Expect(0, 917999, '\P{^Is_Category=c}', "");
Expect(1, 918000, '\p{Is_Category:   -c}', "");
Expect(0, 918000, '\p{^Is_Category:   -c}', "");
Expect(0, 918000, '\P{Is_Category:   -c}', "");
Expect(1, 918000, '\P{^Is_Category:   -c}', "");
Expect(0, 917999, '\p{Is_Category:   -c}', "");
Expect(1, 917999, '\p{^Is_Category:   -c}', "");
Expect(1, 917999, '\P{Is_Category:   -c}', "");
Expect(0, 917999, '\P{^Is_Category:   -c}', "");
Error('\p{General_Category=_:=control}');
Error('\P{General_Category=_:=control}');
Expect(1, 159, '\p{General_Category=control}', "");
Expect(0, 159, '\p{^General_Category=control}', "");
Expect(0, 159, '\P{General_Category=control}', "");
Expect(1, 159, '\P{^General_Category=control}', "");
Expect(0, 160, '\p{General_Category=control}', "");
Expect(1, 160, '\p{^General_Category=control}', "");
Expect(1, 160, '\P{General_Category=control}', "");
Expect(0, 160, '\P{^General_Category=control}', "");
Expect(1, 159, '\p{General_Category:    control}', "");
Expect(0, 159, '\p{^General_Category:    control}', "");
Expect(0, 159, '\P{General_Category:    control}', "");
Expect(1, 159, '\P{^General_Category:    control}', "");
Expect(0, 160, '\p{General_Category:    control}', "");
Expect(1, 160, '\p{^General_Category:    control}', "");
Expect(1, 160, '\P{General_Category:    control}', "");
Expect(0, 160, '\P{^General_Category:    control}', "");
Error('\p{Gc=-CC/a/}');
Error('\P{Gc=-CC/a/}');
Expect(1, 159, '\p{Gc: cc}', "");
Expect(0, 159, '\p{^Gc: cc}', "");
Expect(0, 159, '\P{Gc: cc}', "");
Expect(1, 159, '\P{^Gc: cc}', "");
Expect(0, 160, '\p{Gc: cc}', "");
Expect(1, 160, '\p{^Gc: cc}', "");
Expect(1, 160, '\P{Gc: cc}', "");
Expect(0, 160, '\P{^Gc: cc}', "");
Expect(1, 159, '\p{Gc= 	Cc}', "");
Expect(0, 159, '\p{^Gc= 	Cc}', "");
Expect(0, 159, '\P{Gc= 	Cc}', "");
Expect(1, 159, '\P{^Gc= 	Cc}', "");
Expect(0, 160, '\p{Gc= 	Cc}', "");
Expect(1, 160, '\p{^Gc= 	Cc}', "");
Expect(1, 160, '\P{Gc= 	Cc}', "");
Expect(0, 160, '\P{^Gc= 	Cc}', "");
Error('\p{Category:	_	Cntrl/a/}');
Error('\P{Category:	_	Cntrl/a/}');
Expect(1, 159, '\p{Category=cntrl}', "");
Expect(0, 159, '\p{^Category=cntrl}', "");
Expect(0, 159, '\P{Category=cntrl}', "");
Expect(1, 159, '\P{^Category=cntrl}', "");
Expect(0, 160, '\p{Category=cntrl}', "");
Expect(1, 160, '\p{^Category=cntrl}', "");
Expect(1, 160, '\P{Category=cntrl}', "");
Expect(0, 160, '\P{^Category=cntrl}', "");
Expect(1, 159, '\p{Category=- CNTRL}', "");
Expect(0, 159, '\p{^Category=- CNTRL}', "");
Expect(0, 159, '\P{Category=- CNTRL}', "");
Expect(1, 159, '\P{^Category=- CNTRL}', "");
Expect(0, 160, '\p{Category=- CNTRL}', "");
Expect(1, 160, '\p{^Category=- CNTRL}', "");
Expect(1, 160, '\P{Category=- CNTRL}', "");
Expect(0, 160, '\P{^Category=- CNTRL}', "");
Error('\p{Is_General_Category=/a/--Control}');
Error('\P{Is_General_Category=/a/--Control}');
Expect(1, 159, '\p{Is_General_Category=control}', "");
Expect(0, 159, '\p{^Is_General_Category=control}', "");
Expect(0, 159, '\P{Is_General_Category=control}', "");
Expect(1, 159, '\P{^Is_General_Category=control}', "");
Expect(0, 160, '\p{Is_General_Category=control}', "");
Expect(1, 160, '\p{^Is_General_Category=control}', "");
Expect(1, 160, '\P{Is_General_Category=control}', "");
Expect(0, 160, '\P{^Is_General_Category=control}', "");
Expect(1, 159, '\p{Is_General_Category=_control}', "");
Expect(0, 159, '\p{^Is_General_Category=_control}', "");
Expect(0, 159, '\P{Is_General_Category=_control}', "");
Expect(1, 159, '\P{^Is_General_Category=_control}', "");
Expect(0, 160, '\p{Is_General_Category=_control}', "");
Expect(1, 160, '\p{^Is_General_Category=_control}', "");
Expect(1, 160, '\P{Is_General_Category=_control}', "");
Expect(0, 160, '\P{^Is_General_Category=_control}', "");
Error('\p{Is_Gc=_-Cc:=}');
Error('\P{Is_Gc=_-Cc:=}');
Expect(1, 159, '\p{Is_Gc=cc}', "");
Expect(0, 159, '\p{^Is_Gc=cc}', "");
Expect(0, 159, '\P{Is_Gc=cc}', "");
Expect(1, 159, '\P{^Is_Gc=cc}', "");
Expect(0, 160, '\p{Is_Gc=cc}', "");
Expect(1, 160, '\p{^Is_Gc=cc}', "");
Expect(1, 160, '\P{Is_Gc=cc}', "");
Expect(0, 160, '\P{^Is_Gc=cc}', "");
Expect(1, 159, '\p{Is_Gc=		Cc}', "");
Expect(0, 159, '\p{^Is_Gc=		Cc}', "");
Expect(0, 159, '\P{Is_Gc=		Cc}', "");
Expect(1, 159, '\P{^Is_Gc=		Cc}', "");
Expect(0, 160, '\p{Is_Gc=		Cc}', "");
Expect(1, 160, '\p{^Is_Gc=		Cc}', "");
Expect(1, 160, '\P{Is_Gc=		Cc}', "");
Expect(0, 160, '\P{^Is_Gc=		Cc}', "");
Error('\p{Is_Category=-:=cntrl}');
Error('\P{Is_Category=-:=cntrl}');
Expect(1, 159, '\p{Is_Category=cntrl}', "");
Expect(0, 159, '\p{^Is_Category=cntrl}', "");
Expect(0, 159, '\P{Is_Category=cntrl}', "");
Expect(1, 159, '\P{^Is_Category=cntrl}', "");
Expect(0, 160, '\p{Is_Category=cntrl}', "");
Expect(1, 160, '\p{^Is_Category=cntrl}', "");
Expect(1, 160, '\P{Is_Category=cntrl}', "");
Expect(0, 160, '\P{^Is_Category=cntrl}', "");
Expect(1, 159, '\p{Is_Category=- CNTRL}', "");
Expect(0, 159, '\p{^Is_Category=- CNTRL}', "");
Expect(0, 159, '\P{Is_Category=- CNTRL}', "");
Expect(1, 159, '\P{^Is_Category=- CNTRL}', "");
Expect(0, 160, '\p{Is_Category=- CNTRL}', "");
Expect(1, 160, '\p{^Is_Category=- CNTRL}', "");
Expect(1, 160, '\P{Is_Category=- CNTRL}', "");
Expect(0, 160, '\P{^Is_Category=- CNTRL}', "");
Error('\p{General_Category=__FORMAT:=}');
Error('\P{General_Category=__FORMAT:=}');
Expect(1, 917631, '\p{General_Category=format}', "");
Expect(0, 917631, '\p{^General_Category=format}', "");
Expect(0, 917631, '\P{General_Category=format}', "");
Expect(1, 917631, '\P{^General_Category=format}', "");
Expect(0, 917632, '\p{General_Category=format}', "");
Expect(1, 917632, '\p{^General_Category=format}', "");
Expect(1, 917632, '\P{General_Category=format}', "");
Expect(0, 917632, '\P{^General_Category=format}', "");
Expect(1, 917631, '\p{General_Category=FORMAT}', "");
Expect(0, 917631, '\p{^General_Category=FORMAT}', "");
Expect(0, 917631, '\P{General_Category=FORMAT}', "");
Expect(1, 917631, '\P{^General_Category=FORMAT}', "");
Expect(0, 917632, '\p{General_Category=FORMAT}', "");
Expect(1, 917632, '\p{^General_Category=FORMAT}', "");
Expect(1, 917632, '\P{General_Category=FORMAT}', "");
Expect(0, 917632, '\P{^General_Category=FORMAT}', "");
Error('\p{Gc=-/a/CF}');
Error('\P{Gc=-/a/CF}');
Expect(1, 917631, '\p{Gc=cf}', "");
Expect(0, 917631, '\p{^Gc=cf}', "");
Expect(0, 917631, '\P{Gc=cf}', "");
Expect(1, 917631, '\P{^Gc=cf}', "");
Expect(0, 917632, '\p{Gc=cf}', "");
Expect(1, 917632, '\p{^Gc=cf}', "");
Expect(1, 917632, '\P{Gc=cf}', "");
Expect(0, 917632, '\P{^Gc=cf}', "");
Expect(1, 917631, '\p{Gc= 	CF}', "");
Expect(0, 917631, '\p{^Gc= 	CF}', "");
Expect(0, 917631, '\P{Gc= 	CF}', "");
Expect(1, 917631, '\P{^Gc= 	CF}', "");
Expect(0, 917632, '\p{Gc= 	CF}', "");
Expect(1, 917632, '\p{^Gc= 	CF}', "");
Expect(1, 917632, '\P{Gc= 	CF}', "");
Expect(0, 917632, '\P{^Gc= 	CF}', "");
Error('\p{Category=/a/	-FORMAT}');
Error('\P{Category=/a/	-FORMAT}');
Expect(1, 917631, '\p{Category=format}', "");
Expect(0, 917631, '\p{^Category=format}', "");
Expect(0, 917631, '\P{Category=format}', "");
Expect(1, 917631, '\P{^Category=format}', "");
Expect(0, 917632, '\p{Category=format}', "");
Expect(1, 917632, '\p{^Category=format}', "");
Expect(1, 917632, '\P{Category=format}', "");
Expect(0, 917632, '\P{^Category=format}', "");
Expect(1, 917631, '\p{Category=_format}', "");
Expect(0, 917631, '\p{^Category=_format}', "");
Expect(0, 917631, '\P{Category=_format}', "");
Expect(1, 917631, '\P{^Category=_format}', "");
Expect(0, 917632, '\p{Category=_format}', "");
Expect(1, 917632, '\p{^Category=_format}', "");
Expect(1, 917632, '\P{Category=_format}', "");
Expect(0, 917632, '\P{^Category=_format}', "");
Error('\p{Is_General_Category=:=cf}');
Error('\P{Is_General_Category=:=cf}');
Expect(1, 917631, '\p{Is_General_Category=cf}', "");
Expect(0, 917631, '\p{^Is_General_Category=cf}', "");
Expect(0, 917631, '\P{Is_General_Category=cf}', "");
Expect(1, 917631, '\P{^Is_General_Category=cf}', "");
Expect(0, 917632, '\p{Is_General_Category=cf}', "");
Expect(1, 917632, '\p{^Is_General_Category=cf}', "");
Expect(1, 917632, '\P{Is_General_Category=cf}', "");
Expect(0, 917632, '\P{^Is_General_Category=cf}', "");
Expect(1, 917631, '\p{Is_General_Category= _Cf}', "");
Expect(0, 917631, '\p{^Is_General_Category= _Cf}', "");
Expect(0, 917631, '\P{Is_General_Category= _Cf}', "");
Expect(1, 917631, '\P{^Is_General_Category= _Cf}', "");
Expect(0, 917632, '\p{Is_General_Category= _Cf}', "");
Expect(1, 917632, '\p{^Is_General_Category= _Cf}', "");
Expect(1, 917632, '\P{Is_General_Category= _Cf}', "");
Expect(0, 917632, '\P{^Is_General_Category= _Cf}', "");
Error('\p{Is_Gc=:=--format}');
Error('\P{Is_Gc=:=--format}');
Expect(1, 917631, '\p{Is_Gc=format}', "");
Expect(0, 917631, '\p{^Is_Gc=format}', "");
Expect(0, 917631, '\P{Is_Gc=format}', "");
Expect(1, 917631, '\P{^Is_Gc=format}', "");
Expect(0, 917632, '\p{Is_Gc=format}', "");
Expect(1, 917632, '\p{^Is_Gc=format}', "");
Expect(1, 917632, '\P{Is_Gc=format}', "");
Expect(0, 917632, '\P{^Is_Gc=format}', "");
Expect(1, 917631, '\p{Is_Gc=_FORMAT}', "");
Expect(0, 917631, '\p{^Is_Gc=_FORMAT}', "");
Expect(0, 917631, '\P{Is_Gc=_FORMAT}', "");
Expect(1, 917631, '\P{^Is_Gc=_FORMAT}', "");
Expect(0, 917632, '\p{Is_Gc=_FORMAT}', "");
Expect(1, 917632, '\p{^Is_Gc=_FORMAT}', "");
Expect(1, 917632, '\P{Is_Gc=_FORMAT}', "");
Expect(0, 917632, '\P{^Is_Gc=_FORMAT}', "");
Error('\p{Is_Category=:=  Cf}');
Error('\P{Is_Category=:=  Cf}');
Expect(1, 917631, '\p{Is_Category=cf}', "");
Expect(0, 917631, '\p{^Is_Category=cf}', "");
Expect(0, 917631, '\P{Is_Category=cf}', "");
Expect(1, 917631, '\P{^Is_Category=cf}', "");
Expect(0, 917632, '\p{Is_Category=cf}', "");
Expect(1, 917632, '\p{^Is_Category=cf}', "");
Expect(1, 917632, '\P{Is_Category=cf}', "");
Expect(0, 917632, '\P{^Is_Category=cf}', "");
Expect(1, 917631, '\p{Is_Category=_	CF}', "");
Expect(0, 917631, '\p{^Is_Category=_	CF}', "");
Expect(0, 917631, '\P{Is_Category=_	CF}', "");
Expect(1, 917631, '\P{^Is_Category=_	CF}', "");
Expect(0, 917632, '\p{Is_Category=_	CF}', "");
Expect(1, 917632, '\p{^Is_Category=_	CF}', "");
Expect(1, 917632, '\P{Is_Category=_	CF}', "");
Expect(0, 917632, '\P{^Is_Category=_	CF}', "");
Error('\p{General_Category=:= Unassigned}');
Error('\P{General_Category=:= Unassigned}');
Expect(1, 918000, '\p{General_Category=unassigned}', "");
Expect(0, 918000, '\p{^General_Category=unassigned}', "");
Expect(0, 918000, '\P{General_Category=unassigned}', "");
Expect(1, 918000, '\P{^General_Category=unassigned}', "");
Expect(0, 1114109, '\p{General_Category=unassigned}', "");
Expect(1, 1114109, '\p{^General_Category=unassigned}', "");
Expect(1, 1114109, '\P{General_Category=unassigned}', "");
Expect(0, 1114109, '\P{^General_Category=unassigned}', "");
Expect(1, 918000, '\p{General_Category= UNASSIGNED}', "");
Expect(0, 918000, '\p{^General_Category= UNASSIGNED}', "");
Expect(0, 918000, '\P{General_Category= UNASSIGNED}', "");
Expect(1, 918000, '\P{^General_Category= UNASSIGNED}', "");
Expect(0, 1114109, '\p{General_Category= UNASSIGNED}', "");
Expect(1, 1114109, '\p{^General_Category= UNASSIGNED}', "");
Expect(1, 1114109, '\P{General_Category= UNASSIGNED}', "");
Expect(0, 1114109, '\P{^General_Category= UNASSIGNED}', "");
Error('\p{Gc=:=- Cn}');
Error('\P{Gc=:=- Cn}');
Expect(1, 918000, '\p{Gc=cn}', "");
Expect(0, 918000, '\p{^Gc=cn}', "");
Expect(0, 918000, '\P{Gc=cn}', "");
Expect(1, 918000, '\P{^Gc=cn}', "");
Expect(0, 1114109, '\p{Gc=cn}', "");
Expect(1, 1114109, '\p{^Gc=cn}', "");
Expect(1, 1114109, '\P{Gc=cn}', "");
Expect(0, 1114109, '\P{^Gc=cn}', "");
Expect(1, 918000, '\p{Gc=	 Cn}', "");
Expect(0, 918000, '\p{^Gc=	 Cn}', "");
Expect(0, 918000, '\P{Gc=	 Cn}', "");
Expect(1, 918000, '\P{^Gc=	 Cn}', "");
Expect(0, 1114109, '\p{Gc=	 Cn}', "");
Expect(1, 1114109, '\p{^Gc=	 Cn}', "");
Expect(1, 1114109, '\P{Gc=	 Cn}', "");
Expect(0, 1114109, '\P{^Gc=	 Cn}', "");
Error('\p{Category=	:=Unassigned}');
Error('\P{Category=	:=Unassigned}');
Expect(1, 918000, '\p{Category=unassigned}', "");
Expect(0, 918000, '\p{^Category=unassigned}', "");
Expect(0, 918000, '\P{Category=unassigned}', "");
Expect(1, 918000, '\P{^Category=unassigned}', "");
Expect(0, 1114109, '\p{Category=unassigned}', "");
Expect(1, 1114109, '\p{^Category=unassigned}', "");
Expect(1, 1114109, '\P{Category=unassigned}', "");
Expect(0, 1114109, '\P{^Category=unassigned}', "");
Expect(1, 918000, '\p{Category: Unassigned}', "");
Expect(0, 918000, '\p{^Category: Unassigned}', "");
Expect(0, 918000, '\P{Category: Unassigned}', "");
Expect(1, 918000, '\P{^Category: Unassigned}', "");
Expect(0, 1114109, '\p{Category: Unassigned}', "");
Expect(1, 1114109, '\p{^Category: Unassigned}', "");
Expect(1, 1114109, '\P{Category: Unassigned}', "");
Expect(0, 1114109, '\P{^Category: Unassigned}', "");
Error('\p{Is_General_Category=:=_	Cn}');
Error('\P{Is_General_Category=:=_	Cn}');
Expect(1, 918000, '\p{Is_General_Category=cn}', "");
Expect(0, 918000, '\p{^Is_General_Category=cn}', "");
Expect(0, 918000, '\P{Is_General_Category=cn}', "");
Expect(1, 918000, '\P{^Is_General_Category=cn}', "");
Expect(0, 1114109, '\p{Is_General_Category=cn}', "");
Expect(1, 1114109, '\p{^Is_General_Category=cn}', "");
Expect(1, 1114109, '\P{Is_General_Category=cn}', "");
Expect(0, 1114109, '\P{^Is_General_Category=cn}', "");
Expect(1, 918000, '\p{Is_General_Category=	 Cn}', "");
Expect(0, 918000, '\p{^Is_General_Category=	 Cn}', "");
Expect(0, 918000, '\P{Is_General_Category=	 Cn}', "");
Expect(1, 918000, '\P{^Is_General_Category=	 Cn}', "");
Expect(0, 1114109, '\p{Is_General_Category=	 Cn}', "");
Expect(1, 1114109, '\p{^Is_General_Category=	 Cn}', "");
Expect(1, 1114109, '\P{Is_General_Category=	 Cn}', "");
Expect(0, 1114109, '\P{^Is_General_Category=	 Cn}', "");
Error('\p{Is_Gc=_unassigned/a/}');
Error('\P{Is_Gc=_unassigned/a/}');
Expect(1, 918000, '\p{Is_Gc=unassigned}', "");
Expect(0, 918000, '\p{^Is_Gc=unassigned}', "");
Expect(0, 918000, '\P{Is_Gc=unassigned}', "");
Expect(1, 918000, '\P{^Is_Gc=unassigned}', "");
Expect(0, 1114109, '\p{Is_Gc=unassigned}', "");
Expect(1, 1114109, '\p{^Is_Gc=unassigned}', "");
Expect(1, 1114109, '\P{Is_Gc=unassigned}', "");
Expect(0, 1114109, '\P{^Is_Gc=unassigned}', "");
Expect(1, 918000, '\p{Is_Gc:   -Unassigned}', "");
Expect(0, 918000, '\p{^Is_Gc:   -Unassigned}', "");
Expect(0, 918000, '\P{Is_Gc:   -Unassigned}', "");
Expect(1, 918000, '\P{^Is_Gc:   -Unassigned}', "");
Expect(0, 1114109, '\p{Is_Gc:   -Unassigned}', "");
Expect(1, 1114109, '\p{^Is_Gc:   -Unassigned}', "");
Expect(1, 1114109, '\P{Is_Gc:   -Unassigned}', "");
Expect(0, 1114109, '\P{^Is_Gc:   -Unassigned}', "");
Error('\p{Is_Category:/a/--Cn}');
Error('\P{Is_Category:/a/--Cn}');
Expect(1, 918000, '\p{Is_Category=cn}', "");
Expect(0, 918000, '\p{^Is_Category=cn}', "");
Expect(0, 918000, '\P{Is_Category=cn}', "");
Expect(1, 918000, '\P{^Is_Category=cn}', "");
Expect(0, 1114109, '\p{Is_Category=cn}', "");
Expect(1, 1114109, '\p{^Is_Category=cn}', "");
Expect(1, 1114109, '\P{Is_Category=cn}', "");
Expect(0, 1114109, '\P{^Is_Category=cn}', "");
Expect(1, 918000, '\p{Is_Category=_	Cn}', "");
Expect(0, 918000, '\p{^Is_Category=_	Cn}', "");
Expect(0, 918000, '\P{Is_Category=_	Cn}', "");
Expect(1, 918000, '\P{^Is_Category=_	Cn}', "");
Expect(0, 1114109, '\p{Is_Category=_	Cn}', "");
Expect(1, 1114109, '\p{^Is_Category=_	Cn}', "");
Expect(1, 1114109, '\P{Is_Category=_	Cn}', "");
Expect(0, 1114109, '\P{^Is_Category=_	Cn}', "");
Error('\p{General_Category=:=-Private_USE}');
Error('\P{General_Category=:=-Private_USE}');
Expect(1, 1114109, '\p{General_Category=privateuse}', "");
Expect(0, 1114109, '\p{^General_Category=privateuse}', "");
Expect(0, 1114109, '\P{General_Category=privateuse}', "");
Expect(1, 1114109, '\P{^General_Category=privateuse}', "");
Expect(0, 63744, '\p{General_Category=privateuse}', "");
Expect(1, 63744, '\p{^General_Category=privateuse}', "");
Expect(1, 63744, '\P{General_Category=privateuse}', "");
Expect(0, 63744, '\P{^General_Category=privateuse}', "");
Expect(1, 1114109, '\p{General_Category:_Private_Use}', "");
Expect(0, 1114109, '\p{^General_Category:_Private_Use}', "");
Expect(0, 1114109, '\P{General_Category:_Private_Use}', "");
Expect(1, 1114109, '\P{^General_Category:_Private_Use}', "");
Expect(0, 63744, '\p{General_Category:_Private_Use}', "");
Expect(1, 63744, '\p{^General_Category:_Private_Use}', "");
Expect(1, 63744, '\P{General_Category:_Private_Use}', "");
Expect(0, 63744, '\P{^General_Category:_Private_Use}', "");
Error('\p{Gc= :=Co}');
Error('\P{Gc= :=Co}');
Expect(1, 1114109, '\p{Gc=co}', "");
Expect(0, 1114109, '\p{^Gc=co}', "");
Expect(0, 1114109, '\P{Gc=co}', "");
Expect(1, 1114109, '\P{^Gc=co}', "");
Expect(0, 63744, '\p{Gc=co}', "");
Expect(1, 63744, '\p{^Gc=co}', "");
Expect(1, 63744, '\P{Gc=co}', "");
Expect(0, 63744, '\P{^Gc=co}', "");
Expect(1, 1114109, '\p{Gc= _co}', "");
Expect(0, 1114109, '\p{^Gc= _co}', "");
Expect(0, 1114109, '\P{Gc= _co}', "");
Expect(1, 1114109, '\P{^Gc= _co}', "");
Expect(0, 63744, '\p{Gc= _co}', "");
Expect(1, 63744, '\p{^Gc= _co}', "");
Expect(1, 63744, '\P{Gc= _co}', "");
Expect(0, 63744, '\P{^Gc= _co}', "");
Error('\p{Category=/a/-PRIVATE_Use}');
Error('\P{Category=/a/-PRIVATE_Use}');
Expect(1, 1114109, '\p{Category=privateuse}', "");
Expect(0, 1114109, '\p{^Category=privateuse}', "");
Expect(0, 1114109, '\P{Category=privateuse}', "");
Expect(1, 1114109, '\P{^Category=privateuse}', "");
Expect(0, 63744, '\p{Category=privateuse}', "");
Expect(1, 63744, '\p{^Category=privateuse}', "");
Expect(1, 63744, '\P{Category=privateuse}', "");
Expect(0, 63744, '\P{^Category=privateuse}', "");
Expect(1, 1114109, '\p{Category=_	private_Use}', "");
Expect(0, 1114109, '\p{^Category=_	private_Use}', "");
Expect(0, 1114109, '\P{Category=_	private_Use}', "");
Expect(1, 1114109, '\P{^Category=_	private_Use}', "");
Expect(0, 63744, '\p{Category=_	private_Use}', "");
Expect(1, 63744, '\p{^Category=_	private_Use}', "");
Expect(1, 63744, '\P{Category=_	private_Use}', "");
Expect(0, 63744, '\P{^Category=_	private_Use}', "");
Error('\p{Is_General_Category: --Co:=}');
Error('\P{Is_General_Category: --Co:=}');
Expect(1, 1114109, '\p{Is_General_Category=co}', "");
Expect(0, 1114109, '\p{^Is_General_Category=co}', "");
Expect(0, 1114109, '\P{Is_General_Category=co}', "");
Expect(1, 1114109, '\P{^Is_General_Category=co}', "");
Expect(0, 63744, '\p{Is_General_Category=co}', "");
Expect(1, 63744, '\p{^Is_General_Category=co}', "");
Expect(1, 63744, '\P{Is_General_Category=co}', "");
Expect(0, 63744, '\P{^Is_General_Category=co}', "");
Expect(1, 1114109, '\p{Is_General_Category=-_co}', "");
Expect(0, 1114109, '\p{^Is_General_Category=-_co}', "");
Expect(0, 1114109, '\P{Is_General_Category=-_co}', "");
Expect(1, 1114109, '\P{^Is_General_Category=-_co}', "");
Expect(0, 63744, '\p{Is_General_Category=-_co}', "");
Expect(1, 63744, '\p{^Is_General_Category=-_co}', "");
Expect(1, 63744, '\P{Is_General_Category=-_co}', "");
Expect(0, 63744, '\P{^Is_General_Category=-_co}', "");
Error('\p{Is_Gc=_:=Private_Use}');
Error('\P{Is_Gc=_:=Private_Use}');
Expect(1, 1114109, '\p{Is_Gc=privateuse}', "");
Expect(0, 1114109, '\p{^Is_Gc=privateuse}', "");
Expect(0, 1114109, '\P{Is_Gc=privateuse}', "");
Expect(1, 1114109, '\P{^Is_Gc=privateuse}', "");
Expect(0, 63744, '\p{Is_Gc=privateuse}', "");
Expect(1, 63744, '\p{^Is_Gc=privateuse}', "");
Expect(1, 63744, '\P{Is_Gc=privateuse}', "");
Expect(0, 63744, '\P{^Is_Gc=privateuse}', "");
Expect(1, 1114109, '\p{Is_Gc:	_Private_USE}', "");
Expect(0, 1114109, '\p{^Is_Gc:	_Private_USE}', "");
Expect(0, 1114109, '\P{Is_Gc:	_Private_USE}', "");
Expect(1, 1114109, '\P{^Is_Gc:	_Private_USE}', "");
Expect(0, 63744, '\p{Is_Gc:	_Private_USE}', "");
Expect(1, 63744, '\p{^Is_Gc:	_Private_USE}', "");
Expect(1, 63744, '\P{Is_Gc:	_Private_USE}', "");
Expect(0, 63744, '\P{^Is_Gc:	_Private_USE}', "");
Error('\p{Is_Category= 	Co/a/}');
Error('\P{Is_Category= 	Co/a/}');
Expect(1, 1114109, '\p{Is_Category=co}', "");
Expect(0, 1114109, '\p{^Is_Category=co}', "");
Expect(0, 1114109, '\P{Is_Category=co}', "");
Expect(1, 1114109, '\P{^Is_Category=co}', "");
Expect(0, 63744, '\p{Is_Category=co}', "");
Expect(1, 63744, '\p{^Is_Category=co}', "");
Expect(1, 63744, '\P{Is_Category=co}', "");
Expect(0, 63744, '\P{^Is_Category=co}', "");
Expect(1, 1114109, '\p{Is_Category=--Co}', "");
Expect(0, 1114109, '\p{^Is_Category=--Co}', "");
Expect(0, 1114109, '\P{Is_Category=--Co}', "");
Expect(1, 1114109, '\P{^Is_Category=--Co}', "");
Expect(0, 63744, '\p{Is_Category=--Co}', "");
Expect(1, 63744, '\p{^Is_Category=--Co}', "");
Expect(1, 63744, '\P{Is_Category=--Co}', "");
Expect(0, 63744, '\P{^Is_Category=--Co}', "");
Error('\p{General_Category=:=-_surrogate}');
Error('\P{General_Category=:=-_surrogate}');
Expect(1, 57343, '\p{General_Category=surrogate}', "");
Expect(0, 57343, '\p{^General_Category=surrogate}', "");
Expect(0, 57343, '\P{General_Category=surrogate}', "");
Expect(1, 57343, '\P{^General_Category=surrogate}', "");
Expect(0, 57344, '\p{General_Category=surrogate}', "");
Expect(1, 57344, '\p{^General_Category=surrogate}', "");
Expect(1, 57344, '\P{General_Category=surrogate}', "");
Expect(0, 57344, '\P{^General_Category=surrogate}', "");
Expect(1, 57343, '\p{General_Category=- SURROGATE}', "");
Expect(0, 57343, '\p{^General_Category=- SURROGATE}', "");
Expect(0, 57343, '\P{General_Category=- SURROGATE}', "");
Expect(1, 57343, '\P{^General_Category=- SURROGATE}', "");
Expect(0, 57344, '\p{General_Category=- SURROGATE}', "");
Expect(1, 57344, '\p{^General_Category=- SURROGATE}', "");
Expect(1, 57344, '\P{General_Category=- SURROGATE}', "");
Expect(0, 57344, '\P{^General_Category=- SURROGATE}', "");
Error('\p{Gc=/a/CS}');
Error('\P{Gc=/a/CS}');
Expect(1, 57343, '\p{Gc=cs}', "");
Expect(0, 57343, '\p{^Gc=cs}', "");
Expect(0, 57343, '\P{Gc=cs}', "");
Expect(1, 57343, '\P{^Gc=cs}', "");
Expect(0, 57344, '\p{Gc=cs}', "");
Expect(1, 57344, '\p{^Gc=cs}', "");
Expect(1, 57344, '\P{Gc=cs}', "");
Expect(0, 57344, '\P{^Gc=cs}', "");
Expect(1, 57343, '\p{Gc= cs}', "");
Expect(0, 57343, '\p{^Gc= cs}', "");
Expect(0, 57343, '\P{Gc= cs}', "");
Expect(1, 57343, '\P{^Gc= cs}', "");
Expect(0, 57344, '\p{Gc= cs}', "");
Expect(1, 57344, '\p{^Gc= cs}', "");
Expect(1, 57344, '\P{Gc= cs}', "");
Expect(0, 57344, '\P{^Gc= cs}', "");
Error('\p{Category=	/a/Surrogate}');
Error('\P{Category=	/a/Surrogate}');
Expect(1, 57343, '\p{Category=surrogate}', "");
Expect(0, 57343, '\p{^Category=surrogate}', "");
Expect(0, 57343, '\P{Category=surrogate}', "");
Expect(1, 57343, '\P{^Category=surrogate}', "");
Expect(0, 57344, '\p{Category=surrogate}', "");
Expect(1, 57344, '\p{^Category=surrogate}', "");
Expect(1, 57344, '\P{Category=surrogate}', "");
Expect(0, 57344, '\P{^Category=surrogate}', "");
Expect(1, 57343, '\p{Category=- Surrogate}', "");
Expect(0, 57343, '\p{^Category=- Surrogate}', "");
Expect(0, 57343, '\P{Category=- Surrogate}', "");
Expect(1, 57343, '\P{^Category=- Surrogate}', "");
Expect(0, 57344, '\p{Category=- Surrogate}', "");
Expect(1, 57344, '\p{^Category=- Surrogate}', "");
Expect(1, 57344, '\P{Category=- Surrogate}', "");
Expect(0, 57344, '\P{^Category=- Surrogate}', "");
Error('\p{Is_General_Category= 	CS/a/}');
Error('\P{Is_General_Category= 	CS/a/}');
Expect(1, 57343, '\p{Is_General_Category=cs}', "");
Expect(0, 57343, '\p{^Is_General_Category=cs}', "");
Expect(0, 57343, '\P{Is_General_Category=cs}', "");
Expect(1, 57343, '\P{^Is_General_Category=cs}', "");
Expect(0, 57344, '\p{Is_General_Category=cs}', "");
Expect(1, 57344, '\p{^Is_General_Category=cs}', "");
Expect(1, 57344, '\P{Is_General_Category=cs}', "");
Expect(0, 57344, '\P{^Is_General_Category=cs}', "");
Expect(1, 57343, '\p{Is_General_Category=_ CS}', "");
Expect(0, 57343, '\p{^Is_General_Category=_ CS}', "");
Expect(0, 57343, '\P{Is_General_Category=_ CS}', "");
Expect(1, 57343, '\P{^Is_General_Category=_ CS}', "");
Expect(0, 57344, '\p{Is_General_Category=_ CS}', "");
Expect(1, 57344, '\p{^Is_General_Category=_ CS}', "");
Expect(1, 57344, '\P{Is_General_Category=_ CS}', "");
Expect(0, 57344, '\P{^Is_General_Category=_ CS}', "");
Error('\p{Is_Gc=:=		surrogate}');
Error('\P{Is_Gc=:=		surrogate}');
Expect(1, 57343, '\p{Is_Gc=surrogate}', "");
Expect(0, 57343, '\p{^Is_Gc=surrogate}', "");
Expect(0, 57343, '\P{Is_Gc=surrogate}', "");
Expect(1, 57343, '\P{^Is_Gc=surrogate}', "");
Expect(0, 57344, '\p{Is_Gc=surrogate}', "");
Expect(1, 57344, '\p{^Is_Gc=surrogate}', "");
Expect(1, 57344, '\P{Is_Gc=surrogate}', "");
Expect(0, 57344, '\P{^Is_Gc=surrogate}', "");
Expect(1, 57343, '\p{Is_Gc=--Surrogate}', "");
Expect(0, 57343, '\p{^Is_Gc=--Surrogate}', "");
Expect(0, 57343, '\P{Is_Gc=--Surrogate}', "");
Expect(1, 57343, '\P{^Is_Gc=--Surrogate}', "");
Expect(0, 57344, '\p{Is_Gc=--Surrogate}', "");
Expect(1, 57344, '\p{^Is_Gc=--Surrogate}', "");
Expect(1, 57344, '\P{Is_Gc=--Surrogate}', "");
Expect(0, 57344, '\P{^Is_Gc=--Surrogate}', "");
Error('\p{Is_Category=	 Cs/a/}');
Error('\P{Is_Category=	 Cs/a/}');
Expect(1, 57343, '\p{Is_Category=cs}', "");
Expect(0, 57343, '\p{^Is_Category=cs}', "");
Expect(0, 57343, '\P{Is_Category=cs}', "");
Expect(1, 57343, '\P{^Is_Category=cs}', "");
Expect(0, 57344, '\p{Is_Category=cs}', "");
Expect(1, 57344, '\p{^Is_Category=cs}', "");
Expect(1, 57344, '\P{Is_Category=cs}', "");
Expect(0, 57344, '\P{^Is_Category=cs}', "");
Expect(1, 57343, '\p{Is_Category=-_CS}', "");
Expect(0, 57343, '\p{^Is_Category=-_CS}', "");
Expect(0, 57343, '\P{Is_Category=-_CS}', "");
Expect(1, 57343, '\P{^Is_Category=-_CS}', "");
Expect(0, 57344, '\p{Is_Category=-_CS}', "");
Expect(1, 57344, '\p{^Is_Category=-_CS}', "");
Expect(1, 57344, '\P{Is_Category=-_CS}', "");
Expect(0, 57344, '\P{^Is_Category=-_CS}', "");
Error('\p{General_Category=:=Letter}');
Error('\P{General_Category=:=Letter}');
Expect(1, 195101, '\p{General_Category=letter}', "");
Expect(0, 195101, '\p{^General_Category=letter}', "");
Expect(0, 195101, '\P{General_Category=letter}', "");
Expect(1, 195101, '\P{^General_Category=letter}', "");
Expect(0, 195102, '\p{General_Category=letter}', "");
Expect(1, 195102, '\p{^General_Category=letter}', "");
Expect(1, 195102, '\P{General_Category=letter}', "");
Expect(0, 195102, '\P{^General_Category=letter}', "");
Expect(1, 195101, '\p{General_Category=-letter}', "");
Expect(0, 195101, '\p{^General_Category=-letter}', "");
Expect(0, 195101, '\P{General_Category=-letter}', "");
Expect(1, 195101, '\P{^General_Category=-letter}', "");
Expect(0, 195102, '\p{General_Category=-letter}', "");
Expect(1, 195102, '\p{^General_Category=-letter}', "");
Expect(1, 195102, '\P{General_Category=-letter}', "");
Expect(0, 195102, '\P{^General_Category=-letter}', "");
Error('\p{Gc=		L/a/}');
Error('\P{Gc=		L/a/}');
Expect(1, 195101, '\p{Gc=l}', "");
Expect(0, 195101, '\p{^Gc=l}', "");
Expect(0, 195101, '\P{Gc=l}', "");
Expect(1, 195101, '\P{^Gc=l}', "");
Expect(0, 195102, '\p{Gc=l}', "");
Expect(1, 195102, '\p{^Gc=l}', "");
Expect(1, 195102, '\P{Gc=l}', "");
Expect(0, 195102, '\P{^Gc=l}', "");
Expect(1, 195101, '\p{Gc=__L}', "");
Expect(0, 195101, '\p{^Gc=__L}', "");
Expect(0, 195101, '\P{Gc=__L}', "");
Expect(1, 195101, '\P{^Gc=__L}', "");
Expect(0, 195102, '\p{Gc=__L}', "");
Expect(1, 195102, '\p{^Gc=__L}', "");
Expect(1, 195102, '\P{Gc=__L}', "");
Expect(0, 195102, '\P{^Gc=__L}', "");
Error('\p{Category=_/a/letter}');
Error('\P{Category=_/a/letter}');
Expect(1, 195101, '\p{Category=letter}', "");
Expect(0, 195101, '\p{^Category=letter}', "");
Expect(0, 195101, '\P{Category=letter}', "");
Expect(1, 195101, '\P{^Category=letter}', "");
Expect(0, 195102, '\p{Category=letter}', "");
Expect(1, 195102, '\p{^Category=letter}', "");
Expect(1, 195102, '\P{Category=letter}', "");
Expect(0, 195102, '\P{^Category=letter}', "");
Expect(1, 195101, '\p{Category= -Letter}', "");
Expect(0, 195101, '\p{^Category= -Letter}', "");
Expect(0, 195101, '\P{Category= -Letter}', "");
Expect(1, 195101, '\P{^Category= -Letter}', "");
Expect(0, 195102, '\p{Category= -Letter}', "");
Expect(1, 195102, '\p{^Category= -Letter}', "");
Expect(1, 195102, '\P{Category= -Letter}', "");
Expect(0, 195102, '\P{^Category= -Letter}', "");
Error('\p{Is_General_Category=:=_L}');
Error('\P{Is_General_Category=:=_L}');
Expect(1, 195101, '\p{Is_General_Category=l}', "");
Expect(0, 195101, '\p{^Is_General_Category=l}', "");
Expect(0, 195101, '\P{Is_General_Category=l}', "");
Expect(1, 195101, '\P{^Is_General_Category=l}', "");
Expect(0, 195102, '\p{Is_General_Category=l}', "");
Expect(1, 195102, '\p{^Is_General_Category=l}', "");
Expect(1, 195102, '\P{Is_General_Category=l}', "");
Expect(0, 195102, '\P{^Is_General_Category=l}', "");
Expect(1, 195101, '\p{Is_General_Category=--L}', "");
Expect(0, 195101, '\p{^Is_General_Category=--L}', "");
Expect(0, 195101, '\P{Is_General_Category=--L}', "");
Expect(1, 195101, '\P{^Is_General_Category=--L}', "");
Expect(0, 195102, '\p{Is_General_Category=--L}', "");
Expect(1, 195102, '\p{^Is_General_Category=--L}', "");
Expect(1, 195102, '\P{Is_General_Category=--L}', "");
Expect(0, 195102, '\P{^Is_General_Category=--L}', "");
Error('\p{Is_Gc=	:=LETTER}');
Error('\P{Is_Gc=	:=LETTER}');
Expect(1, 195101, '\p{Is_Gc=letter}', "");
Expect(0, 195101, '\p{^Is_Gc=letter}', "");
Expect(0, 195101, '\P{Is_Gc=letter}', "");
Expect(1, 195101, '\P{^Is_Gc=letter}', "");
Expect(0, 195102, '\p{Is_Gc=letter}', "");
Expect(1, 195102, '\p{^Is_Gc=letter}', "");
Expect(1, 195102, '\P{Is_Gc=letter}', "");
Expect(0, 195102, '\P{^Is_Gc=letter}', "");
Expect(1, 195101, '\p{Is_Gc=-Letter}', "");
Expect(0, 195101, '\p{^Is_Gc=-Letter}', "");
Expect(0, 195101, '\P{Is_Gc=-Letter}', "");
Expect(1, 195101, '\P{^Is_Gc=-Letter}', "");
Expect(0, 195102, '\p{Is_Gc=-Letter}', "");
Expect(1, 195102, '\p{^Is_Gc=-Letter}', "");
Expect(1, 195102, '\P{Is_Gc=-Letter}', "");
Expect(0, 195102, '\P{^Is_Gc=-Letter}', "");
Error('\p{Is_Category= _L/a/}');
Error('\P{Is_Category= _L/a/}');
Expect(1, 195101, '\p{Is_Category=l}', "");
Expect(0, 195101, '\p{^Is_Category=l}', "");
Expect(0, 195101, '\P{Is_Category=l}', "");
Expect(1, 195101, '\P{^Is_Category=l}', "");
Expect(0, 195102, '\p{Is_Category=l}', "");
Expect(1, 195102, '\p{^Is_Category=l}', "");
Expect(1, 195102, '\P{Is_Category=l}', "");
Expect(0, 195102, '\P{^Is_Category=l}', "");
Expect(1, 195101, '\p{Is_Category=  L}', "");
Expect(0, 195101, '\p{^Is_Category=  L}', "");
Expect(0, 195101, '\P{Is_Category=  L}', "");
Expect(1, 195101, '\P{^Is_Category=  L}', "");
Expect(0, 195102, '\p{Is_Category=  L}', "");
Expect(1, 195102, '\p{^Is_Category=  L}', "");
Expect(1, 195102, '\P{Is_Category=  L}', "");
Expect(0, 195102, '\P{^Is_Category=  L}', "");
Error('\p{General_Category=:= _cased_Letter}');
Error('\P{General_Category=:= _cased_Letter}');
Expect(1, 120779, '\p{General_Category=casedletter}', "");
Expect(0, 120779, '\p{^General_Category=casedletter}', "");
Expect(0, 120779, '\P{General_Category=casedletter}', "");
Expect(1, 120779, '\P{^General_Category=casedletter}', "");
Expect(0, 120780, '\p{General_Category=casedletter}', "");
Expect(1, 120780, '\p{^General_Category=casedletter}', "");
Expect(1, 120780, '\P{General_Category=casedletter}', "");
Expect(0, 120780, '\P{^General_Category=casedletter}', "");
Expect(1, 120779, '\p{General_Category=-Cased_Letter}', "");
Expect(0, 120779, '\p{^General_Category=-Cased_Letter}', "");
Expect(0, 120779, '\P{General_Category=-Cased_Letter}', "");
Expect(1, 120779, '\P{^General_Category=-Cased_Letter}', "");
Expect(0, 120780, '\p{General_Category=-Cased_Letter}', "");
Expect(1, 120780, '\p{^General_Category=-Cased_Letter}', "");
Expect(1, 120780, '\P{General_Category=-Cased_Letter}', "");
Expect(0, 120780, '\P{^General_Category=-Cased_Letter}', "");
Error('\p{Gc=/a/LC}');
Error('\P{Gc=/a/LC}');
Expect(1, 120779, '\p{Gc=lc}', "");
Expect(0, 120779, '\p{^Gc=lc}', "");
Expect(0, 120779, '\P{Gc=lc}', "");
Expect(1, 120779, '\P{^Gc=lc}', "");
Expect(0, 120780, '\p{Gc=lc}', "");
Expect(1, 120780, '\p{^Gc=lc}', "");
Expect(1, 120780, '\P{Gc=lc}', "");
Expect(0, 120780, '\P{^Gc=lc}', "");
Expect(1, 120779, '\p{Gc: 		LC}', "");
Expect(0, 120779, '\p{^Gc: 		LC}', "");
Expect(0, 120779, '\P{Gc: 		LC}', "");
Expect(1, 120779, '\P{^Gc: 		LC}', "");
Expect(0, 120780, '\p{Gc: 		LC}', "");
Expect(1, 120780, '\p{^Gc: 		LC}', "");
Expect(1, 120780, '\P{Gc: 		LC}', "");
Expect(0, 120780, '\P{^Gc: 		LC}', "");
Error('\p{Category=/a/L_}');
Error('\P{Category=/a/L_}');
Expect(1, 120779, '\p{Category=l_}', "");
Expect(0, 120779, '\p{^Category=l_}', "");
Expect(0, 120779, '\P{Category=l_}', "");
Expect(1, 120779, '\P{^Category=l_}', "");
Expect(0, 120780, '\p{Category=l_}', "");
Expect(1, 120780, '\p{^Category=l_}', "");
Expect(1, 120780, '\P{Category=l_}', "");
Expect(0, 120780, '\P{^Category=l_}', "");
Expect(1, 120779, '\p{Category= _L_}', "");
Expect(0, 120779, '\p{^Category= _L_}', "");
Expect(0, 120779, '\P{Category= _L_}', "");
Expect(1, 120779, '\P{^Category= _L_}', "");
Expect(0, 120780, '\p{Category= _L_}', "");
Expect(1, 120780, '\p{^Category= _L_}', "");
Expect(1, 120780, '\P{Category= _L_}', "");
Expect(0, 120780, '\P{^Category= _L_}', "");
Error('\p{Is_General_Category=-_L&:=}');
Error('\P{Is_General_Category=-_L&:=}');
Expect(1, 120779, '\p{Is_General_Category=l&}', "");
Expect(0, 120779, '\p{^Is_General_Category=l&}', "");
Expect(0, 120779, '\P{Is_General_Category=l&}', "");
Expect(1, 120779, '\P{^Is_General_Category=l&}', "");
Expect(0, 120780, '\p{Is_General_Category=l&}', "");
Expect(1, 120780, '\p{^Is_General_Category=l&}', "");
Expect(1, 120780, '\P{Is_General_Category=l&}', "");
Expect(0, 120780, '\P{^Is_General_Category=l&}', "");
Expect(1, 120779, '\p{Is_General_Category=__L&}', "");
Expect(0, 120779, '\p{^Is_General_Category=__L&}', "");
Expect(0, 120779, '\P{Is_General_Category=__L&}', "");
Expect(1, 120779, '\P{^Is_General_Category=__L&}', "");
Expect(0, 120780, '\p{Is_General_Category=__L&}', "");
Expect(1, 120780, '\p{^Is_General_Category=__L&}', "");
Expect(1, 120780, '\P{Is_General_Category=__L&}', "");
Expect(0, 120780, '\P{^Is_General_Category=__L&}', "");
Error('\p{Is_Gc=:=	CASED_letter}');
Error('\P{Is_Gc=:=	CASED_letter}');
Expect(1, 120779, '\p{Is_Gc=casedletter}', "");
Expect(0, 120779, '\p{^Is_Gc=casedletter}', "");
Expect(0, 120779, '\P{Is_Gc=casedletter}', "");
Expect(1, 120779, '\P{^Is_Gc=casedletter}', "");
Expect(0, 120780, '\p{Is_Gc=casedletter}', "");
Expect(1, 120780, '\p{^Is_Gc=casedletter}', "");
Expect(1, 120780, '\P{Is_Gc=casedletter}', "");
Expect(0, 120780, '\P{^Is_Gc=casedletter}', "");
Expect(1, 120779, '\p{Is_Gc= cased_LETTER}', "");
Expect(0, 120779, '\p{^Is_Gc= cased_LETTER}', "");
Expect(0, 120779, '\P{Is_Gc= cased_LETTER}', "");
Expect(1, 120779, '\P{^Is_Gc= cased_LETTER}', "");
Expect(0, 120780, '\p{Is_Gc= cased_LETTER}', "");
Expect(1, 120780, '\p{^Is_Gc= cased_LETTER}', "");
Expect(1, 120780, '\P{Is_Gc= cased_LETTER}', "");
Expect(0, 120780, '\P{^Is_Gc= cased_LETTER}', "");
Error('\p{Is_Category=_/a/LC}');
Error('\P{Is_Category=_/a/LC}');
Expect(1, 120779, '\p{Is_Category=lc}', "");
Expect(0, 120779, '\p{^Is_Category=lc}', "");
Expect(0, 120779, '\P{Is_Category=lc}', "");
Expect(1, 120779, '\P{^Is_Category=lc}', "");
Expect(0, 120780, '\p{Is_Category=lc}', "");
Expect(1, 120780, '\p{^Is_Category=lc}', "");
Expect(1, 120780, '\P{Is_Category=lc}', "");
Expect(0, 120780, '\P{^Is_Category=lc}', "");
Expect(1, 120779, '\p{Is_Category=	-LC}', "");
Expect(0, 120779, '\p{^Is_Category=	-LC}', "");
Expect(0, 120779, '\P{Is_Category=	-LC}', "");
Expect(1, 120779, '\P{^Is_Category=	-LC}', "");
Expect(0, 120780, '\p{Is_Category=	-LC}', "");
Expect(1, 120780, '\p{^Is_Category=	-LC}', "");
Expect(1, 120780, '\P{Is_Category=	-LC}', "");
Expect(0, 120780, '\P{^Is_Category=	-LC}', "");
Error('\p{General_Category:_/a/Lowercase_Letter}');
Error('\P{General_Category:_/a/Lowercase_Letter}');
Expect(1, 120779, '\p{General_Category=lowercaseletter}', "");
Expect(0, 120779, '\p{^General_Category=lowercaseletter}', "");
Expect(0, 120779, '\P{General_Category=lowercaseletter}', "");
Expect(1, 120779, '\P{^General_Category=lowercaseletter}', "");
Expect(0, 120780, '\p{General_Category=lowercaseletter}', "");
Expect(1, 120780, '\p{^General_Category=lowercaseletter}', "");
Expect(1, 120780, '\P{General_Category=lowercaseletter}', "");
Expect(0, 120780, '\P{^General_Category=lowercaseletter}', "");
Expect(1, 120779, '\p{General_Category= 	Lowercase_letter}', "");
Expect(0, 120779, '\p{^General_Category= 	Lowercase_letter}', "");
Expect(0, 120779, '\P{General_Category= 	Lowercase_letter}', "");
Expect(1, 120779, '\P{^General_Category= 	Lowercase_letter}', "");
Expect(0, 120780, '\p{General_Category= 	Lowercase_letter}', "");
Expect(1, 120780, '\p{^General_Category= 	Lowercase_letter}', "");
Expect(1, 120780, '\P{General_Category= 	Lowercase_letter}', "");
Expect(0, 120780, '\P{^General_Category= 	Lowercase_letter}', "");
Error('\p{Gc=_-Ll:=}');
Error('\P{Gc=_-Ll:=}');
Expect(1, 120779, '\p{Gc=ll}', "");
Expect(0, 120779, '\p{^Gc=ll}', "");
Expect(0, 120779, '\P{Gc=ll}', "");
Expect(1, 120779, '\P{^Gc=ll}', "");
Expect(0, 120780, '\p{Gc=ll}', "");
Expect(1, 120780, '\p{^Gc=ll}', "");
Expect(1, 120780, '\P{Gc=ll}', "");
Expect(0, 120780, '\P{^Gc=ll}', "");
Expect(1, 120779, '\p{Gc=_-ll}', "");
Expect(0, 120779, '\p{^Gc=_-ll}', "");
Expect(0, 120779, '\P{Gc=_-ll}', "");
Expect(1, 120779, '\P{^Gc=_-ll}', "");
Expect(0, 120780, '\p{Gc=_-ll}', "");
Expect(1, 120780, '\p{^Gc=_-ll}', "");
Expect(1, 120780, '\P{Gc=_-ll}', "");
Expect(0, 120780, '\P{^Gc=_-ll}', "");
Error('\p{Category=/a/		Lowercase_Letter}');
Error('\P{Category=/a/		Lowercase_Letter}');
Expect(1, 120779, '\p{Category=lowercaseletter}', "");
Expect(0, 120779, '\p{^Category=lowercaseletter}', "");
Expect(0, 120779, '\P{Category=lowercaseletter}', "");
Expect(1, 120779, '\P{^Category=lowercaseletter}', "");
Expect(0, 120780, '\p{Category=lowercaseletter}', "");
Expect(1, 120780, '\p{^Category=lowercaseletter}', "");
Expect(1, 120780, '\P{Category=lowercaseletter}', "");
Expect(0, 120780, '\P{^Category=lowercaseletter}', "");
Expect(1, 120779, '\p{Category=		lowercase_LETTER}', "");
Expect(0, 120779, '\p{^Category=		lowercase_LETTER}', "");
Expect(0, 120779, '\P{Category=		lowercase_LETTER}', "");
Expect(1, 120779, '\P{^Category=		lowercase_LETTER}', "");
Expect(0, 120780, '\p{Category=		lowercase_LETTER}', "");
Expect(1, 120780, '\p{^Category=		lowercase_LETTER}', "");
Expect(1, 120780, '\P{Category=		lowercase_LETTER}', "");
Expect(0, 120780, '\P{^Category=		lowercase_LETTER}', "");
Error('\p{Is_General_Category=/a/_Ll}');
Error('\P{Is_General_Category=/a/_Ll}');
Expect(1, 120779, '\p{Is_General_Category=ll}', "");
Expect(0, 120779, '\p{^Is_General_Category=ll}', "");
Expect(0, 120779, '\P{Is_General_Category=ll}', "");
Expect(1, 120779, '\P{^Is_General_Category=ll}', "");
Expect(0, 120780, '\p{Is_General_Category=ll}', "");
Expect(1, 120780, '\p{^Is_General_Category=ll}', "");
Expect(1, 120780, '\P{Is_General_Category=ll}', "");
Expect(0, 120780, '\P{^Is_General_Category=ll}', "");
Expect(1, 120779, '\p{Is_General_Category= Ll}', "");
Expect(0, 120779, '\p{^Is_General_Category= Ll}', "");
Expect(0, 120779, '\P{Is_General_Category= Ll}', "");
Expect(1, 120779, '\P{^Is_General_Category= Ll}', "");
Expect(0, 120780, '\p{Is_General_Category= Ll}', "");
Expect(1, 120780, '\p{^Is_General_Category= Ll}', "");
Expect(1, 120780, '\P{Is_General_Category= Ll}', "");
Expect(0, 120780, '\P{^Is_General_Category= Ll}', "");
Error('\p{Is_Gc:	__LOWERCASE_LETTER/a/}');
Error('\P{Is_Gc:	__LOWERCASE_LETTER/a/}');
Expect(1, 120779, '\p{Is_Gc=lowercaseletter}', "");
Expect(0, 120779, '\p{^Is_Gc=lowercaseletter}', "");
Expect(0, 120779, '\P{Is_Gc=lowercaseletter}', "");
Expect(1, 120779, '\P{^Is_Gc=lowercaseletter}', "");
Expect(0, 120780, '\p{Is_Gc=lowercaseletter}', "");
Expect(1, 120780, '\p{^Is_Gc=lowercaseletter}', "");
Expect(1, 120780, '\P{Is_Gc=lowercaseletter}', "");
Expect(0, 120780, '\P{^Is_Gc=lowercaseletter}', "");
Expect(1, 120779, '\p{Is_Gc=-Lowercase_LETTER}', "");
Expect(0, 120779, '\p{^Is_Gc=-Lowercase_LETTER}', "");
Expect(0, 120779, '\P{Is_Gc=-Lowercase_LETTER}', "");
Expect(1, 120779, '\P{^Is_Gc=-Lowercase_LETTER}', "");
Expect(0, 120780, '\p{Is_Gc=-Lowercase_LETTER}', "");
Expect(1, 120780, '\p{^Is_Gc=-Lowercase_LETTER}', "");
Expect(1, 120780, '\P{Is_Gc=-Lowercase_LETTER}', "");
Expect(0, 120780, '\P{^Is_Gc=-Lowercase_LETTER}', "");
Error('\p{Is_Category=	Ll/a/}');
Error('\P{Is_Category=	Ll/a/}');
Expect(1, 120779, '\p{Is_Category=ll}', "");
Expect(0, 120779, '\p{^Is_Category=ll}', "");
Expect(0, 120779, '\P{Is_Category=ll}', "");
Expect(1, 120779, '\P{^Is_Category=ll}', "");
Expect(0, 120780, '\p{Is_Category=ll}', "");
Expect(1, 120780, '\p{^Is_Category=ll}', "");
Expect(1, 120780, '\P{Is_Category=ll}', "");
Expect(0, 120780, '\P{^Is_Category=ll}', "");
Expect(1, 120779, '\p{Is_Category=-_Ll}', "");
Expect(0, 120779, '\p{^Is_Category=-_Ll}', "");
Expect(0, 120779, '\P{Is_Category=-_Ll}', "");
Expect(1, 120779, '\P{^Is_Category=-_Ll}', "");
Expect(0, 120780, '\p{Is_Category=-_Ll}', "");
Expect(1, 120780, '\p{^Is_Category=-_Ll}', "");
Expect(1, 120780, '\P{Is_Category=-_Ll}', "");
Expect(0, 120780, '\P{^Is_Category=-_Ll}', "");
Error('\p{General_Category= _modifier_Letter/a/}');
Error('\P{General_Category= _modifier_Letter/a/}');
Expect(1, 94111, '\p{General_Category=modifierletter}', "");
Expect(0, 94111, '\p{^General_Category=modifierletter}', "");
Expect(0, 94111, '\P{General_Category=modifierletter}', "");
Expect(1, 94111, '\P{^General_Category=modifierletter}', "");
Expect(0, 94112, '\p{General_Category=modifierletter}', "");
Expect(1, 94112, '\p{^General_Category=modifierletter}', "");
Expect(1, 94112, '\P{General_Category=modifierletter}', "");
Expect(0, 94112, '\P{^General_Category=modifierletter}', "");
Expect(1, 94111, '\p{General_Category=_ modifier_LETTER}', "");
Expect(0, 94111, '\p{^General_Category=_ modifier_LETTER}', "");
Expect(0, 94111, '\P{General_Category=_ modifier_LETTER}', "");
Expect(1, 94111, '\P{^General_Category=_ modifier_LETTER}', "");
Expect(0, 94112, '\p{General_Category=_ modifier_LETTER}', "");
Expect(1, 94112, '\p{^General_Category=_ modifier_LETTER}', "");
Expect(1, 94112, '\P{General_Category=_ modifier_LETTER}', "");
Expect(0, 94112, '\P{^General_Category=_ modifier_LETTER}', "");
Error('\p{Gc=- Lm/a/}');
Error('\P{Gc=- Lm/a/}');
Expect(1, 94111, '\p{Gc=lm}', "");
Expect(0, 94111, '\p{^Gc=lm}', "");
Expect(0, 94111, '\P{Gc=lm}', "");
Expect(1, 94111, '\P{^Gc=lm}', "");
Expect(0, 94112, '\p{Gc=lm}', "");
Expect(1, 94112, '\p{^Gc=lm}', "");
Expect(1, 94112, '\P{Gc=lm}', "");
Expect(0, 94112, '\P{^Gc=lm}', "");
Expect(1, 94111, '\p{Gc: __LM}', "");
Expect(0, 94111, '\p{^Gc: __LM}', "");
Expect(0, 94111, '\P{Gc: __LM}', "");
Expect(1, 94111, '\P{^Gc: __LM}', "");
Expect(0, 94112, '\p{Gc: __LM}', "");
Expect(1, 94112, '\p{^Gc: __LM}', "");
Expect(1, 94112, '\P{Gc: __LM}', "");
Expect(0, 94112, '\P{^Gc: __LM}', "");
Error('\p{Category= -modifier_Letter:=}');
Error('\P{Category= -modifier_Letter:=}');
Expect(1, 94111, '\p{Category=modifierletter}', "");
Expect(0, 94111, '\p{^Category=modifierletter}', "");
Expect(0, 94111, '\P{Category=modifierletter}', "");
Expect(1, 94111, '\P{^Category=modifierletter}', "");
Expect(0, 94112, '\p{Category=modifierletter}', "");
Expect(1, 94112, '\p{^Category=modifierletter}', "");
Expect(1, 94112, '\P{Category=modifierletter}', "");
Expect(0, 94112, '\P{^Category=modifierletter}', "");
Expect(1, 94111, '\p{Category=_ Modifier_LETTER}', "");
Expect(0, 94111, '\p{^Category=_ Modifier_LETTER}', "");
Expect(0, 94111, '\P{Category=_ Modifier_LETTER}', "");
Expect(1, 94111, '\P{^Category=_ Modifier_LETTER}', "");
Expect(0, 94112, '\p{Category=_ Modifier_LETTER}', "");
Expect(1, 94112, '\p{^Category=_ Modifier_LETTER}', "");
Expect(1, 94112, '\P{Category=_ Modifier_LETTER}', "");
Expect(0, 94112, '\P{^Category=_ Modifier_LETTER}', "");
Error('\p{Is_General_Category=:=	_LM}');
Error('\P{Is_General_Category=:=	_LM}');
Expect(1, 94111, '\p{Is_General_Category=lm}', "");
Expect(0, 94111, '\p{^Is_General_Category=lm}', "");
Expect(0, 94111, '\P{Is_General_Category=lm}', "");
Expect(1, 94111, '\P{^Is_General_Category=lm}', "");
Expect(0, 94112, '\p{Is_General_Category=lm}', "");
Expect(1, 94112, '\p{^Is_General_Category=lm}', "");
Expect(1, 94112, '\P{Is_General_Category=lm}', "");
Expect(0, 94112, '\P{^Is_General_Category=lm}', "");
Expect(1, 94111, '\p{Is_General_Category=- LM}', "");
Expect(0, 94111, '\p{^Is_General_Category=- LM}', "");
Expect(0, 94111, '\P{Is_General_Category=- LM}', "");
Expect(1, 94111, '\P{^Is_General_Category=- LM}', "");
Expect(0, 94112, '\p{Is_General_Category=- LM}', "");
Expect(1, 94112, '\p{^Is_General_Category=- LM}', "");
Expect(1, 94112, '\P{Is_General_Category=- LM}', "");
Expect(0, 94112, '\P{^Is_General_Category=- LM}', "");
Error('\p{Is_Gc=/a/-Modifier_Letter}');
Error('\P{Is_Gc=/a/-Modifier_Letter}');
Expect(1, 94111, '\p{Is_Gc=modifierletter}', "");
Expect(0, 94111, '\p{^Is_Gc=modifierletter}', "");
Expect(0, 94111, '\P{Is_Gc=modifierletter}', "");
Expect(1, 94111, '\P{^Is_Gc=modifierletter}', "");
Expect(0, 94112, '\p{Is_Gc=modifierletter}', "");
Expect(1, 94112, '\p{^Is_Gc=modifierletter}', "");
Expect(1, 94112, '\P{Is_Gc=modifierletter}', "");
Expect(0, 94112, '\P{^Is_Gc=modifierletter}', "");
Expect(1, 94111, '\p{Is_Gc=-	MODIFIER_Letter}', "");
Expect(0, 94111, '\p{^Is_Gc=-	MODIFIER_Letter}', "");
Expect(0, 94111, '\P{Is_Gc=-	MODIFIER_Letter}', "");
Expect(1, 94111, '\P{^Is_Gc=-	MODIFIER_Letter}', "");
Expect(0, 94112, '\p{Is_Gc=-	MODIFIER_Letter}', "");
Expect(1, 94112, '\p{^Is_Gc=-	MODIFIER_Letter}', "");
Expect(1, 94112, '\P{Is_Gc=-	MODIFIER_Letter}', "");
Expect(0, 94112, '\P{^Is_Gc=-	MODIFIER_Letter}', "");
Error('\p{Is_Category=/a/_-Lm}');
Error('\P{Is_Category=/a/_-Lm}');
Expect(1, 94111, '\p{Is_Category=lm}', "");
Expect(0, 94111, '\p{^Is_Category=lm}', "");
Expect(0, 94111, '\P{Is_Category=lm}', "");
Expect(1, 94111, '\P{^Is_Category=lm}', "");
Expect(0, 94112, '\p{Is_Category=lm}', "");
Expect(1, 94112, '\p{^Is_Category=lm}', "");
Expect(1, 94112, '\P{Is_Category=lm}', "");
Expect(0, 94112, '\P{^Is_Category=lm}', "");
Expect(1, 94111, '\p{Is_Category=_ lm}', "");
Expect(0, 94111, '\p{^Is_Category=_ lm}', "");
Expect(0, 94111, '\P{Is_Category=_ lm}', "");
Expect(1, 94111, '\P{^Is_Category=_ lm}', "");
Expect(0, 94112, '\p{Is_Category=_ lm}', "");
Expect(1, 94112, '\p{^Is_Category=_ lm}', "");
Expect(1, 94112, '\P{Is_Category=_ lm}', "");
Expect(0, 94112, '\P{^Is_Category=_ lm}', "");
Error('\p{General_Category=/a/	OTHER_LETTER}');
Error('\P{General_Category=/a/	OTHER_LETTER}');
Expect(1, 195101, '\p{General_Category=otherletter}', "");
Expect(0, 195101, '\p{^General_Category=otherletter}', "");
Expect(0, 195101, '\P{General_Category=otherletter}', "");
Expect(1, 195101, '\P{^General_Category=otherletter}', "");
Expect(0, 195102, '\p{General_Category=otherletter}', "");
Expect(1, 195102, '\p{^General_Category=otherletter}', "");
Expect(1, 195102, '\P{General_Category=otherletter}', "");
Expect(0, 195102, '\P{^General_Category=otherletter}', "");
Expect(1, 195101, '\p{General_Category= _OTHER_Letter}', "");
Expect(0, 195101, '\p{^General_Category= _OTHER_Letter}', "");
Expect(0, 195101, '\P{General_Category= _OTHER_Letter}', "");
Expect(1, 195101, '\P{^General_Category= _OTHER_Letter}', "");
Expect(0, 195102, '\p{General_Category= _OTHER_Letter}', "");
Expect(1, 195102, '\p{^General_Category= _OTHER_Letter}', "");
Expect(1, 195102, '\P{General_Category= _OTHER_Letter}', "");
Expect(0, 195102, '\P{^General_Category= _OTHER_Letter}', "");
Error('\p{Gc=/a/  Lo}');
Error('\P{Gc=/a/  Lo}');
Expect(1, 195101, '\p{Gc=lo}', "");
Expect(0, 195101, '\p{^Gc=lo}', "");
Expect(0, 195101, '\P{Gc=lo}', "");
Expect(1, 195101, '\P{^Gc=lo}', "");
Expect(0, 195102, '\p{Gc=lo}', "");
Expect(1, 195102, '\p{^Gc=lo}', "");
Expect(1, 195102, '\P{Gc=lo}', "");
Expect(0, 195102, '\P{^Gc=lo}', "");
Expect(1, 195101, '\p{Gc= Lo}', "");
Expect(0, 195101, '\p{^Gc= Lo}', "");
Expect(0, 195101, '\P{Gc= Lo}', "");
Expect(1, 195101, '\P{^Gc= Lo}', "");
Expect(0, 195102, '\p{Gc= Lo}', "");
Expect(1, 195102, '\p{^Gc= Lo}', "");
Expect(1, 195102, '\P{Gc= Lo}', "");
Expect(0, 195102, '\P{^Gc= Lo}', "");
Error('\p{Category=-other_LETTER:=}');
Error('\P{Category=-other_LETTER:=}');
Expect(1, 195101, '\p{Category=otherletter}', "");
Expect(0, 195101, '\p{^Category=otherletter}', "");
Expect(0, 195101, '\P{Category=otherletter}', "");
Expect(1, 195101, '\P{^Category=otherletter}', "");
Expect(0, 195102, '\p{Category=otherletter}', "");
Expect(1, 195102, '\p{^Category=otherletter}', "");
Expect(1, 195102, '\P{Category=otherletter}', "");
Expect(0, 195102, '\P{^Category=otherletter}', "");
Expect(1, 195101, '\p{Category=	 Other_Letter}', "");
Expect(0, 195101, '\p{^Category=	 Other_Letter}', "");
Expect(0, 195101, '\P{Category=	 Other_Letter}', "");
Expect(1, 195101, '\P{^Category=	 Other_Letter}', "");
Expect(0, 195102, '\p{Category=	 Other_Letter}', "");
Expect(1, 195102, '\p{^Category=	 Other_Letter}', "");
Expect(1, 195102, '\P{Category=	 Other_Letter}', "");
Expect(0, 195102, '\P{^Category=	 Other_Letter}', "");
Error('\p{Is_General_Category=:=		Lo}');
Error('\P{Is_General_Category=:=		Lo}');
Expect(1, 195101, '\p{Is_General_Category=lo}', "");
Expect(0, 195101, '\p{^Is_General_Category=lo}', "");
Expect(0, 195101, '\P{Is_General_Category=lo}', "");
Expect(1, 195101, '\P{^Is_General_Category=lo}', "");
Expect(0, 195102, '\p{Is_General_Category=lo}', "");
Expect(1, 195102, '\p{^Is_General_Category=lo}', "");
Expect(1, 195102, '\P{Is_General_Category=lo}', "");
Expect(0, 195102, '\P{^Is_General_Category=lo}', "");
Expect(1, 195101, '\p{Is_General_Category=--LO}', "");
Expect(0, 195101, '\p{^Is_General_Category=--LO}', "");
Expect(0, 195101, '\P{Is_General_Category=--LO}', "");
Expect(1, 195101, '\P{^Is_General_Category=--LO}', "");
Expect(0, 195102, '\p{Is_General_Category=--LO}', "");
Expect(1, 195102, '\p{^Is_General_Category=--LO}', "");
Expect(1, 195102, '\P{Is_General_Category=--LO}', "");
Expect(0, 195102, '\P{^Is_General_Category=--LO}', "");
Error('\p{Is_Gc:	-:=other_Letter}');
Error('\P{Is_Gc:	-:=other_Letter}');
Expect(1, 195101, '\p{Is_Gc=otherletter}', "");
Expect(0, 195101, '\p{^Is_Gc=otherletter}', "");
Expect(0, 195101, '\P{Is_Gc=otherletter}', "");
Expect(1, 195101, '\P{^Is_Gc=otherletter}', "");
Expect(0, 195102, '\p{Is_Gc=otherletter}', "");
Expect(1, 195102, '\p{^Is_Gc=otherletter}', "");
Expect(1, 195102, '\P{Is_Gc=otherletter}', "");
Expect(0, 195102, '\P{^Is_Gc=otherletter}', "");
Expect(1, 195101, '\p{Is_Gc:_	other_letter}', "");
Expect(0, 195101, '\p{^Is_Gc:_	other_letter}', "");
Expect(0, 195101, '\P{Is_Gc:_	other_letter}', "");
Expect(1, 195101, '\P{^Is_Gc:_	other_letter}', "");
Expect(0, 195102, '\p{Is_Gc:_	other_letter}', "");
Expect(1, 195102, '\p{^Is_Gc:_	other_letter}', "");
Expect(1, 195102, '\P{Is_Gc:_	other_letter}', "");
Expect(0, 195102, '\P{^Is_Gc:_	other_letter}', "");
Error('\p{Is_Category:	/a/ -lo}');
Error('\P{Is_Category:	/a/ -lo}');
Expect(1, 195101, '\p{Is_Category=lo}', "");
Expect(0, 195101, '\p{^Is_Category=lo}', "");
Expect(0, 195101, '\P{Is_Category=lo}', "");
Expect(1, 195101, '\P{^Is_Category=lo}', "");
Expect(0, 195102, '\p{Is_Category=lo}', "");
Expect(1, 195102, '\p{^Is_Category=lo}', "");
Expect(1, 195102, '\P{Is_Category=lo}', "");
Expect(0, 195102, '\P{^Is_Category=lo}', "");
Expect(1, 195101, '\p{Is_Category=	lo}', "");
Expect(0, 195101, '\p{^Is_Category=	lo}', "");
Expect(0, 195101, '\P{Is_Category=	lo}', "");
Expect(1, 195101, '\P{^Is_Category=	lo}', "");
Expect(0, 195102, '\p{Is_Category=	lo}', "");
Expect(1, 195102, '\p{^Is_Category=	lo}', "");
Expect(1, 195102, '\P{Is_Category=	lo}', "");
Expect(0, 195102, '\P{^Is_Category=	lo}', "");
Error('\p{General_Category: _/a/Titlecase_Letter}');
Error('\P{General_Category: _/a/Titlecase_Letter}');
Expect(1, 8188, '\p{General_Category=titlecaseletter}', "");
Expect(0, 8188, '\p{^General_Category=titlecaseletter}', "");
Expect(0, 8188, '\P{General_Category=titlecaseletter}', "");
Expect(1, 8188, '\P{^General_Category=titlecaseletter}', "");
Expect(0, 8189, '\p{General_Category=titlecaseletter}', "");
Expect(1, 8189, '\p{^General_Category=titlecaseletter}', "");
Expect(1, 8189, '\P{General_Category=titlecaseletter}', "");
Expect(0, 8189, '\P{^General_Category=titlecaseletter}', "");
Expect(1, 8188, '\p{General_Category=-Titlecase_letter}', "");
Expect(0, 8188, '\p{^General_Category=-Titlecase_letter}', "");
Expect(0, 8188, '\P{General_Category=-Titlecase_letter}', "");
Expect(1, 8188, '\P{^General_Category=-Titlecase_letter}', "");
Expect(0, 8189, '\p{General_Category=-Titlecase_letter}', "");
Expect(1, 8189, '\p{^General_Category=-Titlecase_letter}', "");
Expect(1, 8189, '\P{General_Category=-Titlecase_letter}', "");
Expect(0, 8189, '\P{^General_Category=-Titlecase_letter}', "");
Error('\p{Gc=	/a/Lt}');
Error('\P{Gc=	/a/Lt}');
Expect(1, 8188, '\p{Gc=lt}', "");
Expect(0, 8188, '\p{^Gc=lt}', "");
Expect(0, 8188, '\P{Gc=lt}', "");
Expect(1, 8188, '\P{^Gc=lt}', "");
Expect(0, 8189, '\p{Gc=lt}', "");
Expect(1, 8189, '\p{^Gc=lt}', "");
Expect(1, 8189, '\P{Gc=lt}', "");
Expect(0, 8189, '\P{^Gc=lt}', "");
Expect(1, 8188, '\p{Gc=	Lt}', "");
Expect(0, 8188, '\p{^Gc=	Lt}', "");
Expect(0, 8188, '\P{Gc=	Lt}', "");
Expect(1, 8188, '\P{^Gc=	Lt}', "");
Expect(0, 8189, '\p{Gc=	Lt}', "");
Expect(1, 8189, '\p{^Gc=	Lt}', "");
Expect(1, 8189, '\P{Gc=	Lt}', "");
Expect(0, 8189, '\P{^Gc=	Lt}', "");
Error('\p{Category: 	/a/Titlecase_Letter}');
Error('\P{Category: 	/a/Titlecase_Letter}');
Expect(1, 8188, '\p{Category: titlecaseletter}', "");
Expect(0, 8188, '\p{^Category: titlecaseletter}', "");
Expect(0, 8188, '\P{Category: titlecaseletter}', "");
Expect(1, 8188, '\P{^Category: titlecaseletter}', "");
Expect(0, 8189, '\p{Category: titlecaseletter}', "");
Expect(1, 8189, '\p{^Category: titlecaseletter}', "");
Expect(1, 8189, '\P{Category: titlecaseletter}', "");
Expect(0, 8189, '\P{^Category: titlecaseletter}', "");
Expect(1, 8188, '\p{Category:	_titlecase_Letter}', "");
Expect(0, 8188, '\p{^Category:	_titlecase_Letter}', "");
Expect(0, 8188, '\P{Category:	_titlecase_Letter}', "");
Expect(1, 8188, '\P{^Category:	_titlecase_Letter}', "");
Expect(0, 8189, '\p{Category:	_titlecase_Letter}', "");
Expect(1, 8189, '\p{^Category:	_titlecase_Letter}', "");
Expect(1, 8189, '\P{Category:	_titlecase_Letter}', "");
Expect(0, 8189, '\P{^Category:	_titlecase_Letter}', "");
Error('\p{Is_General_Category=-LT/a/}');
Error('\P{Is_General_Category=-LT/a/}');
Expect(1, 8188, '\p{Is_General_Category=lt}', "");
Expect(0, 8188, '\p{^Is_General_Category=lt}', "");
Expect(0, 8188, '\P{Is_General_Category=lt}', "");
Expect(1, 8188, '\P{^Is_General_Category=lt}', "");
Expect(0, 8189, '\p{Is_General_Category=lt}', "");
Expect(1, 8189, '\p{^Is_General_Category=lt}', "");
Expect(1, 8189, '\P{Is_General_Category=lt}', "");
Expect(0, 8189, '\P{^Is_General_Category=lt}', "");
Expect(1, 8188, '\p{Is_General_Category: -LT}', "");
Expect(0, 8188, '\p{^Is_General_Category: -LT}', "");
Expect(0, 8188, '\P{Is_General_Category: -LT}', "");
Expect(1, 8188, '\P{^Is_General_Category: -LT}', "");
Expect(0, 8189, '\p{Is_General_Category: -LT}', "");
Expect(1, 8189, '\p{^Is_General_Category: -LT}', "");
Expect(1, 8189, '\P{Is_General_Category: -LT}', "");
Expect(0, 8189, '\P{^Is_General_Category: -LT}', "");
Error('\p{Is_Gc=_Titlecase_Letter/a/}');
Error('\P{Is_Gc=_Titlecase_Letter/a/}');
Expect(1, 8188, '\p{Is_Gc=titlecaseletter}', "");
Expect(0, 8188, '\p{^Is_Gc=titlecaseletter}', "");
Expect(0, 8188, '\P{Is_Gc=titlecaseletter}', "");
Expect(1, 8188, '\P{^Is_Gc=titlecaseletter}', "");
Expect(0, 8189, '\p{Is_Gc=titlecaseletter}', "");
Expect(1, 8189, '\p{^Is_Gc=titlecaseletter}', "");
Expect(1, 8189, '\P{Is_Gc=titlecaseletter}', "");
Expect(0, 8189, '\P{^Is_Gc=titlecaseletter}', "");
Expect(1, 8188, '\p{Is_Gc=	 Titlecase_Letter}', "");
Expect(0, 8188, '\p{^Is_Gc=	 Titlecase_Letter}', "");
Expect(0, 8188, '\P{Is_Gc=	 Titlecase_Letter}', "");
Expect(1, 8188, '\P{^Is_Gc=	 Titlecase_Letter}', "");
Expect(0, 8189, '\p{Is_Gc=	 Titlecase_Letter}', "");
Expect(1, 8189, '\p{^Is_Gc=	 Titlecase_Letter}', "");
Expect(1, 8189, '\P{Is_Gc=	 Titlecase_Letter}', "");
Expect(0, 8189, '\P{^Is_Gc=	 Titlecase_Letter}', "");
Error('\p{Is_Category=-_lt/a/}');
Error('\P{Is_Category=-_lt/a/}');
Expect(1, 8188, '\p{Is_Category=lt}', "");
Expect(0, 8188, '\p{^Is_Category=lt}', "");
Expect(0, 8188, '\P{Is_Category=lt}', "");
Expect(1, 8188, '\P{^Is_Category=lt}', "");
Expect(0, 8189, '\p{Is_Category=lt}', "");
Expect(1, 8189, '\p{^Is_Category=lt}', "");
Expect(1, 8189, '\P{Is_Category=lt}', "");
Expect(0, 8189, '\P{^Is_Category=lt}', "");
Expect(1, 8188, '\p{Is_Category=	LT}', "");
Expect(0, 8188, '\p{^Is_Category=	LT}', "");
Expect(0, 8188, '\P{Is_Category=	LT}', "");
Expect(1, 8188, '\P{^Is_Category=	LT}', "");
Expect(0, 8189, '\p{Is_Category=	LT}', "");
Expect(1, 8189, '\p{^Is_Category=	LT}', "");
Expect(1, 8189, '\P{Is_Category=	LT}', "");
Expect(0, 8189, '\P{^Is_Category=	LT}', "");
Error('\p{General_Category=/a/-UPPERCASE_LETTER}');
Error('\P{General_Category=/a/-UPPERCASE_LETTER}');
Expect(1, 120778, '\p{General_Category=uppercaseletter}', "");
Expect(0, 120778, '\p{^General_Category=uppercaseletter}', "");
Expect(0, 120778, '\P{General_Category=uppercaseletter}', "");
Expect(1, 120778, '\P{^General_Category=uppercaseletter}', "");
Expect(0, 120779, '\p{General_Category=uppercaseletter}', "");
Expect(1, 120779, '\p{^General_Category=uppercaseletter}', "");
Expect(1, 120779, '\P{General_Category=uppercaseletter}', "");
Expect(0, 120779, '\P{^General_Category=uppercaseletter}', "");
Expect(1, 120778, '\p{General_Category= -UPPERCASE_letter}', "");
Expect(0, 120778, '\p{^General_Category= -UPPERCASE_letter}', "");
Expect(0, 120778, '\P{General_Category= -UPPERCASE_letter}', "");
Expect(1, 120778, '\P{^General_Category= -UPPERCASE_letter}', "");
Expect(0, 120779, '\p{General_Category= -UPPERCASE_letter}', "");
Expect(1, 120779, '\p{^General_Category= -UPPERCASE_letter}', "");
Expect(1, 120779, '\P{General_Category= -UPPERCASE_letter}', "");
Expect(0, 120779, '\P{^General_Category= -UPPERCASE_letter}', "");
Error('\p{Gc=__lu:=}');
Error('\P{Gc=__lu:=}');
Expect(1, 120778, '\p{Gc=lu}', "");
Expect(0, 120778, '\p{^Gc=lu}', "");
Expect(0, 120778, '\P{Gc=lu}', "");
Expect(1, 120778, '\P{^Gc=lu}', "");
Expect(0, 120779, '\p{Gc=lu}', "");
Expect(1, 120779, '\p{^Gc=lu}', "");
Expect(1, 120779, '\P{Gc=lu}', "");
Expect(0, 120779, '\P{^Gc=lu}', "");
Expect(1, 120778, '\p{Gc= -lu}', "");
Expect(0, 120778, '\p{^Gc= -lu}', "");
Expect(0, 120778, '\P{Gc= -lu}', "");
Expect(1, 120778, '\P{^Gc= -lu}', "");
Expect(0, 120779, '\p{Gc= -lu}', "");
Expect(1, 120779, '\p{^Gc= -lu}', "");
Expect(1, 120779, '\P{Gc= -lu}', "");
Expect(0, 120779, '\P{^Gc= -lu}', "");
Error('\p{Category=  UPPERCASE_Letter:=}');
Error('\P{Category=  UPPERCASE_Letter:=}');
Expect(1, 120778, '\p{Category=uppercaseletter}', "");
Expect(0, 120778, '\p{^Category=uppercaseletter}', "");
Expect(0, 120778, '\P{Category=uppercaseletter}', "");
Expect(1, 120778, '\P{^Category=uppercaseletter}', "");
Expect(0, 120779, '\p{Category=uppercaseletter}', "");
Expect(1, 120779, '\p{^Category=uppercaseletter}', "");
Expect(1, 120779, '\P{Category=uppercaseletter}', "");
Expect(0, 120779, '\P{^Category=uppercaseletter}', "");
Expect(1, 120778, '\p{Category=	 UPPERCASE_Letter}', "");
Expect(0, 120778, '\p{^Category=	 UPPERCASE_Letter}', "");
Expect(0, 120778, '\P{Category=	 UPPERCASE_Letter}', "");
Expect(1, 120778, '\P{^Category=	 UPPERCASE_Letter}', "");
Expect(0, 120779, '\p{Category=	 UPPERCASE_Letter}', "");
Expect(1, 120779, '\p{^Category=	 UPPERCASE_Letter}', "");
Expect(1, 120779, '\P{Category=	 UPPERCASE_Letter}', "");
Expect(0, 120779, '\P{^Category=	 UPPERCASE_Letter}', "");
Error('\p{Is_General_Category=	:=Lu}');
Error('\P{Is_General_Category=	:=Lu}');
Expect(1, 120778, '\p{Is_General_Category=lu}', "");
Expect(0, 120778, '\p{^Is_General_Category=lu}', "");
Expect(0, 120778, '\P{Is_General_Category=lu}', "");
Expect(1, 120778, '\P{^Is_General_Category=lu}', "");
Expect(0, 120779, '\p{Is_General_Category=lu}', "");
Expect(1, 120779, '\p{^Is_General_Category=lu}', "");
Expect(1, 120779, '\P{Is_General_Category=lu}', "");
Expect(0, 120779, '\P{^Is_General_Category=lu}', "");
Expect(1, 120778, '\p{Is_General_Category= LU}', "");
Expect(0, 120778, '\p{^Is_General_Category= LU}', "");
Expect(0, 120778, '\P{Is_General_Category= LU}', "");
Expect(1, 120778, '\P{^Is_General_Category= LU}', "");
Expect(0, 120779, '\p{Is_General_Category= LU}', "");
Expect(1, 120779, '\p{^Is_General_Category= LU}', "");
Expect(1, 120779, '\P{Is_General_Category= LU}', "");
Expect(0, 120779, '\P{^Is_General_Category= LU}', "");
Error('\p{Is_Gc:/a/-_Uppercase_Letter}');
Error('\P{Is_Gc:/a/-_Uppercase_Letter}');
Expect(1, 120778, '\p{Is_Gc=uppercaseletter}', "");
Expect(0, 120778, '\p{^Is_Gc=uppercaseletter}', "");
Expect(0, 120778, '\P{Is_Gc=uppercaseletter}', "");
Expect(1, 120778, '\P{^Is_Gc=uppercaseletter}', "");
Expect(0, 120779, '\p{Is_Gc=uppercaseletter}', "");
Expect(1, 120779, '\p{^Is_Gc=uppercaseletter}', "");
Expect(1, 120779, '\P{Is_Gc=uppercaseletter}', "");
Expect(0, 120779, '\P{^Is_Gc=uppercaseletter}', "");
Expect(1, 120778, '\p{Is_Gc= -UPPERCASE_Letter}', "");
Expect(0, 120778, '\p{^Is_Gc= -UPPERCASE_Letter}', "");
Expect(0, 120778, '\P{Is_Gc= -UPPERCASE_Letter}', "");
Expect(1, 120778, '\P{^Is_Gc= -UPPERCASE_Letter}', "");
Expect(0, 120779, '\p{Is_Gc= -UPPERCASE_Letter}', "");
Expect(1, 120779, '\p{^Is_Gc= -UPPERCASE_Letter}', "");
Expect(1, 120779, '\P{Is_Gc= -UPPERCASE_Letter}', "");
Expect(0, 120779, '\P{^Is_Gc= -UPPERCASE_Letter}', "");
Error('\p{Is_Category=Lu/a/}');
Error('\P{Is_Category=Lu/a/}');
Expect(1, 120778, '\p{Is_Category=lu}', "");
Expect(0, 120778, '\p{^Is_Category=lu}', "");
Expect(0, 120778, '\P{Is_Category=lu}', "");
Expect(1, 120778, '\P{^Is_Category=lu}', "");
Expect(0, 120779, '\p{Is_Category=lu}', "");
Expect(1, 120779, '\p{^Is_Category=lu}', "");
Expect(1, 120779, '\P{Is_Category=lu}', "");
Expect(0, 120779, '\P{^Is_Category=lu}', "");
Expect(1, 120778, '\p{Is_Category=	LU}', "");
Expect(0, 120778, '\p{^Is_Category=	LU}', "");
Expect(0, 120778, '\P{Is_Category=	LU}', "");
Expect(1, 120778, '\P{^Is_Category=	LU}', "");
Expect(0, 120779, '\p{Is_Category=	LU}', "");
Expect(1, 120779, '\p{^Is_Category=	LU}', "");
Expect(1, 120779, '\P{Is_Category=	LU}', "");
Expect(0, 120779, '\P{^Is_Category=	LU}', "");
Error('\p{General_Category=:=__mark}');
Error('\P{General_Category=:=__mark}');
Expect(1, 917999, '\p{General_Category=mark}', "");
Expect(0, 917999, '\p{^General_Category=mark}', "");
Expect(0, 917999, '\P{General_Category=mark}', "");
Expect(1, 917999, '\P{^General_Category=mark}', "");
Expect(0, 918000, '\p{General_Category=mark}', "");
Expect(1, 918000, '\p{^General_Category=mark}', "");
Expect(1, 918000, '\P{General_Category=mark}', "");
Expect(0, 918000, '\P{^General_Category=mark}', "");
Expect(1, 917999, '\p{General_Category=-_mark}', "");
Expect(0, 917999, '\p{^General_Category=-_mark}', "");
Expect(0, 917999, '\P{General_Category=-_mark}', "");
Expect(1, 917999, '\P{^General_Category=-_mark}', "");
Expect(0, 918000, '\p{General_Category=-_mark}', "");
Expect(1, 918000, '\p{^General_Category=-_mark}', "");
Expect(1, 918000, '\P{General_Category=-_mark}', "");
Expect(0, 918000, '\P{^General_Category=-_mark}', "");
Error('\p{Gc=:=	 M}');
Error('\P{Gc=:=	 M}');
Expect(1, 917999, '\p{Gc=m}', "");
Expect(0, 917999, '\p{^Gc=m}', "");
Expect(0, 917999, '\P{Gc=m}', "");
Expect(1, 917999, '\P{^Gc=m}', "");
Expect(0, 918000, '\p{Gc=m}', "");
Expect(1, 918000, '\p{^Gc=m}', "");
Expect(1, 918000, '\P{Gc=m}', "");
Expect(0, 918000, '\P{^Gc=m}', "");
Expect(1, 917999, '\p{Gc=_	M}', "");
Expect(0, 917999, '\p{^Gc=_	M}', "");
Expect(0, 917999, '\P{Gc=_	M}', "");
Expect(1, 917999, '\P{^Gc=_	M}', "");
Expect(0, 918000, '\p{Gc=_	M}', "");
Expect(1, 918000, '\p{^Gc=_	M}', "");
Expect(1, 918000, '\P{Gc=_	M}', "");
Expect(0, 918000, '\P{^Gc=_	M}', "");
Error('\p{Category=_/a/Combining_MARK}');
Error('\P{Category=_/a/Combining_MARK}');
Expect(1, 917999, '\p{Category:	combiningmark}', "");
Expect(0, 917999, '\p{^Category:	combiningmark}', "");
Expect(0, 917999, '\P{Category:	combiningmark}', "");
Expect(1, 917999, '\P{^Category:	combiningmark}', "");
Expect(0, 918000, '\p{Category:	combiningmark}', "");
Expect(1, 918000, '\p{^Category:	combiningmark}', "");
Expect(1, 918000, '\P{Category:	combiningmark}', "");
Expect(0, 918000, '\P{^Category:	combiningmark}', "");
Expect(1, 917999, '\p{Category= 	Combining_Mark}', "");
Expect(0, 917999, '\p{^Category= 	Combining_Mark}', "");
Expect(0, 917999, '\P{Category= 	Combining_Mark}', "");
Expect(1, 917999, '\P{^Category= 	Combining_Mark}', "");
Expect(0, 918000, '\p{Category= 	Combining_Mark}', "");
Expect(1, 918000, '\p{^Category= 	Combining_Mark}', "");
Expect(1, 918000, '\P{Category= 	Combining_Mark}', "");
Expect(0, 918000, '\P{^Category= 	Combining_Mark}', "");
Error('\p{Is_General_Category=_/a/mark}');
Error('\P{Is_General_Category=_/a/mark}');
Expect(1, 917999, '\p{Is_General_Category=mark}', "");
Expect(0, 917999, '\p{^Is_General_Category=mark}', "");
Expect(0, 917999, '\P{Is_General_Category=mark}', "");
Expect(1, 917999, '\P{^Is_General_Category=mark}', "");
Expect(0, 918000, '\p{Is_General_Category=mark}', "");
Expect(1, 918000, '\p{^Is_General_Category=mark}', "");
Expect(1, 918000, '\P{Is_General_Category=mark}', "");
Expect(0, 918000, '\P{^Is_General_Category=mark}', "");
Expect(1, 917999, '\p{Is_General_Category=--Mark}', "");
Expect(0, 917999, '\p{^Is_General_Category=--Mark}', "");
Expect(0, 917999, '\P{Is_General_Category=--Mark}', "");
Expect(1, 917999, '\P{^Is_General_Category=--Mark}', "");
Expect(0, 918000, '\p{Is_General_Category=--Mark}', "");
Expect(1, 918000, '\p{^Is_General_Category=--Mark}', "");
Expect(1, 918000, '\P{Is_General_Category=--Mark}', "");
Expect(0, 918000, '\P{^Is_General_Category=--Mark}', "");
Error('\p{Is_Gc=/a/-M}');
Error('\P{Is_Gc=/a/-M}');
Expect(1, 917999, '\p{Is_Gc=m}', "");
Expect(0, 917999, '\p{^Is_Gc=m}', "");
Expect(0, 917999, '\P{Is_Gc=m}', "");
Expect(1, 917999, '\P{^Is_Gc=m}', "");
Expect(0, 918000, '\p{Is_Gc=m}', "");
Expect(1, 918000, '\p{^Is_Gc=m}', "");
Expect(1, 918000, '\P{Is_Gc=m}', "");
Expect(0, 918000, '\P{^Is_Gc=m}', "");
Expect(1, 917999, '\p{Is_Gc:    M}', "");
Expect(0, 917999, '\p{^Is_Gc:    M}', "");
Expect(0, 917999, '\P{Is_Gc:    M}', "");
Expect(1, 917999, '\P{^Is_Gc:    M}', "");
Expect(0, 918000, '\p{Is_Gc:    M}', "");
Expect(1, 918000, '\p{^Is_Gc:    M}', "");
Expect(1, 918000, '\P{Is_Gc:    M}', "");
Expect(0, 918000, '\P{^Is_Gc:    M}', "");
Error('\p{Is_Category:	 Combining_Mark:=}');
Error('\P{Is_Category:	 Combining_Mark:=}');
Expect(1, 917999, '\p{Is_Category=combiningmark}', "");
Expect(0, 917999, '\p{^Is_Category=combiningmark}', "");
Expect(0, 917999, '\P{Is_Category=combiningmark}', "");
Expect(1, 917999, '\P{^Is_Category=combiningmark}', "");
Expect(0, 918000, '\p{Is_Category=combiningmark}', "");
Expect(1, 918000, '\p{^Is_Category=combiningmark}', "");
Expect(1, 918000, '\P{Is_Category=combiningmark}', "");
Expect(0, 918000, '\P{^Is_Category=combiningmark}', "");
Expect(1, 917999, '\p{Is_Category=-COMBINING_MARK}', "");
Expect(0, 917999, '\p{^Is_Category=-COMBINING_MARK}', "");
Expect(0, 917999, '\P{Is_Category=-COMBINING_MARK}', "");
Expect(1, 917999, '\P{^Is_Category=-COMBINING_MARK}', "");
Expect(0, 918000, '\p{Is_Category=-COMBINING_MARK}', "");
Expect(1, 918000, '\p{^Is_Category=-COMBINING_MARK}', "");
Expect(1, 918000, '\P{Is_Category=-COMBINING_MARK}', "");
Expect(0, 918000, '\P{^Is_Category=-COMBINING_MARK}', "");
Error('\p{General_Category=-/a/Spacing_MARK}');
Error('\P{General_Category=-/a/Spacing_MARK}');
Expect(1, 119154, '\p{General_Category=spacingmark}', "");
Expect(0, 119154, '\p{^General_Category=spacingmark}', "");
Expect(0, 119154, '\P{General_Category=spacingmark}', "");
Expect(1, 119154, '\P{^General_Category=spacingmark}', "");
Expect(0, 119155, '\p{General_Category=spacingmark}', "");
Expect(1, 119155, '\p{^General_Category=spacingmark}', "");
Expect(1, 119155, '\P{General_Category=spacingmark}', "");
Expect(0, 119155, '\P{^General_Category=spacingmark}', "");
Expect(1, 119154, '\p{General_Category= -Spacing_Mark}', "");
Expect(0, 119154, '\p{^General_Category= -Spacing_Mark}', "");
Expect(0, 119154, '\P{General_Category= -Spacing_Mark}', "");
Expect(1, 119154, '\P{^General_Category= -Spacing_Mark}', "");
Expect(0, 119155, '\p{General_Category= -Spacing_Mark}', "");
Expect(1, 119155, '\p{^General_Category= -Spacing_Mark}', "");
Expect(1, 119155, '\P{General_Category= -Spacing_Mark}', "");
Expect(0, 119155, '\P{^General_Category= -Spacing_Mark}', "");
Error('\p{Gc=	:=Mc}');
Error('\P{Gc=	:=Mc}');
Expect(1, 119154, '\p{Gc=mc}', "");
Expect(0, 119154, '\p{^Gc=mc}', "");
Expect(0, 119154, '\P{Gc=mc}', "");
Expect(1, 119154, '\P{^Gc=mc}', "");
Expect(0, 119155, '\p{Gc=mc}', "");
Expect(1, 119155, '\p{^Gc=mc}', "");
Expect(1, 119155, '\P{Gc=mc}', "");
Expect(0, 119155, '\P{^Gc=mc}', "");
Expect(1, 119154, '\p{Gc= 	mc}', "");
Expect(0, 119154, '\p{^Gc= 	mc}', "");
Expect(0, 119154, '\P{Gc= 	mc}', "");
Expect(1, 119154, '\P{^Gc= 	mc}', "");
Expect(0, 119155, '\p{Gc= 	mc}', "");
Expect(1, 119155, '\p{^Gc= 	mc}', "");
Expect(1, 119155, '\P{Gc= 	mc}', "");
Expect(0, 119155, '\P{^Gc= 	mc}', "");
Error('\p{Category=	_spacing_Mark:=}');
Error('\P{Category=	_spacing_Mark:=}');
Expect(1, 119154, '\p{Category=spacingmark}', "");
Expect(0, 119154, '\p{^Category=spacingmark}', "");
Expect(0, 119154, '\P{Category=spacingmark}', "");
Expect(1, 119154, '\P{^Category=spacingmark}', "");
Expect(0, 119155, '\p{Category=spacingmark}', "");
Expect(1, 119155, '\p{^Category=spacingmark}', "");
Expect(1, 119155, '\P{Category=spacingmark}', "");
Expect(0, 119155, '\P{^Category=spacingmark}', "");
Expect(1, 119154, '\p{Category=--SPACING_Mark}', "");
Expect(0, 119154, '\p{^Category=--SPACING_Mark}', "");
Expect(0, 119154, '\P{Category=--SPACING_Mark}', "");
Expect(1, 119154, '\P{^Category=--SPACING_Mark}', "");
Expect(0, 119155, '\p{Category=--SPACING_Mark}', "");
Expect(1, 119155, '\p{^Category=--SPACING_Mark}', "");
Expect(1, 119155, '\P{Category=--SPACING_Mark}', "");
Expect(0, 119155, '\P{^Category=--SPACING_Mark}', "");
Error('\p{Is_General_Category= /a/Mc}');
Error('\P{Is_General_Category= /a/Mc}');
Expect(1, 119154, '\p{Is_General_Category=mc}', "");
Expect(0, 119154, '\p{^Is_General_Category=mc}', "");
Expect(0, 119154, '\P{Is_General_Category=mc}', "");
Expect(1, 119154, '\P{^Is_General_Category=mc}', "");
Expect(0, 119155, '\p{Is_General_Category=mc}', "");
Expect(1, 119155, '\p{^Is_General_Category=mc}', "");
Expect(1, 119155, '\P{Is_General_Category=mc}', "");
Expect(0, 119155, '\P{^Is_General_Category=mc}', "");
Expect(1, 119154, '\p{Is_General_Category=_-Mc}', "");
Expect(0, 119154, '\p{^Is_General_Category=_-Mc}', "");
Expect(0, 119154, '\P{Is_General_Category=_-Mc}', "");
Expect(1, 119154, '\P{^Is_General_Category=_-Mc}', "");
Expect(0, 119155, '\p{Is_General_Category=_-Mc}', "");
Expect(1, 119155, '\p{^Is_General_Category=_-Mc}', "");
Expect(1, 119155, '\P{Is_General_Category=_-Mc}', "");
Expect(0, 119155, '\P{^Is_General_Category=_-Mc}', "");
Error('\p{Is_Gc=/a/		SPACING_MARK}');
Error('\P{Is_Gc=/a/		SPACING_MARK}');
Expect(1, 119154, '\p{Is_Gc=spacingmark}', "");
Expect(0, 119154, '\p{^Is_Gc=spacingmark}', "");
Expect(0, 119154, '\P{Is_Gc=spacingmark}', "");
Expect(1, 119154, '\P{^Is_Gc=spacingmark}', "");
Expect(0, 119155, '\p{Is_Gc=spacingmark}', "");
Expect(1, 119155, '\p{^Is_Gc=spacingmark}', "");
Expect(1, 119155, '\P{Is_Gc=spacingmark}', "");
Expect(0, 119155, '\P{^Is_Gc=spacingmark}', "");
Expect(1, 119154, '\p{Is_Gc=--SPACING_Mark}', "");
Expect(0, 119154, '\p{^Is_Gc=--SPACING_Mark}', "");
Expect(0, 119154, '\P{Is_Gc=--SPACING_Mark}', "");
Expect(1, 119154, '\P{^Is_Gc=--SPACING_Mark}', "");
Expect(0, 119155, '\p{Is_Gc=--SPACING_Mark}', "");
Expect(1, 119155, '\p{^Is_Gc=--SPACING_Mark}', "");
Expect(1, 119155, '\P{Is_Gc=--SPACING_Mark}', "");
Expect(0, 119155, '\P{^Is_Gc=--SPACING_Mark}', "");
Error('\p{Is_Category=:=__Mc}');
Error('\P{Is_Category=:=__Mc}');
Expect(1, 119154, '\p{Is_Category=mc}', "");
Expect(0, 119154, '\p{^Is_Category=mc}', "");
Expect(0, 119154, '\P{Is_Category=mc}', "");
Expect(1, 119154, '\P{^Is_Category=mc}', "");
Expect(0, 119155, '\p{Is_Category=mc}', "");
Expect(1, 119155, '\p{^Is_Category=mc}', "");
Expect(1, 119155, '\P{Is_Category=mc}', "");
Expect(0, 119155, '\P{^Is_Category=mc}', "");
Expect(1, 119154, '\p{Is_Category=_ mc}', "");
Expect(0, 119154, '\p{^Is_Category=_ mc}', "");
Expect(0, 119154, '\P{Is_Category=_ mc}', "");
Expect(1, 119154, '\P{^Is_Category=_ mc}', "");
Expect(0, 119155, '\p{Is_Category=_ mc}', "");
Expect(1, 119155, '\p{^Is_Category=_ mc}', "");
Expect(1, 119155, '\P{Is_Category=_ mc}', "");
Expect(0, 119155, '\P{^Is_Category=_ mc}', "");
Error('\p{General_Category= /a/Enclosing_MARK}');
Error('\P{General_Category= /a/Enclosing_MARK}');
Expect(1, 42610, '\p{General_Category=enclosingmark}', "");
Expect(0, 42610, '\p{^General_Category=enclosingmark}', "");
Expect(0, 42610, '\P{General_Category=enclosingmark}', "");
Expect(1, 42610, '\P{^General_Category=enclosingmark}', "");
Expect(0, 42611, '\p{General_Category=enclosingmark}', "");
Expect(1, 42611, '\p{^General_Category=enclosingmark}', "");
Expect(1, 42611, '\P{General_Category=enclosingmark}', "");
Expect(0, 42611, '\P{^General_Category=enclosingmark}', "");
Expect(1, 42610, '\p{General_Category:   --enclosing_Mark}', "");
Expect(0, 42610, '\p{^General_Category:   --enclosing_Mark}', "");
Expect(0, 42610, '\P{General_Category:   --enclosing_Mark}', "");
Expect(1, 42610, '\P{^General_Category:   --enclosing_Mark}', "");
Expect(0, 42611, '\p{General_Category:   --enclosing_Mark}', "");
Expect(1, 42611, '\p{^General_Category:   --enclosing_Mark}', "");
Expect(1, 42611, '\P{General_Category:   --enclosing_Mark}', "");
Expect(0, 42611, '\P{^General_Category:   --enclosing_Mark}', "");
Error('\p{Gc=:=_ Me}');
Error('\P{Gc=:=_ Me}');
Expect(1, 42610, '\p{Gc=me}', "");
Expect(0, 42610, '\p{^Gc=me}', "");
Expect(0, 42610, '\P{Gc=me}', "");
Expect(1, 42610, '\P{^Gc=me}', "");
Expect(0, 42611, '\p{Gc=me}', "");
Expect(1, 42611, '\p{^Gc=me}', "");
Expect(1, 42611, '\P{Gc=me}', "");
Expect(0, 42611, '\P{^Gc=me}', "");
Error('\p{Category=/a/  enclosing_Mark}');
Error('\P{Category=/a/  enclosing_Mark}');
Expect(1, 42610, '\p{Category=enclosingmark}', "");
Expect(0, 42610, '\p{^Category=enclosingmark}', "");
Expect(0, 42610, '\P{Category=enclosingmark}', "");
Expect(1, 42610, '\P{^Category=enclosingmark}', "");
Expect(0, 42611, '\p{Category=enclosingmark}', "");
Expect(1, 42611, '\p{^Category=enclosingmark}', "");
Expect(1, 42611, '\P{Category=enclosingmark}', "");
Expect(0, 42611, '\P{^Category=enclosingmark}', "");
Expect(1, 42610, '\p{Category:	ENCLOSING_mark}', "");
Expect(0, 42610, '\p{^Category:	ENCLOSING_mark}', "");
Expect(0, 42610, '\P{Category:	ENCLOSING_mark}', "");
Expect(1, 42610, '\P{^Category:	ENCLOSING_mark}', "");
Expect(0, 42611, '\p{Category:	ENCLOSING_mark}', "");
Expect(1, 42611, '\p{^Category:	ENCLOSING_mark}', "");
Expect(1, 42611, '\P{Category:	ENCLOSING_mark}', "");
Expect(0, 42611, '\P{^Category:	ENCLOSING_mark}', "");
Error('\p{Is_General_Category= Me/a/}');
Error('\P{Is_General_Category= Me/a/}');
Expect(1, 42610, '\p{Is_General_Category=me}', "");
Expect(0, 42610, '\p{^Is_General_Category=me}', "");
Expect(0, 42610, '\P{Is_General_Category=me}', "");
Expect(1, 42610, '\P{^Is_General_Category=me}', "");
Expect(0, 42611, '\p{Is_General_Category=me}', "");
Expect(1, 42611, '\p{^Is_General_Category=me}', "");
Expect(1, 42611, '\P{Is_General_Category=me}', "");
Expect(0, 42611, '\P{^Is_General_Category=me}', "");
Expect(1, 42610, '\p{Is_General_Category: 	_Me}', "");
Expect(0, 42610, '\p{^Is_General_Category: 	_Me}', "");
Expect(0, 42610, '\P{Is_General_Category: 	_Me}', "");
Expect(1, 42610, '\P{^Is_General_Category: 	_Me}', "");
Expect(0, 42611, '\p{Is_General_Category: 	_Me}', "");
Expect(1, 42611, '\p{^Is_General_Category: 	_Me}', "");
Expect(1, 42611, '\P{Is_General_Category: 	_Me}', "");
Expect(0, 42611, '\P{^Is_General_Category: 	_Me}', "");
Error('\p{Is_Gc=/a/_enclosing_MARK}');
Error('\P{Is_Gc=/a/_enclosing_MARK}');
Expect(1, 42610, '\p{Is_Gc=enclosingmark}', "");
Expect(0, 42610, '\p{^Is_Gc=enclosingmark}', "");
Expect(0, 42610, '\P{Is_Gc=enclosingmark}', "");
Expect(1, 42610, '\P{^Is_Gc=enclosingmark}', "");
Expect(0, 42611, '\p{Is_Gc=enclosingmark}', "");
Expect(1, 42611, '\p{^Is_Gc=enclosingmark}', "");
Expect(1, 42611, '\P{Is_Gc=enclosingmark}', "");
Expect(0, 42611, '\P{^Is_Gc=enclosingmark}', "");
Expect(1, 42610, '\p{Is_Gc:	_	Enclosing_Mark}', "");
Expect(0, 42610, '\p{^Is_Gc:	_	Enclosing_Mark}', "");
Expect(0, 42610, '\P{Is_Gc:	_	Enclosing_Mark}', "");
Expect(1, 42610, '\P{^Is_Gc:	_	Enclosing_Mark}', "");
Expect(0, 42611, '\p{Is_Gc:	_	Enclosing_Mark}', "");
Expect(1, 42611, '\p{^Is_Gc:	_	Enclosing_Mark}', "");
Expect(1, 42611, '\P{Is_Gc:	_	Enclosing_Mark}', "");
Expect(0, 42611, '\P{^Is_Gc:	_	Enclosing_Mark}', "");
Error('\p{Is_Category:-ME:=}');
Error('\P{Is_Category:-ME:=}');
Expect(1, 42610, '\p{Is_Category=me}', "");
Expect(0, 42610, '\p{^Is_Category=me}', "");
Expect(0, 42610, '\P{Is_Category=me}', "");
Expect(1, 42610, '\P{^Is_Category=me}', "");
Expect(0, 42611, '\p{Is_Category=me}', "");
Expect(1, 42611, '\p{^Is_Category=me}', "");
Expect(1, 42611, '\P{Is_Category=me}', "");
Expect(0, 42611, '\P{^Is_Category=me}', "");
Expect(1, 42610, '\p{Is_Category=  me}', "");
Expect(0, 42610, '\p{^Is_Category=  me}', "");
Expect(0, 42610, '\P{Is_Category=  me}', "");
Expect(1, 42610, '\P{^Is_Category=  me}', "");
Expect(0, 42611, '\p{Is_Category=  me}', "");
Expect(1, 42611, '\p{^Is_Category=  me}', "");
Expect(1, 42611, '\P{Is_Category=  me}', "");
Expect(0, 42611, '\P{^Is_Category=  me}', "");
Error('\p{General_Category=-/a/nonspacing_MARK}');
Error('\P{General_Category=-/a/nonspacing_MARK}');
Expect(1, 917999, '\p{General_Category:nonspacingmark}', "");
Expect(0, 917999, '\p{^General_Category:nonspacingmark}', "");
Expect(0, 917999, '\P{General_Category:nonspacingmark}', "");
Expect(1, 917999, '\P{^General_Category:nonspacingmark}', "");
Expect(0, 918000, '\p{General_Category:nonspacingmark}', "");
Expect(1, 918000, '\p{^General_Category:nonspacingmark}', "");
Expect(1, 918000, '\P{General_Category:nonspacingmark}', "");
Expect(0, 918000, '\P{^General_Category:nonspacingmark}', "");
Expect(1, 917999, '\p{General_Category= NONSPACING_mark}', "");
Expect(0, 917999, '\p{^General_Category= NONSPACING_mark}', "");
Expect(0, 917999, '\P{General_Category= NONSPACING_mark}', "");
Expect(1, 917999, '\P{^General_Category= NONSPACING_mark}', "");
Expect(0, 918000, '\p{General_Category= NONSPACING_mark}', "");
Expect(1, 918000, '\p{^General_Category= NONSPACING_mark}', "");
Expect(1, 918000, '\P{General_Category= NONSPACING_mark}', "");
Expect(0, 918000, '\P{^General_Category= NONSPACING_mark}', "");
Error('\p{Gc=:=--Mn}');
Error('\P{Gc=:=--Mn}');
Expect(1, 917999, '\p{Gc=mn}', "");
Expect(0, 917999, '\p{^Gc=mn}', "");
Expect(0, 917999, '\P{Gc=mn}', "");
Expect(1, 917999, '\P{^Gc=mn}', "");
Expect(0, 918000, '\p{Gc=mn}', "");
Expect(1, 918000, '\p{^Gc=mn}', "");
Expect(1, 918000, '\P{Gc=mn}', "");
Expect(0, 918000, '\P{^Gc=mn}', "");
Expect(1, 917999, '\p{Gc=_	MN}', "");
Expect(0, 917999, '\p{^Gc=_	MN}', "");
Expect(0, 917999, '\P{Gc=_	MN}', "");
Expect(1, 917999, '\P{^Gc=_	MN}', "");
Expect(0, 918000, '\p{Gc=_	MN}', "");
Expect(1, 918000, '\p{^Gc=_	MN}', "");
Expect(1, 918000, '\P{Gc=_	MN}', "");
Expect(0, 918000, '\P{^Gc=_	MN}', "");
Error('\p{Category=_/a/NONSPACING_Mark}');
Error('\P{Category=_/a/NONSPACING_Mark}');
Expect(1, 917999, '\p{Category=nonspacingmark}', "");
Expect(0, 917999, '\p{^Category=nonspacingmark}', "");
Expect(0, 917999, '\P{Category=nonspacingmark}', "");
Expect(1, 917999, '\P{^Category=nonspacingmark}', "");
Expect(0, 918000, '\p{Category=nonspacingmark}', "");
Expect(1, 918000, '\p{^Category=nonspacingmark}', "");
Expect(1, 918000, '\P{Category=nonspacingmark}', "");
Expect(0, 918000, '\P{^Category=nonspacingmark}', "");
Expect(1, 917999, '\p{Category:   	nonspacing_Mark}', "");
Expect(0, 917999, '\p{^Category:   	nonspacing_Mark}', "");
Expect(0, 917999, '\P{Category:   	nonspacing_Mark}', "");
Expect(1, 917999, '\P{^Category:   	nonspacing_Mark}', "");
Expect(0, 918000, '\p{Category:   	nonspacing_Mark}', "");
Expect(1, 918000, '\p{^Category:   	nonspacing_Mark}', "");
Expect(1, 918000, '\P{Category:   	nonspacing_Mark}', "");
Expect(0, 918000, '\P{^Category:   	nonspacing_Mark}', "");
Error('\p{Is_General_Category=		Mn:=}');
Error('\P{Is_General_Category=		Mn:=}');
Expect(1, 917999, '\p{Is_General_Category=mn}', "");
Expect(0, 917999, '\p{^Is_General_Category=mn}', "");
Expect(0, 917999, '\P{Is_General_Category=mn}', "");
Expect(1, 917999, '\P{^Is_General_Category=mn}', "");
Expect(0, 918000, '\p{Is_General_Category=mn}', "");
Expect(1, 918000, '\p{^Is_General_Category=mn}', "");
Expect(1, 918000, '\P{Is_General_Category=mn}', "");
Expect(0, 918000, '\P{^Is_General_Category=mn}', "");
Expect(1, 917999, '\p{Is_General_Category=		MN}', "");
Expect(0, 917999, '\p{^Is_General_Category=		MN}', "");
Expect(0, 917999, '\P{Is_General_Category=		MN}', "");
Expect(1, 917999, '\P{^Is_General_Category=		MN}', "");
Expect(0, 918000, '\p{Is_General_Category=		MN}', "");
Expect(1, 918000, '\p{^Is_General_Category=		MN}', "");
Expect(1, 918000, '\P{Is_General_Category=		MN}', "");
Expect(0, 918000, '\P{^Is_General_Category=		MN}', "");
Error('\p{Is_Gc=/a/nonspacing_mark}');
Error('\P{Is_Gc=/a/nonspacing_mark}');
Expect(1, 917999, '\p{Is_Gc=nonspacingmark}', "");
Expect(0, 917999, '\p{^Is_Gc=nonspacingmark}', "");
Expect(0, 917999, '\P{Is_Gc=nonspacingmark}', "");
Expect(1, 917999, '\P{^Is_Gc=nonspacingmark}', "");
Expect(0, 918000, '\p{Is_Gc=nonspacingmark}', "");
Expect(1, 918000, '\p{^Is_Gc=nonspacingmark}', "");
Expect(1, 918000, '\P{Is_Gc=nonspacingmark}', "");
Expect(0, 918000, '\P{^Is_Gc=nonspacingmark}', "");
Expect(1, 917999, '\p{Is_Gc: _-NONSPACING_Mark}', "");
Expect(0, 917999, '\p{^Is_Gc: _-NONSPACING_Mark}', "");
Expect(0, 917999, '\P{Is_Gc: _-NONSPACING_Mark}', "");
Expect(1, 917999, '\P{^Is_Gc: _-NONSPACING_Mark}', "");
Expect(0, 918000, '\p{Is_Gc: _-NONSPACING_Mark}', "");
Expect(1, 918000, '\p{^Is_Gc: _-NONSPACING_Mark}', "");
Expect(1, 918000, '\P{Is_Gc: _-NONSPACING_Mark}', "");
Expect(0, 918000, '\P{^Is_Gc: _-NONSPACING_Mark}', "");
Error('\p{Is_Category=-:=Mn}');
Error('\P{Is_Category=-:=Mn}');
Expect(1, 917999, '\p{Is_Category=mn}', "");
Expect(0, 917999, '\p{^Is_Category=mn}', "");
Expect(0, 917999, '\P{Is_Category=mn}', "");
Expect(1, 917999, '\P{^Is_Category=mn}', "");
Expect(0, 918000, '\p{Is_Category=mn}', "");
Expect(1, 918000, '\p{^Is_Category=mn}', "");
Expect(1, 918000, '\P{Is_Category=mn}', "");
Expect(0, 918000, '\P{^Is_Category=mn}', "");
Expect(1, 917999, '\p{Is_Category=	-MN}', "");
Expect(0, 917999, '\p{^Is_Category=	-MN}', "");
Expect(0, 917999, '\P{Is_Category=	-MN}', "");
Expect(1, 917999, '\P{^Is_Category=	-MN}', "");
Expect(0, 918000, '\p{Is_Category=	-MN}', "");
Expect(1, 918000, '\p{^Is_Category=	-MN}', "");
Expect(1, 918000, '\P{Is_Category=	-MN}', "");
Expect(0, 918000, '\P{^Is_Category=	-MN}', "");
Error('\p{General_Category:		_NUMBER:=}');
Error('\P{General_Category:		_NUMBER:=}');
Expect(1, 127242, '\p{General_Category=number}', "");
Expect(0, 127242, '\p{^General_Category=number}', "");
Expect(0, 127242, '\P{General_Category=number}', "");
Expect(1, 127242, '\P{^General_Category=number}', "");
Expect(0, 127243, '\p{General_Category=number}', "");
Expect(1, 127243, '\p{^General_Category=number}', "");
Expect(1, 127243, '\P{General_Category=number}', "");
Expect(0, 127243, '\P{^General_Category=number}', "");
Error('\p{Gc=/a/_N}');
Error('\P{Gc=/a/_N}');
Expect(1, 127242, '\p{Gc=n}', "");
Expect(0, 127242, '\p{^Gc=n}', "");
Expect(0, 127242, '\P{Gc=n}', "");
Expect(1, 127242, '\P{^Gc=n}', "");
Expect(0, 127243, '\p{Gc=n}', "");
Expect(1, 127243, '\p{^Gc=n}', "");
Expect(1, 127243, '\P{Gc=n}', "");
Expect(0, 127243, '\P{^Gc=n}', "");
Expect(1, 127242, '\p{Gc= N}', "");
Expect(0, 127242, '\p{^Gc= N}', "");
Expect(0, 127242, '\P{Gc= N}', "");
Expect(1, 127242, '\P{^Gc= N}', "");
Expect(0, 127243, '\p{Gc= N}', "");
Expect(1, 127243, '\p{^Gc= N}', "");
Expect(1, 127243, '\P{Gc= N}', "");
Expect(0, 127243, '\P{^Gc= N}', "");
Error('\p{Category:    Number:=}');
Error('\P{Category:    Number:=}');
Expect(1, 127242, '\p{Category=number}', "");
Expect(0, 127242, '\p{^Category=number}', "");
Expect(0, 127242, '\P{Category=number}', "");
Expect(1, 127242, '\P{^Category=number}', "");
Expect(0, 127243, '\p{Category=number}', "");
Expect(1, 127243, '\p{^Category=number}', "");
Expect(1, 127243, '\P{Category=number}', "");
Expect(0, 127243, '\P{^Category=number}', "");
Expect(1, 127242, '\p{Category= 	Number}', "");
Expect(0, 127242, '\p{^Category= 	Number}', "");
Expect(0, 127242, '\P{Category= 	Number}', "");
Expect(1, 127242, '\P{^Category= 	Number}', "");
Expect(0, 127243, '\p{Category= 	Number}', "");
Expect(1, 127243, '\p{^Category= 	Number}', "");
Expect(1, 127243, '\P{Category= 	Number}', "");
Expect(0, 127243, '\P{^Category= 	Number}', "");
Error('\p{Is_General_Category= N/a/}');
Error('\P{Is_General_Category= N/a/}');
Expect(1, 127242, '\p{Is_General_Category=n}', "");
Expect(0, 127242, '\p{^Is_General_Category=n}', "");
Expect(0, 127242, '\P{Is_General_Category=n}', "");
Expect(1, 127242, '\P{^Is_General_Category=n}', "");
Expect(0, 127243, '\p{Is_General_Category=n}', "");
Expect(1, 127243, '\p{^Is_General_Category=n}', "");
Expect(1, 127243, '\P{Is_General_Category=n}', "");
Expect(0, 127243, '\P{^Is_General_Category=n}', "");
Expect(1, 127242, '\p{Is_General_Category=	N}', "");
Expect(0, 127242, '\p{^Is_General_Category=	N}', "");
Expect(0, 127242, '\P{Is_General_Category=	N}', "");
Expect(1, 127242, '\P{^Is_General_Category=	N}', "");
Expect(0, 127243, '\p{Is_General_Category=	N}', "");
Expect(1, 127243, '\p{^Is_General_Category=	N}', "");
Expect(1, 127243, '\P{Is_General_Category=	N}', "");
Expect(0, 127243, '\P{^Is_General_Category=	N}', "");
Error('\p{Is_Gc= 	Number:=}');
Error('\P{Is_Gc= 	Number:=}');
Expect(1, 127242, '\p{Is_Gc=number}', "");
Expect(0, 127242, '\p{^Is_Gc=number}', "");
Expect(0, 127242, '\P{Is_Gc=number}', "");
Expect(1, 127242, '\P{^Is_Gc=number}', "");
Expect(0, 127243, '\p{Is_Gc=number}', "");
Expect(1, 127243, '\p{^Is_Gc=number}', "");
Expect(1, 127243, '\P{Is_Gc=number}', "");
Expect(0, 127243, '\P{^Is_Gc=number}', "");
Expect(1, 127242, '\p{Is_Gc=-_Number}', "");
Expect(0, 127242, '\p{^Is_Gc=-_Number}', "");
Expect(0, 127242, '\P{Is_Gc=-_Number}', "");
Expect(1, 127242, '\P{^Is_Gc=-_Number}', "");
Expect(0, 127243, '\p{Is_Gc=-_Number}', "");
Expect(1, 127243, '\p{^Is_Gc=-_Number}', "");
Expect(1, 127243, '\P{Is_Gc=-_Number}', "");
Expect(0, 127243, '\P{^Is_Gc=-_Number}', "");
Error('\p{Is_Category=/a/N}');
Error('\P{Is_Category=/a/N}');
Expect(1, 127242, '\p{Is_Category=n}', "");
Expect(0, 127242, '\p{^Is_Category=n}', "");
Expect(0, 127242, '\P{Is_Category=n}', "");
Expect(1, 127242, '\P{^Is_Category=n}', "");
Expect(0, 127243, '\p{Is_Category=n}', "");
Expect(1, 127243, '\p{^Is_Category=n}', "");
Expect(1, 127243, '\P{Is_Category=n}', "");
Expect(0, 127243, '\P{^Is_Category=n}', "");
Expect(1, 127242, '\p{Is_Category=-N}', "");
Expect(0, 127242, '\p{^Is_Category=-N}', "");
Expect(0, 127242, '\P{Is_Category=-N}', "");
Expect(1, 127242, '\P{^Is_Category=-N}', "");
Expect(0, 127243, '\p{Is_Category=-N}', "");
Expect(1, 127243, '\p{^Is_Category=-N}', "");
Expect(1, 127243, '\P{Is_Category=-N}', "");
Expect(0, 127243, '\P{^Is_Category=-N}', "");
Error('\p{General_Category=		Decimal_Number/a/}');
Error('\P{General_Category=		Decimal_Number/a/}');
Expect(1, 120831, '\p{General_Category=decimalnumber}', "");
Expect(0, 120831, '\p{^General_Category=decimalnumber}', "");
Expect(0, 120831, '\P{General_Category=decimalnumber}', "");
Expect(1, 120831, '\P{^General_Category=decimalnumber}', "");
Expect(0, 120832, '\p{General_Category=decimalnumber}', "");
Expect(1, 120832, '\p{^General_Category=decimalnumber}', "");
Expect(1, 120832, '\P{General_Category=decimalnumber}', "");
Expect(0, 120832, '\P{^General_Category=decimalnumber}', "");
Expect(1, 120831, '\p{General_Category=	 DECIMAL_Number}', "");
Expect(0, 120831, '\p{^General_Category=	 DECIMAL_Number}', "");
Expect(0, 120831, '\P{General_Category=	 DECIMAL_Number}', "");
Expect(1, 120831, '\P{^General_Category=	 DECIMAL_Number}', "");
Expect(0, 120832, '\p{General_Category=	 DECIMAL_Number}', "");
Expect(1, 120832, '\p{^General_Category=	 DECIMAL_Number}', "");
Expect(1, 120832, '\P{General_Category=	 DECIMAL_Number}', "");
Expect(0, 120832, '\P{^General_Category=	 DECIMAL_Number}', "");
Error('\p{Gc=/a/	_ND}');
Error('\P{Gc=/a/	_ND}');
Expect(1, 120831, '\p{Gc=nd}', "");
Expect(0, 120831, '\p{^Gc=nd}', "");
Expect(0, 120831, '\P{Gc=nd}', "");
Expect(1, 120831, '\P{^Gc=nd}', "");
Expect(0, 120832, '\p{Gc=nd}', "");
Expect(1, 120832, '\p{^Gc=nd}', "");
Expect(1, 120832, '\P{Gc=nd}', "");
Expect(0, 120832, '\P{^Gc=nd}', "");
Expect(1, 120831, '\p{Gc=		ND}', "");
Expect(0, 120831, '\p{^Gc=		ND}', "");
Expect(0, 120831, '\P{Gc=		ND}', "");
Expect(1, 120831, '\P{^Gc=		ND}', "");
Expect(0, 120832, '\p{Gc=		ND}', "");
Expect(1, 120832, '\p{^Gc=		ND}', "");
Expect(1, 120832, '\P{Gc=		ND}', "");
Expect(0, 120832, '\P{^Gc=		ND}', "");
Error('\p{Category=	/a/digit}');
Error('\P{Category=	/a/digit}');
Expect(1, 120831, '\p{Category:digit}', "");
Expect(0, 120831, '\p{^Category:digit}', "");
Expect(0, 120831, '\P{Category:digit}', "");
Expect(1, 120831, '\P{^Category:digit}', "");
Expect(0, 120832, '\p{Category:digit}', "");
Expect(1, 120832, '\p{^Category:digit}', "");
Expect(1, 120832, '\P{Category:digit}', "");
Expect(0, 120832, '\P{^Category:digit}', "");
Expect(1, 120831, '\p{Category= digit}', "");
Expect(0, 120831, '\p{^Category= digit}', "");
Expect(0, 120831, '\P{Category= digit}', "");
Expect(1, 120831, '\P{^Category= digit}', "");
Expect(0, 120832, '\p{Category= digit}', "");
Expect(1, 120832, '\p{^Category= digit}', "");
Expect(1, 120832, '\P{Category= digit}', "");
Expect(0, 120832, '\P{^Category= digit}', "");
Error('\p{Is_General_Category=/a/-_Decimal_number}');
Error('\P{Is_General_Category=/a/-_Decimal_number}');
Expect(1, 120831, '\p{Is_General_Category=decimalnumber}', "");
Expect(0, 120831, '\p{^Is_General_Category=decimalnumber}', "");
Expect(0, 120831, '\P{Is_General_Category=decimalnumber}', "");
Expect(1, 120831, '\P{^Is_General_Category=decimalnumber}', "");
Expect(0, 120832, '\p{Is_General_Category=decimalnumber}', "");
Expect(1, 120832, '\p{^Is_General_Category=decimalnumber}', "");
Expect(1, 120832, '\P{Is_General_Category=decimalnumber}', "");
Expect(0, 120832, '\P{^Is_General_Category=decimalnumber}', "");
Expect(1, 120831, '\p{Is_General_Category=--decimal_Number}', "");
Expect(0, 120831, '\p{^Is_General_Category=--decimal_Number}', "");
Expect(0, 120831, '\P{Is_General_Category=--decimal_Number}', "");
Expect(1, 120831, '\P{^Is_General_Category=--decimal_Number}', "");
Expect(0, 120832, '\p{Is_General_Category=--decimal_Number}', "");
Expect(1, 120832, '\p{^Is_General_Category=--decimal_Number}', "");
Expect(1, 120832, '\P{Is_General_Category=--decimal_Number}', "");
Expect(0, 120832, '\P{^Is_General_Category=--decimal_Number}', "");
Error('\p{Is_Gc=/a/- ND}');
Error('\P{Is_Gc=/a/- ND}');
Expect(1, 120831, '\p{Is_Gc:   nd}', "");
Expect(0, 120831, '\p{^Is_Gc:   nd}', "");
Expect(0, 120831, '\P{Is_Gc:   nd}', "");
Expect(1, 120831, '\P{^Is_Gc:   nd}', "");
Expect(0, 120832, '\p{Is_Gc:   nd}', "");
Expect(1, 120832, '\p{^Is_Gc:   nd}', "");
Expect(1, 120832, '\P{Is_Gc:   nd}', "");
Expect(0, 120832, '\P{^Is_Gc:   nd}', "");
Expect(1, 120831, '\p{Is_Gc:  	Nd}', "");
Expect(0, 120831, '\p{^Is_Gc:  	Nd}', "");
Expect(0, 120831, '\P{Is_Gc:  	Nd}', "");
Expect(1, 120831, '\P{^Is_Gc:  	Nd}', "");
Expect(0, 120832, '\p{Is_Gc:  	Nd}', "");
Expect(1, 120832, '\p{^Is_Gc:  	Nd}', "");
Expect(1, 120832, '\P{Is_Gc:  	Nd}', "");
Expect(0, 120832, '\P{^Is_Gc:  	Nd}', "");
Error('\p{Is_Category: /a/-DIGIT}');
Error('\P{Is_Category: /a/-DIGIT}');
Expect(1, 120831, '\p{Is_Category=digit}', "");
Expect(0, 120831, '\p{^Is_Category=digit}', "");
Expect(0, 120831, '\P{Is_Category=digit}', "");
Expect(1, 120831, '\P{^Is_Category=digit}', "");
Expect(0, 120832, '\p{Is_Category=digit}', "");
Expect(1, 120832, '\p{^Is_Category=digit}', "");
Expect(1, 120832, '\P{Is_Category=digit}', "");
Expect(0, 120832, '\P{^Is_Category=digit}', "");
Expect(1, 120831, '\p{Is_Category= Digit}', "");
Expect(0, 120831, '\p{^Is_Category= Digit}', "");
Expect(0, 120831, '\P{Is_Category= Digit}', "");
Expect(1, 120831, '\P{^Is_Category= Digit}', "");
Expect(0, 120832, '\p{Is_Category= Digit}', "");
Expect(1, 120832, '\p{^Is_Category= Digit}', "");
Expect(1, 120832, '\P{Is_Category= Digit}', "");
Expect(0, 120832, '\P{^Is_Category= Digit}', "");
Error('\p{General_Category=-:=Letter_Number}');
Error('\P{General_Category=-:=Letter_Number}');
Expect(1, 74850, '\p{General_Category=letternumber}', "");
Expect(0, 74850, '\p{^General_Category=letternumber}', "");
Expect(0, 74850, '\P{General_Category=letternumber}', "");
Expect(1, 74850, '\P{^General_Category=letternumber}', "");
Expect(0, 74851, '\p{General_Category=letternumber}', "");
Expect(1, 74851, '\p{^General_Category=letternumber}', "");
Expect(1, 74851, '\P{General_Category=letternumber}', "");
Expect(0, 74851, '\P{^General_Category=letternumber}', "");
Expect(1, 74850, '\p{General_Category=-	letter_number}', "");
Expect(0, 74850, '\p{^General_Category=-	letter_number}', "");
Expect(0, 74850, '\P{General_Category=-	letter_number}', "");
Expect(1, 74850, '\P{^General_Category=-	letter_number}', "");
Expect(0, 74851, '\p{General_Category=-	letter_number}', "");
Expect(1, 74851, '\p{^General_Category=-	letter_number}', "");
Expect(1, 74851, '\P{General_Category=-	letter_number}', "");
Expect(0, 74851, '\P{^General_Category=-	letter_number}', "");
Error('\p{Gc=	-Nl:=}');
Error('\P{Gc=	-Nl:=}');
Expect(1, 74850, '\p{Gc=nl}', "");
Expect(0, 74850, '\p{^Gc=nl}', "");
Expect(0, 74850, '\P{Gc=nl}', "");
Expect(1, 74850, '\P{^Gc=nl}', "");
Expect(0, 74851, '\p{Gc=nl}', "");
Expect(1, 74851, '\p{^Gc=nl}', "");
Expect(1, 74851, '\P{Gc=nl}', "");
Expect(0, 74851, '\P{^Gc=nl}', "");
Expect(1, 74850, '\p{Gc=	_nl}', "");
Expect(0, 74850, '\p{^Gc=	_nl}', "");
Expect(0, 74850, '\P{Gc=	_nl}', "");
Expect(1, 74850, '\P{^Gc=	_nl}', "");
Expect(0, 74851, '\p{Gc=	_nl}', "");
Expect(1, 74851, '\p{^Gc=	_nl}', "");
Expect(1, 74851, '\P{Gc=	_nl}', "");
Expect(0, 74851, '\P{^Gc=	_nl}', "");
Error('\p{Category=/a/  Letter_Number}');
Error('\P{Category=/a/  Letter_Number}');
Expect(1, 74850, '\p{Category=letternumber}', "");
Expect(0, 74850, '\p{^Category=letternumber}', "");
Expect(0, 74850, '\P{Category=letternumber}', "");
Expect(1, 74850, '\P{^Category=letternumber}', "");
Expect(0, 74851, '\p{Category=letternumber}', "");
Expect(1, 74851, '\p{^Category=letternumber}', "");
Expect(1, 74851, '\P{Category=letternumber}', "");
Expect(0, 74851, '\P{^Category=letternumber}', "");
Expect(1, 74850, '\p{Category=-letter_NUMBER}', "");
Expect(0, 74850, '\p{^Category=-letter_NUMBER}', "");
Expect(0, 74850, '\P{Category=-letter_NUMBER}', "");
Expect(1, 74850, '\P{^Category=-letter_NUMBER}', "");
Expect(0, 74851, '\p{Category=-letter_NUMBER}', "");
Expect(1, 74851, '\p{^Category=-letter_NUMBER}', "");
Expect(1, 74851, '\P{Category=-letter_NUMBER}', "");
Expect(0, 74851, '\P{^Category=-letter_NUMBER}', "");
Error('\p{Is_General_Category=-	Nl/a/}');
Error('\P{Is_General_Category=-	Nl/a/}');
Expect(1, 74850, '\p{Is_General_Category=nl}', "");
Expect(0, 74850, '\p{^Is_General_Category=nl}', "");
Expect(0, 74850, '\P{Is_General_Category=nl}', "");
Expect(1, 74850, '\P{^Is_General_Category=nl}', "");
Expect(0, 74851, '\p{Is_General_Category=nl}', "");
Expect(1, 74851, '\p{^Is_General_Category=nl}', "");
Expect(1, 74851, '\P{Is_General_Category=nl}', "");
Expect(0, 74851, '\P{^Is_General_Category=nl}', "");
Expect(1, 74850, '\p{Is_General_Category= Nl}', "");
Expect(0, 74850, '\p{^Is_General_Category= Nl}', "");
Expect(0, 74850, '\P{Is_General_Category= Nl}', "");
Expect(1, 74850, '\P{^Is_General_Category= Nl}', "");
Expect(0, 74851, '\p{Is_General_Category= Nl}', "");
Expect(1, 74851, '\p{^Is_General_Category= Nl}', "");
Expect(1, 74851, '\P{Is_General_Category= Nl}', "");
Expect(0, 74851, '\P{^Is_General_Category= Nl}', "");
Error('\p{Is_Gc=:=Letter_Number}');
Error('\P{Is_Gc=:=Letter_Number}');
Expect(1, 74850, '\p{Is_Gc=letternumber}', "");
Expect(0, 74850, '\p{^Is_Gc=letternumber}', "");
Expect(0, 74850, '\P{Is_Gc=letternumber}', "");
Expect(1, 74850, '\P{^Is_Gc=letternumber}', "");
Expect(0, 74851, '\p{Is_Gc=letternumber}', "");
Expect(1, 74851, '\p{^Is_Gc=letternumber}', "");
Expect(1, 74851, '\P{Is_Gc=letternumber}', "");
Expect(0, 74851, '\P{^Is_Gc=letternumber}', "");
Expect(1, 74850, '\p{Is_Gc=_letter_Number}', "");
Expect(0, 74850, '\p{^Is_Gc=_letter_Number}', "");
Expect(0, 74850, '\P{Is_Gc=_letter_Number}', "");
Expect(1, 74850, '\P{^Is_Gc=_letter_Number}', "");
Expect(0, 74851, '\p{Is_Gc=_letter_Number}', "");
Expect(1, 74851, '\p{^Is_Gc=_letter_Number}', "");
Expect(1, 74851, '\P{Is_Gc=_letter_Number}', "");
Expect(0, 74851, '\P{^Is_Gc=_letter_Number}', "");
Error('\p{Is_Category=:=Nl}');
Error('\P{Is_Category=:=Nl}');
Expect(1, 74850, '\p{Is_Category=nl}', "");
Expect(0, 74850, '\p{^Is_Category=nl}', "");
Expect(0, 74850, '\P{Is_Category=nl}', "");
Expect(1, 74850, '\P{^Is_Category=nl}', "");
Expect(0, 74851, '\p{Is_Category=nl}', "");
Expect(1, 74851, '\p{^Is_Category=nl}', "");
Expect(1, 74851, '\P{Is_Category=nl}', "");
Expect(0, 74851, '\P{^Is_Category=nl}', "");
Expect(1, 74850, '\p{Is_Category= 	NL}', "");
Expect(0, 74850, '\p{^Is_Category= 	NL}', "");
Expect(0, 74850, '\P{Is_Category= 	NL}', "");
Expect(1, 74850, '\P{^Is_Category= 	NL}', "");
Expect(0, 74851, '\p{Is_Category= 	NL}', "");
Expect(1, 74851, '\p{^Is_Category= 	NL}', "");
Expect(1, 74851, '\P{Is_Category= 	NL}', "");
Expect(0, 74851, '\P{^Is_Category= 	NL}', "");
Error('\p{General_Category=/a/Other_NUMBER}');
Error('\P{General_Category=/a/Other_NUMBER}');
Expect(1, 127242, '\p{General_Category=othernumber}', "");
Expect(0, 127242, '\p{^General_Category=othernumber}', "");
Expect(0, 127242, '\P{General_Category=othernumber}', "");
Expect(1, 127242, '\P{^General_Category=othernumber}', "");
Expect(0, 127243, '\p{General_Category=othernumber}', "");
Expect(1, 127243, '\p{^General_Category=othernumber}', "");
Expect(1, 127243, '\P{General_Category=othernumber}', "");
Expect(0, 127243, '\P{^General_Category=othernumber}', "");
Expect(1, 127242, '\p{General_Category=--Other_NUMBER}', "");
Expect(0, 127242, '\p{^General_Category=--Other_NUMBER}', "");
Expect(0, 127242, '\P{General_Category=--Other_NUMBER}', "");
Expect(1, 127242, '\P{^General_Category=--Other_NUMBER}', "");
Expect(0, 127243, '\p{General_Category=--Other_NUMBER}', "");
Expect(1, 127243, '\p{^General_Category=--Other_NUMBER}', "");
Expect(1, 127243, '\P{General_Category=--Other_NUMBER}', "");
Expect(0, 127243, '\P{^General_Category=--Other_NUMBER}', "");
Error('\p{Gc=	No/a/}');
Error('\P{Gc=	No/a/}');
Expect(1, 127242, '\p{Gc=no}', "");
Expect(0, 127242, '\p{^Gc=no}', "");
Expect(0, 127242, '\P{Gc=no}', "");
Expect(1, 127242, '\P{^Gc=no}', "");
Expect(0, 127243, '\p{Gc=no}', "");
Expect(1, 127243, '\p{^Gc=no}', "");
Expect(1, 127243, '\P{Gc=no}', "");
Expect(0, 127243, '\P{^Gc=no}', "");
Expect(1, 127242, '\p{Gc=--No}', "");
Expect(0, 127242, '\p{^Gc=--No}', "");
Expect(0, 127242, '\P{Gc=--No}', "");
Expect(1, 127242, '\P{^Gc=--No}', "");
Expect(0, 127243, '\p{Gc=--No}', "");
Expect(1, 127243, '\p{^Gc=--No}', "");
Expect(1, 127243, '\P{Gc=--No}', "");
Expect(0, 127243, '\P{^Gc=--No}', "");
Error('\p{Category=/a/		OTHER_number}');
Error('\P{Category=/a/		OTHER_number}');
Expect(1, 127242, '\p{Category=othernumber}', "");
Expect(0, 127242, '\p{^Category=othernumber}', "");
Expect(0, 127242, '\P{Category=othernumber}', "");
Expect(1, 127242, '\P{^Category=othernumber}', "");
Expect(0, 127243, '\p{Category=othernumber}', "");
Expect(1, 127243, '\p{^Category=othernumber}', "");
Expect(1, 127243, '\P{Category=othernumber}', "");
Expect(0, 127243, '\P{^Category=othernumber}', "");
Expect(1, 127242, '\p{Category=	OTHER_NUMBER}', "");
Expect(0, 127242, '\p{^Category=	OTHER_NUMBER}', "");
Expect(0, 127242, '\P{Category=	OTHER_NUMBER}', "");
Expect(1, 127242, '\P{^Category=	OTHER_NUMBER}', "");
Expect(0, 127243, '\p{Category=	OTHER_NUMBER}', "");
Expect(1, 127243, '\p{^Category=	OTHER_NUMBER}', "");
Expect(1, 127243, '\P{Category=	OTHER_NUMBER}', "");
Expect(0, 127243, '\P{^Category=	OTHER_NUMBER}', "");
Error('\p{Is_General_Category= No:=}');
Error('\P{Is_General_Category= No:=}');
Expect(1, 127242, '\p{Is_General_Category:   no}', "");
Expect(0, 127242, '\p{^Is_General_Category:   no}', "");
Expect(0, 127242, '\P{Is_General_Category:   no}', "");
Expect(1, 127242, '\P{^Is_General_Category:   no}', "");
Expect(0, 127243, '\p{Is_General_Category:   no}', "");
Expect(1, 127243, '\p{^Is_General_Category:   no}', "");
Expect(1, 127243, '\P{Is_General_Category:   no}', "");
Expect(0, 127243, '\P{^Is_General_Category:   no}', "");
Expect(1, 127242, '\p{Is_General_Category=	No}', "");
Expect(0, 127242, '\p{^Is_General_Category=	No}', "");
Expect(0, 127242, '\P{Is_General_Category=	No}', "");
Expect(1, 127242, '\P{^Is_General_Category=	No}', "");
Expect(0, 127243, '\p{Is_General_Category=	No}', "");
Expect(1, 127243, '\p{^Is_General_Category=	No}', "");
Expect(1, 127243, '\P{Is_General_Category=	No}', "");
Expect(0, 127243, '\P{^Is_General_Category=	No}', "");
Error('\p{Is_Gc=:=	 Other_Number}');
Error('\P{Is_Gc=:=	 Other_Number}');
Expect(1, 127242, '\p{Is_Gc: othernumber}', "");
Expect(0, 127242, '\p{^Is_Gc: othernumber}', "");
Expect(0, 127242, '\P{Is_Gc: othernumber}', "");
Expect(1, 127242, '\P{^Is_Gc: othernumber}', "");
Expect(0, 127243, '\p{Is_Gc: othernumber}', "");
Expect(1, 127243, '\p{^Is_Gc: othernumber}', "");
Expect(1, 127243, '\P{Is_Gc: othernumber}', "");
Expect(0, 127243, '\P{^Is_Gc: othernumber}', "");
Expect(1, 127242, '\p{Is_Gc= OTHER_number}', "");
Expect(0, 127242, '\p{^Is_Gc= OTHER_number}', "");
Expect(0, 127242, '\P{Is_Gc= OTHER_number}', "");
Expect(1, 127242, '\P{^Is_Gc= OTHER_number}', "");
Expect(0, 127243, '\p{Is_Gc= OTHER_number}', "");
Expect(1, 127243, '\p{^Is_Gc= OTHER_number}', "");
Expect(1, 127243, '\P{Is_Gc= OTHER_number}', "");
Expect(0, 127243, '\P{^Is_Gc= OTHER_number}', "");
Error('\p{Is_Category=:=- No}');
Error('\P{Is_Category=:=- No}');
Expect(1, 127242, '\p{Is_Category:no}', "");
Expect(0, 127242, '\p{^Is_Category:no}', "");
Expect(0, 127242, '\P{Is_Category:no}', "");
Expect(1, 127242, '\P{^Is_Category:no}', "");
Expect(0, 127243, '\p{Is_Category:no}', "");
Expect(1, 127243, '\p{^Is_Category:no}', "");
Expect(1, 127243, '\P{Is_Category:no}', "");
Expect(0, 127243, '\P{^Is_Category:no}', "");
Expect(1, 127242, '\p{Is_Category= 	No}', "");
Expect(0, 127242, '\p{^Is_Category= 	No}', "");
Expect(0, 127242, '\P{Is_Category= 	No}', "");
Expect(1, 127242, '\P{^Is_Category= 	No}', "");
Expect(0, 127243, '\p{Is_Category= 	No}', "");
Expect(1, 127243, '\p{^Is_Category= 	No}', "");
Expect(1, 127243, '\P{Is_Category= 	No}', "");
Expect(0, 127243, '\P{^Is_Category= 	No}', "");
Error('\p{General_Category=		Punctuation/a/}');
Error('\P{General_Category=		Punctuation/a/}');
Expect(1, 74867, '\p{General_Category=punctuation}', "");
Expect(0, 74867, '\p{^General_Category=punctuation}', "");
Expect(0, 74867, '\P{General_Category=punctuation}', "");
Expect(1, 74867, '\P{^General_Category=punctuation}', "");
Expect(0, 74868, '\p{General_Category=punctuation}', "");
Expect(1, 74868, '\p{^General_Category=punctuation}', "");
Expect(1, 74868, '\P{General_Category=punctuation}', "");
Expect(0, 74868, '\P{^General_Category=punctuation}', "");
Expect(1, 74867, '\p{General_Category=_-Punctuation}', "");
Expect(0, 74867, '\p{^General_Category=_-Punctuation}', "");
Expect(0, 74867, '\P{General_Category=_-Punctuation}', "");
Expect(1, 74867, '\P{^General_Category=_-Punctuation}', "");
Expect(0, 74868, '\p{General_Category=_-Punctuation}', "");
Expect(1, 74868, '\p{^General_Category=_-Punctuation}', "");
Expect(1, 74868, '\P{General_Category=_-Punctuation}', "");
Expect(0, 74868, '\P{^General_Category=_-Punctuation}', "");
Error('\p{Gc=-/a/P}');
Error('\P{Gc=-/a/P}');
Expect(1, 74867, '\p{Gc=p}', "");
Expect(0, 74867, '\p{^Gc=p}', "");
Expect(0, 74867, '\P{Gc=p}', "");
Expect(1, 74867, '\P{^Gc=p}', "");
Expect(0, 74868, '\p{Gc=p}', "");
Expect(1, 74868, '\p{^Gc=p}', "");
Expect(1, 74868, '\P{Gc=p}', "");
Expect(0, 74868, '\P{^Gc=p}', "");
Expect(1, 74867, '\p{Gc=	P}', "");
Expect(0, 74867, '\p{^Gc=	P}', "");
Expect(0, 74867, '\P{Gc=	P}', "");
Expect(1, 74867, '\P{^Gc=	P}', "");
Expect(0, 74868, '\p{Gc=	P}', "");
Expect(1, 74868, '\p{^Gc=	P}', "");
Expect(1, 74868, '\P{Gc=	P}', "");
Expect(0, 74868, '\P{^Gc=	P}', "");
Error('\p{Category:   /a/ _PUNCT}');
Error('\P{Category:   /a/ _PUNCT}');
Expect(1, 74867, '\p{Category=punct}', "");
Expect(0, 74867, '\p{^Category=punct}', "");
Expect(0, 74867, '\P{Category=punct}', "");
Expect(1, 74867, '\P{^Category=punct}', "");
Expect(0, 74868, '\p{Category=punct}', "");
Expect(1, 74868, '\p{^Category=punct}', "");
Expect(1, 74868, '\P{Category=punct}', "");
Expect(0, 74868, '\P{^Category=punct}', "");
Expect(1, 74867, '\p{Category=	Punct}', "");
Expect(0, 74867, '\p{^Category=	Punct}', "");
Expect(0, 74867, '\P{Category=	Punct}', "");
Expect(1, 74867, '\P{^Category=	Punct}', "");
Expect(0, 74868, '\p{Category=	Punct}', "");
Expect(1, 74868, '\p{^Category=	Punct}', "");
Expect(1, 74868, '\P{Category=	Punct}', "");
Expect(0, 74868, '\P{^Category=	Punct}', "");
Error('\p{Is_General_Category=:= Punctuation}');
Error('\P{Is_General_Category=:= Punctuation}');
Expect(1, 74867, '\p{Is_General_Category=punctuation}', "");
Expect(0, 74867, '\p{^Is_General_Category=punctuation}', "");
Expect(0, 74867, '\P{Is_General_Category=punctuation}', "");
Expect(1, 74867, '\P{^Is_General_Category=punctuation}', "");
Expect(0, 74868, '\p{Is_General_Category=punctuation}', "");
Expect(1, 74868, '\p{^Is_General_Category=punctuation}', "");
Expect(1, 74868, '\P{Is_General_Category=punctuation}', "");
Expect(0, 74868, '\P{^Is_General_Category=punctuation}', "");
Expect(1, 74867, '\p{Is_General_Category= 	PUNCTUATION}', "");
Expect(0, 74867, '\p{^Is_General_Category= 	PUNCTUATION}', "");
Expect(0, 74867, '\P{Is_General_Category= 	PUNCTUATION}', "");
Expect(1, 74867, '\P{^Is_General_Category= 	PUNCTUATION}', "");
Expect(0, 74868, '\p{Is_General_Category= 	PUNCTUATION}', "");
Expect(1, 74868, '\p{^Is_General_Category= 	PUNCTUATION}', "");
Expect(1, 74868, '\P{Is_General_Category= 	PUNCTUATION}', "");
Expect(0, 74868, '\P{^Is_General_Category= 	PUNCTUATION}', "");
Error('\p{Is_Gc=-:=P}');
Error('\P{Is_Gc=-:=P}');
Expect(1, 74867, '\p{Is_Gc:   p}', "");
Expect(0, 74867, '\p{^Is_Gc:   p}', "");
Expect(0, 74867, '\P{Is_Gc:   p}', "");
Expect(1, 74867, '\P{^Is_Gc:   p}', "");
Expect(0, 74868, '\p{Is_Gc:   p}', "");
Expect(1, 74868, '\p{^Is_Gc:   p}', "");
Expect(1, 74868, '\P{Is_Gc:   p}', "");
Expect(0, 74868, '\P{^Is_Gc:   p}', "");
Expect(1, 74867, '\p{Is_Gc=--P}', "");
Expect(0, 74867, '\p{^Is_Gc=--P}', "");
Expect(0, 74867, '\P{Is_Gc=--P}', "");
Expect(1, 74867, '\P{^Is_Gc=--P}', "");
Expect(0, 74868, '\p{Is_Gc=--P}', "");
Expect(1, 74868, '\p{^Is_Gc=--P}', "");
Expect(1, 74868, '\P{Is_Gc=--P}', "");
Expect(0, 74868, '\P{^Is_Gc=--P}', "");
Error('\p{Is_Category= -Punct/a/}');
Error('\P{Is_Category= -Punct/a/}');
Expect(1, 74867, '\p{Is_Category=punct}', "");
Expect(0, 74867, '\p{^Is_Category=punct}', "");
Expect(0, 74867, '\P{Is_Category=punct}', "");
Expect(1, 74867, '\P{^Is_Category=punct}', "");
Expect(0, 74868, '\p{Is_Category=punct}', "");
Expect(1, 74868, '\p{^Is_Category=punct}', "");
Expect(1, 74868, '\P{Is_Category=punct}', "");
Expect(0, 74868, '\P{^Is_Category=punct}', "");
Expect(1, 74867, '\p{Is_Category=  Punct}', "");
Expect(0, 74867, '\p{^Is_Category=  Punct}', "");
Expect(0, 74867, '\P{Is_Category=  Punct}', "");
Expect(1, 74867, '\P{^Is_Category=  Punct}', "");
Expect(0, 74868, '\p{Is_Category=  Punct}', "");
Expect(1, 74868, '\p{^Is_Category=  Punct}', "");
Expect(1, 74868, '\P{Is_Category=  Punct}', "");
Expect(0, 74868, '\P{^Is_Category=  Punct}', "");
Error('\p{General_Category=	-Connector_Punctuation:=}');
Error('\P{General_Category=	-Connector_Punctuation:=}');
Expect(1, 65343, '\p{General_Category=connectorpunctuation}', "");
Expect(0, 65343, '\p{^General_Category=connectorpunctuation}', "");
Expect(0, 65343, '\P{General_Category=connectorpunctuation}', "");
Expect(1, 65343, '\P{^General_Category=connectorpunctuation}', "");
Expect(0, 65344, '\p{General_Category=connectorpunctuation}', "");
Expect(1, 65344, '\p{^General_Category=connectorpunctuation}', "");
Expect(1, 65344, '\P{General_Category=connectorpunctuation}', "");
Expect(0, 65344, '\P{^General_Category=connectorpunctuation}', "");
Expect(1, 65343, '\p{General_Category=	connector_punctuation}', "");
Expect(0, 65343, '\p{^General_Category=	connector_punctuation}', "");
Expect(0, 65343, '\P{General_Category=	connector_punctuation}', "");
Expect(1, 65343, '\P{^General_Category=	connector_punctuation}', "");
Expect(0, 65344, '\p{General_Category=	connector_punctuation}', "");
Expect(1, 65344, '\p{^General_Category=	connector_punctuation}', "");
Expect(1, 65344, '\P{General_Category=	connector_punctuation}', "");
Expect(0, 65344, '\P{^General_Category=	connector_punctuation}', "");
Error('\p{Gc= /a/PC}');
Error('\P{Gc= /a/PC}');
Expect(1, 65343, '\p{Gc=pc}', "");
Expect(0, 65343, '\p{^Gc=pc}', "");
Expect(0, 65343, '\P{Gc=pc}', "");
Expect(1, 65343, '\P{^Gc=pc}', "");
Expect(0, 65344, '\p{Gc=pc}', "");
Expect(1, 65344, '\p{^Gc=pc}', "");
Expect(1, 65344, '\P{Gc=pc}', "");
Expect(0, 65344, '\P{^Gc=pc}', "");
Expect(1, 65343, '\p{Gc:__Pc}', "");
Expect(0, 65343, '\p{^Gc:__Pc}', "");
Expect(0, 65343, '\P{Gc:__Pc}', "");
Expect(1, 65343, '\P{^Gc:__Pc}', "");
Expect(0, 65344, '\p{Gc:__Pc}', "");
Expect(1, 65344, '\p{^Gc:__Pc}', "");
Expect(1, 65344, '\P{Gc:__Pc}', "");
Expect(0, 65344, '\P{^Gc:__Pc}', "");
Error('\p{Category= /a/Connector_Punctuation}');
Error('\P{Category= /a/Connector_Punctuation}');
Expect(1, 65343, '\p{Category=connectorpunctuation}', "");
Expect(0, 65343, '\p{^Category=connectorpunctuation}', "");
Expect(0, 65343, '\P{Category=connectorpunctuation}', "");
Expect(1, 65343, '\P{^Category=connectorpunctuation}', "");
Expect(0, 65344, '\p{Category=connectorpunctuation}', "");
Expect(1, 65344, '\p{^Category=connectorpunctuation}', "");
Expect(1, 65344, '\P{Category=connectorpunctuation}', "");
Expect(0, 65344, '\P{^Category=connectorpunctuation}', "");
Expect(1, 65343, '\p{Category=-connector_Punctuation}', "");
Expect(0, 65343, '\p{^Category=-connector_Punctuation}', "");
Expect(0, 65343, '\P{Category=-connector_Punctuation}', "");
Expect(1, 65343, '\P{^Category=-connector_Punctuation}', "");
Expect(0, 65344, '\p{Category=-connector_Punctuation}', "");
Expect(1, 65344, '\p{^Category=-connector_Punctuation}', "");
Expect(1, 65344, '\P{Category=-connector_Punctuation}', "");
Expect(0, 65344, '\P{^Category=-connector_Punctuation}', "");
Error('\p{Is_General_Category=	Pc/a/}');
Error('\P{Is_General_Category=	Pc/a/}');
Expect(1, 65343, '\p{Is_General_Category=pc}', "");
Expect(0, 65343, '\p{^Is_General_Category=pc}', "");
Expect(0, 65343, '\P{Is_General_Category=pc}', "");
Expect(1, 65343, '\P{^Is_General_Category=pc}', "");
Expect(0, 65344, '\p{Is_General_Category=pc}', "");
Expect(1, 65344, '\p{^Is_General_Category=pc}', "");
Expect(1, 65344, '\P{Is_General_Category=pc}', "");
Expect(0, 65344, '\P{^Is_General_Category=pc}', "");
Expect(1, 65343, '\p{Is_General_Category=_ PC}', "");
Expect(0, 65343, '\p{^Is_General_Category=_ PC}', "");
Expect(0, 65343, '\P{Is_General_Category=_ PC}', "");
Expect(1, 65343, '\P{^Is_General_Category=_ PC}', "");
Expect(0, 65344, '\p{Is_General_Category=_ PC}', "");
Expect(1, 65344, '\p{^Is_General_Category=_ PC}', "");
Expect(1, 65344, '\P{Is_General_Category=_ PC}', "");
Expect(0, 65344, '\P{^Is_General_Category=_ PC}', "");
Error('\p{Is_Gc=:=- connector_Punctuation}');
Error('\P{Is_Gc=:=- connector_Punctuation}');
Expect(1, 65343, '\p{Is_Gc=connectorpunctuation}', "");
Expect(0, 65343, '\p{^Is_Gc=connectorpunctuation}', "");
Expect(0, 65343, '\P{Is_Gc=connectorpunctuation}', "");
Expect(1, 65343, '\P{^Is_Gc=connectorpunctuation}', "");
Expect(0, 65344, '\p{Is_Gc=connectorpunctuation}', "");
Expect(1, 65344, '\p{^Is_Gc=connectorpunctuation}', "");
Expect(1, 65344, '\P{Is_Gc=connectorpunctuation}', "");
Expect(0, 65344, '\P{^Is_Gc=connectorpunctuation}', "");
Expect(1, 65343, '\p{Is_Gc=__Connector_Punctuation}', "");
Expect(0, 65343, '\p{^Is_Gc=__Connector_Punctuation}', "");
Expect(0, 65343, '\P{Is_Gc=__Connector_Punctuation}', "");
Expect(1, 65343, '\P{^Is_Gc=__Connector_Punctuation}', "");
Expect(0, 65344, '\p{Is_Gc=__Connector_Punctuation}', "");
Expect(1, 65344, '\p{^Is_Gc=__Connector_Punctuation}', "");
Expect(1, 65344, '\P{Is_Gc=__Connector_Punctuation}', "");
Expect(0, 65344, '\P{^Is_Gc=__Connector_Punctuation}', "");
Error('\p{Is_Category=-	Pc/a/}');
Error('\P{Is_Category=-	Pc/a/}');
Expect(1, 65343, '\p{Is_Category:pc}', "");
Expect(0, 65343, '\p{^Is_Category:pc}', "");
Expect(0, 65343, '\P{Is_Category:pc}', "");
Expect(1, 65343, '\P{^Is_Category:pc}', "");
Expect(0, 65344, '\p{Is_Category:pc}', "");
Expect(1, 65344, '\p{^Is_Category:pc}', "");
Expect(1, 65344, '\P{Is_Category:pc}', "");
Expect(0, 65344, '\P{^Is_Category:pc}', "");
Expect(1, 65343, '\p{Is_Category= 	Pc}', "");
Expect(0, 65343, '\p{^Is_Category= 	Pc}', "");
Expect(0, 65343, '\P{Is_Category= 	Pc}', "");
Expect(1, 65343, '\P{^Is_Category= 	Pc}', "");
Expect(0, 65344, '\p{Is_Category= 	Pc}', "");
Expect(1, 65344, '\p{^Is_Category= 	Pc}', "");
Expect(1, 65344, '\P{Is_Category= 	Pc}', "");
Expect(0, 65344, '\P{^Is_Category= 	Pc}', "");
Error('\p{General_Category= :=DASH_Punctuation}');
Error('\P{General_Category= :=DASH_Punctuation}');
Expect(1, 65293, '\p{General_Category=dashpunctuation}', "");
Expect(0, 65293, '\p{^General_Category=dashpunctuation}', "");
Expect(0, 65293, '\P{General_Category=dashpunctuation}', "");
Expect(1, 65293, '\P{^General_Category=dashpunctuation}', "");
Expect(0, 65294, '\p{General_Category=dashpunctuation}', "");
Expect(1, 65294, '\p{^General_Category=dashpunctuation}', "");
Expect(1, 65294, '\P{General_Category=dashpunctuation}', "");
Expect(0, 65294, '\P{^General_Category=dashpunctuation}', "");
Expect(1, 65293, '\p{General_Category= Dash_Punctuation}', "");
Expect(0, 65293, '\p{^General_Category= Dash_Punctuation}', "");
Expect(0, 65293, '\P{General_Category= Dash_Punctuation}', "");
Expect(1, 65293, '\P{^General_Category= Dash_Punctuation}', "");
Expect(0, 65294, '\p{General_Category= Dash_Punctuation}', "");
Expect(1, 65294, '\p{^General_Category= Dash_Punctuation}', "");
Expect(1, 65294, '\P{General_Category= Dash_Punctuation}', "");
Expect(0, 65294, '\P{^General_Category= Dash_Punctuation}', "");
Error('\p{Gc=__pd:=}');
Error('\P{Gc=__pd:=}');
Expect(1, 65293, '\p{Gc=pd}', "");
Expect(0, 65293, '\p{^Gc=pd}', "");
Expect(0, 65293, '\P{Gc=pd}', "");
Expect(1, 65293, '\P{^Gc=pd}', "");
Expect(0, 65294, '\p{Gc=pd}', "");
Expect(1, 65294, '\p{^Gc=pd}', "");
Expect(1, 65294, '\P{Gc=pd}', "");
Expect(0, 65294, '\P{^Gc=pd}', "");
Expect(1, 65293, '\p{Gc:- PD}', "");
Expect(0, 65293, '\p{^Gc:- PD}', "");
Expect(0, 65293, '\P{Gc:- PD}', "");
Expect(1, 65293, '\P{^Gc:- PD}', "");
Expect(0, 65294, '\p{Gc:- PD}', "");
Expect(1, 65294, '\p{^Gc:- PD}', "");
Expect(1, 65294, '\P{Gc:- PD}', "");
Expect(0, 65294, '\P{^Gc:- PD}', "");
Error('\p{Category=	-DASH_punctuation/a/}');
Error('\P{Category=	-DASH_punctuation/a/}');
Expect(1, 65293, '\p{Category=dashpunctuation}', "");
Expect(0, 65293, '\p{^Category=dashpunctuation}', "");
Expect(0, 65293, '\P{Category=dashpunctuation}', "");
Expect(1, 65293, '\P{^Category=dashpunctuation}', "");
Expect(0, 65294, '\p{Category=dashpunctuation}', "");
Expect(1, 65294, '\p{^Category=dashpunctuation}', "");
Expect(1, 65294, '\P{Category=dashpunctuation}', "");
Expect(0, 65294, '\P{^Category=dashpunctuation}', "");
Expect(1, 65293, '\p{Category=DASH_Punctuation}', "");
Expect(0, 65293, '\p{^Category=DASH_Punctuation}', "");
Expect(0, 65293, '\P{Category=DASH_Punctuation}', "");
Expect(1, 65293, '\P{^Category=DASH_Punctuation}', "");
Expect(0, 65294, '\p{Category=DASH_Punctuation}', "");
Expect(1, 65294, '\p{^Category=DASH_Punctuation}', "");
Expect(1, 65294, '\P{Category=DASH_Punctuation}', "");
Expect(0, 65294, '\P{^Category=DASH_Punctuation}', "");
Error('\p{Is_General_Category=:=Pd}');
Error('\P{Is_General_Category=:=Pd}');
Expect(1, 65293, '\p{Is_General_Category=pd}', "");
Expect(0, 65293, '\p{^Is_General_Category=pd}', "");
Expect(0, 65293, '\P{Is_General_Category=pd}', "");
Expect(1, 65293, '\P{^Is_General_Category=pd}', "");
Expect(0, 65294, '\p{Is_General_Category=pd}', "");
Expect(1, 65294, '\p{^Is_General_Category=pd}', "");
Expect(1, 65294, '\P{Is_General_Category=pd}', "");
Expect(0, 65294, '\P{^Is_General_Category=pd}', "");
Expect(1, 65293, '\p{Is_General_Category= Pd}', "");
Expect(0, 65293, '\p{^Is_General_Category= Pd}', "");
Expect(0, 65293, '\P{Is_General_Category= Pd}', "");
Expect(1, 65293, '\P{^Is_General_Category= Pd}', "");
Expect(0, 65294, '\p{Is_General_Category= Pd}', "");
Expect(1, 65294, '\p{^Is_General_Category= Pd}', "");
Expect(1, 65294, '\P{Is_General_Category= Pd}', "");
Expect(0, 65294, '\P{^Is_General_Category= Pd}', "");
Error('\p{Is_Gc=-:=Dash_Punctuation}');
Error('\P{Is_Gc=-:=Dash_Punctuation}');
Expect(1, 65293, '\p{Is_Gc=dashpunctuation}', "");
Expect(0, 65293, '\p{^Is_Gc=dashpunctuation}', "");
Expect(0, 65293, '\P{Is_Gc=dashpunctuation}', "");
Expect(1, 65293, '\P{^Is_Gc=dashpunctuation}', "");
Expect(0, 65294, '\p{Is_Gc=dashpunctuation}', "");
Expect(1, 65294, '\p{^Is_Gc=dashpunctuation}', "");
Expect(1, 65294, '\P{Is_Gc=dashpunctuation}', "");
Expect(0, 65294, '\P{^Is_Gc=dashpunctuation}', "");
Expect(1, 65293, '\p{Is_Gc=_dash_Punctuation}', "");
Expect(0, 65293, '\p{^Is_Gc=_dash_Punctuation}', "");
Expect(0, 65293, '\P{Is_Gc=_dash_Punctuation}', "");
Expect(1, 65293, '\P{^Is_Gc=_dash_Punctuation}', "");
Expect(0, 65294, '\p{Is_Gc=_dash_Punctuation}', "");
Expect(1, 65294, '\p{^Is_Gc=_dash_Punctuation}', "");
Expect(1, 65294, '\P{Is_Gc=_dash_Punctuation}', "");
Expect(0, 65294, '\P{^Is_Gc=_dash_Punctuation}', "");
Error('\p{Is_Category=-/a/Pd}');
Error('\P{Is_Category=-/a/Pd}');
Expect(1, 65293, '\p{Is_Category=pd}', "");
Expect(0, 65293, '\p{^Is_Category=pd}', "");
Expect(0, 65293, '\P{Is_Category=pd}', "");
Expect(1, 65293, '\P{^Is_Category=pd}', "");
Expect(0, 65294, '\p{Is_Category=pd}', "");
Expect(1, 65294, '\p{^Is_Category=pd}', "");
Expect(1, 65294, '\P{Is_Category=pd}', "");
Expect(0, 65294, '\P{^Is_Category=pd}', "");
Expect(1, 65293, '\p{Is_Category=	pd}', "");
Expect(0, 65293, '\p{^Is_Category=	pd}', "");
Expect(0, 65293, '\P{Is_Category=	pd}', "");
Expect(1, 65293, '\P{^Is_Category=	pd}', "");
Expect(0, 65294, '\p{Is_Category=	pd}', "");
Expect(1, 65294, '\p{^Is_Category=	pd}', "");
Expect(1, 65294, '\P{Is_Category=	pd}', "");
Expect(0, 65294, '\P{^Is_Category=	pd}', "");
Error('\p{General_Category=/a/_ close_punctuation}');
Error('\P{General_Category=/a/_ close_punctuation}');
Expect(1, 65379, '\p{General_Category=closepunctuation}', "");
Expect(0, 65379, '\p{^General_Category=closepunctuation}', "");
Expect(0, 65379, '\P{General_Category=closepunctuation}', "");
Expect(1, 65379, '\P{^General_Category=closepunctuation}', "");
Expect(0, 65380, '\p{General_Category=closepunctuation}', "");
Expect(1, 65380, '\p{^General_Category=closepunctuation}', "");
Expect(1, 65380, '\P{General_Category=closepunctuation}', "");
Expect(0, 65380, '\P{^General_Category=closepunctuation}', "");
Expect(1, 65379, '\p{General_Category=--Close_PUNCTUATION}', "");
Expect(0, 65379, '\p{^General_Category=--Close_PUNCTUATION}', "");
Expect(0, 65379, '\P{General_Category=--Close_PUNCTUATION}', "");
Expect(1, 65379, '\P{^General_Category=--Close_PUNCTUATION}', "");
Expect(0, 65380, '\p{General_Category=--Close_PUNCTUATION}', "");
Expect(1, 65380, '\p{^General_Category=--Close_PUNCTUATION}', "");
Expect(1, 65380, '\P{General_Category=--Close_PUNCTUATION}', "");
Expect(0, 65380, '\P{^General_Category=--Close_PUNCTUATION}', "");
Error('\p{Gc=/a/		Pe}');
Error('\P{Gc=/a/		Pe}');
Expect(1, 65379, '\p{Gc=pe}', "");
Expect(0, 65379, '\p{^Gc=pe}', "");
Expect(0, 65379, '\P{Gc=pe}', "");
Expect(1, 65379, '\P{^Gc=pe}', "");
Expect(0, 65380, '\p{Gc=pe}', "");
Expect(1, 65380, '\p{^Gc=pe}', "");
Expect(1, 65380, '\P{Gc=pe}', "");
Expect(0, 65380, '\P{^Gc=pe}', "");
Expect(1, 65379, '\p{Gc=_	PE}', "");
Expect(0, 65379, '\p{^Gc=_	PE}', "");
Expect(0, 65379, '\P{Gc=_	PE}', "");
Expect(1, 65379, '\P{^Gc=_	PE}', "");
Expect(0, 65380, '\p{Gc=_	PE}', "");
Expect(1, 65380, '\p{^Gc=_	PE}', "");
Expect(1, 65380, '\P{Gc=_	PE}', "");
Expect(0, 65380, '\P{^Gc=_	PE}', "");
Error('\p{Category=:=--CLOSE_PUNCTUATION}');
Error('\P{Category=:=--CLOSE_PUNCTUATION}');
Expect(1, 65379, '\p{Category=closepunctuation}', "");
Expect(0, 65379, '\p{^Category=closepunctuation}', "");
Expect(0, 65379, '\P{Category=closepunctuation}', "");
Expect(1, 65379, '\P{^Category=closepunctuation}', "");
Expect(0, 65380, '\p{Category=closepunctuation}', "");
Expect(1, 65380, '\p{^Category=closepunctuation}', "");
Expect(1, 65380, '\P{Category=closepunctuation}', "");
Expect(0, 65380, '\P{^Category=closepunctuation}', "");
Expect(1, 65379, '\p{Category=-close_PUNCTUATION}', "");
Expect(0, 65379, '\p{^Category=-close_PUNCTUATION}', "");
Expect(0, 65379, '\P{Category=-close_PUNCTUATION}', "");
Expect(1, 65379, '\P{^Category=-close_PUNCTUATION}', "");
Expect(0, 65380, '\p{Category=-close_PUNCTUATION}', "");
Expect(1, 65380, '\p{^Category=-close_PUNCTUATION}', "");
Expect(1, 65380, '\P{Category=-close_PUNCTUATION}', "");
Expect(0, 65380, '\P{^Category=-close_PUNCTUATION}', "");
Error('\p{Is_General_Category=--Pe/a/}');
Error('\P{Is_General_Category=--Pe/a/}');
Expect(1, 65379, '\p{Is_General_Category=pe}', "");
Expect(0, 65379, '\p{^Is_General_Category=pe}', "");
Expect(0, 65379, '\P{Is_General_Category=pe}', "");
Expect(1, 65379, '\P{^Is_General_Category=pe}', "");
Expect(0, 65380, '\p{Is_General_Category=pe}', "");
Expect(1, 65380, '\p{^Is_General_Category=pe}', "");
Expect(1, 65380, '\P{Is_General_Category=pe}', "");
Expect(0, 65380, '\P{^Is_General_Category=pe}', "");
Expect(1, 65379, '\p{Is_General_Category=--Pe}', "");
Expect(0, 65379, '\p{^Is_General_Category=--Pe}', "");
Expect(0, 65379, '\P{Is_General_Category=--Pe}', "");
Expect(1, 65379, '\P{^Is_General_Category=--Pe}', "");
Expect(0, 65380, '\p{Is_General_Category=--Pe}', "");
Expect(1, 65380, '\p{^Is_General_Category=--Pe}', "");
Expect(1, 65380, '\P{Is_General_Category=--Pe}', "");
Expect(0, 65380, '\P{^Is_General_Category=--Pe}', "");
Error('\p{Is_Gc::=CLOSE_Punctuation}');
Error('\P{Is_Gc::=CLOSE_Punctuation}');
Expect(1, 65379, '\p{Is_Gc=closepunctuation}', "");
Expect(0, 65379, '\p{^Is_Gc=closepunctuation}', "");
Expect(0, 65379, '\P{Is_Gc=closepunctuation}', "");
Expect(1, 65379, '\P{^Is_Gc=closepunctuation}', "");
Expect(0, 65380, '\p{Is_Gc=closepunctuation}', "");
Expect(1, 65380, '\p{^Is_Gc=closepunctuation}', "");
Expect(1, 65380, '\P{Is_Gc=closepunctuation}', "");
Expect(0, 65380, '\P{^Is_Gc=closepunctuation}', "");
Expect(1, 65379, '\p{Is_Gc=-	Close_PUNCTUATION}', "");
Expect(0, 65379, '\p{^Is_Gc=-	Close_PUNCTUATION}', "");
Expect(0, 65379, '\P{Is_Gc=-	Close_PUNCTUATION}', "");
Expect(1, 65379, '\P{^Is_Gc=-	Close_PUNCTUATION}', "");
Expect(0, 65380, '\p{Is_Gc=-	Close_PUNCTUATION}', "");
Expect(1, 65380, '\p{^Is_Gc=-	Close_PUNCTUATION}', "");
Expect(1, 65380, '\P{Is_Gc=-	Close_PUNCTUATION}', "");
Expect(0, 65380, '\P{^Is_Gc=-	Close_PUNCTUATION}', "");
Error('\p{Is_Category=_:=Pe}');
Error('\P{Is_Category=_:=Pe}');
Expect(1, 65379, '\p{Is_Category=pe}', "");
Expect(0, 65379, '\p{^Is_Category=pe}', "");
Expect(0, 65379, '\P{Is_Category=pe}', "");
Expect(1, 65379, '\P{^Is_Category=pe}', "");
Expect(0, 65380, '\p{Is_Category=pe}', "");
Expect(1, 65380, '\p{^Is_Category=pe}', "");
Expect(1, 65380, '\P{Is_Category=pe}', "");
Expect(0, 65380, '\P{^Is_Category=pe}', "");
Expect(1, 65379, '\p{Is_Category=_PE}', "");
Expect(0, 65379, '\p{^Is_Category=_PE}', "");
Expect(0, 65379, '\P{Is_Category=_PE}', "");
Expect(1, 65379, '\P{^Is_Category=_PE}', "");
Expect(0, 65380, '\p{Is_Category=_PE}', "");
Expect(1, 65380, '\p{^Is_Category=_PE}', "");
Expect(1, 65380, '\P{Is_Category=_PE}', "");
Expect(0, 65380, '\P{^Is_Category=_PE}', "");
Error('\p{General_Category= :=final_Punctuation}');
Error('\P{General_Category= :=final_Punctuation}');
Expect(1, 11809, '\p{General_Category=finalpunctuation}', "");
Expect(0, 11809, '\p{^General_Category=finalpunctuation}', "");
Expect(0, 11809, '\P{General_Category=finalpunctuation}', "");
Expect(1, 11809, '\P{^General_Category=finalpunctuation}', "");
Expect(0, 11810, '\p{General_Category=finalpunctuation}', "");
Expect(1, 11810, '\p{^General_Category=finalpunctuation}', "");
Expect(1, 11810, '\P{General_Category=finalpunctuation}', "");
Expect(0, 11810, '\P{^General_Category=finalpunctuation}', "");
Expect(1, 11809, '\p{General_Category=-_Final_Punctuation}', "");
Expect(0, 11809, '\p{^General_Category=-_Final_Punctuation}', "");
Expect(0, 11809, '\P{General_Category=-_Final_Punctuation}', "");
Expect(1, 11809, '\P{^General_Category=-_Final_Punctuation}', "");
Expect(0, 11810, '\p{General_Category=-_Final_Punctuation}', "");
Expect(1, 11810, '\p{^General_Category=-_Final_Punctuation}', "");
Expect(1, 11810, '\P{General_Category=-_Final_Punctuation}', "");
Expect(0, 11810, '\P{^General_Category=-_Final_Punctuation}', "");
Error('\p{Gc:	/a/		Pf}');
Error('\P{Gc:	/a/		Pf}');
Expect(1, 11809, '\p{Gc=pf}', "");
Expect(0, 11809, '\p{^Gc=pf}', "");
Expect(0, 11809, '\P{Gc=pf}', "");
Expect(1, 11809, '\P{^Gc=pf}', "");
Expect(0, 11810, '\p{Gc=pf}', "");
Expect(1, 11810, '\p{^Gc=pf}', "");
Expect(1, 11810, '\P{Gc=pf}', "");
Expect(0, 11810, '\P{^Gc=pf}', "");
Expect(1, 11809, '\p{Gc:	  Pf}', "");
Expect(0, 11809, '\p{^Gc:	  Pf}', "");
Expect(0, 11809, '\P{Gc:	  Pf}', "");
Expect(1, 11809, '\P{^Gc:	  Pf}', "");
Expect(0, 11810, '\p{Gc:	  Pf}', "");
Expect(1, 11810, '\p{^Gc:	  Pf}', "");
Expect(1, 11810, '\P{Gc:	  Pf}', "");
Expect(0, 11810, '\P{^Gc:	  Pf}', "");
Error('\p{Category=-	final_punctuation:=}');
Error('\P{Category=-	final_punctuation:=}');
Expect(1, 11809, '\p{Category=finalpunctuation}', "");
Expect(0, 11809, '\p{^Category=finalpunctuation}', "");
Expect(0, 11809, '\P{Category=finalpunctuation}', "");
Expect(1, 11809, '\P{^Category=finalpunctuation}', "");
Expect(0, 11810, '\p{Category=finalpunctuation}', "");
Expect(1, 11810, '\p{^Category=finalpunctuation}', "");
Expect(1, 11810, '\P{Category=finalpunctuation}', "");
Expect(0, 11810, '\P{^Category=finalpunctuation}', "");
Expect(1, 11809, '\p{Category:	--Final_Punctuation}', "");
Expect(0, 11809, '\p{^Category:	--Final_Punctuation}', "");
Expect(0, 11809, '\P{Category:	--Final_Punctuation}', "");
Expect(1, 11809, '\P{^Category:	--Final_Punctuation}', "");
Expect(0, 11810, '\p{Category:	--Final_Punctuation}', "");
Expect(1, 11810, '\p{^Category:	--Final_Punctuation}', "");
Expect(1, 11810, '\P{Category:	--Final_Punctuation}', "");
Expect(0, 11810, '\P{^Category:	--Final_Punctuation}', "");
Error('\p{Is_General_Category=-:=PF}');
Error('\P{Is_General_Category=-:=PF}');
Expect(1, 11809, '\p{Is_General_Category=pf}', "");
Expect(0, 11809, '\p{^Is_General_Category=pf}', "");
Expect(0, 11809, '\P{Is_General_Category=pf}', "");
Expect(1, 11809, '\P{^Is_General_Category=pf}', "");
Expect(0, 11810, '\p{Is_General_Category=pf}', "");
Expect(1, 11810, '\p{^Is_General_Category=pf}', "");
Expect(1, 11810, '\P{Is_General_Category=pf}', "");
Expect(0, 11810, '\P{^Is_General_Category=pf}', "");
Expect(1, 11809, '\p{Is_General_Category=_ Pf}', "");
Expect(0, 11809, '\p{^Is_General_Category=_ Pf}', "");
Expect(0, 11809, '\P{Is_General_Category=_ Pf}', "");
Expect(1, 11809, '\P{^Is_General_Category=_ Pf}', "");
Expect(0, 11810, '\p{Is_General_Category=_ Pf}', "");
Expect(1, 11810, '\p{^Is_General_Category=_ Pf}', "");
Expect(1, 11810, '\P{Is_General_Category=_ Pf}', "");
Expect(0, 11810, '\P{^Is_General_Category=_ Pf}', "");
Error('\p{Is_Gc=/a/_-final_Punctuation}');
Error('\P{Is_Gc=/a/_-final_Punctuation}');
Expect(1, 11809, '\p{Is_Gc=finalpunctuation}', "");
Expect(0, 11809, '\p{^Is_Gc=finalpunctuation}', "");
Expect(0, 11809, '\P{Is_Gc=finalpunctuation}', "");
Expect(1, 11809, '\P{^Is_Gc=finalpunctuation}', "");
Expect(0, 11810, '\p{Is_Gc=finalpunctuation}', "");
Expect(1, 11810, '\p{^Is_Gc=finalpunctuation}', "");
Expect(1, 11810, '\P{Is_Gc=finalpunctuation}', "");
Expect(0, 11810, '\P{^Is_Gc=finalpunctuation}', "");
Expect(1, 11809, '\p{Is_Gc=_-FINAL_punctuation}', "");
Expect(0, 11809, '\p{^Is_Gc=_-FINAL_punctuation}', "");
Expect(0, 11809, '\P{Is_Gc=_-FINAL_punctuation}', "");
Expect(1, 11809, '\P{^Is_Gc=_-FINAL_punctuation}', "");
Expect(0, 11810, '\p{Is_Gc=_-FINAL_punctuation}', "");
Expect(1, 11810, '\p{^Is_Gc=_-FINAL_punctuation}', "");
Expect(1, 11810, '\P{Is_Gc=_-FINAL_punctuation}', "");
Expect(0, 11810, '\P{^Is_Gc=_-FINAL_punctuation}', "");
Error('\p{Is_Category=/a/ 	PF}');
Error('\P{Is_Category=/a/ 	PF}');
Expect(1, 11809, '\p{Is_Category=pf}', "");
Expect(0, 11809, '\p{^Is_Category=pf}', "");
Expect(0, 11809, '\P{Is_Category=pf}', "");
Expect(1, 11809, '\P{^Is_Category=pf}', "");
Expect(0, 11810, '\p{Is_Category=pf}', "");
Expect(1, 11810, '\p{^Is_Category=pf}', "");
Expect(1, 11810, '\P{Is_Category=pf}', "");
Expect(0, 11810, '\P{^Is_Category=pf}', "");
Expect(1, 11809, '\p{Is_Category=-Pf}', "");
Expect(0, 11809, '\p{^Is_Category=-Pf}', "");
Expect(0, 11809, '\P{Is_Category=-Pf}', "");
Expect(1, 11809, '\P{^Is_Category=-Pf}', "");
Expect(0, 11810, '\p{Is_Category=-Pf}', "");
Expect(1, 11810, '\p{^Is_Category=-Pf}', "");
Expect(1, 11810, '\P{Is_Category=-Pf}', "");
Expect(0, 11810, '\P{^Is_Category=-Pf}', "");
Error('\p{General_Category:_/a/INITIAL_Punctuation}');
Error('\P{General_Category:_/a/INITIAL_Punctuation}');
Expect(1, 11808, '\p{General_Category=initialpunctuation}', "");
Expect(0, 11808, '\p{^General_Category=initialpunctuation}', "");
Expect(0, 11808, '\P{General_Category=initialpunctuation}', "");
Expect(1, 11808, '\P{^General_Category=initialpunctuation}', "");
Expect(0, 11809, '\p{General_Category=initialpunctuation}', "");
Expect(1, 11809, '\p{^General_Category=initialpunctuation}', "");
Expect(1, 11809, '\P{General_Category=initialpunctuation}', "");
Expect(0, 11809, '\P{^General_Category=initialpunctuation}', "");
Expect(1, 11808, '\p{General_Category=Initial_Punctuation}', "");
Expect(0, 11808, '\p{^General_Category=Initial_Punctuation}', "");
Expect(0, 11808, '\P{General_Category=Initial_Punctuation}', "");
Expect(1, 11808, '\P{^General_Category=Initial_Punctuation}', "");
Expect(0, 11809, '\p{General_Category=Initial_Punctuation}', "");
Expect(1, 11809, '\p{^General_Category=Initial_Punctuation}', "");
Expect(1, 11809, '\P{General_Category=Initial_Punctuation}', "");
Expect(0, 11809, '\P{^General_Category=Initial_Punctuation}', "");
Error('\p{Gc=:=	_PI}');
Error('\P{Gc=:=	_PI}');
Expect(1, 11808, '\p{Gc=pi}', "");
Expect(0, 11808, '\p{^Gc=pi}', "");
Expect(0, 11808, '\P{Gc=pi}', "");
Expect(1, 11808, '\P{^Gc=pi}', "");
Expect(0, 11809, '\p{Gc=pi}', "");
Expect(1, 11809, '\p{^Gc=pi}', "");
Expect(1, 11809, '\P{Gc=pi}', "");
Expect(0, 11809, '\P{^Gc=pi}', "");
Expect(1, 11808, '\p{Gc=_ PI}', "");
Expect(0, 11808, '\p{^Gc=_ PI}', "");
Expect(0, 11808, '\P{Gc=_ PI}', "");
Expect(1, 11808, '\P{^Gc=_ PI}', "");
Expect(0, 11809, '\p{Gc=_ PI}', "");
Expect(1, 11809, '\p{^Gc=_ PI}', "");
Expect(1, 11809, '\P{Gc=_ PI}', "");
Expect(0, 11809, '\P{^Gc=_ PI}', "");
Error('\p{Category=-_initial_Punctuation/a/}');
Error('\P{Category=-_initial_Punctuation/a/}');
Expect(1, 11808, '\p{Category=initialpunctuation}', "");
Expect(0, 11808, '\p{^Category=initialpunctuation}', "");
Expect(0, 11808, '\P{Category=initialpunctuation}', "");
Expect(1, 11808, '\P{^Category=initialpunctuation}', "");
Expect(0, 11809, '\p{Category=initialpunctuation}', "");
Expect(1, 11809, '\p{^Category=initialpunctuation}', "");
Expect(1, 11809, '\P{Category=initialpunctuation}', "");
Expect(0, 11809, '\P{^Category=initialpunctuation}', "");
Expect(1, 11808, '\p{Category=	-Initial_PUNCTUATION}', "");
Expect(0, 11808, '\p{^Category=	-Initial_PUNCTUATION}', "");
Expect(0, 11808, '\P{Category=	-Initial_PUNCTUATION}', "");
Expect(1, 11808, '\P{^Category=	-Initial_PUNCTUATION}', "");
Expect(0, 11809, '\p{Category=	-Initial_PUNCTUATION}', "");
Expect(1, 11809, '\p{^Category=	-Initial_PUNCTUATION}', "");
Expect(1, 11809, '\P{Category=	-Initial_PUNCTUATION}', "");
Expect(0, 11809, '\P{^Category=	-Initial_PUNCTUATION}', "");
Error('\p{Is_General_Category=_:=Pi}');
Error('\P{Is_General_Category=_:=Pi}');
Expect(1, 11808, '\p{Is_General_Category:pi}', "");
Expect(0, 11808, '\p{^Is_General_Category:pi}', "");
Expect(0, 11808, '\P{Is_General_Category:pi}', "");
Expect(1, 11808, '\P{^Is_General_Category:pi}', "");
Expect(0, 11809, '\p{Is_General_Category:pi}', "");
Expect(1, 11809, '\p{^Is_General_Category:pi}', "");
Expect(1, 11809, '\P{Is_General_Category:pi}', "");
Expect(0, 11809, '\P{^Is_General_Category:pi}', "");
Expect(1, 11808, '\p{Is_General_Category= -Pi}', "");
Expect(0, 11808, '\p{^Is_General_Category= -Pi}', "");
Expect(0, 11808, '\P{Is_General_Category= -Pi}', "");
Expect(1, 11808, '\P{^Is_General_Category= -Pi}', "");
Expect(0, 11809, '\p{Is_General_Category= -Pi}', "");
Expect(1, 11809, '\p{^Is_General_Category= -Pi}', "");
Expect(1, 11809, '\P{Is_General_Category= -Pi}', "");
Expect(0, 11809, '\P{^Is_General_Category= -Pi}', "");
Error('\p{Is_Gc: /a/ 	INITIAL_PUNCTUATION}');
Error('\P{Is_Gc: /a/ 	INITIAL_PUNCTUATION}');
Expect(1, 11808, '\p{Is_Gc: initialpunctuation}', "");
Expect(0, 11808, '\p{^Is_Gc: initialpunctuation}', "");
Expect(0, 11808, '\P{Is_Gc: initialpunctuation}', "");
Expect(1, 11808, '\P{^Is_Gc: initialpunctuation}', "");
Expect(0, 11809, '\p{Is_Gc: initialpunctuation}', "");
Expect(1, 11809, '\p{^Is_Gc: initialpunctuation}', "");
Expect(1, 11809, '\P{Is_Gc: initialpunctuation}', "");
Expect(0, 11809, '\P{^Is_Gc: initialpunctuation}', "");
Expect(1, 11808, '\p{Is_Gc=__Initial_Punctuation}', "");
Expect(0, 11808, '\p{^Is_Gc=__Initial_Punctuation}', "");
Expect(0, 11808, '\P{Is_Gc=__Initial_Punctuation}', "");
Expect(1, 11808, '\P{^Is_Gc=__Initial_Punctuation}', "");
Expect(0, 11809, '\p{Is_Gc=__Initial_Punctuation}', "");
Expect(1, 11809, '\p{^Is_Gc=__Initial_Punctuation}', "");
Expect(1, 11809, '\P{Is_Gc=__Initial_Punctuation}', "");
Expect(0, 11809, '\P{^Is_Gc=__Initial_Punctuation}', "");
Error('\p{Is_Category=_:=PI}');
Error('\P{Is_Category=_:=PI}');
Expect(1, 11808, '\p{Is_Category=pi}', "");
Expect(0, 11808, '\p{^Is_Category=pi}', "");
Expect(0, 11808, '\P{Is_Category=pi}', "");
Expect(1, 11808, '\P{^Is_Category=pi}', "");
Expect(0, 11809, '\p{Is_Category=pi}', "");
Expect(1, 11809, '\p{^Is_Category=pi}', "");
Expect(1, 11809, '\P{Is_Category=pi}', "");
Expect(0, 11809, '\P{^Is_Category=pi}', "");
Expect(1, 11808, '\p{Is_Category=- Pi}', "");
Expect(0, 11808, '\p{^Is_Category=- Pi}', "");
Expect(0, 11808, '\P{Is_Category=- Pi}', "");
Expect(1, 11808, '\P{^Is_Category=- Pi}', "");
Expect(0, 11809, '\p{Is_Category=- Pi}', "");
Expect(1, 11809, '\p{^Is_Category=- Pi}', "");
Expect(1, 11809, '\P{Is_Category=- Pi}', "");
Expect(0, 11809, '\P{^Is_Category=- Pi}', "");
Error('\p{General_Category= :=Other_Punctuation}');
Error('\P{General_Category= :=Other_Punctuation}');
Expect(1, 74867, '\p{General_Category=otherpunctuation}', "");
Expect(0, 74867, '\p{^General_Category=otherpunctuation}', "");
Expect(0, 74867, '\P{General_Category=otherpunctuation}', "");
Expect(1, 74867, '\P{^General_Category=otherpunctuation}', "");
Expect(0, 74868, '\p{General_Category=otherpunctuation}', "");
Expect(1, 74868, '\p{^General_Category=otherpunctuation}', "");
Expect(1, 74868, '\P{General_Category=otherpunctuation}', "");
Expect(0, 74868, '\P{^General_Category=otherpunctuation}', "");
Expect(1, 74867, '\p{General_Category:_	other_Punctuation}', "");
Expect(0, 74867, '\p{^General_Category:_	other_Punctuation}', "");
Expect(0, 74867, '\P{General_Category:_	other_Punctuation}', "");
Expect(1, 74867, '\P{^General_Category:_	other_Punctuation}', "");
Expect(0, 74868, '\p{General_Category:_	other_Punctuation}', "");
Expect(1, 74868, '\p{^General_Category:_	other_Punctuation}', "");
Expect(1, 74868, '\P{General_Category:_	other_Punctuation}', "");
Expect(0, 74868, '\P{^General_Category:_	other_Punctuation}', "");
Error('\p{Gc=_Po/a/}');
Error('\P{Gc=_Po/a/}');
Expect(1, 74867, '\p{Gc=po}', "");
Expect(0, 74867, '\p{^Gc=po}', "");
Expect(0, 74867, '\P{Gc=po}', "");
Expect(1, 74867, '\P{^Gc=po}', "");
Expect(0, 74868, '\p{Gc=po}', "");
Expect(1, 74868, '\p{^Gc=po}', "");
Expect(1, 74868, '\P{Gc=po}', "");
Expect(0, 74868, '\P{^Gc=po}', "");
Expect(1, 74867, '\p{Gc= po}', "");
Expect(0, 74867, '\p{^Gc= po}', "");
Expect(0, 74867, '\P{Gc= po}', "");
Expect(1, 74867, '\P{^Gc= po}', "");
Expect(0, 74868, '\p{Gc= po}', "");
Expect(1, 74868, '\p{^Gc= po}', "");
Expect(1, 74868, '\P{Gc= po}', "");
Expect(0, 74868, '\P{^Gc= po}', "");
Error('\p{Category=_:=Other_Punctuation}');
Error('\P{Category=_:=Other_Punctuation}');
Expect(1, 74867, '\p{Category=otherpunctuation}', "");
Expect(0, 74867, '\p{^Category=otherpunctuation}', "");
Expect(0, 74867, '\P{Category=otherpunctuation}', "");
Expect(1, 74867, '\P{^Category=otherpunctuation}', "");
Expect(0, 74868, '\p{Category=otherpunctuation}', "");
Expect(1, 74868, '\p{^Category=otherpunctuation}', "");
Expect(1, 74868, '\P{Category=otherpunctuation}', "");
Expect(0, 74868, '\P{^Category=otherpunctuation}', "");
Expect(1, 74867, '\p{Category=	_other_Punctuation}', "");
Expect(0, 74867, '\p{^Category=	_other_Punctuation}', "");
Expect(0, 74867, '\P{Category=	_other_Punctuation}', "");
Expect(1, 74867, '\P{^Category=	_other_Punctuation}', "");
Expect(0, 74868, '\p{Category=	_other_Punctuation}', "");
Expect(1, 74868, '\p{^Category=	_other_Punctuation}', "");
Expect(1, 74868, '\P{Category=	_other_Punctuation}', "");
Expect(0, 74868, '\P{^Category=	_other_Punctuation}', "");
Error('\p{Is_General_Category:	- PO/a/}');
Error('\P{Is_General_Category:	- PO/a/}');
Expect(1, 74867, '\p{Is_General_Category=po}', "");
Expect(0, 74867, '\p{^Is_General_Category=po}', "");
Expect(0, 74867, '\P{Is_General_Category=po}', "");
Expect(1, 74867, '\P{^Is_General_Category=po}', "");
Expect(0, 74868, '\p{Is_General_Category=po}', "");
Expect(1, 74868, '\p{^Is_General_Category=po}', "");
Expect(1, 74868, '\P{Is_General_Category=po}', "");
Expect(0, 74868, '\P{^Is_General_Category=po}', "");
Expect(1, 74867, '\p{Is_General_Category=	-Po}', "");
Expect(0, 74867, '\p{^Is_General_Category=	-Po}', "");
Expect(0, 74867, '\P{Is_General_Category=	-Po}', "");
Expect(1, 74867, '\P{^Is_General_Category=	-Po}', "");
Expect(0, 74868, '\p{Is_General_Category=	-Po}', "");
Expect(1, 74868, '\p{^Is_General_Category=	-Po}', "");
Expect(1, 74868, '\P{Is_General_Category=	-Po}', "");
Expect(0, 74868, '\P{^Is_General_Category=	-Po}', "");
Error('\p{Is_Gc: 	/a/OTHER_punctuation}');
Error('\P{Is_Gc: 	/a/OTHER_punctuation}');
Expect(1, 74867, '\p{Is_Gc=otherpunctuation}', "");
Expect(0, 74867, '\p{^Is_Gc=otherpunctuation}', "");
Expect(0, 74867, '\P{Is_Gc=otherpunctuation}', "");
Expect(1, 74867, '\P{^Is_Gc=otherpunctuation}', "");
Expect(0, 74868, '\p{Is_Gc=otherpunctuation}', "");
Expect(1, 74868, '\p{^Is_Gc=otherpunctuation}', "");
Expect(1, 74868, '\P{Is_Gc=otherpunctuation}', "");
Expect(0, 74868, '\P{^Is_Gc=otherpunctuation}', "");
Expect(1, 74867, '\p{Is_Gc=_Other_Punctuation}', "");
Expect(0, 74867, '\p{^Is_Gc=_Other_Punctuation}', "");
Expect(0, 74867, '\P{Is_Gc=_Other_Punctuation}', "");
Expect(1, 74867, '\P{^Is_Gc=_Other_Punctuation}', "");
Expect(0, 74868, '\p{Is_Gc=_Other_Punctuation}', "");
Expect(1, 74868, '\p{^Is_Gc=_Other_Punctuation}', "");
Expect(1, 74868, '\P{Is_Gc=_Other_Punctuation}', "");
Expect(0, 74868, '\P{^Is_Gc=_Other_Punctuation}', "");
Error('\p{Is_Category=/a/  Po}');
Error('\P{Is_Category=/a/  Po}');
Expect(1, 74867, '\p{Is_Category=po}', "");
Expect(0, 74867, '\p{^Is_Category=po}', "");
Expect(0, 74867, '\P{Is_Category=po}', "");
Expect(1, 74867, '\P{^Is_Category=po}', "");
Expect(0, 74868, '\p{Is_Category=po}', "");
Expect(1, 74868, '\p{^Is_Category=po}', "");
Expect(1, 74868, '\P{Is_Category=po}', "");
Expect(0, 74868, '\P{^Is_Category=po}', "");
Expect(1, 74867, '\p{Is_Category= -Po}', "");
Expect(0, 74867, '\p{^Is_Category= -Po}', "");
Expect(0, 74867, '\P{Is_Category= -Po}', "");
Expect(1, 74867, '\P{^Is_Category= -Po}', "");
Expect(0, 74868, '\p{Is_Category= -Po}', "");
Expect(1, 74868, '\p{^Is_Category= -Po}', "");
Expect(1, 74868, '\P{Is_Category= -Po}', "");
Expect(0, 74868, '\P{^Is_Category= -Po}', "");
Error('\p{General_Category=/a/ OPEN_PUNCTUATION}');
Error('\P{General_Category=/a/ OPEN_PUNCTUATION}');
Expect(1, 65378, '\p{General_Category=openpunctuation}', "");
Expect(0, 65378, '\p{^General_Category=openpunctuation}', "");
Expect(0, 65378, '\P{General_Category=openpunctuation}', "");
Expect(1, 65378, '\P{^General_Category=openpunctuation}', "");
Expect(0, 65379, '\p{General_Category=openpunctuation}', "");
Expect(1, 65379, '\p{^General_Category=openpunctuation}', "");
Expect(1, 65379, '\P{General_Category=openpunctuation}', "");
Expect(0, 65379, '\P{^General_Category=openpunctuation}', "");
Expect(1, 65378, '\p{General_Category=_	OPEN_Punctuation}', "");
Expect(0, 65378, '\p{^General_Category=_	OPEN_Punctuation}', "");
Expect(0, 65378, '\P{General_Category=_	OPEN_Punctuation}', "");
Expect(1, 65378, '\P{^General_Category=_	OPEN_Punctuation}', "");
Expect(0, 65379, '\p{General_Category=_	OPEN_Punctuation}', "");
Expect(1, 65379, '\p{^General_Category=_	OPEN_Punctuation}', "");
Expect(1, 65379, '\P{General_Category=_	OPEN_Punctuation}', "");
Expect(0, 65379, '\P{^General_Category=_	OPEN_Punctuation}', "");
Error('\p{Gc=-/a/PS}');
Error('\P{Gc=-/a/PS}');
Expect(1, 65378, '\p{Gc=ps}', "");
Expect(0, 65378, '\p{^Gc=ps}', "");
Expect(0, 65378, '\P{Gc=ps}', "");
Expect(1, 65378, '\P{^Gc=ps}', "");
Expect(0, 65379, '\p{Gc=ps}', "");
Expect(1, 65379, '\p{^Gc=ps}', "");
Expect(1, 65379, '\P{Gc=ps}', "");
Expect(0, 65379, '\P{^Gc=ps}', "");
Expect(1, 65378, '\p{Gc=_ps}', "");
Expect(0, 65378, '\p{^Gc=_ps}', "");
Expect(0, 65378, '\P{Gc=_ps}', "");
Expect(1, 65378, '\P{^Gc=_ps}', "");
Expect(0, 65379, '\p{Gc=_ps}', "");
Expect(1, 65379, '\p{^Gc=_ps}', "");
Expect(1, 65379, '\P{Gc=_ps}', "");
Expect(0, 65379, '\P{^Gc=_ps}', "");
Error('\p{Category=/a/_ OPEN_punctuation}');
Error('\P{Category=/a/_ OPEN_punctuation}');
Expect(1, 65378, '\p{Category=openpunctuation}', "");
Expect(0, 65378, '\p{^Category=openpunctuation}', "");
Expect(0, 65378, '\P{Category=openpunctuation}', "");
Expect(1, 65378, '\P{^Category=openpunctuation}', "");
Expect(0, 65379, '\p{Category=openpunctuation}', "");
Expect(1, 65379, '\p{^Category=openpunctuation}', "");
Expect(1, 65379, '\P{Category=openpunctuation}', "");
Expect(0, 65379, '\P{^Category=openpunctuation}', "");
Expect(1, 65378, '\p{Category=__Open_punctuation}', "");
Expect(0, 65378, '\p{^Category=__Open_punctuation}', "");
Expect(0, 65378, '\P{Category=__Open_punctuation}', "");
Expect(1, 65378, '\P{^Category=__Open_punctuation}', "");
Expect(0, 65379, '\p{Category=__Open_punctuation}', "");
Expect(1, 65379, '\p{^Category=__Open_punctuation}', "");
Expect(1, 65379, '\P{Category=__Open_punctuation}', "");
Expect(0, 65379, '\P{^Category=__Open_punctuation}', "");
Error('\p{Is_General_Category=-:=PS}');
Error('\P{Is_General_Category=-:=PS}');
Expect(1, 65378, '\p{Is_General_Category=ps}', "");
Expect(0, 65378, '\p{^Is_General_Category=ps}', "");
Expect(0, 65378, '\P{Is_General_Category=ps}', "");
Expect(1, 65378, '\P{^Is_General_Category=ps}', "");
Expect(0, 65379, '\p{Is_General_Category=ps}', "");
Expect(1, 65379, '\p{^Is_General_Category=ps}', "");
Expect(1, 65379, '\P{Is_General_Category=ps}', "");
Expect(0, 65379, '\P{^Is_General_Category=ps}', "");
Expect(1, 65378, '\p{Is_General_Category= _PS}', "");
Expect(0, 65378, '\p{^Is_General_Category= _PS}', "");
Expect(0, 65378, '\P{Is_General_Category= _PS}', "");
Expect(1, 65378, '\P{^Is_General_Category= _PS}', "");
Expect(0, 65379, '\p{Is_General_Category= _PS}', "");
Expect(1, 65379, '\p{^Is_General_Category= _PS}', "");
Expect(1, 65379, '\P{Is_General_Category= _PS}', "");
Expect(0, 65379, '\P{^Is_General_Category= _PS}', "");
Error('\p{Is_Gc=-/a/OPEN_punctuation}');
Error('\P{Is_Gc=-/a/OPEN_punctuation}');
Expect(1, 65378, '\p{Is_Gc=openpunctuation}', "");
Expect(0, 65378, '\p{^Is_Gc=openpunctuation}', "");
Expect(0, 65378, '\P{Is_Gc=openpunctuation}', "");
Expect(1, 65378, '\P{^Is_Gc=openpunctuation}', "");
Expect(0, 65379, '\p{Is_Gc=openpunctuation}', "");
Expect(1, 65379, '\p{^Is_Gc=openpunctuation}', "");
Expect(1, 65379, '\P{Is_Gc=openpunctuation}', "");
Expect(0, 65379, '\P{^Is_Gc=openpunctuation}', "");
Expect(1, 65378, '\p{Is_Gc=	OPEN_PUNCTUATION}', "");
Expect(0, 65378, '\p{^Is_Gc=	OPEN_PUNCTUATION}', "");
Expect(0, 65378, '\P{Is_Gc=	OPEN_PUNCTUATION}', "");
Expect(1, 65378, '\P{^Is_Gc=	OPEN_PUNCTUATION}', "");
Expect(0, 65379, '\p{Is_Gc=	OPEN_PUNCTUATION}', "");
Expect(1, 65379, '\p{^Is_Gc=	OPEN_PUNCTUATION}', "");
Expect(1, 65379, '\P{Is_Gc=	OPEN_PUNCTUATION}', "");
Expect(0, 65379, '\P{^Is_Gc=	OPEN_PUNCTUATION}', "");
Error('\p{Is_Category=:=	 PS}');
Error('\P{Is_Category=:=	 PS}');
Expect(1, 65378, '\p{Is_Category: ps}', "");
Expect(0, 65378, '\p{^Is_Category: ps}', "");
Expect(0, 65378, '\P{Is_Category: ps}', "");
Expect(1, 65378, '\P{^Is_Category: ps}', "");
Expect(0, 65379, '\p{Is_Category: ps}', "");
Expect(1, 65379, '\p{^Is_Category: ps}', "");
Expect(1, 65379, '\P{Is_Category: ps}', "");
Expect(0, 65379, '\P{^Is_Category: ps}', "");
Expect(1, 65378, '\p{Is_Category=_ Ps}', "");
Expect(0, 65378, '\p{^Is_Category=_ Ps}', "");
Expect(0, 65378, '\P{Is_Category=_ Ps}', "");
Expect(1, 65378, '\P{^Is_Category=_ Ps}', "");
Expect(0, 65379, '\p{Is_Category=_ Ps}', "");
Expect(1, 65379, '\p{^Is_Category=_ Ps}', "");
Expect(1, 65379, '\P{Is_Category=_ Ps}', "");
Expect(0, 65379, '\P{^Is_Category=_ Ps}', "");
Error('\p{General_Category=	Symbol/a/}');
Error('\P{General_Category=	Symbol/a/}');
Expect(1, 128883, '\p{General_Category=symbol}', "");
Expect(0, 128883, '\p{^General_Category=symbol}', "");
Expect(0, 128883, '\P{General_Category=symbol}', "");
Expect(1, 128883, '\P{^General_Category=symbol}', "");
Expect(0, 128884, '\p{General_Category=symbol}', "");
Expect(1, 128884, '\p{^General_Category=symbol}', "");
Expect(1, 128884, '\P{General_Category=symbol}', "");
Expect(0, 128884, '\P{^General_Category=symbol}', "");
Expect(1, 128883, '\p{General_Category= _SYMBOL}', "");
Expect(0, 128883, '\p{^General_Category= _SYMBOL}', "");
Expect(0, 128883, '\P{General_Category= _SYMBOL}', "");
Expect(1, 128883, '\P{^General_Category= _SYMBOL}', "");
Expect(0, 128884, '\p{General_Category= _SYMBOL}', "");
Expect(1, 128884, '\p{^General_Category= _SYMBOL}', "");
Expect(1, 128884, '\P{General_Category= _SYMBOL}', "");
Expect(0, 128884, '\P{^General_Category= _SYMBOL}', "");
Error('\p{Gc=:= 	S}');
Error('\P{Gc=:= 	S}');
Expect(1, 128883, '\p{Gc=s}', "");
Expect(0, 128883, '\p{^Gc=s}', "");
Expect(0, 128883, '\P{Gc=s}', "");
Expect(1, 128883, '\P{^Gc=s}', "");
Expect(0, 128884, '\p{Gc=s}', "");
Expect(1, 128884, '\p{^Gc=s}', "");
Expect(1, 128884, '\P{Gc=s}', "");
Expect(0, 128884, '\P{^Gc=s}', "");
Expect(1, 128883, '\p{Gc=-S}', "");
Expect(0, 128883, '\p{^Gc=-S}', "");
Expect(0, 128883, '\P{Gc=-S}', "");
Expect(1, 128883, '\P{^Gc=-S}', "");
Expect(0, 128884, '\p{Gc=-S}', "");
Expect(1, 128884, '\p{^Gc=-S}', "");
Expect(1, 128884, '\P{Gc=-S}', "");
Expect(0, 128884, '\P{^Gc=-S}', "");
Error('\p{Category=:=_-symbol}');
Error('\P{Category=:=_-symbol}');
Expect(1, 128883, '\p{Category=symbol}', "");
Expect(0, 128883, '\p{^Category=symbol}', "");
Expect(0, 128883, '\P{Category=symbol}', "");
Expect(1, 128883, '\P{^Category=symbol}', "");
Expect(0, 128884, '\p{Category=symbol}', "");
Expect(1, 128884, '\p{^Category=symbol}', "");
Expect(1, 128884, '\P{Category=symbol}', "");
Expect(0, 128884, '\P{^Category=symbol}', "");
Expect(1, 128883, '\p{Category=-SYMBOL}', "");
Expect(0, 128883, '\p{^Category=-SYMBOL}', "");
Expect(0, 128883, '\P{Category=-SYMBOL}', "");
Expect(1, 128883, '\P{^Category=-SYMBOL}', "");
Expect(0, 128884, '\p{Category=-SYMBOL}', "");
Expect(1, 128884, '\p{^Category=-SYMBOL}', "");
Expect(1, 128884, '\P{Category=-SYMBOL}', "");
Expect(0, 128884, '\P{^Category=-SYMBOL}', "");
Error('\p{Is_General_Category=	_S/a/}');
Error('\P{Is_General_Category=	_S/a/}');
Expect(1, 128883, '\p{Is_General_Category=s}', "");
Expect(0, 128883, '\p{^Is_General_Category=s}', "");
Expect(0, 128883, '\P{Is_General_Category=s}', "");
Expect(1, 128883, '\P{^Is_General_Category=s}', "");
Expect(0, 128884, '\p{Is_General_Category=s}', "");
Expect(1, 128884, '\p{^Is_General_Category=s}', "");
Expect(1, 128884, '\P{Is_General_Category=s}', "");
Expect(0, 128884, '\P{^Is_General_Category=s}', "");
Expect(1, 128883, '\p{Is_General_Category=	S}', "");
Expect(0, 128883, '\p{^Is_General_Category=	S}', "");
Expect(0, 128883, '\P{Is_General_Category=	S}', "");
Expect(1, 128883, '\P{^Is_General_Category=	S}', "");
Expect(0, 128884, '\p{Is_General_Category=	S}', "");
Expect(1, 128884, '\p{^Is_General_Category=	S}', "");
Expect(1, 128884, '\P{Is_General_Category=	S}', "");
Expect(0, 128884, '\P{^Is_General_Category=	S}', "");
Error('\p{Is_Gc=:=_-SYMBOL}');
Error('\P{Is_Gc=:=_-SYMBOL}');
Expect(1, 128883, '\p{Is_Gc=symbol}', "");
Expect(0, 128883, '\p{^Is_Gc=symbol}', "");
Expect(0, 128883, '\P{Is_Gc=symbol}', "");
Expect(1, 128883, '\P{^Is_Gc=symbol}', "");
Expect(0, 128884, '\p{Is_Gc=symbol}', "");
Expect(1, 128884, '\p{^Is_Gc=symbol}', "");
Expect(1, 128884, '\P{Is_Gc=symbol}', "");
Expect(0, 128884, '\P{^Is_Gc=symbol}', "");
Expect(1, 128883, '\p{Is_Gc=-SYMBOL}', "");
Expect(0, 128883, '\p{^Is_Gc=-SYMBOL}', "");
Expect(0, 128883, '\P{Is_Gc=-SYMBOL}', "");
Expect(1, 128883, '\P{^Is_Gc=-SYMBOL}', "");
Expect(0, 128884, '\p{Is_Gc=-SYMBOL}', "");
Expect(1, 128884, '\p{^Is_Gc=-SYMBOL}', "");
Expect(1, 128884, '\P{Is_Gc=-SYMBOL}', "");
Expect(0, 128884, '\P{^Is_Gc=-SYMBOL}', "");
Error('\p{Is_Category=:=	 S}');
Error('\P{Is_Category=:=	 S}');
Expect(1, 128883, '\p{Is_Category:   s}', "");
Expect(0, 128883, '\p{^Is_Category:   s}', "");
Expect(0, 128883, '\P{Is_Category:   s}', "");
Expect(1, 128883, '\P{^Is_Category:   s}', "");
Expect(0, 128884, '\p{Is_Category:   s}', "");
Expect(1, 128884, '\p{^Is_Category:   s}', "");
Expect(1, 128884, '\P{Is_Category:   s}', "");
Expect(0, 128884, '\P{^Is_Category:   s}', "");
Expect(1, 128883, '\p{Is_Category:	_S}', "");
Expect(0, 128883, '\p{^Is_Category:	_S}', "");
Expect(0, 128883, '\P{Is_Category:	_S}', "");
Expect(1, 128883, '\P{^Is_Category:	_S}', "");
Expect(0, 128884, '\p{Is_Category:	_S}', "");
Expect(1, 128884, '\p{^Is_Category:	_S}', "");
Expect(1, 128884, '\P{Is_Category:	_S}', "");
Expect(0, 128884, '\P{^Is_Category:	_S}', "");
Error('\p{General_Category=_/a/currency_Symbol}');
Error('\P{General_Category=_/a/currency_Symbol}');
Expect(1, 65510, '\p{General_Category=currencysymbol}', "");
Expect(0, 65510, '\p{^General_Category=currencysymbol}', "");
Expect(0, 65510, '\P{General_Category=currencysymbol}', "");
Expect(1, 65510, '\P{^General_Category=currencysymbol}', "");
Expect(0, 65511, '\p{General_Category=currencysymbol}', "");
Expect(1, 65511, '\p{^General_Category=currencysymbol}', "");
Expect(1, 65511, '\P{General_Category=currencysymbol}', "");
Expect(0, 65511, '\P{^General_Category=currencysymbol}', "");
Expect(1, 65510, '\p{General_Category=-	CURRENCY_Symbol}', "");
Expect(0, 65510, '\p{^General_Category=-	CURRENCY_Symbol}', "");
Expect(0, 65510, '\P{General_Category=-	CURRENCY_Symbol}', "");
Expect(1, 65510, '\P{^General_Category=-	CURRENCY_Symbol}', "");
Expect(0, 65511, '\p{General_Category=-	CURRENCY_Symbol}', "");
Expect(1, 65511, '\p{^General_Category=-	CURRENCY_Symbol}', "");
Expect(1, 65511, '\P{General_Category=-	CURRENCY_Symbol}', "");
Expect(0, 65511, '\P{^General_Category=-	CURRENCY_Symbol}', "");
Error('\p{Gc=_/a/Sc}');
Error('\P{Gc=_/a/Sc}');
Expect(1, 65510, '\p{Gc=sc}', "");
Expect(0, 65510, '\p{^Gc=sc}', "");
Expect(0, 65510, '\P{Gc=sc}', "");
Expect(1, 65510, '\P{^Gc=sc}', "");
Expect(0, 65511, '\p{Gc=sc}', "");
Expect(1, 65511, '\p{^Gc=sc}', "");
Expect(1, 65511, '\P{Gc=sc}', "");
Expect(0, 65511, '\P{^Gc=sc}', "");
Expect(1, 65510, '\p{Gc= 	Sc}', "");
Expect(0, 65510, '\p{^Gc= 	Sc}', "");
Expect(0, 65510, '\P{Gc= 	Sc}', "");
Expect(1, 65510, '\P{^Gc= 	Sc}', "");
Expect(0, 65511, '\p{Gc= 	Sc}', "");
Expect(1, 65511, '\p{^Gc= 	Sc}', "");
Expect(1, 65511, '\P{Gc= 	Sc}', "");
Expect(0, 65511, '\P{^Gc= 	Sc}', "");
Error('\p{Category=_ CURRENCY_Symbol/a/}');
Error('\P{Category=_ CURRENCY_Symbol/a/}');
Expect(1, 65510, '\p{Category=currencysymbol}', "");
Expect(0, 65510, '\p{^Category=currencysymbol}', "");
Expect(0, 65510, '\P{Category=currencysymbol}', "");
Expect(1, 65510, '\P{^Category=currencysymbol}', "");
Expect(0, 65511, '\p{Category=currencysymbol}', "");
Expect(1, 65511, '\p{^Category=currencysymbol}', "");
Expect(1, 65511, '\P{Category=currencysymbol}', "");
Expect(0, 65511, '\P{^Category=currencysymbol}', "");
Expect(1, 65510, '\p{Category=	-currency_Symbol}', "");
Expect(0, 65510, '\p{^Category=	-currency_Symbol}', "");
Expect(0, 65510, '\P{Category=	-currency_Symbol}', "");
Expect(1, 65510, '\P{^Category=	-currency_Symbol}', "");
Expect(0, 65511, '\p{Category=	-currency_Symbol}', "");
Expect(1, 65511, '\p{^Category=	-currency_Symbol}', "");
Expect(1, 65511, '\P{Category=	-currency_Symbol}', "");
Expect(0, 65511, '\P{^Category=	-currency_Symbol}', "");
Error('\p{Is_General_Category= -Sc/a/}');
Error('\P{Is_General_Category= -Sc/a/}');
Expect(1, 65510, '\p{Is_General_Category=sc}', "");
Expect(0, 65510, '\p{^Is_General_Category=sc}', "");
Expect(0, 65510, '\P{Is_General_Category=sc}', "");
Expect(1, 65510, '\P{^Is_General_Category=sc}', "");
Expect(0, 65511, '\p{Is_General_Category=sc}', "");
Expect(1, 65511, '\p{^Is_General_Category=sc}', "");
Expect(1, 65511, '\P{Is_General_Category=sc}', "");
Expect(0, 65511, '\P{^Is_General_Category=sc}', "");
Expect(1, 65510, '\p{Is_General_Category=	 Sc}', "");
Expect(0, 65510, '\p{^Is_General_Category=	 Sc}', "");
Expect(0, 65510, '\P{Is_General_Category=	 Sc}', "");
Expect(1, 65510, '\P{^Is_General_Category=	 Sc}', "");
Expect(0, 65511, '\p{Is_General_Category=	 Sc}', "");
Expect(1, 65511, '\p{^Is_General_Category=	 Sc}', "");
Expect(1, 65511, '\P{Is_General_Category=	 Sc}', "");
Expect(0, 65511, '\P{^Is_General_Category=	 Sc}', "");
Error('\p{Is_Gc=:= CURRENCY_Symbol}');
Error('\P{Is_Gc=:= CURRENCY_Symbol}');
Expect(1, 65510, '\p{Is_Gc=currencysymbol}', "");
Expect(0, 65510, '\p{^Is_Gc=currencysymbol}', "");
Expect(0, 65510, '\P{Is_Gc=currencysymbol}', "");
Expect(1, 65510, '\P{^Is_Gc=currencysymbol}', "");
Expect(0, 65511, '\p{Is_Gc=currencysymbol}', "");
Expect(1, 65511, '\p{^Is_Gc=currencysymbol}', "");
Expect(1, 65511, '\P{Is_Gc=currencysymbol}', "");
Expect(0, 65511, '\P{^Is_Gc=currencysymbol}', "");
Expect(1, 65510, '\p{Is_Gc=_currency_SYMBOL}', "");
Expect(0, 65510, '\p{^Is_Gc=_currency_SYMBOL}', "");
Expect(0, 65510, '\P{Is_Gc=_currency_SYMBOL}', "");
Expect(1, 65510, '\P{^Is_Gc=_currency_SYMBOL}', "");
Expect(0, 65511, '\p{Is_Gc=_currency_SYMBOL}', "");
Expect(1, 65511, '\p{^Is_Gc=_currency_SYMBOL}', "");
Expect(1, 65511, '\P{Is_Gc=_currency_SYMBOL}', "");
Expect(0, 65511, '\P{^Is_Gc=_currency_SYMBOL}', "");
Error('\p{Is_Category=/a/	-Sc}');
Error('\P{Is_Category=/a/	-Sc}');
Expect(1, 65510, '\p{Is_Category=sc}', "");
Expect(0, 65510, '\p{^Is_Category=sc}', "");
Expect(0, 65510, '\P{Is_Category=sc}', "");
Expect(1, 65510, '\P{^Is_Category=sc}', "");
Expect(0, 65511, '\p{Is_Category=sc}', "");
Expect(1, 65511, '\p{^Is_Category=sc}', "");
Expect(1, 65511, '\P{Is_Category=sc}', "");
Expect(0, 65511, '\P{^Is_Category=sc}', "");
Expect(1, 65510, '\p{Is_Category= sc}', "");
Expect(0, 65510, '\p{^Is_Category= sc}', "");
Expect(0, 65510, '\P{Is_Category= sc}', "");
Expect(1, 65510, '\P{^Is_Category= sc}', "");
Expect(0, 65511, '\p{Is_Category= sc}', "");
Expect(1, 65511, '\p{^Is_Category= sc}', "");
Expect(1, 65511, '\P{Is_Category= sc}', "");
Expect(0, 65511, '\P{^Is_Category= sc}', "");
Error('\p{General_Category=/a/_-Modifier_symbol}');
Error('\P{General_Category=/a/_-Modifier_symbol}');
Expect(1, 65507, '\p{General_Category=modifiersymbol}', "");
Expect(0, 65507, '\p{^General_Category=modifiersymbol}', "");
Expect(0, 65507, '\P{General_Category=modifiersymbol}', "");
Expect(1, 65507, '\P{^General_Category=modifiersymbol}', "");
Expect(0, 65508, '\p{General_Category=modifiersymbol}', "");
Expect(1, 65508, '\p{^General_Category=modifiersymbol}', "");
Expect(1, 65508, '\P{General_Category=modifiersymbol}', "");
Expect(0, 65508, '\P{^General_Category=modifiersymbol}', "");
Expect(1, 65507, '\p{General_Category= _modifier_Symbol}', "");
Expect(0, 65507, '\p{^General_Category= _modifier_Symbol}', "");
Expect(0, 65507, '\P{General_Category= _modifier_Symbol}', "");
Expect(1, 65507, '\P{^General_Category= _modifier_Symbol}', "");
Expect(0, 65508, '\p{General_Category= _modifier_Symbol}', "");
Expect(1, 65508, '\p{^General_Category= _modifier_Symbol}', "");
Expect(1, 65508, '\P{General_Category= _modifier_Symbol}', "");
Expect(0, 65508, '\P{^General_Category= _modifier_Symbol}', "");
Error('\p{Gc:/a/		Sk}');
Error('\P{Gc:/a/		Sk}');
Expect(1, 65507, '\p{Gc=sk}', "");
Expect(0, 65507, '\p{^Gc=sk}', "");
Expect(0, 65507, '\P{Gc=sk}', "");
Expect(1, 65507, '\P{^Gc=sk}', "");
Expect(0, 65508, '\p{Gc=sk}', "");
Expect(1, 65508, '\p{^Gc=sk}', "");
Expect(1, 65508, '\P{Gc=sk}', "");
Expect(0, 65508, '\P{^Gc=sk}', "");
Expect(1, 65507, '\p{Gc=_	SK}', "");
Expect(0, 65507, '\p{^Gc=_	SK}', "");
Expect(0, 65507, '\P{Gc=_	SK}', "");
Expect(1, 65507, '\P{^Gc=_	SK}', "");
Expect(0, 65508, '\p{Gc=_	SK}', "");
Expect(1, 65508, '\p{^Gc=_	SK}', "");
Expect(1, 65508, '\P{Gc=_	SK}', "");
Expect(0, 65508, '\P{^Gc=_	SK}', "");
Error('\p{Category=	MODIFIER_SYMBOL/a/}');
Error('\P{Category=	MODIFIER_SYMBOL/a/}');
Expect(1, 65507, '\p{Category=modifiersymbol}', "");
Expect(0, 65507, '\p{^Category=modifiersymbol}', "");
Expect(0, 65507, '\P{Category=modifiersymbol}', "");
Expect(1, 65507, '\P{^Category=modifiersymbol}', "");
Expect(0, 65508, '\p{Category=modifiersymbol}', "");
Expect(1, 65508, '\p{^Category=modifiersymbol}', "");
Expect(1, 65508, '\P{Category=modifiersymbol}', "");
Expect(0, 65508, '\P{^Category=modifiersymbol}', "");
Expect(1, 65507, '\p{Category=	Modifier_Symbol}', "");
Expect(0, 65507, '\p{^Category=	Modifier_Symbol}', "");
Expect(0, 65507, '\P{Category=	Modifier_Symbol}', "");
Expect(1, 65507, '\P{^Category=	Modifier_Symbol}', "");
Expect(0, 65508, '\p{Category=	Modifier_Symbol}', "");
Expect(1, 65508, '\p{^Category=	Modifier_Symbol}', "");
Expect(1, 65508, '\P{Category=	Modifier_Symbol}', "");
Expect(0, 65508, '\P{^Category=	Modifier_Symbol}', "");
Error('\p{Is_General_Category=__Sk/a/}');
Error('\P{Is_General_Category=__Sk/a/}');
Expect(1, 65507, '\p{Is_General_Category:   sk}', "");
Expect(0, 65507, '\p{^Is_General_Category:   sk}', "");
Expect(0, 65507, '\P{Is_General_Category:   sk}', "");
Expect(1, 65507, '\P{^Is_General_Category:   sk}', "");
Expect(0, 65508, '\p{Is_General_Category:   sk}', "");
Expect(1, 65508, '\p{^Is_General_Category:   sk}', "");
Expect(1, 65508, '\P{Is_General_Category:   sk}', "");
Expect(0, 65508, '\P{^Is_General_Category:   sk}', "");
Expect(1, 65507, '\p{Is_General_Category=	sk}', "");
Expect(0, 65507, '\p{^Is_General_Category=	sk}', "");
Expect(0, 65507, '\P{Is_General_Category=	sk}', "");
Expect(1, 65507, '\P{^Is_General_Category=	sk}', "");
Expect(0, 65508, '\p{Is_General_Category=	sk}', "");
Expect(1, 65508, '\p{^Is_General_Category=	sk}', "");
Expect(1, 65508, '\P{Is_General_Category=	sk}', "");
Expect(0, 65508, '\P{^Is_General_Category=	sk}', "");
Error('\p{Is_Gc=	/a/MODIFIER_Symbol}');
Error('\P{Is_Gc=	/a/MODIFIER_Symbol}');
Expect(1, 65507, '\p{Is_Gc=modifiersymbol}', "");
Expect(0, 65507, '\p{^Is_Gc=modifiersymbol}', "");
Expect(0, 65507, '\P{Is_Gc=modifiersymbol}', "");
Expect(1, 65507, '\P{^Is_Gc=modifiersymbol}', "");
Expect(0, 65508, '\p{Is_Gc=modifiersymbol}', "");
Expect(1, 65508, '\p{^Is_Gc=modifiersymbol}', "");
Expect(1, 65508, '\P{Is_Gc=modifiersymbol}', "");
Expect(0, 65508, '\P{^Is_Gc=modifiersymbol}', "");
Expect(1, 65507, '\p{Is_Gc=_ Modifier_symbol}', "");
Expect(0, 65507, '\p{^Is_Gc=_ Modifier_symbol}', "");
Expect(0, 65507, '\P{Is_Gc=_ Modifier_symbol}', "");
Expect(1, 65507, '\P{^Is_Gc=_ Modifier_symbol}', "");
Expect(0, 65508, '\p{Is_Gc=_ Modifier_symbol}', "");
Expect(1, 65508, '\p{^Is_Gc=_ Modifier_symbol}', "");
Expect(1, 65508, '\P{Is_Gc=_ Modifier_symbol}', "");
Expect(0, 65508, '\P{^Is_Gc=_ Modifier_symbol}', "");
Error('\p{Is_Category=:=SK}');
Error('\P{Is_Category=:=SK}');
Expect(1, 65507, '\p{Is_Category=sk}', "");
Expect(0, 65507, '\p{^Is_Category=sk}', "");
Expect(0, 65507, '\P{Is_Category=sk}', "");
Expect(1, 65507, '\P{^Is_Category=sk}', "");
Expect(0, 65508, '\p{Is_Category=sk}', "");
Expect(1, 65508, '\p{^Is_Category=sk}', "");
Expect(1, 65508, '\P{Is_Category=sk}', "");
Expect(0, 65508, '\P{^Is_Category=sk}', "");
Expect(1, 65507, '\p{Is_Category=	SK}', "");
Expect(0, 65507, '\p{^Is_Category=	SK}', "");
Expect(0, 65507, '\P{Is_Category=	SK}', "");
Expect(1, 65507, '\P{^Is_Category=	SK}', "");
Expect(0, 65508, '\p{Is_Category=	SK}', "");
Expect(1, 65508, '\p{^Is_Category=	SK}', "");
Expect(1, 65508, '\P{Is_Category=	SK}', "");
Expect(0, 65508, '\P{^Is_Category=	SK}', "");
Error('\p{General_Category= 	Math_Symbol:=}');
Error('\P{General_Category= 	Math_Symbol:=}');
Expect(1, 126705, '\p{General_Category=mathsymbol}', "");
Expect(0, 126705, '\p{^General_Category=mathsymbol}', "");
Expect(0, 126705, '\P{General_Category=mathsymbol}', "");
Expect(1, 126705, '\P{^General_Category=mathsymbol}', "");
Expect(0, 126706, '\p{General_Category=mathsymbol}', "");
Expect(1, 126706, '\p{^General_Category=mathsymbol}', "");
Expect(1, 126706, '\P{General_Category=mathsymbol}', "");
Expect(0, 126706, '\P{^General_Category=mathsymbol}', "");
Expect(1, 126705, '\p{General_Category:	  Math_Symbol}', "");
Expect(0, 126705, '\p{^General_Category:	  Math_Symbol}', "");
Expect(0, 126705, '\P{General_Category:	  Math_Symbol}', "");
Expect(1, 126705, '\P{^General_Category:	  Math_Symbol}', "");
Expect(0, 126706, '\p{General_Category:	  Math_Symbol}', "");
Expect(1, 126706, '\p{^General_Category:	  Math_Symbol}', "");
Expect(1, 126706, '\P{General_Category:	  Math_Symbol}', "");
Expect(0, 126706, '\P{^General_Category:	  Math_Symbol}', "");
Error('\p{Gc= SM/a/}');
Error('\P{Gc= SM/a/}');
Expect(1, 126705, '\p{Gc=sm}', "");
Expect(0, 126705, '\p{^Gc=sm}', "");
Expect(0, 126705, '\P{Gc=sm}', "");
Expect(1, 126705, '\P{^Gc=sm}', "");
Expect(0, 126706, '\p{Gc=sm}', "");
Expect(1, 126706, '\p{^Gc=sm}', "");
Expect(1, 126706, '\P{Gc=sm}', "");
Expect(0, 126706, '\P{^Gc=sm}', "");
Expect(1, 126705, '\p{Gc=	 sm}', "");
Expect(0, 126705, '\p{^Gc=	 sm}', "");
Expect(0, 126705, '\P{Gc=	 sm}', "");
Expect(1, 126705, '\P{^Gc=	 sm}', "");
Expect(0, 126706, '\p{Gc=	 sm}', "");
Expect(1, 126706, '\p{^Gc=	 sm}', "");
Expect(1, 126706, '\P{Gc=	 sm}', "");
Expect(0, 126706, '\P{^Gc=	 sm}', "");
Error('\p{Category=	_math_Symbol/a/}');
Error('\P{Category=	_math_Symbol/a/}');
Expect(1, 126705, '\p{Category=mathsymbol}', "");
Expect(0, 126705, '\p{^Category=mathsymbol}', "");
Expect(0, 126705, '\P{Category=mathsymbol}', "");
Expect(1, 126705, '\P{^Category=mathsymbol}', "");
Expect(0, 126706, '\p{Category=mathsymbol}', "");
Expect(1, 126706, '\p{^Category=mathsymbol}', "");
Expect(1, 126706, '\P{Category=mathsymbol}', "");
Expect(0, 126706, '\P{^Category=mathsymbol}', "");
Expect(1, 126705, '\p{Category=  Math_symbol}', "");
Expect(0, 126705, '\p{^Category=  Math_symbol}', "");
Expect(0, 126705, '\P{Category=  Math_symbol}', "");
Expect(1, 126705, '\P{^Category=  Math_symbol}', "");
Expect(0, 126706, '\p{Category=  Math_symbol}', "");
Expect(1, 126706, '\p{^Category=  Math_symbol}', "");
Expect(1, 126706, '\P{Category=  Math_symbol}', "");
Expect(0, 126706, '\P{^Category=  Math_symbol}', "");
Error('\p{Is_General_Category=_Sm:=}');
Error('\P{Is_General_Category=_Sm:=}');
Expect(1, 126705, '\p{Is_General_Category=sm}', "");
Expect(0, 126705, '\p{^Is_General_Category=sm}', "");
Expect(0, 126705, '\P{Is_General_Category=sm}', "");
Expect(1, 126705, '\P{^Is_General_Category=sm}', "");
Expect(0, 126706, '\p{Is_General_Category=sm}', "");
Expect(1, 126706, '\p{^Is_General_Category=sm}', "");
Expect(1, 126706, '\P{Is_General_Category=sm}', "");
Expect(0, 126706, '\P{^Is_General_Category=sm}', "");
Expect(1, 126705, '\p{Is_General_Category: --sm}', "");
Expect(0, 126705, '\p{^Is_General_Category: --sm}', "");
Expect(0, 126705, '\P{Is_General_Category: --sm}', "");
Expect(1, 126705, '\P{^Is_General_Category: --sm}', "");
Expect(0, 126706, '\p{Is_General_Category: --sm}', "");
Expect(1, 126706, '\p{^Is_General_Category: --sm}', "");
Expect(1, 126706, '\P{Is_General_Category: --sm}', "");
Expect(0, 126706, '\P{^Is_General_Category: --sm}', "");
Error('\p{Is_Gc= :=MATH_SYMBOL}');
Error('\P{Is_Gc= :=MATH_SYMBOL}');
Expect(1, 126705, '\p{Is_Gc=mathsymbol}', "");
Expect(0, 126705, '\p{^Is_Gc=mathsymbol}', "");
Expect(0, 126705, '\P{Is_Gc=mathsymbol}', "");
Expect(1, 126705, '\P{^Is_Gc=mathsymbol}', "");
Expect(0, 126706, '\p{Is_Gc=mathsymbol}', "");
Expect(1, 126706, '\p{^Is_Gc=mathsymbol}', "");
Expect(1, 126706, '\P{Is_Gc=mathsymbol}', "");
Expect(0, 126706, '\P{^Is_Gc=mathsymbol}', "");
Expect(1, 126705, '\p{Is_Gc=_-MATH_SYMBOL}', "");
Expect(0, 126705, '\p{^Is_Gc=_-MATH_SYMBOL}', "");
Expect(0, 126705, '\P{Is_Gc=_-MATH_SYMBOL}', "");
Expect(1, 126705, '\P{^Is_Gc=_-MATH_SYMBOL}', "");
Expect(0, 126706, '\p{Is_Gc=_-MATH_SYMBOL}', "");
Expect(1, 126706, '\p{^Is_Gc=_-MATH_SYMBOL}', "");
Expect(1, 126706, '\P{Is_Gc=_-MATH_SYMBOL}', "");
Expect(0, 126706, '\P{^Is_Gc=_-MATH_SYMBOL}', "");
Error('\p{Is_Category= /a/sm}');
Error('\P{Is_Category= /a/sm}');
Expect(1, 126705, '\p{Is_Category=sm}', "");
Expect(0, 126705, '\p{^Is_Category=sm}', "");
Expect(0, 126705, '\P{Is_Category=sm}', "");
Expect(1, 126705, '\P{^Is_Category=sm}', "");
Expect(0, 126706, '\p{Is_Category=sm}', "");
Expect(1, 126706, '\p{^Is_Category=sm}', "");
Expect(1, 126706, '\P{Is_Category=sm}', "");
Expect(0, 126706, '\P{^Is_Category=sm}', "");
Expect(1, 126705, '\p{Is_Category=_sm}', "");
Expect(0, 126705, '\p{^Is_Category=_sm}', "");
Expect(0, 126705, '\P{Is_Category=_sm}', "");
Expect(1, 126705, '\P{^Is_Category=_sm}', "");
Expect(0, 126706, '\p{Is_Category=_sm}', "");
Expect(1, 126706, '\p{^Is_Category=_sm}', "");
Expect(1, 126706, '\P{Is_Category=_sm}', "");
Expect(0, 126706, '\P{^Is_Category=_sm}', "");
Error('\p{General_Category=:= -OTHER_SYMBOL}');
Error('\P{General_Category=:= -OTHER_SYMBOL}');
Expect(1, 128883, '\p{General_Category=othersymbol}', "");
Expect(0, 128883, '\p{^General_Category=othersymbol}', "");
Expect(0, 128883, '\P{General_Category=othersymbol}', "");
Expect(1, 128883, '\P{^General_Category=othersymbol}', "");
Expect(0, 128884, '\p{General_Category=othersymbol}', "");
Expect(1, 128884, '\p{^General_Category=othersymbol}', "");
Expect(1, 128884, '\P{General_Category=othersymbol}', "");
Expect(0, 128884, '\P{^General_Category=othersymbol}', "");
Expect(1, 128883, '\p{General_Category=__Other_Symbol}', "");
Expect(0, 128883, '\p{^General_Category=__Other_Symbol}', "");
Expect(0, 128883, '\P{General_Category=__Other_Symbol}', "");
Expect(1, 128883, '\P{^General_Category=__Other_Symbol}', "");
Expect(0, 128884, '\p{General_Category=__Other_Symbol}', "");
Expect(1, 128884, '\p{^General_Category=__Other_Symbol}', "");
Expect(1, 128884, '\P{General_Category=__Other_Symbol}', "");
Expect(0, 128884, '\P{^General_Category=__Other_Symbol}', "");
Error('\p{Gc=	/a/so}');
Error('\P{Gc=	/a/so}');
Expect(1, 128883, '\p{Gc=so}', "");
Expect(0, 128883, '\p{^Gc=so}', "");
Expect(0, 128883, '\P{Gc=so}', "");
Expect(1, 128883, '\P{^Gc=so}', "");
Expect(0, 128884, '\p{Gc=so}', "");
Expect(1, 128884, '\p{^Gc=so}', "");
Expect(1, 128884, '\P{Gc=so}', "");
Expect(0, 128884, '\P{^Gc=so}', "");
Expect(1, 128883, '\p{Gc=  SO}', "");
Expect(0, 128883, '\p{^Gc=  SO}', "");
Expect(0, 128883, '\P{Gc=  SO}', "");
Expect(1, 128883, '\P{^Gc=  SO}', "");
Expect(0, 128884, '\p{Gc=  SO}', "");
Expect(1, 128884, '\p{^Gc=  SO}', "");
Expect(1, 128884, '\P{Gc=  SO}', "");
Expect(0, 128884, '\P{^Gc=  SO}', "");
Error('\p{Category=_other_Symbol/a/}');
Error('\P{Category=_other_Symbol/a/}');
Expect(1, 128883, '\p{Category=othersymbol}', "");
Expect(0, 128883, '\p{^Category=othersymbol}', "");
Expect(0, 128883, '\P{Category=othersymbol}', "");
Expect(1, 128883, '\P{^Category=othersymbol}', "");
Expect(0, 128884, '\p{Category=othersymbol}', "");
Expect(1, 128884, '\p{^Category=othersymbol}', "");
Expect(1, 128884, '\P{Category=othersymbol}', "");
Expect(0, 128884, '\P{^Category=othersymbol}', "");
Expect(1, 128883, '\p{Category=--OTHER_Symbol}', "");
Expect(0, 128883, '\p{^Category=--OTHER_Symbol}', "");
Expect(0, 128883, '\P{Category=--OTHER_Symbol}', "");
Expect(1, 128883, '\P{^Category=--OTHER_Symbol}', "");
Expect(0, 128884, '\p{Category=--OTHER_Symbol}', "");
Expect(1, 128884, '\p{^Category=--OTHER_Symbol}', "");
Expect(1, 128884, '\P{Category=--OTHER_Symbol}', "");
Expect(0, 128884, '\P{^Category=--OTHER_Symbol}', "");
Error('\p{Is_General_Category=	/a/so}');
Error('\P{Is_General_Category=	/a/so}');
Expect(1, 128883, '\p{Is_General_Category=so}', "");
Expect(0, 128883, '\p{^Is_General_Category=so}', "");
Expect(0, 128883, '\P{Is_General_Category=so}', "");
Expect(1, 128883, '\P{^Is_General_Category=so}', "");
Expect(0, 128884, '\p{Is_General_Category=so}', "");
Expect(1, 128884, '\p{^Is_General_Category=so}', "");
Expect(1, 128884, '\P{Is_General_Category=so}', "");
Expect(0, 128884, '\P{^Is_General_Category=so}', "");
Expect(1, 128883, '\p{Is_General_Category=	 so}', "");
Expect(0, 128883, '\p{^Is_General_Category=	 so}', "");
Expect(0, 128883, '\P{Is_General_Category=	 so}', "");
Expect(1, 128883, '\P{^Is_General_Category=	 so}', "");
Expect(0, 128884, '\p{Is_General_Category=	 so}', "");
Expect(1, 128884, '\p{^Is_General_Category=	 so}', "");
Expect(1, 128884, '\P{Is_General_Category=	 so}', "");
Expect(0, 128884, '\P{^Is_General_Category=	 so}', "");
Error('\p{Is_Gc=:=OTHER_symbol}');
Error('\P{Is_Gc=:=OTHER_symbol}');
Expect(1, 128883, '\p{Is_Gc=othersymbol}', "");
Expect(0, 128883, '\p{^Is_Gc=othersymbol}', "");
Expect(0, 128883, '\P{Is_Gc=othersymbol}', "");
Expect(1, 128883, '\P{^Is_Gc=othersymbol}', "");
Expect(0, 128884, '\p{Is_Gc=othersymbol}', "");
Expect(1, 128884, '\p{^Is_Gc=othersymbol}', "");
Expect(1, 128884, '\P{Is_Gc=othersymbol}', "");
Expect(0, 128884, '\P{^Is_Gc=othersymbol}', "");
Expect(1, 128883, '\p{Is_Gc:   -OTHER_symbol}', "");
Expect(0, 128883, '\p{^Is_Gc:   -OTHER_symbol}', "");
Expect(0, 128883, '\P{Is_Gc:   -OTHER_symbol}', "");
Expect(1, 128883, '\P{^Is_Gc:   -OTHER_symbol}', "");
Expect(0, 128884, '\p{Is_Gc:   -OTHER_symbol}', "");
Expect(1, 128884, '\p{^Is_Gc:   -OTHER_symbol}', "");
Expect(1, 128884, '\P{Is_Gc:   -OTHER_symbol}', "");
Expect(0, 128884, '\P{^Is_Gc:   -OTHER_symbol}', "");
Error('\p{Is_Category=/a/_ So}');
Error('\P{Is_Category=/a/_ So}');
Expect(1, 128883, '\p{Is_Category=so}', "");
Expect(0, 128883, '\p{^Is_Category=so}', "");
Expect(0, 128883, '\P{Is_Category=so}', "");
Expect(1, 128883, '\P{^Is_Category=so}', "");
Expect(0, 128884, '\p{Is_Category=so}', "");
Expect(1, 128884, '\p{^Is_Category=so}', "");
Expect(1, 128884, '\P{Is_Category=so}', "");
Expect(0, 128884, '\P{^Is_Category=so}', "");
Expect(1, 128883, '\p{Is_Category=__SO}', "");
Expect(0, 128883, '\p{^Is_Category=__SO}', "");
Expect(0, 128883, '\P{Is_Category=__SO}', "");
Expect(1, 128883, '\P{^Is_Category=__SO}', "");
Expect(0, 128884, '\p{Is_Category=__SO}', "");
Expect(1, 128884, '\p{^Is_Category=__SO}', "");
Expect(1, 128884, '\P{Is_Category=__SO}', "");
Expect(0, 128884, '\P{^Is_Category=__SO}', "");
Error('\p{General_Category=_-SEPARATOR/a/}');
Error('\P{General_Category=_-SEPARATOR/a/}');
Expect(1, 12288, '\p{General_Category=separator}', "");
Expect(0, 12288, '\p{^General_Category=separator}', "");
Expect(0, 12288, '\P{General_Category=separator}', "");
Expect(1, 12288, '\P{^General_Category=separator}', "");
Expect(0, 12289, '\p{General_Category=separator}', "");
Expect(1, 12289, '\p{^General_Category=separator}', "");
Expect(1, 12289, '\P{General_Category=separator}', "");
Expect(0, 12289, '\P{^General_Category=separator}', "");
Expect(1, 12288, '\p{General_Category=-	SEPARATOR}', "");
Expect(0, 12288, '\p{^General_Category=-	SEPARATOR}', "");
Expect(0, 12288, '\P{General_Category=-	SEPARATOR}', "");
Expect(1, 12288, '\P{^General_Category=-	SEPARATOR}', "");
Expect(0, 12289, '\p{General_Category=-	SEPARATOR}', "");
Expect(1, 12289, '\p{^General_Category=-	SEPARATOR}', "");
Expect(1, 12289, '\P{General_Category=-	SEPARATOR}', "");
Expect(0, 12289, '\P{^General_Category=-	SEPARATOR}', "");
Error('\p{Gc=_Z/a/}');
Error('\P{Gc=_Z/a/}');
Expect(1, 12288, '\p{Gc=z}', "");
Expect(0, 12288, '\p{^Gc=z}', "");
Expect(0, 12288, '\P{Gc=z}', "");
Expect(1, 12288, '\P{^Gc=z}', "");
Expect(0, 12289, '\p{Gc=z}', "");
Expect(1, 12289, '\p{^Gc=z}', "");
Expect(1, 12289, '\P{Gc=z}', "");
Expect(0, 12289, '\P{^Gc=z}', "");
Expect(1, 12288, '\p{Gc=-Z}', "");
Expect(0, 12288, '\p{^Gc=-Z}', "");
Expect(0, 12288, '\P{Gc=-Z}', "");
Expect(1, 12288, '\P{^Gc=-Z}', "");
Expect(0, 12289, '\p{Gc=-Z}', "");
Expect(1, 12289, '\p{^Gc=-Z}', "");
Expect(1, 12289, '\P{Gc=-Z}', "");
Expect(0, 12289, '\P{^Gc=-Z}', "");
Error('\p{Category=	:=Separator}');
Error('\P{Category=	:=Separator}');
Expect(1, 12288, '\p{Category=separator}', "");
Expect(0, 12288, '\p{^Category=separator}', "");
Expect(0, 12288, '\P{Category=separator}', "");
Expect(1, 12288, '\P{^Category=separator}', "");
Expect(0, 12289, '\p{Category=separator}', "");
Expect(1, 12289, '\p{^Category=separator}', "");
Expect(1, 12289, '\P{Category=separator}', "");
Expect(0, 12289, '\P{^Category=separator}', "");
Expect(1, 12288, '\p{Category=-SEPARATOR}', "");
Expect(0, 12288, '\p{^Category=-SEPARATOR}', "");
Expect(0, 12288, '\P{Category=-SEPARATOR}', "");
Expect(1, 12288, '\P{^Category=-SEPARATOR}', "");
Expect(0, 12289, '\p{Category=-SEPARATOR}', "");
Expect(1, 12289, '\p{^Category=-SEPARATOR}', "");
Expect(1, 12289, '\P{Category=-SEPARATOR}', "");
Expect(0, 12289, '\P{^Category=-SEPARATOR}', "");
Error('\p{Is_General_Category:	_Z:=}');
Error('\P{Is_General_Category:	_Z:=}');
Expect(1, 12288, '\p{Is_General_Category=z}', "");
Expect(0, 12288, '\p{^Is_General_Category=z}', "");
Expect(0, 12288, '\P{Is_General_Category=z}', "");
Expect(1, 12288, '\P{^Is_General_Category=z}', "");
Expect(0, 12289, '\p{Is_General_Category=z}', "");
Expect(1, 12289, '\p{^Is_General_Category=z}', "");
Expect(1, 12289, '\P{Is_General_Category=z}', "");
Expect(0, 12289, '\P{^Is_General_Category=z}', "");
Expect(1, 12288, '\p{Is_General_Category= 	Z}', "");
Expect(0, 12288, '\p{^Is_General_Category= 	Z}', "");
Expect(0, 12288, '\P{Is_General_Category= 	Z}', "");
Expect(1, 12288, '\P{^Is_General_Category= 	Z}', "");
Expect(0, 12289, '\p{Is_General_Category= 	Z}', "");
Expect(1, 12289, '\p{^Is_General_Category= 	Z}', "");
Expect(1, 12289, '\P{Is_General_Category= 	Z}', "");
Expect(0, 12289, '\P{^Is_General_Category= 	Z}', "");
Error('\p{Is_Gc=/a/SEPARATOR}');
Error('\P{Is_Gc=/a/SEPARATOR}');
Expect(1, 12288, '\p{Is_Gc: separator}', "");
Expect(0, 12288, '\p{^Is_Gc: separator}', "");
Expect(0, 12288, '\P{Is_Gc: separator}', "");
Expect(1, 12288, '\P{^Is_Gc: separator}', "");
Expect(0, 12289, '\p{Is_Gc: separator}', "");
Expect(1, 12289, '\p{^Is_Gc: separator}', "");
Expect(1, 12289, '\P{Is_Gc: separator}', "");
Expect(0, 12289, '\P{^Is_Gc: separator}', "");
Expect(1, 12288, '\p{Is_Gc= _SEPARATOR}', "");
Expect(0, 12288, '\p{^Is_Gc= _SEPARATOR}', "");
Expect(0, 12288, '\P{Is_Gc= _SEPARATOR}', "");
Expect(1, 12288, '\P{^Is_Gc= _SEPARATOR}', "");
Expect(0, 12289, '\p{Is_Gc= _SEPARATOR}', "");
Expect(1, 12289, '\p{^Is_Gc= _SEPARATOR}', "");
Expect(1, 12289, '\P{Is_Gc= _SEPARATOR}', "");
Expect(0, 12289, '\P{^Is_Gc= _SEPARATOR}', "");
Error('\p{Is_Category=:=-	Z}');
Error('\P{Is_Category=:=-	Z}');
Expect(1, 12288, '\p{Is_Category=z}', "");
Expect(0, 12288, '\p{^Is_Category=z}', "");
Expect(0, 12288, '\P{Is_Category=z}', "");
Expect(1, 12288, '\P{^Is_Category=z}', "");
Expect(0, 12289, '\p{Is_Category=z}', "");
Expect(1, 12289, '\p{^Is_Category=z}', "");
Expect(1, 12289, '\P{Is_Category=z}', "");
Expect(0, 12289, '\P{^Is_Category=z}', "");
Expect(1, 12288, '\p{Is_Category=_Z}', "");
Expect(0, 12288, '\p{^Is_Category=_Z}', "");
Expect(0, 12288, '\P{Is_Category=_Z}', "");
Expect(1, 12288, '\P{^Is_Category=_Z}', "");
Expect(0, 12289, '\p{Is_Category=_Z}', "");
Expect(1, 12289, '\p{^Is_Category=_Z}', "");
Expect(1, 12289, '\P{Is_Category=_Z}', "");
Expect(0, 12289, '\P{^Is_Category=_Z}', "");
Error('\p{General_Category=	:=line_SEPARATOR}');
Error('\P{General_Category=	:=line_SEPARATOR}');
Expect(1, 8232, '\p{General_Category=lineseparator}', "");
Expect(0, 8232, '\p{^General_Category=lineseparator}', "");
Expect(0, 8232, '\P{General_Category=lineseparator}', "");
Expect(1, 8232, '\P{^General_Category=lineseparator}', "");
Expect(0, 8233, '\p{General_Category=lineseparator}', "");
Expect(1, 8233, '\p{^General_Category=lineseparator}', "");
Expect(1, 8233, '\P{General_Category=lineseparator}', "");
Expect(0, 8233, '\P{^General_Category=lineseparator}', "");
Expect(1, 8232, '\p{General_Category=-	Line_separator}', "");
Expect(0, 8232, '\p{^General_Category=-	Line_separator}', "");
Expect(0, 8232, '\P{General_Category=-	Line_separator}', "");
Expect(1, 8232, '\P{^General_Category=-	Line_separator}', "");
Expect(0, 8233, '\p{General_Category=-	Line_separator}', "");
Expect(1, 8233, '\p{^General_Category=-	Line_separator}', "");
Expect(1, 8233, '\P{General_Category=-	Line_separator}', "");
Expect(0, 8233, '\P{^General_Category=-	Line_separator}', "");
Error('\p{Gc=/a/	_Zl}');
Error('\P{Gc=/a/	_Zl}');
Expect(1, 8232, '\p{Gc=zl}', "");
Expect(0, 8232, '\p{^Gc=zl}', "");
Expect(0, 8232, '\P{Gc=zl}', "");
Expect(1, 8232, '\P{^Gc=zl}', "");
Expect(0, 8233, '\p{Gc=zl}', "");
Expect(1, 8233, '\p{^Gc=zl}', "");
Expect(1, 8233, '\P{Gc=zl}', "");
Expect(0, 8233, '\P{^Gc=zl}', "");
Expect(1, 8232, '\p{Gc=_ Zl}', "");
Expect(0, 8232, '\p{^Gc=_ Zl}', "");
Expect(0, 8232, '\P{Gc=_ Zl}', "");
Expect(1, 8232, '\P{^Gc=_ Zl}', "");
Expect(0, 8233, '\p{Gc=_ Zl}', "");
Expect(1, 8233, '\p{^Gc=_ Zl}', "");
Expect(1, 8233, '\P{Gc=_ Zl}', "");
Expect(0, 8233, '\P{^Gc=_ Zl}', "");
Error('\p{Category=	:=Line_Separator}');
Error('\P{Category=	:=Line_Separator}');
Expect(1, 8232, '\p{Category=lineseparator}', "");
Expect(0, 8232, '\p{^Category=lineseparator}', "");
Expect(0, 8232, '\P{Category=lineseparator}', "");
Expect(1, 8232, '\P{^Category=lineseparator}', "");
Expect(0, 8233, '\p{Category=lineseparator}', "");
Expect(1, 8233, '\p{^Category=lineseparator}', "");
Expect(1, 8233, '\P{Category=lineseparator}', "");
Expect(0, 8233, '\P{^Category=lineseparator}', "");
Expect(1, 8232, '\p{Category:-LINE_Separator}', "");
Expect(0, 8232, '\p{^Category:-LINE_Separator}', "");
Expect(0, 8232, '\P{Category:-LINE_Separator}', "");
Expect(1, 8232, '\P{^Category:-LINE_Separator}', "");
Expect(0, 8233, '\p{Category:-LINE_Separator}', "");
Expect(1, 8233, '\p{^Category:-LINE_Separator}', "");
Expect(1, 8233, '\P{Category:-LINE_Separator}', "");
Expect(0, 8233, '\P{^Category:-LINE_Separator}', "");
Error('\p{Is_General_Category=	/a/Zl}');
Error('\P{Is_General_Category=	/a/Zl}');
Expect(1, 8232, '\p{Is_General_Category=zl}', "");
Expect(0, 8232, '\p{^Is_General_Category=zl}', "");
Expect(0, 8232, '\P{Is_General_Category=zl}', "");
Expect(1, 8232, '\P{^Is_General_Category=zl}', "");
Expect(0, 8233, '\p{Is_General_Category=zl}', "");
Expect(1, 8233, '\p{^Is_General_Category=zl}', "");
Expect(1, 8233, '\P{Is_General_Category=zl}', "");
Expect(0, 8233, '\P{^Is_General_Category=zl}', "");
Expect(1, 8232, '\p{Is_General_Category=_Zl}', "");
Expect(0, 8232, '\p{^Is_General_Category=_Zl}', "");
Expect(0, 8232, '\P{Is_General_Category=_Zl}', "");
Expect(1, 8232, '\P{^Is_General_Category=_Zl}', "");
Expect(0, 8233, '\p{Is_General_Category=_Zl}', "");
Expect(1, 8233, '\p{^Is_General_Category=_Zl}', "");
Expect(1, 8233, '\P{Is_General_Category=_Zl}', "");
Expect(0, 8233, '\P{^Is_General_Category=_Zl}', "");
Error('\p{Is_Gc=:=Line_Separator}');
Error('\P{Is_Gc=:=Line_Separator}');
Expect(1, 8232, '\p{Is_Gc=lineseparator}', "");
Expect(0, 8232, '\p{^Is_Gc=lineseparator}', "");
Expect(0, 8232, '\P{Is_Gc=lineseparator}', "");
Expect(1, 8232, '\P{^Is_Gc=lineseparator}', "");
Expect(0, 8233, '\p{Is_Gc=lineseparator}', "");
Expect(1, 8233, '\p{^Is_Gc=lineseparator}', "");
Expect(1, 8233, '\P{Is_Gc=lineseparator}', "");
Expect(0, 8233, '\P{^Is_Gc=lineseparator}', "");
Expect(1, 8232, '\p{Is_Gc=	_Line_Separator}', "");
Expect(0, 8232, '\p{^Is_Gc=	_Line_Separator}', "");
Expect(0, 8232, '\P{Is_Gc=	_Line_Separator}', "");
Expect(1, 8232, '\P{^Is_Gc=	_Line_Separator}', "");
Expect(0, 8233, '\p{Is_Gc=	_Line_Separator}', "");
Expect(1, 8233, '\p{^Is_Gc=	_Line_Separator}', "");
Expect(1, 8233, '\P{Is_Gc=	_Line_Separator}', "");
Expect(0, 8233, '\P{^Is_Gc=	_Line_Separator}', "");
Error('\p{Is_Category=_/a/Zl}');
Error('\P{Is_Category=_/a/Zl}');
Expect(1, 8232, '\p{Is_Category=zl}', "");
Expect(0, 8232, '\p{^Is_Category=zl}', "");
Expect(0, 8232, '\P{Is_Category=zl}', "");
Expect(1, 8232, '\P{^Is_Category=zl}', "");
Expect(0, 8233, '\p{Is_Category=zl}', "");
Expect(1, 8233, '\p{^Is_Category=zl}', "");
Expect(1, 8233, '\P{Is_Category=zl}', "");
Expect(0, 8233, '\P{^Is_Category=zl}', "");
Expect(1, 8232, '\p{Is_Category=  zl}', "");
Expect(0, 8232, '\p{^Is_Category=  zl}', "");
Expect(0, 8232, '\P{Is_Category=  zl}', "");
Expect(1, 8232, '\P{^Is_Category=  zl}', "");
Expect(0, 8233, '\p{Is_Category=  zl}', "");
Expect(1, 8233, '\p{^Is_Category=  zl}', "");
Expect(1, 8233, '\P{Is_Category=  zl}', "");
Expect(0, 8233, '\P{^Is_Category=  zl}', "");
Error('\p{General_Category=-_Paragraph_SEPARATOR:=}');
Error('\P{General_Category=-_Paragraph_SEPARATOR:=}');
Expect(1, 8233, '\p{General_Category=paragraphseparator}', "");
Expect(0, 8233, '\p{^General_Category=paragraphseparator}', "");
Expect(0, 8233, '\P{General_Category=paragraphseparator}', "");
Expect(1, 8233, '\P{^General_Category=paragraphseparator}', "");
Expect(0, 8234, '\p{General_Category=paragraphseparator}', "");
Expect(1, 8234, '\p{^General_Category=paragraphseparator}', "");
Expect(1, 8234, '\P{General_Category=paragraphseparator}', "");
Expect(0, 8234, '\P{^General_Category=paragraphseparator}', "");
Expect(1, 8233, '\p{General_Category=-Paragraph_Separator}', "");
Expect(0, 8233, '\p{^General_Category=-Paragraph_Separator}', "");
Expect(0, 8233, '\P{General_Category=-Paragraph_Separator}', "");
Expect(1, 8233, '\P{^General_Category=-Paragraph_Separator}', "");
Expect(0, 8234, '\p{General_Category=-Paragraph_Separator}', "");
Expect(1, 8234, '\p{^General_Category=-Paragraph_Separator}', "");
Expect(1, 8234, '\P{General_Category=-Paragraph_Separator}', "");
Expect(0, 8234, '\P{^General_Category=-Paragraph_Separator}', "");
Error('\p{Gc:	:=-_Zp}');
Error('\P{Gc:	:=-_Zp}');
Expect(1, 8233, '\p{Gc=zp}', "");
Expect(0, 8233, '\p{^Gc=zp}', "");
Expect(0, 8233, '\P{Gc=zp}', "");
Expect(1, 8233, '\P{^Gc=zp}', "");
Expect(0, 8234, '\p{Gc=zp}', "");
Expect(1, 8234, '\p{^Gc=zp}', "");
Expect(1, 8234, '\P{Gc=zp}', "");
Expect(0, 8234, '\P{^Gc=zp}', "");
Expect(1, 8233, '\p{Gc=		ZP}', "");
Expect(0, 8233, '\p{^Gc=		ZP}', "");
Expect(0, 8233, '\P{Gc=		ZP}', "");
Expect(1, 8233, '\P{^Gc=		ZP}', "");
Expect(0, 8234, '\p{Gc=		ZP}', "");
Expect(1, 8234, '\p{^Gc=		ZP}', "");
Expect(1, 8234, '\P{Gc=		ZP}', "");
Expect(0, 8234, '\P{^Gc=		ZP}', "");
Error('\p{Category= -PARAGRAPH_Separator/a/}');
Error('\P{Category= -PARAGRAPH_Separator/a/}');
Expect(1, 8233, '\p{Category=paragraphseparator}', "");
Expect(0, 8233, '\p{^Category=paragraphseparator}', "");
Expect(0, 8233, '\P{Category=paragraphseparator}', "");
Expect(1, 8233, '\P{^Category=paragraphseparator}', "");
Expect(0, 8234, '\p{Category=paragraphseparator}', "");
Expect(1, 8234, '\p{^Category=paragraphseparator}', "");
Expect(1, 8234, '\P{Category=paragraphseparator}', "");
Expect(0, 8234, '\P{^Category=paragraphseparator}', "");
Expect(1, 8233, '\p{Category=	_Paragraph_Separator}', "");
Expect(0, 8233, '\p{^Category=	_Paragraph_Separator}', "");
Expect(0, 8233, '\P{Category=	_Paragraph_Separator}', "");
Expect(1, 8233, '\P{^Category=	_Paragraph_Separator}', "");
Expect(0, 8234, '\p{Category=	_Paragraph_Separator}', "");
Expect(1, 8234, '\p{^Category=	_Paragraph_Separator}', "");
Expect(1, 8234, '\P{Category=	_Paragraph_Separator}', "");
Expect(0, 8234, '\P{^Category=	_Paragraph_Separator}', "");
Error('\p{Is_General_Category=/a/	Zp}');
Error('\P{Is_General_Category=/a/	Zp}');
Expect(1, 8233, '\p{Is_General_Category=zp}', "");
Expect(0, 8233, '\p{^Is_General_Category=zp}', "");
Expect(0, 8233, '\P{Is_General_Category=zp}', "");
Expect(1, 8233, '\P{^Is_General_Category=zp}', "");
Expect(0, 8234, '\p{Is_General_Category=zp}', "");
Expect(1, 8234, '\p{^Is_General_Category=zp}', "");
Expect(1, 8234, '\P{Is_General_Category=zp}', "");
Expect(0, 8234, '\P{^Is_General_Category=zp}', "");
Expect(1, 8233, '\p{Is_General_Category=_Zp}', "");
Expect(0, 8233, '\p{^Is_General_Category=_Zp}', "");
Expect(0, 8233, '\P{Is_General_Category=_Zp}', "");
Expect(1, 8233, '\P{^Is_General_Category=_Zp}', "");
Expect(0, 8234, '\p{Is_General_Category=_Zp}', "");
Expect(1, 8234, '\p{^Is_General_Category=_Zp}', "");
Expect(1, 8234, '\P{Is_General_Category=_Zp}', "");
Expect(0, 8234, '\P{^Is_General_Category=_Zp}', "");
Error('\p{Is_Gc=_/a/Paragraph_separator}');
Error('\P{Is_Gc=_/a/Paragraph_separator}');
Expect(1, 8233, '\p{Is_Gc=paragraphseparator}', "");
Expect(0, 8233, '\p{^Is_Gc=paragraphseparator}', "");
Expect(0, 8233, '\P{Is_Gc=paragraphseparator}', "");
Expect(1, 8233, '\P{^Is_Gc=paragraphseparator}', "");
Expect(0, 8234, '\p{Is_Gc=paragraphseparator}', "");
Expect(1, 8234, '\p{^Is_Gc=paragraphseparator}', "");
Expect(1, 8234, '\P{Is_Gc=paragraphseparator}', "");
Expect(0, 8234, '\P{^Is_Gc=paragraphseparator}', "");
Expect(1, 8233, '\p{Is_Gc=_PARAGRAPH_Separator}', "");
Expect(0, 8233, '\p{^Is_Gc=_PARAGRAPH_Separator}', "");
Expect(0, 8233, '\P{Is_Gc=_PARAGRAPH_Separator}', "");
Expect(1, 8233, '\P{^Is_Gc=_PARAGRAPH_Separator}', "");
Expect(0, 8234, '\p{Is_Gc=_PARAGRAPH_Separator}', "");
Expect(1, 8234, '\p{^Is_Gc=_PARAGRAPH_Separator}', "");
Expect(1, 8234, '\P{Is_Gc=_PARAGRAPH_Separator}', "");
Expect(0, 8234, '\P{^Is_Gc=_PARAGRAPH_Separator}', "");
Error('\p{Is_Category=	:=ZP}');
Error('\P{Is_Category=	:=ZP}');
Expect(1, 8233, '\p{Is_Category=zp}', "");
Expect(0, 8233, '\p{^Is_Category=zp}', "");
Expect(0, 8233, '\P{Is_Category=zp}', "");
Expect(1, 8233, '\P{^Is_Category=zp}', "");
Expect(0, 8234, '\p{Is_Category=zp}', "");
Expect(1, 8234, '\p{^Is_Category=zp}', "");
Expect(1, 8234, '\P{Is_Category=zp}', "");
Expect(0, 8234, '\P{^Is_Category=zp}', "");
Expect(1, 8233, '\p{Is_Category=		Zp}', "");
Expect(0, 8233, '\p{^Is_Category=		Zp}', "");
Expect(0, 8233, '\P{Is_Category=		Zp}', "");
Expect(1, 8233, '\P{^Is_Category=		Zp}', "");
Expect(0, 8234, '\p{Is_Category=		Zp}', "");
Expect(1, 8234, '\p{^Is_Category=		Zp}', "");
Expect(1, 8234, '\P{Is_Category=		Zp}', "");
Expect(0, 8234, '\P{^Is_Category=		Zp}', "");
Error('\p{General_Category=	:=Space_Separator}');
Error('\P{General_Category=	:=Space_Separator}');
Expect(1, 12288, '\p{General_Category=spaceseparator}', "");
Expect(0, 12288, '\p{^General_Category=spaceseparator}', "");
Expect(0, 12288, '\P{General_Category=spaceseparator}', "");
Expect(1, 12288, '\P{^General_Category=spaceseparator}', "");
Expect(0, 12289, '\p{General_Category=spaceseparator}', "");
Expect(1, 12289, '\p{^General_Category=spaceseparator}', "");
Expect(1, 12289, '\P{General_Category=spaceseparator}', "");
Expect(0, 12289, '\P{^General_Category=spaceseparator}', "");
Expect(1, 12288, '\p{General_Category= space_Separator}', "");
Expect(0, 12288, '\p{^General_Category= space_Separator}', "");
Expect(0, 12288, '\P{General_Category= space_Separator}', "");
Expect(1, 12288, '\P{^General_Category= space_Separator}', "");
Expect(0, 12289, '\p{General_Category= space_Separator}', "");
Expect(1, 12289, '\p{^General_Category= space_Separator}', "");
Expect(1, 12289, '\P{General_Category= space_Separator}', "");
Expect(0, 12289, '\P{^General_Category= space_Separator}', "");
Error('\p{Gc=-:=ZS}');
Error('\P{Gc=-:=ZS}');
Expect(1, 12288, '\p{Gc=zs}', "");
Expect(0, 12288, '\p{^Gc=zs}', "");
Expect(0, 12288, '\P{Gc=zs}', "");
Expect(1, 12288, '\P{^Gc=zs}', "");
Expect(0, 12289, '\p{Gc=zs}', "");
Expect(1, 12289, '\p{^Gc=zs}', "");
Expect(1, 12289, '\P{Gc=zs}', "");
Expect(0, 12289, '\P{^Gc=zs}', "");
Expect(1, 12288, '\p{Gc=- Zs}', "");
Expect(0, 12288, '\p{^Gc=- Zs}', "");
Expect(0, 12288, '\P{Gc=- Zs}', "");
Expect(1, 12288, '\P{^Gc=- Zs}', "");
Expect(0, 12289, '\p{Gc=- Zs}', "");
Expect(1, 12289, '\p{^Gc=- Zs}', "");
Expect(1, 12289, '\P{Gc=- Zs}', "");
Expect(0, 12289, '\P{^Gc=- Zs}', "");
Error('\p{Category: /a/- SPACE_Separator}');
Error('\P{Category: /a/- SPACE_Separator}');
Expect(1, 12288, '\p{Category=spaceseparator}', "");
Expect(0, 12288, '\p{^Category=spaceseparator}', "");
Expect(0, 12288, '\P{Category=spaceseparator}', "");
Expect(1, 12288, '\P{^Category=spaceseparator}', "");
Expect(0, 12289, '\p{Category=spaceseparator}', "");
Expect(1, 12289, '\p{^Category=spaceseparator}', "");
Expect(1, 12289, '\P{Category=spaceseparator}', "");
Expect(0, 12289, '\P{^Category=spaceseparator}', "");
Expect(1, 12288, '\p{Category=__Space_Separator}', "");
Expect(0, 12288, '\p{^Category=__Space_Separator}', "");
Expect(0, 12288, '\P{Category=__Space_Separator}', "");
Expect(1, 12288, '\P{^Category=__Space_Separator}', "");
Expect(0, 12289, '\p{Category=__Space_Separator}', "");
Expect(1, 12289, '\p{^Category=__Space_Separator}', "");
Expect(1, 12289, '\P{Category=__Space_Separator}', "");
Expect(0, 12289, '\P{^Category=__Space_Separator}', "");
Error('\p{Is_General_Category=- ZS/a/}');
Error('\P{Is_General_Category=- ZS/a/}');
Expect(1, 12288, '\p{Is_General_Category=zs}', "");
Expect(0, 12288, '\p{^Is_General_Category=zs}', "");
Expect(0, 12288, '\P{Is_General_Category=zs}', "");
Expect(1, 12288, '\P{^Is_General_Category=zs}', "");
Expect(0, 12289, '\p{Is_General_Category=zs}', "");
Expect(1, 12289, '\p{^Is_General_Category=zs}', "");
Expect(1, 12289, '\P{Is_General_Category=zs}', "");
Expect(0, 12289, '\P{^Is_General_Category=zs}', "");
Expect(1, 12288, '\p{Is_General_Category= ZS}', "");
Expect(0, 12288, '\p{^Is_General_Category= ZS}', "");
Expect(0, 12288, '\P{Is_General_Category= ZS}', "");
Expect(1, 12288, '\P{^Is_General_Category= ZS}', "");
Expect(0, 12289, '\p{Is_General_Category= ZS}', "");
Expect(1, 12289, '\p{^Is_General_Category= ZS}', "");
Expect(1, 12289, '\P{Is_General_Category= ZS}', "");
Expect(0, 12289, '\P{^Is_General_Category= ZS}', "");
Error('\p{Is_Gc=-:=SPACE_Separator}');
Error('\P{Is_Gc=-:=SPACE_Separator}');
Expect(1, 12288, '\p{Is_Gc=spaceseparator}', "");
Expect(0, 12288, '\p{^Is_Gc=spaceseparator}', "");
Expect(0, 12288, '\P{Is_Gc=spaceseparator}', "");
Expect(1, 12288, '\P{^Is_Gc=spaceseparator}', "");
Expect(0, 12289, '\p{Is_Gc=spaceseparator}', "");
Expect(1, 12289, '\p{^Is_Gc=spaceseparator}', "");
Expect(1, 12289, '\P{Is_Gc=spaceseparator}', "");
Expect(0, 12289, '\P{^Is_Gc=spaceseparator}', "");
Expect(1, 12288, '\p{Is_Gc=SPACE_Separator}', "");
Expect(0, 12288, '\p{^Is_Gc=SPACE_Separator}', "");
Expect(0, 12288, '\P{Is_Gc=SPACE_Separator}', "");
Expect(1, 12288, '\P{^Is_Gc=SPACE_Separator}', "");
Expect(0, 12289, '\p{Is_Gc=SPACE_Separator}', "");
Expect(1, 12289, '\p{^Is_Gc=SPACE_Separator}', "");
Expect(1, 12289, '\P{Is_Gc=SPACE_Separator}', "");
Expect(0, 12289, '\P{^Is_Gc=SPACE_Separator}', "");
Error('\p{Is_Category= zs/a/}');
Error('\P{Is_Category= zs/a/}');
Expect(1, 12288, '\p{Is_Category=zs}', "");
Expect(0, 12288, '\p{^Is_Category=zs}', "");
Expect(0, 12288, '\P{Is_Category=zs}', "");
Expect(1, 12288, '\P{^Is_Category=zs}', "");
Expect(0, 12289, '\p{Is_Category=zs}', "");
Expect(1, 12289, '\p{^Is_Category=zs}', "");
Expect(1, 12289, '\P{Is_Category=zs}', "");
Expect(0, 12289, '\P{^Is_Category=zs}', "");
Error('\p{Hangul_Syllable_Type=	-LEADING_JAMO:=}');
Error('\P{Hangul_Syllable_Type=	-LEADING_JAMO:=}');
Expect(1, 43388, '\p{Hangul_Syllable_Type=leadingjamo}', "");
Expect(0, 43388, '\p{^Hangul_Syllable_Type=leadingjamo}', "");
Expect(0, 43388, '\P{Hangul_Syllable_Type=leadingjamo}', "");
Expect(1, 43388, '\P{^Hangul_Syllable_Type=leadingjamo}', "");
Expect(0, 43389, '\p{Hangul_Syllable_Type=leadingjamo}', "");
Expect(1, 43389, '\p{^Hangul_Syllable_Type=leadingjamo}', "");
Expect(1, 43389, '\P{Hangul_Syllable_Type=leadingjamo}', "");
Expect(0, 43389, '\P{^Hangul_Syllable_Type=leadingjamo}', "");
Expect(1, 43388, '\p{Hangul_Syllable_Type:    LEADING_Jamo}', "");
Expect(0, 43388, '\p{^Hangul_Syllable_Type:    LEADING_Jamo}', "");
Expect(0, 43388, '\P{Hangul_Syllable_Type:    LEADING_Jamo}', "");
Expect(1, 43388, '\P{^Hangul_Syllable_Type:    LEADING_Jamo}', "");
Expect(0, 43389, '\p{Hangul_Syllable_Type:    LEADING_Jamo}', "");
Expect(1, 43389, '\p{^Hangul_Syllable_Type:    LEADING_Jamo}', "");
Expect(1, 43389, '\P{Hangul_Syllable_Type:    LEADING_Jamo}', "");
Expect(0, 43389, '\P{^Hangul_Syllable_Type:    LEADING_Jamo}', "");
Error('\p{Hst=:= -L}');
Error('\P{Hst=:= -L}');
Expect(1, 43388, '\p{Hst=l}', "");
Expect(0, 43388, '\p{^Hst=l}', "");
Expect(0, 43388, '\P{Hst=l}', "");
Expect(1, 43388, '\P{^Hst=l}', "");
Expect(0, 43389, '\p{Hst=l}', "");
Expect(1, 43389, '\p{^Hst=l}', "");
Expect(1, 43389, '\P{Hst=l}', "");
Expect(0, 43389, '\P{^Hst=l}', "");
Expect(1, 43388, '\p{Hst=-L}', "");
Expect(0, 43388, '\p{^Hst=-L}', "");
Expect(0, 43388, '\P{Hst=-L}', "");
Expect(1, 43388, '\P{^Hst=-L}', "");
Expect(0, 43389, '\p{Hst=-L}', "");
Expect(1, 43389, '\p{^Hst=-L}', "");
Expect(1, 43389, '\P{Hst=-L}', "");
Expect(0, 43389, '\P{^Hst=-L}', "");
Error('\p{Is_Hangul_Syllable_Type=	_Leading_JAMO:=}');
Error('\P{Is_Hangul_Syllable_Type=	_Leading_JAMO:=}');
Expect(1, 43388, '\p{Is_Hangul_Syllable_Type: leadingjamo}', "");
Expect(0, 43388, '\p{^Is_Hangul_Syllable_Type: leadingjamo}', "");
Expect(0, 43388, '\P{Is_Hangul_Syllable_Type: leadingjamo}', "");
Expect(1, 43388, '\P{^Is_Hangul_Syllable_Type: leadingjamo}', "");
Expect(0, 43389, '\p{Is_Hangul_Syllable_Type: leadingjamo}', "");
Expect(1, 43389, '\p{^Is_Hangul_Syllable_Type: leadingjamo}', "");
Expect(1, 43389, '\P{Is_Hangul_Syllable_Type: leadingjamo}', "");
Expect(0, 43389, '\P{^Is_Hangul_Syllable_Type: leadingjamo}', "");
Expect(1, 43388, '\p{Is_Hangul_Syllable_Type=	LEADING_JAMO}', "");
Expect(0, 43388, '\p{^Is_Hangul_Syllable_Type=	LEADING_JAMO}', "");
Expect(0, 43388, '\P{Is_Hangul_Syllable_Type=	LEADING_JAMO}', "");
Expect(1, 43388, '\P{^Is_Hangul_Syllable_Type=	LEADING_JAMO}', "");
Expect(0, 43389, '\p{Is_Hangul_Syllable_Type=	LEADING_JAMO}', "");
Expect(1, 43389, '\p{^Is_Hangul_Syllable_Type=	LEADING_JAMO}', "");
Expect(1, 43389, '\P{Is_Hangul_Syllable_Type=	LEADING_JAMO}', "");
Expect(0, 43389, '\P{^Is_Hangul_Syllable_Type=	LEADING_JAMO}', "");
Error('\p{Is_Hst=/a/		l}');
Error('\P{Is_Hst=/a/		l}');
Expect(1, 43388, '\p{Is_Hst=l}', "");
Expect(0, 43388, '\p{^Is_Hst=l}', "");
Expect(0, 43388, '\P{Is_Hst=l}', "");
Expect(1, 43388, '\P{^Is_Hst=l}', "");
Expect(0, 43389, '\p{Is_Hst=l}', "");
Expect(1, 43389, '\p{^Is_Hst=l}', "");
Expect(1, 43389, '\P{Is_Hst=l}', "");
Expect(0, 43389, '\P{^Is_Hst=l}', "");
Expect(1, 43388, '\p{Is_Hst=__L}', "");
Expect(0, 43388, '\p{^Is_Hst=__L}', "");
Expect(0, 43388, '\P{Is_Hst=__L}', "");
Expect(1, 43388, '\P{^Is_Hst=__L}', "");
Expect(0, 43389, '\p{Is_Hst=__L}', "");
Expect(1, 43389, '\p{^Is_Hst=__L}', "");
Expect(1, 43389, '\P{Is_Hst=__L}', "");
Expect(0, 43389, '\P{^Is_Hst=__L}', "");
Error('\p{Hangul_Syllable_Type=:= _lv_Syllable}');
Error('\P{Hangul_Syllable_Type=:= _lv_Syllable}');
Expect(1, 55176, '\p{Hangul_Syllable_Type=lvsyllable}', "");
Expect(0, 55176, '\p{^Hangul_Syllable_Type=lvsyllable}', "");
Expect(0, 55176, '\P{Hangul_Syllable_Type=lvsyllable}', "");
Expect(1, 55176, '\P{^Hangul_Syllable_Type=lvsyllable}', "");
Expect(0, 55177, '\p{Hangul_Syllable_Type=lvsyllable}', "");
Expect(1, 55177, '\p{^Hangul_Syllable_Type=lvsyllable}', "");
Expect(1, 55177, '\P{Hangul_Syllable_Type=lvsyllable}', "");
Expect(0, 55177, '\P{^Hangul_Syllable_Type=lvsyllable}', "");
Expect(1, 55176, '\p{Hangul_Syllable_Type= -lv_syllable}', "");
Expect(0, 55176, '\p{^Hangul_Syllable_Type= -lv_syllable}', "");
Expect(0, 55176, '\P{Hangul_Syllable_Type= -lv_syllable}', "");
Expect(1, 55176, '\P{^Hangul_Syllable_Type= -lv_syllable}', "");
Expect(0, 55177, '\p{Hangul_Syllable_Type= -lv_syllable}', "");
Expect(1, 55177, '\p{^Hangul_Syllable_Type= -lv_syllable}', "");
Expect(1, 55177, '\P{Hangul_Syllable_Type= -lv_syllable}', "");
Expect(0, 55177, '\P{^Hangul_Syllable_Type= -lv_syllable}', "");
Error('\p{Hst=:=lv}');
Error('\P{Hst=:=lv}');
Expect(1, 55176, '\p{Hst=lv}', "");
Expect(0, 55176, '\p{^Hst=lv}', "");
Expect(0, 55176, '\P{Hst=lv}', "");
Expect(1, 55176, '\P{^Hst=lv}', "");
Expect(0, 55177, '\p{Hst=lv}', "");
Expect(1, 55177, '\p{^Hst=lv}', "");
Expect(1, 55177, '\P{Hst=lv}', "");
Expect(0, 55177, '\P{^Hst=lv}', "");
Expect(1, 55176, '\p{Hst=	LV}', "");
Expect(0, 55176, '\p{^Hst=	LV}', "");
Expect(0, 55176, '\P{Hst=	LV}', "");
Expect(1, 55176, '\P{^Hst=	LV}', "");
Expect(0, 55177, '\p{Hst=	LV}', "");
Expect(1, 55177, '\p{^Hst=	LV}', "");
Expect(1, 55177, '\P{Hst=	LV}', "");
Expect(0, 55177, '\P{^Hst=	LV}', "");
Error('\p{Is_Hangul_Syllable_Type= lv_Syllable/a/}');
Error('\P{Is_Hangul_Syllable_Type= lv_Syllable/a/}');
Expect(1, 55176, '\p{Is_Hangul_Syllable_Type=lvsyllable}', "");
Expect(0, 55176, '\p{^Is_Hangul_Syllable_Type=lvsyllable}', "");
Expect(0, 55176, '\P{Is_Hangul_Syllable_Type=lvsyllable}', "");
Expect(1, 55176, '\P{^Is_Hangul_Syllable_Type=lvsyllable}', "");
Expect(0, 55177, '\p{Is_Hangul_Syllable_Type=lvsyllable}', "");
Expect(1, 55177, '\p{^Is_Hangul_Syllable_Type=lvsyllable}', "");
Expect(1, 55177, '\P{Is_Hangul_Syllable_Type=lvsyllable}', "");
Expect(0, 55177, '\P{^Is_Hangul_Syllable_Type=lvsyllable}', "");
Expect(1, 55176, '\p{Is_Hangul_Syllable_Type:		-lv_Syllable}', "");
Expect(0, 55176, '\p{^Is_Hangul_Syllable_Type:		-lv_Syllable}', "");
Expect(0, 55176, '\P{Is_Hangul_Syllable_Type:		-lv_Syllable}', "");
Expect(1, 55176, '\P{^Is_Hangul_Syllable_Type:		-lv_Syllable}', "");
Expect(0, 55177, '\p{Is_Hangul_Syllable_Type:		-lv_Syllable}', "");
Expect(1, 55177, '\p{^Is_Hangul_Syllable_Type:		-lv_Syllable}', "");
Expect(1, 55177, '\P{Is_Hangul_Syllable_Type:		-lv_Syllable}', "");
Expect(0, 55177, '\P{^Is_Hangul_Syllable_Type:		-lv_Syllable}', "");
Error('\p{Is_Hst=	-LV/a/}');
Error('\P{Is_Hst=	-LV/a/}');
Expect(1, 55176, '\p{Is_Hst=lv}', "");
Expect(0, 55176, '\p{^Is_Hst=lv}', "");
Expect(0, 55176, '\P{Is_Hst=lv}', "");
Expect(1, 55176, '\P{^Is_Hst=lv}', "");
Expect(0, 55177, '\p{Is_Hst=lv}', "");
Expect(1, 55177, '\p{^Is_Hst=lv}', "");
Expect(1, 55177, '\P{Is_Hst=lv}', "");
Expect(0, 55177, '\P{^Is_Hst=lv}', "");
Expect(1, 55176, '\p{Is_Hst:-LV}', "");
Expect(0, 55176, '\p{^Is_Hst:-LV}', "");
Expect(0, 55176, '\P{Is_Hst:-LV}', "");
Expect(1, 55176, '\P{^Is_Hst:-LV}', "");
Expect(0, 55177, '\p{Is_Hst:-LV}', "");
Expect(1, 55177, '\p{^Is_Hst:-LV}', "");
Expect(1, 55177, '\P{Is_Hst:-LV}', "");
Expect(0, 55177, '\P{^Is_Hst:-LV}', "");
Error('\p{Hangul_Syllable_Type=/a/-lvt_Syllable}');
Error('\P{Hangul_Syllable_Type=/a/-lvt_Syllable}');
Expect(1, 55203, '\p{Hangul_Syllable_Type=lvtsyllable}', "");
Expect(0, 55203, '\p{^Hangul_Syllable_Type=lvtsyllable}', "");
Expect(0, 55203, '\P{Hangul_Syllable_Type=lvtsyllable}', "");
Expect(1, 55203, '\P{^Hangul_Syllable_Type=lvtsyllable}', "");
Expect(0, 55204, '\p{Hangul_Syllable_Type=lvtsyllable}', "");
Expect(1, 55204, '\p{^Hangul_Syllable_Type=lvtsyllable}', "");
Expect(1, 55204, '\P{Hangul_Syllable_Type=lvtsyllable}', "");
Expect(0, 55204, '\P{^Hangul_Syllable_Type=lvtsyllable}', "");
Expect(1, 55203, '\p{Hangul_Syllable_Type=lvt_Syllable}', "");
Expect(0, 55203, '\p{^Hangul_Syllable_Type=lvt_Syllable}', "");
Expect(0, 55203, '\P{Hangul_Syllable_Type=lvt_Syllable}', "");
Expect(1, 55203, '\P{^Hangul_Syllable_Type=lvt_Syllable}', "");
Expect(0, 55204, '\p{Hangul_Syllable_Type=lvt_Syllable}', "");
Expect(1, 55204, '\p{^Hangul_Syllable_Type=lvt_Syllable}', "");
Expect(1, 55204, '\P{Hangul_Syllable_Type=lvt_Syllable}', "");
Expect(0, 55204, '\P{^Hangul_Syllable_Type=lvt_Syllable}', "");
Error('\p{Hst=/a/_LVT}');
Error('\P{Hst=/a/_LVT}');
Expect(1, 55203, '\p{Hst=lvt}', "");
Expect(0, 55203, '\p{^Hst=lvt}', "");
Expect(0, 55203, '\P{Hst=lvt}', "");
Expect(1, 55203, '\P{^Hst=lvt}', "");
Expect(0, 55204, '\p{Hst=lvt}', "");
Expect(1, 55204, '\p{^Hst=lvt}', "");
Expect(1, 55204, '\P{Hst=lvt}', "");
Expect(0, 55204, '\P{^Hst=lvt}', "");
Expect(1, 55203, '\p{Hst=-	LVT}', "");
Expect(0, 55203, '\p{^Hst=-	LVT}', "");
Expect(0, 55203, '\P{Hst=-	LVT}', "");
Expect(1, 55203, '\P{^Hst=-	LVT}', "");
Expect(0, 55204, '\p{Hst=-	LVT}', "");
Expect(1, 55204, '\p{^Hst=-	LVT}', "");
Expect(1, 55204, '\P{Hst=-	LVT}', "");
Expect(0, 55204, '\P{^Hst=-	LVT}', "");
Error('\p{Is_Hangul_Syllable_Type=-/a/LVT_SYLLABLE}');
Error('\P{Is_Hangul_Syllable_Type=-/a/LVT_SYLLABLE}');
Expect(1, 55203, '\p{Is_Hangul_Syllable_Type=lvtsyllable}', "");
Expect(0, 55203, '\p{^Is_Hangul_Syllable_Type=lvtsyllable}', "");
Expect(0, 55203, '\P{Is_Hangul_Syllable_Type=lvtsyllable}', "");
Expect(1, 55203, '\P{^Is_Hangul_Syllable_Type=lvtsyllable}', "");
Expect(0, 55204, '\p{Is_Hangul_Syllable_Type=lvtsyllable}', "");
Expect(1, 55204, '\p{^Is_Hangul_Syllable_Type=lvtsyllable}', "");
Expect(1, 55204, '\P{Is_Hangul_Syllable_Type=lvtsyllable}', "");
Expect(0, 55204, '\P{^Is_Hangul_Syllable_Type=lvtsyllable}', "");
Expect(1, 55203, '\p{Is_Hangul_Syllable_Type=_lvt_Syllable}', "");
Expect(0, 55203, '\p{^Is_Hangul_Syllable_Type=_lvt_Syllable}', "");
Expect(0, 55203, '\P{Is_Hangul_Syllable_Type=_lvt_Syllable}', "");
Expect(1, 55203, '\P{^Is_Hangul_Syllable_Type=_lvt_Syllable}', "");
Expect(0, 55204, '\p{Is_Hangul_Syllable_Type=_lvt_Syllable}', "");
Expect(1, 55204, '\p{^Is_Hangul_Syllable_Type=_lvt_Syllable}', "");
Expect(1, 55204, '\P{Is_Hangul_Syllable_Type=_lvt_Syllable}', "");
Expect(0, 55204, '\P{^Is_Hangul_Syllable_Type=_lvt_Syllable}', "");
Error('\p{Is_Hst:/a/--LVT}');
Error('\P{Is_Hst:/a/--LVT}');
Expect(1, 55203, '\p{Is_Hst=lvt}', "");
Expect(0, 55203, '\p{^Is_Hst=lvt}', "");
Expect(0, 55203, '\P{Is_Hst=lvt}', "");
Expect(1, 55203, '\P{^Is_Hst=lvt}', "");
Expect(0, 55204, '\p{Is_Hst=lvt}', "");
Expect(1, 55204, '\p{^Is_Hst=lvt}', "");
Expect(1, 55204, '\P{Is_Hst=lvt}', "");
Expect(0, 55204, '\P{^Is_Hst=lvt}', "");
Expect(1, 55203, '\p{Is_Hst= LVT}', "");
Expect(0, 55203, '\p{^Is_Hst= LVT}', "");
Expect(0, 55203, '\P{Is_Hst= LVT}', "");
Expect(1, 55203, '\P{^Is_Hst= LVT}', "");
Expect(0, 55204, '\p{Is_Hst= LVT}', "");
Expect(1, 55204, '\p{^Is_Hst= LVT}', "");
Expect(1, 55204, '\P{Is_Hst= LVT}', "");
Expect(0, 55204, '\P{^Is_Hst= LVT}', "");
Error('\p{Hangul_Syllable_Type=:=	NOT_Applicable}');
Error('\P{Hangul_Syllable_Type=:=	NOT_Applicable}');
Expect(1, 55292, '\p{Hangul_Syllable_Type=notapplicable}', "");
Expect(0, 55292, '\p{^Hangul_Syllable_Type=notapplicable}', "");
Expect(0, 55292, '\P{Hangul_Syllable_Type=notapplicable}', "");
Expect(1, 55292, '\P{^Hangul_Syllable_Type=notapplicable}', "");
Expect(0, 55291, '\p{Hangul_Syllable_Type=notapplicable}', "");
Expect(1, 55291, '\p{^Hangul_Syllable_Type=notapplicable}', "");
Expect(1, 55291, '\P{Hangul_Syllable_Type=notapplicable}', "");
Expect(0, 55291, '\P{^Hangul_Syllable_Type=notapplicable}', "");
Expect(1, 55292, '\p{Hangul_Syllable_Type=-not_Applicable}', "");
Expect(0, 55292, '\p{^Hangul_Syllable_Type=-not_Applicable}', "");
Expect(0, 55292, '\P{Hangul_Syllable_Type=-not_Applicable}', "");
Expect(1, 55292, '\P{^Hangul_Syllable_Type=-not_Applicable}', "");
Expect(0, 55291, '\p{Hangul_Syllable_Type=-not_Applicable}', "");
Expect(1, 55291, '\p{^Hangul_Syllable_Type=-not_Applicable}', "");
Expect(1, 55291, '\P{Hangul_Syllable_Type=-not_Applicable}', "");
Expect(0, 55291, '\P{^Hangul_Syllable_Type=-not_Applicable}', "");
Error('\p{Hst=_	NA:=}');
Error('\P{Hst=_	NA:=}');
Expect(1, 55292, '\p{Hst=na}', "");
Expect(0, 55292, '\p{^Hst=na}', "");
Expect(0, 55292, '\P{Hst=na}', "");
Expect(1, 55292, '\P{^Hst=na}', "");
Expect(0, 55291, '\p{Hst=na}', "");
Expect(1, 55291, '\p{^Hst=na}', "");
Expect(1, 55291, '\P{Hst=na}', "");
Expect(0, 55291, '\P{^Hst=na}', "");
Expect(1, 55292, '\p{Hst=NA}', "");
Expect(0, 55292, '\p{^Hst=NA}', "");
Expect(0, 55292, '\P{Hst=NA}', "");
Expect(1, 55292, '\P{^Hst=NA}', "");
Expect(0, 55291, '\p{Hst=NA}', "");
Expect(1, 55291, '\p{^Hst=NA}', "");
Expect(1, 55291, '\P{Hst=NA}', "");
Expect(0, 55291, '\P{^Hst=NA}', "");
Error('\p{Is_Hangul_Syllable_Type=_/a/not_APPLICABLE}');
Error('\P{Is_Hangul_Syllable_Type=_/a/not_APPLICABLE}');
Expect(1, 55292, '\p{Is_Hangul_Syllable_Type=notapplicable}', "");
Expect(0, 55292, '\p{^Is_Hangul_Syllable_Type=notapplicable}', "");
Expect(0, 55292, '\P{Is_Hangul_Syllable_Type=notapplicable}', "");
Expect(1, 55292, '\P{^Is_Hangul_Syllable_Type=notapplicable}', "");
Expect(0, 55291, '\p{Is_Hangul_Syllable_Type=notapplicable}', "");
Expect(1, 55291, '\p{^Is_Hangul_Syllable_Type=notapplicable}', "");
Expect(1, 55291, '\P{Is_Hangul_Syllable_Type=notapplicable}', "");
Expect(0, 55291, '\P{^Is_Hangul_Syllable_Type=notapplicable}', "");
Expect(1, 55292, '\p{Is_Hangul_Syllable_Type=_	Not_Applicable}', "");
Expect(0, 55292, '\p{^Is_Hangul_Syllable_Type=_	Not_Applicable}', "");
Expect(0, 55292, '\P{Is_Hangul_Syllable_Type=_	Not_Applicable}', "");
Expect(1, 55292, '\P{^Is_Hangul_Syllable_Type=_	Not_Applicable}', "");
Expect(0, 55291, '\p{Is_Hangul_Syllable_Type=_	Not_Applicable}', "");
Expect(1, 55291, '\p{^Is_Hangul_Syllable_Type=_	Not_Applicable}', "");
Expect(1, 55291, '\P{Is_Hangul_Syllable_Type=_	Not_Applicable}', "");
Expect(0, 55291, '\P{^Is_Hangul_Syllable_Type=_	Not_Applicable}', "");
Error('\p{Is_Hst=__NA/a/}');
Error('\P{Is_Hst=__NA/a/}');
Expect(1, 55292, '\p{Is_Hst=na}', "");
Expect(0, 55292, '\p{^Is_Hst=na}', "");
Expect(0, 55292, '\P{Is_Hst=na}', "");
Expect(1, 55292, '\P{^Is_Hst=na}', "");
Expect(0, 55291, '\p{Is_Hst=na}', "");
Expect(1, 55291, '\p{^Is_Hst=na}', "");
Expect(1, 55291, '\P{Is_Hst=na}', "");
Expect(0, 55291, '\P{^Is_Hst=na}', "");
Expect(1, 55292, '\p{Is_Hst=_ NA}', "");
Expect(0, 55292, '\p{^Is_Hst=_ NA}', "");
Expect(0, 55292, '\P{Is_Hst=_ NA}', "");
Expect(1, 55292, '\P{^Is_Hst=_ NA}', "");
Expect(0, 55291, '\p{Is_Hst=_ NA}', "");
Expect(1, 55291, '\p{^Is_Hst=_ NA}', "");
Expect(1, 55291, '\P{Is_Hst=_ NA}', "");
Expect(0, 55291, '\P{^Is_Hst=_ NA}', "");
Error('\p{Hangul_Syllable_Type= :=trailing_JAMO}');
Error('\P{Hangul_Syllable_Type= :=trailing_JAMO}');
Expect(1, 55291, '\p{Hangul_Syllable_Type=trailingjamo}', "");
Expect(0, 55291, '\p{^Hangul_Syllable_Type=trailingjamo}', "");
Expect(0, 55291, '\P{Hangul_Syllable_Type=trailingjamo}', "");
Expect(1, 55291, '\P{^Hangul_Syllable_Type=trailingjamo}', "");
Expect(0, 55292, '\p{Hangul_Syllable_Type=trailingjamo}', "");
Expect(1, 55292, '\p{^Hangul_Syllable_Type=trailingjamo}', "");
Expect(1, 55292, '\P{Hangul_Syllable_Type=trailingjamo}', "");
Expect(0, 55292, '\P{^Hangul_Syllable_Type=trailingjamo}', "");
Expect(1, 55291, '\p{Hangul_Syllable_Type=-_Trailing_JAMO}', "");
Expect(0, 55291, '\p{^Hangul_Syllable_Type=-_Trailing_JAMO}', "");
Expect(0, 55291, '\P{Hangul_Syllable_Type=-_Trailing_JAMO}', "");
Expect(1, 55291, '\P{^Hangul_Syllable_Type=-_Trailing_JAMO}', "");
Expect(0, 55292, '\p{Hangul_Syllable_Type=-_Trailing_JAMO}', "");
Expect(1, 55292, '\p{^Hangul_Syllable_Type=-_Trailing_JAMO}', "");
Expect(1, 55292, '\P{Hangul_Syllable_Type=-_Trailing_JAMO}', "");
Expect(0, 55292, '\P{^Hangul_Syllable_Type=-_Trailing_JAMO}', "");
Error('\p{Hst=	T/a/}');
Error('\P{Hst=	T/a/}');
Expect(1, 55291, '\p{Hst=t}', "");
Expect(0, 55291, '\p{^Hst=t}', "");
Expect(0, 55291, '\P{Hst=t}', "");
Expect(1, 55291, '\P{^Hst=t}', "");
Expect(0, 55292, '\p{Hst=t}', "");
Expect(1, 55292, '\p{^Hst=t}', "");
Expect(1, 55292, '\P{Hst=t}', "");
Expect(0, 55292, '\P{^Hst=t}', "");
Expect(1, 55291, '\p{Hst=-_T}', "");
Expect(0, 55291, '\p{^Hst=-_T}', "");
Expect(0, 55291, '\P{Hst=-_T}', "");
Expect(1, 55291, '\P{^Hst=-_T}', "");
Expect(0, 55292, '\p{Hst=-_T}', "");
Expect(1, 55292, '\p{^Hst=-_T}', "");
Expect(1, 55292, '\P{Hst=-_T}', "");
Expect(0, 55292, '\P{^Hst=-_T}', "");
Error('\p{Is_Hangul_Syllable_Type=-/a/trailing_Jamo}');
Error('\P{Is_Hangul_Syllable_Type=-/a/trailing_Jamo}');
Expect(1, 55291, '\p{Is_Hangul_Syllable_Type=trailingjamo}', "");
Expect(0, 55291, '\p{^Is_Hangul_Syllable_Type=trailingjamo}', "");
Expect(0, 55291, '\P{Is_Hangul_Syllable_Type=trailingjamo}', "");
Expect(1, 55291, '\P{^Is_Hangul_Syllable_Type=trailingjamo}', "");
Expect(0, 55292, '\p{Is_Hangul_Syllable_Type=trailingjamo}', "");
Expect(1, 55292, '\p{^Is_Hangul_Syllable_Type=trailingjamo}', "");
Expect(1, 55292, '\P{Is_Hangul_Syllable_Type=trailingjamo}', "");
Expect(0, 55292, '\P{^Is_Hangul_Syllable_Type=trailingjamo}', "");
Expect(1, 55291, '\p{Is_Hangul_Syllable_Type=--Trailing_JAMO}', "");
Expect(0, 55291, '\p{^Is_Hangul_Syllable_Type=--Trailing_JAMO}', "");
Expect(0, 55291, '\P{Is_Hangul_Syllable_Type=--Trailing_JAMO}', "");
Expect(1, 55291, '\P{^Is_Hangul_Syllable_Type=--Trailing_JAMO}', "");
Expect(0, 55292, '\p{Is_Hangul_Syllable_Type=--Trailing_JAMO}', "");
Expect(1, 55292, '\p{^Is_Hangul_Syllable_Type=--Trailing_JAMO}', "");
Expect(1, 55292, '\P{Is_Hangul_Syllable_Type=--Trailing_JAMO}', "");
Expect(0, 55292, '\P{^Is_Hangul_Syllable_Type=--Trailing_JAMO}', "");
Error('\p{Is_Hst:		_T:=}');
Error('\P{Is_Hst:		_T:=}');
Expect(1, 55291, '\p{Is_Hst=t}', "");
Expect(0, 55291, '\p{^Is_Hst=t}', "");
Expect(0, 55291, '\P{Is_Hst=t}', "");
Expect(1, 55291, '\P{^Is_Hst=t}', "");
Expect(0, 55292, '\p{Is_Hst=t}', "");
Expect(1, 55292, '\p{^Is_Hst=t}', "");
Expect(1, 55292, '\P{Is_Hst=t}', "");
Expect(0, 55292, '\P{^Is_Hst=t}', "");
Expect(1, 55291, '\p{Is_Hst=T}', "");
Expect(0, 55291, '\p{^Is_Hst=T}', "");
Expect(0, 55291, '\P{Is_Hst=T}', "");
Expect(1, 55291, '\P{^Is_Hst=T}', "");
Expect(0, 55292, '\p{Is_Hst=T}', "");
Expect(1, 55292, '\p{^Is_Hst=T}', "");
Expect(1, 55292, '\P{Is_Hst=T}', "");
Expect(0, 55292, '\P{^Is_Hst=T}', "");
Error('\p{Hangul_Syllable_Type=	 VOWEL_Jamo/a/}');
Error('\P{Hangul_Syllable_Type=	 VOWEL_Jamo/a/}');
Expect(1, 55238, '\p{Hangul_Syllable_Type=voweljamo}', "");
Expect(0, 55238, '\p{^Hangul_Syllable_Type=voweljamo}', "");
Expect(0, 55238, '\P{Hangul_Syllable_Type=voweljamo}', "");
Expect(1, 55238, '\P{^Hangul_Syllable_Type=voweljamo}', "");
Expect(0, 55239, '\p{Hangul_Syllable_Type=voweljamo}', "");
Expect(1, 55239, '\p{^Hangul_Syllable_Type=voweljamo}', "");
Expect(1, 55239, '\P{Hangul_Syllable_Type=voweljamo}', "");
Expect(0, 55239, '\P{^Hangul_Syllable_Type=voweljamo}', "");
Expect(1, 55238, '\p{Hangul_Syllable_Type=		vowel_Jamo}', "");
Expect(0, 55238, '\p{^Hangul_Syllable_Type=		vowel_Jamo}', "");
Expect(0, 55238, '\P{Hangul_Syllable_Type=		vowel_Jamo}', "");
Expect(1, 55238, '\P{^Hangul_Syllable_Type=		vowel_Jamo}', "");
Expect(0, 55239, '\p{Hangul_Syllable_Type=		vowel_Jamo}', "");
Expect(1, 55239, '\p{^Hangul_Syllable_Type=		vowel_Jamo}', "");
Expect(1, 55239, '\P{Hangul_Syllable_Type=		vowel_Jamo}', "");
Expect(0, 55239, '\P{^Hangul_Syllable_Type=		vowel_Jamo}', "");
Error('\p{Hst= _V/a/}');
Error('\P{Hst= _V/a/}');
Expect(1, 55238, '\p{Hst=v}', "");
Expect(0, 55238, '\p{^Hst=v}', "");
Expect(0, 55238, '\P{Hst=v}', "");
Expect(1, 55238, '\P{^Hst=v}', "");
Expect(0, 55239, '\p{Hst=v}', "");
Expect(1, 55239, '\p{^Hst=v}', "");
Expect(1, 55239, '\P{Hst=v}', "");
Expect(0, 55239, '\P{^Hst=v}', "");
Expect(1, 55238, '\p{Hst=	V}', "");
Expect(0, 55238, '\p{^Hst=	V}', "");
Expect(0, 55238, '\P{Hst=	V}', "");
Expect(1, 55238, '\P{^Hst=	V}', "");
Expect(0, 55239, '\p{Hst=	V}', "");
Expect(1, 55239, '\p{^Hst=	V}', "");
Expect(1, 55239, '\P{Hst=	V}', "");
Expect(0, 55239, '\P{^Hst=	V}', "");
Error('\p{Is_Hangul_Syllable_Type=-:=Vowel_Jamo}');
Error('\P{Is_Hangul_Syllable_Type=-:=Vowel_Jamo}');
Expect(1, 55238, '\p{Is_Hangul_Syllable_Type=voweljamo}', "");
Expect(0, 55238, '\p{^Is_Hangul_Syllable_Type=voweljamo}', "");
Expect(0, 55238, '\P{Is_Hangul_Syllable_Type=voweljamo}', "");
Expect(1, 55238, '\P{^Is_Hangul_Syllable_Type=voweljamo}', "");
Expect(0, 55239, '\p{Is_Hangul_Syllable_Type=voweljamo}', "");
Expect(1, 55239, '\p{^Is_Hangul_Syllable_Type=voweljamo}', "");
Expect(1, 55239, '\P{Is_Hangul_Syllable_Type=voweljamo}', "");
Expect(0, 55239, '\P{^Is_Hangul_Syllable_Type=voweljamo}', "");
Expect(1, 55238, '\p{Is_Hangul_Syllable_Type=	VOWEL_Jamo}', "");
Expect(0, 55238, '\p{^Is_Hangul_Syllable_Type=	VOWEL_Jamo}', "");
Expect(0, 55238, '\P{Is_Hangul_Syllable_Type=	VOWEL_Jamo}', "");
Expect(1, 55238, '\P{^Is_Hangul_Syllable_Type=	VOWEL_Jamo}', "");
Expect(0, 55239, '\p{Is_Hangul_Syllable_Type=	VOWEL_Jamo}', "");
Expect(1, 55239, '\p{^Is_Hangul_Syllable_Type=	VOWEL_Jamo}', "");
Expect(1, 55239, '\P{Is_Hangul_Syllable_Type=	VOWEL_Jamo}', "");
Expect(0, 55239, '\P{^Is_Hangul_Syllable_Type=	VOWEL_Jamo}', "");
Error('\p{Is_Hst= :=V}');
Error('\P{Is_Hst= :=V}');
Expect(1, 55238, '\p{Is_Hst=v}', "");
Expect(0, 55238, '\p{^Is_Hst=v}', "");
Expect(0, 55238, '\P{Is_Hst=v}', "");
Expect(1, 55238, '\P{^Is_Hst=v}', "");
Expect(0, 55239, '\p{Is_Hst=v}', "");
Expect(1, 55239, '\p{^Is_Hst=v}', "");
Expect(1, 55239, '\P{Is_Hst=v}', "");
Expect(0, 55239, '\P{^Is_Hst=v}', "");
Expect(1, 55238, '\p{Is_Hst=_V}', "");
Expect(0, 55238, '\p{^Is_Hst=_V}', "");
Expect(0, 55238, '\P{Is_Hst=_V}', "");
Expect(1, 55238, '\P{^Is_Hst=_V}', "");
Expect(0, 55239, '\p{Is_Hst=_V}', "");
Expect(1, 55239, '\p{^Is_Hst=_V}', "");
Expect(1, 55239, '\P{Is_Hst=_V}', "");
Expect(0, 55239, '\P{^Is_Hst=_V}', "");
Error('\p{Joining_Group=_-ain/a/}');
Error('\P{Joining_Group=_-ain/a/}');
Expect(1, 1887, '\p{Joining_Group=ain}', "");
Expect(0, 1887, '\p{^Joining_Group=ain}', "");
Expect(0, 1887, '\P{Joining_Group=ain}', "");
Expect(1, 1887, '\P{^Joining_Group=ain}', "");
Expect(0, 1888, '\p{Joining_Group=ain}', "");
Expect(1, 1888, '\p{^Joining_Group=ain}', "");
Expect(1, 1888, '\P{Joining_Group=ain}', "");
Expect(0, 1888, '\P{^Joining_Group=ain}', "");
Expect(1, 1887, '\p{Joining_Group:	-_AIN}', "");
Expect(0, 1887, '\p{^Joining_Group:	-_AIN}', "");
Expect(0, 1887, '\P{Joining_Group:	-_AIN}', "");
Expect(1, 1887, '\P{^Joining_Group:	-_AIN}', "");
Expect(0, 1888, '\p{Joining_Group:	-_AIN}', "");
Expect(1, 1888, '\p{^Joining_Group:	-_AIN}', "");
Expect(1, 1888, '\P{Joining_Group:	-_AIN}', "");
Expect(0, 1888, '\P{^Joining_Group:	-_AIN}', "");
Error('\p{Jg=:=		Ain}');
Error('\P{Jg=:=		Ain}');
Expect(1, 1887, '\p{Jg=ain}', "");
Expect(0, 1887, '\p{^Jg=ain}', "");
Expect(0, 1887, '\P{Jg=ain}', "");
Expect(1, 1887, '\P{^Jg=ain}', "");
Expect(0, 1888, '\p{Jg=ain}', "");
Expect(1, 1888, '\p{^Jg=ain}', "");
Expect(1, 1888, '\P{Jg=ain}', "");
Expect(0, 1888, '\P{^Jg=ain}', "");
Expect(1, 1887, '\p{Jg:_-AIN}', "");
Expect(0, 1887, '\p{^Jg:_-AIN}', "");
Expect(0, 1887, '\P{Jg:_-AIN}', "");
Expect(1, 1887, '\P{^Jg:_-AIN}', "");
Expect(0, 1888, '\p{Jg:_-AIN}', "");
Expect(1, 1888, '\p{^Jg:_-AIN}', "");
Expect(1, 1888, '\P{Jg:_-AIN}', "");
Expect(0, 1888, '\P{^Jg:_-AIN}', "");
Error('\p{Is_Joining_Group=	:=Ain}');
Error('\P{Is_Joining_Group=	:=Ain}');
Expect(1, 1887, '\p{Is_Joining_Group=ain}', "");
Expect(0, 1887, '\p{^Is_Joining_Group=ain}', "");
Expect(0, 1887, '\P{Is_Joining_Group=ain}', "");
Expect(1, 1887, '\P{^Is_Joining_Group=ain}', "");
Expect(0, 1888, '\p{Is_Joining_Group=ain}', "");
Expect(1, 1888, '\p{^Is_Joining_Group=ain}', "");
Expect(1, 1888, '\P{Is_Joining_Group=ain}', "");
Expect(0, 1888, '\P{^Is_Joining_Group=ain}', "");
Expect(1, 1887, '\p{Is_Joining_Group=	_ain}', "");
Expect(0, 1887, '\p{^Is_Joining_Group=	_ain}', "");
Expect(0, 1887, '\P{Is_Joining_Group=	_ain}', "");
Expect(1, 1887, '\P{^Is_Joining_Group=	_ain}', "");
Expect(0, 1888, '\p{Is_Joining_Group=	_ain}', "");
Expect(1, 1888, '\p{^Is_Joining_Group=	_ain}', "");
Expect(1, 1888, '\P{Is_Joining_Group=	_ain}', "");
Expect(0, 1888, '\P{^Is_Joining_Group=	_ain}', "");
Error('\p{Is_Jg::= -Ain}');
Error('\P{Is_Jg::= -Ain}');
Expect(1, 1887, '\p{Is_Jg=ain}', "");
Expect(0, 1887, '\p{^Is_Jg=ain}', "");
Expect(0, 1887, '\P{Is_Jg=ain}', "");
Expect(1, 1887, '\P{^Is_Jg=ain}', "");
Expect(0, 1888, '\p{Is_Jg=ain}', "");
Expect(1, 1888, '\p{^Is_Jg=ain}', "");
Expect(1, 1888, '\P{Is_Jg=ain}', "");
Expect(0, 1888, '\P{^Is_Jg=ain}', "");
Expect(1, 1887, '\p{Is_Jg:   	Ain}', "");
Expect(0, 1887, '\p{^Is_Jg:   	Ain}', "");
Expect(0, 1887, '\P{Is_Jg:   	Ain}', "");
Expect(1, 1887, '\P{^Is_Jg:   	Ain}', "");
Expect(0, 1888, '\p{Is_Jg:   	Ain}', "");
Expect(1, 1888, '\p{^Is_Jg:   	Ain}', "");
Expect(1, 1888, '\P{Is_Jg:   	Ain}', "");
Expect(0, 1888, '\P{^Is_Jg:   	Ain}', "");
Error('\p{Joining_Group:	_Alaph:=}');
Error('\P{Joining_Group:	_Alaph:=}');
Expect(1, 1808, '\p{Joining_Group=alaph}', "");
Expect(0, 1808, '\p{^Joining_Group=alaph}', "");
Expect(0, 1808, '\P{Joining_Group=alaph}', "");
Expect(1, 1808, '\P{^Joining_Group=alaph}', "");
Expect(0, 1809, '\p{Joining_Group=alaph}', "");
Expect(1, 1809, '\p{^Joining_Group=alaph}', "");
Expect(1, 1809, '\P{Joining_Group=alaph}', "");
Expect(0, 1809, '\P{^Joining_Group=alaph}', "");
Expect(1, 1808, '\p{Joining_Group=_ ALAPH}', "");
Expect(0, 1808, '\p{^Joining_Group=_ ALAPH}', "");
Expect(0, 1808, '\P{Joining_Group=_ ALAPH}', "");
Expect(1, 1808, '\P{^Joining_Group=_ ALAPH}', "");
Expect(0, 1809, '\p{Joining_Group=_ ALAPH}', "");
Expect(1, 1809, '\p{^Joining_Group=_ ALAPH}', "");
Expect(1, 1809, '\P{Joining_Group=_ ALAPH}', "");
Expect(0, 1809, '\P{^Joining_Group=_ ALAPH}', "");
Error('\p{Jg=ALAPH:=}');
Error('\P{Jg=ALAPH:=}');
Expect(1, 1808, '\p{Jg=alaph}', "");
Expect(0, 1808, '\p{^Jg=alaph}', "");
Expect(0, 1808, '\P{Jg=alaph}', "");
Expect(1, 1808, '\P{^Jg=alaph}', "");
Expect(0, 1809, '\p{Jg=alaph}', "");
Expect(1, 1809, '\p{^Jg=alaph}', "");
Expect(1, 1809, '\P{Jg=alaph}', "");
Expect(0, 1809, '\P{^Jg=alaph}', "");
Expect(1, 1808, '\p{Jg=-alaph}', "");
Expect(0, 1808, '\p{^Jg=-alaph}', "");
Expect(0, 1808, '\P{Jg=-alaph}', "");
Expect(1, 1808, '\P{^Jg=-alaph}', "");
Expect(0, 1809, '\p{Jg=-alaph}', "");
Expect(1, 1809, '\p{^Jg=-alaph}', "");
Expect(1, 1809, '\P{Jg=-alaph}', "");
Expect(0, 1809, '\P{^Jg=-alaph}', "");
Error('\p{Is_Joining_Group=-_Alaph:=}');
Error('\P{Is_Joining_Group=-_Alaph:=}');
Expect(1, 1808, '\p{Is_Joining_Group=alaph}', "");
Expect(0, 1808, '\p{^Is_Joining_Group=alaph}', "");
Expect(0, 1808, '\P{Is_Joining_Group=alaph}', "");
Expect(1, 1808, '\P{^Is_Joining_Group=alaph}', "");
Expect(0, 1809, '\p{Is_Joining_Group=alaph}', "");
Expect(1, 1809, '\p{^Is_Joining_Group=alaph}', "");
Expect(1, 1809, '\P{Is_Joining_Group=alaph}', "");
Expect(0, 1809, '\P{^Is_Joining_Group=alaph}', "");
Expect(1, 1808, '\p{Is_Joining_Group: 		ALAPH}', "");
Expect(0, 1808, '\p{^Is_Joining_Group: 		ALAPH}', "");
Expect(0, 1808, '\P{Is_Joining_Group: 		ALAPH}', "");
Expect(1, 1808, '\P{^Is_Joining_Group: 		ALAPH}', "");
Expect(0, 1809, '\p{Is_Joining_Group: 		ALAPH}', "");
Expect(1, 1809, '\p{^Is_Joining_Group: 		ALAPH}', "");
Expect(1, 1809, '\P{Is_Joining_Group: 		ALAPH}', "");
Expect(0, 1809, '\P{^Is_Joining_Group: 		ALAPH}', "");
Error('\p{Is_Jg=	Alaph:=}');
Error('\P{Is_Jg=	Alaph:=}');
Expect(1, 1808, '\p{Is_Jg=alaph}', "");
Expect(0, 1808, '\p{^Is_Jg=alaph}', "");
Expect(0, 1808, '\P{Is_Jg=alaph}', "");
Expect(1, 1808, '\P{^Is_Jg=alaph}', "");
Expect(0, 1809, '\p{Is_Jg=alaph}', "");
Expect(1, 1809, '\p{^Is_Jg=alaph}', "");
Expect(1, 1809, '\P{Is_Jg=alaph}', "");
Expect(0, 1809, '\P{^Is_Jg=alaph}', "");
Expect(1, 1808, '\p{Is_Jg=	_alaph}', "");
Expect(0, 1808, '\p{^Is_Jg=	_alaph}', "");
Expect(0, 1808, '\P{Is_Jg=	_alaph}', "");
Expect(1, 1808, '\P{^Is_Jg=	_alaph}', "");
Expect(0, 1809, '\p{Is_Jg=	_alaph}', "");
Expect(1, 1809, '\p{^Is_Jg=	_alaph}', "");
Expect(1, 1809, '\P{Is_Jg=	_alaph}', "");
Expect(0, 1809, '\P{^Is_Jg=	_alaph}', "");
Error('\p{Joining_Group= alef/a/}');
Error('\P{Joining_Group= alef/a/}');
Expect(1, 1908, '\p{Joining_Group=alef}', "");
Expect(0, 1908, '\p{^Joining_Group=alef}', "");
Expect(0, 1908, '\P{Joining_Group=alef}', "");
Expect(1, 1908, '\P{^Joining_Group=alef}', "");
Expect(0, 1909, '\p{Joining_Group=alef}', "");
Expect(1, 1909, '\p{^Joining_Group=alef}', "");
Expect(1, 1909, '\P{Joining_Group=alef}', "");
Expect(0, 1909, '\P{^Joining_Group=alef}', "");
Expect(1, 1908, '\p{Joining_Group= -Alef}', "");
Expect(0, 1908, '\p{^Joining_Group= -Alef}', "");
Expect(0, 1908, '\P{Joining_Group= -Alef}', "");
Expect(1, 1908, '\P{^Joining_Group= -Alef}', "");
Expect(0, 1909, '\p{Joining_Group= -Alef}', "");
Expect(1, 1909, '\p{^Joining_Group= -Alef}', "");
Expect(1, 1909, '\P{Joining_Group= -Alef}', "");
Expect(0, 1909, '\P{^Joining_Group= -Alef}', "");
Error('\p{Jg:	_-Alef:=}');
Error('\P{Jg:	_-Alef:=}');
Expect(1, 1908, '\p{Jg=alef}', "");
Expect(0, 1908, '\p{^Jg=alef}', "");
Expect(0, 1908, '\P{Jg=alef}', "");
Expect(1, 1908, '\P{^Jg=alef}', "");
Expect(0, 1909, '\p{Jg=alef}', "");
Expect(1, 1909, '\p{^Jg=alef}', "");
Expect(1, 1909, '\P{Jg=alef}', "");
Expect(0, 1909, '\P{^Jg=alef}', "");
Expect(1, 1908, '\p{Jg= alef}', "");
Expect(0, 1908, '\p{^Jg= alef}', "");
Expect(0, 1908, '\P{Jg= alef}', "");
Expect(1, 1908, '\P{^Jg= alef}', "");
Expect(0, 1909, '\p{Jg= alef}', "");
Expect(1, 1909, '\p{^Jg= alef}', "");
Expect(1, 1909, '\P{Jg= alef}', "");
Expect(0, 1909, '\P{^Jg= alef}', "");
Error('\p{Is_Joining_Group= /a/Alef}');
Error('\P{Is_Joining_Group= /a/Alef}');
Expect(1, 1908, '\p{Is_Joining_Group:	alef}', "");
Expect(0, 1908, '\p{^Is_Joining_Group:	alef}', "");
Expect(0, 1908, '\P{Is_Joining_Group:	alef}', "");
Expect(1, 1908, '\P{^Is_Joining_Group:	alef}', "");
Expect(0, 1909, '\p{Is_Joining_Group:	alef}', "");
Expect(1, 1909, '\p{^Is_Joining_Group:	alef}', "");
Expect(1, 1909, '\P{Is_Joining_Group:	alef}', "");
Expect(0, 1909, '\P{^Is_Joining_Group:	alef}', "");
Expect(1, 1908, '\p{Is_Joining_Group=	Alef}', "");
Expect(0, 1908, '\p{^Is_Joining_Group=	Alef}', "");
Expect(0, 1908, '\P{Is_Joining_Group=	Alef}', "");
Expect(1, 1908, '\P{^Is_Joining_Group=	Alef}', "");
Expect(0, 1909, '\p{Is_Joining_Group=	Alef}', "");
Expect(1, 1909, '\p{^Is_Joining_Group=	Alef}', "");
Expect(1, 1909, '\P{Is_Joining_Group=	Alef}', "");
Expect(0, 1909, '\P{^Is_Joining_Group=	Alef}', "");
Error('\p{Is_Jg:	/a/	 alef}');
Error('\P{Is_Jg:	/a/	 alef}');
Expect(1, 1908, '\p{Is_Jg=alef}', "");
Expect(0, 1908, '\p{^Is_Jg=alef}', "");
Expect(0, 1908, '\P{Is_Jg=alef}', "");
Expect(1, 1908, '\P{^Is_Jg=alef}', "");
Expect(0, 1909, '\p{Is_Jg=alef}', "");
Expect(1, 1909, '\p{^Is_Jg=alef}', "");
Expect(1, 1909, '\P{Is_Jg=alef}', "");
Expect(0, 1909, '\P{^Is_Jg=alef}', "");
Expect(1, 1908, '\p{Is_Jg=		alef}', "");
Expect(0, 1908, '\p{^Is_Jg=		alef}', "");
Expect(0, 1908, '\P{Is_Jg=		alef}', "");
Expect(1, 1908, '\P{^Is_Jg=		alef}', "");
Expect(0, 1909, '\p{Is_Jg=		alef}', "");
Expect(1, 1909, '\p{^Is_Jg=		alef}', "");
Expect(1, 1909, '\P{Is_Jg=		alef}', "");
Expect(0, 1909, '\P{^Is_Jg=		alef}', "");
Error('\p{Joining_Group:   /a/ Beh}');
Error('\P{Joining_Group:   /a/ Beh}');
Expect(1, 2208, '\p{Joining_Group=beh}', "");
Expect(0, 2208, '\p{^Joining_Group=beh}', "");
Expect(0, 2208, '\P{Joining_Group=beh}', "");
Expect(1, 2208, '\P{^Joining_Group=beh}', "");
Expect(0, 2209, '\p{Joining_Group=beh}', "");
Expect(1, 2209, '\p{^Joining_Group=beh}', "");
Expect(1, 2209, '\P{Joining_Group=beh}', "");
Expect(0, 2209, '\P{^Joining_Group=beh}', "");
Expect(1, 2208, '\p{Joining_Group= Beh}', "");
Expect(0, 2208, '\p{^Joining_Group= Beh}', "");
Expect(0, 2208, '\P{Joining_Group= Beh}', "");
Expect(1, 2208, '\P{^Joining_Group= Beh}', "");
Expect(0, 2209, '\p{Joining_Group= Beh}', "");
Expect(1, 2209, '\p{^Joining_Group= Beh}', "");
Expect(1, 2209, '\P{Joining_Group= Beh}', "");
Expect(0, 2209, '\P{^Joining_Group= Beh}', "");
Error('\p{Jg=:=	-Beh}');
Error('\P{Jg=:=	-Beh}');
Expect(1, 2208, '\p{Jg=beh}', "");
Expect(0, 2208, '\p{^Jg=beh}', "");
Expect(0, 2208, '\P{Jg=beh}', "");
Expect(1, 2208, '\P{^Jg=beh}', "");
Expect(0, 2209, '\p{Jg=beh}', "");
Expect(1, 2209, '\p{^Jg=beh}', "");
Expect(1, 2209, '\P{Jg=beh}', "");
Expect(0, 2209, '\P{^Jg=beh}', "");
Expect(1, 2208, '\p{Jg=_BEH}', "");
Expect(0, 2208, '\p{^Jg=_BEH}', "");
Expect(0, 2208, '\P{Jg=_BEH}', "");
Expect(1, 2208, '\P{^Jg=_BEH}', "");
Expect(0, 2209, '\p{Jg=_BEH}', "");
Expect(1, 2209, '\p{^Jg=_BEH}', "");
Expect(1, 2209, '\P{Jg=_BEH}', "");
Expect(0, 2209, '\P{^Jg=_BEH}', "");
Error('\p{Is_Joining_Group=/a/ Beh}');
Error('\P{Is_Joining_Group=/a/ Beh}');
Expect(1, 2208, '\p{Is_Joining_Group=beh}', "");
Expect(0, 2208, '\p{^Is_Joining_Group=beh}', "");
Expect(0, 2208, '\P{Is_Joining_Group=beh}', "");
Expect(1, 2208, '\P{^Is_Joining_Group=beh}', "");
Expect(0, 2209, '\p{Is_Joining_Group=beh}', "");
Expect(1, 2209, '\p{^Is_Joining_Group=beh}', "");
Expect(1, 2209, '\P{Is_Joining_Group=beh}', "");
Expect(0, 2209, '\P{^Is_Joining_Group=beh}', "");
Expect(1, 2208, '\p{Is_Joining_Group=  Beh}', "");
Expect(0, 2208, '\p{^Is_Joining_Group=  Beh}', "");
Expect(0, 2208, '\P{Is_Joining_Group=  Beh}', "");
Expect(1, 2208, '\P{^Is_Joining_Group=  Beh}', "");
Expect(0, 2209, '\p{Is_Joining_Group=  Beh}', "");
Expect(1, 2209, '\p{^Is_Joining_Group=  Beh}', "");
Expect(1, 2209, '\P{Is_Joining_Group=  Beh}', "");
Expect(0, 2209, '\P{^Is_Joining_Group=  Beh}', "");
Error('\p{Is_Jg=	beh:=}');
Error('\P{Is_Jg=	beh:=}');
Expect(1, 2208, '\p{Is_Jg=beh}', "");
Expect(0, 2208, '\p{^Is_Jg=beh}', "");
Expect(0, 2208, '\P{Is_Jg=beh}', "");
Expect(1, 2208, '\P{^Is_Jg=beh}', "");
Expect(0, 2209, '\p{Is_Jg=beh}', "");
Expect(1, 2209, '\p{^Is_Jg=beh}', "");
Expect(1, 2209, '\P{Is_Jg=beh}', "");
Expect(0, 2209, '\P{^Is_Jg=beh}', "");
Expect(1, 2208, '\p{Is_Jg=_-beh}', "");
Expect(0, 2208, '\p{^Is_Jg=_-beh}', "");
Expect(0, 2208, '\P{Is_Jg=_-beh}', "");
Expect(1, 2208, '\P{^Is_Jg=_-beh}', "");
Expect(0, 2209, '\p{Is_Jg=_-beh}', "");
Expect(1, 2209, '\p{^Is_Jg=_-beh}', "");
Expect(1, 2209, '\P{Is_Jg=_-beh}', "");
Expect(0, 2209, '\P{^Is_Jg=_-beh}', "");
Error('\p{Joining_Group:   :=-Beth}');
Error('\P{Joining_Group:   :=-Beth}');
Expect(1, 1837, '\p{Joining_Group=beth}', "");
Expect(0, 1837, '\p{^Joining_Group=beth}', "");
Expect(0, 1837, '\P{Joining_Group=beth}', "");
Expect(1, 1837, '\P{^Joining_Group=beth}', "");
Expect(0, 1838, '\p{Joining_Group=beth}', "");
Expect(1, 1838, '\p{^Joining_Group=beth}', "");
Expect(1, 1838, '\P{Joining_Group=beth}', "");
Expect(0, 1838, '\P{^Joining_Group=beth}', "");
Expect(1, 1837, '\p{Joining_Group:	 Beth}', "");
Expect(0, 1837, '\p{^Joining_Group:	 Beth}', "");
Expect(0, 1837, '\P{Joining_Group:	 Beth}', "");
Expect(1, 1837, '\P{^Joining_Group:	 Beth}', "");
Expect(0, 1838, '\p{Joining_Group:	 Beth}', "");
Expect(1, 1838, '\p{^Joining_Group:	 Beth}', "");
Expect(1, 1838, '\P{Joining_Group:	 Beth}', "");
Expect(0, 1838, '\P{^Joining_Group:	 Beth}', "");
Error('\p{Jg: :=Beth}');
Error('\P{Jg: :=Beth}');
Expect(1, 1837, '\p{Jg=beth}', "");
Expect(0, 1837, '\p{^Jg=beth}', "");
Expect(0, 1837, '\P{Jg=beth}', "");
Expect(1, 1837, '\P{^Jg=beth}', "");
Expect(0, 1838, '\p{Jg=beth}', "");
Expect(1, 1838, '\p{^Jg=beth}', "");
Expect(1, 1838, '\P{Jg=beth}', "");
Expect(0, 1838, '\P{^Jg=beth}', "");
Expect(1, 1837, '\p{Jg= 	Beth}', "");
Expect(0, 1837, '\p{^Jg= 	Beth}', "");
Expect(0, 1837, '\P{Jg= 	Beth}', "");
Expect(1, 1837, '\P{^Jg= 	Beth}', "");
Expect(0, 1838, '\p{Jg= 	Beth}', "");
Expect(1, 1838, '\p{^Jg= 	Beth}', "");
Expect(1, 1838, '\P{Jg= 	Beth}', "");
Expect(0, 1838, '\P{^Jg= 	Beth}', "");
Error('\p{Is_Joining_Group=/a/beth}');
Error('\P{Is_Joining_Group=/a/beth}');
Expect(1, 1837, '\p{Is_Joining_Group=beth}', "");
Expect(0, 1837, '\p{^Is_Joining_Group=beth}', "");
Expect(0, 1837, '\P{Is_Joining_Group=beth}', "");
Expect(1, 1837, '\P{^Is_Joining_Group=beth}', "");
Expect(0, 1838, '\p{Is_Joining_Group=beth}', "");
Expect(1, 1838, '\p{^Is_Joining_Group=beth}', "");
Expect(1, 1838, '\P{Is_Joining_Group=beth}', "");
Expect(0, 1838, '\P{^Is_Joining_Group=beth}', "");
Expect(1, 1837, '\p{Is_Joining_Group:   _	Beth}', "");
Expect(0, 1837, '\p{^Is_Joining_Group:   _	Beth}', "");
Expect(0, 1837, '\P{Is_Joining_Group:   _	Beth}', "");
Expect(1, 1837, '\P{^Is_Joining_Group:   _	Beth}', "");
Expect(0, 1838, '\p{Is_Joining_Group:   _	Beth}', "");
Expect(1, 1838, '\p{^Is_Joining_Group:   _	Beth}', "");
Expect(1, 1838, '\P{Is_Joining_Group:   _	Beth}', "");
Expect(0, 1838, '\P{^Is_Joining_Group:   _	Beth}', "");
Error('\p{Is_Jg=_:=Beth}');
Error('\P{Is_Jg=_:=Beth}');
Expect(1, 1837, '\p{Is_Jg=beth}', "");
Expect(0, 1837, '\p{^Is_Jg=beth}', "");
Expect(0, 1837, '\P{Is_Jg=beth}', "");
Expect(1, 1837, '\P{^Is_Jg=beth}', "");
Expect(0, 1838, '\p{Is_Jg=beth}', "");
Expect(1, 1838, '\p{^Is_Jg=beth}', "");
Expect(1, 1838, '\P{Is_Jg=beth}', "");
Expect(0, 1838, '\P{^Is_Jg=beth}', "");
Expect(1, 1837, '\p{Is_Jg=--BETH}', "");
Expect(0, 1837, '\p{^Is_Jg=--BETH}', "");
Expect(0, 1837, '\P{Is_Jg=--BETH}', "");
Expect(1, 1837, '\P{^Is_Jg=--BETH}', "");
Expect(0, 1838, '\p{Is_Jg=--BETH}', "");
Expect(1, 1838, '\p{^Is_Jg=--BETH}', "");
Expect(1, 1838, '\P{Is_Jg=--BETH}', "");
Expect(0, 1838, '\P{^Is_Jg=--BETH}', "");
Error('\p{Joining_Group=_	burushaski_Yeh_Barree:=}');
Error('\P{Joining_Group=_	burushaski_Yeh_Barree:=}');
Expect(1, 1915, '\p{Joining_Group=burushaskiyehbarree}', "");
Expect(0, 1915, '\p{^Joining_Group=burushaskiyehbarree}', "");
Expect(0, 1915, '\P{Joining_Group=burushaskiyehbarree}', "");
Expect(1, 1915, '\P{^Joining_Group=burushaskiyehbarree}', "");
Expect(0, 1916, '\p{Joining_Group=burushaskiyehbarree}', "");
Expect(1, 1916, '\p{^Joining_Group=burushaskiyehbarree}', "");
Expect(1, 1916, '\P{Joining_Group=burushaskiyehbarree}', "");
Expect(0, 1916, '\P{^Joining_Group=burushaskiyehbarree}', "");
Expect(1, 1915, '\p{Joining_Group=-	burushaski_yeh_BARREE}', "");
Expect(0, 1915, '\p{^Joining_Group=-	burushaski_yeh_BARREE}', "");
Expect(0, 1915, '\P{Joining_Group=-	burushaski_yeh_BARREE}', "");
Expect(1, 1915, '\P{^Joining_Group=-	burushaski_yeh_BARREE}', "");
Expect(0, 1916, '\p{Joining_Group=-	burushaski_yeh_BARREE}', "");
Expect(1, 1916, '\p{^Joining_Group=-	burushaski_yeh_BARREE}', "");
Expect(1, 1916, '\P{Joining_Group=-	burushaski_yeh_BARREE}', "");
Expect(0, 1916, '\P{^Joining_Group=-	burushaski_yeh_BARREE}', "");
Error('\p{Jg=_:=burushaski_Yeh_barree}');
Error('\P{Jg=_:=burushaski_Yeh_barree}');
Expect(1, 1915, '\p{Jg=burushaskiyehbarree}', "");
Expect(0, 1915, '\p{^Jg=burushaskiyehbarree}', "");
Expect(0, 1915, '\P{Jg=burushaskiyehbarree}', "");
Expect(1, 1915, '\P{^Jg=burushaskiyehbarree}', "");
Expect(0, 1916, '\p{Jg=burushaskiyehbarree}', "");
Expect(1, 1916, '\p{^Jg=burushaskiyehbarree}', "");
Expect(1, 1916, '\P{Jg=burushaskiyehbarree}', "");
Expect(0, 1916, '\P{^Jg=burushaskiyehbarree}', "");
Expect(1, 1915, '\p{Jg=  BURUSHASKI_Yeh_Barree}', "");
Expect(0, 1915, '\p{^Jg=  BURUSHASKI_Yeh_Barree}', "");
Expect(0, 1915, '\P{Jg=  BURUSHASKI_Yeh_Barree}', "");
Expect(1, 1915, '\P{^Jg=  BURUSHASKI_Yeh_Barree}', "");
Expect(0, 1916, '\p{Jg=  BURUSHASKI_Yeh_Barree}', "");
Expect(1, 1916, '\p{^Jg=  BURUSHASKI_Yeh_Barree}', "");
Expect(1, 1916, '\P{Jg=  BURUSHASKI_Yeh_Barree}', "");
Expect(0, 1916, '\P{^Jg=  BURUSHASKI_Yeh_Barree}', "");
Error('\p{Is_Joining_Group=:=  Burushaski_yeh_Barree}');
Error('\P{Is_Joining_Group=:=  Burushaski_yeh_Barree}');
Expect(1, 1915, '\p{Is_Joining_Group=burushaskiyehbarree}', "");
Expect(0, 1915, '\p{^Is_Joining_Group=burushaskiyehbarree}', "");
Expect(0, 1915, '\P{Is_Joining_Group=burushaskiyehbarree}', "");
Expect(1, 1915, '\P{^Is_Joining_Group=burushaskiyehbarree}', "");
Expect(0, 1916, '\p{Is_Joining_Group=burushaskiyehbarree}', "");
Expect(1, 1916, '\p{^Is_Joining_Group=burushaskiyehbarree}', "");
Expect(1, 1916, '\P{Is_Joining_Group=burushaskiyehbarree}', "");
Expect(0, 1916, '\P{^Is_Joining_Group=burushaskiyehbarree}', "");
Expect(1, 1915, '\p{Is_Joining_Group=	BURUSHASKI_Yeh_barree}', "");
Expect(0, 1915, '\p{^Is_Joining_Group=	BURUSHASKI_Yeh_barree}', "");
Expect(0, 1915, '\P{Is_Joining_Group=	BURUSHASKI_Yeh_barree}', "");
Expect(1, 1915, '\P{^Is_Joining_Group=	BURUSHASKI_Yeh_barree}', "");
Expect(0, 1916, '\p{Is_Joining_Group=	BURUSHASKI_Yeh_barree}', "");
Expect(1, 1916, '\p{^Is_Joining_Group=	BURUSHASKI_Yeh_barree}', "");
Expect(1, 1916, '\P{Is_Joining_Group=	BURUSHASKI_Yeh_barree}', "");
Expect(0, 1916, '\P{^Is_Joining_Group=	BURUSHASKI_Yeh_barree}', "");
Error('\p{Is_Jg=/a/-Burushaski_yeh_Barree}');
Error('\P{Is_Jg=/a/-Burushaski_yeh_Barree}');
Expect(1, 1915, '\p{Is_Jg=burushaskiyehbarree}', "");
Expect(0, 1915, '\p{^Is_Jg=burushaskiyehbarree}', "");
Expect(0, 1915, '\P{Is_Jg=burushaskiyehbarree}', "");
Expect(1, 1915, '\P{^Is_Jg=burushaskiyehbarree}', "");
Expect(0, 1916, '\p{Is_Jg=burushaskiyehbarree}', "");
Expect(1, 1916, '\p{^Is_Jg=burushaskiyehbarree}', "");
Expect(1, 1916, '\P{Is_Jg=burushaskiyehbarree}', "");
Expect(0, 1916, '\P{^Is_Jg=burushaskiyehbarree}', "");
Expect(1, 1915, '\p{Is_Jg:    	burushaski_Yeh_barree}', "");
Expect(0, 1915, '\p{^Is_Jg:    	burushaski_Yeh_barree}', "");
Expect(0, 1915, '\P{Is_Jg:    	burushaski_Yeh_barree}', "");
Expect(1, 1915, '\P{^Is_Jg:    	burushaski_Yeh_barree}', "");
Expect(0, 1916, '\p{Is_Jg:    	burushaski_Yeh_barree}', "");
Expect(1, 1916, '\p{^Is_Jg:    	burushaski_Yeh_barree}', "");
Expect(1, 1916, '\P{Is_Jg:    	burushaski_Yeh_barree}', "");
Expect(0, 1916, '\P{^Is_Jg:    	burushaski_Yeh_barree}', "");
Error('\p{Joining_Group=	:=dal}');
Error('\P{Joining_Group=	:=dal}');
Expect(1, 1882, '\p{Joining_Group=dal}', "");
Expect(0, 1882, '\p{^Joining_Group=dal}', "");
Expect(0, 1882, '\P{Joining_Group=dal}', "");
Expect(1, 1882, '\P{^Joining_Group=dal}', "");
Expect(0, 1883, '\p{Joining_Group=dal}', "");
Expect(1, 1883, '\p{^Joining_Group=dal}', "");
Expect(1, 1883, '\P{Joining_Group=dal}', "");
Expect(0, 1883, '\P{^Joining_Group=dal}', "");
Expect(1, 1882, '\p{Joining_Group=	-dal}', "");
Expect(0, 1882, '\p{^Joining_Group=	-dal}', "");
Expect(0, 1882, '\P{Joining_Group=	-dal}', "");
Expect(1, 1882, '\P{^Joining_Group=	-dal}', "");
Expect(0, 1883, '\p{Joining_Group=	-dal}', "");
Expect(1, 1883, '\p{^Joining_Group=	-dal}', "");
Expect(1, 1883, '\P{Joining_Group=	-dal}', "");
Expect(0, 1883, '\P{^Joining_Group=	-dal}', "");
Error('\p{Jg=-:=Dal}');
Error('\P{Jg=-:=Dal}');
Expect(1, 1882, '\p{Jg=dal}', "");
Expect(0, 1882, '\p{^Jg=dal}', "");
Expect(0, 1882, '\P{Jg=dal}', "");
Expect(1, 1882, '\P{^Jg=dal}', "");
Expect(0, 1883, '\p{Jg=dal}', "");
Expect(1, 1883, '\p{^Jg=dal}', "");
Expect(1, 1883, '\P{Jg=dal}', "");
Expect(0, 1883, '\P{^Jg=dal}', "");
Expect(1, 1882, '\p{Jg=-	dal}', "");
Expect(0, 1882, '\p{^Jg=-	dal}', "");
Expect(0, 1882, '\P{Jg=-	dal}', "");
Expect(1, 1882, '\P{^Jg=-	dal}', "");
Expect(0, 1883, '\p{Jg=-	dal}', "");
Expect(1, 1883, '\p{^Jg=-	dal}', "");
Expect(1, 1883, '\P{Jg=-	dal}', "");
Expect(0, 1883, '\P{^Jg=-	dal}', "");
Error('\p{Is_Joining_Group=-DAL:=}');
Error('\P{Is_Joining_Group=-DAL:=}');
Expect(1, 1882, '\p{Is_Joining_Group=dal}', "");
Expect(0, 1882, '\p{^Is_Joining_Group=dal}', "");
Expect(0, 1882, '\P{Is_Joining_Group=dal}', "");
Expect(1, 1882, '\P{^Is_Joining_Group=dal}', "");
Expect(0, 1883, '\p{Is_Joining_Group=dal}', "");
Expect(1, 1883, '\p{^Is_Joining_Group=dal}', "");
Expect(1, 1883, '\P{Is_Joining_Group=dal}', "");
Expect(0, 1883, '\P{^Is_Joining_Group=dal}', "");
Expect(1, 1882, '\p{Is_Joining_Group=- DAL}', "");
Expect(0, 1882, '\p{^Is_Joining_Group=- DAL}', "");
Expect(0, 1882, '\P{Is_Joining_Group=- DAL}', "");
Expect(1, 1882, '\P{^Is_Joining_Group=- DAL}', "");
Expect(0, 1883, '\p{Is_Joining_Group=- DAL}', "");
Expect(1, 1883, '\p{^Is_Joining_Group=- DAL}', "");
Expect(1, 1883, '\P{Is_Joining_Group=- DAL}', "");
Expect(0, 1883, '\P{^Is_Joining_Group=- DAL}', "");
Error('\p{Is_Jg=  DAL:=}');
Error('\P{Is_Jg=  DAL:=}');
Expect(1, 1882, '\p{Is_Jg=dal}', "");
Expect(0, 1882, '\p{^Is_Jg=dal}', "");
Expect(0, 1882, '\P{Is_Jg=dal}', "");
Expect(1, 1882, '\P{^Is_Jg=dal}', "");
Expect(0, 1883, '\p{Is_Jg=dal}', "");
Expect(1, 1883, '\p{^Is_Jg=dal}', "");
Expect(1, 1883, '\P{Is_Jg=dal}', "");
Expect(0, 1883, '\P{^Is_Jg=dal}', "");
Expect(1, 1882, '\p{Is_Jg=		DAL}', "");
Expect(0, 1882, '\p{^Is_Jg=		DAL}', "");
Expect(0, 1882, '\P{Is_Jg=		DAL}', "");
Expect(1, 1882, '\P{^Is_Jg=		DAL}', "");
Expect(0, 1883, '\p{Is_Jg=		DAL}', "");
Expect(1, 1883, '\p{^Is_Jg=		DAL}', "");
Expect(1, 1883, '\P{Is_Jg=		DAL}', "");
Expect(0, 1883, '\P{^Is_Jg=		DAL}', "");
Error('\p{Joining_Group: /a/_-Dalath_Rish}');
Error('\P{Joining_Group: /a/_-Dalath_Rish}');
Expect(1, 1839, '\p{Joining_Group=dalathrish}', "");
Expect(0, 1839, '\p{^Joining_Group=dalathrish}', "");
Expect(0, 1839, '\P{Joining_Group=dalathrish}', "");
Expect(1, 1839, '\P{^Joining_Group=dalathrish}', "");
Expect(0, 1840, '\p{Joining_Group=dalathrish}', "");
Expect(1, 1840, '\p{^Joining_Group=dalathrish}', "");
Expect(1, 1840, '\P{Joining_Group=dalathrish}', "");
Expect(0, 1840, '\P{^Joining_Group=dalathrish}', "");
Expect(1, 1839, '\p{Joining_Group=-_dalath_rish}', "");
Expect(0, 1839, '\p{^Joining_Group=-_dalath_rish}', "");
Expect(0, 1839, '\P{Joining_Group=-_dalath_rish}', "");
Expect(1, 1839, '\P{^Joining_Group=-_dalath_rish}', "");
Expect(0, 1840, '\p{Joining_Group=-_dalath_rish}', "");
Expect(1, 1840, '\p{^Joining_Group=-_dalath_rish}', "");
Expect(1, 1840, '\P{Joining_Group=-_dalath_rish}', "");
Expect(0, 1840, '\P{^Joining_Group=-_dalath_rish}', "");
Error('\p{Jg=_/a/Dalath_RISH}');
Error('\P{Jg=_/a/Dalath_RISH}');
Expect(1, 1839, '\p{Jg=dalathrish}', "");
Expect(0, 1839, '\p{^Jg=dalathrish}', "");
Expect(0, 1839, '\P{Jg=dalathrish}', "");
Expect(1, 1839, '\P{^Jg=dalathrish}', "");
Expect(0, 1840, '\p{Jg=dalathrish}', "");
Expect(1, 1840, '\p{^Jg=dalathrish}', "");
Expect(1, 1840, '\P{Jg=dalathrish}', "");
Expect(0, 1840, '\P{^Jg=dalathrish}', "");
Expect(1, 1839, '\p{Jg=_	dalath_rish}', "");
Expect(0, 1839, '\p{^Jg=_	dalath_rish}', "");
Expect(0, 1839, '\P{Jg=_	dalath_rish}', "");
Expect(1, 1839, '\P{^Jg=_	dalath_rish}', "");
Expect(0, 1840, '\p{Jg=_	dalath_rish}', "");
Expect(1, 1840, '\p{^Jg=_	dalath_rish}', "");
Expect(1, 1840, '\P{Jg=_	dalath_rish}', "");
Expect(0, 1840, '\P{^Jg=_	dalath_rish}', "");
Error('\p{Is_Joining_Group=:=--DALATH_rish}');
Error('\P{Is_Joining_Group=:=--DALATH_rish}');
Expect(1, 1839, '\p{Is_Joining_Group=dalathrish}', "");
Expect(0, 1839, '\p{^Is_Joining_Group=dalathrish}', "");
Expect(0, 1839, '\P{Is_Joining_Group=dalathrish}', "");
Expect(1, 1839, '\P{^Is_Joining_Group=dalathrish}', "");
Expect(0, 1840, '\p{Is_Joining_Group=dalathrish}', "");
Expect(1, 1840, '\p{^Is_Joining_Group=dalathrish}', "");
Expect(1, 1840, '\P{Is_Joining_Group=dalathrish}', "");
Expect(0, 1840, '\P{^Is_Joining_Group=dalathrish}', "");
Expect(1, 1839, '\p{Is_Joining_Group= 	DALATH_Rish}', "");
Expect(0, 1839, '\p{^Is_Joining_Group= 	DALATH_Rish}', "");
Expect(0, 1839, '\P{Is_Joining_Group= 	DALATH_Rish}', "");
Expect(1, 1839, '\P{^Is_Joining_Group= 	DALATH_Rish}', "");
Expect(0, 1840, '\p{Is_Joining_Group= 	DALATH_Rish}', "");
Expect(1, 1840, '\p{^Is_Joining_Group= 	DALATH_Rish}', "");
Expect(1, 1840, '\P{Is_Joining_Group= 	DALATH_Rish}', "");
Expect(0, 1840, '\P{^Is_Joining_Group= 	DALATH_Rish}', "");
Error('\p{Is_Jg=-:=Dalath_Rish}');
Error('\P{Is_Jg=-:=Dalath_Rish}');
Expect(1, 1839, '\p{Is_Jg: dalathrish}', "");
Expect(0, 1839, '\p{^Is_Jg: dalathrish}', "");
Expect(0, 1839, '\P{Is_Jg: dalathrish}', "");
Expect(1, 1839, '\P{^Is_Jg: dalathrish}', "");
Expect(0, 1840, '\p{Is_Jg: dalathrish}', "");
Expect(1, 1840, '\p{^Is_Jg: dalathrish}', "");
Expect(1, 1840, '\P{Is_Jg: dalathrish}', "");
Expect(0, 1840, '\P{^Is_Jg: dalathrish}', "");
Expect(1, 1839, '\p{Is_Jg=-_DALATH_rish}', "");
Expect(0, 1839, '\p{^Is_Jg=-_DALATH_rish}', "");
Expect(0, 1839, '\P{Is_Jg=-_DALATH_rish}', "");
Expect(1, 1839, '\P{^Is_Jg=-_DALATH_rish}', "");
Expect(0, 1840, '\p{Is_Jg=-_DALATH_rish}', "");
Expect(1, 1840, '\p{^Is_Jg=-_DALATH_rish}', "");
Expect(1, 1840, '\P{Is_Jg=-_DALATH_rish}', "");
Expect(0, 1840, '\P{^Is_Jg=-_DALATH_rish}', "");
Error('\p{Joining_Group=	-E/a/}');
Error('\P{Joining_Group=	-E/a/}');
Expect(1, 1829, '\p{Joining_Group=e}', "");
Expect(0, 1829, '\p{^Joining_Group=e}', "");
Expect(0, 1829, '\P{Joining_Group=e}', "");
Expect(1, 1829, '\P{^Joining_Group=e}', "");
Expect(0, 1830, '\p{Joining_Group=e}', "");
Expect(1, 1830, '\p{^Joining_Group=e}', "");
Expect(1, 1830, '\P{Joining_Group=e}', "");
Expect(0, 1830, '\P{^Joining_Group=e}', "");
Expect(1, 1829, '\p{Joining_Group=		E}', "");
Expect(0, 1829, '\p{^Joining_Group=		E}', "");
Expect(0, 1829, '\P{Joining_Group=		E}', "");
Expect(1, 1829, '\P{^Joining_Group=		E}', "");
Expect(0, 1830, '\p{Joining_Group=		E}', "");
Expect(1, 1830, '\p{^Joining_Group=		E}', "");
Expect(1, 1830, '\P{Joining_Group=		E}', "");
Expect(0, 1830, '\P{^Joining_Group=		E}', "");
Error('\p{Jg=_ E:=}');
Error('\P{Jg=_ E:=}');
Expect(1, 1829, '\p{Jg=e}', "");
Expect(0, 1829, '\p{^Jg=e}', "");
Expect(0, 1829, '\P{Jg=e}', "");
Expect(1, 1829, '\P{^Jg=e}', "");
Expect(0, 1830, '\p{Jg=e}', "");
Expect(1, 1830, '\p{^Jg=e}', "");
Expect(1, 1830, '\P{Jg=e}', "");
Expect(0, 1830, '\P{^Jg=e}', "");
Expect(1, 1829, '\p{Jg= _E}', "");
Expect(0, 1829, '\p{^Jg= _E}', "");
Expect(0, 1829, '\P{Jg= _E}', "");
Expect(1, 1829, '\P{^Jg= _E}', "");
Expect(0, 1830, '\p{Jg= _E}', "");
Expect(1, 1830, '\p{^Jg= _E}', "");
Expect(1, 1830, '\P{Jg= _E}', "");
Expect(0, 1830, '\P{^Jg= _E}', "");
Error('\p{Is_Joining_Group=/a/	E}');
Error('\P{Is_Joining_Group=/a/	E}');
Expect(1, 1829, '\p{Is_Joining_Group=e}', "");
Expect(0, 1829, '\p{^Is_Joining_Group=e}', "");
Expect(0, 1829, '\P{Is_Joining_Group=e}', "");
Expect(1, 1829, '\P{^Is_Joining_Group=e}', "");
Expect(0, 1830, '\p{Is_Joining_Group=e}', "");
Expect(1, 1830, '\p{^Is_Joining_Group=e}', "");
Expect(1, 1830, '\P{Is_Joining_Group=e}', "");
Expect(0, 1830, '\P{^Is_Joining_Group=e}', "");
Expect(1, 1829, '\p{Is_Joining_Group=		e}', "");
Expect(0, 1829, '\p{^Is_Joining_Group=		e}', "");
Expect(0, 1829, '\P{Is_Joining_Group=		e}', "");
Expect(1, 1829, '\P{^Is_Joining_Group=		e}', "");
Expect(0, 1830, '\p{Is_Joining_Group=		e}', "");
Expect(1, 1830, '\p{^Is_Joining_Group=		e}', "");
Expect(1, 1830, '\P{Is_Joining_Group=		e}', "");
Expect(0, 1830, '\P{^Is_Joining_Group=		e}', "");
Error('\p{Is_Jg=:=		E}');
Error('\P{Is_Jg=:=		E}');
Expect(1, 1829, '\p{Is_Jg:   e}', "");
Expect(0, 1829, '\p{^Is_Jg:   e}', "");
Expect(0, 1829, '\P{Is_Jg:   e}', "");
Expect(1, 1829, '\P{^Is_Jg:   e}', "");
Expect(0, 1830, '\p{Is_Jg:   e}', "");
Expect(1, 1830, '\p{^Is_Jg:   e}', "");
Expect(1, 1830, '\P{Is_Jg:   e}', "");
Expect(0, 1830, '\P{^Is_Jg:   e}', "");
Expect(1, 1829, '\p{Is_Jg= E}', "");
Expect(0, 1829, '\p{^Is_Jg= E}', "");
Expect(0, 1829, '\P{Is_Jg= E}', "");
Expect(1, 1829, '\P{^Is_Jg= E}', "");
Expect(0, 1830, '\p{Is_Jg= E}', "");
Expect(1, 1830, '\p{^Is_Jg= E}', "");
Expect(1, 1830, '\P{Is_Jg= E}', "");
Expect(0, 1830, '\P{^Is_Jg= E}', "");
Error('\p{Joining_Group=	_farsi_Yeh/a/}');
Error('\P{Joining_Group=	_farsi_Yeh/a/}');
Expect(1, 1910, '\p{Joining_Group=farsiyeh}', "");
Expect(0, 1910, '\p{^Joining_Group=farsiyeh}', "");
Expect(0, 1910, '\P{Joining_Group=farsiyeh}', "");
Expect(1, 1910, '\P{^Joining_Group=farsiyeh}', "");
Expect(0, 1911, '\p{Joining_Group=farsiyeh}', "");
Expect(1, 1911, '\p{^Joining_Group=farsiyeh}', "");
Expect(1, 1911, '\P{Joining_Group=farsiyeh}', "");
Expect(0, 1911, '\P{^Joining_Group=farsiyeh}', "");
Expect(1, 1910, '\p{Joining_Group=__FARSI_YEH}', "");
Expect(0, 1910, '\p{^Joining_Group=__FARSI_YEH}', "");
Expect(0, 1910, '\P{Joining_Group=__FARSI_YEH}', "");
Expect(1, 1910, '\P{^Joining_Group=__FARSI_YEH}', "");
Expect(0, 1911, '\p{Joining_Group=__FARSI_YEH}', "");
Expect(1, 1911, '\p{^Joining_Group=__FARSI_YEH}', "");
Expect(1, 1911, '\P{Joining_Group=__FARSI_YEH}', "");
Expect(0, 1911, '\P{^Joining_Group=__FARSI_YEH}', "");
Error('\p{Jg=:=	Farsi_Yeh}');
Error('\P{Jg=:=	Farsi_Yeh}');
Expect(1, 1910, '\p{Jg=farsiyeh}', "");
Expect(0, 1910, '\p{^Jg=farsiyeh}', "");
Expect(0, 1910, '\P{Jg=farsiyeh}', "");
Expect(1, 1910, '\P{^Jg=farsiyeh}', "");
Expect(0, 1911, '\p{Jg=farsiyeh}', "");
Expect(1, 1911, '\p{^Jg=farsiyeh}', "");
Expect(1, 1911, '\P{Jg=farsiyeh}', "");
Expect(0, 1911, '\P{^Jg=farsiyeh}', "");
Expect(1, 1910, '\p{Jg= -Farsi_yeh}', "");
Expect(0, 1910, '\p{^Jg= -Farsi_yeh}', "");
Expect(0, 1910, '\P{Jg= -Farsi_yeh}', "");
Expect(1, 1910, '\P{^Jg= -Farsi_yeh}', "");
Expect(0, 1911, '\p{Jg= -Farsi_yeh}', "");
Expect(1, 1911, '\p{^Jg= -Farsi_yeh}', "");
Expect(1, 1911, '\P{Jg= -Farsi_yeh}', "");
Expect(0, 1911, '\P{^Jg= -Farsi_yeh}', "");
Error('\p{Is_Joining_Group=/a/ 	Farsi_Yeh}');
Error('\P{Is_Joining_Group=/a/ 	Farsi_Yeh}');
Expect(1, 1910, '\p{Is_Joining_Group=farsiyeh}', "");
Expect(0, 1910, '\p{^Is_Joining_Group=farsiyeh}', "");
Expect(0, 1910, '\P{Is_Joining_Group=farsiyeh}', "");
Expect(1, 1910, '\P{^Is_Joining_Group=farsiyeh}', "");
Expect(0, 1911, '\p{Is_Joining_Group=farsiyeh}', "");
Expect(1, 1911, '\p{^Is_Joining_Group=farsiyeh}', "");
Expect(1, 1911, '\P{Is_Joining_Group=farsiyeh}', "");
Expect(0, 1911, '\P{^Is_Joining_Group=farsiyeh}', "");
Expect(1, 1910, '\p{Is_Joining_Group=- Farsi_Yeh}', "");
Expect(0, 1910, '\p{^Is_Joining_Group=- Farsi_Yeh}', "");
Expect(0, 1910, '\P{Is_Joining_Group=- Farsi_Yeh}', "");
Expect(1, 1910, '\P{^Is_Joining_Group=- Farsi_Yeh}', "");
Expect(0, 1911, '\p{Is_Joining_Group=- Farsi_Yeh}', "");
Expect(1, 1911, '\p{^Is_Joining_Group=- Farsi_Yeh}', "");
Expect(1, 1911, '\P{Is_Joining_Group=- Farsi_Yeh}', "");
Expect(0, 1911, '\P{^Is_Joining_Group=- Farsi_Yeh}', "");
Error('\p{Is_Jg=_/a/farsi_Yeh}');
Error('\P{Is_Jg=_/a/farsi_Yeh}');
Expect(1, 1910, '\p{Is_Jg=farsiyeh}', "");
Expect(0, 1910, '\p{^Is_Jg=farsiyeh}', "");
Expect(0, 1910, '\P{Is_Jg=farsiyeh}', "");
Expect(1, 1910, '\P{^Is_Jg=farsiyeh}', "");
Expect(0, 1911, '\p{Is_Jg=farsiyeh}', "");
Expect(1, 1911, '\p{^Is_Jg=farsiyeh}', "");
Expect(1, 1911, '\P{Is_Jg=farsiyeh}', "");
Expect(0, 1911, '\P{^Is_Jg=farsiyeh}', "");
Expect(1, 1910, '\p{Is_Jg=  FARSI_Yeh}', "");
Expect(0, 1910, '\p{^Is_Jg=  FARSI_Yeh}', "");
Expect(0, 1910, '\P{Is_Jg=  FARSI_Yeh}', "");
Expect(1, 1910, '\P{^Is_Jg=  FARSI_Yeh}', "");
Expect(0, 1911, '\p{Is_Jg=  FARSI_Yeh}', "");
Expect(1, 1911, '\p{^Is_Jg=  FARSI_Yeh}', "");
Expect(1, 1911, '\P{Is_Jg=  FARSI_Yeh}', "");
Expect(0, 1911, '\P{^Is_Jg=  FARSI_Yeh}', "");
Error('\p{Joining_Group=-Fe/a/}');
Error('\P{Joining_Group=-Fe/a/}');
Expect(1, 1871, '\p{Joining_Group=fe}', "");
Expect(0, 1871, '\p{^Joining_Group=fe}', "");
Expect(0, 1871, '\P{Joining_Group=fe}', "");
Expect(1, 1871, '\P{^Joining_Group=fe}', "");
Expect(0, 1872, '\p{Joining_Group=fe}', "");
Expect(1, 1872, '\p{^Joining_Group=fe}', "");
Expect(1, 1872, '\P{Joining_Group=fe}', "");
Expect(0, 1872, '\P{^Joining_Group=fe}', "");
Expect(1, 1871, '\p{Joining_Group= fe}', "");
Expect(0, 1871, '\p{^Joining_Group= fe}', "");
Expect(0, 1871, '\P{Joining_Group= fe}', "");
Expect(1, 1871, '\P{^Joining_Group= fe}', "");
Expect(0, 1872, '\p{Joining_Group= fe}', "");
Expect(1, 1872, '\p{^Joining_Group= fe}', "");
Expect(1, 1872, '\P{Joining_Group= fe}', "");
Expect(0, 1872, '\P{^Joining_Group= fe}', "");
Error('\p{Jg=:= 	FE}');
Error('\P{Jg=:= 	FE}');
Expect(1, 1871, '\p{Jg=fe}', "");
Expect(0, 1871, '\p{^Jg=fe}', "");
Expect(0, 1871, '\P{Jg=fe}', "");
Expect(1, 1871, '\P{^Jg=fe}', "");
Expect(0, 1872, '\p{Jg=fe}', "");
Expect(1, 1872, '\p{^Jg=fe}', "");
Expect(1, 1872, '\P{Jg=fe}', "");
Expect(0, 1872, '\P{^Jg=fe}', "");
Expect(1, 1871, '\p{Jg=-_FE}', "");
Expect(0, 1871, '\p{^Jg=-_FE}', "");
Expect(0, 1871, '\P{Jg=-_FE}', "");
Expect(1, 1871, '\P{^Jg=-_FE}', "");
Expect(0, 1872, '\p{Jg=-_FE}', "");
Expect(1, 1872, '\p{^Jg=-_FE}', "");
Expect(1, 1872, '\P{Jg=-_FE}', "");
Expect(0, 1872, '\P{^Jg=-_FE}', "");
Error('\p{Is_Joining_Group=/a/  Fe}');
Error('\P{Is_Joining_Group=/a/  Fe}');
Expect(1, 1871, '\p{Is_Joining_Group=fe}', "");
Expect(0, 1871, '\p{^Is_Joining_Group=fe}', "");
Expect(0, 1871, '\P{Is_Joining_Group=fe}', "");
Expect(1, 1871, '\P{^Is_Joining_Group=fe}', "");
Expect(0, 1872, '\p{Is_Joining_Group=fe}', "");
Expect(1, 1872, '\p{^Is_Joining_Group=fe}', "");
Expect(1, 1872, '\P{Is_Joining_Group=fe}', "");
Expect(0, 1872, '\P{^Is_Joining_Group=fe}', "");
Expect(1, 1871, '\p{Is_Joining_Group=_-Fe}', "");
Expect(0, 1871, '\p{^Is_Joining_Group=_-Fe}', "");
Expect(0, 1871, '\P{Is_Joining_Group=_-Fe}', "");
Expect(1, 1871, '\P{^Is_Joining_Group=_-Fe}', "");
Expect(0, 1872, '\p{Is_Joining_Group=_-Fe}', "");
Expect(1, 1872, '\p{^Is_Joining_Group=_-Fe}', "");
Expect(1, 1872, '\P{Is_Joining_Group=_-Fe}', "");
Expect(0, 1872, '\P{^Is_Joining_Group=_-Fe}', "");
Error('\p{Is_Jg=/a/_	fe}');
Error('\P{Is_Jg=/a/_	fe}');
Expect(1, 1871, '\p{Is_Jg=fe}', "");
Expect(0, 1871, '\p{^Is_Jg=fe}', "");
Expect(0, 1871, '\P{Is_Jg=fe}', "");
Expect(1, 1871, '\P{^Is_Jg=fe}', "");
Expect(0, 1872, '\p{Is_Jg=fe}', "");
Expect(1, 1872, '\p{^Is_Jg=fe}', "");
Expect(1, 1872, '\P{Is_Jg=fe}', "");
Expect(0, 1872, '\P{^Is_Jg=fe}', "");
Expect(1, 1871, '\p{Is_Jg:   -fe}', "");
Expect(0, 1871, '\p{^Is_Jg:   -fe}', "");
Expect(0, 1871, '\P{Is_Jg:   -fe}', "");
Expect(1, 1871, '\P{^Is_Jg:   -fe}', "");
Expect(0, 1872, '\p{Is_Jg:   -fe}', "");
Expect(1, 1872, '\p{^Is_Jg:   -fe}', "");
Expect(1, 1872, '\P{Is_Jg:   -fe}', "");
Expect(0, 1872, '\P{^Is_Jg:   -fe}', "");
Error('\p{Joining_Group=_-Feh/a/}');
Error('\P{Joining_Group=_-Feh/a/}');
Expect(1, 2212, '\p{Joining_Group:feh}', "");
Expect(0, 2212, '\p{^Joining_Group:feh}', "");
Expect(0, 2212, '\P{Joining_Group:feh}', "");
Expect(1, 2212, '\P{^Joining_Group:feh}', "");
Expect(0, 2213, '\p{Joining_Group:feh}', "");
Expect(1, 2213, '\p{^Joining_Group:feh}', "");
Expect(1, 2213, '\P{Joining_Group:feh}', "");
Expect(0, 2213, '\P{^Joining_Group:feh}', "");
Expect(1, 2212, '\p{Joining_Group=Feh}', "");
Expect(0, 2212, '\p{^Joining_Group=Feh}', "");
Expect(0, 2212, '\P{Joining_Group=Feh}', "");
Expect(1, 2212, '\P{^Joining_Group=Feh}', "");
Expect(0, 2213, '\p{Joining_Group=Feh}', "");
Expect(1, 2213, '\p{^Joining_Group=Feh}', "");
Expect(1, 2213, '\P{Joining_Group=Feh}', "");
Expect(0, 2213, '\P{^Joining_Group=Feh}', "");
Error('\p{Jg=  Feh:=}');
Error('\P{Jg=  Feh:=}');
Expect(1, 2212, '\p{Jg=feh}', "");
Expect(0, 2212, '\p{^Jg=feh}', "");
Expect(0, 2212, '\P{Jg=feh}', "");
Expect(1, 2212, '\P{^Jg=feh}', "");
Expect(0, 2213, '\p{Jg=feh}', "");
Expect(1, 2213, '\p{^Jg=feh}', "");
Expect(1, 2213, '\P{Jg=feh}', "");
Expect(0, 2213, '\P{^Jg=feh}', "");
Expect(1, 2212, '\p{Jg=	_feh}', "");
Expect(0, 2212, '\p{^Jg=	_feh}', "");
Expect(0, 2212, '\P{Jg=	_feh}', "");
Expect(1, 2212, '\P{^Jg=	_feh}', "");
Expect(0, 2213, '\p{Jg=	_feh}', "");
Expect(1, 2213, '\p{^Jg=	_feh}', "");
Expect(1, 2213, '\P{Jg=	_feh}', "");
Expect(0, 2213, '\P{^Jg=	_feh}', "");
Error('\p{Is_Joining_Group:		-Feh:=}');
Error('\P{Is_Joining_Group:		-Feh:=}');
Expect(1, 2212, '\p{Is_Joining_Group=feh}', "");
Expect(0, 2212, '\p{^Is_Joining_Group=feh}', "");
Expect(0, 2212, '\P{Is_Joining_Group=feh}', "");
Expect(1, 2212, '\P{^Is_Joining_Group=feh}', "");
Expect(0, 2213, '\p{Is_Joining_Group=feh}', "");
Expect(1, 2213, '\p{^Is_Joining_Group=feh}', "");
Expect(1, 2213, '\P{Is_Joining_Group=feh}', "");
Expect(0, 2213, '\P{^Is_Joining_Group=feh}', "");
Expect(1, 2212, '\p{Is_Joining_Group=Feh}', "");
Expect(0, 2212, '\p{^Is_Joining_Group=Feh}', "");
Expect(0, 2212, '\P{Is_Joining_Group=Feh}', "");
Expect(1, 2212, '\P{^Is_Joining_Group=Feh}', "");
Expect(0, 2213, '\p{Is_Joining_Group=Feh}', "");
Expect(1, 2213, '\p{^Is_Joining_Group=Feh}', "");
Expect(1, 2213, '\P{Is_Joining_Group=Feh}', "");
Expect(0, 2213, '\P{^Is_Joining_Group=Feh}', "");
Error('\p{Is_Jg=--Feh/a/}');
Error('\P{Is_Jg=--Feh/a/}');
Expect(1, 2212, '\p{Is_Jg:   feh}', "");
Expect(0, 2212, '\p{^Is_Jg:   feh}', "");
Expect(0, 2212, '\P{Is_Jg:   feh}', "");
Expect(1, 2212, '\P{^Is_Jg:   feh}', "");
Expect(0, 2213, '\p{Is_Jg:   feh}', "");
Expect(1, 2213, '\p{^Is_Jg:   feh}', "");
Expect(1, 2213, '\P{Is_Jg:   feh}', "");
Expect(0, 2213, '\P{^Is_Jg:   feh}', "");
Expect(1, 2212, '\p{Is_Jg=--feh}', "");
Expect(0, 2212, '\p{^Is_Jg=--feh}', "");
Expect(0, 2212, '\P{Is_Jg=--feh}', "");
Expect(1, 2212, '\P{^Is_Jg=--feh}', "");
Expect(0, 2213, '\p{Is_Jg=--feh}', "");
Expect(1, 2213, '\p{^Is_Jg=--feh}', "");
Expect(1, 2213, '\P{Is_Jg=--feh}', "");
Expect(0, 2213, '\P{^Is_Jg=--feh}', "");
Error('\p{Joining_Group=_	Final_Semkath/a/}');
Error('\P{Joining_Group=_	Final_Semkath/a/}');
Expect(1, 1828, '\p{Joining_Group=finalsemkath}', "");
Expect(0, 1828, '\p{^Joining_Group=finalsemkath}', "");
Expect(0, 1828, '\P{Joining_Group=finalsemkath}', "");
Expect(1, 1828, '\P{^Joining_Group=finalsemkath}', "");
Expect(0, 1829, '\p{Joining_Group=finalsemkath}', "");
Expect(1, 1829, '\p{^Joining_Group=finalsemkath}', "");
Expect(1, 1829, '\P{Joining_Group=finalsemkath}', "");
Expect(0, 1829, '\P{^Joining_Group=finalsemkath}', "");
Expect(1, 1828, '\p{Joining_Group= 	FINAL_semkath}', "");
Expect(0, 1828, '\p{^Joining_Group= 	FINAL_semkath}', "");
Expect(0, 1828, '\P{Joining_Group= 	FINAL_semkath}', "");
Expect(1, 1828, '\P{^Joining_Group= 	FINAL_semkath}', "");
Expect(0, 1829, '\p{Joining_Group= 	FINAL_semkath}', "");
Expect(1, 1829, '\p{^Joining_Group= 	FINAL_semkath}', "");
Expect(1, 1829, '\P{Joining_Group= 	FINAL_semkath}', "");
Expect(0, 1829, '\P{^Joining_Group= 	FINAL_semkath}', "");
Error('\p{Jg=  Final_Semkath/a/}');
Error('\P{Jg=  Final_Semkath/a/}');
Expect(1, 1828, '\p{Jg:   finalsemkath}', "");
Expect(0, 1828, '\p{^Jg:   finalsemkath}', "");
Expect(0, 1828, '\P{Jg:   finalsemkath}', "");
Expect(1, 1828, '\P{^Jg:   finalsemkath}', "");
Expect(0, 1829, '\p{Jg:   finalsemkath}', "");
Expect(1, 1829, '\p{^Jg:   finalsemkath}', "");
Expect(1, 1829, '\P{Jg:   finalsemkath}', "");
Expect(0, 1829, '\P{^Jg:   finalsemkath}', "");
Expect(1, 1828, '\p{Jg=_	FINAL_semkath}', "");
Expect(0, 1828, '\p{^Jg=_	FINAL_semkath}', "");
Expect(0, 1828, '\P{Jg=_	FINAL_semkath}', "");
Expect(1, 1828, '\P{^Jg=_	FINAL_semkath}', "");
Expect(0, 1829, '\p{Jg=_	FINAL_semkath}', "");
Expect(1, 1829, '\p{^Jg=_	FINAL_semkath}', "");
Expect(1, 1829, '\P{Jg=_	FINAL_semkath}', "");
Expect(0, 1829, '\P{^Jg=_	FINAL_semkath}', "");
Error('\p{Is_Joining_Group=/a/- final_Semkath}');
Error('\P{Is_Joining_Group=/a/- final_Semkath}');
Expect(1, 1828, '\p{Is_Joining_Group=finalsemkath}', "");
Expect(0, 1828, '\p{^Is_Joining_Group=finalsemkath}', "");
Expect(0, 1828, '\P{Is_Joining_Group=finalsemkath}', "");
Expect(1, 1828, '\P{^Is_Joining_Group=finalsemkath}', "");
Expect(0, 1829, '\p{Is_Joining_Group=finalsemkath}', "");
Expect(1, 1829, '\p{^Is_Joining_Group=finalsemkath}', "");
Expect(1, 1829, '\P{Is_Joining_Group=finalsemkath}', "");
Expect(0, 1829, '\P{^Is_Joining_Group=finalsemkath}', "");
Expect(1, 1828, '\p{Is_Joining_Group=--final_Semkath}', "");
Expect(0, 1828, '\p{^Is_Joining_Group=--final_Semkath}', "");
Expect(0, 1828, '\P{Is_Joining_Group=--final_Semkath}', "");
Expect(1, 1828, '\P{^Is_Joining_Group=--final_Semkath}', "");
Expect(0, 1829, '\p{Is_Joining_Group=--final_Semkath}', "");
Expect(1, 1829, '\p{^Is_Joining_Group=--final_Semkath}', "");
Expect(1, 1829, '\P{Is_Joining_Group=--final_Semkath}', "");
Expect(0, 1829, '\P{^Is_Joining_Group=--final_Semkath}', "");
Error('\p{Is_Jg=/a/ 	FINAL_Semkath}');
Error('\P{Is_Jg=/a/ 	FINAL_Semkath}');
Expect(1, 1828, '\p{Is_Jg=finalsemkath}', "");
Expect(0, 1828, '\p{^Is_Jg=finalsemkath}', "");
Expect(0, 1828, '\P{Is_Jg=finalsemkath}', "");
Expect(1, 1828, '\P{^Is_Jg=finalsemkath}', "");
Expect(0, 1829, '\p{Is_Jg=finalsemkath}', "");
Expect(1, 1829, '\p{^Is_Jg=finalsemkath}', "");
Expect(1, 1829, '\P{Is_Jg=finalsemkath}', "");
Expect(0, 1829, '\P{^Is_Jg=finalsemkath}', "");
Expect(1, 1828, '\p{Is_Jg=_Final_SEMKATH}', "");
Expect(0, 1828, '\p{^Is_Jg=_Final_SEMKATH}', "");
Expect(0, 1828, '\P{Is_Jg=_Final_SEMKATH}', "");
Expect(1, 1828, '\P{^Is_Jg=_Final_SEMKATH}', "");
Expect(0, 1829, '\p{Is_Jg=_Final_SEMKATH}', "");
Expect(1, 1829, '\p{^Is_Jg=_Final_SEMKATH}', "");
Expect(1, 1829, '\P{Is_Jg=_Final_SEMKATH}', "");
Expect(0, 1829, '\P{^Is_Jg=_Final_SEMKATH}', "");
Error('\p{Joining_Group=	/a/GAF}');
Error('\P{Joining_Group=	/a/GAF}');
Expect(1, 1892, '\p{Joining_Group=gaf}', "");
Expect(0, 1892, '\p{^Joining_Group=gaf}', "");
Expect(0, 1892, '\P{Joining_Group=gaf}', "");
Expect(1, 1892, '\P{^Joining_Group=gaf}', "");
Expect(0, 1893, '\p{Joining_Group=gaf}', "");
Expect(1, 1893, '\p{^Joining_Group=gaf}', "");
Expect(1, 1893, '\P{Joining_Group=gaf}', "");
Expect(0, 1893, '\P{^Joining_Group=gaf}', "");
Expect(1, 1892, '\p{Joining_Group=_-gaf}', "");
Expect(0, 1892, '\p{^Joining_Group=_-gaf}', "");
Expect(0, 1892, '\P{Joining_Group=_-gaf}', "");
Expect(1, 1892, '\P{^Joining_Group=_-gaf}', "");
Expect(0, 1893, '\p{Joining_Group=_-gaf}', "");
Expect(1, 1893, '\p{^Joining_Group=_-gaf}', "");
Expect(1, 1893, '\P{Joining_Group=_-gaf}', "");
Expect(0, 1893, '\P{^Joining_Group=_-gaf}', "");
Error('\p{Jg=-/a/GAF}');
Error('\P{Jg=-/a/GAF}');
Expect(1, 1892, '\p{Jg=gaf}', "");
Expect(0, 1892, '\p{^Jg=gaf}', "");
Expect(0, 1892, '\P{Jg=gaf}', "");
Expect(1, 1892, '\P{^Jg=gaf}', "");
Expect(0, 1893, '\p{Jg=gaf}', "");
Expect(1, 1893, '\p{^Jg=gaf}', "");
Expect(1, 1893, '\P{Jg=gaf}', "");
Expect(0, 1893, '\P{^Jg=gaf}', "");
Expect(1, 1892, '\p{Jg=-_Gaf}', "");
Expect(0, 1892, '\p{^Jg=-_Gaf}', "");
Expect(0, 1892, '\P{Jg=-_Gaf}', "");
Expect(1, 1892, '\P{^Jg=-_Gaf}', "");
Expect(0, 1893, '\p{Jg=-_Gaf}', "");
Expect(1, 1893, '\p{^Jg=-_Gaf}', "");
Expect(1, 1893, '\P{Jg=-_Gaf}', "");
Expect(0, 1893, '\P{^Jg=-_Gaf}', "");
Error('\p{Is_Joining_Group:-:=gaf}');
Error('\P{Is_Joining_Group:-:=gaf}');
Expect(1, 1892, '\p{Is_Joining_Group=gaf}', "");
Expect(0, 1892, '\p{^Is_Joining_Group=gaf}', "");
Expect(0, 1892, '\P{Is_Joining_Group=gaf}', "");
Expect(1, 1892, '\P{^Is_Joining_Group=gaf}', "");
Expect(0, 1893, '\p{Is_Joining_Group=gaf}', "");
Expect(1, 1893, '\p{^Is_Joining_Group=gaf}', "");
Expect(1, 1893, '\P{Is_Joining_Group=gaf}', "");
Expect(0, 1893, '\P{^Is_Joining_Group=gaf}', "");
Expect(1, 1892, '\p{Is_Joining_Group=_-GAF}', "");
Expect(0, 1892, '\p{^Is_Joining_Group=_-GAF}', "");
Expect(0, 1892, '\P{Is_Joining_Group=_-GAF}', "");
Expect(1, 1892, '\P{^Is_Joining_Group=_-GAF}', "");
Expect(0, 1893, '\p{Is_Joining_Group=_-GAF}', "");
Expect(1, 1893, '\p{^Is_Joining_Group=_-GAF}', "");
Expect(1, 1893, '\P{Is_Joining_Group=_-GAF}', "");
Expect(0, 1893, '\P{^Is_Joining_Group=_-GAF}', "");
Error('\p{Is_Jg=/a/_-gaf}');
Error('\P{Is_Jg=/a/_-gaf}');
Expect(1, 1892, '\p{Is_Jg=gaf}', "");
Expect(0, 1892, '\p{^Is_Jg=gaf}', "");
Expect(0, 1892, '\P{Is_Jg=gaf}', "");
Expect(1, 1892, '\P{^Is_Jg=gaf}', "");
Expect(0, 1893, '\p{Is_Jg=gaf}', "");
Expect(1, 1893, '\p{^Is_Jg=gaf}', "");
Expect(1, 1893, '\P{Is_Jg=gaf}', "");
Expect(0, 1893, '\P{^Is_Jg=gaf}', "");
Expect(1, 1892, '\p{Is_Jg:__Gaf}', "");
Expect(0, 1892, '\p{^Is_Jg:__Gaf}', "");
Expect(0, 1892, '\P{Is_Jg:__Gaf}', "");
Expect(1, 1892, '\P{^Is_Jg:__Gaf}', "");
Expect(0, 1893, '\p{Is_Jg:__Gaf}', "");
Expect(1, 1893, '\p{^Is_Jg:__Gaf}', "");
Expect(1, 1893, '\P{Is_Jg:__Gaf}', "");
Expect(0, 1893, '\P{^Is_Jg:__Gaf}', "");
Error('\p{Joining_Group=/a/		Gamal}');
Error('\P{Joining_Group=/a/		Gamal}');
Expect(1, 1838, '\p{Joining_Group=gamal}', "");
Expect(0, 1838, '\p{^Joining_Group=gamal}', "");
Expect(0, 1838, '\P{Joining_Group=gamal}', "");
Expect(1, 1838, '\P{^Joining_Group=gamal}', "");
Expect(0, 1839, '\p{Joining_Group=gamal}', "");
Expect(1, 1839, '\p{^Joining_Group=gamal}', "");
Expect(1, 1839, '\P{Joining_Group=gamal}', "");
Expect(0, 1839, '\P{^Joining_Group=gamal}', "");
Expect(1, 1838, '\p{Joining_Group:   	Gamal}', "");
Expect(0, 1838, '\p{^Joining_Group:   	Gamal}', "");
Expect(0, 1838, '\P{Joining_Group:   	Gamal}', "");
Expect(1, 1838, '\P{^Joining_Group:   	Gamal}', "");
Expect(0, 1839, '\p{Joining_Group:   	Gamal}', "");
Expect(1, 1839, '\p{^Joining_Group:   	Gamal}', "");
Expect(1, 1839, '\P{Joining_Group:   	Gamal}', "");
Expect(0, 1839, '\P{^Joining_Group:   	Gamal}', "");
Error('\p{Jg=gamal/a/}');
Error('\P{Jg=gamal/a/}');
Expect(1, 1838, '\p{Jg=gamal}', "");
Expect(0, 1838, '\p{^Jg=gamal}', "");
Expect(0, 1838, '\P{Jg=gamal}', "");
Expect(1, 1838, '\P{^Jg=gamal}', "");
Expect(0, 1839, '\p{Jg=gamal}', "");
Expect(1, 1839, '\p{^Jg=gamal}', "");
Expect(1, 1839, '\P{Jg=gamal}', "");
Expect(0, 1839, '\P{^Jg=gamal}', "");
Expect(1, 1838, '\p{Jg= _Gamal}', "");
Expect(0, 1838, '\p{^Jg= _Gamal}', "");
Expect(0, 1838, '\P{Jg= _Gamal}', "");
Expect(1, 1838, '\P{^Jg= _Gamal}', "");
Expect(0, 1839, '\p{Jg= _Gamal}', "");
Expect(1, 1839, '\p{^Jg= _Gamal}', "");
Expect(1, 1839, '\P{Jg= _Gamal}', "");
Expect(0, 1839, '\P{^Jg= _Gamal}', "");
Error('\p{Is_Joining_Group=	:=GAMAL}');
Error('\P{Is_Joining_Group=	:=GAMAL}');
Expect(1, 1838, '\p{Is_Joining_Group=gamal}', "");
Expect(0, 1838, '\p{^Is_Joining_Group=gamal}', "");
Expect(0, 1838, '\P{Is_Joining_Group=gamal}', "");
Expect(1, 1838, '\P{^Is_Joining_Group=gamal}', "");
Expect(0, 1839, '\p{Is_Joining_Group=gamal}', "");
Expect(1, 1839, '\p{^Is_Joining_Group=gamal}', "");
Expect(1, 1839, '\P{Is_Joining_Group=gamal}', "");
Expect(0, 1839, '\P{^Is_Joining_Group=gamal}', "");
Expect(1, 1838, '\p{Is_Joining_Group=--Gamal}', "");
Expect(0, 1838, '\p{^Is_Joining_Group=--Gamal}', "");
Expect(0, 1838, '\P{Is_Joining_Group=--Gamal}', "");
Expect(1, 1838, '\P{^Is_Joining_Group=--Gamal}', "");
Expect(0, 1839, '\p{Is_Joining_Group=--Gamal}', "");
Expect(1, 1839, '\p{^Is_Joining_Group=--Gamal}', "");
Expect(1, 1839, '\P{Is_Joining_Group=--Gamal}', "");
Expect(0, 1839, '\P{^Is_Joining_Group=--Gamal}', "");
Error('\p{Is_Jg=/a/_	gamal}');
Error('\P{Is_Jg=/a/_	gamal}');
Expect(1, 1838, '\p{Is_Jg=gamal}', "");
Expect(0, 1838, '\p{^Is_Jg=gamal}', "");
Expect(0, 1838, '\P{Is_Jg=gamal}', "");
Expect(1, 1838, '\P{^Is_Jg=gamal}', "");
Expect(0, 1839, '\p{Is_Jg=gamal}', "");
Expect(1, 1839, '\p{^Is_Jg=gamal}', "");
Expect(1, 1839, '\P{Is_Jg=gamal}', "");
Expect(0, 1839, '\P{^Is_Jg=gamal}', "");
Expect(1, 1838, '\p{Is_Jg=__GAMAL}', "");
Expect(0, 1838, '\p{^Is_Jg=__GAMAL}', "");
Expect(0, 1838, '\P{Is_Jg=__GAMAL}', "");
Expect(1, 1838, '\P{^Is_Jg=__GAMAL}', "");
Expect(0, 1839, '\p{Is_Jg=__GAMAL}', "");
Expect(1, 1839, '\p{^Is_Jg=__GAMAL}', "");
Expect(1, 1839, '\P{Is_Jg=__GAMAL}', "");
Expect(0, 1839, '\P{^Is_Jg=__GAMAL}', "");
Error('\p{Joining_Group= :=Hah}');
Error('\P{Joining_Group= :=Hah}');
Expect(1, 2210, '\p{Joining_Group:   hah}', "");
Expect(0, 2210, '\p{^Joining_Group:   hah}', "");
Expect(0, 2210, '\P{Joining_Group:   hah}', "");
Expect(1, 2210, '\P{^Joining_Group:   hah}', "");
Expect(0, 2211, '\p{Joining_Group:   hah}', "");
Expect(1, 2211, '\p{^Joining_Group:   hah}', "");
Expect(1, 2211, '\P{Joining_Group:   hah}', "");
Expect(0, 2211, '\P{^Joining_Group:   hah}', "");
Expect(1, 2210, '\p{Joining_Group=		HAH}', "");
Expect(0, 2210, '\p{^Joining_Group=		HAH}', "");
Expect(0, 2210, '\P{Joining_Group=		HAH}', "");
Expect(1, 2210, '\P{^Joining_Group=		HAH}', "");
Expect(0, 2211, '\p{Joining_Group=		HAH}', "");
Expect(1, 2211, '\p{^Joining_Group=		HAH}', "");
Expect(1, 2211, '\P{Joining_Group=		HAH}', "");
Expect(0, 2211, '\P{^Joining_Group=		HAH}', "");
Error('\p{Jg=	-Hah/a/}');
Error('\P{Jg=	-Hah/a/}');
Expect(1, 2210, '\p{Jg:   hah}', "");
Expect(0, 2210, '\p{^Jg:   hah}', "");
Expect(0, 2210, '\P{Jg:   hah}', "");
Expect(1, 2210, '\P{^Jg:   hah}', "");
Expect(0, 2211, '\p{Jg:   hah}', "");
Expect(1, 2211, '\p{^Jg:   hah}', "");
Expect(1, 2211, '\P{Jg:   hah}', "");
Expect(0, 2211, '\P{^Jg:   hah}', "");
Expect(1, 2210, '\p{Jg=	Hah}', "");
Expect(0, 2210, '\p{^Jg=	Hah}', "");
Expect(0, 2210, '\P{Jg=	Hah}', "");
Expect(1, 2210, '\P{^Jg=	Hah}', "");
Expect(0, 2211, '\p{Jg=	Hah}', "");
Expect(1, 2211, '\p{^Jg=	Hah}', "");
Expect(1, 2211, '\P{Jg=	Hah}', "");
Expect(0, 2211, '\P{^Jg=	Hah}', "");
Error('\p{Is_Joining_Group=/a/-	HAH}');
Error('\P{Is_Joining_Group=/a/-	HAH}');
Expect(1, 2210, '\p{Is_Joining_Group=hah}', "");
Expect(0, 2210, '\p{^Is_Joining_Group=hah}', "");
Expect(0, 2210, '\P{Is_Joining_Group=hah}', "");
Expect(1, 2210, '\P{^Is_Joining_Group=hah}', "");
Expect(0, 2211, '\p{Is_Joining_Group=hah}', "");
Expect(1, 2211, '\p{^Is_Joining_Group=hah}', "");
Expect(1, 2211, '\P{Is_Joining_Group=hah}', "");
Expect(0, 2211, '\P{^Is_Joining_Group=hah}', "");
Expect(1, 2210, '\p{Is_Joining_Group=_-Hah}', "");
Expect(0, 2210, '\p{^Is_Joining_Group=_-Hah}', "");
Expect(0, 2210, '\P{Is_Joining_Group=_-Hah}', "");
Expect(1, 2210, '\P{^Is_Joining_Group=_-Hah}', "");
Expect(0, 2211, '\p{Is_Joining_Group=_-Hah}', "");
Expect(1, 2211, '\p{^Is_Joining_Group=_-Hah}', "");
Expect(1, 2211, '\P{Is_Joining_Group=_-Hah}', "");
Expect(0, 2211, '\P{^Is_Joining_Group=_-Hah}', "");
Error('\p{Is_Jg= /a/hah}');
Error('\P{Is_Jg= /a/hah}');
Expect(1, 2210, '\p{Is_Jg=hah}', "");
Expect(0, 2210, '\p{^Is_Jg=hah}', "");
Expect(0, 2210, '\P{Is_Jg=hah}', "");
Expect(1, 2210, '\P{^Is_Jg=hah}', "");
Expect(0, 2211, '\p{Is_Jg=hah}', "");
Expect(1, 2211, '\p{^Is_Jg=hah}', "");
Expect(1, 2211, '\P{Is_Jg=hah}', "");
Expect(0, 2211, '\P{^Is_Jg=hah}', "");
Expect(1, 2210, '\p{Is_Jg=-_Hah}', "");
Expect(0, 2210, '\p{^Is_Jg=-_Hah}', "");
Expect(0, 2210, '\P{Is_Jg=-_Hah}', "");
Expect(1, 2210, '\P{^Is_Jg=-_Hah}', "");
Expect(0, 2211, '\p{Is_Jg=-_Hah}', "");
Expect(1, 2211, '\p{^Is_Jg=-_Hah}', "");
Expect(1, 2211, '\P{Is_Jg=-_Hah}', "");
Expect(0, 2211, '\P{^Is_Jg=-_Hah}', "");
Error('\p{Joining_Group= /a/He}');
Error('\P{Joining_Group= /a/He}');
Expect(1, 1815, '\p{Joining_Group=he}', "");
Expect(0, 1815, '\p{^Joining_Group=he}', "");
Expect(0, 1815, '\P{Joining_Group=he}', "");
Expect(1, 1815, '\P{^Joining_Group=he}', "");
Expect(0, 1816, '\p{Joining_Group=he}', "");
Expect(1, 1816, '\p{^Joining_Group=he}', "");
Expect(1, 1816, '\P{Joining_Group=he}', "");
Expect(0, 1816, '\P{^Joining_Group=he}', "");
Expect(1, 1815, '\p{Joining_Group=	 he}', "");
Expect(0, 1815, '\p{^Joining_Group=	 he}', "");
Expect(0, 1815, '\P{Joining_Group=	 he}', "");
Expect(1, 1815, '\P{^Joining_Group=	 he}', "");
Expect(0, 1816, '\p{Joining_Group=	 he}', "");
Expect(1, 1816, '\p{^Joining_Group=	 he}', "");
Expect(1, 1816, '\P{Joining_Group=	 he}', "");
Expect(0, 1816, '\P{^Joining_Group=	 he}', "");
Error('\p{Jg=	/a/He}');
Error('\P{Jg=	/a/He}');
Expect(1, 1815, '\p{Jg=he}', "");
Expect(0, 1815, '\p{^Jg=he}', "");
Expect(0, 1815, '\P{Jg=he}', "");
Expect(1, 1815, '\P{^Jg=he}', "");
Expect(0, 1816, '\p{Jg=he}', "");
Expect(1, 1816, '\p{^Jg=he}', "");
Expect(1, 1816, '\P{Jg=he}', "");
Expect(0, 1816, '\P{^Jg=he}', "");
Expect(1, 1815, '\p{Jg=_-He}', "");
Expect(0, 1815, '\p{^Jg=_-He}', "");
Expect(0, 1815, '\P{Jg=_-He}', "");
Expect(1, 1815, '\P{^Jg=_-He}', "");
Expect(0, 1816, '\p{Jg=_-He}', "");
Expect(1, 1816, '\p{^Jg=_-He}', "");
Expect(1, 1816, '\P{Jg=_-He}', "");
Expect(0, 1816, '\P{^Jg=_-He}', "");
Error('\p{Is_Joining_Group=-:=he}');
Error('\P{Is_Joining_Group=-:=he}');
Expect(1, 1815, '\p{Is_Joining_Group=he}', "");
Expect(0, 1815, '\p{^Is_Joining_Group=he}', "");
Expect(0, 1815, '\P{Is_Joining_Group=he}', "");
Expect(1, 1815, '\P{^Is_Joining_Group=he}', "");
Expect(0, 1816, '\p{Is_Joining_Group=he}', "");
Expect(1, 1816, '\p{^Is_Joining_Group=he}', "");
Expect(1, 1816, '\P{Is_Joining_Group=he}', "");
Expect(0, 1816, '\P{^Is_Joining_Group=he}', "");
Expect(1, 1815, '\p{Is_Joining_Group=	HE}', "");
Expect(0, 1815, '\p{^Is_Joining_Group=	HE}', "");
Expect(0, 1815, '\P{Is_Joining_Group=	HE}', "");
Expect(1, 1815, '\P{^Is_Joining_Group=	HE}', "");
Expect(0, 1816, '\p{Is_Joining_Group=	HE}', "");
Expect(1, 1816, '\p{^Is_Joining_Group=	HE}', "");
Expect(1, 1816, '\P{Is_Joining_Group=	HE}', "");
Expect(0, 1816, '\P{^Is_Joining_Group=	HE}', "");
Error('\p{Is_Jg=:= _He}');
Error('\P{Is_Jg=:= _He}');
Expect(1, 1815, '\p{Is_Jg: he}', "");
Expect(0, 1815, '\p{^Is_Jg: he}', "");
Expect(0, 1815, '\P{Is_Jg: he}', "");
Expect(1, 1815, '\P{^Is_Jg: he}', "");
Expect(0, 1816, '\p{Is_Jg: he}', "");
Expect(1, 1816, '\p{^Is_Jg: he}', "");
Expect(1, 1816, '\P{Is_Jg: he}', "");
Expect(0, 1816, '\P{^Is_Jg: he}', "");
Expect(1, 1815, '\p{Is_Jg=-he}', "");
Expect(0, 1815, '\p{^Is_Jg=-he}', "");
Expect(0, 1815, '\P{Is_Jg=-he}', "");
Expect(1, 1815, '\P{^Is_Jg=-he}', "");
Expect(0, 1816, '\p{Is_Jg=-he}', "");
Expect(1, 1816, '\p{^Is_Jg=-he}', "");
Expect(1, 1816, '\P{Is_Jg=-he}', "");
Expect(0, 1816, '\P{^Is_Jg=-he}', "");
Error('\p{Joining_Group=-/a/Heh}');
Error('\P{Joining_Group=-/a/Heh}');
Expect(1, 1607, '\p{Joining_Group=heh}', "");
Expect(0, 1607, '\p{^Joining_Group=heh}', "");
Expect(0, 1607, '\P{Joining_Group=heh}', "");
Expect(1, 1607, '\P{^Joining_Group=heh}', "");
Expect(0, 1608, '\p{Joining_Group=heh}', "");
Expect(1, 1608, '\p{^Joining_Group=heh}', "");
Expect(1, 1608, '\P{Joining_Group=heh}', "");
Expect(0, 1608, '\P{^Joining_Group=heh}', "");
Expect(1, 1607, '\p{Joining_Group=_Heh}', "");
Expect(0, 1607, '\p{^Joining_Group=_Heh}', "");
Expect(0, 1607, '\P{Joining_Group=_Heh}', "");
Expect(1, 1607, '\P{^Joining_Group=_Heh}', "");
Expect(0, 1608, '\p{Joining_Group=_Heh}', "");
Expect(1, 1608, '\p{^Joining_Group=_Heh}', "");
Expect(1, 1608, '\P{Joining_Group=_Heh}', "");
Expect(0, 1608, '\P{^Joining_Group=_Heh}', "");
Error('\p{Jg=	:=heh}');
Error('\P{Jg=	:=heh}');
Expect(1, 1607, '\p{Jg=heh}', "");
Expect(0, 1607, '\p{^Jg=heh}', "");
Expect(0, 1607, '\P{Jg=heh}', "");
Expect(1, 1607, '\P{^Jg=heh}', "");
Expect(0, 1608, '\p{Jg=heh}', "");
Expect(1, 1608, '\p{^Jg=heh}', "");
Expect(1, 1608, '\P{Jg=heh}', "");
Expect(0, 1608, '\P{^Jg=heh}', "");
Expect(1, 1607, '\p{Jg=	-HEH}', "");
Expect(0, 1607, '\p{^Jg=	-HEH}', "");
Expect(0, 1607, '\P{Jg=	-HEH}', "");
Expect(1, 1607, '\P{^Jg=	-HEH}', "");
Expect(0, 1608, '\p{Jg=	-HEH}', "");
Expect(1, 1608, '\p{^Jg=	-HEH}', "");
Expect(1, 1608, '\P{Jg=	-HEH}', "");
Expect(0, 1608, '\P{^Jg=	-HEH}', "");
Error('\p{Is_Joining_Group=-/a/heh}');
Error('\P{Is_Joining_Group=-/a/heh}');
Expect(1, 1607, '\p{Is_Joining_Group=heh}', "");
Expect(0, 1607, '\p{^Is_Joining_Group=heh}', "");
Expect(0, 1607, '\P{Is_Joining_Group=heh}', "");
Expect(1, 1607, '\P{^Is_Joining_Group=heh}', "");
Expect(0, 1608, '\p{Is_Joining_Group=heh}', "");
Expect(1, 1608, '\p{^Is_Joining_Group=heh}', "");
Expect(1, 1608, '\P{Is_Joining_Group=heh}', "");
Expect(0, 1608, '\P{^Is_Joining_Group=heh}', "");
Expect(1, 1607, '\p{Is_Joining_Group= -heh}', "");
Expect(0, 1607, '\p{^Is_Joining_Group= -heh}', "");
Expect(0, 1607, '\P{Is_Joining_Group= -heh}', "");
Expect(1, 1607, '\P{^Is_Joining_Group= -heh}', "");
Expect(0, 1608, '\p{Is_Joining_Group= -heh}', "");
Expect(1, 1608, '\p{^Is_Joining_Group= -heh}', "");
Expect(1, 1608, '\P{Is_Joining_Group= -heh}', "");
Expect(0, 1608, '\P{^Is_Joining_Group= -heh}', "");
Error('\p{Is_Jg=-/a/Heh}');
Error('\P{Is_Jg=-/a/Heh}');
Expect(1, 1607, '\p{Is_Jg: heh}', "");
Expect(0, 1607, '\p{^Is_Jg: heh}', "");
Expect(0, 1607, '\P{Is_Jg: heh}', "");
Expect(1, 1607, '\P{^Is_Jg: heh}', "");
Expect(0, 1608, '\p{Is_Jg: heh}', "");
Expect(1, 1608, '\p{^Is_Jg: heh}', "");
Expect(1, 1608, '\P{Is_Jg: heh}', "");
Expect(0, 1608, '\P{^Is_Jg: heh}', "");
Expect(1, 1607, '\p{Is_Jg=Heh}', "");
Expect(0, 1607, '\p{^Is_Jg=Heh}', "");
Expect(0, 1607, '\P{Is_Jg=Heh}', "");
Expect(1, 1607, '\P{^Is_Jg=Heh}', "");
Expect(0, 1608, '\p{Is_Jg=Heh}', "");
Expect(1, 1608, '\p{^Is_Jg=Heh}', "");
Expect(1, 1608, '\P{Is_Jg=Heh}', "");
Expect(0, 1608, '\P{^Is_Jg=Heh}', "");
Error('\p{Joining_Group=-/a/heh_Goal}');
Error('\P{Joining_Group=-/a/heh_Goal}');
Expect(1, 1730, '\p{Joining_Group=hehgoal}', "");
Expect(0, 1730, '\p{^Joining_Group=hehgoal}', "");
Expect(0, 1730, '\P{Joining_Group=hehgoal}', "");
Expect(1, 1730, '\P{^Joining_Group=hehgoal}', "");
Expect(0, 1731, '\p{Joining_Group=hehgoal}', "");
Expect(1, 1731, '\p{^Joining_Group=hehgoal}', "");
Expect(1, 1731, '\P{Joining_Group=hehgoal}', "");
Expect(0, 1731, '\P{^Joining_Group=hehgoal}', "");
Expect(1, 1730, '\p{Joining_Group=- HEH_Goal}', "");
Expect(0, 1730, '\p{^Joining_Group=- HEH_Goal}', "");
Expect(0, 1730, '\P{Joining_Group=- HEH_Goal}', "");
Expect(1, 1730, '\P{^Joining_Group=- HEH_Goal}', "");
Expect(0, 1731, '\p{Joining_Group=- HEH_Goal}', "");
Expect(1, 1731, '\p{^Joining_Group=- HEH_Goal}', "");
Expect(1, 1731, '\P{Joining_Group=- HEH_Goal}', "");
Expect(0, 1731, '\P{^Joining_Group=- HEH_Goal}', "");
Error('\p{Jg=_	Heh_Goal/a/}');
Error('\P{Jg=_	Heh_Goal/a/}');
Expect(1, 1730, '\p{Jg=hehgoal}', "");
Expect(0, 1730, '\p{^Jg=hehgoal}', "");
Expect(0, 1730, '\P{Jg=hehgoal}', "");
Expect(1, 1730, '\P{^Jg=hehgoal}', "");
Expect(0, 1731, '\p{Jg=hehgoal}', "");
Expect(1, 1731, '\p{^Jg=hehgoal}', "");
Expect(1, 1731, '\P{Jg=hehgoal}', "");
Expect(0, 1731, '\P{^Jg=hehgoal}', "");
Expect(1, 1730, '\p{Jg:   _-HEH_Goal}', "");
Expect(0, 1730, '\p{^Jg:   _-HEH_Goal}', "");
Expect(0, 1730, '\P{Jg:   _-HEH_Goal}', "");
Expect(1, 1730, '\P{^Jg:   _-HEH_Goal}', "");
Expect(0, 1731, '\p{Jg:   _-HEH_Goal}', "");
Expect(1, 1731, '\p{^Jg:   _-HEH_Goal}', "");
Expect(1, 1731, '\P{Jg:   _-HEH_Goal}', "");
Expect(0, 1731, '\P{^Jg:   _-HEH_Goal}', "");
Error('\p{Is_Joining_Group=-/a/heh_goal}');
Error('\P{Is_Joining_Group=-/a/heh_goal}');
Expect(1, 1730, '\p{Is_Joining_Group=hehgoal}', "");
Expect(0, 1730, '\p{^Is_Joining_Group=hehgoal}', "");
Expect(0, 1730, '\P{Is_Joining_Group=hehgoal}', "");
Expect(1, 1730, '\P{^Is_Joining_Group=hehgoal}', "");
Expect(0, 1731, '\p{Is_Joining_Group=hehgoal}', "");
Expect(1, 1731, '\p{^Is_Joining_Group=hehgoal}', "");
Expect(1, 1731, '\P{Is_Joining_Group=hehgoal}', "");
Expect(0, 1731, '\P{^Is_Joining_Group=hehgoal}', "");
Expect(1, 1730, '\p{Is_Joining_Group= 	HEH_goal}', "");
Expect(0, 1730, '\p{^Is_Joining_Group= 	HEH_goal}', "");
Expect(0, 1730, '\P{Is_Joining_Group= 	HEH_goal}', "");
Expect(1, 1730, '\P{^Is_Joining_Group= 	HEH_goal}', "");
Expect(0, 1731, '\p{Is_Joining_Group= 	HEH_goal}', "");
Expect(1, 1731, '\p{^Is_Joining_Group= 	HEH_goal}', "");
Expect(1, 1731, '\P{Is_Joining_Group= 	HEH_goal}', "");
Expect(0, 1731, '\P{^Is_Joining_Group= 	HEH_goal}', "");
Error('\p{Is_Jg=	HEH_Goal:=}');
Error('\P{Is_Jg=	HEH_Goal:=}');
Expect(1, 1730, '\p{Is_Jg: hehgoal}', "");
Expect(0, 1730, '\p{^Is_Jg: hehgoal}', "");
Expect(0, 1730, '\P{Is_Jg: hehgoal}', "");
Expect(1, 1730, '\P{^Is_Jg: hehgoal}', "");
Expect(0, 1731, '\p{Is_Jg: hehgoal}', "");
Expect(1, 1731, '\p{^Is_Jg: hehgoal}', "");
Expect(1, 1731, '\P{Is_Jg: hehgoal}', "");
Expect(0, 1731, '\P{^Is_Jg: hehgoal}', "");
Expect(1, 1730, '\p{Is_Jg=-_Heh_goal}', "");
Expect(0, 1730, '\p{^Is_Jg=-_Heh_goal}', "");
Expect(0, 1730, '\P{Is_Jg=-_Heh_goal}', "");
Expect(1, 1730, '\P{^Is_Jg=-_Heh_goal}', "");
Expect(0, 1731, '\p{Is_Jg=-_Heh_goal}', "");
Expect(1, 1731, '\p{^Is_Jg=-_Heh_goal}', "");
Expect(1, 1731, '\P{Is_Jg=-_Heh_goal}', "");
Expect(0, 1731, '\P{^Is_Jg=-_Heh_goal}', "");
Error('\p{Joining_Group=_ Heth/a/}');
Error('\P{Joining_Group=_ Heth/a/}');
Expect(1, 1818, '\p{Joining_Group=heth}', "");
Expect(0, 1818, '\p{^Joining_Group=heth}', "");
Expect(0, 1818, '\P{Joining_Group=heth}', "");
Expect(1, 1818, '\P{^Joining_Group=heth}', "");
Expect(0, 1819, '\p{Joining_Group=heth}', "");
Expect(1, 1819, '\p{^Joining_Group=heth}', "");
Expect(1, 1819, '\P{Joining_Group=heth}', "");
Expect(0, 1819, '\P{^Joining_Group=heth}', "");
Expect(1, 1818, '\p{Joining_Group=Heth}', "");
Expect(0, 1818, '\p{^Joining_Group=Heth}', "");
Expect(0, 1818, '\P{Joining_Group=Heth}', "");
Expect(1, 1818, '\P{^Joining_Group=Heth}', "");
Expect(0, 1819, '\p{Joining_Group=Heth}', "");
Expect(1, 1819, '\p{^Joining_Group=Heth}', "");
Expect(1, 1819, '\P{Joining_Group=Heth}', "");
Expect(0, 1819, '\P{^Joining_Group=Heth}', "");
Error('\p{Jg=/a/  HETH}');
Error('\P{Jg=/a/  HETH}');
Expect(1, 1818, '\p{Jg=heth}', "");
Expect(0, 1818, '\p{^Jg=heth}', "");
Expect(0, 1818, '\P{Jg=heth}', "");
Expect(1, 1818, '\P{^Jg=heth}', "");
Expect(0, 1819, '\p{Jg=heth}', "");
Expect(1, 1819, '\p{^Jg=heth}', "");
Expect(1, 1819, '\P{Jg=heth}', "");
Expect(0, 1819, '\P{^Jg=heth}', "");
Expect(1, 1818, '\p{Jg=-	heth}', "");
Expect(0, 1818, '\p{^Jg=-	heth}', "");
Expect(0, 1818, '\P{Jg=-	heth}', "");
Expect(1, 1818, '\P{^Jg=-	heth}', "");
Expect(0, 1819, '\p{Jg=-	heth}', "");
Expect(1, 1819, '\p{^Jg=-	heth}', "");
Expect(1, 1819, '\P{Jg=-	heth}', "");
Expect(0, 1819, '\P{^Jg=-	heth}', "");
Error('\p{Is_Joining_Group=-/a/Heth}');
Error('\P{Is_Joining_Group=-/a/Heth}');
Expect(1, 1818, '\p{Is_Joining_Group=heth}', "");
Expect(0, 1818, '\p{^Is_Joining_Group=heth}', "");
Expect(0, 1818, '\P{Is_Joining_Group=heth}', "");
Expect(1, 1818, '\P{^Is_Joining_Group=heth}', "");
Expect(0, 1819, '\p{Is_Joining_Group=heth}', "");
Expect(1, 1819, '\p{^Is_Joining_Group=heth}', "");
Expect(1, 1819, '\P{Is_Joining_Group=heth}', "");
Expect(0, 1819, '\P{^Is_Joining_Group=heth}', "");
Expect(1, 1818, '\p{Is_Joining_Group:	-_HETH}', "");
Expect(0, 1818, '\p{^Is_Joining_Group:	-_HETH}', "");
Expect(0, 1818, '\P{Is_Joining_Group:	-_HETH}', "");
Expect(1, 1818, '\P{^Is_Joining_Group:	-_HETH}', "");
Expect(0, 1819, '\p{Is_Joining_Group:	-_HETH}', "");
Expect(1, 1819, '\p{^Is_Joining_Group:	-_HETH}', "");
Expect(1, 1819, '\P{Is_Joining_Group:	-_HETH}', "");
Expect(0, 1819, '\P{^Is_Joining_Group:	-_HETH}', "");
Error('\p{Is_Jg=	 HETH/a/}');
Error('\P{Is_Jg=	 HETH/a/}');
Expect(1, 1818, '\p{Is_Jg:	heth}', "");
Expect(0, 1818, '\p{^Is_Jg:	heth}', "");
Expect(0, 1818, '\P{Is_Jg:	heth}', "");
Expect(1, 1818, '\P{^Is_Jg:	heth}', "");
Expect(0, 1819, '\p{Is_Jg:	heth}', "");
Expect(1, 1819, '\p{^Is_Jg:	heth}', "");
Expect(1, 1819, '\P{Is_Jg:	heth}', "");
Expect(0, 1819, '\P{^Is_Jg:	heth}', "");
Expect(1, 1818, '\p{Is_Jg= Heth}', "");
Expect(0, 1818, '\p{^Is_Jg= Heth}', "");
Expect(0, 1818, '\P{Is_Jg= Heth}', "");
Expect(1, 1818, '\P{^Is_Jg= Heth}', "");
Expect(0, 1819, '\p{Is_Jg= Heth}', "");
Expect(1, 1819, '\p{^Is_Jg= Heth}', "");
Expect(1, 1819, '\P{Is_Jg= Heth}', "");
Expect(0, 1819, '\P{^Is_Jg= Heth}', "");
Error('\p{Joining_Group=	_Kaf:=}');
Error('\P{Joining_Group=	_Kaf:=}');
Expect(1, 1919, '\p{Joining_Group=kaf}', "");
Expect(0, 1919, '\p{^Joining_Group=kaf}', "");
Expect(0, 1919, '\P{Joining_Group=kaf}', "");
Expect(1, 1919, '\P{^Joining_Group=kaf}', "");
Expect(0, 1920, '\p{Joining_Group=kaf}', "");
Expect(1, 1920, '\p{^Joining_Group=kaf}', "");
Expect(1, 1920, '\P{Joining_Group=kaf}', "");
Expect(0, 1920, '\P{^Joining_Group=kaf}', "");
Expect(1, 1919, '\p{Joining_Group= 	kaf}', "");
Expect(0, 1919, '\p{^Joining_Group= 	kaf}', "");
Expect(0, 1919, '\P{Joining_Group= 	kaf}', "");
Expect(1, 1919, '\P{^Joining_Group= 	kaf}', "");
Expect(0, 1920, '\p{Joining_Group= 	kaf}', "");
Expect(1, 1920, '\p{^Joining_Group= 	kaf}', "");
Expect(1, 1920, '\P{Joining_Group= 	kaf}', "");
Expect(0, 1920, '\P{^Joining_Group= 	kaf}', "");
Error('\p{Jg=/a/	_KAF}');
Error('\P{Jg=/a/	_KAF}');
Expect(1, 1919, '\p{Jg=kaf}', "");
Expect(0, 1919, '\p{^Jg=kaf}', "");
Expect(0, 1919, '\P{Jg=kaf}', "");
Expect(1, 1919, '\P{^Jg=kaf}', "");
Expect(0, 1920, '\p{Jg=kaf}', "");
Expect(1, 1920, '\p{^Jg=kaf}', "");
Expect(1, 1920, '\P{Jg=kaf}', "");
Expect(0, 1920, '\P{^Jg=kaf}', "");
Expect(1, 1919, '\p{Jg=-kaf}', "");
Expect(0, 1919, '\p{^Jg=-kaf}', "");
Expect(0, 1919, '\P{Jg=-kaf}', "");
Expect(1, 1919, '\P{^Jg=-kaf}', "");
Expect(0, 1920, '\p{Jg=-kaf}', "");
Expect(1, 1920, '\p{^Jg=-kaf}', "");
Expect(1, 1920, '\P{Jg=-kaf}', "");
Expect(0, 1920, '\P{^Jg=-kaf}', "");
Error('\p{Is_Joining_Group=/a/Kaf}');
Error('\P{Is_Joining_Group=/a/Kaf}');
Expect(1, 1919, '\p{Is_Joining_Group=kaf}', "");
Expect(0, 1919, '\p{^Is_Joining_Group=kaf}', "");
Expect(0, 1919, '\P{Is_Joining_Group=kaf}', "");
Expect(1, 1919, '\P{^Is_Joining_Group=kaf}', "");
Expect(0, 1920, '\p{Is_Joining_Group=kaf}', "");
Expect(1, 1920, '\p{^Is_Joining_Group=kaf}', "");
Expect(1, 1920, '\P{Is_Joining_Group=kaf}', "");
Expect(0, 1920, '\P{^Is_Joining_Group=kaf}', "");
Expect(1, 1919, '\p{Is_Joining_Group=_ Kaf}', "");
Expect(0, 1919, '\p{^Is_Joining_Group=_ Kaf}', "");
Expect(0, 1919, '\P{Is_Joining_Group=_ Kaf}', "");
Expect(1, 1919, '\P{^Is_Joining_Group=_ Kaf}', "");
Expect(0, 1920, '\p{Is_Joining_Group=_ Kaf}', "");
Expect(1, 1920, '\p{^Is_Joining_Group=_ Kaf}', "");
Expect(1, 1920, '\P{Is_Joining_Group=_ Kaf}', "");
Expect(0, 1920, '\P{^Is_Joining_Group=_ Kaf}', "");
Error('\p{Is_Jg= 	KAF:=}');
Error('\P{Is_Jg= 	KAF:=}');
Expect(1, 1919, '\p{Is_Jg: kaf}', "");
Expect(0, 1919, '\p{^Is_Jg: kaf}', "");
Expect(0, 1919, '\P{Is_Jg: kaf}', "");
Expect(1, 1919, '\P{^Is_Jg: kaf}', "");
Expect(0, 1920, '\p{Is_Jg: kaf}', "");
Expect(1, 1920, '\p{^Is_Jg: kaf}', "");
Expect(1, 1920, '\P{Is_Jg: kaf}', "");
Expect(0, 1920, '\P{^Is_Jg: kaf}', "");
Expect(1, 1919, '\p{Is_Jg=_-Kaf}', "");
Expect(0, 1919, '\p{^Is_Jg=_-Kaf}', "");
Expect(0, 1919, '\P{Is_Jg=_-Kaf}', "");
Expect(1, 1919, '\P{^Is_Jg=_-Kaf}', "");
Expect(0, 1920, '\p{Is_Jg=_-Kaf}', "");
Expect(1, 1920, '\p{^Is_Jg=_-Kaf}', "");
Expect(1, 1920, '\P{Is_Jg=_-Kaf}', "");
Expect(0, 1920, '\P{^Is_Jg=_-Kaf}', "");
Error('\p{Joining_Group=	:=kaph}');
Error('\P{Joining_Group=	:=kaph}');
Expect(1, 1823, '\p{Joining_Group=kaph}', "");
Expect(0, 1823, '\p{^Joining_Group=kaph}', "");
Expect(0, 1823, '\P{Joining_Group=kaph}', "");
Expect(1, 1823, '\P{^Joining_Group=kaph}', "");
Expect(0, 1824, '\p{Joining_Group=kaph}', "");
Expect(1, 1824, '\p{^Joining_Group=kaph}', "");
Expect(1, 1824, '\P{Joining_Group=kaph}', "");
Expect(0, 1824, '\P{^Joining_Group=kaph}', "");
Error('\p{Jg=/a/kaph}');
Error('\P{Jg=/a/kaph}');
Expect(1, 1823, '\p{Jg=kaph}', "");
Expect(0, 1823, '\p{^Jg=kaph}', "");
Expect(0, 1823, '\P{Jg=kaph}', "");
Expect(1, 1823, '\P{^Jg=kaph}', "");
Expect(0, 1824, '\p{Jg=kaph}', "");
Expect(1, 1824, '\p{^Jg=kaph}', "");
Expect(1, 1824, '\P{Jg=kaph}', "");
Expect(0, 1824, '\P{^Jg=kaph}', "");
Expect(1, 1823, '\p{Jg=	 Kaph}', "");
Expect(0, 1823, '\p{^Jg=	 Kaph}', "");
Expect(0, 1823, '\P{Jg=	 Kaph}', "");
Expect(1, 1823, '\P{^Jg=	 Kaph}', "");
Expect(0, 1824, '\p{Jg=	 Kaph}', "");
Expect(1, 1824, '\p{^Jg=	 Kaph}', "");
Expect(1, 1824, '\P{Jg=	 Kaph}', "");
Expect(0, 1824, '\P{^Jg=	 Kaph}', "");
Error('\p{Is_Joining_Group=		Kaph:=}');
Error('\P{Is_Joining_Group=		Kaph:=}');
Expect(1, 1823, '\p{Is_Joining_Group=kaph}', "");
Expect(0, 1823, '\p{^Is_Joining_Group=kaph}', "");
Expect(0, 1823, '\P{Is_Joining_Group=kaph}', "");
Expect(1, 1823, '\P{^Is_Joining_Group=kaph}', "");
Expect(0, 1824, '\p{Is_Joining_Group=kaph}', "");
Expect(1, 1824, '\p{^Is_Joining_Group=kaph}', "");
Expect(1, 1824, '\P{Is_Joining_Group=kaph}', "");
Expect(0, 1824, '\P{^Is_Joining_Group=kaph}', "");
Expect(1, 1823, '\p{Is_Joining_Group=_	Kaph}', "");
Expect(0, 1823, '\p{^Is_Joining_Group=_	Kaph}', "");
Expect(0, 1823, '\P{Is_Joining_Group=_	Kaph}', "");
Expect(1, 1823, '\P{^Is_Joining_Group=_	Kaph}', "");
Expect(0, 1824, '\p{Is_Joining_Group=_	Kaph}', "");
Expect(1, 1824, '\p{^Is_Joining_Group=_	Kaph}', "");
Expect(1, 1824, '\P{Is_Joining_Group=_	Kaph}', "");
Expect(0, 1824, '\P{^Is_Joining_Group=_	Kaph}', "");
Error('\p{Is_Jg=  Kaph/a/}');
Error('\P{Is_Jg=  Kaph/a/}');
Expect(1, 1823, '\p{Is_Jg=kaph}', "");
Expect(0, 1823, '\p{^Is_Jg=kaph}', "");
Expect(0, 1823, '\P{Is_Jg=kaph}', "");
Expect(1, 1823, '\P{^Is_Jg=kaph}', "");
Expect(0, 1824, '\p{Is_Jg=kaph}', "");
Expect(1, 1824, '\p{^Is_Jg=kaph}', "");
Expect(1, 1824, '\P{Is_Jg=kaph}', "");
Expect(0, 1824, '\P{^Is_Jg=kaph}', "");
Expect(1, 1823, '\p{Is_Jg= kaph}', "");
Expect(0, 1823, '\p{^Is_Jg= kaph}', "");
Expect(0, 1823, '\P{Is_Jg= kaph}', "");
Expect(1, 1823, '\P{^Is_Jg= kaph}', "");
Expect(0, 1824, '\p{Is_Jg= kaph}', "");
Expect(1, 1824, '\p{^Is_Jg= kaph}', "");
Expect(1, 1824, '\P{Is_Jg= kaph}', "");
Expect(0, 1824, '\P{^Is_Jg= kaph}', "");
Error('\p{Joining_Group=/a/_	Khaph}');
Error('\P{Joining_Group=/a/_	Khaph}');
Expect(1, 1870, '\p{Joining_Group=khaph}', "");
Expect(0, 1870, '\p{^Joining_Group=khaph}', "");
Expect(0, 1870, '\P{Joining_Group=khaph}', "");
Expect(1, 1870, '\P{^Joining_Group=khaph}', "");
Expect(0, 1871, '\p{Joining_Group=khaph}', "");
Expect(1, 1871, '\p{^Joining_Group=khaph}', "");
Expect(1, 1871, '\P{Joining_Group=khaph}', "");
Expect(0, 1871, '\P{^Joining_Group=khaph}', "");
Expect(1, 1870, '\p{Joining_Group= 	KHAPH}', "");
Expect(0, 1870, '\p{^Joining_Group= 	KHAPH}', "");
Expect(0, 1870, '\P{Joining_Group= 	KHAPH}', "");
Expect(1, 1870, '\P{^Joining_Group= 	KHAPH}', "");
Expect(0, 1871, '\p{Joining_Group= 	KHAPH}', "");
Expect(1, 1871, '\p{^Joining_Group= 	KHAPH}', "");
Expect(1, 1871, '\P{Joining_Group= 	KHAPH}', "");
Expect(0, 1871, '\P{^Joining_Group= 	KHAPH}', "");
Error('\p{Jg=	_khaph:=}');
Error('\P{Jg=	_khaph:=}');
Expect(1, 1870, '\p{Jg=khaph}', "");
Expect(0, 1870, '\p{^Jg=khaph}', "");
Expect(0, 1870, '\P{Jg=khaph}', "");
Expect(1, 1870, '\P{^Jg=khaph}', "");
Expect(0, 1871, '\p{Jg=khaph}', "");
Expect(1, 1871, '\p{^Jg=khaph}', "");
Expect(1, 1871, '\P{Jg=khaph}', "");
Expect(0, 1871, '\P{^Jg=khaph}', "");
Expect(1, 1870, '\p{Jg= 	KHAPH}', "");
Expect(0, 1870, '\p{^Jg= 	KHAPH}', "");
Expect(0, 1870, '\P{Jg= 	KHAPH}', "");
Expect(1, 1870, '\P{^Jg= 	KHAPH}', "");
Expect(0, 1871, '\p{Jg= 	KHAPH}', "");
Expect(1, 1871, '\p{^Jg= 	KHAPH}', "");
Expect(1, 1871, '\P{Jg= 	KHAPH}', "");
Expect(0, 1871, '\P{^Jg= 	KHAPH}', "");
Error('\p{Is_Joining_Group=:=	 KHAPH}');
Error('\P{Is_Joining_Group=:=	 KHAPH}');
Expect(1, 1870, '\p{Is_Joining_Group=khaph}', "");
Expect(0, 1870, '\p{^Is_Joining_Group=khaph}', "");
Expect(0, 1870, '\P{Is_Joining_Group=khaph}', "");
Expect(1, 1870, '\P{^Is_Joining_Group=khaph}', "");
Expect(0, 1871, '\p{Is_Joining_Group=khaph}', "");
Expect(1, 1871, '\p{^Is_Joining_Group=khaph}', "");
Expect(1, 1871, '\P{Is_Joining_Group=khaph}', "");
Expect(0, 1871, '\P{^Is_Joining_Group=khaph}', "");
Expect(1, 1870, '\p{Is_Joining_Group= _KHAPH}', "");
Expect(0, 1870, '\p{^Is_Joining_Group= _KHAPH}', "");
Expect(0, 1870, '\P{Is_Joining_Group= _KHAPH}', "");
Expect(1, 1870, '\P{^Is_Joining_Group= _KHAPH}', "");
Expect(0, 1871, '\p{Is_Joining_Group= _KHAPH}', "");
Expect(1, 1871, '\p{^Is_Joining_Group= _KHAPH}', "");
Expect(1, 1871, '\P{Is_Joining_Group= _KHAPH}', "");
Expect(0, 1871, '\P{^Is_Joining_Group= _KHAPH}', "");
Error('\p{Is_Jg=	/a/Khaph}');
Error('\P{Is_Jg=	/a/Khaph}');
Expect(1, 1870, '\p{Is_Jg=khaph}', "");
Expect(0, 1870, '\p{^Is_Jg=khaph}', "");
Expect(0, 1870, '\P{Is_Jg=khaph}', "");
Expect(1, 1870, '\P{^Is_Jg=khaph}', "");
Expect(0, 1871, '\p{Is_Jg=khaph}', "");
Expect(1, 1871, '\p{^Is_Jg=khaph}', "");
Expect(1, 1871, '\P{Is_Jg=khaph}', "");
Expect(0, 1871, '\P{^Is_Jg=khaph}', "");
Expect(1, 1870, '\p{Is_Jg=-	KHAPH}', "");
Expect(0, 1870, '\p{^Is_Jg=-	KHAPH}', "");
Expect(0, 1870, '\P{Is_Jg=-	KHAPH}', "");
Expect(1, 1870, '\P{^Is_Jg=-	KHAPH}', "");
Expect(0, 1871, '\p{Is_Jg=-	KHAPH}', "");
Expect(1, 1871, '\p{^Is_Jg=-	KHAPH}', "");
Expect(1, 1871, '\P{Is_Jg=-	KHAPH}', "");
Expect(0, 1871, '\P{^Is_Jg=-	KHAPH}', "");
Error('\p{Joining_Group=	knotted_HEH/a/}');
Error('\P{Joining_Group=	knotted_HEH/a/}');
Expect(1, 1791, '\p{Joining_Group=knottedheh}', "");
Expect(0, 1791, '\p{^Joining_Group=knottedheh}', "");
Expect(0, 1791, '\P{Joining_Group=knottedheh}', "");
Expect(1, 1791, '\P{^Joining_Group=knottedheh}', "");
Expect(0, 1792, '\p{Joining_Group=knottedheh}', "");
Expect(1, 1792, '\p{^Joining_Group=knottedheh}', "");
Expect(1, 1792, '\P{Joining_Group=knottedheh}', "");
Expect(0, 1792, '\P{^Joining_Group=knottedheh}', "");
Expect(1, 1791, '\p{Joining_Group=_ Knotted_Heh}', "");
Expect(0, 1791, '\p{^Joining_Group=_ Knotted_Heh}', "");
Expect(0, 1791, '\P{Joining_Group=_ Knotted_Heh}', "");
Expect(1, 1791, '\P{^Joining_Group=_ Knotted_Heh}', "");
Expect(0, 1792, '\p{Joining_Group=_ Knotted_Heh}', "");
Expect(1, 1792, '\p{^Joining_Group=_ Knotted_Heh}', "");
Expect(1, 1792, '\P{Joining_Group=_ Knotted_Heh}', "");
Expect(0, 1792, '\P{^Joining_Group=_ Knotted_Heh}', "");
Error('\p{Jg=/a/	_knotted_HEH}');
Error('\P{Jg=/a/	_knotted_HEH}');
Expect(1, 1791, '\p{Jg=knottedheh}', "");
Expect(0, 1791, '\p{^Jg=knottedheh}', "");
Expect(0, 1791, '\P{Jg=knottedheh}', "");
Expect(1, 1791, '\P{^Jg=knottedheh}', "");
Expect(0, 1792, '\p{Jg=knottedheh}', "");
Expect(1, 1792, '\p{^Jg=knottedheh}', "");
Expect(1, 1792, '\P{Jg=knottedheh}', "");
Expect(0, 1792, '\P{^Jg=knottedheh}', "");
Expect(1, 1791, '\p{Jg=-_knotted_Heh}', "");
Expect(0, 1791, '\p{^Jg=-_knotted_Heh}', "");
Expect(0, 1791, '\P{Jg=-_knotted_Heh}', "");
Expect(1, 1791, '\P{^Jg=-_knotted_Heh}', "");
Expect(0, 1792, '\p{Jg=-_knotted_Heh}', "");
Expect(1, 1792, '\p{^Jg=-_knotted_Heh}', "");
Expect(1, 1792, '\P{Jg=-_knotted_Heh}', "");
Expect(0, 1792, '\P{^Jg=-_knotted_Heh}', "");
Error('\p{Is_Joining_Group=:=	knotted_Heh}');
Error('\P{Is_Joining_Group=:=	knotted_Heh}');
Expect(1, 1791, '\p{Is_Joining_Group=knottedheh}', "");
Expect(0, 1791, '\p{^Is_Joining_Group=knottedheh}', "");
Expect(0, 1791, '\P{Is_Joining_Group=knottedheh}', "");
Expect(1, 1791, '\P{^Is_Joining_Group=knottedheh}', "");
Expect(0, 1792, '\p{Is_Joining_Group=knottedheh}', "");
Expect(1, 1792, '\p{^Is_Joining_Group=knottedheh}', "");
Expect(1, 1792, '\P{Is_Joining_Group=knottedheh}', "");
Expect(0, 1792, '\P{^Is_Joining_Group=knottedheh}', "");
Expect(1, 1791, '\p{Is_Joining_Group=_Knotted_heh}', "");
Expect(0, 1791, '\p{^Is_Joining_Group=_Knotted_heh}', "");
Expect(0, 1791, '\P{Is_Joining_Group=_Knotted_heh}', "");
Expect(1, 1791, '\P{^Is_Joining_Group=_Knotted_heh}', "");
Expect(0, 1792, '\p{Is_Joining_Group=_Knotted_heh}', "");
Expect(1, 1792, '\p{^Is_Joining_Group=_Knotted_heh}', "");
Expect(1, 1792, '\P{Is_Joining_Group=_Knotted_heh}', "");
Expect(0, 1792, '\P{^Is_Joining_Group=_Knotted_heh}', "");
Error('\p{Is_Jg:	:=	_Knotted_Heh}');
Error('\P{Is_Jg:	:=	_Knotted_Heh}');
Expect(1, 1791, '\p{Is_Jg=knottedheh}', "");
Expect(0, 1791, '\p{^Is_Jg=knottedheh}', "");
Expect(0, 1791, '\P{Is_Jg=knottedheh}', "");
Expect(1, 1791, '\P{^Is_Jg=knottedheh}', "");
Expect(0, 1792, '\p{Is_Jg=knottedheh}', "");
Expect(1, 1792, '\p{^Is_Jg=knottedheh}', "");
Expect(1, 1792, '\P{Is_Jg=knottedheh}', "");
Expect(0, 1792, '\P{^Is_Jg=knottedheh}', "");
Expect(1, 1791, '\p{Is_Jg=_ Knotted_HEH}', "");
Expect(0, 1791, '\p{^Is_Jg=_ Knotted_HEH}', "");
Expect(0, 1791, '\P{Is_Jg=_ Knotted_HEH}', "");
Expect(1, 1791, '\P{^Is_Jg=_ Knotted_HEH}', "");
Expect(0, 1792, '\p{Is_Jg=_ Knotted_HEH}', "");
Expect(1, 1792, '\p{^Is_Jg=_ Knotted_HEH}', "");
Expect(1, 1792, '\P{Is_Jg=_ Knotted_HEH}', "");
Expect(0, 1792, '\P{^Is_Jg=_ Knotted_HEH}', "");
Error('\p{Joining_Group=	/a/lam}');
Error('\P{Joining_Group=	/a/lam}');
Expect(1, 2214, '\p{Joining_Group=lam}', "");
Expect(0, 2214, '\p{^Joining_Group=lam}', "");
Expect(0, 2214, '\P{Joining_Group=lam}', "");
Expect(1, 2214, '\P{^Joining_Group=lam}', "");
Expect(0, 2215, '\p{Joining_Group=lam}', "");
Expect(1, 2215, '\p{^Joining_Group=lam}', "");
Expect(1, 2215, '\P{Joining_Group=lam}', "");
Expect(0, 2215, '\P{^Joining_Group=lam}', "");
Expect(1, 2214, '\p{Joining_Group=-LAM}', "");
Expect(0, 2214, '\p{^Joining_Group=-LAM}', "");
Expect(0, 2214, '\P{Joining_Group=-LAM}', "");
Expect(1, 2214, '\P{^Joining_Group=-LAM}', "");
Expect(0, 2215, '\p{Joining_Group=-LAM}', "");
Expect(1, 2215, '\p{^Joining_Group=-LAM}', "");
Expect(1, 2215, '\P{Joining_Group=-LAM}', "");
Expect(0, 2215, '\P{^Joining_Group=-LAM}', "");
Error('\p{Jg=	:=lam}');
Error('\P{Jg=	:=lam}');
Expect(1, 2214, '\p{Jg=lam}', "");
Expect(0, 2214, '\p{^Jg=lam}', "");
Expect(0, 2214, '\P{Jg=lam}', "");
Expect(1, 2214, '\P{^Jg=lam}', "");
Expect(0, 2215, '\p{Jg=lam}', "");
Expect(1, 2215, '\p{^Jg=lam}', "");
Expect(1, 2215, '\P{Jg=lam}', "");
Expect(0, 2215, '\P{^Jg=lam}', "");
Expect(1, 2214, '\p{Jg:	-LAM}', "");
Expect(0, 2214, '\p{^Jg:	-LAM}', "");
Expect(0, 2214, '\P{Jg:	-LAM}', "");
Expect(1, 2214, '\P{^Jg:	-LAM}', "");
Expect(0, 2215, '\p{Jg:	-LAM}', "");
Expect(1, 2215, '\p{^Jg:	-LAM}', "");
Expect(1, 2215, '\P{Jg:	-LAM}', "");
Expect(0, 2215, '\P{^Jg:	-LAM}', "");
Error('\p{Is_Joining_Group=:=-	Lam}');
Error('\P{Is_Joining_Group=:=-	Lam}');
Expect(1, 2214, '\p{Is_Joining_Group=lam}', "");
Expect(0, 2214, '\p{^Is_Joining_Group=lam}', "");
Expect(0, 2214, '\P{Is_Joining_Group=lam}', "");
Expect(1, 2214, '\P{^Is_Joining_Group=lam}', "");
Expect(0, 2215, '\p{Is_Joining_Group=lam}', "");
Expect(1, 2215, '\p{^Is_Joining_Group=lam}', "");
Expect(1, 2215, '\P{Is_Joining_Group=lam}', "");
Expect(0, 2215, '\P{^Is_Joining_Group=lam}', "");
Expect(1, 2214, '\p{Is_Joining_Group=-LAM}', "");
Expect(0, 2214, '\p{^Is_Joining_Group=-LAM}', "");
Expect(0, 2214, '\P{Is_Joining_Group=-LAM}', "");
Expect(1, 2214, '\P{^Is_Joining_Group=-LAM}', "");
Expect(0, 2215, '\p{Is_Joining_Group=-LAM}', "");
Expect(1, 2215, '\p{^Is_Joining_Group=-LAM}', "");
Expect(1, 2215, '\P{Is_Joining_Group=-LAM}', "");
Expect(0, 2215, '\P{^Is_Joining_Group=-LAM}', "");
Error('\p{Is_Jg= :=lam}');
Error('\P{Is_Jg= :=lam}');
Expect(1, 2214, '\p{Is_Jg=lam}', "");
Expect(0, 2214, '\p{^Is_Jg=lam}', "");
Expect(0, 2214, '\P{Is_Jg=lam}', "");
Expect(1, 2214, '\P{^Is_Jg=lam}', "");
Expect(0, 2215, '\p{Is_Jg=lam}', "");
Expect(1, 2215, '\p{^Is_Jg=lam}', "");
Expect(1, 2215, '\P{Is_Jg=lam}', "");
Expect(0, 2215, '\P{^Is_Jg=lam}', "");
Expect(1, 2214, '\p{Is_Jg=	LAM}', "");
Expect(0, 2214, '\p{^Is_Jg=	LAM}', "");
Expect(0, 2214, '\P{Is_Jg=	LAM}', "");
Expect(1, 2214, '\P{^Is_Jg=	LAM}', "");
Expect(0, 2215, '\p{Is_Jg=	LAM}', "");
Expect(1, 2215, '\p{^Is_Jg=	LAM}', "");
Expect(1, 2215, '\P{Is_Jg=	LAM}', "");
Expect(0, 2215, '\P{^Is_Jg=	LAM}', "");
Error('\p{Joining_Group=-:=Lamadh}');
Error('\P{Joining_Group=-:=Lamadh}');
Expect(1, 1824, '\p{Joining_Group=lamadh}', "");
Expect(0, 1824, '\p{^Joining_Group=lamadh}', "");
Expect(0, 1824, '\P{Joining_Group=lamadh}', "");
Expect(1, 1824, '\P{^Joining_Group=lamadh}', "");
Expect(0, 1825, '\p{Joining_Group=lamadh}', "");
Expect(1, 1825, '\p{^Joining_Group=lamadh}', "");
Expect(1, 1825, '\P{Joining_Group=lamadh}', "");
Expect(0, 1825, '\P{^Joining_Group=lamadh}', "");
Expect(1, 1824, '\p{Joining_Group=-	Lamadh}', "");
Expect(0, 1824, '\p{^Joining_Group=-	Lamadh}', "");
Expect(0, 1824, '\P{Joining_Group=-	Lamadh}', "");
Expect(1, 1824, '\P{^Joining_Group=-	Lamadh}', "");
Expect(0, 1825, '\p{Joining_Group=-	Lamadh}', "");
Expect(1, 1825, '\p{^Joining_Group=-	Lamadh}', "");
Expect(1, 1825, '\P{Joining_Group=-	Lamadh}', "");
Expect(0, 1825, '\P{^Joining_Group=-	Lamadh}', "");
Error('\p{Jg=	_Lamadh/a/}');
Error('\P{Jg=	_Lamadh/a/}');
Expect(1, 1824, '\p{Jg=lamadh}', "");
Expect(0, 1824, '\p{^Jg=lamadh}', "");
Expect(0, 1824, '\P{Jg=lamadh}', "");
Expect(1, 1824, '\P{^Jg=lamadh}', "");
Expect(0, 1825, '\p{Jg=lamadh}', "");
Expect(1, 1825, '\p{^Jg=lamadh}', "");
Expect(1, 1825, '\P{Jg=lamadh}', "");
Expect(0, 1825, '\P{^Jg=lamadh}', "");
Expect(1, 1824, '\p{Jg=_	Lamadh}', "");
Expect(0, 1824, '\p{^Jg=_	Lamadh}', "");
Expect(0, 1824, '\P{Jg=_	Lamadh}', "");
Expect(1, 1824, '\P{^Jg=_	Lamadh}', "");
Expect(0, 1825, '\p{Jg=_	Lamadh}', "");
Expect(1, 1825, '\p{^Jg=_	Lamadh}', "");
Expect(1, 1825, '\P{Jg=_	Lamadh}', "");
Expect(0, 1825, '\P{^Jg=_	Lamadh}', "");
Error('\p{Is_Joining_Group=	:=Lamadh}');
Error('\P{Is_Joining_Group=	:=Lamadh}');
Expect(1, 1824, '\p{Is_Joining_Group=lamadh}', "");
Expect(0, 1824, '\p{^Is_Joining_Group=lamadh}', "");
Expect(0, 1824, '\P{Is_Joining_Group=lamadh}', "");
Expect(1, 1824, '\P{^Is_Joining_Group=lamadh}', "");
Expect(0, 1825, '\p{Is_Joining_Group=lamadh}', "");
Expect(1, 1825, '\p{^Is_Joining_Group=lamadh}', "");
Expect(1, 1825, '\P{Is_Joining_Group=lamadh}', "");
Expect(0, 1825, '\P{^Is_Joining_Group=lamadh}', "");
Expect(1, 1824, '\p{Is_Joining_Group= lamadh}', "");
Expect(0, 1824, '\p{^Is_Joining_Group= lamadh}', "");
Expect(0, 1824, '\P{Is_Joining_Group= lamadh}', "");
Expect(1, 1824, '\P{^Is_Joining_Group= lamadh}', "");
Expect(0, 1825, '\p{Is_Joining_Group= lamadh}', "");
Expect(1, 1825, '\p{^Is_Joining_Group= lamadh}', "");
Expect(1, 1825, '\P{Is_Joining_Group= lamadh}', "");
Expect(0, 1825, '\P{^Is_Joining_Group= lamadh}', "");
Error('\p{Is_Jg=-:=LAMADH}');
Error('\P{Is_Jg=-:=LAMADH}');
Expect(1, 1824, '\p{Is_Jg=lamadh}', "");
Expect(0, 1824, '\p{^Is_Jg=lamadh}', "");
Expect(0, 1824, '\P{Is_Jg=lamadh}', "");
Expect(1, 1824, '\P{^Is_Jg=lamadh}', "");
Expect(0, 1825, '\p{Is_Jg=lamadh}', "");
Expect(1, 1825, '\p{^Is_Jg=lamadh}', "");
Expect(1, 1825, '\P{Is_Jg=lamadh}', "");
Expect(0, 1825, '\P{^Is_Jg=lamadh}', "");
Expect(1, 1824, '\p{Is_Jg=_	LAMADH}', "");
Expect(0, 1824, '\p{^Is_Jg=_	LAMADH}', "");
Expect(0, 1824, '\P{Is_Jg=_	LAMADH}', "");
Expect(1, 1824, '\P{^Is_Jg=_	LAMADH}', "");
Expect(0, 1825, '\p{Is_Jg=_	LAMADH}', "");
Expect(1, 1825, '\p{^Is_Jg=_	LAMADH}', "");
Expect(1, 1825, '\P{Is_Jg=_	LAMADH}', "");
Expect(0, 1825, '\P{^Is_Jg=_	LAMADH}', "");
Error('\p{Joining_Group=--meem/a/}');
Error('\P{Joining_Group=--meem/a/}');
Expect(1, 2215, '\p{Joining_Group=meem}', "");
Expect(0, 2215, '\p{^Joining_Group=meem}', "");
Expect(0, 2215, '\P{Joining_Group=meem}', "");
Expect(1, 2215, '\P{^Joining_Group=meem}', "");
Expect(0, 2216, '\p{Joining_Group=meem}', "");
Expect(1, 2216, '\p{^Joining_Group=meem}', "");
Expect(1, 2216, '\P{Joining_Group=meem}', "");
Expect(0, 2216, '\P{^Joining_Group=meem}', "");
Expect(1, 2215, '\p{Joining_Group:    MEEM}', "");
Expect(0, 2215, '\p{^Joining_Group:    MEEM}', "");
Expect(0, 2215, '\P{Joining_Group:    MEEM}', "");
Expect(1, 2215, '\P{^Joining_Group:    MEEM}', "");
Expect(0, 2216, '\p{Joining_Group:    MEEM}', "");
Expect(1, 2216, '\p{^Joining_Group:    MEEM}', "");
Expect(1, 2216, '\P{Joining_Group:    MEEM}', "");
Expect(0, 2216, '\P{^Joining_Group:    MEEM}', "");
Error('\p{Jg:   _-meem:=}');
Error('\P{Jg:   _-meem:=}');
Expect(1, 2215, '\p{Jg=meem}', "");
Expect(0, 2215, '\p{^Jg=meem}', "");
Expect(0, 2215, '\P{Jg=meem}', "");
Expect(1, 2215, '\P{^Jg=meem}', "");
Expect(0, 2216, '\p{Jg=meem}', "");
Expect(1, 2216, '\p{^Jg=meem}', "");
Expect(1, 2216, '\P{Jg=meem}', "");
Expect(0, 2216, '\P{^Jg=meem}', "");
Expect(1, 2215, '\p{Jg=--meem}', "");
Expect(0, 2215, '\p{^Jg=--meem}', "");
Expect(0, 2215, '\P{Jg=--meem}', "");
Expect(1, 2215, '\P{^Jg=--meem}', "");
Expect(0, 2216, '\p{Jg=--meem}', "");
Expect(1, 2216, '\p{^Jg=--meem}', "");
Expect(1, 2216, '\P{Jg=--meem}', "");
Expect(0, 2216, '\P{^Jg=--meem}', "");
Error('\p{Is_Joining_Group=	-Meem/a/}');
Error('\P{Is_Joining_Group=	-Meem/a/}');
Expect(1, 2215, '\p{Is_Joining_Group=meem}', "");
Expect(0, 2215, '\p{^Is_Joining_Group=meem}', "");
Expect(0, 2215, '\P{Is_Joining_Group=meem}', "");
Expect(1, 2215, '\P{^Is_Joining_Group=meem}', "");
Expect(0, 2216, '\p{Is_Joining_Group=meem}', "");
Expect(1, 2216, '\p{^Is_Joining_Group=meem}', "");
Expect(1, 2216, '\P{Is_Joining_Group=meem}', "");
Expect(0, 2216, '\P{^Is_Joining_Group=meem}', "");
Expect(1, 2215, '\p{Is_Joining_Group= -Meem}', "");
Expect(0, 2215, '\p{^Is_Joining_Group= -Meem}', "");
Expect(0, 2215, '\P{Is_Joining_Group= -Meem}', "");
Expect(1, 2215, '\P{^Is_Joining_Group= -Meem}', "");
Expect(0, 2216, '\p{Is_Joining_Group= -Meem}', "");
Expect(1, 2216, '\p{^Is_Joining_Group= -Meem}', "");
Expect(1, 2216, '\P{Is_Joining_Group= -Meem}', "");
Expect(0, 2216, '\P{^Is_Joining_Group= -Meem}', "");
Error('\p{Is_Jg= Meem/a/}');
Error('\P{Is_Jg= Meem/a/}');
Expect(1, 2215, '\p{Is_Jg=meem}', "");
Expect(0, 2215, '\p{^Is_Jg=meem}', "");
Expect(0, 2215, '\P{Is_Jg=meem}', "");
Expect(1, 2215, '\P{^Is_Jg=meem}', "");
Expect(0, 2216, '\p{Is_Jg=meem}', "");
Expect(1, 2216, '\p{^Is_Jg=meem}', "");
Expect(1, 2216, '\P{Is_Jg=meem}', "");
Expect(0, 2216, '\P{^Is_Jg=meem}', "");
Expect(1, 2215, '\p{Is_Jg= -Meem}', "");
Expect(0, 2215, '\p{^Is_Jg= -Meem}', "");
Expect(0, 2215, '\P{Is_Jg= -Meem}', "");
Expect(1, 2215, '\P{^Is_Jg= -Meem}', "");
Expect(0, 2216, '\p{Is_Jg= -Meem}', "");
Expect(1, 2216, '\p{^Is_Jg= -Meem}', "");
Expect(1, 2216, '\P{Is_Jg= -Meem}', "");
Expect(0, 2216, '\P{^Is_Jg= -Meem}', "");
Error('\p{Joining_Group= :=Mim}');
Error('\P{Joining_Group= :=Mim}');
Expect(1, 1825, '\p{Joining_Group=mim}', "");
Expect(0, 1825, '\p{^Joining_Group=mim}', "");
Expect(0, 1825, '\P{Joining_Group=mim}', "");
Expect(1, 1825, '\P{^Joining_Group=mim}', "");
Expect(0, 1826, '\p{Joining_Group=mim}', "");
Expect(1, 1826, '\p{^Joining_Group=mim}', "");
Expect(1, 1826, '\P{Joining_Group=mim}', "");
Expect(0, 1826, '\P{^Joining_Group=mim}', "");
Expect(1, 1825, '\p{Joining_Group= 	mim}', "");
Expect(0, 1825, '\p{^Joining_Group= 	mim}', "");
Expect(0, 1825, '\P{Joining_Group= 	mim}', "");
Expect(1, 1825, '\P{^Joining_Group= 	mim}', "");
Expect(0, 1826, '\p{Joining_Group= 	mim}', "");
Expect(1, 1826, '\p{^Joining_Group= 	mim}', "");
Expect(1, 1826, '\P{Joining_Group= 	mim}', "");
Expect(0, 1826, '\P{^Joining_Group= 	mim}', "");
Error('\p{Jg=	:=Mim}');
Error('\P{Jg=	:=Mim}');
Expect(1, 1825, '\p{Jg:mim}', "");
Expect(0, 1825, '\p{^Jg:mim}', "");
Expect(0, 1825, '\P{Jg:mim}', "");
Expect(1, 1825, '\P{^Jg:mim}', "");
Expect(0, 1826, '\p{Jg:mim}', "");
Expect(1, 1826, '\p{^Jg:mim}', "");
Expect(1, 1826, '\P{Jg:mim}', "");
Expect(0, 1826, '\P{^Jg:mim}', "");
Expect(1, 1825, '\p{Jg=-_mim}', "");
Expect(0, 1825, '\p{^Jg=-_mim}', "");
Expect(0, 1825, '\P{Jg=-_mim}', "");
Expect(1, 1825, '\P{^Jg=-_mim}', "");
Expect(0, 1826, '\p{Jg=-_mim}', "");
Expect(1, 1826, '\p{^Jg=-_mim}', "");
Expect(1, 1826, '\P{Jg=-_mim}', "");
Expect(0, 1826, '\P{^Jg=-_mim}', "");
Error('\p{Is_Joining_Group=/a/ 	MIM}');
Error('\P{Is_Joining_Group=/a/ 	MIM}');
Expect(1, 1825, '\p{Is_Joining_Group=mim}', "");
Expect(0, 1825, '\p{^Is_Joining_Group=mim}', "");
Expect(0, 1825, '\P{Is_Joining_Group=mim}', "");
Expect(1, 1825, '\P{^Is_Joining_Group=mim}', "");
Expect(0, 1826, '\p{Is_Joining_Group=mim}', "");
Expect(1, 1826, '\p{^Is_Joining_Group=mim}', "");
Expect(1, 1826, '\P{Is_Joining_Group=mim}', "");
Expect(0, 1826, '\P{^Is_Joining_Group=mim}', "");
Expect(1, 1825, '\p{Is_Joining_Group=-	Mim}', "");
Expect(0, 1825, '\p{^Is_Joining_Group=-	Mim}', "");
Expect(0, 1825, '\P{Is_Joining_Group=-	Mim}', "");
Expect(1, 1825, '\P{^Is_Joining_Group=-	Mim}', "");
Expect(0, 1826, '\p{Is_Joining_Group=-	Mim}', "");
Expect(1, 1826, '\p{^Is_Joining_Group=-	Mim}', "");
Expect(1, 1826, '\P{Is_Joining_Group=-	Mim}', "");
Expect(0, 1826, '\P{^Is_Joining_Group=-	Mim}', "");
Error('\p{Is_Jg= :=mim}');
Error('\P{Is_Jg= :=mim}');
Expect(1, 1825, '\p{Is_Jg=mim}', "");
Expect(0, 1825, '\p{^Is_Jg=mim}', "");
Expect(0, 1825, '\P{Is_Jg=mim}', "");
Expect(1, 1825, '\P{^Is_Jg=mim}', "");
Expect(0, 1826, '\p{Is_Jg=mim}', "");
Expect(1, 1826, '\p{^Is_Jg=mim}', "");
Expect(1, 1826, '\P{Is_Jg=mim}', "");
Expect(0, 1826, '\P{^Is_Jg=mim}', "");
Expect(1, 1825, '\p{Is_Jg=-	Mim}', "");
Expect(0, 1825, '\p{^Is_Jg=-	Mim}', "");
Expect(0, 1825, '\P{Is_Jg=-	Mim}', "");
Expect(1, 1825, '\P{^Is_Jg=-	Mim}', "");
Expect(0, 1826, '\p{Is_Jg=-	Mim}', "");
Expect(1, 1826, '\p{^Is_Jg=-	Mim}', "");
Expect(1, 1826, '\P{Is_Jg=-	Mim}', "");
Expect(0, 1826, '\P{^Is_Jg=-	Mim}', "");
Error('\p{Joining_Group: :=	_no_joining_Group}');
Error('\P{Joining_Group: :=	_no_joining_Group}');
Expect(1, 2221, '\p{Joining_Group=nojoininggroup}', "");
Expect(0, 2221, '\p{^Joining_Group=nojoininggroup}', "");
Expect(0, 2221, '\P{Joining_Group=nojoininggroup}', "");
Expect(1, 2221, '\P{^Joining_Group=nojoininggroup}', "");
Expect(0, 2220, '\p{Joining_Group=nojoininggroup}', "");
Expect(1, 2220, '\p{^Joining_Group=nojoininggroup}', "");
Expect(1, 2220, '\P{Joining_Group=nojoininggroup}', "");
Expect(0, 2220, '\P{^Joining_Group=nojoininggroup}', "");
Expect(1, 2221, '\p{Joining_Group= 	NO_joining_Group}', "");
Expect(0, 2221, '\p{^Joining_Group= 	NO_joining_Group}', "");
Expect(0, 2221, '\P{Joining_Group= 	NO_joining_Group}', "");
Expect(1, 2221, '\P{^Joining_Group= 	NO_joining_Group}', "");
Expect(0, 2220, '\p{Joining_Group= 	NO_joining_Group}', "");
Expect(1, 2220, '\p{^Joining_Group= 	NO_joining_Group}', "");
Expect(1, 2220, '\P{Joining_Group= 	NO_joining_Group}', "");
Expect(0, 2220, '\P{^Joining_Group= 	NO_joining_Group}', "");
Error('\p{Jg=/a/ -No_JOINING_group}');
Error('\P{Jg=/a/ -No_JOINING_group}');
Expect(1, 2221, '\p{Jg=nojoininggroup}', "");
Expect(0, 2221, '\p{^Jg=nojoininggroup}', "");
Expect(0, 2221, '\P{Jg=nojoininggroup}', "");
Expect(1, 2221, '\P{^Jg=nojoininggroup}', "");
Expect(0, 2220, '\p{Jg=nojoininggroup}', "");
Expect(1, 2220, '\p{^Jg=nojoininggroup}', "");
Expect(1, 2220, '\P{Jg=nojoininggroup}', "");
Expect(0, 2220, '\P{^Jg=nojoininggroup}', "");
Expect(1, 2221, '\p{Jg=No_Joining_GROUP}', "");
Expect(0, 2221, '\p{^Jg=No_Joining_GROUP}', "");
Expect(0, 2221, '\P{Jg=No_Joining_GROUP}', "");
Expect(1, 2221, '\P{^Jg=No_Joining_GROUP}', "");
Expect(0, 2220, '\p{Jg=No_Joining_GROUP}', "");
Expect(1, 2220, '\p{^Jg=No_Joining_GROUP}', "");
Expect(1, 2220, '\P{Jg=No_Joining_GROUP}', "");
Expect(0, 2220, '\P{^Jg=No_Joining_GROUP}', "");
Error('\p{Is_Joining_Group=_/a/No_joining_group}');
Error('\P{Is_Joining_Group=_/a/No_joining_group}');
Expect(1, 2221, '\p{Is_Joining_Group=nojoininggroup}', "");
Expect(0, 2221, '\p{^Is_Joining_Group=nojoininggroup}', "");
Expect(0, 2221, '\P{Is_Joining_Group=nojoininggroup}', "");
Expect(1, 2221, '\P{^Is_Joining_Group=nojoininggroup}', "");
Expect(0, 2220, '\p{Is_Joining_Group=nojoininggroup}', "");
Expect(1, 2220, '\p{^Is_Joining_Group=nojoininggroup}', "");
Expect(1, 2220, '\P{Is_Joining_Group=nojoininggroup}', "");
Expect(0, 2220, '\P{^Is_Joining_Group=nojoininggroup}', "");
Expect(1, 2221, '\p{Is_Joining_Group=NO_JOINING_Group}', "");
Expect(0, 2221, '\p{^Is_Joining_Group=NO_JOINING_Group}', "");
Expect(0, 2221, '\P{Is_Joining_Group=NO_JOINING_Group}', "");
Expect(1, 2221, '\P{^Is_Joining_Group=NO_JOINING_Group}', "");
Expect(0, 2220, '\p{Is_Joining_Group=NO_JOINING_Group}', "");
Expect(1, 2220, '\p{^Is_Joining_Group=NO_JOINING_Group}', "");
Expect(1, 2220, '\P{Is_Joining_Group=NO_JOINING_Group}', "");
Expect(0, 2220, '\P{^Is_Joining_Group=NO_JOINING_Group}', "");
Error('\p{Is_Jg:    _No_JOINING_group/a/}');
Error('\P{Is_Jg:    _No_JOINING_group/a/}');
Expect(1, 2221, '\p{Is_Jg: nojoininggroup}', "");
Expect(0, 2221, '\p{^Is_Jg: nojoininggroup}', "");
Expect(0, 2221, '\P{Is_Jg: nojoininggroup}', "");
Expect(1, 2221, '\P{^Is_Jg: nojoininggroup}', "");
Expect(0, 2220, '\p{Is_Jg: nojoininggroup}', "");
Expect(1, 2220, '\p{^Is_Jg: nojoininggroup}', "");
Expect(1, 2220, '\P{Is_Jg: nojoininggroup}', "");
Expect(0, 2220, '\P{^Is_Jg: nojoininggroup}', "");
Expect(1, 2221, '\p{Is_Jg=_-No_joining_Group}', "");
Expect(0, 2221, '\p{^Is_Jg=_-No_joining_Group}', "");
Expect(0, 2221, '\P{Is_Jg=_-No_joining_Group}', "");
Expect(1, 2221, '\P{^Is_Jg=_-No_joining_Group}', "");
Expect(0, 2220, '\p{Is_Jg=_-No_joining_Group}', "");
Expect(1, 2220, '\p{^Is_Jg=_-No_joining_Group}', "");
Expect(1, 2220, '\P{Is_Jg=_-No_joining_Group}', "");
Expect(0, 2220, '\P{^Is_Jg=_-No_joining_Group}', "");
Error('\p{Joining_Group=_-Noon:=}');
Error('\P{Joining_Group=_-Noon:=}');
Expect(1, 1897, '\p{Joining_Group=noon}', "");
Expect(0, 1897, '\p{^Joining_Group=noon}', "");
Expect(0, 1897, '\P{Joining_Group=noon}', "");
Expect(1, 1897, '\P{^Joining_Group=noon}', "");
Expect(0, 1898, '\p{Joining_Group=noon}', "");
Expect(1, 1898, '\p{^Joining_Group=noon}', "");
Expect(1, 1898, '\P{Joining_Group=noon}', "");
Expect(0, 1898, '\P{^Joining_Group=noon}', "");
Expect(1, 1897, '\p{Joining_Group:	-	NOON}', "");
Expect(0, 1897, '\p{^Joining_Group:	-	NOON}', "");
Expect(0, 1897, '\P{Joining_Group:	-	NOON}', "");
Expect(1, 1897, '\P{^Joining_Group:	-	NOON}', "");
Expect(0, 1898, '\p{Joining_Group:	-	NOON}', "");
Expect(1, 1898, '\p{^Joining_Group:	-	NOON}', "");
Expect(1, 1898, '\P{Joining_Group:	-	NOON}', "");
Expect(0, 1898, '\P{^Joining_Group:	-	NOON}', "");
Error('\p{Jg=:=_ NOON}');
Error('\P{Jg=:=_ NOON}');
Expect(1, 1897, '\p{Jg=noon}', "");
Expect(0, 1897, '\p{^Jg=noon}', "");
Expect(0, 1897, '\P{Jg=noon}', "");
Expect(1, 1897, '\P{^Jg=noon}', "");
Expect(0, 1898, '\p{Jg=noon}', "");
Expect(1, 1898, '\p{^Jg=noon}', "");
Expect(1, 1898, '\P{Jg=noon}', "");
Expect(0, 1898, '\P{^Jg=noon}', "");
Expect(1, 1897, '\p{Jg=	Noon}', "");
Expect(0, 1897, '\p{^Jg=	Noon}', "");
Expect(0, 1897, '\P{Jg=	Noon}', "");
Expect(1, 1897, '\P{^Jg=	Noon}', "");
Expect(0, 1898, '\p{Jg=	Noon}', "");
Expect(1, 1898, '\p{^Jg=	Noon}', "");
Expect(1, 1898, '\P{Jg=	Noon}', "");
Expect(0, 1898, '\P{^Jg=	Noon}', "");
Error('\p{Is_Joining_Group:   /a/	Noon}');
Error('\P{Is_Joining_Group:   /a/	Noon}');
Expect(1, 1897, '\p{Is_Joining_Group=noon}', "");
Expect(0, 1897, '\p{^Is_Joining_Group=noon}', "");
Expect(0, 1897, '\P{Is_Joining_Group=noon}', "");
Expect(1, 1897, '\P{^Is_Joining_Group=noon}', "");
Expect(0, 1898, '\p{Is_Joining_Group=noon}', "");
Expect(1, 1898, '\p{^Is_Joining_Group=noon}', "");
Expect(1, 1898, '\P{Is_Joining_Group=noon}', "");
Expect(0, 1898, '\P{^Is_Joining_Group=noon}', "");
Expect(1, 1897, '\p{Is_Joining_Group=	Noon}', "");
Expect(0, 1897, '\p{^Is_Joining_Group=	Noon}', "");
Expect(0, 1897, '\P{Is_Joining_Group=	Noon}', "");
Expect(1, 1897, '\P{^Is_Joining_Group=	Noon}', "");
Expect(0, 1898, '\p{Is_Joining_Group=	Noon}', "");
Expect(1, 1898, '\p{^Is_Joining_Group=	Noon}', "");
Expect(1, 1898, '\P{Is_Joining_Group=	Noon}', "");
Expect(0, 1898, '\P{^Is_Joining_Group=	Noon}', "");
Error('\p{Is_Jg= 	Noon:=}');
Error('\P{Is_Jg= 	Noon:=}');
Expect(1, 1897, '\p{Is_Jg=noon}', "");
Expect(0, 1897, '\p{^Is_Jg=noon}', "");
Expect(0, 1897, '\P{Is_Jg=noon}', "");
Expect(1, 1897, '\P{^Is_Jg=noon}', "");
Expect(0, 1898, '\p{Is_Jg=noon}', "");
Expect(1, 1898, '\p{^Is_Jg=noon}', "");
Expect(1, 1898, '\P{Is_Jg=noon}', "");
Expect(0, 1898, '\P{^Is_Jg=noon}', "");
Expect(1, 1897, '\p{Is_Jg=-_noon}', "");
Expect(0, 1897, '\p{^Is_Jg=-_noon}', "");
Expect(0, 1897, '\P{Is_Jg=-_noon}', "");
Expect(1, 1897, '\P{^Is_Jg=-_noon}', "");
Expect(0, 1898, '\p{Is_Jg=-_noon}', "");
Expect(1, 1898, '\p{^Is_Jg=-_noon}', "");
Expect(1, 1898, '\P{Is_Jg=-_noon}', "");
Expect(0, 1898, '\P{^Is_Jg=-_noon}', "");
Error('\p{Joining_Group= -Nun/a/}');
Error('\P{Joining_Group= -Nun/a/}');
Expect(1, 1826, '\p{Joining_Group=nun}', "");
Expect(0, 1826, '\p{^Joining_Group=nun}', "");
Expect(0, 1826, '\P{Joining_Group=nun}', "");
Expect(1, 1826, '\P{^Joining_Group=nun}', "");
Expect(0, 1827, '\p{Joining_Group=nun}', "");
Expect(1, 1827, '\p{^Joining_Group=nun}', "");
Expect(1, 1827, '\P{Joining_Group=nun}', "");
Expect(0, 1827, '\P{^Joining_Group=nun}', "");
Error('\p{Jg=/a/ -NUN}');
Error('\P{Jg=/a/ -NUN}');
Expect(1, 1826, '\p{Jg=nun}', "");
Expect(0, 1826, '\p{^Jg=nun}', "");
Expect(0, 1826, '\P{Jg=nun}', "");
Expect(1, 1826, '\P{^Jg=nun}', "");
Expect(0, 1827, '\p{Jg=nun}', "");
Expect(1, 1827, '\p{^Jg=nun}', "");
Expect(1, 1827, '\P{Jg=nun}', "");
Expect(0, 1827, '\P{^Jg=nun}', "");
Expect(1, 1826, '\p{Jg= _nun}', "");
Expect(0, 1826, '\p{^Jg= _nun}', "");
Expect(0, 1826, '\P{Jg= _nun}', "");
Expect(1, 1826, '\P{^Jg= _nun}', "");
Expect(0, 1827, '\p{Jg= _nun}', "");
Expect(1, 1827, '\p{^Jg= _nun}', "");
Expect(1, 1827, '\P{Jg= _nun}', "");
Expect(0, 1827, '\P{^Jg= _nun}', "");
Error('\p{Is_Joining_Group= :=NUN}');
Error('\P{Is_Joining_Group= :=NUN}');
Expect(1, 1826, '\p{Is_Joining_Group=nun}', "");
Expect(0, 1826, '\p{^Is_Joining_Group=nun}', "");
Expect(0, 1826, '\P{Is_Joining_Group=nun}', "");
Expect(1, 1826, '\P{^Is_Joining_Group=nun}', "");
Expect(0, 1827, '\p{Is_Joining_Group=nun}', "");
Expect(1, 1827, '\p{^Is_Joining_Group=nun}', "");
Expect(1, 1827, '\P{Is_Joining_Group=nun}', "");
Expect(0, 1827, '\P{^Is_Joining_Group=nun}', "");
Expect(1, 1826, '\p{Is_Joining_Group= Nun}', "");
Expect(0, 1826, '\p{^Is_Joining_Group= Nun}', "");
Expect(0, 1826, '\P{Is_Joining_Group= Nun}', "");
Expect(1, 1826, '\P{^Is_Joining_Group= Nun}', "");
Expect(0, 1827, '\p{Is_Joining_Group= Nun}', "");
Expect(1, 1827, '\p{^Is_Joining_Group= Nun}', "");
Expect(1, 1827, '\P{Is_Joining_Group= Nun}', "");
Expect(0, 1827, '\P{^Is_Joining_Group= Nun}', "");
Error('\p{Is_Jg=/a/  NUN}');
Error('\P{Is_Jg=/a/  NUN}');
Expect(1, 1826, '\p{Is_Jg=nun}', "");
Expect(0, 1826, '\p{^Is_Jg=nun}', "");
Expect(0, 1826, '\P{Is_Jg=nun}', "");
Expect(1, 1826, '\P{^Is_Jg=nun}', "");
Expect(0, 1827, '\p{Is_Jg=nun}', "");
Expect(1, 1827, '\p{^Is_Jg=nun}', "");
Expect(1, 1827, '\P{Is_Jg=nun}', "");
Expect(0, 1827, '\P{^Is_Jg=nun}', "");
Expect(1, 1826, '\p{Is_Jg=Nun}', "");
Expect(0, 1826, '\p{^Is_Jg=Nun}', "");
Expect(0, 1826, '\P{Is_Jg=Nun}', "");
Expect(1, 1826, '\P{^Is_Jg=Nun}', "");
Expect(0, 1827, '\p{Is_Jg=Nun}', "");
Expect(1, 1827, '\p{^Is_Jg=Nun}', "");
Expect(1, 1827, '\P{Is_Jg=Nun}', "");
Expect(0, 1827, '\P{^Is_Jg=Nun}', "");
Error('\p{Joining_Group= nya/a/}');
Error('\P{Joining_Group= nya/a/}');
Expect(1, 1725, '\p{Joining_Group=nya}', "");
Expect(0, 1725, '\p{^Joining_Group=nya}', "");
Expect(0, 1725, '\P{Joining_Group=nya}', "");
Expect(1, 1725, '\P{^Joining_Group=nya}', "");
Expect(0, 1726, '\p{Joining_Group=nya}', "");
Expect(1, 1726, '\p{^Joining_Group=nya}', "");
Expect(1, 1726, '\P{Joining_Group=nya}', "");
Expect(0, 1726, '\P{^Joining_Group=nya}', "");
Expect(1, 1725, '\p{Joining_Group=__NYA}', "");
Expect(0, 1725, '\p{^Joining_Group=__NYA}', "");
Expect(0, 1725, '\P{Joining_Group=__NYA}', "");
Expect(1, 1725, '\P{^Joining_Group=__NYA}', "");
Expect(0, 1726, '\p{Joining_Group=__NYA}', "");
Expect(1, 1726, '\p{^Joining_Group=__NYA}', "");
Expect(1, 1726, '\P{Joining_Group=__NYA}', "");
Expect(0, 1726, '\P{^Joining_Group=__NYA}', "");
Error('\p{Jg=-	Nya:=}');
Error('\P{Jg=-	Nya:=}');
Expect(1, 1725, '\p{Jg=nya}', "");
Expect(0, 1725, '\p{^Jg=nya}', "");
Expect(0, 1725, '\P{Jg=nya}', "");
Expect(1, 1725, '\P{^Jg=nya}', "");
Expect(0, 1726, '\p{Jg=nya}', "");
Expect(1, 1726, '\p{^Jg=nya}', "");
Expect(1, 1726, '\P{Jg=nya}', "");
Expect(0, 1726, '\P{^Jg=nya}', "");
Expect(1, 1725, '\p{Jg=  Nya}', "");
Expect(0, 1725, '\p{^Jg=  Nya}', "");
Expect(0, 1725, '\P{Jg=  Nya}', "");
Expect(1, 1725, '\P{^Jg=  Nya}', "");
Expect(0, 1726, '\p{Jg=  Nya}', "");
Expect(1, 1726, '\p{^Jg=  Nya}', "");
Expect(1, 1726, '\P{Jg=  Nya}', "");
Expect(0, 1726, '\P{^Jg=  Nya}', "");
Error('\p{Is_Joining_Group=/a/	-NYA}');
Error('\P{Is_Joining_Group=/a/	-NYA}');
Expect(1, 1725, '\p{Is_Joining_Group=nya}', "");
Expect(0, 1725, '\p{^Is_Joining_Group=nya}', "");
Expect(0, 1725, '\P{Is_Joining_Group=nya}', "");
Expect(1, 1725, '\P{^Is_Joining_Group=nya}', "");
Expect(0, 1726, '\p{Is_Joining_Group=nya}', "");
Expect(1, 1726, '\p{^Is_Joining_Group=nya}', "");
Expect(1, 1726, '\P{Is_Joining_Group=nya}', "");
Expect(0, 1726, '\P{^Is_Joining_Group=nya}', "");
Expect(1, 1725, '\p{Is_Joining_Group=NYA}', "");
Expect(0, 1725, '\p{^Is_Joining_Group=NYA}', "");
Expect(0, 1725, '\P{Is_Joining_Group=NYA}', "");
Expect(1, 1725, '\P{^Is_Joining_Group=NYA}', "");
Expect(0, 1726, '\p{Is_Joining_Group=NYA}', "");
Expect(1, 1726, '\p{^Is_Joining_Group=NYA}', "");
Expect(1, 1726, '\P{Is_Joining_Group=NYA}', "");
Expect(0, 1726, '\P{^Is_Joining_Group=NYA}', "");
Error('\p{Is_Jg=	Nya/a/}');
Error('\P{Is_Jg=	Nya/a/}');
Expect(1, 1725, '\p{Is_Jg=nya}', "");
Expect(0, 1725, '\p{^Is_Jg=nya}', "");
Expect(0, 1725, '\P{Is_Jg=nya}', "");
Expect(1, 1725, '\P{^Is_Jg=nya}', "");
Expect(0, 1726, '\p{Is_Jg=nya}', "");
Expect(1, 1726, '\p{^Is_Jg=nya}', "");
Expect(1, 1726, '\P{Is_Jg=nya}', "");
Expect(0, 1726, '\P{^Is_Jg=nya}', "");
Expect(1, 1725, '\p{Is_Jg=_nya}', "");
Expect(0, 1725, '\p{^Is_Jg=_nya}', "");
Expect(0, 1725, '\P{Is_Jg=_nya}', "");
Expect(1, 1725, '\P{^Is_Jg=_nya}', "");
Expect(0, 1726, '\p{Is_Jg=_nya}', "");
Expect(1, 1726, '\p{^Is_Jg=_nya}', "");
Expect(1, 1726, '\P{Is_Jg=_nya}', "");
Expect(0, 1726, '\P{^Is_Jg=_nya}', "");
Error('\p{Joining_Group=:=_PE}');
Error('\P{Joining_Group=:=_PE}');
Expect(1, 1830, '\p{Joining_Group=pe}', "");
Expect(0, 1830, '\p{^Joining_Group=pe}', "");
Expect(0, 1830, '\P{Joining_Group=pe}', "");
Expect(1, 1830, '\P{^Joining_Group=pe}', "");
Expect(0, 1831, '\p{Joining_Group=pe}', "");
Expect(1, 1831, '\p{^Joining_Group=pe}', "");
Expect(1, 1831, '\P{Joining_Group=pe}', "");
Expect(0, 1831, '\P{^Joining_Group=pe}', "");
Expect(1, 1830, '\p{Joining_Group=	-Pe}', "");
Expect(0, 1830, '\p{^Joining_Group=	-Pe}', "");
Expect(0, 1830, '\P{Joining_Group=	-Pe}', "");
Expect(1, 1830, '\P{^Joining_Group=	-Pe}', "");
Expect(0, 1831, '\p{Joining_Group=	-Pe}', "");
Expect(1, 1831, '\p{^Joining_Group=	-Pe}', "");
Expect(1, 1831, '\P{Joining_Group=	-Pe}', "");
Expect(0, 1831, '\P{^Joining_Group=	-Pe}', "");
Error('\p{Jg=-pe/a/}');
Error('\P{Jg=-pe/a/}');
Expect(1, 1830, '\p{Jg=pe}', "");
Expect(0, 1830, '\p{^Jg=pe}', "");
Expect(0, 1830, '\P{Jg=pe}', "");
Expect(1, 1830, '\P{^Jg=pe}', "");
Expect(0, 1831, '\p{Jg=pe}', "");
Expect(1, 1831, '\p{^Jg=pe}', "");
Expect(1, 1831, '\P{Jg=pe}', "");
Expect(0, 1831, '\P{^Jg=pe}', "");
Error('\p{Is_Joining_Group=_/a/Pe}');
Error('\P{Is_Joining_Group=_/a/Pe}');
Expect(1, 1830, '\p{Is_Joining_Group=pe}', "");
Expect(0, 1830, '\p{^Is_Joining_Group=pe}', "");
Expect(0, 1830, '\P{Is_Joining_Group=pe}', "");
Expect(1, 1830, '\P{^Is_Joining_Group=pe}', "");
Expect(0, 1831, '\p{Is_Joining_Group=pe}', "");
Expect(1, 1831, '\p{^Is_Joining_Group=pe}', "");
Expect(1, 1831, '\P{Is_Joining_Group=pe}', "");
Expect(0, 1831, '\P{^Is_Joining_Group=pe}', "");
Expect(1, 1830, '\p{Is_Joining_Group=_Pe}', "");
Expect(0, 1830, '\p{^Is_Joining_Group=_Pe}', "");
Expect(0, 1830, '\P{Is_Joining_Group=_Pe}', "");
Expect(1, 1830, '\P{^Is_Joining_Group=_Pe}', "");
Expect(0, 1831, '\p{Is_Joining_Group=_Pe}', "");
Expect(1, 1831, '\p{^Is_Joining_Group=_Pe}', "");
Expect(1, 1831, '\P{Is_Joining_Group=_Pe}', "");
Expect(0, 1831, '\P{^Is_Joining_Group=_Pe}', "");
Error('\p{Is_Jg=	/a/PE}');
Error('\P{Is_Jg=	/a/PE}');
Expect(1, 1830, '\p{Is_Jg=pe}', "");
Expect(0, 1830, '\p{^Is_Jg=pe}', "");
Expect(0, 1830, '\P{Is_Jg=pe}', "");
Expect(1, 1830, '\P{^Is_Jg=pe}', "");
Expect(0, 1831, '\p{Is_Jg=pe}', "");
Expect(1, 1831, '\p{^Is_Jg=pe}', "");
Expect(1, 1831, '\P{Is_Jg=pe}', "");
Expect(0, 1831, '\P{^Is_Jg=pe}', "");
Expect(1, 1830, '\p{Is_Jg= -Pe}', "");
Expect(0, 1830, '\p{^Is_Jg= -Pe}', "");
Expect(0, 1830, '\P{Is_Jg= -Pe}', "");
Expect(1, 1830, '\P{^Is_Jg= -Pe}', "");
Expect(0, 1831, '\p{Is_Jg= -Pe}', "");
Expect(1, 1831, '\p{^Is_Jg= -Pe}', "");
Expect(1, 1831, '\P{Is_Jg= -Pe}', "");
Expect(0, 1831, '\P{^Is_Jg= -Pe}', "");
Error('\p{Joining_Group=/a/	qaf}');
Error('\P{Joining_Group=/a/	qaf}');
Expect(1, 2213, '\p{Joining_Group=qaf}', "");
Expect(0, 2213, '\p{^Joining_Group=qaf}', "");
Expect(0, 2213, '\P{Joining_Group=qaf}', "");
Expect(1, 2213, '\P{^Joining_Group=qaf}', "");
Expect(0, 2214, '\p{Joining_Group=qaf}', "");
Expect(1, 2214, '\p{^Joining_Group=qaf}', "");
Expect(1, 2214, '\P{Joining_Group=qaf}', "");
Expect(0, 2214, '\P{^Joining_Group=qaf}', "");
Expect(1, 2213, '\p{Joining_Group=- qaf}', "");
Expect(0, 2213, '\p{^Joining_Group=- qaf}', "");
Expect(0, 2213, '\P{Joining_Group=- qaf}', "");
Expect(1, 2213, '\P{^Joining_Group=- qaf}', "");
Expect(0, 2214, '\p{Joining_Group=- qaf}', "");
Expect(1, 2214, '\p{^Joining_Group=- qaf}', "");
Expect(1, 2214, '\P{Joining_Group=- qaf}', "");
Expect(0, 2214, '\P{^Joining_Group=- qaf}', "");
Error('\p{Jg=:=	Qaf}');
Error('\P{Jg=:=	Qaf}');
Expect(1, 2213, '\p{Jg=qaf}', "");
Expect(0, 2213, '\p{^Jg=qaf}', "");
Expect(0, 2213, '\P{Jg=qaf}', "");
Expect(1, 2213, '\P{^Jg=qaf}', "");
Expect(0, 2214, '\p{Jg=qaf}', "");
Expect(1, 2214, '\p{^Jg=qaf}', "");
Expect(1, 2214, '\P{Jg=qaf}', "");
Expect(0, 2214, '\P{^Jg=qaf}', "");
Expect(1, 2213, '\p{Jg=- qaf}', "");
Expect(0, 2213, '\p{^Jg=- qaf}', "");
Expect(0, 2213, '\P{Jg=- qaf}', "");
Expect(1, 2213, '\P{^Jg=- qaf}', "");
Expect(0, 2214, '\p{Jg=- qaf}', "");
Expect(1, 2214, '\p{^Jg=- qaf}', "");
Expect(1, 2214, '\P{Jg=- qaf}', "");
Expect(0, 2214, '\P{^Jg=- qaf}', "");
Error('\p{Is_Joining_Group: /a/_Qaf}');
Error('\P{Is_Joining_Group: /a/_Qaf}');
Expect(1, 2213, '\p{Is_Joining_Group:   qaf}', "");
Expect(0, 2213, '\p{^Is_Joining_Group:   qaf}', "");
Expect(0, 2213, '\P{Is_Joining_Group:   qaf}', "");
Expect(1, 2213, '\P{^Is_Joining_Group:   qaf}', "");
Expect(0, 2214, '\p{Is_Joining_Group:   qaf}', "");
Expect(1, 2214, '\p{^Is_Joining_Group:   qaf}', "");
Expect(1, 2214, '\P{Is_Joining_Group:   qaf}', "");
Expect(0, 2214, '\P{^Is_Joining_Group:   qaf}', "");
Expect(1, 2213, '\p{Is_Joining_Group=_QAF}', "");
Expect(0, 2213, '\p{^Is_Joining_Group=_QAF}', "");
Expect(0, 2213, '\P{Is_Joining_Group=_QAF}', "");
Expect(1, 2213, '\P{^Is_Joining_Group=_QAF}', "");
Expect(0, 2214, '\p{Is_Joining_Group=_QAF}', "");
Expect(1, 2214, '\p{^Is_Joining_Group=_QAF}', "");
Expect(1, 2214, '\P{Is_Joining_Group=_QAF}', "");
Expect(0, 2214, '\P{^Is_Joining_Group=_QAF}', "");
Error('\p{Is_Jg=__QAF/a/}');
Error('\P{Is_Jg=__QAF/a/}');
Expect(1, 2213, '\p{Is_Jg=qaf}', "");
Expect(0, 2213, '\p{^Is_Jg=qaf}', "");
Expect(0, 2213, '\P{Is_Jg=qaf}', "");
Expect(1, 2213, '\P{^Is_Jg=qaf}', "");
Expect(0, 2214, '\p{Is_Jg=qaf}', "");
Expect(1, 2214, '\p{^Is_Jg=qaf}', "");
Expect(1, 2214, '\P{Is_Jg=qaf}', "");
Expect(0, 2214, '\P{^Is_Jg=qaf}', "");
Expect(1, 2213, '\p{Is_Jg: _Qaf}', "");
Expect(0, 2213, '\p{^Is_Jg: _Qaf}', "");
Expect(0, 2213, '\P{Is_Jg: _Qaf}', "");
Expect(1, 2213, '\P{^Is_Jg: _Qaf}', "");
Expect(0, 2214, '\p{Is_Jg: _Qaf}', "");
Expect(1, 2214, '\p{^Is_Jg: _Qaf}', "");
Expect(1, 2214, '\P{Is_Jg: _Qaf}', "");
Expect(0, 2214, '\P{^Is_Jg: _Qaf}', "");
Error('\p{Joining_Group=	:=QAPH}');
Error('\P{Joining_Group=	:=QAPH}');
Expect(1, 1833, '\p{Joining_Group=qaph}', "");
Expect(0, 1833, '\p{^Joining_Group=qaph}', "");
Expect(0, 1833, '\P{Joining_Group=qaph}', "");
Expect(1, 1833, '\P{^Joining_Group=qaph}', "");
Expect(0, 1834, '\p{Joining_Group=qaph}', "");
Expect(1, 1834, '\p{^Joining_Group=qaph}', "");
Expect(1, 1834, '\P{Joining_Group=qaph}', "");
Expect(0, 1834, '\P{^Joining_Group=qaph}', "");
Expect(1, 1833, '\p{Joining_Group=	qaph}', "");
Expect(0, 1833, '\p{^Joining_Group=	qaph}', "");
Expect(0, 1833, '\P{Joining_Group=	qaph}', "");
Expect(1, 1833, '\P{^Joining_Group=	qaph}', "");
Expect(0, 1834, '\p{Joining_Group=	qaph}', "");
Expect(1, 1834, '\p{^Joining_Group=	qaph}', "");
Expect(1, 1834, '\P{Joining_Group=	qaph}', "");
Expect(0, 1834, '\P{^Joining_Group=	qaph}', "");
Error('\p{Jg=-/a/Qaph}');
Error('\P{Jg=-/a/Qaph}');
Expect(1, 1833, '\p{Jg=qaph}', "");
Expect(0, 1833, '\p{^Jg=qaph}', "");
Expect(0, 1833, '\P{Jg=qaph}', "");
Expect(1, 1833, '\P{^Jg=qaph}', "");
Expect(0, 1834, '\p{Jg=qaph}', "");
Expect(1, 1834, '\p{^Jg=qaph}', "");
Expect(1, 1834, '\P{Jg=qaph}', "");
Expect(0, 1834, '\P{^Jg=qaph}', "");
Expect(1, 1833, '\p{Jg=	qaph}', "");
Expect(0, 1833, '\p{^Jg=	qaph}', "");
Expect(0, 1833, '\P{Jg=	qaph}', "");
Expect(1, 1833, '\P{^Jg=	qaph}', "");
Expect(0, 1834, '\p{Jg=	qaph}', "");
Expect(1, 1834, '\p{^Jg=	qaph}', "");
Expect(1, 1834, '\P{Jg=	qaph}', "");
Expect(0, 1834, '\P{^Jg=	qaph}', "");
Error('\p{Is_Joining_Group=_/a/QAPH}');
Error('\P{Is_Joining_Group=_/a/QAPH}');
Expect(1, 1833, '\p{Is_Joining_Group:qaph}', "");
Expect(0, 1833, '\p{^Is_Joining_Group:qaph}', "");
Expect(0, 1833, '\P{Is_Joining_Group:qaph}', "");
Expect(1, 1833, '\P{^Is_Joining_Group:qaph}', "");
Expect(0, 1834, '\p{Is_Joining_Group:qaph}', "");
Expect(1, 1834, '\p{^Is_Joining_Group:qaph}', "");
Expect(1, 1834, '\P{Is_Joining_Group:qaph}', "");
Expect(0, 1834, '\P{^Is_Joining_Group:qaph}', "");
Expect(1, 1833, '\p{Is_Joining_Group=- Qaph}', "");
Expect(0, 1833, '\p{^Is_Joining_Group=- Qaph}', "");
Expect(0, 1833, '\P{Is_Joining_Group=- Qaph}', "");
Expect(1, 1833, '\P{^Is_Joining_Group=- Qaph}', "");
Expect(0, 1834, '\p{Is_Joining_Group=- Qaph}', "");
Expect(1, 1834, '\p{^Is_Joining_Group=- Qaph}', "");
Expect(1, 1834, '\P{Is_Joining_Group=- Qaph}', "");
Expect(0, 1834, '\P{^Is_Joining_Group=- Qaph}', "");
Error('\p{Is_Jg=	 qaph/a/}');
Error('\P{Is_Jg=	 qaph/a/}');
Expect(1, 1833, '\p{Is_Jg=qaph}', "");
Expect(0, 1833, '\p{^Is_Jg=qaph}', "");
Expect(0, 1833, '\P{Is_Jg=qaph}', "");
Expect(1, 1833, '\P{^Is_Jg=qaph}', "");
Expect(0, 1834, '\p{Is_Jg=qaph}', "");
Expect(1, 1834, '\p{^Is_Jg=qaph}', "");
Expect(1, 1834, '\P{Is_Jg=qaph}', "");
Expect(0, 1834, '\P{^Is_Jg=qaph}', "");
Expect(1, 1833, '\p{Is_Jg=-qaph}', "");
Expect(0, 1833, '\p{^Is_Jg=-qaph}', "");
Expect(0, 1833, '\P{Is_Jg=-qaph}', "");
Expect(1, 1833, '\P{^Is_Jg=-qaph}', "");
Expect(0, 1834, '\p{Is_Jg=-qaph}', "");
Expect(1, 1834, '\p{^Is_Jg=-qaph}', "");
Expect(1, 1834, '\P{Is_Jg=-qaph}', "");
Expect(0, 1834, '\P{^Is_Jg=-qaph}', "");
Error('\p{Joining_Group=_Reh/a/}');
Error('\P{Joining_Group=_Reh/a/}');
Expect(1, 2218, '\p{Joining_Group=reh}', "");
Expect(0, 2218, '\p{^Joining_Group=reh}', "");
Expect(0, 2218, '\P{Joining_Group=reh}', "");
Expect(1, 2218, '\P{^Joining_Group=reh}', "");
Expect(0, 2219, '\p{Joining_Group=reh}', "");
Expect(1, 2219, '\p{^Joining_Group=reh}', "");
Expect(1, 2219, '\P{Joining_Group=reh}', "");
Expect(0, 2219, '\P{^Joining_Group=reh}', "");
Expect(1, 2218, '\p{Joining_Group=_REH}', "");
Expect(0, 2218, '\p{^Joining_Group=_REH}', "");
Expect(0, 2218, '\P{Joining_Group=_REH}', "");
Expect(1, 2218, '\P{^Joining_Group=_REH}', "");
Expect(0, 2219, '\p{Joining_Group=_REH}', "");
Expect(1, 2219, '\p{^Joining_Group=_REH}', "");
Expect(1, 2219, '\P{Joining_Group=_REH}', "");
Expect(0, 2219, '\P{^Joining_Group=_REH}', "");
Error('\p{Jg=:=_-Reh}');
Error('\P{Jg=:=_-Reh}');
Expect(1, 2218, '\p{Jg=reh}', "");
Expect(0, 2218, '\p{^Jg=reh}', "");
Expect(0, 2218, '\P{Jg=reh}', "");
Expect(1, 2218, '\P{^Jg=reh}', "");
Expect(0, 2219, '\p{Jg=reh}', "");
Expect(1, 2219, '\p{^Jg=reh}', "");
Expect(1, 2219, '\P{Jg=reh}', "");
Expect(0, 2219, '\P{^Jg=reh}', "");
Expect(1, 2218, '\p{Jg=- Reh}', "");
Expect(0, 2218, '\p{^Jg=- Reh}', "");
Expect(0, 2218, '\P{Jg=- Reh}', "");
Expect(1, 2218, '\P{^Jg=- Reh}', "");
Expect(0, 2219, '\p{Jg=- Reh}', "");
Expect(1, 2219, '\p{^Jg=- Reh}', "");
Expect(1, 2219, '\P{Jg=- Reh}', "");
Expect(0, 2219, '\P{^Jg=- Reh}', "");
Error('\p{Is_Joining_Group=-/a/reh}');
Error('\P{Is_Joining_Group=-/a/reh}');
Expect(1, 2218, '\p{Is_Joining_Group=reh}', "");
Expect(0, 2218, '\p{^Is_Joining_Group=reh}', "");
Expect(0, 2218, '\P{Is_Joining_Group=reh}', "");
Expect(1, 2218, '\P{^Is_Joining_Group=reh}', "");
Expect(0, 2219, '\p{Is_Joining_Group=reh}', "");
Expect(1, 2219, '\p{^Is_Joining_Group=reh}', "");
Expect(1, 2219, '\P{Is_Joining_Group=reh}', "");
Expect(0, 2219, '\P{^Is_Joining_Group=reh}', "");
Expect(1, 2218, '\p{Is_Joining_Group=-Reh}', "");
Expect(0, 2218, '\p{^Is_Joining_Group=-Reh}', "");
Expect(0, 2218, '\P{Is_Joining_Group=-Reh}', "");
Expect(1, 2218, '\P{^Is_Joining_Group=-Reh}', "");
Expect(0, 2219, '\p{Is_Joining_Group=-Reh}', "");
Expect(1, 2219, '\p{^Is_Joining_Group=-Reh}', "");
Expect(1, 2219, '\P{Is_Joining_Group=-Reh}', "");
Expect(0, 2219, '\P{^Is_Joining_Group=-Reh}', "");
Error('\p{Is_Jg=/a/__Reh}');
Error('\P{Is_Jg=/a/__Reh}');
Expect(1, 2218, '\p{Is_Jg=reh}', "");
Expect(0, 2218, '\p{^Is_Jg=reh}', "");
Expect(0, 2218, '\P{Is_Jg=reh}', "");
Expect(1, 2218, '\P{^Is_Jg=reh}', "");
Expect(0, 2219, '\p{Is_Jg=reh}', "");
Expect(1, 2219, '\p{^Is_Jg=reh}', "");
Expect(1, 2219, '\P{Is_Jg=reh}', "");
Expect(0, 2219, '\P{^Is_Jg=reh}', "");
Expect(1, 2218, '\p{Is_Jg: 	reh}', "");
Expect(0, 2218, '\p{^Is_Jg: 	reh}', "");
Expect(0, 2218, '\P{Is_Jg: 	reh}', "");
Expect(1, 2218, '\P{^Is_Jg: 	reh}', "");
Expect(0, 2219, '\p{Is_Jg: 	reh}', "");
Expect(1, 2219, '\p{^Is_Jg: 	reh}', "");
Expect(1, 2219, '\P{Is_Jg: 	reh}', "");
Expect(0, 2219, '\P{^Is_Jg: 	reh}', "");
Error('\p{Joining_Group=	:=reversed_pe}');
Error('\P{Joining_Group=	:=reversed_pe}');
Expect(1, 1831, '\p{Joining_Group:	reversedpe}', "");
Expect(0, 1831, '\p{^Joining_Group:	reversedpe}', "");
Expect(0, 1831, '\P{Joining_Group:	reversedpe}', "");
Expect(1, 1831, '\P{^Joining_Group:	reversedpe}', "");
Expect(0, 1832, '\p{Joining_Group:	reversedpe}', "");
Expect(1, 1832, '\p{^Joining_Group:	reversedpe}', "");
Expect(1, 1832, '\P{Joining_Group:	reversedpe}', "");
Expect(0, 1832, '\P{^Joining_Group:	reversedpe}', "");
Expect(1, 1831, '\p{Joining_Group=_-reversed_Pe}', "");
Expect(0, 1831, '\p{^Joining_Group=_-reversed_Pe}', "");
Expect(0, 1831, '\P{Joining_Group=_-reversed_Pe}', "");
Expect(1, 1831, '\P{^Joining_Group=_-reversed_Pe}', "");
Expect(0, 1832, '\p{Joining_Group=_-reversed_Pe}', "");
Expect(1, 1832, '\p{^Joining_Group=_-reversed_Pe}', "");
Expect(1, 1832, '\P{Joining_Group=_-reversed_Pe}', "");
Expect(0, 1832, '\P{^Joining_Group=_-reversed_Pe}', "");
Error('\p{Jg=_	REVERSED_Pe/a/}');
Error('\P{Jg=_	REVERSED_Pe/a/}');
Expect(1, 1831, '\p{Jg=reversedpe}', "");
Expect(0, 1831, '\p{^Jg=reversedpe}', "");
Expect(0, 1831, '\P{Jg=reversedpe}', "");
Expect(1, 1831, '\P{^Jg=reversedpe}', "");
Expect(0, 1832, '\p{Jg=reversedpe}', "");
Expect(1, 1832, '\p{^Jg=reversedpe}', "");
Expect(1, 1832, '\P{Jg=reversedpe}', "");
Expect(0, 1832, '\P{^Jg=reversedpe}', "");
Expect(1, 1831, '\p{Jg=-reversed_Pe}', "");
Expect(0, 1831, '\p{^Jg=-reversed_Pe}', "");
Expect(0, 1831, '\P{Jg=-reversed_Pe}', "");
Expect(1, 1831, '\P{^Jg=-reversed_Pe}', "");
Expect(0, 1832, '\p{Jg=-reversed_Pe}', "");
Expect(1, 1832, '\p{^Jg=-reversed_Pe}', "");
Expect(1, 1832, '\P{Jg=-reversed_Pe}', "");
Expect(0, 1832, '\P{^Jg=-reversed_Pe}', "");
Error('\p{Is_Joining_Group= Reversed_pe/a/}');
Error('\P{Is_Joining_Group= Reversed_pe/a/}');
Expect(1, 1831, '\p{Is_Joining_Group=reversedpe}', "");
Expect(0, 1831, '\p{^Is_Joining_Group=reversedpe}', "");
Expect(0, 1831, '\P{Is_Joining_Group=reversedpe}', "");
Expect(1, 1831, '\P{^Is_Joining_Group=reversedpe}', "");
Expect(0, 1832, '\p{Is_Joining_Group=reversedpe}', "");
Expect(1, 1832, '\p{^Is_Joining_Group=reversedpe}', "");
Expect(1, 1832, '\P{Is_Joining_Group=reversedpe}', "");
Expect(0, 1832, '\P{^Is_Joining_Group=reversedpe}', "");
Expect(1, 1831, '\p{Is_Joining_Group=-_reversed_PE}', "");
Expect(0, 1831, '\p{^Is_Joining_Group=-_reversed_PE}', "");
Expect(0, 1831, '\P{Is_Joining_Group=-_reversed_PE}', "");
Expect(1, 1831, '\P{^Is_Joining_Group=-_reversed_PE}', "");
Expect(0, 1832, '\p{Is_Joining_Group=-_reversed_PE}', "");
Expect(1, 1832, '\p{^Is_Joining_Group=-_reversed_PE}', "");
Expect(1, 1832, '\P{Is_Joining_Group=-_reversed_PE}', "");
Expect(0, 1832, '\P{^Is_Joining_Group=-_reversed_PE}', "");
Error('\p{Is_Jg=	 Reversed_Pe:=}');
Error('\P{Is_Jg=	 Reversed_Pe:=}');
Expect(1, 1831, '\p{Is_Jg=reversedpe}', "");
Expect(0, 1831, '\p{^Is_Jg=reversedpe}', "");
Expect(0, 1831, '\P{Is_Jg=reversedpe}', "");
Expect(1, 1831, '\P{^Is_Jg=reversedpe}', "");
Expect(0, 1832, '\p{Is_Jg=reversedpe}', "");
Expect(1, 1832, '\p{^Is_Jg=reversedpe}', "");
Expect(1, 1832, '\P{Is_Jg=reversedpe}', "");
Expect(0, 1832, '\P{^Is_Jg=reversedpe}', "");
Expect(1, 1831, '\p{Is_Jg= reversed_Pe}', "");
Expect(0, 1831, '\p{^Is_Jg= reversed_Pe}', "");
Expect(0, 1831, '\P{Is_Jg= reversed_Pe}', "");
Expect(1, 1831, '\P{^Is_Jg= reversed_Pe}', "");
Expect(0, 1832, '\p{Is_Jg= reversed_Pe}', "");
Expect(1, 1832, '\p{^Is_Jg= reversed_Pe}', "");
Expect(1, 1832, '\P{Is_Jg= reversed_Pe}', "");
Expect(0, 1832, '\P{^Is_Jg= reversed_Pe}', "");
Error('\p{Joining_Group:   _ Rohingya_Yeh/a/}');
Error('\P{Joining_Group:   _ Rohingya_Yeh/a/}');
Expect(1, 2220, '\p{Joining_Group=rohingyayeh}', "");
Expect(0, 2220, '\p{^Joining_Group=rohingyayeh}', "");
Expect(0, 2220, '\P{Joining_Group=rohingyayeh}', "");
Expect(1, 2220, '\P{^Joining_Group=rohingyayeh}', "");
Expect(0, 2221, '\p{Joining_Group=rohingyayeh}', "");
Expect(1, 2221, '\p{^Joining_Group=rohingyayeh}', "");
Expect(1, 2221, '\P{Joining_Group=rohingyayeh}', "");
Expect(0, 2221, '\P{^Joining_Group=rohingyayeh}', "");
Expect(1, 2220, '\p{Joining_Group=	_Rohingya_Yeh}', "");
Expect(0, 2220, '\p{^Joining_Group=	_Rohingya_Yeh}', "");
Expect(0, 2220, '\P{Joining_Group=	_Rohingya_Yeh}', "");
Expect(1, 2220, '\P{^Joining_Group=	_Rohingya_Yeh}', "");
Expect(0, 2221, '\p{Joining_Group=	_Rohingya_Yeh}', "");
Expect(1, 2221, '\p{^Joining_Group=	_Rohingya_Yeh}', "");
Expect(1, 2221, '\P{Joining_Group=	_Rohingya_Yeh}', "");
Expect(0, 2221, '\P{^Joining_Group=	_Rohingya_Yeh}', "");
Error('\p{Jg=_Rohingya_yeh:=}');
Error('\P{Jg=_Rohingya_yeh:=}');
Expect(1, 2220, '\p{Jg=rohingyayeh}', "");
Expect(0, 2220, '\p{^Jg=rohingyayeh}', "");
Expect(0, 2220, '\P{Jg=rohingyayeh}', "");
Expect(1, 2220, '\P{^Jg=rohingyayeh}', "");
Expect(0, 2221, '\p{Jg=rohingyayeh}', "");
Expect(1, 2221, '\p{^Jg=rohingyayeh}', "");
Expect(1, 2221, '\P{Jg=rohingyayeh}', "");
Expect(0, 2221, '\P{^Jg=rohingyayeh}', "");
Expect(1, 2220, '\p{Jg=-	Rohingya_yeh}', "");
Expect(0, 2220, '\p{^Jg=-	Rohingya_yeh}', "");
Expect(0, 2220, '\P{Jg=-	Rohingya_yeh}', "");
Expect(1, 2220, '\P{^Jg=-	Rohingya_yeh}', "");
Expect(0, 2221, '\p{Jg=-	Rohingya_yeh}', "");
Expect(1, 2221, '\p{^Jg=-	Rohingya_yeh}', "");
Expect(1, 2221, '\P{Jg=-	Rohingya_yeh}', "");
Expect(0, 2221, '\P{^Jg=-	Rohingya_yeh}', "");
Error('\p{Is_Joining_Group=/a/--Rohingya_Yeh}');
Error('\P{Is_Joining_Group=/a/--Rohingya_Yeh}');
Expect(1, 2220, '\p{Is_Joining_Group:	rohingyayeh}', "");
Expect(0, 2220, '\p{^Is_Joining_Group:	rohingyayeh}', "");
Expect(0, 2220, '\P{Is_Joining_Group:	rohingyayeh}', "");
Expect(1, 2220, '\P{^Is_Joining_Group:	rohingyayeh}', "");
Expect(0, 2221, '\p{Is_Joining_Group:	rohingyayeh}', "");
Expect(1, 2221, '\p{^Is_Joining_Group:	rohingyayeh}', "");
Expect(1, 2221, '\P{Is_Joining_Group:	rohingyayeh}', "");
Expect(0, 2221, '\P{^Is_Joining_Group:	rohingyayeh}', "");
Expect(1, 2220, '\p{Is_Joining_Group=_ rohingya_Yeh}', "");
Expect(0, 2220, '\p{^Is_Joining_Group=_ rohingya_Yeh}', "");
Expect(0, 2220, '\P{Is_Joining_Group=_ rohingya_Yeh}', "");
Expect(1, 2220, '\P{^Is_Joining_Group=_ rohingya_Yeh}', "");
Expect(0, 2221, '\p{Is_Joining_Group=_ rohingya_Yeh}', "");
Expect(1, 2221, '\p{^Is_Joining_Group=_ rohingya_Yeh}', "");
Expect(1, 2221, '\P{Is_Joining_Group=_ rohingya_Yeh}', "");
Expect(0, 2221, '\P{^Is_Joining_Group=_ rohingya_Yeh}', "");
Error('\p{Is_Jg:  rohingya_Yeh/a/}');
Error('\P{Is_Jg:  rohingya_Yeh/a/}');
Expect(1, 2220, '\p{Is_Jg=rohingyayeh}', "");
Expect(0, 2220, '\p{^Is_Jg=rohingyayeh}', "");
Expect(0, 2220, '\P{Is_Jg=rohingyayeh}', "");
Expect(1, 2220, '\P{^Is_Jg=rohingyayeh}', "");
Expect(0, 2221, '\p{Is_Jg=rohingyayeh}', "");
Expect(1, 2221, '\p{^Is_Jg=rohingyayeh}', "");
Expect(1, 2221, '\P{Is_Jg=rohingyayeh}', "");
Expect(0, 2221, '\P{^Is_Jg=rohingyayeh}', "");
Expect(1, 2220, '\p{Is_Jg=	 Rohingya_Yeh}', "");
Expect(0, 2220, '\p{^Is_Jg=	 Rohingya_Yeh}', "");
Expect(0, 2220, '\P{Is_Jg=	 Rohingya_Yeh}', "");
Expect(1, 2220, '\P{^Is_Jg=	 Rohingya_Yeh}', "");
Expect(0, 2221, '\p{Is_Jg=	 Rohingya_Yeh}', "");
Expect(1, 2221, '\p{^Is_Jg=	 Rohingya_Yeh}', "");
Expect(1, 2221, '\P{Is_Jg=	 Rohingya_Yeh}', "");
Expect(0, 2221, '\P{^Is_Jg=	 Rohingya_Yeh}', "");
Error('\p{Joining_Group=_/a/SAD}');
Error('\P{Joining_Group=_/a/SAD}');
Expect(1, 1787, '\p{Joining_Group=sad}', "");
Expect(0, 1787, '\p{^Joining_Group=sad}', "");
Expect(0, 1787, '\P{Joining_Group=sad}', "");
Expect(1, 1787, '\P{^Joining_Group=sad}', "");
Expect(0, 1788, '\p{Joining_Group=sad}', "");
Expect(1, 1788, '\p{^Joining_Group=sad}', "");
Expect(1, 1788, '\P{Joining_Group=sad}', "");
Expect(0, 1788, '\P{^Joining_Group=sad}', "");
Expect(1, 1787, '\p{Joining_Group=_SAD}', "");
Expect(0, 1787, '\p{^Joining_Group=_SAD}', "");
Expect(0, 1787, '\P{Joining_Group=_SAD}', "");
Expect(1, 1787, '\P{^Joining_Group=_SAD}', "");
Expect(0, 1788, '\p{Joining_Group=_SAD}', "");
Expect(1, 1788, '\p{^Joining_Group=_SAD}', "");
Expect(1, 1788, '\P{Joining_Group=_SAD}', "");
Expect(0, 1788, '\P{^Joining_Group=_SAD}', "");
Error('\p{Jg=-:=SAD}');
Error('\P{Jg=-:=SAD}');
Expect(1, 1787, '\p{Jg=sad}', "");
Expect(0, 1787, '\p{^Jg=sad}', "");
Expect(0, 1787, '\P{Jg=sad}', "");
Expect(1, 1787, '\P{^Jg=sad}', "");
Expect(0, 1788, '\p{Jg=sad}', "");
Expect(1, 1788, '\p{^Jg=sad}', "");
Expect(1, 1788, '\P{Jg=sad}', "");
Expect(0, 1788, '\P{^Jg=sad}', "");
Expect(1, 1787, '\p{Jg=	_sad}', "");
Expect(0, 1787, '\p{^Jg=	_sad}', "");
Expect(0, 1787, '\P{Jg=	_sad}', "");
Expect(1, 1787, '\P{^Jg=	_sad}', "");
Expect(0, 1788, '\p{Jg=	_sad}', "");
Expect(1, 1788, '\p{^Jg=	_sad}', "");
Expect(1, 1788, '\P{Jg=	_sad}', "");
Expect(0, 1788, '\P{^Jg=	_sad}', "");
Error('\p{Is_Joining_Group=:=	-SAD}');
Error('\P{Is_Joining_Group=:=	-SAD}');
Expect(1, 1787, '\p{Is_Joining_Group:	sad}', "");
Expect(0, 1787, '\p{^Is_Joining_Group:	sad}', "");
Expect(0, 1787, '\P{Is_Joining_Group:	sad}', "");
Expect(1, 1787, '\P{^Is_Joining_Group:	sad}', "");
Expect(0, 1788, '\p{Is_Joining_Group:	sad}', "");
Expect(1, 1788, '\p{^Is_Joining_Group:	sad}', "");
Expect(1, 1788, '\P{Is_Joining_Group:	sad}', "");
Expect(0, 1788, '\P{^Is_Joining_Group:	sad}', "");
Expect(1, 1787, '\p{Is_Joining_Group=-sad}', "");
Expect(0, 1787, '\p{^Is_Joining_Group=-sad}', "");
Expect(0, 1787, '\P{Is_Joining_Group=-sad}', "");
Expect(1, 1787, '\P{^Is_Joining_Group=-sad}', "");
Expect(0, 1788, '\p{Is_Joining_Group=-sad}', "");
Expect(1, 1788, '\p{^Is_Joining_Group=-sad}', "");
Expect(1, 1788, '\P{Is_Joining_Group=-sad}', "");
Expect(0, 1788, '\P{^Is_Joining_Group=-sad}', "");
Error('\p{Is_Jg=-SAD/a/}');
Error('\P{Is_Jg=-SAD/a/}');
Expect(1, 1787, '\p{Is_Jg=sad}', "");
Expect(0, 1787, '\p{^Is_Jg=sad}', "");
Expect(0, 1787, '\P{Is_Jg=sad}', "");
Expect(1, 1787, '\P{^Is_Jg=sad}', "");
Expect(0, 1788, '\p{Is_Jg=sad}', "");
Expect(1, 1788, '\p{^Is_Jg=sad}', "");
Expect(1, 1788, '\P{Is_Jg=sad}', "");
Expect(0, 1788, '\P{^Is_Jg=sad}', "");
Expect(1, 1787, '\p{Is_Jg=_	sad}', "");
Expect(0, 1787, '\p{^Is_Jg=_	sad}', "");
Expect(0, 1787, '\P{Is_Jg=_	sad}', "");
Expect(1, 1787, '\P{^Is_Jg=_	sad}', "");
Expect(0, 1788, '\p{Is_Jg=_	sad}', "");
Expect(1, 1788, '\p{^Is_Jg=_	sad}', "");
Expect(1, 1788, '\P{Is_Jg=_	sad}', "");
Expect(0, 1788, '\P{^Is_Jg=_	sad}', "");
Error('\p{Joining_Group=-/a/SADHE}');
Error('\P{Joining_Group=-/a/SADHE}');
Expect(1, 1832, '\p{Joining_Group:sadhe}', "");
Expect(0, 1832, '\p{^Joining_Group:sadhe}', "");
Expect(0, 1832, '\P{Joining_Group:sadhe}', "");
Expect(1, 1832, '\P{^Joining_Group:sadhe}', "");
Expect(0, 1833, '\p{Joining_Group:sadhe}', "");
Expect(1, 1833, '\p{^Joining_Group:sadhe}', "");
Expect(1, 1833, '\P{Joining_Group:sadhe}', "");
Expect(0, 1833, '\P{^Joining_Group:sadhe}', "");
Expect(1, 1832, '\p{Joining_Group=--Sadhe}', "");
Expect(0, 1832, '\p{^Joining_Group=--Sadhe}', "");
Expect(0, 1832, '\P{Joining_Group=--Sadhe}', "");
Expect(1, 1832, '\P{^Joining_Group=--Sadhe}', "");
Expect(0, 1833, '\p{Joining_Group=--Sadhe}', "");
Expect(1, 1833, '\p{^Joining_Group=--Sadhe}', "");
Expect(1, 1833, '\P{Joining_Group=--Sadhe}', "");
Expect(0, 1833, '\P{^Joining_Group=--Sadhe}', "");
Error('\p{Jg=	Sadhe:=}');
Error('\P{Jg=	Sadhe:=}');
Expect(1, 1832, '\p{Jg=sadhe}', "");
Expect(0, 1832, '\p{^Jg=sadhe}', "");
Expect(0, 1832, '\P{Jg=sadhe}', "");
Expect(1, 1832, '\P{^Jg=sadhe}', "");
Expect(0, 1833, '\p{Jg=sadhe}', "");
Expect(1, 1833, '\p{^Jg=sadhe}', "");
Expect(1, 1833, '\P{Jg=sadhe}', "");
Expect(0, 1833, '\P{^Jg=sadhe}', "");
Expect(1, 1832, '\p{Jg=-	SADHE}', "");
Expect(0, 1832, '\p{^Jg=-	SADHE}', "");
Expect(0, 1832, '\P{Jg=-	SADHE}', "");
Expect(1, 1832, '\P{^Jg=-	SADHE}', "");
Expect(0, 1833, '\p{Jg=-	SADHE}', "");
Expect(1, 1833, '\p{^Jg=-	SADHE}', "");
Expect(1, 1833, '\P{Jg=-	SADHE}', "");
Expect(0, 1833, '\P{^Jg=-	SADHE}', "");
Error('\p{Is_Joining_Group=:=-SADHE}');
Error('\P{Is_Joining_Group=:=-SADHE}');
Expect(1, 1832, '\p{Is_Joining_Group=sadhe}', "");
Expect(0, 1832, '\p{^Is_Joining_Group=sadhe}', "");
Expect(0, 1832, '\P{Is_Joining_Group=sadhe}', "");
Expect(1, 1832, '\P{^Is_Joining_Group=sadhe}', "");
Expect(0, 1833, '\p{Is_Joining_Group=sadhe}', "");
Expect(1, 1833, '\p{^Is_Joining_Group=sadhe}', "");
Expect(1, 1833, '\P{Is_Joining_Group=sadhe}', "");
Expect(0, 1833, '\P{^Is_Joining_Group=sadhe}', "");
Expect(1, 1832, '\p{Is_Joining_Group= _Sadhe}', "");
Expect(0, 1832, '\p{^Is_Joining_Group= _Sadhe}', "");
Expect(0, 1832, '\P{Is_Joining_Group= _Sadhe}', "");
Expect(1, 1832, '\P{^Is_Joining_Group= _Sadhe}', "");
Expect(0, 1833, '\p{Is_Joining_Group= _Sadhe}', "");
Expect(1, 1833, '\p{^Is_Joining_Group= _Sadhe}', "");
Expect(1, 1833, '\P{Is_Joining_Group= _Sadhe}', "");
Expect(0, 1833, '\P{^Is_Joining_Group= _Sadhe}', "");
Error('\p{Is_Jg:	/a/--sadhe}');
Error('\P{Is_Jg:	/a/--sadhe}');
Expect(1, 1832, '\p{Is_Jg=sadhe}', "");
Expect(0, 1832, '\p{^Is_Jg=sadhe}', "");
Expect(0, 1832, '\P{Is_Jg=sadhe}', "");
Expect(1, 1832, '\P{^Is_Jg=sadhe}', "");
Expect(0, 1833, '\p{Is_Jg=sadhe}', "");
Expect(1, 1833, '\p{^Is_Jg=sadhe}', "");
Expect(1, 1833, '\P{Is_Jg=sadhe}', "");
Expect(0, 1833, '\P{^Is_Jg=sadhe}', "");
Expect(1, 1832, '\p{Is_Jg= -SADHE}', "");
Expect(0, 1832, '\p{^Is_Jg= -SADHE}', "");
Expect(0, 1832, '\P{Is_Jg= -SADHE}', "");
Expect(1, 1832, '\P{^Is_Jg= -SADHE}', "");
Expect(0, 1833, '\p{Is_Jg= -SADHE}', "");
Expect(1, 1833, '\p{^Is_Jg= -SADHE}', "");
Expect(1, 1833, '\P{Is_Jg= -SADHE}', "");
Expect(0, 1833, '\P{^Is_Jg= -SADHE}', "");
Error('\p{Joining_Group:	:=  seen}');
Error('\P{Joining_Group:	:=  seen}');
Expect(1, 1918, '\p{Joining_Group=seen}', "");
Expect(0, 1918, '\p{^Joining_Group=seen}', "");
Expect(0, 1918, '\P{Joining_Group=seen}', "");
Expect(1, 1918, '\P{^Joining_Group=seen}', "");
Expect(0, 1919, '\p{Joining_Group=seen}', "");
Expect(1, 1919, '\p{^Joining_Group=seen}', "");
Expect(1, 1919, '\P{Joining_Group=seen}', "");
Expect(0, 1919, '\P{^Joining_Group=seen}', "");
Expect(1, 1918, '\p{Joining_Group=-SEEN}', "");
Expect(0, 1918, '\p{^Joining_Group=-SEEN}', "");
Expect(0, 1918, '\P{Joining_Group=-SEEN}', "");
Expect(1, 1918, '\P{^Joining_Group=-SEEN}', "");
Expect(0, 1919, '\p{Joining_Group=-SEEN}', "");
Expect(1, 1919, '\p{^Joining_Group=-SEEN}', "");
Expect(1, 1919, '\P{Joining_Group=-SEEN}', "");
Expect(0, 1919, '\P{^Joining_Group=-SEEN}', "");
Error('\p{Jg=/a/	Seen}');
Error('\P{Jg=/a/	Seen}');
Expect(1, 1918, '\p{Jg=seen}', "");
Expect(0, 1918, '\p{^Jg=seen}', "");
Expect(0, 1918, '\P{Jg=seen}', "");
Expect(1, 1918, '\P{^Jg=seen}', "");
Expect(0, 1919, '\p{Jg=seen}', "");
Expect(1, 1919, '\p{^Jg=seen}', "");
Expect(1, 1919, '\P{Jg=seen}', "");
Expect(0, 1919, '\P{^Jg=seen}', "");
Expect(1, 1918, '\p{Jg: -Seen}', "");
Expect(0, 1918, '\p{^Jg: -Seen}', "");
Expect(0, 1918, '\P{Jg: -Seen}', "");
Expect(1, 1918, '\P{^Jg: -Seen}', "");
Expect(0, 1919, '\p{Jg: -Seen}', "");
Expect(1, 1919, '\p{^Jg: -Seen}', "");
Expect(1, 1919, '\P{Jg: -Seen}', "");
Expect(0, 1919, '\P{^Jg: -Seen}', "");
Error('\p{Is_Joining_Group:   /a/--seen}');
Error('\P{Is_Joining_Group:   /a/--seen}');
Expect(1, 1918, '\p{Is_Joining_Group=seen}', "");
Expect(0, 1918, '\p{^Is_Joining_Group=seen}', "");
Expect(0, 1918, '\P{Is_Joining_Group=seen}', "");
Expect(1, 1918, '\P{^Is_Joining_Group=seen}', "");
Expect(0, 1919, '\p{Is_Joining_Group=seen}', "");
Expect(1, 1919, '\p{^Is_Joining_Group=seen}', "");
Expect(1, 1919, '\P{Is_Joining_Group=seen}', "");
Expect(0, 1919, '\P{^Is_Joining_Group=seen}', "");
Expect(1, 1918, '\p{Is_Joining_Group= seen}', "");
Expect(0, 1918, '\p{^Is_Joining_Group= seen}', "");
Expect(0, 1918, '\P{Is_Joining_Group= seen}', "");
Expect(1, 1918, '\P{^Is_Joining_Group= seen}', "");
Expect(0, 1919, '\p{Is_Joining_Group= seen}', "");
Expect(1, 1919, '\p{^Is_Joining_Group= seen}', "");
Expect(1, 1919, '\P{Is_Joining_Group= seen}', "");
Expect(0, 1919, '\P{^Is_Joining_Group= seen}', "");
Error('\p{Is_Jg=	Seen:=}');
Error('\P{Is_Jg=	Seen:=}');
Expect(1, 1918, '\p{Is_Jg=seen}', "");
Expect(0, 1918, '\p{^Is_Jg=seen}', "");
Expect(0, 1918, '\P{Is_Jg=seen}', "");
Expect(1, 1918, '\P{^Is_Jg=seen}', "");
Expect(0, 1919, '\p{Is_Jg=seen}', "");
Expect(1, 1919, '\p{^Is_Jg=seen}', "");
Expect(1, 1919, '\P{Is_Jg=seen}', "");
Expect(0, 1919, '\P{^Is_Jg=seen}', "");
Expect(1, 1918, '\p{Is_Jg= seen}', "");
Expect(0, 1918, '\p{^Is_Jg= seen}', "");
Expect(0, 1918, '\P{Is_Jg= seen}', "");
Expect(1, 1918, '\P{^Is_Jg= seen}', "");
Expect(0, 1919, '\p{Is_Jg= seen}', "");
Expect(1, 1919, '\p{^Is_Jg= seen}', "");
Expect(1, 1919, '\P{Is_Jg= seen}', "");
Expect(0, 1919, '\P{^Is_Jg= seen}', "");
Error('\p{Joining_Group=:=-_Semkath}');
Error('\P{Joining_Group=:=-_Semkath}');
Expect(1, 1827, '\p{Joining_Group:	semkath}', "");
Expect(0, 1827, '\p{^Joining_Group:	semkath}', "");
Expect(0, 1827, '\P{Joining_Group:	semkath}', "");
Expect(1, 1827, '\P{^Joining_Group:	semkath}', "");
Expect(0, 1828, '\p{Joining_Group:	semkath}', "");
Expect(1, 1828, '\p{^Joining_Group:	semkath}', "");
Expect(1, 1828, '\P{Joining_Group:	semkath}', "");
Expect(0, 1828, '\P{^Joining_Group:	semkath}', "");
Expect(1, 1827, '\p{Joining_Group=_Semkath}', "");
Expect(0, 1827, '\p{^Joining_Group=_Semkath}', "");
Expect(0, 1827, '\P{Joining_Group=_Semkath}', "");
Expect(1, 1827, '\P{^Joining_Group=_Semkath}', "");
Expect(0, 1828, '\p{Joining_Group=_Semkath}', "");
Expect(1, 1828, '\p{^Joining_Group=_Semkath}', "");
Expect(1, 1828, '\P{Joining_Group=_Semkath}', "");
Expect(0, 1828, '\P{^Joining_Group=_Semkath}', "");
Error('\p{Jg=/a/_SEMKATH}');
Error('\P{Jg=/a/_SEMKATH}');
Expect(1, 1827, '\p{Jg=semkath}', "");
Expect(0, 1827, '\p{^Jg=semkath}', "");
Expect(0, 1827, '\P{Jg=semkath}', "");
Expect(1, 1827, '\P{^Jg=semkath}', "");
Expect(0, 1828, '\p{Jg=semkath}', "");
Expect(1, 1828, '\p{^Jg=semkath}', "");
Expect(1, 1828, '\P{Jg=semkath}', "");
Expect(0, 1828, '\P{^Jg=semkath}', "");
Error('\p{Is_Joining_Group= :=Semkath}');
Error('\P{Is_Joining_Group= :=Semkath}');
Expect(1, 1827, '\p{Is_Joining_Group=semkath}', "");
Expect(0, 1827, '\p{^Is_Joining_Group=semkath}', "");
Expect(0, 1827, '\P{Is_Joining_Group=semkath}', "");
Expect(1, 1827, '\P{^Is_Joining_Group=semkath}', "");
Expect(0, 1828, '\p{Is_Joining_Group=semkath}', "");
Expect(1, 1828, '\p{^Is_Joining_Group=semkath}', "");
Expect(1, 1828, '\P{Is_Joining_Group=semkath}', "");
Expect(0, 1828, '\P{^Is_Joining_Group=semkath}', "");
Expect(1, 1827, '\p{Is_Joining_Group=_ Semkath}', "");
Expect(0, 1827, '\p{^Is_Joining_Group=_ Semkath}', "");
Expect(0, 1827, '\P{Is_Joining_Group=_ Semkath}', "");
Expect(1, 1827, '\P{^Is_Joining_Group=_ Semkath}', "");
Expect(0, 1828, '\p{Is_Joining_Group=_ Semkath}', "");
Expect(1, 1828, '\p{^Is_Joining_Group=_ Semkath}', "");
Expect(1, 1828, '\P{Is_Joining_Group=_ Semkath}', "");
Expect(0, 1828, '\P{^Is_Joining_Group=_ Semkath}', "");
Error('\p{Is_Jg=/a/	 SEMKATH}');
Error('\P{Is_Jg=/a/	 SEMKATH}');
Expect(1, 1827, '\p{Is_Jg=semkath}', "");
Expect(0, 1827, '\p{^Is_Jg=semkath}', "");
Expect(0, 1827, '\P{Is_Jg=semkath}', "");
Expect(1, 1827, '\P{^Is_Jg=semkath}', "");
Expect(0, 1828, '\p{Is_Jg=semkath}', "");
Expect(1, 1828, '\p{^Is_Jg=semkath}', "");
Expect(1, 1828, '\P{Is_Jg=semkath}', "");
Expect(0, 1828, '\P{^Is_Jg=semkath}', "");
Expect(1, 1827, '\p{Is_Jg=--SEMKATH}', "");
Expect(0, 1827, '\p{^Is_Jg=--SEMKATH}', "");
Expect(0, 1827, '\P{Is_Jg=--SEMKATH}', "");
Expect(1, 1827, '\P{^Is_Jg=--SEMKATH}', "");
Expect(0, 1828, '\p{Is_Jg=--SEMKATH}', "");
Expect(1, 1828, '\p{^Is_Jg=--SEMKATH}', "");
Expect(1, 1828, '\P{Is_Jg=--SEMKATH}', "");
Expect(0, 1828, '\P{^Is_Jg=--SEMKATH}', "");
Error('\p{Joining_Group=:=_ Shin}');
Error('\P{Joining_Group=:=_ Shin}');
Expect(1, 1835, '\p{Joining_Group=shin}', "");
Expect(0, 1835, '\p{^Joining_Group=shin}', "");
Expect(0, 1835, '\P{Joining_Group=shin}', "");
Expect(1, 1835, '\P{^Joining_Group=shin}', "");
Expect(0, 1836, '\p{Joining_Group=shin}', "");
Expect(1, 1836, '\p{^Joining_Group=shin}', "");
Expect(1, 1836, '\P{Joining_Group=shin}', "");
Expect(0, 1836, '\P{^Joining_Group=shin}', "");
Expect(1, 1835, '\p{Joining_Group:	 _shin}', "");
Expect(0, 1835, '\p{^Joining_Group:	 _shin}', "");
Expect(0, 1835, '\P{Joining_Group:	 _shin}', "");
Expect(1, 1835, '\P{^Joining_Group:	 _shin}', "");
Expect(0, 1836, '\p{Joining_Group:	 _shin}', "");
Expect(1, 1836, '\p{^Joining_Group:	 _shin}', "");
Expect(1, 1836, '\P{Joining_Group:	 _shin}', "");
Expect(0, 1836, '\P{^Joining_Group:	 _shin}', "");
Error('\p{Jg=:=-Shin}');
Error('\P{Jg=:=-Shin}');
Expect(1, 1835, '\p{Jg=shin}', "");
Expect(0, 1835, '\p{^Jg=shin}', "");
Expect(0, 1835, '\P{Jg=shin}', "");
Expect(1, 1835, '\P{^Jg=shin}', "");
Expect(0, 1836, '\p{Jg=shin}', "");
Expect(1, 1836, '\p{^Jg=shin}', "");
Expect(1, 1836, '\P{Jg=shin}', "");
Expect(0, 1836, '\P{^Jg=shin}', "");
Expect(1, 1835, '\p{Jg=	Shin}', "");
Expect(0, 1835, '\p{^Jg=	Shin}', "");
Expect(0, 1835, '\P{Jg=	Shin}', "");
Expect(1, 1835, '\P{^Jg=	Shin}', "");
Expect(0, 1836, '\p{Jg=	Shin}', "");
Expect(1, 1836, '\p{^Jg=	Shin}', "");
Expect(1, 1836, '\P{Jg=	Shin}', "");
Expect(0, 1836, '\P{^Jg=	Shin}', "");
Error('\p{Is_Joining_Group=/a/__Shin}');
Error('\P{Is_Joining_Group=/a/__Shin}');
Expect(1, 1835, '\p{Is_Joining_Group:shin}', "");
Expect(0, 1835, '\p{^Is_Joining_Group:shin}', "");
Expect(0, 1835, '\P{Is_Joining_Group:shin}', "");
Expect(1, 1835, '\P{^Is_Joining_Group:shin}', "");
Expect(0, 1836, '\p{Is_Joining_Group:shin}', "");
Expect(1, 1836, '\p{^Is_Joining_Group:shin}', "");
Expect(1, 1836, '\P{Is_Joining_Group:shin}', "");
Expect(0, 1836, '\P{^Is_Joining_Group:shin}', "");
Expect(1, 1835, '\p{Is_Joining_Group=	-shin}', "");
Expect(0, 1835, '\p{^Is_Joining_Group=	-shin}', "");
Expect(0, 1835, '\P{Is_Joining_Group=	-shin}', "");
Expect(1, 1835, '\P{^Is_Joining_Group=	-shin}', "");
Expect(0, 1836, '\p{Is_Joining_Group=	-shin}', "");
Expect(1, 1836, '\p{^Is_Joining_Group=	-shin}', "");
Expect(1, 1836, '\P{Is_Joining_Group=	-shin}', "");
Expect(0, 1836, '\P{^Is_Joining_Group=	-shin}', "");
Error('\p{Is_Jg: :=	shin}');
Error('\P{Is_Jg: :=	shin}');
Expect(1, 1835, '\p{Is_Jg: shin}', "");
Expect(0, 1835, '\p{^Is_Jg: shin}', "");
Expect(0, 1835, '\P{Is_Jg: shin}', "");
Expect(1, 1835, '\P{^Is_Jg: shin}', "");
Expect(0, 1836, '\p{Is_Jg: shin}', "");
Expect(1, 1836, '\p{^Is_Jg: shin}', "");
Expect(1, 1836, '\P{Is_Jg: shin}', "");
Expect(0, 1836, '\P{^Is_Jg: shin}', "");
Expect(1, 1835, '\p{Is_Jg=-Shin}', "");
Expect(0, 1835, '\p{^Is_Jg=-Shin}', "");
Expect(0, 1835, '\P{Is_Jg=-Shin}', "");
Expect(1, 1835, '\P{^Is_Jg=-Shin}', "");
Expect(0, 1836, '\p{Is_Jg=-Shin}', "");
Expect(1, 1836, '\p{^Is_Jg=-Shin}', "");
Expect(1, 1836, '\P{Is_Jg=-Shin}', "");
Expect(0, 1836, '\P{^Is_Jg=-Shin}', "");
Error('\p{Joining_Group=_/a/Swash_Kaf}');
Error('\P{Joining_Group=_/a/Swash_Kaf}');
Expect(1, 1706, '\p{Joining_Group=swashkaf}', "");
Expect(0, 1706, '\p{^Joining_Group=swashkaf}', "");
Expect(0, 1706, '\P{Joining_Group=swashkaf}', "");
Expect(1, 1706, '\P{^Joining_Group=swashkaf}', "");
Expect(0, 1707, '\p{Joining_Group=swashkaf}', "");
Expect(1, 1707, '\p{^Joining_Group=swashkaf}', "");
Expect(1, 1707, '\P{Joining_Group=swashkaf}', "");
Expect(0, 1707, '\P{^Joining_Group=swashkaf}', "");
Expect(1, 1706, '\p{Joining_Group=	Swash_Kaf}', "");
Expect(0, 1706, '\p{^Joining_Group=	Swash_Kaf}', "");
Expect(0, 1706, '\P{Joining_Group=	Swash_Kaf}', "");
Expect(1, 1706, '\P{^Joining_Group=	Swash_Kaf}', "");
Expect(0, 1707, '\p{Joining_Group=	Swash_Kaf}', "");
Expect(1, 1707, '\p{^Joining_Group=	Swash_Kaf}', "");
Expect(1, 1707, '\P{Joining_Group=	Swash_Kaf}', "");
Expect(0, 1707, '\P{^Joining_Group=	Swash_Kaf}', "");
Error('\p{Jg=	_Swash_kaf/a/}');
Error('\P{Jg=	_Swash_kaf/a/}');
Expect(1, 1706, '\p{Jg=swashkaf}', "");
Expect(0, 1706, '\p{^Jg=swashkaf}', "");
Expect(0, 1706, '\P{Jg=swashkaf}', "");
Expect(1, 1706, '\P{^Jg=swashkaf}', "");
Expect(0, 1707, '\p{Jg=swashkaf}', "");
Expect(1, 1707, '\p{^Jg=swashkaf}', "");
Expect(1, 1707, '\P{Jg=swashkaf}', "");
Expect(0, 1707, '\P{^Jg=swashkaf}', "");
Expect(1, 1706, '\p{Jg=_-Swash_KAF}', "");
Expect(0, 1706, '\p{^Jg=_-Swash_KAF}', "");
Expect(0, 1706, '\P{Jg=_-Swash_KAF}', "");
Expect(1, 1706, '\P{^Jg=_-Swash_KAF}', "");
Expect(0, 1707, '\p{Jg=_-Swash_KAF}', "");
Expect(1, 1707, '\p{^Jg=_-Swash_KAF}', "");
Expect(1, 1707, '\P{Jg=_-Swash_KAF}', "");
Expect(0, 1707, '\P{^Jg=_-Swash_KAF}', "");
Error('\p{Is_Joining_Group=:=	-SWASH_Kaf}');
Error('\P{Is_Joining_Group=:=	-SWASH_Kaf}');
Expect(1, 1706, '\p{Is_Joining_Group=swashkaf}', "");
Expect(0, 1706, '\p{^Is_Joining_Group=swashkaf}', "");
Expect(0, 1706, '\P{Is_Joining_Group=swashkaf}', "");
Expect(1, 1706, '\P{^Is_Joining_Group=swashkaf}', "");
Expect(0, 1707, '\p{Is_Joining_Group=swashkaf}', "");
Expect(1, 1707, '\p{^Is_Joining_Group=swashkaf}', "");
Expect(1, 1707, '\P{Is_Joining_Group=swashkaf}', "");
Expect(0, 1707, '\P{^Is_Joining_Group=swashkaf}', "");
Expect(1, 1706, '\p{Is_Joining_Group=	_Swash_Kaf}', "");
Expect(0, 1706, '\p{^Is_Joining_Group=	_Swash_Kaf}', "");
Expect(0, 1706, '\P{Is_Joining_Group=	_Swash_Kaf}', "");
Expect(1, 1706, '\P{^Is_Joining_Group=	_Swash_Kaf}', "");
Expect(0, 1707, '\p{Is_Joining_Group=	_Swash_Kaf}', "");
Expect(1, 1707, '\p{^Is_Joining_Group=	_Swash_Kaf}', "");
Expect(1, 1707, '\P{Is_Joining_Group=	_Swash_Kaf}', "");
Expect(0, 1707, '\P{^Is_Joining_Group=	_Swash_Kaf}', "");
Error('\p{Is_Jg=:=  swash_kaf}');
Error('\P{Is_Jg=:=  swash_kaf}');
Expect(1, 1706, '\p{Is_Jg=swashkaf}', "");
Expect(0, 1706, '\p{^Is_Jg=swashkaf}', "");
Expect(0, 1706, '\P{Is_Jg=swashkaf}', "");
Expect(1, 1706, '\P{^Is_Jg=swashkaf}', "");
Expect(0, 1707, '\p{Is_Jg=swashkaf}', "");
Expect(1, 1707, '\p{^Is_Jg=swashkaf}', "");
Expect(1, 1707, '\P{Is_Jg=swashkaf}', "");
Expect(0, 1707, '\P{^Is_Jg=swashkaf}', "");
Expect(1, 1706, '\p{Is_Jg:   SWASH_Kaf}', "");
Expect(0, 1706, '\p{^Is_Jg:   SWASH_Kaf}', "");
Expect(0, 1706, '\P{Is_Jg:   SWASH_Kaf}', "");
Expect(1, 1706, '\P{^Is_Jg:   SWASH_Kaf}', "");
Expect(0, 1707, '\p{Is_Jg:   SWASH_Kaf}', "");
Expect(1, 1707, '\p{^Is_Jg:   SWASH_Kaf}', "");
Expect(1, 1707, '\P{Is_Jg:   SWASH_Kaf}', "");
Expect(0, 1707, '\P{^Is_Jg:   SWASH_Kaf}', "");
Error('\p{Joining_Group=-SYRIAC_Waw:=}');
Error('\P{Joining_Group=-SYRIAC_Waw:=}');
Expect(1, 1816, '\p{Joining_Group=syriacwaw}', "");
Expect(0, 1816, '\p{^Joining_Group=syriacwaw}', "");
Expect(0, 1816, '\P{Joining_Group=syriacwaw}', "");
Expect(1, 1816, '\P{^Joining_Group=syriacwaw}', "");
Expect(0, 1817, '\p{Joining_Group=syriacwaw}', "");
Expect(1, 1817, '\p{^Joining_Group=syriacwaw}', "");
Expect(1, 1817, '\P{Joining_Group=syriacwaw}', "");
Expect(0, 1817, '\P{^Joining_Group=syriacwaw}', "");
Expect(1, 1816, '\p{Joining_Group= _SYRIAC_WAW}', "");
Expect(0, 1816, '\p{^Joining_Group= _SYRIAC_WAW}', "");
Expect(0, 1816, '\P{Joining_Group= _SYRIAC_WAW}', "");
Expect(1, 1816, '\P{^Joining_Group= _SYRIAC_WAW}', "");
Expect(0, 1817, '\p{Joining_Group= _SYRIAC_WAW}', "");
Expect(1, 1817, '\p{^Joining_Group= _SYRIAC_WAW}', "");
Expect(1, 1817, '\P{Joining_Group= _SYRIAC_WAW}', "");
Expect(0, 1817, '\P{^Joining_Group= _SYRIAC_WAW}', "");
Error('\p{Jg=- SYRIAC_WAW/a/}');
Error('\P{Jg=- SYRIAC_WAW/a/}');
Expect(1, 1816, '\p{Jg=syriacwaw}', "");
Expect(0, 1816, '\p{^Jg=syriacwaw}', "");
Expect(0, 1816, '\P{Jg=syriacwaw}', "");
Expect(1, 1816, '\P{^Jg=syriacwaw}', "");
Expect(0, 1817, '\p{Jg=syriacwaw}', "");
Expect(1, 1817, '\p{^Jg=syriacwaw}', "");
Expect(1, 1817, '\P{Jg=syriacwaw}', "");
Expect(0, 1817, '\P{^Jg=syriacwaw}', "");
Expect(1, 1816, '\p{Jg=-_syriac_Waw}', "");
Expect(0, 1816, '\p{^Jg=-_syriac_Waw}', "");
Expect(0, 1816, '\P{Jg=-_syriac_Waw}', "");
Expect(1, 1816, '\P{^Jg=-_syriac_Waw}', "");
Expect(0, 1817, '\p{Jg=-_syriac_Waw}', "");
Expect(1, 1817, '\p{^Jg=-_syriac_Waw}', "");
Expect(1, 1817, '\P{Jg=-_syriac_Waw}', "");
Expect(0, 1817, '\P{^Jg=-_syriac_Waw}', "");
Error('\p{Is_Joining_Group=/a/-Syriac_WAW}');
Error('\P{Is_Joining_Group=/a/-Syriac_WAW}');
Expect(1, 1816, '\p{Is_Joining_Group=syriacwaw}', "");
Expect(0, 1816, '\p{^Is_Joining_Group=syriacwaw}', "");
Expect(0, 1816, '\P{Is_Joining_Group=syriacwaw}', "");
Expect(1, 1816, '\P{^Is_Joining_Group=syriacwaw}', "");
Expect(0, 1817, '\p{Is_Joining_Group=syriacwaw}', "");
Expect(1, 1817, '\p{^Is_Joining_Group=syriacwaw}', "");
Expect(1, 1817, '\P{Is_Joining_Group=syriacwaw}', "");
Expect(0, 1817, '\P{^Is_Joining_Group=syriacwaw}', "");
Expect(1, 1816, '\p{Is_Joining_Group=-Syriac_Waw}', "");
Expect(0, 1816, '\p{^Is_Joining_Group=-Syriac_Waw}', "");
Expect(0, 1816, '\P{Is_Joining_Group=-Syriac_Waw}', "");
Expect(1, 1816, '\P{^Is_Joining_Group=-Syriac_Waw}', "");
Expect(0, 1817, '\p{Is_Joining_Group=-Syriac_Waw}', "");
Expect(1, 1817, '\p{^Is_Joining_Group=-Syriac_Waw}', "");
Expect(1, 1817, '\P{Is_Joining_Group=-Syriac_Waw}', "");
Expect(0, 1817, '\P{^Is_Joining_Group=-Syriac_Waw}', "");
Error('\p{Is_Jg=/a/-	SYRIAC_waw}');
Error('\P{Is_Jg=/a/-	SYRIAC_waw}');
Expect(1, 1816, '\p{Is_Jg=syriacwaw}', "");
Expect(0, 1816, '\p{^Is_Jg=syriacwaw}', "");
Expect(0, 1816, '\P{Is_Jg=syriacwaw}', "");
Expect(1, 1816, '\P{^Is_Jg=syriacwaw}', "");
Expect(0, 1817, '\p{Is_Jg=syriacwaw}', "");
Expect(1, 1817, '\p{^Is_Jg=syriacwaw}', "");
Expect(1, 1817, '\P{Is_Jg=syriacwaw}', "");
Expect(0, 1817, '\P{^Is_Jg=syriacwaw}', "");
Expect(1, 1816, '\p{Is_Jg=_SYRIAC_Waw}', "");
Expect(0, 1816, '\p{^Is_Jg=_SYRIAC_Waw}', "");
Expect(0, 1816, '\P{Is_Jg=_SYRIAC_Waw}', "");
Expect(1, 1816, '\P{^Is_Jg=_SYRIAC_Waw}', "");
Expect(0, 1817, '\p{Is_Jg=_SYRIAC_Waw}', "");
Expect(1, 1817, '\p{^Is_Jg=_SYRIAC_Waw}', "");
Expect(1, 1817, '\P{Is_Jg=_SYRIAC_Waw}', "");
Expect(0, 1817, '\P{^Is_Jg=_SYRIAC_Waw}', "");
Error('\p{Joining_Group=:=TAH}');
Error('\P{Joining_Group=:=TAH}');
Expect(1, 2211, '\p{Joining_Group=tah}', "");
Expect(0, 2211, '\p{^Joining_Group=tah}', "");
Expect(0, 2211, '\P{Joining_Group=tah}', "");
Expect(1, 2211, '\P{^Joining_Group=tah}', "");
Expect(0, 2212, '\p{Joining_Group=tah}', "");
Expect(1, 2212, '\p{^Joining_Group=tah}', "");
Expect(1, 2212, '\P{Joining_Group=tah}', "");
Expect(0, 2212, '\P{^Joining_Group=tah}', "");
Expect(1, 2211, '\p{Joining_Group=--Tah}', "");
Expect(0, 2211, '\p{^Joining_Group=--Tah}', "");
Expect(0, 2211, '\P{Joining_Group=--Tah}', "");
Expect(1, 2211, '\P{^Joining_Group=--Tah}', "");
Expect(0, 2212, '\p{Joining_Group=--Tah}', "");
Expect(1, 2212, '\p{^Joining_Group=--Tah}', "");
Expect(1, 2212, '\P{Joining_Group=--Tah}', "");
Expect(0, 2212, '\P{^Joining_Group=--Tah}', "");
Error('\p{Jg=	TAH/a/}');
Error('\P{Jg=	TAH/a/}');
Expect(1, 2211, '\p{Jg=tah}', "");
Expect(0, 2211, '\p{^Jg=tah}', "");
Expect(0, 2211, '\P{Jg=tah}', "");
Expect(1, 2211, '\P{^Jg=tah}', "");
Expect(0, 2212, '\p{Jg=tah}', "");
Expect(1, 2212, '\p{^Jg=tah}', "");
Expect(1, 2212, '\P{Jg=tah}', "");
Expect(0, 2212, '\P{^Jg=tah}', "");
Expect(1, 2211, '\p{Jg=- Tah}', "");
Expect(0, 2211, '\p{^Jg=- Tah}', "");
Expect(0, 2211, '\P{Jg=- Tah}', "");
Expect(1, 2211, '\P{^Jg=- Tah}', "");
Expect(0, 2212, '\p{Jg=- Tah}', "");
Expect(1, 2212, '\p{^Jg=- Tah}', "");
Expect(1, 2212, '\P{Jg=- Tah}', "");
Expect(0, 2212, '\P{^Jg=- Tah}', "");
Error('\p{Is_Joining_Group=-_tah:=}');
Error('\P{Is_Joining_Group=-_tah:=}');
Expect(1, 2211, '\p{Is_Joining_Group=tah}', "");
Expect(0, 2211, '\p{^Is_Joining_Group=tah}', "");
Expect(0, 2211, '\P{Is_Joining_Group=tah}', "");
Expect(1, 2211, '\P{^Is_Joining_Group=tah}', "");
Expect(0, 2212, '\p{Is_Joining_Group=tah}', "");
Expect(1, 2212, '\p{^Is_Joining_Group=tah}', "");
Expect(1, 2212, '\P{Is_Joining_Group=tah}', "");
Expect(0, 2212, '\P{^Is_Joining_Group=tah}', "");
Expect(1, 2211, '\p{Is_Joining_Group=--Tah}', "");
Expect(0, 2211, '\p{^Is_Joining_Group=--Tah}', "");
Expect(0, 2211, '\P{Is_Joining_Group=--Tah}', "");
Expect(1, 2211, '\P{^Is_Joining_Group=--Tah}', "");
Expect(0, 2212, '\p{Is_Joining_Group=--Tah}', "");
Expect(1, 2212, '\p{^Is_Joining_Group=--Tah}', "");
Expect(1, 2212, '\P{Is_Joining_Group=--Tah}', "");
Expect(0, 2212, '\P{^Is_Joining_Group=--Tah}', "");
Error('\p{Is_Jg:   TAH/a/}');
Error('\P{Is_Jg:   TAH/a/}');
Expect(1, 2211, '\p{Is_Jg=tah}', "");
Expect(0, 2211, '\p{^Is_Jg=tah}', "");
Expect(0, 2211, '\P{Is_Jg=tah}', "");
Expect(1, 2211, '\P{^Is_Jg=tah}', "");
Expect(0, 2212, '\p{Is_Jg=tah}', "");
Expect(1, 2212, '\p{^Is_Jg=tah}', "");
Expect(1, 2212, '\P{Is_Jg=tah}', "");
Expect(0, 2212, '\P{^Is_Jg=tah}', "");
Expect(1, 2211, '\p{Is_Jg= 	Tah}', "");
Expect(0, 2211, '\p{^Is_Jg= 	Tah}', "");
Expect(0, 2211, '\P{Is_Jg= 	Tah}', "");
Expect(1, 2211, '\P{^Is_Jg= 	Tah}', "");
Expect(0, 2212, '\p{Is_Jg= 	Tah}', "");
Expect(1, 2212, '\p{^Is_Jg= 	Tah}', "");
Expect(1, 2212, '\P{Is_Jg= 	Tah}', "");
Expect(0, 2212, '\P{^Is_Jg= 	Tah}', "");
Error('\p{Joining_Group=_ Taw:=}');
Error('\P{Joining_Group=_ Taw:=}');
Expect(1, 1836, '\p{Joining_Group=taw}', "");
Expect(0, 1836, '\p{^Joining_Group=taw}', "");
Expect(0, 1836, '\P{Joining_Group=taw}', "");
Expect(1, 1836, '\P{^Joining_Group=taw}', "");
Expect(0, 1837, '\p{Joining_Group=taw}', "");
Expect(1, 1837, '\p{^Joining_Group=taw}', "");
Expect(1, 1837, '\P{Joining_Group=taw}', "");
Expect(0, 1837, '\P{^Joining_Group=taw}', "");
Expect(1, 1836, '\p{Joining_Group=-_Taw}', "");
Expect(0, 1836, '\p{^Joining_Group=-_Taw}', "");
Expect(0, 1836, '\P{Joining_Group=-_Taw}', "");
Expect(1, 1836, '\P{^Joining_Group=-_Taw}', "");
Expect(0, 1837, '\p{Joining_Group=-_Taw}', "");
Expect(1, 1837, '\p{^Joining_Group=-_Taw}', "");
Expect(1, 1837, '\P{Joining_Group=-_Taw}', "");
Expect(0, 1837, '\P{^Joining_Group=-_Taw}', "");
Error('\p{Jg=	Taw:=}');
Error('\P{Jg=	Taw:=}');
Expect(1, 1836, '\p{Jg=taw}', "");
Expect(0, 1836, '\p{^Jg=taw}', "");
Expect(0, 1836, '\P{Jg=taw}', "");
Expect(1, 1836, '\P{^Jg=taw}', "");
Expect(0, 1837, '\p{Jg=taw}', "");
Expect(1, 1837, '\p{^Jg=taw}', "");
Expect(1, 1837, '\P{Jg=taw}', "");
Expect(0, 1837, '\P{^Jg=taw}', "");
Expect(1, 1836, '\p{Jg=-taw}', "");
Expect(0, 1836, '\p{^Jg=-taw}', "");
Expect(0, 1836, '\P{Jg=-taw}', "");
Expect(1, 1836, '\P{^Jg=-taw}', "");
Expect(0, 1837, '\p{Jg=-taw}', "");
Expect(1, 1837, '\p{^Jg=-taw}', "");
Expect(1, 1837, '\P{Jg=-taw}', "");
Expect(0, 1837, '\P{^Jg=-taw}', "");
Error('\p{Is_Joining_Group:   	/a/TAW}');
Error('\P{Is_Joining_Group:   	/a/TAW}');
Expect(1, 1836, '\p{Is_Joining_Group=taw}', "");
Expect(0, 1836, '\p{^Is_Joining_Group=taw}', "");
Expect(0, 1836, '\P{Is_Joining_Group=taw}', "");
Expect(1, 1836, '\P{^Is_Joining_Group=taw}', "");
Expect(0, 1837, '\p{Is_Joining_Group=taw}', "");
Expect(1, 1837, '\p{^Is_Joining_Group=taw}', "");
Expect(1, 1837, '\P{Is_Joining_Group=taw}', "");
Expect(0, 1837, '\P{^Is_Joining_Group=taw}', "");
Expect(1, 1836, '\p{Is_Joining_Group=__Taw}', "");
Expect(0, 1836, '\p{^Is_Joining_Group=__Taw}', "");
Expect(0, 1836, '\P{Is_Joining_Group=__Taw}', "");
Expect(1, 1836, '\P{^Is_Joining_Group=__Taw}', "");
Expect(0, 1837, '\p{Is_Joining_Group=__Taw}', "");
Expect(1, 1837, '\p{^Is_Joining_Group=__Taw}', "");
Expect(1, 1837, '\P{Is_Joining_Group=__Taw}', "");
Expect(0, 1837, '\P{^Is_Joining_Group=__Taw}', "");
Error('\p{Is_Jg=/a/_Taw}');
Error('\P{Is_Jg=/a/_Taw}');
Expect(1, 1836, '\p{Is_Jg=taw}', "");
Expect(0, 1836, '\p{^Is_Jg=taw}', "");
Expect(0, 1836, '\P{Is_Jg=taw}', "");
Expect(1, 1836, '\P{^Is_Jg=taw}', "");
Expect(0, 1837, '\p{Is_Jg=taw}', "");
Expect(1, 1837, '\p{^Is_Jg=taw}', "");
Expect(1, 1837, '\P{Is_Jg=taw}', "");
Expect(0, 1837, '\P{^Is_Jg=taw}', "");
Expect(1, 1836, '\p{Is_Jg=- taw}', "");
Expect(0, 1836, '\p{^Is_Jg=- taw}', "");
Expect(0, 1836, '\P{Is_Jg=- taw}', "");
Expect(1, 1836, '\P{^Is_Jg=- taw}', "");
Expect(0, 1837, '\p{Is_Jg=- taw}', "");
Expect(1, 1837, '\p{^Is_Jg=- taw}', "");
Expect(1, 1837, '\P{Is_Jg=- taw}', "");
Expect(0, 1837, '\P{^Is_Jg=- taw}', "");
Error('\p{Joining_Group=_/a/Teh_Marbuta}');
Error('\P{Joining_Group=_/a/Teh_Marbuta}');
Expect(1, 1749, '\p{Joining_Group=tehmarbuta}', "");
Expect(0, 1749, '\p{^Joining_Group=tehmarbuta}', "");
Expect(0, 1749, '\P{Joining_Group=tehmarbuta}', "");
Expect(1, 1749, '\P{^Joining_Group=tehmarbuta}', "");
Expect(0, 1750, '\p{Joining_Group=tehmarbuta}', "");
Expect(1, 1750, '\p{^Joining_Group=tehmarbuta}', "");
Expect(1, 1750, '\P{Joining_Group=tehmarbuta}', "");
Expect(0, 1750, '\P{^Joining_Group=tehmarbuta}', "");
Expect(1, 1749, '\p{Joining_Group=_Teh_Marbuta}', "");
Expect(0, 1749, '\p{^Joining_Group=_Teh_Marbuta}', "");
Expect(0, 1749, '\P{Joining_Group=_Teh_Marbuta}', "");
Expect(1, 1749, '\P{^Joining_Group=_Teh_Marbuta}', "");
Expect(0, 1750, '\p{Joining_Group=_Teh_Marbuta}', "");
Expect(1, 1750, '\p{^Joining_Group=_Teh_Marbuta}', "");
Expect(1, 1750, '\P{Joining_Group=_Teh_Marbuta}', "");
Expect(0, 1750, '\P{^Joining_Group=_Teh_Marbuta}', "");
Error('\p{Jg=  teh_Marbuta/a/}');
Error('\P{Jg=  teh_Marbuta/a/}');
Expect(1, 1749, '\p{Jg=tehmarbuta}', "");
Expect(0, 1749, '\p{^Jg=tehmarbuta}', "");
Expect(0, 1749, '\P{Jg=tehmarbuta}', "");
Expect(1, 1749, '\P{^Jg=tehmarbuta}', "");
Expect(0, 1750, '\p{Jg=tehmarbuta}', "");
Expect(1, 1750, '\p{^Jg=tehmarbuta}', "");
Expect(1, 1750, '\P{Jg=tehmarbuta}', "");
Expect(0, 1750, '\P{^Jg=tehmarbuta}', "");
Expect(1, 1749, '\p{Jg= -Teh_MARBUTA}', "");
Expect(0, 1749, '\p{^Jg= -Teh_MARBUTA}', "");
Expect(0, 1749, '\P{Jg= -Teh_MARBUTA}', "");
Expect(1, 1749, '\P{^Jg= -Teh_MARBUTA}', "");
Expect(0, 1750, '\p{Jg= -Teh_MARBUTA}', "");
Expect(1, 1750, '\p{^Jg= -Teh_MARBUTA}', "");
Expect(1, 1750, '\P{Jg= -Teh_MARBUTA}', "");
Expect(0, 1750, '\P{^Jg= -Teh_MARBUTA}', "");
Error('\p{Is_Joining_Group=:=	 Teh_marbuta}');
Error('\P{Is_Joining_Group=:=	 Teh_marbuta}');
Expect(1, 1749, '\p{Is_Joining_Group=tehmarbuta}', "");
Expect(0, 1749, '\p{^Is_Joining_Group=tehmarbuta}', "");
Expect(0, 1749, '\P{Is_Joining_Group=tehmarbuta}', "");
Expect(1, 1749, '\P{^Is_Joining_Group=tehmarbuta}', "");
Expect(0, 1750, '\p{Is_Joining_Group=tehmarbuta}', "");
Expect(1, 1750, '\p{^Is_Joining_Group=tehmarbuta}', "");
Expect(1, 1750, '\P{Is_Joining_Group=tehmarbuta}', "");
Expect(0, 1750, '\P{^Is_Joining_Group=tehmarbuta}', "");
Expect(1, 1749, '\p{Is_Joining_Group=	TEH_Marbuta}', "");
Expect(0, 1749, '\p{^Is_Joining_Group=	TEH_Marbuta}', "");
Expect(0, 1749, '\P{Is_Joining_Group=	TEH_Marbuta}', "");
Expect(1, 1749, '\P{^Is_Joining_Group=	TEH_Marbuta}', "");
Expect(0, 1750, '\p{Is_Joining_Group=	TEH_Marbuta}', "");
Expect(1, 1750, '\p{^Is_Joining_Group=	TEH_Marbuta}', "");
Expect(1, 1750, '\P{Is_Joining_Group=	TEH_Marbuta}', "");
Expect(0, 1750, '\P{^Is_Joining_Group=	TEH_Marbuta}', "");
Error('\p{Is_Jg=/a/-teh_marbuta}');
Error('\P{Is_Jg=/a/-teh_marbuta}');
Expect(1, 1749, '\p{Is_Jg=tehmarbuta}', "");
Expect(0, 1749, '\p{^Is_Jg=tehmarbuta}', "");
Expect(0, 1749, '\P{Is_Jg=tehmarbuta}', "");
Expect(1, 1749, '\P{^Is_Jg=tehmarbuta}', "");
Expect(0, 1750, '\p{Is_Jg=tehmarbuta}', "");
Expect(1, 1750, '\p{^Is_Jg=tehmarbuta}', "");
Expect(1, 1750, '\P{Is_Jg=tehmarbuta}', "");
Expect(0, 1750, '\P{^Is_Jg=tehmarbuta}', "");
Expect(1, 1749, '\p{Is_Jg= -Teh_Marbuta}', "");
Expect(0, 1749, '\p{^Is_Jg= -Teh_Marbuta}', "");
Expect(0, 1749, '\P{Is_Jg= -Teh_Marbuta}', "");
Expect(1, 1749, '\P{^Is_Jg= -Teh_Marbuta}', "");
Expect(0, 1750, '\p{Is_Jg= -Teh_Marbuta}', "");
Expect(1, 1750, '\p{^Is_Jg= -Teh_Marbuta}', "");
Expect(1, 1750, '\P{Is_Jg= -Teh_Marbuta}', "");
Expect(0, 1750, '\P{^Is_Jg= -Teh_Marbuta}', "");
Error('\p{Joining_Group=/a/	 Hamza_ON_Heh_GOAL}');
Error('\P{Joining_Group=/a/	 Hamza_ON_Heh_GOAL}');
Expect(1, 1731, '\p{Joining_Group: hamzaonhehgoal}', "");
Expect(0, 1731, '\p{^Joining_Group: hamzaonhehgoal}', "");
Expect(0, 1731, '\P{Joining_Group: hamzaonhehgoal}', "");
Expect(1, 1731, '\P{^Joining_Group: hamzaonhehgoal}', "");
Expect(0, 1732, '\p{Joining_Group: hamzaonhehgoal}', "");
Expect(1, 1732, '\p{^Joining_Group: hamzaonhehgoal}', "");
Expect(1, 1732, '\P{Joining_Group: hamzaonhehgoal}', "");
Expect(0, 1732, '\P{^Joining_Group: hamzaonhehgoal}', "");
Expect(1, 1731, '\p{Joining_Group=	 hamza_On_Heh_goal}', "");
Expect(0, 1731, '\p{^Joining_Group=	 hamza_On_Heh_goal}', "");
Expect(0, 1731, '\P{Joining_Group=	 hamza_On_Heh_goal}', "");
Expect(1, 1731, '\P{^Joining_Group=	 hamza_On_Heh_goal}', "");
Expect(0, 1732, '\p{Joining_Group=	 hamza_On_Heh_goal}', "");
Expect(1, 1732, '\p{^Joining_Group=	 hamza_On_Heh_goal}', "");
Expect(1, 1732, '\P{Joining_Group=	 hamza_On_Heh_goal}', "");
Expect(0, 1732, '\P{^Joining_Group=	 hamza_On_Heh_goal}', "");
Error('\p{Jg=-:=Teh_Marbuta_Goal}');
Error('\P{Jg=-:=Teh_Marbuta_Goal}');
Expect(1, 1731, '\p{Jg=tehmarbutagoal}', "");
Expect(0, 1731, '\p{^Jg=tehmarbutagoal}', "");
Expect(0, 1731, '\P{Jg=tehmarbutagoal}', "");
Expect(1, 1731, '\P{^Jg=tehmarbutagoal}', "");
Expect(0, 1732, '\p{Jg=tehmarbutagoal}', "");
Expect(1, 1732, '\p{^Jg=tehmarbutagoal}', "");
Expect(1, 1732, '\P{Jg=tehmarbutagoal}', "");
Expect(0, 1732, '\P{^Jg=tehmarbutagoal}', "");
Expect(1, 1731, '\p{Jg=	-Teh_Marbuta_GOAL}', "");
Expect(0, 1731, '\p{^Jg=	-Teh_Marbuta_GOAL}', "");
Expect(0, 1731, '\P{Jg=	-Teh_Marbuta_GOAL}', "");
Expect(1, 1731, '\P{^Jg=	-Teh_Marbuta_GOAL}', "");
Expect(0, 1732, '\p{Jg=	-Teh_Marbuta_GOAL}', "");
Expect(1, 1732, '\p{^Jg=	-Teh_Marbuta_GOAL}', "");
Expect(1, 1732, '\P{Jg=	-Teh_Marbuta_GOAL}', "");
Expect(0, 1732, '\P{^Jg=	-Teh_Marbuta_GOAL}', "");
Error('\p{Is_Joining_Group=Hamza_On_HEH_goal/a/}');
Error('\P{Is_Joining_Group=Hamza_On_HEH_goal/a/}');
Expect(1, 1731, '\p{Is_Joining_Group:   hamzaonhehgoal}', "");
Expect(0, 1731, '\p{^Is_Joining_Group:   hamzaonhehgoal}', "");
Expect(0, 1731, '\P{Is_Joining_Group:   hamzaonhehgoal}', "");
Expect(1, 1731, '\P{^Is_Joining_Group:   hamzaonhehgoal}', "");
Expect(0, 1732, '\p{Is_Joining_Group:   hamzaonhehgoal}', "");
Expect(1, 1732, '\p{^Is_Joining_Group:   hamzaonhehgoal}', "");
Expect(1, 1732, '\P{Is_Joining_Group:   hamzaonhehgoal}', "");
Expect(0, 1732, '\P{^Is_Joining_Group:   hamzaonhehgoal}', "");
Expect(1, 1731, '\p{Is_Joining_Group=_-hamza_On_Heh_GOAL}', "");
Expect(0, 1731, '\p{^Is_Joining_Group=_-hamza_On_Heh_GOAL}', "");
Expect(0, 1731, '\P{Is_Joining_Group=_-hamza_On_Heh_GOAL}', "");
Expect(1, 1731, '\P{^Is_Joining_Group=_-hamza_On_Heh_GOAL}', "");
Expect(0, 1732, '\p{Is_Joining_Group=_-hamza_On_Heh_GOAL}', "");
Expect(1, 1732, '\p{^Is_Joining_Group=_-hamza_On_Heh_GOAL}', "");
Expect(1, 1732, '\P{Is_Joining_Group=_-hamza_On_Heh_GOAL}', "");
Expect(0, 1732, '\P{^Is_Joining_Group=_-hamza_On_Heh_GOAL}', "");
Error('\p{Is_Jg::=	teh_Marbuta_GOAL}');
Error('\P{Is_Jg::=	teh_Marbuta_GOAL}');
Expect(1, 1731, '\p{Is_Jg=tehmarbutagoal}', "");
Expect(0, 1731, '\p{^Is_Jg=tehmarbutagoal}', "");
Expect(0, 1731, '\P{Is_Jg=tehmarbutagoal}', "");
Expect(1, 1731, '\P{^Is_Jg=tehmarbutagoal}', "");
Expect(0, 1732, '\p{Is_Jg=tehmarbutagoal}', "");
Expect(1, 1732, '\p{^Is_Jg=tehmarbutagoal}', "");
Expect(1, 1732, '\P{Is_Jg=tehmarbutagoal}', "");
Expect(0, 1732, '\P{^Is_Jg=tehmarbutagoal}', "");
Expect(1, 1731, '\p{Is_Jg=-TEH_marbuta_GOAL}', "");
Expect(0, 1731, '\p{^Is_Jg=-TEH_marbuta_GOAL}', "");
Expect(0, 1731, '\P{Is_Jg=-TEH_marbuta_GOAL}', "");
Expect(1, 1731, '\P{^Is_Jg=-TEH_marbuta_GOAL}', "");
Expect(0, 1732, '\p{Is_Jg=-TEH_marbuta_GOAL}', "");
Expect(1, 1732, '\p{^Is_Jg=-TEH_marbuta_GOAL}', "");
Expect(1, 1732, '\P{Is_Jg=-TEH_marbuta_GOAL}', "");
Expect(0, 1732, '\P{^Is_Jg=-TEH_marbuta_GOAL}', "");
Error('\p{Joining_Group=:=_ Teth}');
Error('\P{Joining_Group=:=_ Teth}');
Expect(1, 1820, '\p{Joining_Group:	teth}', "");
Expect(0, 1820, '\p{^Joining_Group:	teth}', "");
Expect(0, 1820, '\P{Joining_Group:	teth}', "");
Expect(1, 1820, '\P{^Joining_Group:	teth}', "");
Expect(0, 1821, '\p{Joining_Group:	teth}', "");
Expect(1, 1821, '\p{^Joining_Group:	teth}', "");
Expect(1, 1821, '\P{Joining_Group:	teth}', "");
Expect(0, 1821, '\P{^Joining_Group:	teth}', "");
Expect(1, 1820, '\p{Joining_Group:   	Teth}', "");
Expect(0, 1820, '\p{^Joining_Group:   	Teth}', "");
Expect(0, 1820, '\P{Joining_Group:   	Teth}', "");
Expect(1, 1820, '\P{^Joining_Group:   	Teth}', "");
Expect(0, 1821, '\p{Joining_Group:   	Teth}', "");
Expect(1, 1821, '\p{^Joining_Group:   	Teth}', "");
Expect(1, 1821, '\P{Joining_Group:   	Teth}', "");
Expect(0, 1821, '\P{^Joining_Group:   	Teth}', "");
Error('\p{Jg=:=	 Teth}');
Error('\P{Jg=:=	 Teth}');
Expect(1, 1820, '\p{Jg=teth}', "");
Expect(0, 1820, '\p{^Jg=teth}', "");
Expect(0, 1820, '\P{Jg=teth}', "");
Expect(1, 1820, '\P{^Jg=teth}', "");
Expect(0, 1821, '\p{Jg=teth}', "");
Expect(1, 1821, '\p{^Jg=teth}', "");
Expect(1, 1821, '\P{Jg=teth}', "");
Expect(0, 1821, '\P{^Jg=teth}', "");
Expect(1, 1820, '\p{Jg=-Teth}', "");
Expect(0, 1820, '\p{^Jg=-Teth}', "");
Expect(0, 1820, '\P{Jg=-Teth}', "");
Expect(1, 1820, '\P{^Jg=-Teth}', "");
Expect(0, 1821, '\p{Jg=-Teth}', "");
Expect(1, 1821, '\p{^Jg=-Teth}', "");
Expect(1, 1821, '\P{Jg=-Teth}', "");
Expect(0, 1821, '\P{^Jg=-Teth}', "");
Error('\p{Is_Joining_Group=/a/-TETH}');
Error('\P{Is_Joining_Group=/a/-TETH}');
Expect(1, 1820, '\p{Is_Joining_Group=teth}', "");
Expect(0, 1820, '\p{^Is_Joining_Group=teth}', "");
Expect(0, 1820, '\P{Is_Joining_Group=teth}', "");
Expect(1, 1820, '\P{^Is_Joining_Group=teth}', "");
Expect(0, 1821, '\p{Is_Joining_Group=teth}', "");
Expect(1, 1821, '\p{^Is_Joining_Group=teth}', "");
Expect(1, 1821, '\P{Is_Joining_Group=teth}', "");
Expect(0, 1821, '\P{^Is_Joining_Group=teth}', "");
Expect(1, 1820, '\p{Is_Joining_Group= TETH}', "");
Expect(0, 1820, '\p{^Is_Joining_Group= TETH}', "");
Expect(0, 1820, '\P{Is_Joining_Group= TETH}', "");
Expect(1, 1820, '\P{^Is_Joining_Group= TETH}', "");
Expect(0, 1821, '\p{Is_Joining_Group= TETH}', "");
Expect(1, 1821, '\p{^Is_Joining_Group= TETH}', "");
Expect(1, 1821, '\P{Is_Joining_Group= TETH}', "");
Expect(0, 1821, '\P{^Is_Joining_Group= TETH}', "");
Error('\p{Is_Jg=	:=Teth}');
Error('\P{Is_Jg=	:=Teth}');
Expect(1, 1820, '\p{Is_Jg=teth}', "");
Expect(0, 1820, '\p{^Is_Jg=teth}', "");
Expect(0, 1820, '\P{Is_Jg=teth}', "");
Expect(1, 1820, '\P{^Is_Jg=teth}', "");
Expect(0, 1821, '\p{Is_Jg=teth}', "");
Expect(1, 1821, '\p{^Is_Jg=teth}', "");
Expect(1, 1821, '\P{Is_Jg=teth}', "");
Expect(0, 1821, '\P{^Is_Jg=teth}', "");
Expect(1, 1820, '\p{Is_Jg=- TETH}', "");
Expect(0, 1820, '\p{^Is_Jg=- TETH}', "");
Expect(0, 1820, '\P{Is_Jg=- TETH}', "");
Expect(1, 1820, '\P{^Is_Jg=- TETH}', "");
Expect(0, 1821, '\p{Is_Jg=- TETH}', "");
Expect(1, 1821, '\p{^Is_Jg=- TETH}', "");
Expect(1, 1821, '\P{Is_Jg=- TETH}', "");
Expect(0, 1821, '\P{^Is_Jg=- TETH}', "");
Error('\p{Joining_Group=/a/Waw}');
Error('\P{Joining_Group=/a/Waw}');
Expect(1, 2219, '\p{Joining_Group=waw}', "");
Expect(0, 2219, '\p{^Joining_Group=waw}', "");
Expect(0, 2219, '\P{Joining_Group=waw}', "");
Expect(1, 2219, '\P{^Joining_Group=waw}', "");
Expect(0, 2220, '\p{Joining_Group=waw}', "");
Expect(1, 2220, '\p{^Joining_Group=waw}', "");
Expect(1, 2220, '\P{Joining_Group=waw}', "");
Expect(0, 2220, '\P{^Joining_Group=waw}', "");
Expect(1, 2219, '\p{Joining_Group=  Waw}', "");
Expect(0, 2219, '\p{^Joining_Group=  Waw}', "");
Expect(0, 2219, '\P{Joining_Group=  Waw}', "");
Expect(1, 2219, '\P{^Joining_Group=  Waw}', "");
Expect(0, 2220, '\p{Joining_Group=  Waw}', "");
Expect(1, 2220, '\p{^Joining_Group=  Waw}', "");
Expect(1, 2220, '\P{Joining_Group=  Waw}', "");
Expect(0, 2220, '\P{^Joining_Group=  Waw}', "");
Error('\p{Jg=_:=Waw}');
Error('\P{Jg=_:=Waw}');
Expect(1, 2219, '\p{Jg=waw}', "");
Expect(0, 2219, '\p{^Jg=waw}', "");
Expect(0, 2219, '\P{Jg=waw}', "");
Expect(1, 2219, '\P{^Jg=waw}', "");
Expect(0, 2220, '\p{Jg=waw}', "");
Expect(1, 2220, '\p{^Jg=waw}', "");
Expect(1, 2220, '\P{Jg=waw}', "");
Expect(0, 2220, '\P{^Jg=waw}', "");
Expect(1, 2219, '\p{Jg=_WAW}', "");
Expect(0, 2219, '\p{^Jg=_WAW}', "");
Expect(0, 2219, '\P{Jg=_WAW}', "");
Expect(1, 2219, '\P{^Jg=_WAW}', "");
Expect(0, 2220, '\p{Jg=_WAW}', "");
Expect(1, 2220, '\p{^Jg=_WAW}', "");
Expect(1, 2220, '\P{Jg=_WAW}', "");
Expect(0, 2220, '\P{^Jg=_WAW}', "");
Error('\p{Is_Joining_Group=	:=Waw}');
Error('\P{Is_Joining_Group=	:=Waw}');
Expect(1, 2219, '\p{Is_Joining_Group=waw}', "");
Expect(0, 2219, '\p{^Is_Joining_Group=waw}', "");
Expect(0, 2219, '\P{Is_Joining_Group=waw}', "");
Expect(1, 2219, '\P{^Is_Joining_Group=waw}', "");
Expect(0, 2220, '\p{Is_Joining_Group=waw}', "");
Expect(1, 2220, '\p{^Is_Joining_Group=waw}', "");
Expect(1, 2220, '\P{Is_Joining_Group=waw}', "");
Expect(0, 2220, '\P{^Is_Joining_Group=waw}', "");
Expect(1, 2219, '\p{Is_Joining_Group=_-waw}', "");
Expect(0, 2219, '\p{^Is_Joining_Group=_-waw}', "");
Expect(0, 2219, '\P{Is_Joining_Group=_-waw}', "");
Expect(1, 2219, '\P{^Is_Joining_Group=_-waw}', "");
Expect(0, 2220, '\p{Is_Joining_Group=_-waw}', "");
Expect(1, 2220, '\p{^Is_Joining_Group=_-waw}', "");
Expect(1, 2220, '\P{Is_Joining_Group=_-waw}', "");
Expect(0, 2220, '\P{^Is_Joining_Group=_-waw}', "");
Error('\p{Is_Jg=_ Waw/a/}');
Error('\P{Is_Jg=_ Waw/a/}');
Expect(1, 2219, '\p{Is_Jg=waw}', "");
Expect(0, 2219, '\p{^Is_Jg=waw}', "");
Expect(0, 2219, '\P{Is_Jg=waw}', "");
Expect(1, 2219, '\P{^Is_Jg=waw}', "");
Expect(0, 2220, '\p{Is_Jg=waw}', "");
Expect(1, 2220, '\p{^Is_Jg=waw}', "");
Expect(1, 2220, '\P{Is_Jg=waw}', "");
Expect(0, 2220, '\P{^Is_Jg=waw}', "");
Expect(1, 2219, '\p{Is_Jg=	WAW}', "");
Expect(0, 2219, '\p{^Is_Jg=	WAW}', "");
Expect(0, 2219, '\P{Is_Jg=	WAW}', "");
Expect(1, 2219, '\P{^Is_Jg=	WAW}', "");
Expect(0, 2220, '\p{Is_Jg=	WAW}', "");
Expect(1, 2220, '\p{^Is_Jg=	WAW}', "");
Expect(1, 2220, '\P{Is_Jg=	WAW}', "");
Expect(0, 2220, '\P{^Is_Jg=	WAW}', "");
Error('\p{Joining_Group=_Yeh:=}');
Error('\P{Joining_Group=_Yeh:=}');
Expect(1, 2217, '\p{Joining_Group=yeh}', "");
Expect(0, 2217, '\p{^Joining_Group=yeh}', "");
Expect(0, 2217, '\P{Joining_Group=yeh}', "");
Expect(1, 2217, '\P{^Joining_Group=yeh}', "");
Expect(0, 2218, '\p{Joining_Group=yeh}', "");
Expect(1, 2218, '\p{^Joining_Group=yeh}', "");
Expect(1, 2218, '\P{Joining_Group=yeh}', "");
Expect(0, 2218, '\P{^Joining_Group=yeh}', "");
Expect(1, 2217, '\p{Joining_Group=-_yeh}', "");
Expect(0, 2217, '\p{^Joining_Group=-_yeh}', "");
Expect(0, 2217, '\P{Joining_Group=-_yeh}', "");
Expect(1, 2217, '\P{^Joining_Group=-_yeh}', "");
Expect(0, 2218, '\p{Joining_Group=-_yeh}', "");
Expect(1, 2218, '\p{^Joining_Group=-_yeh}', "");
Expect(1, 2218, '\P{Joining_Group=-_yeh}', "");
Expect(0, 2218, '\P{^Joining_Group=-_yeh}', "");
Error('\p{Jg: :=YEH}');
Error('\P{Jg: :=YEH}');
Expect(1, 2217, '\p{Jg=yeh}', "");
Expect(0, 2217, '\p{^Jg=yeh}', "");
Expect(0, 2217, '\P{Jg=yeh}', "");
Expect(1, 2217, '\P{^Jg=yeh}', "");
Expect(0, 2218, '\p{Jg=yeh}', "");
Expect(1, 2218, '\p{^Jg=yeh}', "");
Expect(1, 2218, '\P{Jg=yeh}', "");
Expect(0, 2218, '\P{^Jg=yeh}', "");
Expect(1, 2217, '\p{Jg=	-YEH}', "");
Expect(0, 2217, '\p{^Jg=	-YEH}', "");
Expect(0, 2217, '\P{Jg=	-YEH}', "");
Expect(1, 2217, '\P{^Jg=	-YEH}', "");
Expect(0, 2218, '\p{Jg=	-YEH}', "");
Expect(1, 2218, '\p{^Jg=	-YEH}', "");
Expect(1, 2218, '\P{Jg=	-YEH}', "");
Expect(0, 2218, '\P{^Jg=	-YEH}', "");
Error('\p{Is_Joining_Group=-:=Yeh}');
Error('\P{Is_Joining_Group=-:=Yeh}');
Expect(1, 2217, '\p{Is_Joining_Group=yeh}', "");
Expect(0, 2217, '\p{^Is_Joining_Group=yeh}', "");
Expect(0, 2217, '\P{Is_Joining_Group=yeh}', "");
Expect(1, 2217, '\P{^Is_Joining_Group=yeh}', "");
Expect(0, 2218, '\p{Is_Joining_Group=yeh}', "");
Expect(1, 2218, '\p{^Is_Joining_Group=yeh}', "");
Expect(1, 2218, '\P{Is_Joining_Group=yeh}', "");
Expect(0, 2218, '\P{^Is_Joining_Group=yeh}', "");
Expect(1, 2217, '\p{Is_Joining_Group= Yeh}', "");
Expect(0, 2217, '\p{^Is_Joining_Group= Yeh}', "");
Expect(0, 2217, '\P{Is_Joining_Group= Yeh}', "");
Expect(1, 2217, '\P{^Is_Joining_Group= Yeh}', "");
Expect(0, 2218, '\p{Is_Joining_Group= Yeh}', "");
Expect(1, 2218, '\p{^Is_Joining_Group= Yeh}', "");
Expect(1, 2218, '\P{Is_Joining_Group= Yeh}', "");
Expect(0, 2218, '\P{^Is_Joining_Group= Yeh}', "");
Error('\p{Is_Jg=:=Yeh}');
Error('\P{Is_Jg=:=Yeh}');
Expect(1, 2217, '\p{Is_Jg=yeh}', "");
Expect(0, 2217, '\p{^Is_Jg=yeh}', "");
Expect(0, 2217, '\P{Is_Jg=yeh}', "");
Expect(1, 2217, '\P{^Is_Jg=yeh}', "");
Expect(0, 2218, '\p{Is_Jg=yeh}', "");
Expect(1, 2218, '\p{^Is_Jg=yeh}', "");
Expect(1, 2218, '\P{Is_Jg=yeh}', "");
Expect(0, 2218, '\P{^Is_Jg=yeh}', "");
Expect(1, 2217, '\p{Is_Jg=_	yeh}', "");
Expect(0, 2217, '\p{^Is_Jg=_	yeh}', "");
Expect(0, 2217, '\P{Is_Jg=_	yeh}', "");
Expect(1, 2217, '\P{^Is_Jg=_	yeh}', "");
Expect(0, 2218, '\p{Is_Jg=_	yeh}', "");
Expect(1, 2218, '\p{^Is_Jg=_	yeh}', "");
Expect(1, 2218, '\P{Is_Jg=_	yeh}', "");
Expect(0, 2218, '\P{^Is_Jg=_	yeh}', "");
Error('\p{Joining_Group=:= -yeh_barree}');
Error('\P{Joining_Group=:= -yeh_barree}');
Expect(1, 1747, '\p{Joining_Group=yehbarree}', "");
Expect(0, 1747, '\p{^Joining_Group=yehbarree}', "");
Expect(0, 1747, '\P{Joining_Group=yehbarree}', "");
Expect(1, 1747, '\P{^Joining_Group=yehbarree}', "");
Expect(0, 1748, '\p{Joining_Group=yehbarree}', "");
Expect(1, 1748, '\p{^Joining_Group=yehbarree}', "");
Expect(1, 1748, '\P{Joining_Group=yehbarree}', "");
Expect(0, 1748, '\P{^Joining_Group=yehbarree}', "");
Expect(1, 1747, '\p{Joining_Group=	Yeh_Barree}', "");
Expect(0, 1747, '\p{^Joining_Group=	Yeh_Barree}', "");
Expect(0, 1747, '\P{Joining_Group=	Yeh_Barree}', "");
Expect(1, 1747, '\P{^Joining_Group=	Yeh_Barree}', "");
Expect(0, 1748, '\p{Joining_Group=	Yeh_Barree}', "");
Expect(1, 1748, '\p{^Joining_Group=	Yeh_Barree}', "");
Expect(1, 1748, '\P{Joining_Group=	Yeh_Barree}', "");
Expect(0, 1748, '\P{^Joining_Group=	Yeh_Barree}', "");
Error('\p{Jg=/a/  YEH_barree}');
Error('\P{Jg=/a/  YEH_barree}');
Expect(1, 1747, '\p{Jg=yehbarree}', "");
Expect(0, 1747, '\p{^Jg=yehbarree}', "");
Expect(0, 1747, '\P{Jg=yehbarree}', "");
Expect(1, 1747, '\P{^Jg=yehbarree}', "");
Expect(0, 1748, '\p{Jg=yehbarree}', "");
Expect(1, 1748, '\p{^Jg=yehbarree}', "");
Expect(1, 1748, '\P{Jg=yehbarree}', "");
Expect(0, 1748, '\P{^Jg=yehbarree}', "");
Expect(1, 1747, '\p{Jg=_YEH_Barree}', "");
Expect(0, 1747, '\p{^Jg=_YEH_Barree}', "");
Expect(0, 1747, '\P{Jg=_YEH_Barree}', "");
Expect(1, 1747, '\P{^Jg=_YEH_Barree}', "");
Expect(0, 1748, '\p{Jg=_YEH_Barree}', "");
Expect(1, 1748, '\p{^Jg=_YEH_Barree}', "");
Expect(1, 1748, '\P{Jg=_YEH_Barree}', "");
Expect(0, 1748, '\P{^Jg=_YEH_Barree}', "");
Error('\p{Is_Joining_Group=YEH_Barree/a/}');
Error('\P{Is_Joining_Group=YEH_Barree/a/}');
Expect(1, 1747, '\p{Is_Joining_Group:yehbarree}', "");
Expect(0, 1747, '\p{^Is_Joining_Group:yehbarree}', "");
Expect(0, 1747, '\P{Is_Joining_Group:yehbarree}', "");
Expect(1, 1747, '\P{^Is_Joining_Group:yehbarree}', "");
Expect(0, 1748, '\p{Is_Joining_Group:yehbarree}', "");
Expect(1, 1748, '\p{^Is_Joining_Group:yehbarree}', "");
Expect(1, 1748, '\P{Is_Joining_Group:yehbarree}', "");
Expect(0, 1748, '\P{^Is_Joining_Group:yehbarree}', "");
Expect(1, 1747, '\p{Is_Joining_Group:    _Yeh_Barree}', "");
Expect(0, 1747, '\p{^Is_Joining_Group:    _Yeh_Barree}', "");
Expect(0, 1747, '\P{Is_Joining_Group:    _Yeh_Barree}', "");
Expect(1, 1747, '\P{^Is_Joining_Group:    _Yeh_Barree}', "");
Expect(0, 1748, '\p{Is_Joining_Group:    _Yeh_Barree}', "");
Expect(1, 1748, '\p{^Is_Joining_Group:    _Yeh_Barree}', "");
Expect(1, 1748, '\P{Is_Joining_Group:    _Yeh_Barree}', "");
Expect(0, 1748, '\P{^Is_Joining_Group:    _Yeh_Barree}', "");
Error('\p{Is_Jg=/a/	 Yeh_BARREE}');
Error('\P{Is_Jg=/a/	 Yeh_BARREE}');
Expect(1, 1747, '\p{Is_Jg: yehbarree}', "");
Expect(0, 1747, '\p{^Is_Jg: yehbarree}', "");
Expect(0, 1747, '\P{Is_Jg: yehbarree}', "");
Expect(1, 1747, '\P{^Is_Jg: yehbarree}', "");
Expect(0, 1748, '\p{Is_Jg: yehbarree}', "");
Expect(1, 1748, '\p{^Is_Jg: yehbarree}', "");
Expect(1, 1748, '\P{Is_Jg: yehbarree}', "");
Expect(0, 1748, '\P{^Is_Jg: yehbarree}', "");
Expect(1, 1747, '\p{Is_Jg=	 YEH_BARREE}', "");
Expect(0, 1747, '\p{^Is_Jg=	 YEH_BARREE}', "");
Expect(0, 1747, '\P{Is_Jg=	 YEH_BARREE}', "");
Expect(1, 1747, '\P{^Is_Jg=	 YEH_BARREE}', "");
Expect(0, 1748, '\p{Is_Jg=	 YEH_BARREE}', "");
Expect(1, 1748, '\p{^Is_Jg=	 YEH_BARREE}', "");
Expect(1, 1748, '\P{Is_Jg=	 YEH_BARREE}', "");
Expect(0, 1748, '\P{^Is_Jg=	 YEH_BARREE}', "");
Error('\p{Joining_Group=_-Yeh_with_Tail:=}');
Error('\P{Joining_Group=_-Yeh_with_Tail:=}');
Expect(1, 1741, '\p{Joining_Group=yehwithtail}', "");
Expect(0, 1741, '\p{^Joining_Group=yehwithtail}', "");
Expect(0, 1741, '\P{Joining_Group=yehwithtail}', "");
Expect(1, 1741, '\P{^Joining_Group=yehwithtail}', "");
Expect(0, 1742, '\p{Joining_Group=yehwithtail}', "");
Expect(1, 1742, '\p{^Joining_Group=yehwithtail}', "");
Expect(1, 1742, '\P{Joining_Group=yehwithtail}', "");
Expect(0, 1742, '\P{^Joining_Group=yehwithtail}', "");
Expect(1, 1741, '\p{Joining_Group=-YEH_WITH_Tail}', "");
Expect(0, 1741, '\p{^Joining_Group=-YEH_WITH_Tail}', "");
Expect(0, 1741, '\P{Joining_Group=-YEH_WITH_Tail}', "");
Expect(1, 1741, '\P{^Joining_Group=-YEH_WITH_Tail}', "");
Expect(0, 1742, '\p{Joining_Group=-YEH_WITH_Tail}', "");
Expect(1, 1742, '\p{^Joining_Group=-YEH_WITH_Tail}', "");
Expect(1, 1742, '\P{Joining_Group=-YEH_WITH_Tail}', "");
Expect(0, 1742, '\P{^Joining_Group=-YEH_WITH_Tail}', "");
Error('\p{Jg:	:=	_Yeh_With_tail}');
Error('\P{Jg:	:=	_Yeh_With_tail}');
Expect(1, 1741, '\p{Jg=yehwithtail}', "");
Expect(0, 1741, '\p{^Jg=yehwithtail}', "");
Expect(0, 1741, '\P{Jg=yehwithtail}', "");
Expect(1, 1741, '\P{^Jg=yehwithtail}', "");
Expect(0, 1742, '\p{Jg=yehwithtail}', "");
Expect(1, 1742, '\p{^Jg=yehwithtail}', "");
Expect(1, 1742, '\P{Jg=yehwithtail}', "");
Expect(0, 1742, '\P{^Jg=yehwithtail}', "");
Expect(1, 1741, '\p{Jg=-Yeh_With_Tail}', "");
Expect(0, 1741, '\p{^Jg=-Yeh_With_Tail}', "");
Expect(0, 1741, '\P{Jg=-Yeh_With_Tail}', "");
Expect(1, 1741, '\P{^Jg=-Yeh_With_Tail}', "");
Expect(0, 1742, '\p{Jg=-Yeh_With_Tail}', "");
Expect(1, 1742, '\p{^Jg=-Yeh_With_Tail}', "");
Expect(1, 1742, '\P{Jg=-Yeh_With_Tail}', "");
Expect(0, 1742, '\P{^Jg=-Yeh_With_Tail}', "");
Error('\p{Is_Joining_Group=/a/_	YEH_with_Tail}');
Error('\P{Is_Joining_Group=/a/_	YEH_with_Tail}');
Expect(1, 1741, '\p{Is_Joining_Group=yehwithtail}', "");
Expect(0, 1741, '\p{^Is_Joining_Group=yehwithtail}', "");
Expect(0, 1741, '\P{Is_Joining_Group=yehwithtail}', "");
Expect(1, 1741, '\P{^Is_Joining_Group=yehwithtail}', "");
Expect(0, 1742, '\p{Is_Joining_Group=yehwithtail}', "");
Expect(1, 1742, '\p{^Is_Joining_Group=yehwithtail}', "");
Expect(1, 1742, '\P{Is_Joining_Group=yehwithtail}', "");
Expect(0, 1742, '\P{^Is_Joining_Group=yehwithtail}', "");
Expect(1, 1741, '\p{Is_Joining_Group=Yeh_With_tail}', "");
Expect(0, 1741, '\p{^Is_Joining_Group=Yeh_With_tail}', "");
Expect(0, 1741, '\P{Is_Joining_Group=Yeh_With_tail}', "");
Expect(1, 1741, '\P{^Is_Joining_Group=Yeh_With_tail}', "");
Expect(0, 1742, '\p{Is_Joining_Group=Yeh_With_tail}', "");
Expect(1, 1742, '\p{^Is_Joining_Group=Yeh_With_tail}', "");
Expect(1, 1742, '\P{Is_Joining_Group=Yeh_With_tail}', "");
Expect(0, 1742, '\P{^Is_Joining_Group=Yeh_With_tail}', "");
Error('\p{Is_Jg=:=-_yeh_WITH_TAIL}');
Error('\P{Is_Jg=:=-_yeh_WITH_TAIL}');
Expect(1, 1741, '\p{Is_Jg:   yehwithtail}', "");
Expect(0, 1741, '\p{^Is_Jg:   yehwithtail}', "");
Expect(0, 1741, '\P{Is_Jg:   yehwithtail}', "");
Expect(1, 1741, '\P{^Is_Jg:   yehwithtail}', "");
Expect(0, 1742, '\p{Is_Jg:   yehwithtail}', "");
Expect(1, 1742, '\p{^Is_Jg:   yehwithtail}', "");
Expect(1, 1742, '\P{Is_Jg:   yehwithtail}', "");
Expect(0, 1742, '\P{^Is_Jg:   yehwithtail}', "");
Expect(1, 1741, '\p{Is_Jg=_	Yeh_With_TAIL}', "");
Expect(0, 1741, '\p{^Is_Jg=_	Yeh_With_TAIL}', "");
Expect(0, 1741, '\P{Is_Jg=_	Yeh_With_TAIL}', "");
Expect(1, 1741, '\P{^Is_Jg=_	Yeh_With_TAIL}', "");
Expect(0, 1742, '\p{Is_Jg=_	Yeh_With_TAIL}', "");
Expect(1, 1742, '\p{^Is_Jg=_	Yeh_With_TAIL}', "");
Expect(1, 1742, '\P{Is_Jg=_	Yeh_With_TAIL}', "");
Expect(0, 1742, '\P{^Is_Jg=_	Yeh_With_TAIL}', "");
Error('\p{Joining_Group:   /a/_-Yudh}');
Error('\P{Joining_Group:   /a/_-Yudh}');
Expect(1, 1821, '\p{Joining_Group=yudh}', "");
Expect(0, 1821, '\p{^Joining_Group=yudh}', "");
Expect(0, 1821, '\P{Joining_Group=yudh}', "");
Expect(1, 1821, '\P{^Joining_Group=yudh}', "");
Expect(0, 1822, '\p{Joining_Group=yudh}', "");
Expect(1, 1822, '\p{^Joining_Group=yudh}', "");
Expect(1, 1822, '\P{Joining_Group=yudh}', "");
Expect(0, 1822, '\P{^Joining_Group=yudh}', "");
Expect(1, 1821, '\p{Joining_Group=-yudh}', "");
Expect(0, 1821, '\p{^Joining_Group=-yudh}', "");
Expect(0, 1821, '\P{Joining_Group=-yudh}', "");
Expect(1, 1821, '\P{^Joining_Group=-yudh}', "");
Expect(0, 1822, '\p{Joining_Group=-yudh}', "");
Expect(1, 1822, '\p{^Joining_Group=-yudh}', "");
Expect(1, 1822, '\P{Joining_Group=-yudh}', "");
Expect(0, 1822, '\P{^Joining_Group=-yudh}', "");
Error('\p{Jg: :=yudh}');
Error('\P{Jg: :=yudh}');
Expect(1, 1821, '\p{Jg=yudh}', "");
Expect(0, 1821, '\p{^Jg=yudh}', "");
Expect(0, 1821, '\P{Jg=yudh}', "");
Expect(1, 1821, '\P{^Jg=yudh}', "");
Expect(0, 1822, '\p{Jg=yudh}', "");
Expect(1, 1822, '\p{^Jg=yudh}', "");
Expect(1, 1822, '\P{Jg=yudh}', "");
Expect(0, 1822, '\P{^Jg=yudh}', "");
Expect(1, 1821, '\p{Jg=-	Yudh}', "");
Expect(0, 1821, '\p{^Jg=-	Yudh}', "");
Expect(0, 1821, '\P{Jg=-	Yudh}', "");
Expect(1, 1821, '\P{^Jg=-	Yudh}', "");
Expect(0, 1822, '\p{Jg=-	Yudh}', "");
Expect(1, 1822, '\p{^Jg=-	Yudh}', "");
Expect(1, 1822, '\P{Jg=-	Yudh}', "");
Expect(0, 1822, '\P{^Jg=-	Yudh}', "");
Error('\p{Is_Joining_Group:   /a/ 	Yudh}');
Error('\P{Is_Joining_Group:   /a/ 	Yudh}');
Expect(1, 1821, '\p{Is_Joining_Group=yudh}', "");
Expect(0, 1821, '\p{^Is_Joining_Group=yudh}', "");
Expect(0, 1821, '\P{Is_Joining_Group=yudh}', "");
Expect(1, 1821, '\P{^Is_Joining_Group=yudh}', "");
Expect(0, 1822, '\p{Is_Joining_Group=yudh}', "");
Expect(1, 1822, '\p{^Is_Joining_Group=yudh}', "");
Expect(1, 1822, '\P{Is_Joining_Group=yudh}', "");
Expect(0, 1822, '\P{^Is_Joining_Group=yudh}', "");
Expect(1, 1821, '\p{Is_Joining_Group=	YUDH}', "");
Expect(0, 1821, '\p{^Is_Joining_Group=	YUDH}', "");
Expect(0, 1821, '\P{Is_Joining_Group=	YUDH}', "");
Expect(1, 1821, '\P{^Is_Joining_Group=	YUDH}', "");
Expect(0, 1822, '\p{Is_Joining_Group=	YUDH}', "");
Expect(1, 1822, '\p{^Is_Joining_Group=	YUDH}', "");
Expect(1, 1822, '\P{Is_Joining_Group=	YUDH}', "");
Expect(0, 1822, '\P{^Is_Joining_Group=	YUDH}', "");
Error('\p{Is_Jg=/a/-YUDH}');
Error('\P{Is_Jg=/a/-YUDH}');
Expect(1, 1821, '\p{Is_Jg=yudh}', "");
Expect(0, 1821, '\p{^Is_Jg=yudh}', "");
Expect(0, 1821, '\P{Is_Jg=yudh}', "");
Expect(1, 1821, '\P{^Is_Jg=yudh}', "");
Expect(0, 1822, '\p{Is_Jg=yudh}', "");
Expect(1, 1822, '\p{^Is_Jg=yudh}', "");
Expect(1, 1822, '\P{Is_Jg=yudh}', "");
Expect(0, 1822, '\P{^Is_Jg=yudh}', "");
Expect(1, 1821, '\p{Is_Jg= YUDH}', "");
Expect(0, 1821, '\p{^Is_Jg= YUDH}', "");
Expect(0, 1821, '\P{Is_Jg= YUDH}', "");
Expect(1, 1821, '\P{^Is_Jg= YUDH}', "");
Expect(0, 1822, '\p{Is_Jg= YUDH}', "");
Expect(1, 1822, '\p{^Is_Jg= YUDH}', "");
Expect(1, 1822, '\P{Is_Jg= YUDH}', "");
Expect(0, 1822, '\P{^Is_Jg= YUDH}', "");
Error('\p{Joining_Group=Yudh_HE:=}');
Error('\P{Joining_Group=Yudh_HE:=}');
Expect(1, 1822, '\p{Joining_Group=yudhhe}', "");
Expect(0, 1822, '\p{^Joining_Group=yudhhe}', "");
Expect(0, 1822, '\P{Joining_Group=yudhhe}', "");
Expect(1, 1822, '\P{^Joining_Group=yudhhe}', "");
Expect(0, 1823, '\p{Joining_Group=yudhhe}', "");
Expect(1, 1823, '\p{^Joining_Group=yudhhe}', "");
Expect(1, 1823, '\P{Joining_Group=yudhhe}', "");
Expect(0, 1823, '\P{^Joining_Group=yudhhe}', "");
Expect(1, 1822, '\p{Joining_Group=	_YUDH_he}', "");
Expect(0, 1822, '\p{^Joining_Group=	_YUDH_he}', "");
Expect(0, 1822, '\P{Joining_Group=	_YUDH_he}', "");
Expect(1, 1822, '\P{^Joining_Group=	_YUDH_he}', "");
Expect(0, 1823, '\p{Joining_Group=	_YUDH_he}', "");
Expect(1, 1823, '\p{^Joining_Group=	_YUDH_he}', "");
Expect(1, 1823, '\P{Joining_Group=	_YUDH_he}', "");
Expect(0, 1823, '\P{^Joining_Group=	_YUDH_he}', "");
Error('\p{Jg= /a/YUDH_HE}');
Error('\P{Jg= /a/YUDH_HE}');
Expect(1, 1822, '\p{Jg=yudhhe}', "");
Expect(0, 1822, '\p{^Jg=yudhhe}', "");
Expect(0, 1822, '\P{Jg=yudhhe}', "");
Expect(1, 1822, '\P{^Jg=yudhhe}', "");
Expect(0, 1823, '\p{Jg=yudhhe}', "");
Expect(1, 1823, '\p{^Jg=yudhhe}', "");
Expect(1, 1823, '\P{Jg=yudhhe}', "");
Expect(0, 1823, '\P{^Jg=yudhhe}', "");
Expect(1, 1822, '\p{Jg=-Yudh_HE}', "");
Expect(0, 1822, '\p{^Jg=-Yudh_HE}', "");
Expect(0, 1822, '\P{Jg=-Yudh_HE}', "");
Expect(1, 1822, '\P{^Jg=-Yudh_HE}', "");
Expect(0, 1823, '\p{Jg=-Yudh_HE}', "");
Expect(1, 1823, '\p{^Jg=-Yudh_HE}', "");
Expect(1, 1823, '\P{Jg=-Yudh_HE}', "");
Expect(0, 1823, '\P{^Jg=-Yudh_HE}', "");
Error('\p{Is_Joining_Group= 	yudh_He:=}');
Error('\P{Is_Joining_Group= 	yudh_He:=}');
Expect(1, 1822, '\p{Is_Joining_Group: yudhhe}', "");
Expect(0, 1822, '\p{^Is_Joining_Group: yudhhe}', "");
Expect(0, 1822, '\P{Is_Joining_Group: yudhhe}', "");
Expect(1, 1822, '\P{^Is_Joining_Group: yudhhe}', "");
Expect(0, 1823, '\p{Is_Joining_Group: yudhhe}', "");
Expect(1, 1823, '\p{^Is_Joining_Group: yudhhe}', "");
Expect(1, 1823, '\P{Is_Joining_Group: yudhhe}', "");
Expect(0, 1823, '\P{^Is_Joining_Group: yudhhe}', "");
Expect(1, 1822, '\p{Is_Joining_Group=	 YUDH_He}', "");
Expect(0, 1822, '\p{^Is_Joining_Group=	 YUDH_He}', "");
Expect(0, 1822, '\P{Is_Joining_Group=	 YUDH_He}', "");
Expect(1, 1822, '\P{^Is_Joining_Group=	 YUDH_He}', "");
Expect(0, 1823, '\p{Is_Joining_Group=	 YUDH_He}', "");
Expect(1, 1823, '\p{^Is_Joining_Group=	 YUDH_He}', "");
Expect(1, 1823, '\P{Is_Joining_Group=	 YUDH_He}', "");
Expect(0, 1823, '\P{^Is_Joining_Group=	 YUDH_He}', "");
Error('\p{Is_Jg:   /a/-Yudh_he}');
Error('\P{Is_Jg:   /a/-Yudh_he}');
Expect(1, 1822, '\p{Is_Jg=yudhhe}', "");
Expect(0, 1822, '\p{^Is_Jg=yudhhe}', "");
Expect(0, 1822, '\P{Is_Jg=yudhhe}', "");
Expect(1, 1822, '\P{^Is_Jg=yudhhe}', "");
Expect(0, 1823, '\p{Is_Jg=yudhhe}', "");
Expect(1, 1823, '\p{^Is_Jg=yudhhe}', "");
Expect(1, 1823, '\P{Is_Jg=yudhhe}', "");
Expect(0, 1823, '\P{^Is_Jg=yudhhe}', "");
Expect(1, 1822, '\p{Is_Jg=-	YUDH_HE}', "");
Expect(0, 1822, '\p{^Is_Jg=-	YUDH_HE}', "");
Expect(0, 1822, '\P{Is_Jg=-	YUDH_HE}', "");
Expect(1, 1822, '\P{^Is_Jg=-	YUDH_HE}', "");
Expect(0, 1823, '\p{Is_Jg=-	YUDH_HE}', "");
Expect(1, 1823, '\p{^Is_Jg=-	YUDH_HE}', "");
Expect(1, 1823, '\P{Is_Jg=-	YUDH_HE}', "");
Expect(0, 1823, '\P{^Is_Jg=-	YUDH_HE}', "");
Error('\p{Joining_Group=-	zain:=}');
Error('\P{Joining_Group=-	zain:=}');
Expect(1, 1817, '\p{Joining_Group=zain}', "");
Expect(0, 1817, '\p{^Joining_Group=zain}', "");
Expect(0, 1817, '\P{Joining_Group=zain}', "");
Expect(1, 1817, '\P{^Joining_Group=zain}', "");
Expect(0, 1818, '\p{Joining_Group=zain}', "");
Expect(1, 1818, '\p{^Joining_Group=zain}', "");
Expect(1, 1818, '\P{Joining_Group=zain}', "");
Expect(0, 1818, '\P{^Joining_Group=zain}', "");
Expect(1, 1817, '\p{Joining_Group=- Zain}', "");
Expect(0, 1817, '\p{^Joining_Group=- Zain}', "");
Expect(0, 1817, '\P{Joining_Group=- Zain}', "");
Expect(1, 1817, '\P{^Joining_Group=- Zain}', "");
Expect(0, 1818, '\p{Joining_Group=- Zain}', "");
Expect(1, 1818, '\p{^Joining_Group=- Zain}', "");
Expect(1, 1818, '\P{Joining_Group=- Zain}', "");
Expect(0, 1818, '\P{^Joining_Group=- Zain}', "");
Error('\p{Jg= _zain/a/}');
Error('\P{Jg= _zain/a/}');
Expect(1, 1817, '\p{Jg=zain}', "");
Expect(0, 1817, '\p{^Jg=zain}', "");
Expect(0, 1817, '\P{Jg=zain}', "");
Expect(1, 1817, '\P{^Jg=zain}', "");
Expect(0, 1818, '\p{Jg=zain}', "");
Expect(1, 1818, '\p{^Jg=zain}', "");
Expect(1, 1818, '\P{Jg=zain}', "");
Expect(0, 1818, '\P{^Jg=zain}', "");
Expect(1, 1817, '\p{Jg=_-ZAIN}', "");
Expect(0, 1817, '\p{^Jg=_-ZAIN}', "");
Expect(0, 1817, '\P{Jg=_-ZAIN}', "");
Expect(1, 1817, '\P{^Jg=_-ZAIN}', "");
Expect(0, 1818, '\p{Jg=_-ZAIN}', "");
Expect(1, 1818, '\p{^Jg=_-ZAIN}', "");
Expect(1, 1818, '\P{Jg=_-ZAIN}', "");
Expect(0, 1818, '\P{^Jg=_-ZAIN}', "");
Error('\p{Is_Joining_Group:/a/_Zain}');
Error('\P{Is_Joining_Group:/a/_Zain}');
Expect(1, 1817, '\p{Is_Joining_Group:zain}', "");
Expect(0, 1817, '\p{^Is_Joining_Group:zain}', "");
Expect(0, 1817, '\P{Is_Joining_Group:zain}', "");
Expect(1, 1817, '\P{^Is_Joining_Group:zain}', "");
Expect(0, 1818, '\p{Is_Joining_Group:zain}', "");
Expect(1, 1818, '\p{^Is_Joining_Group:zain}', "");
Expect(1, 1818, '\P{Is_Joining_Group:zain}', "");
Expect(0, 1818, '\P{^Is_Joining_Group:zain}', "");
Expect(1, 1817, '\p{Is_Joining_Group=_Zain}', "");
Expect(0, 1817, '\p{^Is_Joining_Group=_Zain}', "");
Expect(0, 1817, '\P{Is_Joining_Group=_Zain}', "");
Expect(1, 1817, '\P{^Is_Joining_Group=_Zain}', "");
Expect(0, 1818, '\p{Is_Joining_Group=_Zain}', "");
Expect(1, 1818, '\p{^Is_Joining_Group=_Zain}', "");
Expect(1, 1818, '\P{Is_Joining_Group=_Zain}', "");
Expect(0, 1818, '\P{^Is_Joining_Group=_Zain}', "");
Error('\p{Is_Jg=_/a/Zain}');
Error('\P{Is_Jg=_/a/Zain}');
Expect(1, 1817, '\p{Is_Jg=zain}', "");
Expect(0, 1817, '\p{^Is_Jg=zain}', "");
Expect(0, 1817, '\P{Is_Jg=zain}', "");
Expect(1, 1817, '\P{^Is_Jg=zain}', "");
Expect(0, 1818, '\p{Is_Jg=zain}', "");
Expect(1, 1818, '\p{^Is_Jg=zain}', "");
Expect(1, 1818, '\P{Is_Jg=zain}', "");
Expect(0, 1818, '\P{^Is_Jg=zain}', "");
Expect(1, 1817, '\p{Is_Jg=_ Zain}', "");
Expect(0, 1817, '\p{^Is_Jg=_ Zain}', "");
Expect(0, 1817, '\P{Is_Jg=_ Zain}', "");
Expect(1, 1817, '\P{^Is_Jg=_ Zain}', "");
Expect(0, 1818, '\p{Is_Jg=_ Zain}', "");
Expect(1, 1818, '\p{^Is_Jg=_ Zain}', "");
Expect(1, 1818, '\P{Is_Jg=_ Zain}', "");
Expect(0, 1818, '\P{^Is_Jg=_ Zain}', "");
Error('\p{Joining_Group= 	Zhain:=}');
Error('\P{Joining_Group= 	Zhain:=}');
Expect(1, 1869, '\p{Joining_Group=zhain}', "");
Expect(0, 1869, '\p{^Joining_Group=zhain}', "");
Expect(0, 1869, '\P{Joining_Group=zhain}', "");
Expect(1, 1869, '\P{^Joining_Group=zhain}', "");
Expect(0, 1870, '\p{Joining_Group=zhain}', "");
Expect(1, 1870, '\p{^Joining_Group=zhain}', "");
Expect(1, 1870, '\P{Joining_Group=zhain}', "");
Expect(0, 1870, '\P{^Joining_Group=zhain}', "");
Expect(1, 1869, '\p{Joining_Group=	Zhain}', "");
Expect(0, 1869, '\p{^Joining_Group=	Zhain}', "");
Expect(0, 1869, '\P{Joining_Group=	Zhain}', "");
Expect(1, 1869, '\P{^Joining_Group=	Zhain}', "");
Expect(0, 1870, '\p{Joining_Group=	Zhain}', "");
Expect(1, 1870, '\p{^Joining_Group=	Zhain}', "");
Expect(1, 1870, '\P{Joining_Group=	Zhain}', "");
Expect(0, 1870, '\P{^Joining_Group=	Zhain}', "");
Error('\p{Jg=--zhain:=}');
Error('\P{Jg=--zhain:=}');
Expect(1, 1869, '\p{Jg=zhain}', "");
Expect(0, 1869, '\p{^Jg=zhain}', "");
Expect(0, 1869, '\P{Jg=zhain}', "");
Expect(1, 1869, '\P{^Jg=zhain}', "");
Expect(0, 1870, '\p{Jg=zhain}', "");
Expect(1, 1870, '\p{^Jg=zhain}', "");
Expect(1, 1870, '\P{Jg=zhain}', "");
Expect(0, 1870, '\P{^Jg=zhain}', "");
Expect(1, 1869, '\p{Jg=_Zhain}', "");
Expect(0, 1869, '\p{^Jg=_Zhain}', "");
Expect(0, 1869, '\P{Jg=_Zhain}', "");
Expect(1, 1869, '\P{^Jg=_Zhain}', "");
Expect(0, 1870, '\p{Jg=_Zhain}', "");
Expect(1, 1870, '\p{^Jg=_Zhain}', "");
Expect(1, 1870, '\P{Jg=_Zhain}', "");
Expect(0, 1870, '\P{^Jg=_Zhain}', "");
Error('\p{Is_Joining_Group=_-ZHAIN/a/}');
Error('\P{Is_Joining_Group=_-ZHAIN/a/}');
Expect(1, 1869, '\p{Is_Joining_Group=zhain}', "");
Expect(0, 1869, '\p{^Is_Joining_Group=zhain}', "");
Expect(0, 1869, '\P{Is_Joining_Group=zhain}', "");
Expect(1, 1869, '\P{^Is_Joining_Group=zhain}', "");
Expect(0, 1870, '\p{Is_Joining_Group=zhain}', "");
Expect(1, 1870, '\p{^Is_Joining_Group=zhain}', "");
Expect(1, 1870, '\P{Is_Joining_Group=zhain}', "");
Expect(0, 1870, '\P{^Is_Joining_Group=zhain}', "");
Expect(1, 1869, '\p{Is_Joining_Group=-zhain}', "");
Expect(0, 1869, '\p{^Is_Joining_Group=-zhain}', "");
Expect(0, 1869, '\P{Is_Joining_Group=-zhain}', "");
Expect(1, 1869, '\P{^Is_Joining_Group=-zhain}', "");
Expect(0, 1870, '\p{Is_Joining_Group=-zhain}', "");
Expect(1, 1870, '\p{^Is_Joining_Group=-zhain}', "");
Expect(1, 1870, '\P{Is_Joining_Group=-zhain}', "");
Expect(0, 1870, '\P{^Is_Joining_Group=-zhain}', "");
Error('\p{Is_Jg=_Zhain:=}');
Error('\P{Is_Jg=_Zhain:=}');
Expect(1, 1869, '\p{Is_Jg=zhain}', "");
Expect(0, 1869, '\p{^Is_Jg=zhain}', "");
Expect(0, 1869, '\P{Is_Jg=zhain}', "");
Expect(1, 1869, '\P{^Is_Jg=zhain}', "");
Expect(0, 1870, '\p{Is_Jg=zhain}', "");
Expect(1, 1870, '\p{^Is_Jg=zhain}', "");
Expect(1, 1870, '\P{Is_Jg=zhain}', "");
Expect(0, 1870, '\P{^Is_Jg=zhain}', "");
Expect(1, 1869, '\p{Is_Jg=_	ZHAIN}', "");
Expect(0, 1869, '\p{^Is_Jg=_	ZHAIN}', "");
Expect(0, 1869, '\P{Is_Jg=_	ZHAIN}', "");
Expect(1, 1869, '\P{^Is_Jg=_	ZHAIN}', "");
Expect(0, 1870, '\p{Is_Jg=_	ZHAIN}', "");
Expect(1, 1870, '\p{^Is_Jg=_	ZHAIN}', "");
Expect(1, 1870, '\P{Is_Jg=_	ZHAIN}', "");
Expect(0, 1870, '\P{^Is_Jg=_	ZHAIN}', "");
Error('\p{Joining_Type=:=		Join_Causing}');
Error('\P{Joining_Type=:=		Join_Causing}');
Expect(1, 8205, '\p{Joining_Type=joincausing}', "");
Expect(0, 8205, '\p{^Joining_Type=joincausing}', "");
Expect(0, 8205, '\P{Joining_Type=joincausing}', "");
Expect(1, 8205, '\P{^Joining_Type=joincausing}', "");
Expect(0, 8206, '\p{Joining_Type=joincausing}', "");
Expect(1, 8206, '\p{^Joining_Type=joincausing}', "");
Expect(1, 8206, '\P{Joining_Type=joincausing}', "");
Expect(0, 8206, '\P{^Joining_Type=joincausing}', "");
Expect(1, 8205, '\p{Joining_Type= 	join_Causing}', "");
Expect(0, 8205, '\p{^Joining_Type= 	join_Causing}', "");
Expect(0, 8205, '\P{Joining_Type= 	join_Causing}', "");
Expect(1, 8205, '\P{^Joining_Type= 	join_Causing}', "");
Expect(0, 8206, '\p{Joining_Type= 	join_Causing}', "");
Expect(1, 8206, '\p{^Joining_Type= 	join_Causing}', "");
Expect(1, 8206, '\P{Joining_Type= 	join_Causing}', "");
Expect(0, 8206, '\P{^Joining_Type= 	join_Causing}', "");
Error('\p{Jt=/a/_ C}');
Error('\P{Jt=/a/_ C}');
Expect(1, 8205, '\p{Jt=c}', "");
Expect(0, 8205, '\p{^Jt=c}', "");
Expect(0, 8205, '\P{Jt=c}', "");
Expect(1, 8205, '\P{^Jt=c}', "");
Expect(0, 8206, '\p{Jt=c}', "");
Expect(1, 8206, '\p{^Jt=c}', "");
Expect(1, 8206, '\P{Jt=c}', "");
Expect(0, 8206, '\P{^Jt=c}', "");
Error('\p{Is_Joining_Type=:=- Join_Causing}');
Error('\P{Is_Joining_Type=:=- Join_Causing}');
Expect(1, 8205, '\p{Is_Joining_Type=joincausing}', "");
Expect(0, 8205, '\p{^Is_Joining_Type=joincausing}', "");
Expect(0, 8205, '\P{Is_Joining_Type=joincausing}', "");
Expect(1, 8205, '\P{^Is_Joining_Type=joincausing}', "");
Expect(0, 8206, '\p{Is_Joining_Type=joincausing}', "");
Expect(1, 8206, '\p{^Is_Joining_Type=joincausing}', "");
Expect(1, 8206, '\P{Is_Joining_Type=joincausing}', "");
Expect(0, 8206, '\P{^Is_Joining_Type=joincausing}', "");
Expect(1, 8205, '\p{Is_Joining_Type=  JOIN_CAUSING}', "");
Expect(0, 8205, '\p{^Is_Joining_Type=  JOIN_CAUSING}', "");
Expect(0, 8205, '\P{Is_Joining_Type=  JOIN_CAUSING}', "");
Expect(1, 8205, '\P{^Is_Joining_Type=  JOIN_CAUSING}', "");
Expect(0, 8206, '\p{Is_Joining_Type=  JOIN_CAUSING}', "");
Expect(1, 8206, '\p{^Is_Joining_Type=  JOIN_CAUSING}', "");
Expect(1, 8206, '\P{Is_Joining_Type=  JOIN_CAUSING}', "");
Expect(0, 8206, '\P{^Is_Joining_Type=  JOIN_CAUSING}', "");
Error('\p{Is_Jt=	/a/C}');
Error('\P{Is_Jt=	/a/C}');
Expect(1, 8205, '\p{Is_Jt=c}', "");
Expect(0, 8205, '\p{^Is_Jt=c}', "");
Expect(0, 8205, '\P{Is_Jt=c}', "");
Expect(1, 8205, '\P{^Is_Jt=c}', "");
Expect(0, 8206, '\p{Is_Jt=c}', "");
Expect(1, 8206, '\p{^Is_Jt=c}', "");
Expect(1, 8206, '\P{Is_Jt=c}', "");
Expect(0, 8206, '\P{^Is_Jt=c}', "");
Expect(1, 8205, '\p{Is_Jt=_C}', "");
Expect(0, 8205, '\p{^Is_Jt=_C}', "");
Expect(0, 8205, '\P{Is_Jt=_C}', "");
Expect(1, 8205, '\P{^Is_Jt=_C}', "");
Expect(0, 8206, '\p{Is_Jt=_C}', "");
Expect(1, 8206, '\p{^Is_Jt=_C}', "");
Expect(1, 8206, '\P{Is_Jt=_C}', "");
Expect(0, 8206, '\P{^Is_Jt=_C}', "");
Error('\p{Joining_Type=_:=dual_Joining}');
Error('\P{Joining_Type=_:=dual_Joining}');
Expect(1, 43121, '\p{Joining_Type=dualjoining}', "");
Expect(0, 43121, '\p{^Joining_Type=dualjoining}', "");
Expect(0, 43121, '\P{Joining_Type=dualjoining}', "");
Expect(1, 43121, '\P{^Joining_Type=dualjoining}', "");
Expect(0, 43122, '\p{Joining_Type=dualjoining}', "");
Expect(1, 43122, '\p{^Joining_Type=dualjoining}', "");
Expect(1, 43122, '\P{Joining_Type=dualjoining}', "");
Expect(0, 43122, '\P{^Joining_Type=dualjoining}', "");
Expect(1, 43121, '\p{Joining_Type=	-Dual_JOINING}', "");
Expect(0, 43121, '\p{^Joining_Type=	-Dual_JOINING}', "");
Expect(0, 43121, '\P{Joining_Type=	-Dual_JOINING}', "");
Expect(1, 43121, '\P{^Joining_Type=	-Dual_JOINING}', "");
Expect(0, 43122, '\p{Joining_Type=	-Dual_JOINING}', "");
Expect(1, 43122, '\p{^Joining_Type=	-Dual_JOINING}', "");
Expect(1, 43122, '\P{Joining_Type=	-Dual_JOINING}', "");
Expect(0, 43122, '\P{^Joining_Type=	-Dual_JOINING}', "");
Error('\p{Jt=/a/D}');
Error('\P{Jt=/a/D}');
Expect(1, 43121, '\p{Jt=d}', "");
Expect(0, 43121, '\p{^Jt=d}', "");
Expect(0, 43121, '\P{Jt=d}', "");
Expect(1, 43121, '\P{^Jt=d}', "");
Expect(0, 43122, '\p{Jt=d}', "");
Expect(1, 43122, '\p{^Jt=d}', "");
Expect(1, 43122, '\P{Jt=d}', "");
Expect(0, 43122, '\P{^Jt=d}', "");
Expect(1, 43121, '\p{Jt=_D}', "");
Expect(0, 43121, '\p{^Jt=_D}', "");
Expect(0, 43121, '\P{Jt=_D}', "");
Expect(1, 43121, '\P{^Jt=_D}', "");
Expect(0, 43122, '\p{Jt=_D}', "");
Expect(1, 43122, '\p{^Jt=_D}', "");
Expect(1, 43122, '\P{Jt=_D}', "");
Expect(0, 43122, '\P{^Jt=_D}', "");
Error('\p{Is_Joining_Type=:=-DUAL_Joining}');
Error('\P{Is_Joining_Type=:=-DUAL_Joining}');
Expect(1, 43121, '\p{Is_Joining_Type=dualjoining}', "");
Expect(0, 43121, '\p{^Is_Joining_Type=dualjoining}', "");
Expect(0, 43121, '\P{Is_Joining_Type=dualjoining}', "");
Expect(1, 43121, '\P{^Is_Joining_Type=dualjoining}', "");
Expect(0, 43122, '\p{Is_Joining_Type=dualjoining}', "");
Expect(1, 43122, '\p{^Is_Joining_Type=dualjoining}', "");
Expect(1, 43122, '\P{Is_Joining_Type=dualjoining}', "");
Expect(0, 43122, '\P{^Is_Joining_Type=dualjoining}', "");
Expect(1, 43121, '\p{Is_Joining_Type=	_dual_Joining}', "");
Expect(0, 43121, '\p{^Is_Joining_Type=	_dual_Joining}', "");
Expect(0, 43121, '\P{Is_Joining_Type=	_dual_Joining}', "");
Expect(1, 43121, '\P{^Is_Joining_Type=	_dual_Joining}', "");
Expect(0, 43122, '\p{Is_Joining_Type=	_dual_Joining}', "");
Expect(1, 43122, '\p{^Is_Joining_Type=	_dual_Joining}', "");
Expect(1, 43122, '\P{Is_Joining_Type=	_dual_Joining}', "");
Expect(0, 43122, '\P{^Is_Joining_Type=	_dual_Joining}', "");
Error('\p{Is_Jt=-_D:=}');
Error('\P{Is_Jt=-_D:=}');
Expect(1, 43121, '\p{Is_Jt:d}', "");
Expect(0, 43121, '\p{^Is_Jt:d}', "");
Expect(0, 43121, '\P{Is_Jt:d}', "");
Expect(1, 43121, '\P{^Is_Jt:d}', "");
Expect(0, 43122, '\p{Is_Jt:d}', "");
Expect(1, 43122, '\p{^Is_Jt:d}', "");
Expect(1, 43122, '\P{Is_Jt:d}', "");
Expect(0, 43122, '\P{^Is_Jt:d}', "");
Expect(1, 43121, '\p{Is_Jt=  D}', "");
Expect(0, 43121, '\p{^Is_Jt=  D}', "");
Expect(0, 43121, '\P{Is_Jt=  D}', "");
Expect(1, 43121, '\P{^Is_Jt=  D}', "");
Expect(0, 43122, '\p{Is_Jt=  D}', "");
Expect(1, 43122, '\p{^Is_Jt=  D}', "");
Expect(1, 43122, '\P{Is_Jt=  D}', "");
Expect(0, 43122, '\P{^Is_Jt=  D}', "");
Error('\p{Joining_Type=		Left_joining:=}');
Error('\P{Joining_Type=		Left_joining:=}');
Expect(1, 43122, '\p{Joining_Type=leftjoining}', "");
Expect(0, 43122, '\p{^Joining_Type=leftjoining}', "");
Expect(0, 43122, '\P{Joining_Type=leftjoining}', "");
Expect(1, 43122, '\P{^Joining_Type=leftjoining}', "");
Expect(0, 43123, '\p{Joining_Type=leftjoining}', "");
Expect(1, 43123, '\p{^Joining_Type=leftjoining}', "");
Expect(1, 43123, '\P{Joining_Type=leftjoining}', "");
Expect(0, 43123, '\P{^Joining_Type=leftjoining}', "");
Expect(1, 43122, '\p{Joining_Type= -LEFT_joining}', "");
Expect(0, 43122, '\p{^Joining_Type= -LEFT_joining}', "");
Expect(0, 43122, '\P{Joining_Type= -LEFT_joining}', "");
Expect(1, 43122, '\P{^Joining_Type= -LEFT_joining}', "");
Expect(0, 43123, '\p{Joining_Type= -LEFT_joining}', "");
Expect(1, 43123, '\p{^Joining_Type= -LEFT_joining}', "");
Expect(1, 43123, '\P{Joining_Type= -LEFT_joining}', "");
Expect(0, 43123, '\P{^Joining_Type= -LEFT_joining}', "");
Error('\p{Jt=:=L}');
Error('\P{Jt=:=L}');
Expect(1, 43122, '\p{Jt=l}', "");
Expect(0, 43122, '\p{^Jt=l}', "");
Expect(0, 43122, '\P{Jt=l}', "");
Expect(1, 43122, '\P{^Jt=l}', "");
Expect(0, 43123, '\p{Jt=l}', "");
Expect(1, 43123, '\p{^Jt=l}', "");
Expect(1, 43123, '\P{Jt=l}', "");
Expect(0, 43123, '\P{^Jt=l}', "");
Expect(1, 43122, '\p{Jt=		L}', "");
Expect(0, 43122, '\p{^Jt=		L}', "");
Expect(0, 43122, '\P{Jt=		L}', "");
Expect(1, 43122, '\P{^Jt=		L}', "");
Expect(0, 43123, '\p{Jt=		L}', "");
Expect(1, 43123, '\p{^Jt=		L}', "");
Expect(1, 43123, '\P{Jt=		L}', "");
Expect(0, 43123, '\P{^Jt=		L}', "");
Error('\p{Is_Joining_Type= -Left_Joining/a/}');
Error('\P{Is_Joining_Type= -Left_Joining/a/}');
Expect(1, 43122, '\p{Is_Joining_Type=leftjoining}', "");
Expect(0, 43122, '\p{^Is_Joining_Type=leftjoining}', "");
Expect(0, 43122, '\P{Is_Joining_Type=leftjoining}', "");
Expect(1, 43122, '\P{^Is_Joining_Type=leftjoining}', "");
Expect(0, 43123, '\p{Is_Joining_Type=leftjoining}', "");
Expect(1, 43123, '\p{^Is_Joining_Type=leftjoining}', "");
Expect(1, 43123, '\P{Is_Joining_Type=leftjoining}', "");
Expect(0, 43123, '\P{^Is_Joining_Type=leftjoining}', "");
Expect(1, 43122, '\p{Is_Joining_Type=  Left_joining}', "");
Expect(0, 43122, '\p{^Is_Joining_Type=  Left_joining}', "");
Expect(0, 43122, '\P{Is_Joining_Type=  Left_joining}', "");
Expect(1, 43122, '\P{^Is_Joining_Type=  Left_joining}', "");
Expect(0, 43123, '\p{Is_Joining_Type=  Left_joining}', "");
Expect(1, 43123, '\p{^Is_Joining_Type=  Left_joining}', "");
Expect(1, 43123, '\P{Is_Joining_Type=  Left_joining}', "");
Expect(0, 43123, '\P{^Is_Joining_Type=  Left_joining}', "");
Error('\p{Is_Jt=/a/ -L}');
Error('\P{Is_Jt=/a/ -L}');
Expect(1, 43122, '\p{Is_Jt=l}', "");
Expect(0, 43122, '\p{^Is_Jt=l}', "");
Expect(0, 43122, '\P{Is_Jt=l}', "");
Expect(1, 43122, '\P{^Is_Jt=l}', "");
Expect(0, 43123, '\p{Is_Jt=l}', "");
Expect(1, 43123, '\p{^Is_Jt=l}', "");
Expect(1, 43123, '\P{Is_Jt=l}', "");
Expect(0, 43123, '\P{^Is_Jt=l}', "");
Expect(1, 43122, '\p{Is_Jt= -l}', "");
Expect(0, 43122, '\p{^Is_Jt= -l}', "");
Expect(0, 43122, '\P{Is_Jt= -l}', "");
Expect(1, 43122, '\P{^Is_Jt= -l}', "");
Expect(0, 43123, '\p{Is_Jt= -l}', "");
Expect(1, 43123, '\p{^Is_Jt= -l}', "");
Expect(1, 43123, '\P{Is_Jt= -l}', "");
Expect(0, 43123, '\P{^Is_Jt= -l}', "");
Error('\p{Joining_Type=	_Right_Joining/a/}');
Error('\P{Joining_Type=	_Right_Joining/a/}');
Expect(1, 2220, '\p{Joining_Type:rightjoining}', "");
Expect(0, 2220, '\p{^Joining_Type:rightjoining}', "");
Expect(0, 2220, '\P{Joining_Type:rightjoining}', "");
Expect(1, 2220, '\P{^Joining_Type:rightjoining}', "");
Expect(0, 2221, '\p{Joining_Type:rightjoining}', "");
Expect(1, 2221, '\p{^Joining_Type:rightjoining}', "");
Expect(1, 2221, '\P{Joining_Type:rightjoining}', "");
Expect(0, 2221, '\P{^Joining_Type:rightjoining}', "");
Expect(1, 2220, '\p{Joining_Type=_-Right_Joining}', "");
Expect(0, 2220, '\p{^Joining_Type=_-Right_Joining}', "");
Expect(0, 2220, '\P{Joining_Type=_-Right_Joining}', "");
Expect(1, 2220, '\P{^Joining_Type=_-Right_Joining}', "");
Expect(0, 2221, '\p{Joining_Type=_-Right_Joining}', "");
Expect(1, 2221, '\p{^Joining_Type=_-Right_Joining}', "");
Expect(1, 2221, '\P{Joining_Type=_-Right_Joining}', "");
Expect(0, 2221, '\P{^Joining_Type=_-Right_Joining}', "");
Error('\p{Jt=:=	 R}');
Error('\P{Jt=:=	 R}');
Expect(1, 2220, '\p{Jt=r}', "");
Expect(0, 2220, '\p{^Jt=r}', "");
Expect(0, 2220, '\P{Jt=r}', "");
Expect(1, 2220, '\P{^Jt=r}', "");
Expect(0, 2221, '\p{Jt=r}', "");
Expect(1, 2221, '\p{^Jt=r}', "");
Expect(1, 2221, '\P{Jt=r}', "");
Expect(0, 2221, '\P{^Jt=r}', "");
Expect(1, 2220, '\p{Jt=	 R}', "");
Expect(0, 2220, '\p{^Jt=	 R}', "");
Expect(0, 2220, '\P{Jt=	 R}', "");
Expect(1, 2220, '\P{^Jt=	 R}', "");
Expect(0, 2221, '\p{Jt=	 R}', "");
Expect(1, 2221, '\p{^Jt=	 R}', "");
Expect(1, 2221, '\P{Jt=	 R}', "");
Expect(0, 2221, '\P{^Jt=	 R}', "");
Error('\p{Is_Joining_Type=:=-RIGHT_Joining}');
Error('\P{Is_Joining_Type=:=-RIGHT_Joining}');
Expect(1, 2220, '\p{Is_Joining_Type=rightjoining}', "");
Expect(0, 2220, '\p{^Is_Joining_Type=rightjoining}', "");
Expect(0, 2220, '\P{Is_Joining_Type=rightjoining}', "");
Expect(1, 2220, '\P{^Is_Joining_Type=rightjoining}', "");
Expect(0, 2221, '\p{Is_Joining_Type=rightjoining}', "");
Expect(1, 2221, '\p{^Is_Joining_Type=rightjoining}', "");
Expect(1, 2221, '\P{Is_Joining_Type=rightjoining}', "");
Expect(0, 2221, '\P{^Is_Joining_Type=rightjoining}', "");
Expect(1, 2220, '\p{Is_Joining_Type=-Right_joining}', "");
Expect(0, 2220, '\p{^Is_Joining_Type=-Right_joining}', "");
Expect(0, 2220, '\P{Is_Joining_Type=-Right_joining}', "");
Expect(1, 2220, '\P{^Is_Joining_Type=-Right_joining}', "");
Expect(0, 2221, '\p{Is_Joining_Type=-Right_joining}', "");
Expect(1, 2221, '\p{^Is_Joining_Type=-Right_joining}', "");
Expect(1, 2221, '\P{Is_Joining_Type=-Right_joining}', "");
Expect(0, 2221, '\P{^Is_Joining_Type=-Right_joining}', "");
Error('\p{Is_Jt=_/a/R}');
Error('\P{Is_Jt=_/a/R}');
Expect(1, 2220, '\p{Is_Jt=r}', "");
Expect(0, 2220, '\p{^Is_Jt=r}', "");
Expect(0, 2220, '\P{Is_Jt=r}', "");
Expect(1, 2220, '\P{^Is_Jt=r}', "");
Expect(0, 2221, '\p{Is_Jt=r}', "");
Expect(1, 2221, '\p{^Is_Jt=r}', "");
Expect(1, 2221, '\P{Is_Jt=r}', "");
Expect(0, 2221, '\P{^Is_Jt=r}', "");
Expect(1, 2220, '\p{Is_Jt=-	R}', "");
Expect(0, 2220, '\p{^Is_Jt=-	R}', "");
Expect(0, 2220, '\P{Is_Jt=-	R}', "");
Expect(1, 2220, '\P{^Is_Jt=-	R}', "");
Expect(0, 2221, '\p{Is_Jt=-	R}', "");
Expect(1, 2221, '\p{^Is_Jt=-	R}', "");
Expect(1, 2221, '\P{Is_Jt=-	R}', "");
Expect(0, 2221, '\P{^Is_Jt=-	R}', "");
Error('\p{Joining_Type: /a/ _Transparent}');
Error('\P{Joining_Type: /a/ _Transparent}');
Expect(1, 917999, '\p{Joining_Type=transparent}', "");
Expect(0, 917999, '\p{^Joining_Type=transparent}', "");
Expect(0, 917999, '\P{Joining_Type=transparent}', "");
Expect(1, 917999, '\P{^Joining_Type=transparent}', "");
Expect(0, 918000, '\p{Joining_Type=transparent}', "");
Expect(1, 918000, '\p{^Joining_Type=transparent}', "");
Expect(1, 918000, '\P{Joining_Type=transparent}', "");
Expect(0, 918000, '\P{^Joining_Type=transparent}', "");
Expect(1, 917999, '\p{Joining_Type=__transparent}', "");
Expect(0, 917999, '\p{^Joining_Type=__transparent}', "");
Expect(0, 917999, '\P{Joining_Type=__transparent}', "");
Expect(1, 917999, '\P{^Joining_Type=__transparent}', "");
Expect(0, 918000, '\p{Joining_Type=__transparent}', "");
Expect(1, 918000, '\p{^Joining_Type=__transparent}', "");
Expect(1, 918000, '\P{Joining_Type=__transparent}', "");
Expect(0, 918000, '\P{^Joining_Type=__transparent}', "");
Error('\p{Jt=	-T:=}');
Error('\P{Jt=	-T:=}');
Expect(1, 917999, '\p{Jt=t}', "");
Expect(0, 917999, '\p{^Jt=t}', "");
Expect(0, 917999, '\P{Jt=t}', "");
Expect(1, 917999, '\P{^Jt=t}', "");
Expect(0, 918000, '\p{Jt=t}', "");
Expect(1, 918000, '\p{^Jt=t}', "");
Expect(1, 918000, '\P{Jt=t}', "");
Expect(0, 918000, '\P{^Jt=t}', "");
Expect(1, 917999, '\p{Jt=-T}', "");
Expect(0, 917999, '\p{^Jt=-T}', "");
Expect(0, 917999, '\P{Jt=-T}', "");
Expect(1, 917999, '\P{^Jt=-T}', "");
Expect(0, 918000, '\p{Jt=-T}', "");
Expect(1, 918000, '\p{^Jt=-T}', "");
Expect(1, 918000, '\P{Jt=-T}', "");
Expect(0, 918000, '\P{^Jt=-T}', "");
Error('\p{Is_Joining_Type=_	Transparent/a/}');
Error('\P{Is_Joining_Type=_	Transparent/a/}');
Expect(1, 917999, '\p{Is_Joining_Type=transparent}', "");
Expect(0, 917999, '\p{^Is_Joining_Type=transparent}', "");
Expect(0, 917999, '\P{Is_Joining_Type=transparent}', "");
Expect(1, 917999, '\P{^Is_Joining_Type=transparent}', "");
Expect(0, 918000, '\p{Is_Joining_Type=transparent}', "");
Expect(1, 918000, '\p{^Is_Joining_Type=transparent}', "");
Expect(1, 918000, '\P{Is_Joining_Type=transparent}', "");
Expect(0, 918000, '\P{^Is_Joining_Type=transparent}', "");
Expect(1, 917999, '\p{Is_Joining_Type:    -TRANSPARENT}', "");
Expect(0, 917999, '\p{^Is_Joining_Type:    -TRANSPARENT}', "");
Expect(0, 917999, '\P{Is_Joining_Type:    -TRANSPARENT}', "");
Expect(1, 917999, '\P{^Is_Joining_Type:    -TRANSPARENT}', "");
Expect(0, 918000, '\p{Is_Joining_Type:    -TRANSPARENT}', "");
Expect(1, 918000, '\p{^Is_Joining_Type:    -TRANSPARENT}', "");
Expect(1, 918000, '\P{Is_Joining_Type:    -TRANSPARENT}', "");
Expect(0, 918000, '\P{^Is_Joining_Type:    -TRANSPARENT}', "");
Error('\p{Is_Jt: /a/-t}');
Error('\P{Is_Jt: /a/-t}');
Expect(1, 917999, '\p{Is_Jt:   t}', "");
Expect(0, 917999, '\p{^Is_Jt:   t}', "");
Expect(0, 917999, '\P{Is_Jt:   t}', "");
Expect(1, 917999, '\P{^Is_Jt:   t}', "");
Expect(0, 918000, '\p{Is_Jt:   t}', "");
Expect(1, 918000, '\p{^Is_Jt:   t}', "");
Expect(1, 918000, '\P{Is_Jt:   t}', "");
Expect(0, 918000, '\P{^Is_Jt:   t}', "");
Expect(1, 917999, '\p{Is_Jt=	 t}', "");
Expect(0, 917999, '\p{^Is_Jt=	 t}', "");
Expect(0, 917999, '\P{Is_Jt=	 t}', "");
Expect(1, 917999, '\P{^Is_Jt=	 t}', "");
Expect(0, 918000, '\p{Is_Jt=	 t}', "");
Expect(1, 918000, '\p{^Is_Jt=	 t}', "");
Expect(1, 918000, '\P{Is_Jt=	 t}', "");
Expect(0, 918000, '\P{^Is_Jt=	 t}', "");
Error('\p{Joining_Type= Non_JOINING:=}');
Error('\P{Joining_Type= Non_JOINING:=}');
Expect(1, 918000, '\p{Joining_Type=nonjoining}', "");
Expect(0, 918000, '\p{^Joining_Type=nonjoining}', "");
Expect(0, 918000, '\P{Joining_Type=nonjoining}', "");
Expect(1, 918000, '\P{^Joining_Type=nonjoining}', "");
Expect(0, 917999, '\p{Joining_Type=nonjoining}', "");
Expect(1, 917999, '\p{^Joining_Type=nonjoining}', "");
Expect(1, 917999, '\P{Joining_Type=nonjoining}', "");
Expect(0, 917999, '\P{^Joining_Type=nonjoining}', "");
Expect(1, 918000, '\p{Joining_Type=--non_joining}', "");
Expect(0, 918000, '\p{^Joining_Type=--non_joining}', "");
Expect(0, 918000, '\P{Joining_Type=--non_joining}', "");
Expect(1, 918000, '\P{^Joining_Type=--non_joining}', "");
Expect(0, 917999, '\p{Joining_Type=--non_joining}', "");
Expect(1, 917999, '\p{^Joining_Type=--non_joining}', "");
Expect(1, 917999, '\P{Joining_Type=--non_joining}', "");
Expect(0, 917999, '\P{^Joining_Type=--non_joining}', "");
Error('\p{Jt=/a/-U}');
Error('\P{Jt=/a/-U}');
Expect(1, 918000, '\p{Jt=u}', "");
Expect(0, 918000, '\p{^Jt=u}', "");
Expect(0, 918000, '\P{Jt=u}', "");
Expect(1, 918000, '\P{^Jt=u}', "");
Expect(0, 917999, '\p{Jt=u}', "");
Expect(1, 917999, '\p{^Jt=u}', "");
Expect(1, 917999, '\P{Jt=u}', "");
Expect(0, 917999, '\P{^Jt=u}', "");
Expect(1, 918000, '\p{Jt=-U}', "");
Expect(0, 918000, '\p{^Jt=-U}', "");
Expect(0, 918000, '\P{Jt=-U}', "");
Expect(1, 918000, '\P{^Jt=-U}', "");
Expect(0, 917999, '\p{Jt=-U}', "");
Expect(1, 917999, '\p{^Jt=-U}', "");
Expect(1, 917999, '\P{Jt=-U}', "");
Expect(0, 917999, '\P{^Jt=-U}', "");
Error('\p{Is_Joining_Type=/a/		non_Joining}');
Error('\P{Is_Joining_Type=/a/		non_Joining}');
Expect(1, 918000, '\p{Is_Joining_Type=nonjoining}', "");
Expect(0, 918000, '\p{^Is_Joining_Type=nonjoining}', "");
Expect(0, 918000, '\P{Is_Joining_Type=nonjoining}', "");
Expect(1, 918000, '\P{^Is_Joining_Type=nonjoining}', "");
Expect(0, 917999, '\p{Is_Joining_Type=nonjoining}', "");
Expect(1, 917999, '\p{^Is_Joining_Type=nonjoining}', "");
Expect(1, 917999, '\P{Is_Joining_Type=nonjoining}', "");
Expect(0, 917999, '\P{^Is_Joining_Type=nonjoining}', "");
Expect(1, 918000, '\p{Is_Joining_Type=-non_joining}', "");
Expect(0, 918000, '\p{^Is_Joining_Type=-non_joining}', "");
Expect(0, 918000, '\P{Is_Joining_Type=-non_joining}', "");
Expect(1, 918000, '\P{^Is_Joining_Type=-non_joining}', "");
Expect(0, 917999, '\p{Is_Joining_Type=-non_joining}', "");
Expect(1, 917999, '\p{^Is_Joining_Type=-non_joining}', "");
Expect(1, 917999, '\P{Is_Joining_Type=-non_joining}', "");
Expect(0, 917999, '\P{^Is_Joining_Type=-non_joining}', "");
Error('\p{Is_Jt=/a/	U}');
Error('\P{Is_Jt=/a/	U}');
Expect(1, 918000, '\p{Is_Jt=u}', "");
Expect(0, 918000, '\p{^Is_Jt=u}', "");
Expect(0, 918000, '\P{Is_Jt=u}', "");
Expect(1, 918000, '\P{^Is_Jt=u}', "");
Expect(0, 917999, '\p{Is_Jt=u}', "");
Expect(1, 917999, '\p{^Is_Jt=u}', "");
Expect(1, 917999, '\P{Is_Jt=u}', "");
Expect(0, 917999, '\P{^Is_Jt=u}', "");
Expect(1, 918000, '\p{Is_Jt=- U}', "");
Expect(0, 918000, '\p{^Is_Jt=- U}', "");
Expect(0, 918000, '\P{Is_Jt=- U}', "");
Expect(1, 918000, '\P{^Is_Jt=- U}', "");
Expect(0, 917999, '\p{Is_Jt=- U}', "");
Expect(1, 917999, '\p{^Is_Jt=- U}', "");
Expect(1, 917999, '\P{Is_Jt=- U}', "");
Expect(0, 917999, '\P{^Is_Jt=- U}', "");
Error('\p{Line_Break= -Ambiguous/a/}');
Error('\P{Line_Break= -Ambiguous/a/}');
Expect(1, 127386, '\p{Line_Break=ambiguous}', "");
Expect(0, 127386, '\p{^Line_Break=ambiguous}', "");
Expect(0, 127386, '\P{Line_Break=ambiguous}', "");
Expect(1, 127386, '\P{^Line_Break=ambiguous}', "");
Expect(0, 127387, '\p{Line_Break=ambiguous}', "");
Expect(1, 127387, '\p{^Line_Break=ambiguous}', "");
Expect(1, 127387, '\P{Line_Break=ambiguous}', "");
Expect(0, 127387, '\P{^Line_Break=ambiguous}', "");
Expect(1, 127386, '\p{Line_Break=- AMBIGUOUS}', "");
Expect(0, 127386, '\p{^Line_Break=- AMBIGUOUS}', "");
Expect(0, 127386, '\P{Line_Break=- AMBIGUOUS}', "");
Expect(1, 127386, '\P{^Line_Break=- AMBIGUOUS}', "");
Expect(0, 127387, '\p{Line_Break=- AMBIGUOUS}', "");
Expect(1, 127387, '\p{^Line_Break=- AMBIGUOUS}', "");
Expect(1, 127387, '\P{Line_Break=- AMBIGUOUS}', "");
Expect(0, 127387, '\P{^Line_Break=- AMBIGUOUS}', "");
Error('\p{Lb=_:=ai}');
Error('\P{Lb=_:=ai}');
Expect(1, 127386, '\p{Lb=ai}', "");
Expect(0, 127386, '\p{^Lb=ai}', "");
Expect(0, 127386, '\P{Lb=ai}', "");
Expect(1, 127386, '\P{^Lb=ai}', "");
Expect(0, 127387, '\p{Lb=ai}', "");
Expect(1, 127387, '\p{^Lb=ai}', "");
Expect(1, 127387, '\P{Lb=ai}', "");
Expect(0, 127387, '\P{^Lb=ai}', "");
Expect(1, 127386, '\p{Lb=  AI}', "");
Expect(0, 127386, '\p{^Lb=  AI}', "");
Expect(0, 127386, '\P{Lb=  AI}', "");
Expect(1, 127386, '\P{^Lb=  AI}', "");
Expect(0, 127387, '\p{Lb=  AI}', "");
Expect(1, 127387, '\p{^Lb=  AI}', "");
Expect(1, 127387, '\P{Lb=  AI}', "");
Expect(0, 127387, '\P{^Lb=  AI}', "");
Error('\p{Is_Line_Break:    :=Ambiguous}');
Error('\P{Is_Line_Break:    :=Ambiguous}');
Expect(1, 127386, '\p{Is_Line_Break=ambiguous}', "");
Expect(0, 127386, '\p{^Is_Line_Break=ambiguous}', "");
Expect(0, 127386, '\P{Is_Line_Break=ambiguous}', "");
Expect(1, 127386, '\P{^Is_Line_Break=ambiguous}', "");
Expect(0, 127387, '\p{Is_Line_Break=ambiguous}', "");
Expect(1, 127387, '\p{^Is_Line_Break=ambiguous}', "");
Expect(1, 127387, '\P{Is_Line_Break=ambiguous}', "");
Expect(0, 127387, '\P{^Is_Line_Break=ambiguous}', "");
Expect(1, 127386, '\p{Is_Line_Break=- Ambiguous}', "");
Expect(0, 127386, '\p{^Is_Line_Break=- Ambiguous}', "");
Expect(0, 127386, '\P{Is_Line_Break=- Ambiguous}', "");
Expect(1, 127386, '\P{^Is_Line_Break=- Ambiguous}', "");
Expect(0, 127387, '\p{Is_Line_Break=- Ambiguous}', "");
Expect(1, 127387, '\p{^Is_Line_Break=- Ambiguous}', "");
Expect(1, 127387, '\P{Is_Line_Break=- Ambiguous}', "");
Expect(0, 127387, '\P{^Is_Line_Break=- Ambiguous}', "");
Error('\p{Is_Lb=:= _AI}');
Error('\P{Is_Lb=:= _AI}');
Expect(1, 127386, '\p{Is_Lb=ai}', "");
Expect(0, 127386, '\p{^Is_Lb=ai}', "");
Expect(0, 127386, '\P{Is_Lb=ai}', "");
Expect(1, 127386, '\P{^Is_Lb=ai}', "");
Expect(0, 127387, '\p{Is_Lb=ai}', "");
Expect(1, 127387, '\p{^Is_Lb=ai}', "");
Expect(1, 127387, '\P{Is_Lb=ai}', "");
Expect(0, 127387, '\P{^Is_Lb=ai}', "");
Expect(1, 127386, '\p{Is_Lb=_-AI}', "");
Expect(0, 127386, '\p{^Is_Lb=_-AI}', "");
Expect(0, 127386, '\P{Is_Lb=_-AI}', "");
Expect(1, 127386, '\P{^Is_Lb=_-AI}', "");
Expect(0, 127387, '\p{Is_Lb=_-AI}', "");
Expect(1, 127387, '\p{^Is_Lb=_-AI}', "");
Expect(1, 127387, '\P{Is_Lb=_-AI}', "");
Expect(0, 127387, '\P{^Is_Lb=_-AI}', "");
Error('\p{Line_Break=:=_Alphabetic}');
Error('\P{Line_Break=:=_Alphabetic}');
Expect(1, 128883, '\p{Line_Break=alphabetic}', "");
Expect(0, 128883, '\p{^Line_Break=alphabetic}', "");
Expect(0, 128883, '\P{Line_Break=alphabetic}', "");
Expect(1, 128883, '\P{^Line_Break=alphabetic}', "");
Expect(0, 128884, '\p{Line_Break=alphabetic}', "");
Expect(1, 128884, '\p{^Line_Break=alphabetic}', "");
Expect(1, 128884, '\P{Line_Break=alphabetic}', "");
Expect(0, 128884, '\P{^Line_Break=alphabetic}', "");
Expect(1, 128883, '\p{Line_Break=-_ALPHABETIC}', "");
Expect(0, 128883, '\p{^Line_Break=-_ALPHABETIC}', "");
Expect(0, 128883, '\P{Line_Break=-_ALPHABETIC}', "");
Expect(1, 128883, '\P{^Line_Break=-_ALPHABETIC}', "");
Expect(0, 128884, '\p{Line_Break=-_ALPHABETIC}', "");
Expect(1, 128884, '\p{^Line_Break=-_ALPHABETIC}', "");
Expect(1, 128884, '\P{Line_Break=-_ALPHABETIC}', "");
Expect(0, 128884, '\P{^Line_Break=-_ALPHABETIC}', "");
Error('\p{Lb::=		al}');
Error('\P{Lb::=		al}');
Expect(1, 128883, '\p{Lb=al}', "");
Expect(0, 128883, '\p{^Lb=al}', "");
Expect(0, 128883, '\P{Lb=al}', "");
Expect(1, 128883, '\P{^Lb=al}', "");
Expect(0, 128884, '\p{Lb=al}', "");
Expect(1, 128884, '\p{^Lb=al}', "");
Expect(1, 128884, '\P{Lb=al}', "");
Expect(0, 128884, '\P{^Lb=al}', "");
Expect(1, 128883, '\p{Lb= al}', "");
Expect(0, 128883, '\p{^Lb= al}', "");
Expect(0, 128883, '\P{Lb= al}', "");
Expect(1, 128883, '\P{^Lb= al}', "");
Expect(0, 128884, '\p{Lb= al}', "");
Expect(1, 128884, '\p{^Lb= al}', "");
Expect(1, 128884, '\P{Lb= al}', "");
Expect(0, 128884, '\P{^Lb= al}', "");
Error('\p{Is_Line_Break: _ ALPHABETIC/a/}');
Error('\P{Is_Line_Break: _ ALPHABETIC/a/}');
Expect(1, 128883, '\p{Is_Line_Break=alphabetic}', "");
Expect(0, 128883, '\p{^Is_Line_Break=alphabetic}', "");
Expect(0, 128883, '\P{Is_Line_Break=alphabetic}', "");
Expect(1, 128883, '\P{^Is_Line_Break=alphabetic}', "");
Expect(0, 128884, '\p{Is_Line_Break=alphabetic}', "");
Expect(1, 128884, '\p{^Is_Line_Break=alphabetic}', "");
Expect(1, 128884, '\P{Is_Line_Break=alphabetic}', "");
Expect(0, 128884, '\P{^Is_Line_Break=alphabetic}', "");
Expect(1, 128883, '\p{Is_Line_Break=	alphabetic}', "");
Expect(0, 128883, '\p{^Is_Line_Break=	alphabetic}', "");
Expect(0, 128883, '\P{Is_Line_Break=	alphabetic}', "");
Expect(1, 128883, '\P{^Is_Line_Break=	alphabetic}', "");
Expect(0, 128884, '\p{Is_Line_Break=	alphabetic}', "");
Expect(1, 128884, '\p{^Is_Line_Break=	alphabetic}', "");
Expect(1, 128884, '\P{Is_Line_Break=	alphabetic}', "");
Expect(0, 128884, '\P{^Is_Line_Break=	alphabetic}', "");
Error('\p{Is_Lb:   /a/al}');
Error('\P{Is_Lb:   /a/al}');
Expect(1, 128883, '\p{Is_Lb=al}', "");
Expect(0, 128883, '\p{^Is_Lb=al}', "");
Expect(0, 128883, '\P{Is_Lb=al}', "");
Expect(1, 128883, '\P{^Is_Lb=al}', "");
Expect(0, 128884, '\p{Is_Lb=al}', "");
Expect(1, 128884, '\p{^Is_Lb=al}', "");
Expect(1, 128884, '\P{Is_Lb=al}', "");
Expect(0, 128884, '\P{^Is_Lb=al}', "");
Expect(1, 128883, '\p{Is_Lb=AL}', "");
Expect(0, 128883, '\p{^Is_Lb=AL}', "");
Expect(0, 128883, '\P{Is_Lb=AL}', "");
Expect(1, 128883, '\P{^Is_Lb=AL}', "");
Expect(0, 128884, '\p{Is_Lb=AL}', "");
Expect(1, 128884, '\p{^Is_Lb=AL}', "");
Expect(1, 128884, '\P{Is_Lb=AL}', "");
Expect(0, 128884, '\P{^Is_Lb=AL}', "");
Error('\p{Line_Break=	BREAK_Both:=}');
Error('\P{Line_Break=	BREAK_Both:=}');
Expect(1, 11835, '\p{Line_Break=breakboth}', "");
Expect(0, 11835, '\p{^Line_Break=breakboth}', "");
Expect(0, 11835, '\P{Line_Break=breakboth}', "");
Expect(1, 11835, '\P{^Line_Break=breakboth}', "");
Expect(0, 11836, '\p{Line_Break=breakboth}', "");
Expect(1, 11836, '\p{^Line_Break=breakboth}', "");
Expect(1, 11836, '\P{Line_Break=breakboth}', "");
Expect(0, 11836, '\P{^Line_Break=breakboth}', "");
Expect(1, 11835, '\p{Line_Break:   	Break_Both}', "");
Expect(0, 11835, '\p{^Line_Break:   	Break_Both}', "");
Expect(0, 11835, '\P{Line_Break:   	Break_Both}', "");
Expect(1, 11835, '\P{^Line_Break:   	Break_Both}', "");
Expect(0, 11836, '\p{Line_Break:   	Break_Both}', "");
Expect(1, 11836, '\p{^Line_Break:   	Break_Both}', "");
Expect(1, 11836, '\P{Line_Break:   	Break_Both}', "");
Expect(0, 11836, '\P{^Line_Break:   	Break_Both}', "");
Error('\p{Lb:     B2/a/}');
Error('\P{Lb:     B2/a/}');
Expect(1, 11835, '\p{Lb=b2}', "");
Expect(0, 11835, '\p{^Lb=b2}', "");
Expect(0, 11835, '\P{Lb=b2}', "");
Expect(1, 11835, '\P{^Lb=b2}', "");
Expect(0, 11836, '\p{Lb=b2}', "");
Expect(1, 11836, '\p{^Lb=b2}', "");
Expect(1, 11836, '\P{Lb=b2}', "");
Expect(0, 11836, '\P{^Lb=b2}', "");
Expect(1, 11835, '\p{Lb=-b2}', "");
Expect(0, 11835, '\p{^Lb=-b2}', "");
Expect(0, 11835, '\P{Lb=-b2}', "");
Expect(1, 11835, '\P{^Lb=-b2}', "");
Expect(0, 11836, '\p{Lb=-b2}', "");
Expect(1, 11836, '\p{^Lb=-b2}', "");
Expect(1, 11836, '\P{Lb=-b2}', "");
Expect(0, 11836, '\P{^Lb=-b2}', "");
Error('\p{Is_Line_Break= /a/Break_both}');
Error('\P{Is_Line_Break= /a/Break_both}');
Expect(1, 11835, '\p{Is_Line_Break=breakboth}', "");
Expect(0, 11835, '\p{^Is_Line_Break=breakboth}', "");
Expect(0, 11835, '\P{Is_Line_Break=breakboth}', "");
Expect(1, 11835, '\P{^Is_Line_Break=breakboth}', "");
Expect(0, 11836, '\p{Is_Line_Break=breakboth}', "");
Expect(1, 11836, '\p{^Is_Line_Break=breakboth}', "");
Expect(1, 11836, '\P{Is_Line_Break=breakboth}', "");
Expect(0, 11836, '\P{^Is_Line_Break=breakboth}', "");
Expect(1, 11835, '\p{Is_Line_Break=--Break_Both}', "");
Expect(0, 11835, '\p{^Is_Line_Break=--Break_Both}', "");
Expect(0, 11835, '\P{Is_Line_Break=--Break_Both}', "");
Expect(1, 11835, '\P{^Is_Line_Break=--Break_Both}', "");
Expect(0, 11836, '\p{Is_Line_Break=--Break_Both}', "");
Expect(1, 11836, '\p{^Is_Line_Break=--Break_Both}', "");
Expect(1, 11836, '\P{Is_Line_Break=--Break_Both}', "");
Expect(0, 11836, '\P{^Is_Line_Break=--Break_Both}', "");
Error('\p{Is_Lb=/a/B2}');
Error('\P{Is_Lb=/a/B2}');
Expect(1, 11835, '\p{Is_Lb=b2}', "");
Expect(0, 11835, '\p{^Is_Lb=b2}', "");
Expect(0, 11835, '\P{Is_Lb=b2}', "");
Expect(1, 11835, '\P{^Is_Lb=b2}', "");
Expect(0, 11836, '\p{Is_Lb=b2}', "");
Expect(1, 11836, '\p{^Is_Lb=b2}', "");
Expect(1, 11836, '\P{Is_Lb=b2}', "");
Expect(0, 11836, '\P{^Is_Lb=b2}', "");
Expect(1, 11835, '\p{Is_Lb:		-B2}', "");
Expect(0, 11835, '\p{^Is_Lb:		-B2}', "");
Expect(0, 11835, '\P{Is_Lb:		-B2}', "");
Expect(1, 11835, '\P{^Is_Lb:		-B2}', "");
Expect(0, 11836, '\p{Is_Lb:		-B2}', "");
Expect(1, 11836, '\p{^Is_Lb:		-B2}', "");
Expect(1, 11836, '\P{Is_Lb:		-B2}', "");
Expect(0, 11836, '\P{^Is_Lb:		-B2}', "");
Error('\p{Line_Break=_/a/Break_AFTER}');
Error('\P{Line_Break=_/a/Break_AFTER}');
Expect(1, 74867, '\p{Line_Break=breakafter}', "");
Expect(0, 74867, '\p{^Line_Break=breakafter}', "");
Expect(0, 74867, '\P{Line_Break=breakafter}', "");
Expect(1, 74867, '\P{^Line_Break=breakafter}', "");
Expect(0, 74868, '\p{Line_Break=breakafter}', "");
Expect(1, 74868, '\p{^Line_Break=breakafter}', "");
Expect(1, 74868, '\P{Line_Break=breakafter}', "");
Expect(0, 74868, '\P{^Line_Break=breakafter}', "");
Expect(1, 74867, '\p{Line_Break= BREAK_After}', "");
Expect(0, 74867, '\p{^Line_Break= BREAK_After}', "");
Expect(0, 74867, '\P{Line_Break= BREAK_After}', "");
Expect(1, 74867, '\P{^Line_Break= BREAK_After}', "");
Expect(0, 74868, '\p{Line_Break= BREAK_After}', "");
Expect(1, 74868, '\p{^Line_Break= BREAK_After}', "");
Expect(1, 74868, '\P{Line_Break= BREAK_After}', "");
Expect(0, 74868, '\P{^Line_Break= BREAK_After}', "");
Error('\p{Lb=:=	-BA}');
Error('\P{Lb=:=	-BA}');
Expect(1, 74867, '\p{Lb=ba}', "");
Expect(0, 74867, '\p{^Lb=ba}', "");
Expect(0, 74867, '\P{Lb=ba}', "");
Expect(1, 74867, '\P{^Lb=ba}', "");
Expect(0, 74868, '\p{Lb=ba}', "");
Expect(1, 74868, '\p{^Lb=ba}', "");
Expect(1, 74868, '\P{Lb=ba}', "");
Expect(0, 74868, '\P{^Lb=ba}', "");
Expect(1, 74867, '\p{Lb=	ba}', "");
Expect(0, 74867, '\p{^Lb=	ba}', "");
Expect(0, 74867, '\P{Lb=	ba}', "");
Expect(1, 74867, '\P{^Lb=	ba}', "");
Expect(0, 74868, '\p{Lb=	ba}', "");
Expect(1, 74868, '\p{^Lb=	ba}', "");
Expect(1, 74868, '\P{Lb=	ba}', "");
Expect(0, 74868, '\P{^Lb=	ba}', "");
Error('\p{Is_Line_Break= 	Break_AFTER/a/}');
Error('\P{Is_Line_Break= 	Break_AFTER/a/}');
Expect(1, 74867, '\p{Is_Line_Break=breakafter}', "");
Expect(0, 74867, '\p{^Is_Line_Break=breakafter}', "");
Expect(0, 74867, '\P{Is_Line_Break=breakafter}', "");
Expect(1, 74867, '\P{^Is_Line_Break=breakafter}', "");
Expect(0, 74868, '\p{Is_Line_Break=breakafter}', "");
Expect(1, 74868, '\p{^Is_Line_Break=breakafter}', "");
Expect(1, 74868, '\P{Is_Line_Break=breakafter}', "");
Expect(0, 74868, '\P{^Is_Line_Break=breakafter}', "");
Expect(1, 74867, '\p{Is_Line_Break=	_break_After}', "");
Expect(0, 74867, '\p{^Is_Line_Break=	_break_After}', "");
Expect(0, 74867, '\P{Is_Line_Break=	_break_After}', "");
Expect(1, 74867, '\P{^Is_Line_Break=	_break_After}', "");
Expect(0, 74868, '\p{Is_Line_Break=	_break_After}', "");
Expect(1, 74868, '\p{^Is_Line_Break=	_break_After}', "");
Expect(1, 74868, '\P{Is_Line_Break=	_break_After}', "");
Expect(0, 74868, '\P{^Is_Line_Break=	_break_After}', "");
Error('\p{Is_Lb=	 BA/a/}');
Error('\P{Is_Lb=	 BA/a/}');
Expect(1, 74867, '\p{Is_Lb=ba}', "");
Expect(0, 74867, '\p{^Is_Lb=ba}', "");
Expect(0, 74867, '\P{Is_Lb=ba}', "");
Expect(1, 74867, '\P{^Is_Lb=ba}', "");
Expect(0, 74868, '\p{Is_Lb=ba}', "");
Expect(1, 74868, '\p{^Is_Lb=ba}', "");
Expect(1, 74868, '\P{Is_Lb=ba}', "");
Expect(0, 74868, '\P{^Is_Lb=ba}', "");
Expect(1, 74867, '\p{Is_Lb=_BA}', "");
Expect(0, 74867, '\p{^Is_Lb=_BA}', "");
Expect(0, 74867, '\P{Is_Lb=_BA}', "");
Expect(1, 74867, '\P{^Is_Lb=_BA}', "");
Expect(0, 74868, '\p{Is_Lb=_BA}', "");
Expect(1, 74868, '\p{^Is_Lb=_BA}', "");
Expect(1, 74868, '\P{Is_Lb=_BA}', "");
Expect(0, 74868, '\P{^Is_Lb=_BA}', "");
Error('\p{Line_Break=_ Break_BEFORE/a/}');
Error('\P{Line_Break=_ Break_BEFORE/a/}');
Expect(1, 43125, '\p{Line_Break=breakbefore}', "");
Expect(0, 43125, '\p{^Line_Break=breakbefore}', "");
Expect(0, 43125, '\P{Line_Break=breakbefore}', "");
Expect(1, 43125, '\P{^Line_Break=breakbefore}', "");
Expect(0, 43126, '\p{Line_Break=breakbefore}', "");
Expect(1, 43126, '\p{^Line_Break=breakbefore}', "");
Expect(1, 43126, '\P{Line_Break=breakbefore}', "");
Expect(0, 43126, '\P{^Line_Break=breakbefore}', "");
Expect(1, 43125, '\p{Line_Break=-Break_BEFORE}', "");
Expect(0, 43125, '\p{^Line_Break=-Break_BEFORE}', "");
Expect(0, 43125, '\P{Line_Break=-Break_BEFORE}', "");
Expect(1, 43125, '\P{^Line_Break=-Break_BEFORE}', "");
Expect(0, 43126, '\p{Line_Break=-Break_BEFORE}', "");
Expect(1, 43126, '\p{^Line_Break=-Break_BEFORE}', "");
Expect(1, 43126, '\P{Line_Break=-Break_BEFORE}', "");
Expect(0, 43126, '\P{^Line_Break=-Break_BEFORE}', "");
Error('\p{Lb= /a/BB}');
Error('\P{Lb= /a/BB}');
Expect(1, 43125, '\p{Lb=bb}', "");
Expect(0, 43125, '\p{^Lb=bb}', "");
Expect(0, 43125, '\P{Lb=bb}', "");
Expect(1, 43125, '\P{^Lb=bb}', "");
Expect(0, 43126, '\p{Lb=bb}', "");
Expect(1, 43126, '\p{^Lb=bb}', "");
Expect(1, 43126, '\P{Lb=bb}', "");
Expect(0, 43126, '\P{^Lb=bb}', "");
Expect(1, 43125, '\p{Lb=_-bb}', "");
Expect(0, 43125, '\p{^Lb=_-bb}', "");
Expect(0, 43125, '\P{Lb=_-bb}', "");
Expect(1, 43125, '\P{^Lb=_-bb}', "");
Expect(0, 43126, '\p{Lb=_-bb}', "");
Expect(1, 43126, '\p{^Lb=_-bb}', "");
Expect(1, 43126, '\P{Lb=_-bb}', "");
Expect(0, 43126, '\P{^Lb=_-bb}', "");
Error('\p{Is_Line_Break= -Break_BEFORE:=}');
Error('\P{Is_Line_Break= -Break_BEFORE:=}');
Expect(1, 43125, '\p{Is_Line_Break=breakbefore}', "");
Expect(0, 43125, '\p{^Is_Line_Break=breakbefore}', "");
Expect(0, 43125, '\P{Is_Line_Break=breakbefore}', "");
Expect(1, 43125, '\P{^Is_Line_Break=breakbefore}', "");
Expect(0, 43126, '\p{Is_Line_Break=breakbefore}', "");
Expect(1, 43126, '\p{^Is_Line_Break=breakbefore}', "");
Expect(1, 43126, '\P{Is_Line_Break=breakbefore}', "");
Expect(0, 43126, '\P{^Is_Line_Break=breakbefore}', "");
Expect(1, 43125, '\p{Is_Line_Break=_ Break_before}', "");
Expect(0, 43125, '\p{^Is_Line_Break=_ Break_before}', "");
Expect(0, 43125, '\P{Is_Line_Break=_ Break_before}', "");
Expect(1, 43125, '\P{^Is_Line_Break=_ Break_before}', "");
Expect(0, 43126, '\p{Is_Line_Break=_ Break_before}', "");
Expect(1, 43126, '\p{^Is_Line_Break=_ Break_before}', "");
Expect(1, 43126, '\P{Is_Line_Break=_ Break_before}', "");
Expect(0, 43126, '\P{^Is_Line_Break=_ Break_before}', "");
Error('\p{Is_Lb:	/a/ bb}');
Error('\P{Is_Lb:	/a/ bb}');
Expect(1, 43125, '\p{Is_Lb=bb}', "");
Expect(0, 43125, '\p{^Is_Lb=bb}', "");
Expect(0, 43125, '\P{Is_Lb=bb}', "");
Expect(1, 43125, '\P{^Is_Lb=bb}', "");
Expect(0, 43126, '\p{Is_Lb=bb}', "");
Expect(1, 43126, '\p{^Is_Lb=bb}', "");
Expect(1, 43126, '\P{Is_Lb=bb}', "");
Expect(0, 43126, '\P{^Is_Lb=bb}', "");
Expect(1, 43125, '\p{Is_Lb=	bb}', "");
Expect(0, 43125, '\p{^Is_Lb=	bb}', "");
Expect(0, 43125, '\P{Is_Lb=	bb}', "");
Expect(1, 43125, '\P{^Is_Lb=	bb}', "");
Expect(0, 43126, '\p{Is_Lb=	bb}', "");
Expect(1, 43126, '\p{^Is_Lb=	bb}', "");
Expect(1, 43126, '\P{Is_Lb=	bb}', "");
Expect(0, 43126, '\P{^Is_Lb=	bb}', "");
Error('\p{Line_Break=_-mandatory_Break:=}');
Error('\P{Line_Break=_-mandatory_Break:=}');
Expect(1, 8233, '\p{Line_Break: mandatorybreak}', "");
Expect(0, 8233, '\p{^Line_Break: mandatorybreak}', "");
Expect(0, 8233, '\P{Line_Break: mandatorybreak}', "");
Expect(1, 8233, '\P{^Line_Break: mandatorybreak}', "");
Expect(0, 8234, '\p{Line_Break: mandatorybreak}', "");
Expect(1, 8234, '\p{^Line_Break: mandatorybreak}', "");
Expect(1, 8234, '\P{Line_Break: mandatorybreak}', "");
Expect(0, 8234, '\P{^Line_Break: mandatorybreak}', "");
Expect(1, 8233, '\p{Line_Break=	-MANDATORY_Break}', "");
Expect(0, 8233, '\p{^Line_Break=	-MANDATORY_Break}', "");
Expect(0, 8233, '\P{Line_Break=	-MANDATORY_Break}', "");
Expect(1, 8233, '\P{^Line_Break=	-MANDATORY_Break}', "");
Expect(0, 8234, '\p{Line_Break=	-MANDATORY_Break}', "");
Expect(1, 8234, '\p{^Line_Break=	-MANDATORY_Break}', "");
Expect(1, 8234, '\P{Line_Break=	-MANDATORY_Break}', "");
Expect(0, 8234, '\P{^Line_Break=	-MANDATORY_Break}', "");
Error('\p{Lb=-/a/BK}');
Error('\P{Lb=-/a/BK}');
Expect(1, 8233, '\p{Lb=bk}', "");
Expect(0, 8233, '\p{^Lb=bk}', "");
Expect(0, 8233, '\P{Lb=bk}', "");
Expect(1, 8233, '\P{^Lb=bk}', "");
Expect(0, 8234, '\p{Lb=bk}', "");
Expect(1, 8234, '\p{^Lb=bk}', "");
Expect(1, 8234, '\P{Lb=bk}', "");
Expect(0, 8234, '\P{^Lb=bk}', "");
Expect(1, 8233, '\p{Lb=  BK}', "");
Expect(0, 8233, '\p{^Lb=  BK}', "");
Expect(0, 8233, '\P{Lb=  BK}', "");
Expect(1, 8233, '\P{^Lb=  BK}', "");
Expect(0, 8234, '\p{Lb=  BK}', "");
Expect(1, 8234, '\p{^Lb=  BK}', "");
Expect(1, 8234, '\P{Lb=  BK}', "");
Expect(0, 8234, '\P{^Lb=  BK}', "");
Error('\p{Is_Line_Break=	 Mandatory_Break/a/}');
Error('\P{Is_Line_Break=	 Mandatory_Break/a/}');
Expect(1, 8233, '\p{Is_Line_Break=mandatorybreak}', "");
Expect(0, 8233, '\p{^Is_Line_Break=mandatorybreak}', "");
Expect(0, 8233, '\P{Is_Line_Break=mandatorybreak}', "");
Expect(1, 8233, '\P{^Is_Line_Break=mandatorybreak}', "");
Expect(0, 8234, '\p{Is_Line_Break=mandatorybreak}', "");
Expect(1, 8234, '\p{^Is_Line_Break=mandatorybreak}', "");
Expect(1, 8234, '\P{Is_Line_Break=mandatorybreak}', "");
Expect(0, 8234, '\P{^Is_Line_Break=mandatorybreak}', "");
Expect(1, 8233, '\p{Is_Line_Break=mandatory_Break}', "");
Expect(0, 8233, '\p{^Is_Line_Break=mandatory_Break}', "");
Expect(0, 8233, '\P{Is_Line_Break=mandatory_Break}', "");
Expect(1, 8233, '\P{^Is_Line_Break=mandatory_Break}', "");
Expect(0, 8234, '\p{Is_Line_Break=mandatory_Break}', "");
Expect(1, 8234, '\p{^Is_Line_Break=mandatory_Break}', "");
Expect(1, 8234, '\P{Is_Line_Break=mandatory_Break}', "");
Expect(0, 8234, '\P{^Is_Line_Break=mandatory_Break}', "");
Error('\p{Is_Lb=/a/BK}');
Error('\P{Is_Lb=/a/BK}');
Expect(1, 8233, '\p{Is_Lb=bk}', "");
Expect(0, 8233, '\p{^Is_Lb=bk}', "");
Expect(0, 8233, '\P{Is_Lb=bk}', "");
Expect(1, 8233, '\P{^Is_Lb=bk}', "");
Expect(0, 8234, '\p{Is_Lb=bk}', "");
Expect(1, 8234, '\p{^Is_Lb=bk}', "");
Expect(1, 8234, '\P{Is_Lb=bk}', "");
Expect(0, 8234, '\P{^Is_Lb=bk}', "");
Expect(1, 8233, '\p{Is_Lb=-	BK}', "");
Expect(0, 8233, '\p{^Is_Lb=-	BK}', "");
Expect(0, 8233, '\P{Is_Lb=-	BK}', "");
Expect(1, 8233, '\P{^Is_Lb=-	BK}', "");
Expect(0, 8234, '\p{Is_Lb=-	BK}', "");
Expect(1, 8234, '\p{^Is_Lb=-	BK}', "");
Expect(1, 8234, '\P{Is_Lb=-	BK}', "");
Expect(0, 8234, '\P{^Is_Lb=-	BK}', "");
Error('\p{Line_Break=:=	_contingent_Break}');
Error('\P{Line_Break=:=	_contingent_Break}');
Expect(1, 65532, '\p{Line_Break=contingentbreak}', "");
Expect(0, 65532, '\p{^Line_Break=contingentbreak}', "");
Expect(0, 65532, '\P{Line_Break=contingentbreak}', "");
Expect(1, 65532, '\P{^Line_Break=contingentbreak}', "");
Expect(0, 65533, '\p{Line_Break=contingentbreak}', "");
Expect(1, 65533, '\p{^Line_Break=contingentbreak}', "");
Expect(1, 65533, '\P{Line_Break=contingentbreak}', "");
Expect(0, 65533, '\P{^Line_Break=contingentbreak}', "");
Expect(1, 65532, '\p{Line_Break=_Contingent_Break}', "");
Expect(0, 65532, '\p{^Line_Break=_Contingent_Break}', "");
Expect(0, 65532, '\P{Line_Break=_Contingent_Break}', "");
Expect(1, 65532, '\P{^Line_Break=_Contingent_Break}', "");
Expect(0, 65533, '\p{Line_Break=_Contingent_Break}', "");
Expect(1, 65533, '\p{^Line_Break=_Contingent_Break}', "");
Expect(1, 65533, '\P{Line_Break=_Contingent_Break}', "");
Expect(0, 65533, '\P{^Line_Break=_Contingent_Break}', "");
Error('\p{Lb=/a/_CB}');
Error('\P{Lb=/a/_CB}');
Expect(1, 65532, '\p{Lb=cb}', "");
Expect(0, 65532, '\p{^Lb=cb}', "");
Expect(0, 65532, '\P{Lb=cb}', "");
Expect(1, 65532, '\P{^Lb=cb}', "");
Expect(0, 65533, '\p{Lb=cb}', "");
Expect(1, 65533, '\p{^Lb=cb}', "");
Expect(1, 65533, '\P{Lb=cb}', "");
Expect(0, 65533, '\P{^Lb=cb}', "");
Expect(1, 65532, '\p{Lb=_	CB}', "");
Expect(0, 65532, '\p{^Lb=_	CB}', "");
Expect(0, 65532, '\P{Lb=_	CB}', "");
Expect(1, 65532, '\P{^Lb=_	CB}', "");
Expect(0, 65533, '\p{Lb=_	CB}', "");
Expect(1, 65533, '\p{^Lb=_	CB}', "");
Expect(1, 65533, '\P{Lb=_	CB}', "");
Expect(0, 65533, '\P{^Lb=_	CB}', "");
Error('\p{Is_Line_Break=Contingent_break:=}');
Error('\P{Is_Line_Break=Contingent_break:=}');
Expect(1, 65532, '\p{Is_Line_Break=contingentbreak}', "");
Expect(0, 65532, '\p{^Is_Line_Break=contingentbreak}', "");
Expect(0, 65532, '\P{Is_Line_Break=contingentbreak}', "");
Expect(1, 65532, '\P{^Is_Line_Break=contingentbreak}', "");
Expect(0, 65533, '\p{Is_Line_Break=contingentbreak}', "");
Expect(1, 65533, '\p{^Is_Line_Break=contingentbreak}', "");
Expect(1, 65533, '\P{Is_Line_Break=contingentbreak}', "");
Expect(0, 65533, '\P{^Is_Line_Break=contingentbreak}', "");
Expect(1, 65532, '\p{Is_Line_Break= contingent_Break}', "");
Expect(0, 65532, '\p{^Is_Line_Break= contingent_Break}', "");
Expect(0, 65532, '\P{Is_Line_Break= contingent_Break}', "");
Expect(1, 65532, '\P{^Is_Line_Break= contingent_Break}', "");
Expect(0, 65533, '\p{Is_Line_Break= contingent_Break}', "");
Expect(1, 65533, '\p{^Is_Line_Break= contingent_Break}', "");
Expect(1, 65533, '\P{Is_Line_Break= contingent_Break}', "");
Expect(0, 65533, '\P{^Is_Line_Break= contingent_Break}', "");
Error('\p{Is_Lb=-:=cb}');
Error('\P{Is_Lb=-:=cb}');
Expect(1, 65532, '\p{Is_Lb=cb}', "");
Expect(0, 65532, '\p{^Is_Lb=cb}', "");
Expect(0, 65532, '\P{Is_Lb=cb}', "");
Expect(1, 65532, '\P{^Is_Lb=cb}', "");
Expect(0, 65533, '\p{Is_Lb=cb}', "");
Expect(1, 65533, '\p{^Is_Lb=cb}', "");
Expect(1, 65533, '\P{Is_Lb=cb}', "");
Expect(0, 65533, '\P{^Is_Lb=cb}', "");
Expect(1, 65532, '\p{Is_Lb: _CB}', "");
Expect(0, 65532, '\p{^Is_Lb: _CB}', "");
Expect(0, 65532, '\P{Is_Lb: _CB}', "");
Expect(1, 65532, '\P{^Is_Lb: _CB}', "");
Expect(0, 65533, '\p{Is_Lb: _CB}', "");
Expect(1, 65533, '\p{^Is_Lb: _CB}', "");
Expect(1, 65533, '\P{Is_Lb: _CB}', "");
Expect(0, 65533, '\P{^Is_Lb: _CB}', "");
Error('\p{Line_Break:	/a/CONDITIONAL_Japanese_Starter}');
Error('\P{Line_Break:	/a/CONDITIONAL_Japanese_Starter}');
Expect(1, 65392, '\p{Line_Break=conditionaljapanesestarter}', "");
Expect(0, 65392, '\p{^Line_Break=conditionaljapanesestarter}', "");
Expect(0, 65392, '\P{Line_Break=conditionaljapanesestarter}', "");
Expect(1, 65392, '\P{^Line_Break=conditionaljapanesestarter}', "");
Expect(0, 65393, '\p{Line_Break=conditionaljapanesestarter}', "");
Expect(1, 65393, '\p{^Line_Break=conditionaljapanesestarter}', "");
Expect(1, 65393, '\P{Line_Break=conditionaljapanesestarter}', "");
Expect(0, 65393, '\P{^Line_Break=conditionaljapanesestarter}', "");
Expect(1, 65392, '\p{Line_Break=-	conditional_japanese_Starter}', "");
Expect(0, 65392, '\p{^Line_Break=-	conditional_japanese_Starter}', "");
Expect(0, 65392, '\P{Line_Break=-	conditional_japanese_Starter}', "");
Expect(1, 65392, '\P{^Line_Break=-	conditional_japanese_Starter}', "");
Expect(0, 65393, '\p{Line_Break=-	conditional_japanese_Starter}', "");
Expect(1, 65393, '\p{^Line_Break=-	conditional_japanese_Starter}', "");
Expect(1, 65393, '\P{Line_Break=-	conditional_japanese_Starter}', "");
Expect(0, 65393, '\P{^Line_Break=-	conditional_japanese_Starter}', "");
Error('\p{Lb=/a/		CJ}');
Error('\P{Lb=/a/		CJ}');
Expect(1, 65392, '\p{Lb=cj}', "");
Expect(0, 65392, '\p{^Lb=cj}', "");
Expect(0, 65392, '\P{Lb=cj}', "");
Expect(1, 65392, '\P{^Lb=cj}', "");
Expect(0, 65393, '\p{Lb=cj}', "");
Expect(1, 65393, '\p{^Lb=cj}', "");
Expect(1, 65393, '\P{Lb=cj}', "");
Expect(0, 65393, '\P{^Lb=cj}', "");
Expect(1, 65392, '\p{Lb= cj}', "");
Expect(0, 65392, '\p{^Lb= cj}', "");
Expect(0, 65392, '\P{Lb= cj}', "");
Expect(1, 65392, '\P{^Lb= cj}', "");
Expect(0, 65393, '\p{Lb= cj}', "");
Expect(1, 65393, '\p{^Lb= cj}', "");
Expect(1, 65393, '\P{Lb= cj}', "");
Expect(0, 65393, '\P{^Lb= cj}', "");
Error('\p{Is_Line_Break=	_Conditional_Japanese_starter/a/}');
Error('\P{Is_Line_Break=	_Conditional_Japanese_starter/a/}');
Expect(1, 65392, '\p{Is_Line_Break=conditionaljapanesestarter}', "");
Expect(0, 65392, '\p{^Is_Line_Break=conditionaljapanesestarter}', "");
Expect(0, 65392, '\P{Is_Line_Break=conditionaljapanesestarter}', "");
Expect(1, 65392, '\P{^Is_Line_Break=conditionaljapanesestarter}', "");
Expect(0, 65393, '\p{Is_Line_Break=conditionaljapanesestarter}', "");
Expect(1, 65393, '\p{^Is_Line_Break=conditionaljapanesestarter}', "");
Expect(1, 65393, '\P{Is_Line_Break=conditionaljapanesestarter}', "");
Expect(0, 65393, '\P{^Is_Line_Break=conditionaljapanesestarter}', "");
Expect(1, 65392, '\p{Is_Line_Break=__Conditional_JAPANESE_starter}', "");
Expect(0, 65392, '\p{^Is_Line_Break=__Conditional_JAPANESE_starter}', "");
Expect(0, 65392, '\P{Is_Line_Break=__Conditional_JAPANESE_starter}', "");
Expect(1, 65392, '\P{^Is_Line_Break=__Conditional_JAPANESE_starter}', "");
Expect(0, 65393, '\p{Is_Line_Break=__Conditional_JAPANESE_starter}', "");
Expect(1, 65393, '\p{^Is_Line_Break=__Conditional_JAPANESE_starter}', "");
Expect(1, 65393, '\P{Is_Line_Break=__Conditional_JAPANESE_starter}', "");
Expect(0, 65393, '\P{^Is_Line_Break=__Conditional_JAPANESE_starter}', "");
Error('\p{Is_Lb=- CJ:=}');
Error('\P{Is_Lb=- CJ:=}');
Expect(1, 65392, '\p{Is_Lb=cj}', "");
Expect(0, 65392, '\p{^Is_Lb=cj}', "");
Expect(0, 65392, '\P{Is_Lb=cj}', "");
Expect(1, 65392, '\P{^Is_Lb=cj}', "");
Expect(0, 65393, '\p{Is_Lb=cj}', "");
Expect(1, 65393, '\p{^Is_Lb=cj}', "");
Expect(1, 65393, '\P{Is_Lb=cj}', "");
Expect(0, 65393, '\P{^Is_Lb=cj}', "");
Expect(1, 65392, '\p{Is_Lb=-CJ}', "");
Expect(0, 65392, '\p{^Is_Lb=-CJ}', "");
Expect(0, 65392, '\P{Is_Lb=-CJ}', "");
Expect(1, 65392, '\P{^Is_Lb=-CJ}', "");
Expect(0, 65393, '\p{Is_Lb=-CJ}', "");
Expect(1, 65393, '\p{^Is_Lb=-CJ}', "");
Expect(1, 65393, '\P{Is_Lb=-CJ}', "");
Expect(0, 65393, '\P{^Is_Lb=-CJ}', "");
Error('\p{Line_Break:	/a/ CLOSE_Punctuation}');
Error('\P{Line_Break:	/a/ CLOSE_Punctuation}');
Expect(1, 78715, '\p{Line_Break:	closepunctuation}', "");
Expect(0, 78715, '\p{^Line_Break:	closepunctuation}', "");
Expect(0, 78715, '\P{Line_Break:	closepunctuation}', "");
Expect(1, 78715, '\P{^Line_Break:	closepunctuation}', "");
Expect(0, 78716, '\p{Line_Break:	closepunctuation}', "");
Expect(1, 78716, '\p{^Line_Break:	closepunctuation}', "");
Expect(1, 78716, '\P{Line_Break:	closepunctuation}', "");
Expect(0, 78716, '\P{^Line_Break:	closepunctuation}', "");
Expect(1, 78715, '\p{Line_Break= _Close_PUNCTUATION}', "");
Expect(0, 78715, '\p{^Line_Break= _Close_PUNCTUATION}', "");
Expect(0, 78715, '\P{Line_Break= _Close_PUNCTUATION}', "");
Expect(1, 78715, '\P{^Line_Break= _Close_PUNCTUATION}', "");
Expect(0, 78716, '\p{Line_Break= _Close_PUNCTUATION}', "");
Expect(1, 78716, '\p{^Line_Break= _Close_PUNCTUATION}', "");
Expect(1, 78716, '\P{Line_Break= _Close_PUNCTUATION}', "");
Expect(0, 78716, '\P{^Line_Break= _Close_PUNCTUATION}', "");
Error('\p{Lb= _cl/a/}');
Error('\P{Lb= _cl/a/}');
Expect(1, 78715, '\p{Lb:   cl}', "");
Expect(0, 78715, '\p{^Lb:   cl}', "");
Expect(0, 78715, '\P{Lb:   cl}', "");
Expect(1, 78715, '\P{^Lb:   cl}', "");
Expect(0, 78716, '\p{Lb:   cl}', "");
Expect(1, 78716, '\p{^Lb:   cl}', "");
Expect(1, 78716, '\P{Lb:   cl}', "");
Expect(0, 78716, '\P{^Lb:   cl}', "");
Expect(1, 78715, '\p{Lb= -CL}', "");
Expect(0, 78715, '\p{^Lb= -CL}', "");
Expect(0, 78715, '\P{Lb= -CL}', "");
Expect(1, 78715, '\P{^Lb= -CL}', "");
Expect(0, 78716, '\p{Lb= -CL}', "");
Expect(1, 78716, '\p{^Lb= -CL}', "");
Expect(1, 78716, '\P{Lb= -CL}', "");
Expect(0, 78716, '\P{^Lb= -CL}', "");
Error('\p{Is_Line_Break=:=	_close_Punctuation}');
Error('\P{Is_Line_Break=:=	_close_Punctuation}');
Expect(1, 78715, '\p{Is_Line_Break=closepunctuation}', "");
Expect(0, 78715, '\p{^Is_Line_Break=closepunctuation}', "");
Expect(0, 78715, '\P{Is_Line_Break=closepunctuation}', "");
Expect(1, 78715, '\P{^Is_Line_Break=closepunctuation}', "");
Expect(0, 78716, '\p{Is_Line_Break=closepunctuation}', "");
Expect(1, 78716, '\p{^Is_Line_Break=closepunctuation}', "");
Expect(1, 78716, '\P{Is_Line_Break=closepunctuation}', "");
Expect(0, 78716, '\P{^Is_Line_Break=closepunctuation}', "");
Expect(1, 78715, '\p{Is_Line_Break=	-Close_PUNCTUATION}', "");
Expect(0, 78715, '\p{^Is_Line_Break=	-Close_PUNCTUATION}', "");
Expect(0, 78715, '\P{Is_Line_Break=	-Close_PUNCTUATION}', "");
Expect(1, 78715, '\P{^Is_Line_Break=	-Close_PUNCTUATION}', "");
Expect(0, 78716, '\p{Is_Line_Break=	-Close_PUNCTUATION}', "");
Expect(1, 78716, '\p{^Is_Line_Break=	-Close_PUNCTUATION}', "");
Expect(1, 78716, '\P{Is_Line_Break=	-Close_PUNCTUATION}', "");
Expect(0, 78716, '\P{^Is_Line_Break=	-Close_PUNCTUATION}', "");
Error('\p{Is_Lb=/a/ CL}');
Error('\P{Is_Lb=/a/ CL}');
Expect(1, 78715, '\p{Is_Lb=cl}', "");
Expect(0, 78715, '\p{^Is_Lb=cl}', "");
Expect(0, 78715, '\P{Is_Lb=cl}', "");
Expect(1, 78715, '\P{^Is_Lb=cl}', "");
Expect(0, 78716, '\p{Is_Lb=cl}', "");
Expect(1, 78716, '\p{^Is_Lb=cl}', "");
Expect(1, 78716, '\P{Is_Lb=cl}', "");
Expect(0, 78716, '\P{^Is_Lb=cl}', "");
Expect(1, 78715, '\p{Is_Lb=_ cl}', "");
Expect(0, 78715, '\p{^Is_Lb=_ cl}', "");
Expect(0, 78715, '\P{Is_Lb=_ cl}', "");
Expect(1, 78715, '\P{^Is_Lb=_ cl}', "");
Expect(0, 78716, '\p{Is_Lb=_ cl}', "");
Expect(1, 78716, '\p{^Is_Lb=_ cl}', "");
Expect(1, 78716, '\P{Is_Lb=_ cl}', "");
Expect(0, 78716, '\P{^Is_Lb=_ cl}', "");
Error('\p{Line_Break= _Combining_Mark:=}');
Error('\P{Line_Break= _Combining_Mark:=}');
Expect(1, 917999, '\p{Line_Break=combiningmark}', "");
Expect(0, 917999, '\p{^Line_Break=combiningmark}', "");
Expect(0, 917999, '\P{Line_Break=combiningmark}', "");
Expect(1, 917999, '\P{^Line_Break=combiningmark}', "");
Expect(0, 918000, '\p{Line_Break=combiningmark}', "");
Expect(1, 918000, '\p{^Line_Break=combiningmark}', "");
Expect(1, 918000, '\P{Line_Break=combiningmark}', "");
Expect(0, 918000, '\P{^Line_Break=combiningmark}', "");
Expect(1, 917999, '\p{Line_Break:_ Combining_Mark}', "");
Expect(0, 917999, '\p{^Line_Break:_ Combining_Mark}', "");
Expect(0, 917999, '\P{Line_Break:_ Combining_Mark}', "");
Expect(1, 917999, '\P{^Line_Break:_ Combining_Mark}', "");
Expect(0, 918000, '\p{Line_Break:_ Combining_Mark}', "");
Expect(1, 918000, '\p{^Line_Break:_ Combining_Mark}', "");
Expect(1, 918000, '\P{Line_Break:_ Combining_Mark}', "");
Expect(0, 918000, '\P{^Line_Break:_ Combining_Mark}', "");
Error('\p{Lb=	CM:=}');
Error('\P{Lb=	CM:=}');
Expect(1, 917999, '\p{Lb=cm}', "");
Expect(0, 917999, '\p{^Lb=cm}', "");
Expect(0, 917999, '\P{Lb=cm}', "");
Expect(1, 917999, '\P{^Lb=cm}', "");
Expect(0, 918000, '\p{Lb=cm}', "");
Expect(1, 918000, '\p{^Lb=cm}', "");
Expect(1, 918000, '\P{Lb=cm}', "");
Expect(0, 918000, '\P{^Lb=cm}', "");
Expect(1, 917999, '\p{Lb=- CM}', "");
Expect(0, 917999, '\p{^Lb=- CM}', "");
Expect(0, 917999, '\P{Lb=- CM}', "");
Expect(1, 917999, '\P{^Lb=- CM}', "");
Expect(0, 918000, '\p{Lb=- CM}', "");
Expect(1, 918000, '\p{^Lb=- CM}', "");
Expect(1, 918000, '\P{Lb=- CM}', "");
Expect(0, 918000, '\P{^Lb=- CM}', "");
Error('\p{Is_Line_Break=:=--Combining_Mark}');
Error('\P{Is_Line_Break=:=--Combining_Mark}');
Expect(1, 917999, '\p{Is_Line_Break=combiningmark}', "");
Expect(0, 917999, '\p{^Is_Line_Break=combiningmark}', "");
Expect(0, 917999, '\P{Is_Line_Break=combiningmark}', "");
Expect(1, 917999, '\P{^Is_Line_Break=combiningmark}', "");
Expect(0, 918000, '\p{Is_Line_Break=combiningmark}', "");
Expect(1, 918000, '\p{^Is_Line_Break=combiningmark}', "");
Expect(1, 918000, '\P{Is_Line_Break=combiningmark}', "");
Expect(0, 918000, '\P{^Is_Line_Break=combiningmark}', "");
Expect(1, 917999, '\p{Is_Line_Break=_Combining_Mark}', "");
Expect(0, 917999, '\p{^Is_Line_Break=_Combining_Mark}', "");
Expect(0, 917999, '\P{Is_Line_Break=_Combining_Mark}', "");
Expect(1, 917999, '\P{^Is_Line_Break=_Combining_Mark}', "");
Expect(0, 918000, '\p{Is_Line_Break=_Combining_Mark}', "");
Expect(1, 918000, '\p{^Is_Line_Break=_Combining_Mark}', "");
Expect(1, 918000, '\P{Is_Line_Break=_Combining_Mark}', "");
Expect(0, 918000, '\P{^Is_Line_Break=_Combining_Mark}', "");
Error('\p{Is_Lb:__CM:=}');
Error('\P{Is_Lb:__CM:=}');
Expect(1, 917999, '\p{Is_Lb=cm}', "");
Expect(0, 917999, '\p{^Is_Lb=cm}', "");
Expect(0, 917999, '\P{Is_Lb=cm}', "");
Expect(1, 917999, '\P{^Is_Lb=cm}', "");
Expect(0, 918000, '\p{Is_Lb=cm}', "");
Expect(1, 918000, '\p{^Is_Lb=cm}', "");
Expect(1, 918000, '\P{Is_Lb=cm}', "");
Expect(0, 918000, '\P{^Is_Lb=cm}', "");
Expect(1, 917999, '\p{Is_Lb=_-CM}', "");
Expect(0, 917999, '\p{^Is_Lb=_-CM}', "");
Expect(0, 917999, '\P{Is_Lb=_-CM}', "");
Expect(1, 917999, '\P{^Is_Lb=_-CM}', "");
Expect(0, 918000, '\p{Is_Lb=_-CM}', "");
Expect(1, 918000, '\p{^Is_Lb=_-CM}', "");
Expect(1, 918000, '\P{Is_Lb=_-CM}', "");
Expect(0, 918000, '\P{^Is_Lb=_-CM}', "");
Error('\p{Line_Break=_:=CLOSE_Parenthesis}');
Error('\P{Line_Break=_:=CLOSE_Parenthesis}');
Expect(1, 93, '\p{Line_Break=closeparenthesis}', "");
Expect(0, 93, '\p{^Line_Break=closeparenthesis}', "");
Expect(0, 93, '\P{Line_Break=closeparenthesis}', "");
Expect(1, 93, '\P{^Line_Break=closeparenthesis}', "");
Expect(0, 94, '\p{Line_Break=closeparenthesis}', "");
Expect(1, 94, '\p{^Line_Break=closeparenthesis}', "");
Expect(1, 94, '\P{Line_Break=closeparenthesis}', "");
Expect(0, 94, '\P{^Line_Break=closeparenthesis}', "");
Expect(1, 93, '\p{Line_Break=	-Close_parenthesis}', "");
Expect(0, 93, '\p{^Line_Break=	-Close_parenthesis}', "");
Expect(0, 93, '\P{Line_Break=	-Close_parenthesis}', "");
Expect(1, 93, '\P{^Line_Break=	-Close_parenthesis}', "");
Expect(0, 94, '\p{Line_Break=	-Close_parenthesis}', "");
Expect(1, 94, '\p{^Line_Break=	-Close_parenthesis}', "");
Expect(1, 94, '\P{Line_Break=	-Close_parenthesis}', "");
Expect(0, 94, '\P{^Line_Break=	-Close_parenthesis}', "");
Error('\p{Lb=_CP:=}');
Error('\P{Lb=_CP:=}');
Expect(1, 93, '\p{Lb=cp}', "");
Expect(0, 93, '\p{^Lb=cp}', "");
Expect(0, 93, '\P{Lb=cp}', "");
Expect(1, 93, '\P{^Lb=cp}', "");
Expect(0, 94, '\p{Lb=cp}', "");
Expect(1, 94, '\p{^Lb=cp}', "");
Expect(1, 94, '\P{Lb=cp}', "");
Expect(0, 94, '\P{^Lb=cp}', "");
Expect(1, 93, '\p{Lb= 	CP}', "");
Expect(0, 93, '\p{^Lb= 	CP}', "");
Expect(0, 93, '\P{Lb= 	CP}', "");
Expect(1, 93, '\P{^Lb= 	CP}', "");
Expect(0, 94, '\p{Lb= 	CP}', "");
Expect(1, 94, '\p{^Lb= 	CP}', "");
Expect(1, 94, '\P{Lb= 	CP}', "");
Expect(0, 94, '\P{^Lb= 	CP}', "");
Error('\p{Is_Line_Break=/a/Close_PARENTHESIS}');
Error('\P{Is_Line_Break=/a/Close_PARENTHESIS}');
Expect(1, 93, '\p{Is_Line_Break=closeparenthesis}', "");
Expect(0, 93, '\p{^Is_Line_Break=closeparenthesis}', "");
Expect(0, 93, '\P{Is_Line_Break=closeparenthesis}', "");
Expect(1, 93, '\P{^Is_Line_Break=closeparenthesis}', "");
Expect(0, 94, '\p{Is_Line_Break=closeparenthesis}', "");
Expect(1, 94, '\p{^Is_Line_Break=closeparenthesis}', "");
Expect(1, 94, '\P{Is_Line_Break=closeparenthesis}', "");
Expect(0, 94, '\P{^Is_Line_Break=closeparenthesis}', "");
Expect(1, 93, '\p{Is_Line_Break= Close_parenthesis}', "");
Expect(0, 93, '\p{^Is_Line_Break= Close_parenthesis}', "");
Expect(0, 93, '\P{Is_Line_Break= Close_parenthesis}', "");
Expect(1, 93, '\P{^Is_Line_Break= Close_parenthesis}', "");
Expect(0, 94, '\p{Is_Line_Break= Close_parenthesis}', "");
Expect(1, 94, '\p{^Is_Line_Break= Close_parenthesis}', "");
Expect(1, 94, '\P{Is_Line_Break= Close_parenthesis}', "");
Expect(0, 94, '\P{^Is_Line_Break= Close_parenthesis}', "");
Error('\p{Is_Lb=- cp/a/}');
Error('\P{Is_Lb=- cp/a/}');
Expect(1, 93, '\p{Is_Lb=cp}', "");
Expect(0, 93, '\p{^Is_Lb=cp}', "");
Expect(0, 93, '\P{Is_Lb=cp}', "");
Expect(1, 93, '\P{^Is_Lb=cp}', "");
Expect(0, 94, '\p{Is_Lb=cp}', "");
Expect(1, 94, '\p{^Is_Lb=cp}', "");
Expect(1, 94, '\P{Is_Lb=cp}', "");
Expect(0, 94, '\P{^Is_Lb=cp}', "");
Expect(1, 93, '\p{Is_Lb= 	CP}', "");
Expect(0, 93, '\p{^Is_Lb= 	CP}', "");
Expect(0, 93, '\P{Is_Lb= 	CP}', "");
Expect(1, 93, '\P{^Is_Lb= 	CP}', "");
Expect(0, 94, '\p{Is_Lb= 	CP}', "");
Expect(1, 94, '\p{^Is_Lb= 	CP}', "");
Expect(1, 94, '\P{Is_Lb= 	CP}', "");
Expect(0, 94, '\P{^Is_Lb= 	CP}', "");
Error('\p{Line_Break=_/a/CARRIAGE_RETURN}');
Error('\P{Line_Break=_/a/CARRIAGE_RETURN}');
Expect(1, 13, '\p{Line_Break=carriagereturn}', "");
Expect(0, 13, '\p{^Line_Break=carriagereturn}', "");
Expect(0, 13, '\P{Line_Break=carriagereturn}', "");
Expect(1, 13, '\P{^Line_Break=carriagereturn}', "");
Expect(0, 14, '\p{Line_Break=carriagereturn}', "");
Expect(1, 14, '\p{^Line_Break=carriagereturn}', "");
Expect(1, 14, '\P{Line_Break=carriagereturn}', "");
Expect(0, 14, '\P{^Line_Break=carriagereturn}', "");
Expect(1, 13, '\p{Line_Break=	-carriage_return}', "");
Expect(0, 13, '\p{^Line_Break=	-carriage_return}', "");
Expect(0, 13, '\P{Line_Break=	-carriage_return}', "");
Expect(1, 13, '\P{^Line_Break=	-carriage_return}', "");
Expect(0, 14, '\p{Line_Break=	-carriage_return}', "");
Expect(1, 14, '\p{^Line_Break=	-carriage_return}', "");
Expect(1, 14, '\P{Line_Break=	-carriage_return}', "");
Expect(0, 14, '\P{^Line_Break=	-carriage_return}', "");
Error('\p{Lb=/a/-cr}');
Error('\P{Lb=/a/-cr}');
Expect(1, 13, '\p{Lb=cr}', "");
Expect(0, 13, '\p{^Lb=cr}', "");
Expect(0, 13, '\P{Lb=cr}', "");
Expect(1, 13, '\P{^Lb=cr}', "");
Expect(0, 14, '\p{Lb=cr}', "");
Expect(1, 14, '\p{^Lb=cr}', "");
Expect(1, 14, '\P{Lb=cr}', "");
Expect(0, 14, '\P{^Lb=cr}', "");
Expect(1, 13, '\p{Lb=_	cr}', "");
Expect(0, 13, '\p{^Lb=_	cr}', "");
Expect(0, 13, '\P{Lb=_	cr}', "");
Expect(1, 13, '\P{^Lb=_	cr}', "");
Expect(0, 14, '\p{Lb=_	cr}', "");
Expect(1, 14, '\p{^Lb=_	cr}', "");
Expect(1, 14, '\P{Lb=_	cr}', "");
Expect(0, 14, '\P{^Lb=_	cr}', "");
Error('\p{Is_Line_Break=/a/_	carriage_Return}');
Error('\P{Is_Line_Break=/a/_	carriage_Return}');
Expect(1, 13, '\p{Is_Line_Break=carriagereturn}', "");
Expect(0, 13, '\p{^Is_Line_Break=carriagereturn}', "");
Expect(0, 13, '\P{Is_Line_Break=carriagereturn}', "");
Expect(1, 13, '\P{^Is_Line_Break=carriagereturn}', "");
Expect(0, 14, '\p{Is_Line_Break=carriagereturn}', "");
Expect(1, 14, '\p{^Is_Line_Break=carriagereturn}', "");
Expect(1, 14, '\P{Is_Line_Break=carriagereturn}', "");
Expect(0, 14, '\P{^Is_Line_Break=carriagereturn}', "");
Expect(1, 13, '\p{Is_Line_Break=_	Carriage_return}', "");
Expect(0, 13, '\p{^Is_Line_Break=_	Carriage_return}', "");
Expect(0, 13, '\P{Is_Line_Break=_	Carriage_return}', "");
Expect(1, 13, '\P{^Is_Line_Break=_	Carriage_return}', "");
Expect(0, 14, '\p{Is_Line_Break=_	Carriage_return}', "");
Expect(1, 14, '\p{^Is_Line_Break=_	Carriage_return}', "");
Expect(1, 14, '\P{Is_Line_Break=_	Carriage_return}', "");
Expect(0, 14, '\P{^Is_Line_Break=_	Carriage_return}', "");
Error('\p{Is_Lb=/a/ CR}');
Error('\P{Is_Lb=/a/ CR}');
Expect(1, 13, '\p{Is_Lb=cr}', "");
Expect(0, 13, '\p{^Is_Lb=cr}', "");
Expect(0, 13, '\P{Is_Lb=cr}', "");
Expect(1, 13, '\P{^Is_Lb=cr}', "");
Expect(0, 14, '\p{Is_Lb=cr}', "");
Expect(1, 14, '\p{^Is_Lb=cr}', "");
Expect(1, 14, '\P{Is_Lb=cr}', "");
Expect(0, 14, '\P{^Is_Lb=cr}', "");
Expect(1, 13, '\p{Is_Lb= _cr}', "");
Expect(0, 13, '\p{^Is_Lb= _cr}', "");
Expect(0, 13, '\P{Is_Lb= _cr}', "");
Expect(1, 13, '\P{^Is_Lb= _cr}', "");
Expect(0, 14, '\p{Is_Lb= _cr}', "");
Expect(1, 14, '\p{^Is_Lb= _cr}', "");
Expect(1, 14, '\P{Is_Lb= _cr}', "");
Expect(0, 14, '\P{^Is_Lb= _cr}', "");
Error('\p{Line_Break=/a/  Exclamation}');
Error('\P{Line_Break=/a/  Exclamation}');
Expect(1, 65311, '\p{Line_Break=exclamation}', "");
Expect(0, 65311, '\p{^Line_Break=exclamation}', "");
Expect(0, 65311, '\P{Line_Break=exclamation}', "");
Expect(1, 65311, '\P{^Line_Break=exclamation}', "");
Expect(0, 65312, '\p{Line_Break=exclamation}', "");
Expect(1, 65312, '\p{^Line_Break=exclamation}', "");
Expect(1, 65312, '\P{Line_Break=exclamation}', "");
Expect(0, 65312, '\P{^Line_Break=exclamation}', "");
Expect(1, 65311, '\p{Line_Break= 	EXCLAMATION}', "");
Expect(0, 65311, '\p{^Line_Break= 	EXCLAMATION}', "");
Expect(0, 65311, '\P{Line_Break= 	EXCLAMATION}', "");
Expect(1, 65311, '\P{^Line_Break= 	EXCLAMATION}', "");
Expect(0, 65312, '\p{Line_Break= 	EXCLAMATION}', "");
Expect(1, 65312, '\p{^Line_Break= 	EXCLAMATION}', "");
Expect(1, 65312, '\P{Line_Break= 	EXCLAMATION}', "");
Expect(0, 65312, '\P{^Line_Break= 	EXCLAMATION}', "");
Error('\p{Lb=	/a/EX}');
Error('\P{Lb=	/a/EX}');
Expect(1, 65311, '\p{Lb:ex}', "");
Expect(0, 65311, '\p{^Lb:ex}', "");
Expect(0, 65311, '\P{Lb:ex}', "");
Expect(1, 65311, '\P{^Lb:ex}', "");
Expect(0, 65312, '\p{Lb:ex}', "");
Expect(1, 65312, '\p{^Lb:ex}', "");
Expect(1, 65312, '\P{Lb:ex}', "");
Expect(0, 65312, '\P{^Lb:ex}', "");
Expect(1, 65311, '\p{Lb= -EX}', "");
Expect(0, 65311, '\p{^Lb= -EX}', "");
Expect(0, 65311, '\P{Lb= -EX}', "");
Expect(1, 65311, '\P{^Lb= -EX}', "");
Expect(0, 65312, '\p{Lb= -EX}', "");
Expect(1, 65312, '\p{^Lb= -EX}', "");
Expect(1, 65312, '\P{Lb= -EX}', "");
Expect(0, 65312, '\P{^Lb= -EX}', "");
Error('\p{Is_Line_Break= _EXCLAMATION:=}');
Error('\P{Is_Line_Break= _EXCLAMATION:=}');
Expect(1, 65311, '\p{Is_Line_Break=exclamation}', "");
Expect(0, 65311, '\p{^Is_Line_Break=exclamation}', "");
Expect(0, 65311, '\P{Is_Line_Break=exclamation}', "");
Expect(1, 65311, '\P{^Is_Line_Break=exclamation}', "");
Expect(0, 65312, '\p{Is_Line_Break=exclamation}', "");
Expect(1, 65312, '\p{^Is_Line_Break=exclamation}', "");
Expect(1, 65312, '\P{Is_Line_Break=exclamation}', "");
Expect(0, 65312, '\P{^Is_Line_Break=exclamation}', "");
Expect(1, 65311, '\p{Is_Line_Break=__Exclamation}', "");
Expect(0, 65311, '\p{^Is_Line_Break=__Exclamation}', "");
Expect(0, 65311, '\P{Is_Line_Break=__Exclamation}', "");
Expect(1, 65311, '\P{^Is_Line_Break=__Exclamation}', "");
Expect(0, 65312, '\p{Is_Line_Break=__Exclamation}', "");
Expect(1, 65312, '\p{^Is_Line_Break=__Exclamation}', "");
Expect(1, 65312, '\P{Is_Line_Break=__Exclamation}', "");
Expect(0, 65312, '\P{^Is_Line_Break=__Exclamation}', "");
Error('\p{Is_Lb=/a/_	EX}');
Error('\P{Is_Lb=/a/_	EX}');
Expect(1, 65311, '\p{Is_Lb:   ex}', "");
Expect(0, 65311, '\p{^Is_Lb:   ex}', "");
Expect(0, 65311, '\P{Is_Lb:   ex}', "");
Expect(1, 65311, '\P{^Is_Lb:   ex}', "");
Expect(0, 65312, '\p{Is_Lb:   ex}', "");
Expect(1, 65312, '\p{^Is_Lb:   ex}', "");
Expect(1, 65312, '\P{Is_Lb:   ex}', "");
Expect(0, 65312, '\P{^Is_Lb:   ex}', "");
Expect(1, 65311, '\p{Is_Lb=_ex}', "");
Expect(0, 65311, '\p{^Is_Lb=_ex}', "");
Expect(0, 65311, '\P{Is_Lb=_ex}', "");
Expect(1, 65311, '\P{^Is_Lb=_ex}', "");
Expect(0, 65312, '\p{Is_Lb=_ex}', "");
Expect(1, 65312, '\p{^Is_Lb=_ex}', "");
Expect(1, 65312, '\P{Is_Lb=_ex}', "");
Expect(0, 65312, '\P{^Is_Lb=_ex}', "");
Error('\p{Line_Break=/a/	 Glue}');
Error('\P{Line_Break=/a/	 Glue}');
Expect(1, 8239, '\p{Line_Break=glue}', "");
Expect(0, 8239, '\p{^Line_Break=glue}', "");
Expect(0, 8239, '\P{Line_Break=glue}', "");
Expect(1, 8239, '\P{^Line_Break=glue}', "");
Expect(0, 8240, '\p{Line_Break=glue}', "");
Expect(1, 8240, '\p{^Line_Break=glue}', "");
Expect(1, 8240, '\P{Line_Break=glue}', "");
Expect(0, 8240, '\P{^Line_Break=glue}', "");
Expect(1, 8239, '\p{Line_Break=	_GLUE}', "");
Expect(0, 8239, '\p{^Line_Break=	_GLUE}', "");
Expect(0, 8239, '\P{Line_Break=	_GLUE}', "");
Expect(1, 8239, '\P{^Line_Break=	_GLUE}', "");
Expect(0, 8240, '\p{Line_Break=	_GLUE}', "");
Expect(1, 8240, '\p{^Line_Break=	_GLUE}', "");
Expect(1, 8240, '\P{Line_Break=	_GLUE}', "");
Expect(0, 8240, '\P{^Line_Break=	_GLUE}', "");
Error('\p{Lb=_:=GL}');
Error('\P{Lb=_:=GL}');
Expect(1, 8239, '\p{Lb=gl}', "");
Expect(0, 8239, '\p{^Lb=gl}', "");
Expect(0, 8239, '\P{Lb=gl}', "");
Expect(1, 8239, '\P{^Lb=gl}', "");
Expect(0, 8240, '\p{Lb=gl}', "");
Expect(1, 8240, '\p{^Lb=gl}', "");
Expect(1, 8240, '\P{Lb=gl}', "");
Expect(0, 8240, '\P{^Lb=gl}', "");
Expect(1, 8239, '\p{Lb=--gl}', "");
Expect(0, 8239, '\p{^Lb=--gl}', "");
Expect(0, 8239, '\P{Lb=--gl}', "");
Expect(1, 8239, '\P{^Lb=--gl}', "");
Expect(0, 8240, '\p{Lb=--gl}', "");
Expect(1, 8240, '\p{^Lb=--gl}', "");
Expect(1, 8240, '\P{Lb=--gl}', "");
Expect(0, 8240, '\P{^Lb=--gl}', "");
Error('\p{Is_Line_Break=-/a/GLUE}');
Error('\P{Is_Line_Break=-/a/GLUE}');
Expect(1, 8239, '\p{Is_Line_Break=glue}', "");
Expect(0, 8239, '\p{^Is_Line_Break=glue}', "");
Expect(0, 8239, '\P{Is_Line_Break=glue}', "");
Expect(1, 8239, '\P{^Is_Line_Break=glue}', "");
Expect(0, 8240, '\p{Is_Line_Break=glue}', "");
Expect(1, 8240, '\p{^Is_Line_Break=glue}', "");
Expect(1, 8240, '\P{Is_Line_Break=glue}', "");
Expect(0, 8240, '\P{^Is_Line_Break=glue}', "");
Expect(1, 8239, '\p{Is_Line_Break=  glue}', "");
Expect(0, 8239, '\p{^Is_Line_Break=  glue}', "");
Expect(0, 8239, '\P{Is_Line_Break=  glue}', "");
Expect(1, 8239, '\P{^Is_Line_Break=  glue}', "");
Expect(0, 8240, '\p{Is_Line_Break=  glue}', "");
Expect(1, 8240, '\p{^Is_Line_Break=  glue}', "");
Expect(1, 8240, '\P{Is_Line_Break=  glue}', "");
Expect(0, 8240, '\P{^Is_Line_Break=  glue}', "");
Error('\p{Is_Lb= GL:=}');
Error('\P{Is_Lb= GL:=}');
Expect(1, 8239, '\p{Is_Lb=gl}', "");
Expect(0, 8239, '\p{^Is_Lb=gl}', "");
Expect(0, 8239, '\P{Is_Lb=gl}', "");
Expect(1, 8239, '\P{^Is_Lb=gl}', "");
Expect(0, 8240, '\p{Is_Lb=gl}', "");
Expect(1, 8240, '\p{^Is_Lb=gl}', "");
Expect(1, 8240, '\P{Is_Lb=gl}', "");
Expect(0, 8240, '\P{^Is_Lb=gl}', "");
Expect(1, 8239, '\p{Is_Lb=	-gl}', "");
Expect(0, 8239, '\p{^Is_Lb=	-gl}', "");
Expect(0, 8239, '\P{Is_Lb=	-gl}', "");
Expect(1, 8239, '\P{^Is_Lb=	-gl}', "");
Expect(0, 8240, '\p{Is_Lb=	-gl}', "");
Expect(1, 8240, '\p{^Is_Lb=	-gl}', "");
Expect(1, 8240, '\P{Is_Lb=	-gl}', "");
Expect(0, 8240, '\P{^Is_Lb=	-gl}', "");
Error('\p{Line_Break: -:=h2}');
Error('\P{Line_Break: -:=h2}');
Expect(1, 55176, '\p{Line_Break=h2}', "");
Expect(0, 55176, '\p{^Line_Break=h2}', "");
Expect(0, 55176, '\P{Line_Break=h2}', "");
Expect(1, 55176, '\P{^Line_Break=h2}', "");
Expect(0, 55177, '\p{Line_Break=h2}', "");
Expect(1, 55177, '\p{^Line_Break=h2}', "");
Expect(1, 55177, '\P{Line_Break=h2}', "");
Expect(0, 55177, '\P{^Line_Break=h2}', "");
Expect(1, 55176, '\p{Line_Break= _H2}', "");
Expect(0, 55176, '\p{^Line_Break= _H2}', "");
Expect(0, 55176, '\P{Line_Break= _H2}', "");
Expect(1, 55176, '\P{^Line_Break= _H2}', "");
Expect(0, 55177, '\p{Line_Break= _H2}', "");
Expect(1, 55177, '\p{^Line_Break= _H2}', "");
Expect(1, 55177, '\P{Line_Break= _H2}', "");
Expect(0, 55177, '\P{^Line_Break= _H2}', "");
Error('\p{Lb= H2:=}');
Error('\P{Lb= H2:=}');
Expect(1, 55176, '\p{Lb=h2}', "");
Expect(0, 55176, '\p{^Lb=h2}', "");
Expect(0, 55176, '\P{Lb=h2}', "");
Expect(1, 55176, '\P{^Lb=h2}', "");
Expect(0, 55177, '\p{Lb=h2}', "");
Expect(1, 55177, '\p{^Lb=h2}', "");
Expect(1, 55177, '\P{Lb=h2}', "");
Expect(0, 55177, '\P{^Lb=h2}', "");
Expect(1, 55176, '\p{Lb=	h2}', "");
Expect(0, 55176, '\p{^Lb=	h2}', "");
Expect(0, 55176, '\P{Lb=	h2}', "");
Expect(1, 55176, '\P{^Lb=	h2}', "");
Expect(0, 55177, '\p{Lb=	h2}', "");
Expect(1, 55177, '\p{^Lb=	h2}', "");
Expect(1, 55177, '\P{Lb=	h2}', "");
Expect(0, 55177, '\P{^Lb=	h2}', "");
Error('\p{Is_Line_Break=:=h2}');
Error('\P{Is_Line_Break=:=h2}');
Expect(1, 55176, '\p{Is_Line_Break:   h2}', "");
Expect(0, 55176, '\p{^Is_Line_Break:   h2}', "");
Expect(0, 55176, '\P{Is_Line_Break:   h2}', "");
Expect(1, 55176, '\P{^Is_Line_Break:   h2}', "");
Expect(0, 55177, '\p{Is_Line_Break:   h2}', "");
Expect(1, 55177, '\p{^Is_Line_Break:   h2}', "");
Expect(1, 55177, '\P{Is_Line_Break:   h2}', "");
Expect(0, 55177, '\P{^Is_Line_Break:   h2}', "");
Expect(1, 55176, '\p{Is_Line_Break:	 h2}', "");
Expect(0, 55176, '\p{^Is_Line_Break:	 h2}', "");
Expect(0, 55176, '\P{Is_Line_Break:	 h2}', "");
Expect(1, 55176, '\P{^Is_Line_Break:	 h2}', "");
Expect(0, 55177, '\p{Is_Line_Break:	 h2}', "");
Expect(1, 55177, '\p{^Is_Line_Break:	 h2}', "");
Expect(1, 55177, '\P{Is_Line_Break:	 h2}', "");
Expect(0, 55177, '\P{^Is_Line_Break:	 h2}', "");
Error('\p{Is_Lb=/a/ 	H2}');
Error('\P{Is_Lb=/a/ 	H2}');
Expect(1, 55176, '\p{Is_Lb: h2}', "");
Expect(0, 55176, '\p{^Is_Lb: h2}', "");
Expect(0, 55176, '\P{Is_Lb: h2}', "");
Expect(1, 55176, '\P{^Is_Lb: h2}', "");
Expect(0, 55177, '\p{Is_Lb: h2}', "");
Expect(1, 55177, '\p{^Is_Lb: h2}', "");
Expect(1, 55177, '\P{Is_Lb: h2}', "");
Expect(0, 55177, '\P{^Is_Lb: h2}', "");
Expect(1, 55176, '\p{Is_Lb:	- H2}', "");
Expect(0, 55176, '\p{^Is_Lb:	- H2}', "");
Expect(0, 55176, '\P{Is_Lb:	- H2}', "");
Expect(1, 55176, '\P{^Is_Lb:	- H2}', "");
Expect(0, 55177, '\p{Is_Lb:	- H2}', "");
Expect(1, 55177, '\p{^Is_Lb:	- H2}', "");
Expect(1, 55177, '\P{Is_Lb:	- H2}', "");
Expect(0, 55177, '\P{^Is_Lb:	- H2}', "");
Error('\p{Line_Break=:=_	h3}');
Error('\P{Line_Break=:=_	h3}');
Expect(1, 55203, '\p{Line_Break=h3}', "");
Expect(0, 55203, '\p{^Line_Break=h3}', "");
Expect(0, 55203, '\P{Line_Break=h3}', "");
Expect(1, 55203, '\P{^Line_Break=h3}', "");
Expect(0, 55204, '\p{Line_Break=h3}', "");
Expect(1, 55204, '\p{^Line_Break=h3}', "");
Expect(1, 55204, '\P{Line_Break=h3}', "");
Expect(0, 55204, '\P{^Line_Break=h3}', "");
Expect(1, 55203, '\p{Line_Break:	 	H3}', "");
Expect(0, 55203, '\p{^Line_Break:	 	H3}', "");
Expect(0, 55203, '\P{Line_Break:	 	H3}', "");
Expect(1, 55203, '\P{^Line_Break:	 	H3}', "");
Expect(0, 55204, '\p{Line_Break:	 	H3}', "");
Expect(1, 55204, '\p{^Line_Break:	 	H3}', "");
Expect(1, 55204, '\P{Line_Break:	 	H3}', "");
Expect(0, 55204, '\P{^Line_Break:	 	H3}', "");
Error('\p{Lb=:=--H3}');
Error('\P{Lb=:=--H3}');
Expect(1, 55203, '\p{Lb:	h3}', "");
Expect(0, 55203, '\p{^Lb:	h3}', "");
Expect(0, 55203, '\P{Lb:	h3}', "");
Expect(1, 55203, '\P{^Lb:	h3}', "");
Expect(0, 55204, '\p{Lb:	h3}', "");
Expect(1, 55204, '\p{^Lb:	h3}', "");
Expect(1, 55204, '\P{Lb:	h3}', "");
Expect(0, 55204, '\P{^Lb:	h3}', "");
Expect(1, 55203, '\p{Lb=-	H3}', "");
Expect(0, 55203, '\p{^Lb=-	H3}', "");
Expect(0, 55203, '\P{Lb=-	H3}', "");
Expect(1, 55203, '\P{^Lb=-	H3}', "");
Expect(0, 55204, '\p{Lb=-	H3}', "");
Expect(1, 55204, '\p{^Lb=-	H3}', "");
Expect(1, 55204, '\P{Lb=-	H3}', "");
Expect(0, 55204, '\P{^Lb=-	H3}', "");
Error('\p{Is_Line_Break=:=_	H3}');
Error('\P{Is_Line_Break=:=_	H3}');
Expect(1, 55203, '\p{Is_Line_Break: h3}', "");
Expect(0, 55203, '\p{^Is_Line_Break: h3}', "");
Expect(0, 55203, '\P{Is_Line_Break: h3}', "");
Expect(1, 55203, '\P{^Is_Line_Break: h3}', "");
Expect(0, 55204, '\p{Is_Line_Break: h3}', "");
Expect(1, 55204, '\p{^Is_Line_Break: h3}', "");
Expect(1, 55204, '\P{Is_Line_Break: h3}', "");
Expect(0, 55204, '\P{^Is_Line_Break: h3}', "");
Expect(1, 55203, '\p{Is_Line_Break= H3}', "");
Expect(0, 55203, '\p{^Is_Line_Break= H3}', "");
Expect(0, 55203, '\P{Is_Line_Break= H3}', "");
Expect(1, 55203, '\P{^Is_Line_Break= H3}', "");
Expect(0, 55204, '\p{Is_Line_Break= H3}', "");
Expect(1, 55204, '\p{^Is_Line_Break= H3}', "");
Expect(1, 55204, '\P{Is_Line_Break= H3}', "");
Expect(0, 55204, '\P{^Is_Line_Break= H3}', "");
Error('\p{Is_Lb=:=-h3}');
Error('\P{Is_Lb=:=-h3}');
Expect(1, 55203, '\p{Is_Lb=h3}', "");
Expect(0, 55203, '\p{^Is_Lb=h3}', "");
Expect(0, 55203, '\P{Is_Lb=h3}', "");
Expect(1, 55203, '\P{^Is_Lb=h3}', "");
Expect(0, 55204, '\p{Is_Lb=h3}', "");
Expect(1, 55204, '\p{^Is_Lb=h3}', "");
Expect(1, 55204, '\P{Is_Lb=h3}', "");
Expect(0, 55204, '\P{^Is_Lb=h3}', "");
Expect(1, 55203, '\p{Is_Lb=	-H3}', "");
Expect(0, 55203, '\p{^Is_Lb=	-H3}', "");
Expect(0, 55203, '\P{Is_Lb=	-H3}', "");
Expect(1, 55203, '\P{^Is_Lb=	-H3}', "");
Expect(0, 55204, '\p{Is_Lb=	-H3}', "");
Expect(1, 55204, '\p{^Is_Lb=	-H3}', "");
Expect(1, 55204, '\P{Is_Lb=	-H3}', "");
Expect(0, 55204, '\P{^Is_Lb=	-H3}', "");
Error('\p{Line_Break:   	/a/HEBREW_Letter}');
Error('\P{Line_Break:   	/a/HEBREW_Letter}');
Expect(1, 64335, '\p{Line_Break=hebrewletter}', "");
Expect(0, 64335, '\p{^Line_Break=hebrewletter}', "");
Expect(0, 64335, '\P{Line_Break=hebrewletter}', "");
Expect(1, 64335, '\P{^Line_Break=hebrewletter}', "");
Expect(0, 64336, '\p{Line_Break=hebrewletter}', "");
Expect(1, 64336, '\p{^Line_Break=hebrewletter}', "");
Expect(1, 64336, '\P{Line_Break=hebrewletter}', "");
Expect(0, 64336, '\P{^Line_Break=hebrewletter}', "");
Expect(1, 64335, '\p{Line_Break:   	 Hebrew_letter}', "");
Expect(0, 64335, '\p{^Line_Break:   	 Hebrew_letter}', "");
Expect(0, 64335, '\P{Line_Break:   	 Hebrew_letter}', "");
Expect(1, 64335, '\P{^Line_Break:   	 Hebrew_letter}', "");
Expect(0, 64336, '\p{Line_Break:   	 Hebrew_letter}', "");
Expect(1, 64336, '\p{^Line_Break:   	 Hebrew_letter}', "");
Expect(1, 64336, '\P{Line_Break:   	 Hebrew_letter}', "");
Expect(0, 64336, '\P{^Line_Break:   	 Hebrew_letter}', "");
Error('\p{Lb=:=	HL}');
Error('\P{Lb=:=	HL}');
Expect(1, 64335, '\p{Lb=hl}', "");
Expect(0, 64335, '\p{^Lb=hl}', "");
Expect(0, 64335, '\P{Lb=hl}', "");
Expect(1, 64335, '\P{^Lb=hl}', "");
Expect(0, 64336, '\p{Lb=hl}', "");
Expect(1, 64336, '\p{^Lb=hl}', "");
Expect(1, 64336, '\P{Lb=hl}', "");
Expect(0, 64336, '\P{^Lb=hl}', "");
Expect(1, 64335, '\p{Lb= -HL}', "");
Expect(0, 64335, '\p{^Lb= -HL}', "");
Expect(0, 64335, '\P{Lb= -HL}', "");
Expect(1, 64335, '\P{^Lb= -HL}', "");
Expect(0, 64336, '\p{Lb= -HL}', "");
Expect(1, 64336, '\p{^Lb= -HL}', "");
Expect(1, 64336, '\P{Lb= -HL}', "");
Expect(0, 64336, '\P{^Lb= -HL}', "");
Error('\p{Is_Line_Break=_ Hebrew_LETTER:=}');
Error('\P{Is_Line_Break=_ Hebrew_LETTER:=}');
Expect(1, 64335, '\p{Is_Line_Break=hebrewletter}', "");
Expect(0, 64335, '\p{^Is_Line_Break=hebrewletter}', "");
Expect(0, 64335, '\P{Is_Line_Break=hebrewletter}', "");
Expect(1, 64335, '\P{^Is_Line_Break=hebrewletter}', "");
Expect(0, 64336, '\p{Is_Line_Break=hebrewletter}', "");
Expect(1, 64336, '\p{^Is_Line_Break=hebrewletter}', "");
Expect(1, 64336, '\P{Is_Line_Break=hebrewletter}', "");
Expect(0, 64336, '\P{^Is_Line_Break=hebrewletter}', "");
Expect(1, 64335, '\p{Is_Line_Break=	_HEBREW_Letter}', "");
Expect(0, 64335, '\p{^Is_Line_Break=	_HEBREW_Letter}', "");
Expect(0, 64335, '\P{Is_Line_Break=	_HEBREW_Letter}', "");
Expect(1, 64335, '\P{^Is_Line_Break=	_HEBREW_Letter}', "");
Expect(0, 64336, '\p{Is_Line_Break=	_HEBREW_Letter}', "");
Expect(1, 64336, '\p{^Is_Line_Break=	_HEBREW_Letter}', "");
Expect(1, 64336, '\P{Is_Line_Break=	_HEBREW_Letter}', "");
Expect(0, 64336, '\P{^Is_Line_Break=	_HEBREW_Letter}', "");
Error('\p{Is_Lb=--HL:=}');
Error('\P{Is_Lb=--HL:=}');
Expect(1, 64335, '\p{Is_Lb=hl}', "");
Expect(0, 64335, '\p{^Is_Lb=hl}', "");
Expect(0, 64335, '\P{Is_Lb=hl}', "");
Expect(1, 64335, '\P{^Is_Lb=hl}', "");
Expect(0, 64336, '\p{Is_Lb=hl}', "");
Expect(1, 64336, '\p{^Is_Lb=hl}', "");
Expect(1, 64336, '\P{Is_Lb=hl}', "");
Expect(0, 64336, '\P{^Is_Lb=hl}', "");
Expect(1, 64335, '\p{Is_Lb= HL}', "");
Expect(0, 64335, '\p{^Is_Lb= HL}', "");
Expect(0, 64335, '\P{Is_Lb= HL}', "");
Expect(1, 64335, '\P{^Is_Lb= HL}', "");
Expect(0, 64336, '\p{Is_Lb= HL}', "");
Expect(1, 64336, '\p{^Is_Lb= HL}', "");
Expect(1, 64336, '\P{Is_Lb= HL}', "");
Expect(0, 64336, '\P{^Is_Lb= HL}', "");
Error('\p{Line_Break=:=Hyphen}');
Error('\P{Line_Break=:=Hyphen}');
Expect(1, 45, '\p{Line_Break=hyphen}', "");
Expect(0, 45, '\p{^Line_Break=hyphen}', "");
Expect(0, 45, '\P{Line_Break=hyphen}', "");
Expect(1, 45, '\P{^Line_Break=hyphen}', "");
Expect(0, 46, '\p{Line_Break=hyphen}', "");
Expect(1, 46, '\p{^Line_Break=hyphen}', "");
Expect(1, 46, '\P{Line_Break=hyphen}', "");
Expect(0, 46, '\P{^Line_Break=hyphen}', "");
Expect(1, 45, '\p{Line_Break=_ Hyphen}', "");
Expect(0, 45, '\p{^Line_Break=_ Hyphen}', "");
Expect(0, 45, '\P{Line_Break=_ Hyphen}', "");
Expect(1, 45, '\P{^Line_Break=_ Hyphen}', "");
Expect(0, 46, '\p{Line_Break=_ Hyphen}', "");
Expect(1, 46, '\p{^Line_Break=_ Hyphen}', "");
Expect(1, 46, '\P{Line_Break=_ Hyphen}', "");
Expect(0, 46, '\P{^Line_Break=_ Hyphen}', "");
Error('\p{Lb=	HY:=}');
Error('\P{Lb=	HY:=}');
Expect(1, 45, '\p{Lb=hy}', "");
Expect(0, 45, '\p{^Lb=hy}', "");
Expect(0, 45, '\P{Lb=hy}', "");
Expect(1, 45, '\P{^Lb=hy}', "");
Expect(0, 46, '\p{Lb=hy}', "");
Expect(1, 46, '\p{^Lb=hy}', "");
Expect(1, 46, '\P{Lb=hy}', "");
Expect(0, 46, '\P{^Lb=hy}', "");
Expect(1, 45, '\p{Lb=_hy}', "");
Expect(0, 45, '\p{^Lb=_hy}', "");
Expect(0, 45, '\P{Lb=_hy}', "");
Expect(1, 45, '\P{^Lb=_hy}', "");
Expect(0, 46, '\p{Lb=_hy}', "");
Expect(1, 46, '\p{^Lb=_hy}', "");
Expect(1, 46, '\P{Lb=_hy}', "");
Expect(0, 46, '\P{^Lb=_hy}', "");
Error('\p{Is_Line_Break=/a/_-Hyphen}');
Error('\P{Is_Line_Break=/a/_-Hyphen}');
Expect(1, 45, '\p{Is_Line_Break=hyphen}', "");
Expect(0, 45, '\p{^Is_Line_Break=hyphen}', "");
Expect(0, 45, '\P{Is_Line_Break=hyphen}', "");
Expect(1, 45, '\P{^Is_Line_Break=hyphen}', "");
Expect(0, 46, '\p{Is_Line_Break=hyphen}', "");
Expect(1, 46, '\p{^Is_Line_Break=hyphen}', "");
Expect(1, 46, '\P{Is_Line_Break=hyphen}', "");
Expect(0, 46, '\P{^Is_Line_Break=hyphen}', "");
Expect(1, 45, '\p{Is_Line_Break=		Hyphen}', "");
Expect(0, 45, '\p{^Is_Line_Break=		Hyphen}', "");
Expect(0, 45, '\P{Is_Line_Break=		Hyphen}', "");
Expect(1, 45, '\P{^Is_Line_Break=		Hyphen}', "");
Expect(0, 46, '\p{Is_Line_Break=		Hyphen}', "");
Expect(1, 46, '\p{^Is_Line_Break=		Hyphen}', "");
Expect(1, 46, '\P{Is_Line_Break=		Hyphen}', "");
Expect(0, 46, '\P{^Is_Line_Break=		Hyphen}', "");
Error('\p{Is_Lb=	:=HY}');
Error('\P{Is_Lb=	:=HY}');
Expect(1, 45, '\p{Is_Lb=hy}', "");
Expect(0, 45, '\p{^Is_Lb=hy}', "");
Expect(0, 45, '\P{Is_Lb=hy}', "");
Expect(1, 45, '\P{^Is_Lb=hy}', "");
Expect(0, 46, '\p{Is_Lb=hy}', "");
Expect(1, 46, '\p{^Is_Lb=hy}', "");
Expect(1, 46, '\P{Is_Lb=hy}', "");
Expect(0, 46, '\P{^Is_Lb=hy}', "");
Expect(1, 45, '\p{Is_Lb= 	HY}', "");
Expect(0, 45, '\p{^Is_Lb= 	HY}', "");
Expect(0, 45, '\P{Is_Lb= 	HY}', "");
Expect(1, 45, '\P{^Is_Lb= 	HY}', "");
Expect(0, 46, '\p{Is_Lb= 	HY}', "");
Expect(1, 46, '\p{^Is_Lb= 	HY}', "");
Expect(1, 46, '\P{Is_Lb= 	HY}', "");
Expect(0, 46, '\P{^Is_Lb= 	HY}', "");
Error('\p{Line_Break=_/a/Ideographic}');
Error('\P{Line_Break=_/a/Ideographic}');
Expect(1, 262141, '\p{Line_Break=ideographic}', "");
Expect(0, 262141, '\p{^Line_Break=ideographic}', "");
Expect(0, 262141, '\P{Line_Break=ideographic}', "");
Expect(1, 262141, '\P{^Line_Break=ideographic}', "");
Expect(0, 262144, '\p{Line_Break=ideographic}', "");
Expect(1, 262144, '\p{^Line_Break=ideographic}', "");
Expect(1, 262144, '\P{Line_Break=ideographic}', "");
Expect(0, 262144, '\P{^Line_Break=ideographic}', "");
Expect(1, 262141, '\p{Line_Break:   	_Ideographic}', "");
Expect(0, 262141, '\p{^Line_Break:   	_Ideographic}', "");
Expect(0, 262141, '\P{Line_Break:   	_Ideographic}', "");
Expect(1, 262141, '\P{^Line_Break:   	_Ideographic}', "");
Expect(0, 262144, '\p{Line_Break:   	_Ideographic}', "");
Expect(1, 262144, '\p{^Line_Break:   	_Ideographic}', "");
Expect(1, 262144, '\P{Line_Break:   	_Ideographic}', "");
Expect(0, 262144, '\P{^Line_Break:   	_Ideographic}', "");
Error('\p{Lb= /a/ID}');
Error('\P{Lb= /a/ID}');
Expect(1, 262141, '\p{Lb=id}', "");
Expect(0, 262141, '\p{^Lb=id}', "");
Expect(0, 262141, '\P{Lb=id}', "");
Expect(1, 262141, '\P{^Lb=id}', "");
Expect(0, 262144, '\p{Lb=id}', "");
Expect(1, 262144, '\p{^Lb=id}', "");
Expect(1, 262144, '\P{Lb=id}', "");
Expect(0, 262144, '\P{^Lb=id}', "");
Expect(1, 262141, '\p{Lb:		-ID}', "");
Expect(0, 262141, '\p{^Lb:		-ID}', "");
Expect(0, 262141, '\P{Lb:		-ID}', "");
Expect(1, 262141, '\P{^Lb:		-ID}', "");
Expect(0, 262144, '\p{Lb:		-ID}', "");
Expect(1, 262144, '\p{^Lb:		-ID}', "");
Expect(1, 262144, '\P{Lb:		-ID}', "");
Expect(0, 262144, '\P{^Lb:		-ID}', "");
Error('\p{Is_Line_Break:   -Ideographic:=}');
Error('\P{Is_Line_Break:   -Ideographic:=}');
Expect(1, 262141, '\p{Is_Line_Break=ideographic}', "");
Expect(0, 262141, '\p{^Is_Line_Break=ideographic}', "");
Expect(0, 262141, '\P{Is_Line_Break=ideographic}', "");
Expect(1, 262141, '\P{^Is_Line_Break=ideographic}', "");
Expect(0, 262144, '\p{Is_Line_Break=ideographic}', "");
Expect(1, 262144, '\p{^Is_Line_Break=ideographic}', "");
Expect(1, 262144, '\P{Is_Line_Break=ideographic}', "");
Expect(0, 262144, '\P{^Is_Line_Break=ideographic}', "");
Expect(1, 262141, '\p{Is_Line_Break= Ideographic}', "");
Expect(0, 262141, '\p{^Is_Line_Break= Ideographic}', "");
Expect(0, 262141, '\P{Is_Line_Break= Ideographic}', "");
Expect(1, 262141, '\P{^Is_Line_Break= Ideographic}', "");
Expect(0, 262144, '\p{Is_Line_Break= Ideographic}', "");
Expect(1, 262144, '\p{^Is_Line_Break= Ideographic}', "");
Expect(1, 262144, '\P{Is_Line_Break= Ideographic}', "");
Expect(0, 262144, '\P{^Is_Line_Break= Ideographic}', "");
Error('\p{Is_Lb=/a/--ID}');
Error('\P{Is_Lb=/a/--ID}');
Expect(1, 262141, '\p{Is_Lb=id}', "");
Expect(0, 262141, '\p{^Is_Lb=id}', "");
Expect(0, 262141, '\P{Is_Lb=id}', "");
Expect(1, 262141, '\P{^Is_Lb=id}', "");
Expect(0, 262144, '\p{Is_Lb=id}', "");
Expect(1, 262144, '\p{^Is_Lb=id}', "");
Expect(1, 262144, '\P{Is_Lb=id}', "");
Expect(0, 262144, '\P{^Is_Lb=id}', "");
Expect(1, 262141, '\p{Is_Lb=	ID}', "");
Expect(0, 262141, '\p{^Is_Lb=	ID}', "");
Expect(0, 262141, '\P{Is_Lb=	ID}', "");
Expect(1, 262141, '\P{^Is_Lb=	ID}', "");
Expect(0, 262144, '\p{Is_Lb=	ID}', "");
Expect(1, 262144, '\p{^Is_Lb=	ID}', "");
Expect(1, 262144, '\P{Is_Lb=	ID}', "");
Expect(0, 262144, '\P{^Is_Lb=	ID}', "");
Error('\p{Line_Break=:= -Inseparable}');
Error('\P{Line_Break=:= -Inseparable}');
Expect(1, 65049, '\p{Line_Break=inseparable}', "");
Expect(0, 65049, '\p{^Line_Break=inseparable}', "");
Expect(0, 65049, '\P{Line_Break=inseparable}', "");
Expect(1, 65049, '\P{^Line_Break=inseparable}', "");
Expect(0, 65050, '\p{Line_Break=inseparable}', "");
Expect(1, 65050, '\p{^Line_Break=inseparable}', "");
Expect(1, 65050, '\P{Line_Break=inseparable}', "");
Expect(0, 65050, '\P{^Line_Break=inseparable}', "");
Expect(1, 65049, '\p{Line_Break:   	-inseparable}', "");
Expect(0, 65049, '\p{^Line_Break:   	-inseparable}', "");
Expect(0, 65049, '\P{Line_Break:   	-inseparable}', "");
Expect(1, 65049, '\P{^Line_Break:   	-inseparable}', "");
Expect(0, 65050, '\p{Line_Break:   	-inseparable}', "");
Expect(1, 65050, '\p{^Line_Break:   	-inseparable}', "");
Expect(1, 65050, '\P{Line_Break:   	-inseparable}', "");
Expect(0, 65050, '\P{^Line_Break:   	-inseparable}', "");
Error('\p{Lb=_IN:=}');
Error('\P{Lb=_IN:=}');
Expect(1, 65049, '\p{Lb=in}', "");
Expect(0, 65049, '\p{^Lb=in}', "");
Expect(0, 65049, '\P{Lb=in}', "");
Expect(1, 65049, '\P{^Lb=in}', "");
Expect(0, 65050, '\p{Lb=in}', "");
Expect(1, 65050, '\p{^Lb=in}', "");
Expect(1, 65050, '\P{Lb=in}', "");
Expect(0, 65050, '\P{^Lb=in}', "");
Expect(1, 65049, '\p{Lb=-IN}', "");
Expect(0, 65049, '\p{^Lb=-IN}', "");
Expect(0, 65049, '\P{Lb=-IN}', "");
Expect(1, 65049, '\P{^Lb=-IN}', "");
Expect(0, 65050, '\p{Lb=-IN}', "");
Expect(1, 65050, '\p{^Lb=-IN}', "");
Expect(1, 65050, '\P{Lb=-IN}', "");
Expect(0, 65050, '\P{^Lb=-IN}', "");
Error('\p{Is_Line_Break:	/a/	Inseperable}');
Error('\P{Is_Line_Break:	/a/	Inseperable}');
Expect(1, 65049, '\p{Is_Line_Break=inseperable}', "");
Expect(0, 65049, '\p{^Is_Line_Break=inseperable}', "");
Expect(0, 65049, '\P{Is_Line_Break=inseperable}', "");
Expect(1, 65049, '\P{^Is_Line_Break=inseperable}', "");
Expect(0, 65050, '\p{Is_Line_Break=inseperable}', "");
Expect(1, 65050, '\p{^Is_Line_Break=inseperable}', "");
Expect(1, 65050, '\P{Is_Line_Break=inseperable}', "");
Expect(0, 65050, '\P{^Is_Line_Break=inseperable}', "");
Expect(1, 65049, '\p{Is_Line_Break=	_INSEPERABLE}', "");
Expect(0, 65049, '\p{^Is_Line_Break=	_INSEPERABLE}', "");
Expect(0, 65049, '\P{Is_Line_Break=	_INSEPERABLE}', "");
Expect(1, 65049, '\P{^Is_Line_Break=	_INSEPERABLE}', "");
Expect(0, 65050, '\p{Is_Line_Break=	_INSEPERABLE}', "");
Expect(1, 65050, '\p{^Is_Line_Break=	_INSEPERABLE}', "");
Expect(1, 65050, '\P{Is_Line_Break=	_INSEPERABLE}', "");
Expect(0, 65050, '\P{^Is_Line_Break=	_INSEPERABLE}', "");
Error('\p{Is_Lb=/a/ _inseparable}');
Error('\P{Is_Lb=/a/ _inseparable}');
Expect(1, 65049, '\p{Is_Lb=inseparable}', "");
Expect(0, 65049, '\p{^Is_Lb=inseparable}', "");
Expect(0, 65049, '\P{Is_Lb=inseparable}', "");
Expect(1, 65049, '\P{^Is_Lb=inseparable}', "");
Expect(0, 65050, '\p{Is_Lb=inseparable}', "");
Expect(1, 65050, '\p{^Is_Lb=inseparable}', "");
Expect(1, 65050, '\P{Is_Lb=inseparable}', "");
Expect(0, 65050, '\P{^Is_Lb=inseparable}', "");
Expect(1, 65049, '\p{Is_Lb= -Inseparable}', "");
Expect(0, 65049, '\p{^Is_Lb= -Inseparable}', "");
Expect(0, 65049, '\P{Is_Lb= -Inseparable}', "");
Expect(1, 65049, '\P{^Is_Lb= -Inseparable}', "");
Expect(0, 65050, '\p{Is_Lb= -Inseparable}', "");
Expect(1, 65050, '\p{^Is_Lb= -Inseparable}', "");
Expect(1, 65050, '\P{Is_Lb= -Inseparable}', "");
Expect(0, 65050, '\P{^Is_Lb= -Inseparable}', "");
Error('\p{Line_Break=--Infix_Numeric/a/}');
Error('\P{Line_Break=--Infix_Numeric/a/}');
Expect(1, 65044, '\p{Line_Break=infixnumeric}', "");
Expect(0, 65044, '\p{^Line_Break=infixnumeric}', "");
Expect(0, 65044, '\P{Line_Break=infixnumeric}', "");
Expect(1, 65044, '\P{^Line_Break=infixnumeric}', "");
Expect(0, 65045, '\p{Line_Break=infixnumeric}', "");
Expect(1, 65045, '\p{^Line_Break=infixnumeric}', "");
Expect(1, 65045, '\P{Line_Break=infixnumeric}', "");
Expect(0, 65045, '\P{^Line_Break=infixnumeric}', "");
Expect(1, 65044, '\p{Line_Break=_Infix_Numeric}', "");
Expect(0, 65044, '\p{^Line_Break=_Infix_Numeric}', "");
Expect(0, 65044, '\P{Line_Break=_Infix_Numeric}', "");
Expect(1, 65044, '\P{^Line_Break=_Infix_Numeric}', "");
Expect(0, 65045, '\p{Line_Break=_Infix_Numeric}', "");
Expect(1, 65045, '\p{^Line_Break=_Infix_Numeric}', "");
Expect(1, 65045, '\P{Line_Break=_Infix_Numeric}', "");
Expect(0, 65045, '\P{^Line_Break=_Infix_Numeric}', "");
Error('\p{Lb=_:=is}');
Error('\P{Lb=_:=is}');
Expect(1, 65044, '\p{Lb=is}', "");
Expect(0, 65044, '\p{^Lb=is}', "");
Expect(0, 65044, '\P{Lb=is}', "");
Expect(1, 65044, '\P{^Lb=is}', "");
Expect(0, 65045, '\p{Lb=is}', "");
Expect(1, 65045, '\p{^Lb=is}', "");
Expect(1, 65045, '\P{Lb=is}', "");
Expect(0, 65045, '\P{^Lb=is}', "");
Expect(1, 65044, '\p{Lb:   -IS}', "");
Expect(0, 65044, '\p{^Lb:   -IS}', "");
Expect(0, 65044, '\P{Lb:   -IS}', "");
Expect(1, 65044, '\P{^Lb:   -IS}', "");
Expect(0, 65045, '\p{Lb:   -IS}', "");
Expect(1, 65045, '\p{^Lb:   -IS}', "");
Expect(1, 65045, '\P{Lb:   -IS}', "");
Expect(0, 65045, '\P{^Lb:   -IS}', "");
Error('\p{Is_Line_Break=--infix_Numeric:=}');
Error('\P{Is_Line_Break=--infix_Numeric:=}');
Expect(1, 65044, '\p{Is_Line_Break=infixnumeric}', "");
Expect(0, 65044, '\p{^Is_Line_Break=infixnumeric}', "");
Expect(0, 65044, '\P{Is_Line_Break=infixnumeric}', "");
Expect(1, 65044, '\P{^Is_Line_Break=infixnumeric}', "");
Expect(0, 65045, '\p{Is_Line_Break=infixnumeric}', "");
Expect(1, 65045, '\p{^Is_Line_Break=infixnumeric}', "");
Expect(1, 65045, '\P{Is_Line_Break=infixnumeric}', "");
Expect(0, 65045, '\P{^Is_Line_Break=infixnumeric}', "");
Expect(1, 65044, '\p{Is_Line_Break=__INFIX_numeric}', "");
Expect(0, 65044, '\p{^Is_Line_Break=__INFIX_numeric}', "");
Expect(0, 65044, '\P{Is_Line_Break=__INFIX_numeric}', "");
Expect(1, 65044, '\P{^Is_Line_Break=__INFIX_numeric}', "");
Expect(0, 65045, '\p{Is_Line_Break=__INFIX_numeric}', "");
Expect(1, 65045, '\p{^Is_Line_Break=__INFIX_numeric}', "");
Expect(1, 65045, '\P{Is_Line_Break=__INFIX_numeric}', "");
Expect(0, 65045, '\P{^Is_Line_Break=__INFIX_numeric}', "");
Error('\p{Is_Lb= /a/IS}');
Error('\P{Is_Lb= /a/IS}');
Expect(1, 65044, '\p{Is_Lb=is}', "");
Expect(0, 65044, '\p{^Is_Lb=is}', "");
Expect(0, 65044, '\P{Is_Lb=is}', "");
Expect(1, 65044, '\P{^Is_Lb=is}', "");
Expect(0, 65045, '\p{Is_Lb=is}', "");
Expect(1, 65045, '\p{^Is_Lb=is}', "");
Expect(1, 65045, '\P{Is_Lb=is}', "");
Expect(0, 65045, '\P{^Is_Lb=is}', "");
Expect(1, 65044, '\p{Is_Lb=_ IS}', "");
Expect(0, 65044, '\p{^Is_Lb=_ IS}', "");
Expect(0, 65044, '\P{Is_Lb=_ IS}', "");
Expect(1, 65044, '\P{^Is_Lb=_ IS}', "");
Expect(0, 65045, '\p{Is_Lb=_ IS}', "");
Expect(1, 65045, '\p{^Is_Lb=_ IS}', "");
Expect(1, 65045, '\P{Is_Lb=_ IS}', "");
Expect(0, 65045, '\P{^Is_Lb=_ IS}', "");
Error('\p{Line_Break=	:=JL}');
Error('\P{Line_Break=	:=JL}');
Expect(1, 43388, '\p{Line_Break: jl}', "");
Expect(0, 43388, '\p{^Line_Break: jl}', "");
Expect(0, 43388, '\P{Line_Break: jl}', "");
Expect(1, 43388, '\P{^Line_Break: jl}', "");
Expect(0, 43389, '\p{Line_Break: jl}', "");
Expect(1, 43389, '\p{^Line_Break: jl}', "");
Expect(1, 43389, '\P{Line_Break: jl}', "");
Expect(0, 43389, '\P{^Line_Break: jl}', "");
Expect(1, 43388, '\p{Line_Break=_jl}', "");
Expect(0, 43388, '\p{^Line_Break=_jl}', "");
Expect(0, 43388, '\P{Line_Break=_jl}', "");
Expect(1, 43388, '\P{^Line_Break=_jl}', "");
Expect(0, 43389, '\p{Line_Break=_jl}', "");
Expect(1, 43389, '\p{^Line_Break=_jl}', "");
Expect(1, 43389, '\P{Line_Break=_jl}', "");
Expect(0, 43389, '\P{^Line_Break=_jl}', "");
Error('\p{Lb= /a/jl}');
Error('\P{Lb= /a/jl}');
Expect(1, 43388, '\p{Lb=jl}', "");
Expect(0, 43388, '\p{^Lb=jl}', "");
Expect(0, 43388, '\P{Lb=jl}', "");
Expect(1, 43388, '\P{^Lb=jl}', "");
Expect(0, 43389, '\p{Lb=jl}', "");
Expect(1, 43389, '\p{^Lb=jl}', "");
Expect(1, 43389, '\P{Lb=jl}', "");
Expect(0, 43389, '\P{^Lb=jl}', "");
Expect(1, 43388, '\p{Lb= -JL}', "");
Expect(0, 43388, '\p{^Lb= -JL}', "");
Expect(0, 43388, '\P{Lb= -JL}', "");
Expect(1, 43388, '\P{^Lb= -JL}', "");
Expect(0, 43389, '\p{Lb= -JL}', "");
Expect(1, 43389, '\p{^Lb= -JL}', "");
Expect(1, 43389, '\P{Lb= -JL}', "");
Expect(0, 43389, '\P{^Lb= -JL}', "");
Error('\p{Is_Line_Break=/a/	jl}');
Error('\P{Is_Line_Break=/a/	jl}');
Expect(1, 43388, '\p{Is_Line_Break=jl}', "");
Expect(0, 43388, '\p{^Is_Line_Break=jl}', "");
Expect(0, 43388, '\P{Is_Line_Break=jl}', "");
Expect(1, 43388, '\P{^Is_Line_Break=jl}', "");
Expect(0, 43389, '\p{Is_Line_Break=jl}', "");
Expect(1, 43389, '\p{^Is_Line_Break=jl}', "");
Expect(1, 43389, '\P{Is_Line_Break=jl}', "");
Expect(0, 43389, '\P{^Is_Line_Break=jl}', "");
Expect(1, 43388, '\p{Is_Line_Break=	_jl}', "");
Expect(0, 43388, '\p{^Is_Line_Break=	_jl}', "");
Expect(0, 43388, '\P{Is_Line_Break=	_jl}', "");
Expect(1, 43388, '\P{^Is_Line_Break=	_jl}', "");
Expect(0, 43389, '\p{Is_Line_Break=	_jl}', "");
Expect(1, 43389, '\p{^Is_Line_Break=	_jl}', "");
Expect(1, 43389, '\P{Is_Line_Break=	_jl}', "");
Expect(0, 43389, '\P{^Is_Line_Break=	_jl}', "");
Error('\p{Is_Lb= /a/JL}');
Error('\P{Is_Lb= /a/JL}');
Expect(1, 43388, '\p{Is_Lb=jl}', "");
Expect(0, 43388, '\p{^Is_Lb=jl}', "");
Expect(0, 43388, '\P{Is_Lb=jl}', "");
Expect(1, 43388, '\P{^Is_Lb=jl}', "");
Expect(0, 43389, '\p{Is_Lb=jl}', "");
Expect(1, 43389, '\p{^Is_Lb=jl}', "");
Expect(1, 43389, '\P{Is_Lb=jl}', "");
Expect(0, 43389, '\P{^Is_Lb=jl}', "");
Expect(1, 43388, '\p{Is_Lb=-JL}', "");
Expect(0, 43388, '\p{^Is_Lb=-JL}', "");
Expect(0, 43388, '\P{Is_Lb=-JL}', "");
Expect(1, 43388, '\P{^Is_Lb=-JL}', "");
Expect(0, 43389, '\p{Is_Lb=-JL}', "");
Expect(1, 43389, '\p{^Is_Lb=-JL}', "");
Expect(1, 43389, '\P{Is_Lb=-JL}', "");
Expect(0, 43389, '\P{^Is_Lb=-JL}', "");
Error('\p{Line_Break=		JT/a/}');
Error('\P{Line_Break=		JT/a/}');
Expect(1, 55291, '\p{Line_Break:   jt}', "");
Expect(0, 55291, '\p{^Line_Break:   jt}', "");
Expect(0, 55291, '\P{Line_Break:   jt}', "");
Expect(1, 55291, '\P{^Line_Break:   jt}', "");
Expect(0, 55292, '\p{Line_Break:   jt}', "");
Expect(1, 55292, '\p{^Line_Break:   jt}', "");
Expect(1, 55292, '\P{Line_Break:   jt}', "");
Expect(0, 55292, '\P{^Line_Break:   jt}', "");
Expect(1, 55291, '\p{Line_Break=_-jt}', "");
Expect(0, 55291, '\p{^Line_Break=_-jt}', "");
Expect(0, 55291, '\P{Line_Break=_-jt}', "");
Expect(1, 55291, '\P{^Line_Break=_-jt}', "");
Expect(0, 55292, '\p{Line_Break=_-jt}', "");
Expect(1, 55292, '\p{^Line_Break=_-jt}', "");
Expect(1, 55292, '\P{Line_Break=_-jt}', "");
Expect(0, 55292, '\P{^Line_Break=_-jt}', "");
Error('\p{Lb=_JT:=}');
Error('\P{Lb=_JT:=}');
Expect(1, 55291, '\p{Lb=jt}', "");
Expect(0, 55291, '\p{^Lb=jt}', "");
Expect(0, 55291, '\P{Lb=jt}', "");
Expect(1, 55291, '\P{^Lb=jt}', "");
Expect(0, 55292, '\p{Lb=jt}', "");
Expect(1, 55292, '\p{^Lb=jt}', "");
Expect(1, 55292, '\P{Lb=jt}', "");
Expect(0, 55292, '\P{^Lb=jt}', "");
Expect(1, 55291, '\p{Lb=_JT}', "");
Expect(0, 55291, '\p{^Lb=_JT}', "");
Expect(0, 55291, '\P{Lb=_JT}', "");
Expect(1, 55291, '\P{^Lb=_JT}', "");
Expect(0, 55292, '\p{Lb=_JT}', "");
Expect(1, 55292, '\p{^Lb=_JT}', "");
Expect(1, 55292, '\P{Lb=_JT}', "");
Expect(0, 55292, '\P{^Lb=_JT}', "");
Error('\p{Is_Line_Break=	/a/JT}');
Error('\P{Is_Line_Break=	/a/JT}');
Expect(1, 55291, '\p{Is_Line_Break=jt}', "");
Expect(0, 55291, '\p{^Is_Line_Break=jt}', "");
Expect(0, 55291, '\P{Is_Line_Break=jt}', "");
Expect(1, 55291, '\P{^Is_Line_Break=jt}', "");
Expect(0, 55292, '\p{Is_Line_Break=jt}', "");
Expect(1, 55292, '\p{^Is_Line_Break=jt}', "");
Expect(1, 55292, '\P{Is_Line_Break=jt}', "");
Expect(0, 55292, '\P{^Is_Line_Break=jt}', "");
Expect(1, 55291, '\p{Is_Line_Break=-JT}', "");
Expect(0, 55291, '\p{^Is_Line_Break=-JT}', "");
Expect(0, 55291, '\P{Is_Line_Break=-JT}', "");
Expect(1, 55291, '\P{^Is_Line_Break=-JT}', "");
Expect(0, 55292, '\p{Is_Line_Break=-JT}', "");
Expect(1, 55292, '\p{^Is_Line_Break=-JT}', "");
Expect(1, 55292, '\P{Is_Line_Break=-JT}', "");
Expect(0, 55292, '\P{^Is_Line_Break=-JT}', "");
Error('\p{Is_Lb=_	JT/a/}');
Error('\P{Is_Lb=_	JT/a/}');
Expect(1, 55291, '\p{Is_Lb=jt}', "");
Expect(0, 55291, '\p{^Is_Lb=jt}', "");
Expect(0, 55291, '\P{Is_Lb=jt}', "");
Expect(1, 55291, '\P{^Is_Lb=jt}', "");
Expect(0, 55292, '\p{Is_Lb=jt}', "");
Expect(1, 55292, '\p{^Is_Lb=jt}', "");
Expect(1, 55292, '\P{Is_Lb=jt}', "");
Expect(0, 55292, '\P{^Is_Lb=jt}', "");
Expect(1, 55291, '\p{Is_Lb=JT}', "");
Expect(0, 55291, '\p{^Is_Lb=JT}', "");
Expect(0, 55291, '\P{Is_Lb=JT}', "");
Expect(1, 55291, '\P{^Is_Lb=JT}', "");
Expect(0, 55292, '\p{Is_Lb=JT}', "");
Expect(1, 55292, '\p{^Is_Lb=JT}', "");
Expect(1, 55292, '\P{Is_Lb=JT}', "");
Expect(0, 55292, '\P{^Is_Lb=JT}', "");
Error('\p{Line_Break= :=jv}');
Error('\P{Line_Break= :=jv}');
Expect(1, 55238, '\p{Line_Break=jv}', "");
Expect(0, 55238, '\p{^Line_Break=jv}', "");
Expect(0, 55238, '\P{Line_Break=jv}', "");
Expect(1, 55238, '\P{^Line_Break=jv}', "");
Expect(0, 55239, '\p{Line_Break=jv}', "");
Expect(1, 55239, '\p{^Line_Break=jv}', "");
Expect(1, 55239, '\P{Line_Break=jv}', "");
Expect(0, 55239, '\P{^Line_Break=jv}', "");
Expect(1, 55238, '\p{Line_Break:  jv}', "");
Expect(0, 55238, '\p{^Line_Break:  jv}', "");
Expect(0, 55238, '\P{Line_Break:  jv}', "");
Expect(1, 55238, '\P{^Line_Break:  jv}', "");
Expect(0, 55239, '\p{Line_Break:  jv}', "");
Expect(1, 55239, '\p{^Line_Break:  jv}', "");
Expect(1, 55239, '\P{Line_Break:  jv}', "");
Expect(0, 55239, '\P{^Line_Break:  jv}', "");
Error('\p{Lb=:=jv}');
Error('\P{Lb=:=jv}');
Expect(1, 55238, '\p{Lb=jv}', "");
Expect(0, 55238, '\p{^Lb=jv}', "");
Expect(0, 55238, '\P{Lb=jv}', "");
Expect(1, 55238, '\P{^Lb=jv}', "");
Expect(0, 55239, '\p{Lb=jv}', "");
Expect(1, 55239, '\p{^Lb=jv}', "");
Expect(1, 55239, '\P{Lb=jv}', "");
Expect(0, 55239, '\P{^Lb=jv}', "");
Expect(1, 55238, '\p{Lb=-_JV}', "");
Expect(0, 55238, '\p{^Lb=-_JV}', "");
Expect(0, 55238, '\P{Lb=-_JV}', "");
Expect(1, 55238, '\P{^Lb=-_JV}', "");
Expect(0, 55239, '\p{Lb=-_JV}', "");
Expect(1, 55239, '\p{^Lb=-_JV}', "");
Expect(1, 55239, '\P{Lb=-_JV}', "");
Expect(0, 55239, '\P{^Lb=-_JV}', "");
Error('\p{Is_Line_Break=/a/_ jv}');
Error('\P{Is_Line_Break=/a/_ jv}');
Expect(1, 55238, '\p{Is_Line_Break=jv}', "");
Expect(0, 55238, '\p{^Is_Line_Break=jv}', "");
Expect(0, 55238, '\P{Is_Line_Break=jv}', "");
Expect(1, 55238, '\P{^Is_Line_Break=jv}', "");
Expect(0, 55239, '\p{Is_Line_Break=jv}', "");
Expect(1, 55239, '\p{^Is_Line_Break=jv}', "");
Expect(1, 55239, '\P{Is_Line_Break=jv}', "");
Expect(0, 55239, '\P{^Is_Line_Break=jv}', "");
Expect(1, 55238, '\p{Is_Line_Break=  JV}', "");
Expect(0, 55238, '\p{^Is_Line_Break=  JV}', "");
Expect(0, 55238, '\P{Is_Line_Break=  JV}', "");
Expect(1, 55238, '\P{^Is_Line_Break=  JV}', "");
Expect(0, 55239, '\p{Is_Line_Break=  JV}', "");
Expect(1, 55239, '\p{^Is_Line_Break=  JV}', "");
Expect(1, 55239, '\P{Is_Line_Break=  JV}', "");
Expect(0, 55239, '\P{^Is_Line_Break=  JV}', "");
Error('\p{Is_Lb= :=JV}');
Error('\P{Is_Lb= :=JV}');
Expect(1, 55238, '\p{Is_Lb=jv}', "");
Expect(0, 55238, '\p{^Is_Lb=jv}', "");
Expect(0, 55238, '\P{Is_Lb=jv}', "");
Expect(1, 55238, '\P{^Is_Lb=jv}', "");
Expect(0, 55239, '\p{Is_Lb=jv}', "");
Expect(1, 55239, '\p{^Is_Lb=jv}', "");
Expect(1, 55239, '\P{Is_Lb=jv}', "");
Expect(0, 55239, '\P{^Is_Lb=jv}', "");
Expect(1, 55238, '\p{Is_Lb=_jv}', "");
Expect(0, 55238, '\p{^Is_Lb=_jv}', "");
Expect(0, 55238, '\P{Is_Lb=_jv}', "");
Expect(1, 55238, '\P{^Is_Lb=_jv}', "");
Expect(0, 55239, '\p{Is_Lb=_jv}', "");
Expect(1, 55239, '\p{^Is_Lb=_jv}', "");
Expect(1, 55239, '\P{Is_Lb=_jv}', "");
Expect(0, 55239, '\P{^Is_Lb=_jv}', "");
Error('\p{Line_Break=:= LINE_Feed}');
Error('\P{Line_Break=:= LINE_Feed}');
Expect(1, 10, '\p{Line_Break=linefeed}', "");
Expect(0, 10, '\p{^Line_Break=linefeed}', "");
Expect(0, 10, '\P{Line_Break=linefeed}', "");
Expect(1, 10, '\P{^Line_Break=linefeed}', "");
Expect(0, 11, '\p{Line_Break=linefeed}', "");
Expect(1, 11, '\p{^Line_Break=linefeed}', "");
Expect(1, 11, '\P{Line_Break=linefeed}', "");
Expect(0, 11, '\P{^Line_Break=linefeed}', "");
Expect(1, 10, '\p{Line_Break=_ Line_Feed}', "");
Expect(0, 10, '\p{^Line_Break=_ Line_Feed}', "");
Expect(0, 10, '\P{Line_Break=_ Line_Feed}', "");
Expect(1, 10, '\P{^Line_Break=_ Line_Feed}', "");
Expect(0, 11, '\p{Line_Break=_ Line_Feed}', "");
Expect(1, 11, '\p{^Line_Break=_ Line_Feed}', "");
Expect(1, 11, '\P{Line_Break=_ Line_Feed}', "");
Expect(0, 11, '\P{^Line_Break=_ Line_Feed}', "");
Error('\p{Lb=:=LF}');
Error('\P{Lb=:=LF}');
Expect(1, 10, '\p{Lb=lf}', "");
Expect(0, 10, '\p{^Lb=lf}', "");
Expect(0, 10, '\P{Lb=lf}', "");
Expect(1, 10, '\P{^Lb=lf}', "");
Expect(0, 11, '\p{Lb=lf}', "");
Expect(1, 11, '\p{^Lb=lf}', "");
Expect(1, 11, '\P{Lb=lf}', "");
Expect(0, 11, '\P{^Lb=lf}', "");
Expect(1, 10, '\p{Lb:   	-LF}', "");
Expect(0, 10, '\p{^Lb:   	-LF}', "");
Expect(0, 10, '\P{Lb:   	-LF}', "");
Expect(1, 10, '\P{^Lb:   	-LF}', "");
Expect(0, 11, '\p{Lb:   	-LF}', "");
Expect(1, 11, '\p{^Lb:   	-LF}', "");
Expect(1, 11, '\P{Lb:   	-LF}', "");
Expect(0, 11, '\P{^Lb:   	-LF}', "");
Error('\p{Is_Line_Break=	-Line_Feed:=}');
Error('\P{Is_Line_Break=	-Line_Feed:=}');
Expect(1, 10, '\p{Is_Line_Break:	linefeed}', "");
Expect(0, 10, '\p{^Is_Line_Break:	linefeed}', "");
Expect(0, 10, '\P{Is_Line_Break:	linefeed}', "");
Expect(1, 10, '\P{^Is_Line_Break:	linefeed}', "");
Expect(0, 11, '\p{Is_Line_Break:	linefeed}', "");
Expect(1, 11, '\p{^Is_Line_Break:	linefeed}', "");
Expect(1, 11, '\P{Is_Line_Break:	linefeed}', "");
Expect(0, 11, '\P{^Is_Line_Break:	linefeed}', "");
Expect(1, 10, '\p{Is_Line_Break=-	Line_Feed}', "");
Expect(0, 10, '\p{^Is_Line_Break=-	Line_Feed}', "");
Expect(0, 10, '\P{Is_Line_Break=-	Line_Feed}', "");
Expect(1, 10, '\P{^Is_Line_Break=-	Line_Feed}', "");
Expect(0, 11, '\p{Is_Line_Break=-	Line_Feed}', "");
Expect(1, 11, '\p{^Is_Line_Break=-	Line_Feed}', "");
Expect(1, 11, '\P{Is_Line_Break=-	Line_Feed}', "");
Expect(0, 11, '\P{^Is_Line_Break=-	Line_Feed}', "");
Error('\p{Is_Lb=_lf:=}');
Error('\P{Is_Lb=_lf:=}');
Expect(1, 10, '\p{Is_Lb=lf}', "");
Expect(0, 10, '\p{^Is_Lb=lf}', "");
Expect(0, 10, '\P{Is_Lb=lf}', "");
Expect(1, 10, '\P{^Is_Lb=lf}', "");
Expect(0, 11, '\p{Is_Lb=lf}', "");
Expect(1, 11, '\p{^Is_Lb=lf}', "");
Expect(1, 11, '\P{Is_Lb=lf}', "");
Expect(0, 11, '\P{^Is_Lb=lf}', "");
Expect(1, 10, '\p{Is_Lb= _LF}', "");
Expect(0, 10, '\p{^Is_Lb= _LF}', "");
Expect(0, 10, '\P{Is_Lb= _LF}', "");
Expect(1, 10, '\P{^Is_Lb= _LF}', "");
Expect(0, 11, '\p{Is_Lb= _LF}', "");
Expect(1, 11, '\p{^Is_Lb= _LF}', "");
Expect(1, 11, '\P{Is_Lb= _LF}', "");
Expect(0, 11, '\P{^Is_Lb= _LF}', "");
Error('\p{Line_Break=/a/Next_line}');
Error('\P{Line_Break=/a/Next_line}');
Expect(1, 133, '\p{Line_Break=nextline}', "");
Expect(0, 133, '\p{^Line_Break=nextline}', "");
Expect(0, 133, '\P{Line_Break=nextline}', "");
Expect(1, 133, '\P{^Line_Break=nextline}', "");
Expect(0, 134, '\p{Line_Break=nextline}', "");
Expect(1, 134, '\p{^Line_Break=nextline}', "");
Expect(1, 134, '\P{Line_Break=nextline}', "");
Expect(0, 134, '\P{^Line_Break=nextline}', "");
Expect(1, 133, '\p{Line_Break= 	NEXT_Line}', "");
Expect(0, 133, '\p{^Line_Break= 	NEXT_Line}', "");
Expect(0, 133, '\P{Line_Break= 	NEXT_Line}', "");
Expect(1, 133, '\P{^Line_Break= 	NEXT_Line}', "");
Expect(0, 134, '\p{Line_Break= 	NEXT_Line}', "");
Expect(1, 134, '\p{^Line_Break= 	NEXT_Line}', "");
Expect(1, 134, '\P{Line_Break= 	NEXT_Line}', "");
Expect(0, 134, '\P{^Line_Break= 	NEXT_Line}', "");
Error('\p{Lb=	-NL/a/}');
Error('\P{Lb=	-NL/a/}');
Expect(1, 133, '\p{Lb=nl}', "");
Expect(0, 133, '\p{^Lb=nl}', "");
Expect(0, 133, '\P{Lb=nl}', "");
Expect(1, 133, '\P{^Lb=nl}', "");
Expect(0, 134, '\p{Lb=nl}', "");
Expect(1, 134, '\p{^Lb=nl}', "");
Expect(1, 134, '\P{Lb=nl}', "");
Expect(0, 134, '\P{^Lb=nl}', "");
Expect(1, 133, '\p{Lb=--NL}', "");
Expect(0, 133, '\p{^Lb=--NL}', "");
Expect(0, 133, '\P{Lb=--NL}', "");
Expect(1, 133, '\P{^Lb=--NL}', "");
Expect(0, 134, '\p{Lb=--NL}', "");
Expect(1, 134, '\p{^Lb=--NL}', "");
Expect(1, 134, '\P{Lb=--NL}', "");
Expect(0, 134, '\P{^Lb=--NL}', "");
Error('\p{Is_Line_Break=	/a/next_LINE}');
Error('\P{Is_Line_Break=	/a/next_LINE}');
Expect(1, 133, '\p{Is_Line_Break=nextline}', "");
Expect(0, 133, '\p{^Is_Line_Break=nextline}', "");
Expect(0, 133, '\P{Is_Line_Break=nextline}', "");
Expect(1, 133, '\P{^Is_Line_Break=nextline}', "");
Expect(0, 134, '\p{Is_Line_Break=nextline}', "");
Expect(1, 134, '\p{^Is_Line_Break=nextline}', "");
Expect(1, 134, '\P{Is_Line_Break=nextline}', "");
Expect(0, 134, '\P{^Is_Line_Break=nextline}', "");
Expect(1, 133, '\p{Is_Line_Break=-Next_Line}', "");
Expect(0, 133, '\p{^Is_Line_Break=-Next_Line}', "");
Expect(0, 133, '\P{Is_Line_Break=-Next_Line}', "");
Expect(1, 133, '\P{^Is_Line_Break=-Next_Line}', "");
Expect(0, 134, '\p{Is_Line_Break=-Next_Line}', "");
Expect(1, 134, '\p{^Is_Line_Break=-Next_Line}', "");
Expect(1, 134, '\P{Is_Line_Break=-Next_Line}', "");
Expect(0, 134, '\P{^Is_Line_Break=-Next_Line}', "");
Error('\p{Is_Lb= /a/NL}');
Error('\P{Is_Lb= /a/NL}');
Expect(1, 133, '\p{Is_Lb=nl}', "");
Expect(0, 133, '\p{^Is_Lb=nl}', "");
Expect(0, 133, '\P{Is_Lb=nl}', "");
Expect(1, 133, '\P{^Is_Lb=nl}', "");
Expect(0, 134, '\p{Is_Lb=nl}', "");
Expect(1, 134, '\p{^Is_Lb=nl}', "");
Expect(1, 134, '\P{Is_Lb=nl}', "");
Expect(0, 134, '\P{^Is_Lb=nl}', "");
Expect(1, 133, '\p{Is_Lb=	 NL}', "");
Expect(0, 133, '\p{^Is_Lb=	 NL}', "");
Expect(0, 133, '\P{Is_Lb=	 NL}', "");
Expect(1, 133, '\P{^Is_Lb=	 NL}', "");
Expect(0, 134, '\p{Is_Lb=	 NL}', "");
Expect(1, 134, '\p{^Is_Lb=	 NL}', "");
Expect(1, 134, '\P{Is_Lb=	 NL}', "");
Expect(0, 134, '\P{^Is_Lb=	 NL}', "");
Error('\p{Line_Break=--Nonstarter/a/}');
Error('\P{Line_Break=--Nonstarter/a/}');
Expect(1, 65439, '\p{Line_Break=nonstarter}', "");
Expect(0, 65439, '\p{^Line_Break=nonstarter}', "");
Expect(0, 65439, '\P{Line_Break=nonstarter}', "");
Expect(1, 65439, '\P{^Line_Break=nonstarter}', "");
Expect(0, 65440, '\p{Line_Break=nonstarter}', "");
Expect(1, 65440, '\p{^Line_Break=nonstarter}', "");
Expect(1, 65440, '\P{Line_Break=nonstarter}', "");
Expect(0, 65440, '\P{^Line_Break=nonstarter}', "");
Expect(1, 65439, '\p{Line_Break= NONSTARTER}', "");
Expect(0, 65439, '\p{^Line_Break= NONSTARTER}', "");
Expect(0, 65439, '\P{Line_Break= NONSTARTER}', "");
Expect(1, 65439, '\P{^Line_Break= NONSTARTER}', "");
Expect(0, 65440, '\p{Line_Break= NONSTARTER}', "");
Expect(1, 65440, '\p{^Line_Break= NONSTARTER}', "");
Expect(1, 65440, '\P{Line_Break= NONSTARTER}', "");
Expect(0, 65440, '\P{^Line_Break= NONSTARTER}', "");
Error('\p{Lb=:= NS}');
Error('\P{Lb=:= NS}');
Expect(1, 65439, '\p{Lb=ns}', "");
Expect(0, 65439, '\p{^Lb=ns}', "");
Expect(0, 65439, '\P{Lb=ns}', "");
Expect(1, 65439, '\P{^Lb=ns}', "");
Expect(0, 65440, '\p{Lb=ns}', "");
Expect(1, 65440, '\p{^Lb=ns}', "");
Expect(1, 65440, '\P{Lb=ns}', "");
Expect(0, 65440, '\P{^Lb=ns}', "");
Expect(1, 65439, '\p{Lb=NS}', "");
Expect(0, 65439, '\p{^Lb=NS}', "");
Expect(0, 65439, '\P{Lb=NS}', "");
Expect(1, 65439, '\P{^Lb=NS}', "");
Expect(0, 65440, '\p{Lb=NS}', "");
Expect(1, 65440, '\p{^Lb=NS}', "");
Expect(1, 65440, '\P{Lb=NS}', "");
Expect(0, 65440, '\P{^Lb=NS}', "");
Error('\p{Is_Line_Break=_Nonstarter/a/}');
Error('\P{Is_Line_Break=_Nonstarter/a/}');
Expect(1, 65439, '\p{Is_Line_Break:   nonstarter}', "");
Expect(0, 65439, '\p{^Is_Line_Break:   nonstarter}', "");
Expect(0, 65439, '\P{Is_Line_Break:   nonstarter}', "");
Expect(1, 65439, '\P{^Is_Line_Break:   nonstarter}', "");
Expect(0, 65440, '\p{Is_Line_Break:   nonstarter}', "");
Expect(1, 65440, '\p{^Is_Line_Break:   nonstarter}', "");
Expect(1, 65440, '\P{Is_Line_Break:   nonstarter}', "");
Expect(0, 65440, '\P{^Is_Line_Break:   nonstarter}', "");
Expect(1, 65439, '\p{Is_Line_Break=-Nonstarter}', "");
Expect(0, 65439, '\p{^Is_Line_Break=-Nonstarter}', "");
Expect(0, 65439, '\P{Is_Line_Break=-Nonstarter}', "");
Expect(1, 65439, '\P{^Is_Line_Break=-Nonstarter}', "");
Expect(0, 65440, '\p{Is_Line_Break=-Nonstarter}', "");
Expect(1, 65440, '\p{^Is_Line_Break=-Nonstarter}', "");
Expect(1, 65440, '\P{Is_Line_Break=-Nonstarter}', "");
Expect(0, 65440, '\P{^Is_Line_Break=-Nonstarter}', "");
Error('\p{Is_Lb=/a/NS}');
Error('\P{Is_Lb=/a/NS}');
Expect(1, 65439, '\p{Is_Lb=ns}', "");
Expect(0, 65439, '\p{^Is_Lb=ns}', "");
Expect(0, 65439, '\P{Is_Lb=ns}', "");
Expect(1, 65439, '\P{^Is_Lb=ns}', "");
Expect(0, 65440, '\p{Is_Lb=ns}', "");
Expect(1, 65440, '\p{^Is_Lb=ns}', "");
Expect(1, 65440, '\P{Is_Lb=ns}', "");
Expect(0, 65440, '\P{^Is_Lb=ns}', "");
Expect(1, 65439, '\p{Is_Lb= ns}', "");
Expect(0, 65439, '\p{^Is_Lb= ns}', "");
Expect(0, 65439, '\P{Is_Lb= ns}', "");
Expect(1, 65439, '\P{^Is_Lb= ns}', "");
Expect(0, 65440, '\p{Is_Lb= ns}', "");
Expect(1, 65440, '\p{^Is_Lb= ns}', "");
Expect(1, 65440, '\P{Is_Lb= ns}', "");
Expect(0, 65440, '\P{^Is_Lb= ns}', "");
Error('\p{Line_Break:		-Numeric/a/}');
Error('\P{Line_Break:		-Numeric/a/}');
Expect(1, 120831, '\p{Line_Break:	numeric}', "");
Expect(0, 120831, '\p{^Line_Break:	numeric}', "");
Expect(0, 120831, '\P{Line_Break:	numeric}', "");
Expect(1, 120831, '\P{^Line_Break:	numeric}', "");
Expect(0, 120832, '\p{Line_Break:	numeric}', "");
Expect(1, 120832, '\p{^Line_Break:	numeric}', "");
Expect(1, 120832, '\P{Line_Break:	numeric}', "");
Expect(0, 120832, '\P{^Line_Break:	numeric}', "");
Expect(1, 120831, '\p{Line_Break= Numeric}', "");
Expect(0, 120831, '\p{^Line_Break= Numeric}', "");
Expect(0, 120831, '\P{Line_Break= Numeric}', "");
Expect(1, 120831, '\P{^Line_Break= Numeric}', "");
Expect(0, 120832, '\p{Line_Break= Numeric}', "");
Expect(1, 120832, '\p{^Line_Break= Numeric}', "");
Expect(1, 120832, '\P{Line_Break= Numeric}', "");
Expect(0, 120832, '\P{^Line_Break= Numeric}', "");
Error('\p{Lb=:=NU}');
Error('\P{Lb=:=NU}');
Expect(1, 120831, '\p{Lb=nu}', "");
Expect(0, 120831, '\p{^Lb=nu}', "");
Expect(0, 120831, '\P{Lb=nu}', "");
Expect(1, 120831, '\P{^Lb=nu}', "");
Expect(0, 120832, '\p{Lb=nu}', "");
Expect(1, 120832, '\p{^Lb=nu}', "");
Expect(1, 120832, '\P{Lb=nu}', "");
Expect(0, 120832, '\P{^Lb=nu}', "");
Expect(1, 120831, '\p{Lb=-NU}', "");
Expect(0, 120831, '\p{^Lb=-NU}', "");
Expect(0, 120831, '\P{Lb=-NU}', "");
Expect(1, 120831, '\P{^Lb=-NU}', "");
Expect(0, 120832, '\p{Lb=-NU}', "");
Expect(1, 120832, '\p{^Lb=-NU}', "");
Expect(1, 120832, '\P{Lb=-NU}', "");
Expect(0, 120832, '\P{^Lb=-NU}', "");
Error('\p{Is_Line_Break=/a/-	numeric}');
Error('\P{Is_Line_Break=/a/-	numeric}');
Expect(1, 120831, '\p{Is_Line_Break=numeric}', "");
Expect(0, 120831, '\p{^Is_Line_Break=numeric}', "");
Expect(0, 120831, '\P{Is_Line_Break=numeric}', "");
Expect(1, 120831, '\P{^Is_Line_Break=numeric}', "");
Expect(0, 120832, '\p{Is_Line_Break=numeric}', "");
Expect(1, 120832, '\p{^Is_Line_Break=numeric}', "");
Expect(1, 120832, '\P{Is_Line_Break=numeric}', "");
Expect(0, 120832, '\P{^Is_Line_Break=numeric}', "");
Expect(1, 120831, '\p{Is_Line_Break=NUMERIC}', "");
Expect(0, 120831, '\p{^Is_Line_Break=NUMERIC}', "");
Expect(0, 120831, '\P{Is_Line_Break=NUMERIC}', "");
Expect(1, 120831, '\P{^Is_Line_Break=NUMERIC}', "");
Expect(0, 120832, '\p{Is_Line_Break=NUMERIC}', "");
Expect(1, 120832, '\p{^Is_Line_Break=NUMERIC}', "");
Expect(1, 120832, '\P{Is_Line_Break=NUMERIC}', "");
Expect(0, 120832, '\P{^Is_Line_Break=NUMERIC}', "");
Error('\p{Is_Lb=:=nu}');
Error('\P{Is_Lb=:=nu}');
Expect(1, 120831, '\p{Is_Lb=nu}', "");
Expect(0, 120831, '\p{^Is_Lb=nu}', "");
Expect(0, 120831, '\P{Is_Lb=nu}', "");
Expect(1, 120831, '\P{^Is_Lb=nu}', "");
Expect(0, 120832, '\p{Is_Lb=nu}', "");
Expect(1, 120832, '\p{^Is_Lb=nu}', "");
Expect(1, 120832, '\P{Is_Lb=nu}', "");
Expect(0, 120832, '\P{^Is_Lb=nu}', "");
Expect(1, 120831, '\p{Is_Lb: 	_nu}', "");
Expect(0, 120831, '\p{^Is_Lb: 	_nu}', "");
Expect(0, 120831, '\P{Is_Lb: 	_nu}', "");
Expect(1, 120831, '\P{^Is_Lb: 	_nu}', "");
Expect(0, 120832, '\p{Is_Lb: 	_nu}', "");
Expect(1, 120832, '\p{^Is_Lb: 	_nu}', "");
Expect(1, 120832, '\P{Is_Lb: 	_nu}', "");
Expect(0, 120832, '\P{^Is_Lb: 	_nu}', "");
Error('\p{Line_Break=:=_open_punctuation}');
Error('\P{Line_Break=:=_open_punctuation}');
Expect(1, 78713, '\p{Line_Break=openpunctuation}', "");
Expect(0, 78713, '\p{^Line_Break=openpunctuation}', "");
Expect(0, 78713, '\P{Line_Break=openpunctuation}', "");
Expect(1, 78713, '\P{^Line_Break=openpunctuation}', "");
Expect(0, 78714, '\p{Line_Break=openpunctuation}', "");
Expect(1, 78714, '\p{^Line_Break=openpunctuation}', "");
Expect(1, 78714, '\P{Line_Break=openpunctuation}', "");
Expect(0, 78714, '\P{^Line_Break=openpunctuation}', "");
Expect(1, 78713, '\p{Line_Break=	Open_PUNCTUATION}', "");
Expect(0, 78713, '\p{^Line_Break=	Open_PUNCTUATION}', "");
Expect(0, 78713, '\P{Line_Break=	Open_PUNCTUATION}', "");
Expect(1, 78713, '\P{^Line_Break=	Open_PUNCTUATION}', "");
Expect(0, 78714, '\p{Line_Break=	Open_PUNCTUATION}', "");
Expect(1, 78714, '\p{^Line_Break=	Open_PUNCTUATION}', "");
Expect(1, 78714, '\P{Line_Break=	Open_PUNCTUATION}', "");
Expect(0, 78714, '\P{^Line_Break=	Open_PUNCTUATION}', "");
Error('\p{Lb= :=OP}');
Error('\P{Lb= :=OP}');
Expect(1, 78713, '\p{Lb=op}', "");
Expect(0, 78713, '\p{^Lb=op}', "");
Expect(0, 78713, '\P{Lb=op}', "");
Expect(1, 78713, '\P{^Lb=op}', "");
Expect(0, 78714, '\p{Lb=op}', "");
Expect(1, 78714, '\p{^Lb=op}', "");
Expect(1, 78714, '\P{Lb=op}', "");
Expect(0, 78714, '\P{^Lb=op}', "");
Expect(1, 78713, '\p{Lb=__OP}', "");
Expect(0, 78713, '\p{^Lb=__OP}', "");
Expect(0, 78713, '\P{Lb=__OP}', "");
Expect(1, 78713, '\P{^Lb=__OP}', "");
Expect(0, 78714, '\p{Lb=__OP}', "");
Expect(1, 78714, '\p{^Lb=__OP}', "");
Expect(1, 78714, '\P{Lb=__OP}', "");
Expect(0, 78714, '\P{^Lb=__OP}', "");
Error('\p{Is_Line_Break=/a/open_punctuation}');
Error('\P{Is_Line_Break=/a/open_punctuation}');
Expect(1, 78713, '\p{Is_Line_Break=openpunctuation}', "");
Expect(0, 78713, '\p{^Is_Line_Break=openpunctuation}', "");
Expect(0, 78713, '\P{Is_Line_Break=openpunctuation}', "");
Expect(1, 78713, '\P{^Is_Line_Break=openpunctuation}', "");
Expect(0, 78714, '\p{Is_Line_Break=openpunctuation}', "");
Expect(1, 78714, '\p{^Is_Line_Break=openpunctuation}', "");
Expect(1, 78714, '\P{Is_Line_Break=openpunctuation}', "");
Expect(0, 78714, '\P{^Is_Line_Break=openpunctuation}', "");
Expect(1, 78713, '\p{Is_Line_Break=- OPEN_PUNCTUATION}', "");
Expect(0, 78713, '\p{^Is_Line_Break=- OPEN_PUNCTUATION}', "");
Expect(0, 78713, '\P{Is_Line_Break=- OPEN_PUNCTUATION}', "");
Expect(1, 78713, '\P{^Is_Line_Break=- OPEN_PUNCTUATION}', "");
Expect(0, 78714, '\p{Is_Line_Break=- OPEN_PUNCTUATION}', "");
Expect(1, 78714, '\p{^Is_Line_Break=- OPEN_PUNCTUATION}', "");
Expect(1, 78714, '\P{Is_Line_Break=- OPEN_PUNCTUATION}', "");
Expect(0, 78714, '\P{^Is_Line_Break=- OPEN_PUNCTUATION}', "");
Error('\p{Is_Lb=:=_	OP}');
Error('\P{Is_Lb=:=_	OP}');
Expect(1, 78713, '\p{Is_Lb=op}', "");
Expect(0, 78713, '\p{^Is_Lb=op}', "");
Expect(0, 78713, '\P{Is_Lb=op}', "");
Expect(1, 78713, '\P{^Is_Lb=op}', "");
Expect(0, 78714, '\p{Is_Lb=op}', "");
Expect(1, 78714, '\p{^Is_Lb=op}', "");
Expect(1, 78714, '\P{Is_Lb=op}', "");
Expect(0, 78714, '\P{^Is_Lb=op}', "");
Expect(1, 78713, '\p{Is_Lb:__OP}', "");
Expect(0, 78713, '\p{^Is_Lb:__OP}', "");
Expect(0, 78713, '\P{Is_Lb:__OP}', "");
Expect(1, 78713, '\P{^Is_Lb:__OP}', "");
Expect(0, 78714, '\p{Is_Lb:__OP}', "");
Expect(1, 78714, '\p{^Is_Lb:__OP}', "");
Expect(1, 78714, '\P{Is_Lb:__OP}', "");
Expect(0, 78714, '\P{^Is_Lb:__OP}', "");
Error('\p{Line_Break=-_Postfix_NUMERIC/a/}');
Error('\P{Line_Break=-_Postfix_NUMERIC/a/}');
Expect(1, 65504, '\p{Line_Break=postfixnumeric}', "");
Expect(0, 65504, '\p{^Line_Break=postfixnumeric}', "");
Expect(0, 65504, '\P{Line_Break=postfixnumeric}', "");
Expect(1, 65504, '\P{^Line_Break=postfixnumeric}', "");
Expect(0, 65505, '\p{Line_Break=postfixnumeric}', "");
Expect(1, 65505, '\p{^Line_Break=postfixnumeric}', "");
Expect(1, 65505, '\P{Line_Break=postfixnumeric}', "");
Expect(0, 65505, '\P{^Line_Break=postfixnumeric}', "");
Expect(1, 65504, '\p{Line_Break=	-Postfix_NUMERIC}', "");
Expect(0, 65504, '\p{^Line_Break=	-Postfix_NUMERIC}', "");
Expect(0, 65504, '\P{Line_Break=	-Postfix_NUMERIC}', "");
Expect(1, 65504, '\P{^Line_Break=	-Postfix_NUMERIC}', "");
Expect(0, 65505, '\p{Line_Break=	-Postfix_NUMERIC}', "");
Expect(1, 65505, '\p{^Line_Break=	-Postfix_NUMERIC}', "");
Expect(1, 65505, '\P{Line_Break=	-Postfix_NUMERIC}', "");
Expect(0, 65505, '\P{^Line_Break=	-Postfix_NUMERIC}', "");
Error('\p{Lb=/a/-_PO}');
Error('\P{Lb=/a/-_PO}');
Expect(1, 65504, '\p{Lb: po}', "");
Expect(0, 65504, '\p{^Lb: po}', "");
Expect(0, 65504, '\P{Lb: po}', "");
Expect(1, 65504, '\P{^Lb: po}', "");
Expect(0, 65505, '\p{Lb: po}', "");
Expect(1, 65505, '\p{^Lb: po}', "");
Expect(1, 65505, '\P{Lb: po}', "");
Expect(0, 65505, '\P{^Lb: po}', "");
Expect(1, 65504, '\p{Lb=_PO}', "");
Expect(0, 65504, '\p{^Lb=_PO}', "");
Expect(0, 65504, '\P{Lb=_PO}', "");
Expect(1, 65504, '\P{^Lb=_PO}', "");
Expect(0, 65505, '\p{Lb=_PO}', "");
Expect(1, 65505, '\p{^Lb=_PO}', "");
Expect(1, 65505, '\P{Lb=_PO}', "");
Expect(0, 65505, '\P{^Lb=_PO}', "");
Error('\p{Is_Line_Break=:=-Postfix_Numeric}');
Error('\P{Is_Line_Break=:=-Postfix_Numeric}');
Expect(1, 65504, '\p{Is_Line_Break=postfixnumeric}', "");
Expect(0, 65504, '\p{^Is_Line_Break=postfixnumeric}', "");
Expect(0, 65504, '\P{Is_Line_Break=postfixnumeric}', "");
Expect(1, 65504, '\P{^Is_Line_Break=postfixnumeric}', "");
Expect(0, 65505, '\p{Is_Line_Break=postfixnumeric}', "");
Expect(1, 65505, '\p{^Is_Line_Break=postfixnumeric}', "");
Expect(1, 65505, '\P{Is_Line_Break=postfixnumeric}', "");
Expect(0, 65505, '\P{^Is_Line_Break=postfixnumeric}', "");
Expect(1, 65504, '\p{Is_Line_Break= -Postfix_NUMERIC}', "");
Expect(0, 65504, '\p{^Is_Line_Break= -Postfix_NUMERIC}', "");
Expect(0, 65504, '\P{Is_Line_Break= -Postfix_NUMERIC}', "");
Expect(1, 65504, '\P{^Is_Line_Break= -Postfix_NUMERIC}', "");
Expect(0, 65505, '\p{Is_Line_Break= -Postfix_NUMERIC}', "");
Expect(1, 65505, '\p{^Is_Line_Break= -Postfix_NUMERIC}', "");
Expect(1, 65505, '\P{Is_Line_Break= -Postfix_NUMERIC}', "");
Expect(0, 65505, '\P{^Is_Line_Break= -Postfix_NUMERIC}', "");
Error('\p{Is_Lb=_:=PO}');
Error('\P{Is_Lb=_:=PO}');
Expect(1, 65504, '\p{Is_Lb=po}', "");
Expect(0, 65504, '\p{^Is_Lb=po}', "");
Expect(0, 65504, '\P{Is_Lb=po}', "");
Expect(1, 65504, '\P{^Is_Lb=po}', "");
Expect(0, 65505, '\p{Is_Lb=po}', "");
Expect(1, 65505, '\p{^Is_Lb=po}', "");
Expect(1, 65505, '\P{Is_Lb=po}', "");
Expect(0, 65505, '\P{^Is_Lb=po}', "");
Expect(1, 65504, '\p{Is_Lb:	 PO}', "");
Expect(0, 65504, '\p{^Is_Lb:	 PO}', "");
Expect(0, 65504, '\P{Is_Lb:	 PO}', "");
Expect(1, 65504, '\P{^Is_Lb:	 PO}', "");
Expect(0, 65505, '\p{Is_Lb:	 PO}', "");
Expect(1, 65505, '\p{^Is_Lb:	 PO}', "");
Expect(1, 65505, '\P{Is_Lb:	 PO}', "");
Expect(0, 65505, '\P{^Is_Lb:	 PO}', "");
Error('\p{Line_Break=_ prefix_Numeric/a/}');
Error('\P{Line_Break=_ prefix_Numeric/a/}');
Expect(1, 65510, '\p{Line_Break=prefixnumeric}', "");
Expect(0, 65510, '\p{^Line_Break=prefixnumeric}', "");
Expect(0, 65510, '\P{Line_Break=prefixnumeric}', "");
Expect(1, 65510, '\P{^Line_Break=prefixnumeric}', "");
Expect(0, 65511, '\p{Line_Break=prefixnumeric}', "");
Expect(1, 65511, '\p{^Line_Break=prefixnumeric}', "");
Expect(1, 65511, '\P{Line_Break=prefixnumeric}', "");
Expect(0, 65511, '\P{^Line_Break=prefixnumeric}', "");
Expect(1, 65510, '\p{Line_Break=-prefix_numeric}', "");
Expect(0, 65510, '\p{^Line_Break=-prefix_numeric}', "");
Expect(0, 65510, '\P{Line_Break=-prefix_numeric}', "");
Expect(1, 65510, '\P{^Line_Break=-prefix_numeric}', "");
Expect(0, 65511, '\p{Line_Break=-prefix_numeric}', "");
Expect(1, 65511, '\p{^Line_Break=-prefix_numeric}', "");
Expect(1, 65511, '\P{Line_Break=-prefix_numeric}', "");
Expect(0, 65511, '\P{^Line_Break=-prefix_numeric}', "");
Error('\p{Lb= _PR/a/}');
Error('\P{Lb= _PR/a/}');
Expect(1, 65510, '\p{Lb=pr}', "");
Expect(0, 65510, '\p{^Lb=pr}', "");
Expect(0, 65510, '\P{Lb=pr}', "");
Expect(1, 65510, '\P{^Lb=pr}', "");
Expect(0, 65511, '\p{Lb=pr}', "");
Expect(1, 65511, '\p{^Lb=pr}', "");
Expect(1, 65511, '\P{Lb=pr}', "");
Expect(0, 65511, '\P{^Lb=pr}', "");
Expect(1, 65510, '\p{Lb=		pr}', "");
Expect(0, 65510, '\p{^Lb=		pr}', "");
Expect(0, 65510, '\P{Lb=		pr}', "");
Expect(1, 65510, '\P{^Lb=		pr}', "");
Expect(0, 65511, '\p{Lb=		pr}', "");
Expect(1, 65511, '\p{^Lb=		pr}', "");
Expect(1, 65511, '\P{Lb=		pr}', "");
Expect(0, 65511, '\P{^Lb=		pr}', "");
Error('\p{Is_Line_Break=/a/ -Prefix_Numeric}');
Error('\P{Is_Line_Break=/a/ -Prefix_Numeric}');
Expect(1, 65510, '\p{Is_Line_Break=prefixnumeric}', "");
Expect(0, 65510, '\p{^Is_Line_Break=prefixnumeric}', "");
Expect(0, 65510, '\P{Is_Line_Break=prefixnumeric}', "");
Expect(1, 65510, '\P{^Is_Line_Break=prefixnumeric}', "");
Expect(0, 65511, '\p{Is_Line_Break=prefixnumeric}', "");
Expect(1, 65511, '\p{^Is_Line_Break=prefixnumeric}', "");
Expect(1, 65511, '\P{Is_Line_Break=prefixnumeric}', "");
Expect(0, 65511, '\P{^Is_Line_Break=prefixnumeric}', "");
Expect(1, 65510, '\p{Is_Line_Break=  prefix_Numeric}', "");
Expect(0, 65510, '\p{^Is_Line_Break=  prefix_Numeric}', "");
Expect(0, 65510, '\P{Is_Line_Break=  prefix_Numeric}', "");
Expect(1, 65510, '\P{^Is_Line_Break=  prefix_Numeric}', "");
Expect(0, 65511, '\p{Is_Line_Break=  prefix_Numeric}', "");
Expect(1, 65511, '\p{^Is_Line_Break=  prefix_Numeric}', "");
Expect(1, 65511, '\P{Is_Line_Break=  prefix_Numeric}', "");
Expect(0, 65511, '\P{^Is_Line_Break=  prefix_Numeric}', "");
Error('\p{Is_Lb=:=PR}');
Error('\P{Is_Lb=:=PR}');
Expect(1, 65510, '\p{Is_Lb=pr}', "");
Expect(0, 65510, '\p{^Is_Lb=pr}', "");
Expect(0, 65510, '\P{Is_Lb=pr}', "");
Expect(1, 65510, '\P{^Is_Lb=pr}', "");
Expect(0, 65511, '\p{Is_Lb=pr}', "");
Expect(1, 65511, '\p{^Is_Lb=pr}', "");
Expect(1, 65511, '\P{Is_Lb=pr}', "");
Expect(0, 65511, '\P{^Is_Lb=pr}', "");
Expect(1, 65510, '\p{Is_Lb:  PR}', "");
Expect(0, 65510, '\p{^Is_Lb:  PR}', "");
Expect(0, 65510, '\P{Is_Lb:  PR}', "");
Expect(1, 65510, '\P{^Is_Lb:  PR}', "");
Expect(0, 65511, '\p{Is_Lb:  PR}', "");
Expect(1, 65511, '\p{^Is_Lb:  PR}', "");
Expect(1, 65511, '\P{Is_Lb:  PR}', "");
Expect(0, 65511, '\P{^Is_Lb:  PR}', "");
Error('\p{Line_Break=:= _quotation}');
Error('\P{Line_Break=:= _quotation}');
Expect(1, 11809, '\p{Line_Break:	quotation}', "");
Expect(0, 11809, '\p{^Line_Break:	quotation}', "");
Expect(0, 11809, '\P{Line_Break:	quotation}', "");
Expect(1, 11809, '\P{^Line_Break:	quotation}', "");
Expect(0, 11810, '\p{Line_Break:	quotation}', "");
Expect(1, 11810, '\p{^Line_Break:	quotation}', "");
Expect(1, 11810, '\P{Line_Break:	quotation}', "");
Expect(0, 11810, '\P{^Line_Break:	quotation}', "");
Expect(1, 11809, '\p{Line_Break:  _quotation}', "");
Expect(0, 11809, '\p{^Line_Break:  _quotation}', "");
Expect(0, 11809, '\P{Line_Break:  _quotation}', "");
Expect(1, 11809, '\P{^Line_Break:  _quotation}', "");
Expect(0, 11810, '\p{Line_Break:  _quotation}', "");
Expect(1, 11810, '\p{^Line_Break:  _quotation}', "");
Expect(1, 11810, '\P{Line_Break:  _quotation}', "");
Expect(0, 11810, '\P{^Line_Break:  _quotation}', "");
Error('\p{Lb=/a/qu}');
Error('\P{Lb=/a/qu}');
Expect(1, 11809, '\p{Lb=qu}', "");
Expect(0, 11809, '\p{^Lb=qu}', "");
Expect(0, 11809, '\P{Lb=qu}', "");
Expect(1, 11809, '\P{^Lb=qu}', "");
Expect(0, 11810, '\p{Lb=qu}', "");
Expect(1, 11810, '\p{^Lb=qu}', "");
Expect(1, 11810, '\P{Lb=qu}', "");
Expect(0, 11810, '\P{^Lb=qu}', "");
Expect(1, 11809, '\p{Lb=	-QU}', "");
Expect(0, 11809, '\p{^Lb=	-QU}', "");
Expect(0, 11809, '\P{Lb=	-QU}', "");
Expect(1, 11809, '\P{^Lb=	-QU}', "");
Expect(0, 11810, '\p{Lb=	-QU}', "");
Expect(1, 11810, '\p{^Lb=	-QU}', "");
Expect(1, 11810, '\P{Lb=	-QU}', "");
Expect(0, 11810, '\P{^Lb=	-QU}', "");
Error('\p{Is_Line_Break=	-Quotation/a/}');
Error('\P{Is_Line_Break=	-Quotation/a/}');
Expect(1, 11809, '\p{Is_Line_Break=quotation}', "");
Expect(0, 11809, '\p{^Is_Line_Break=quotation}', "");
Expect(0, 11809, '\P{Is_Line_Break=quotation}', "");
Expect(1, 11809, '\P{^Is_Line_Break=quotation}', "");
Expect(0, 11810, '\p{Is_Line_Break=quotation}', "");
Expect(1, 11810, '\p{^Is_Line_Break=quotation}', "");
Expect(1, 11810, '\P{Is_Line_Break=quotation}', "");
Expect(0, 11810, '\P{^Is_Line_Break=quotation}', "");
Expect(1, 11809, '\p{Is_Line_Break=-	Quotation}', "");
Expect(0, 11809, '\p{^Is_Line_Break=-	Quotation}', "");
Expect(0, 11809, '\P{Is_Line_Break=-	Quotation}', "");
Expect(1, 11809, '\P{^Is_Line_Break=-	Quotation}', "");
Expect(0, 11810, '\p{Is_Line_Break=-	Quotation}', "");
Expect(1, 11810, '\p{^Is_Line_Break=-	Quotation}', "");
Expect(1, 11810, '\P{Is_Line_Break=-	Quotation}', "");
Expect(0, 11810, '\P{^Is_Line_Break=-	Quotation}', "");
Error('\p{Is_Lb=:=-QU}');
Error('\P{Is_Lb=:=-QU}');
Expect(1, 11809, '\p{Is_Lb=qu}', "");
Expect(0, 11809, '\p{^Is_Lb=qu}', "");
Expect(0, 11809, '\P{Is_Lb=qu}', "");
Expect(1, 11809, '\P{^Is_Lb=qu}', "");
Expect(0, 11810, '\p{Is_Lb=qu}', "");
Expect(1, 11810, '\p{^Is_Lb=qu}', "");
Expect(1, 11810, '\P{Is_Lb=qu}', "");
Expect(0, 11810, '\P{^Is_Lb=qu}', "");
Expect(1, 11809, '\p{Is_Lb=__QU}', "");
Expect(0, 11809, '\p{^Is_Lb=__QU}', "");
Expect(0, 11809, '\P{Is_Lb=__QU}', "");
Expect(1, 11809, '\P{^Is_Lb=__QU}', "");
Expect(0, 11810, '\p{Is_Lb=__QU}', "");
Expect(1, 11810, '\p{^Is_Lb=__QU}', "");
Expect(1, 11810, '\P{Is_Lb=__QU}', "");
Expect(0, 11810, '\P{^Is_Lb=__QU}', "");
Error('\p{Line_Break=:=	 regional_indicator}');
Error('\P{Line_Break=:=	 regional_indicator}');
Expect(1, 127487, '\p{Line_Break=regionalindicator}', "");
Expect(0, 127487, '\p{^Line_Break=regionalindicator}', "");
Expect(0, 127487, '\P{Line_Break=regionalindicator}', "");
Expect(1, 127487, '\P{^Line_Break=regionalindicator}', "");
Expect(0, 127488, '\p{Line_Break=regionalindicator}', "");
Expect(1, 127488, '\p{^Line_Break=regionalindicator}', "");
Expect(1, 127488, '\P{Line_Break=regionalindicator}', "");
Expect(0, 127488, '\P{^Line_Break=regionalindicator}', "");
Expect(1, 127487, '\p{Line_Break=-	regional_indicator}', "");
Expect(0, 127487, '\p{^Line_Break=-	regional_indicator}', "");
Expect(0, 127487, '\P{Line_Break=-	regional_indicator}', "");
Expect(1, 127487, '\P{^Line_Break=-	regional_indicator}', "");
Expect(0, 127488, '\p{Line_Break=-	regional_indicator}', "");
Expect(1, 127488, '\p{^Line_Break=-	regional_indicator}', "");
Expect(1, 127488, '\P{Line_Break=-	regional_indicator}', "");
Expect(0, 127488, '\P{^Line_Break=-	regional_indicator}', "");
Error('\p{Lb=:=-	RI}');
Error('\P{Lb=:=-	RI}');
Expect(1, 127487, '\p{Lb=ri}', "");
Expect(0, 127487, '\p{^Lb=ri}', "");
Expect(0, 127487, '\P{Lb=ri}', "");
Expect(1, 127487, '\P{^Lb=ri}', "");
Expect(0, 127488, '\p{Lb=ri}', "");
Expect(1, 127488, '\p{^Lb=ri}', "");
Expect(1, 127488, '\P{Lb=ri}', "");
Expect(0, 127488, '\P{^Lb=ri}', "");
Expect(1, 127487, '\p{Lb=_-RI}', "");
Expect(0, 127487, '\p{^Lb=_-RI}', "");
Expect(0, 127487, '\P{Lb=_-RI}', "");
Expect(1, 127487, '\P{^Lb=_-RI}', "");
Expect(0, 127488, '\p{Lb=_-RI}', "");
Expect(1, 127488, '\p{^Lb=_-RI}', "");
Expect(1, 127488, '\P{Lb=_-RI}', "");
Expect(0, 127488, '\P{^Lb=_-RI}', "");
Error('\p{Is_Line_Break=_/a/Regional_Indicator}');
Error('\P{Is_Line_Break=_/a/Regional_Indicator}');
Expect(1, 127487, '\p{Is_Line_Break:	regionalindicator}', "");
Expect(0, 127487, '\p{^Is_Line_Break:	regionalindicator}', "");
Expect(0, 127487, '\P{Is_Line_Break:	regionalindicator}', "");
Expect(1, 127487, '\P{^Is_Line_Break:	regionalindicator}', "");
Expect(0, 127488, '\p{Is_Line_Break:	regionalindicator}', "");
Expect(1, 127488, '\p{^Is_Line_Break:	regionalindicator}', "");
Expect(1, 127488, '\P{Is_Line_Break:	regionalindicator}', "");
Expect(0, 127488, '\P{^Is_Line_Break:	regionalindicator}', "");
Expect(1, 127487, '\p{Is_Line_Break=-_Regional_INDICATOR}', "");
Expect(0, 127487, '\p{^Is_Line_Break=-_Regional_INDICATOR}', "");
Expect(0, 127487, '\P{Is_Line_Break=-_Regional_INDICATOR}', "");
Expect(1, 127487, '\P{^Is_Line_Break=-_Regional_INDICATOR}', "");
Expect(0, 127488, '\p{Is_Line_Break=-_Regional_INDICATOR}', "");
Expect(1, 127488, '\p{^Is_Line_Break=-_Regional_INDICATOR}', "");
Expect(1, 127488, '\P{Is_Line_Break=-_Regional_INDICATOR}', "");
Expect(0, 127488, '\P{^Is_Line_Break=-_Regional_INDICATOR}', "");
Error('\p{Is_Lb=/a/	 ri}');
Error('\P{Is_Lb=/a/	 ri}');
Expect(1, 127487, '\p{Is_Lb=ri}', "");
Expect(0, 127487, '\p{^Is_Lb=ri}', "");
Expect(0, 127487, '\P{Is_Lb=ri}', "");
Expect(1, 127487, '\P{^Is_Lb=ri}', "");
Expect(0, 127488, '\p{Is_Lb=ri}', "");
Expect(1, 127488, '\p{^Is_Lb=ri}', "");
Expect(1, 127488, '\P{Is_Lb=ri}', "");
Expect(0, 127488, '\P{^Is_Lb=ri}', "");
Expect(1, 127487, '\p{Is_Lb=  RI}', "");
Expect(0, 127487, '\p{^Is_Lb=  RI}', "");
Expect(0, 127487, '\P{Is_Lb=  RI}', "");
Expect(1, 127487, '\P{^Is_Lb=  RI}', "");
Expect(0, 127488, '\p{Is_Lb=  RI}', "");
Expect(1, 127488, '\p{^Is_Lb=  RI}', "");
Expect(1, 127488, '\P{Is_Lb=  RI}', "");
Expect(0, 127488, '\P{^Is_Lb=  RI}', "");
Error('\p{Line_Break=		Complex_context:=}');
Error('\P{Line_Break=		Complex_context:=}');
Expect(1, 43743, '\p{Line_Break=complexcontext}', "");
Expect(0, 43743, '\p{^Line_Break=complexcontext}', "");
Expect(0, 43743, '\P{Line_Break=complexcontext}', "");
Expect(1, 43743, '\P{^Line_Break=complexcontext}', "");
Expect(0, 43744, '\p{Line_Break=complexcontext}', "");
Expect(1, 43744, '\p{^Line_Break=complexcontext}', "");
Expect(1, 43744, '\P{Line_Break=complexcontext}', "");
Expect(0, 43744, '\P{^Line_Break=complexcontext}', "");
Expect(1, 43743, '\p{Line_Break= Complex_context}', "");
Expect(0, 43743, '\p{^Line_Break= Complex_context}', "");
Expect(0, 43743, '\P{Line_Break= Complex_context}', "");
Expect(1, 43743, '\P{^Line_Break= Complex_context}', "");
Expect(0, 43744, '\p{Line_Break= Complex_context}', "");
Expect(1, 43744, '\p{^Line_Break= Complex_context}', "");
Expect(1, 43744, '\P{Line_Break= Complex_context}', "");
Expect(0, 43744, '\P{^Line_Break= Complex_context}', "");
Error('\p{Lb=/a/_ SA}');
Error('\P{Lb=/a/_ SA}');
Expect(1, 43743, '\p{Lb=sa}', "");
Expect(0, 43743, '\p{^Lb=sa}', "");
Expect(0, 43743, '\P{Lb=sa}', "");
Expect(1, 43743, '\P{^Lb=sa}', "");
Expect(0, 43744, '\p{Lb=sa}', "");
Expect(1, 43744, '\p{^Lb=sa}', "");
Expect(1, 43744, '\P{Lb=sa}', "");
Expect(0, 43744, '\P{^Lb=sa}', "");
Expect(1, 43743, '\p{Lb=SA}', "");
Expect(0, 43743, '\p{^Lb=SA}', "");
Expect(0, 43743, '\P{Lb=SA}', "");
Expect(1, 43743, '\P{^Lb=SA}', "");
Expect(0, 43744, '\p{Lb=SA}', "");
Expect(1, 43744, '\p{^Lb=SA}', "");
Expect(1, 43744, '\P{Lb=SA}', "");
Expect(0, 43744, '\P{^Lb=SA}', "");
Error('\p{Is_Line_Break=:=Complex_Context}');
Error('\P{Is_Line_Break=:=Complex_Context}');
Expect(1, 43743, '\p{Is_Line_Break: complexcontext}', "");
Expect(0, 43743, '\p{^Is_Line_Break: complexcontext}', "");
Expect(0, 43743, '\P{Is_Line_Break: complexcontext}', "");
Expect(1, 43743, '\P{^Is_Line_Break: complexcontext}', "");
Expect(0, 43744, '\p{Is_Line_Break: complexcontext}', "");
Expect(1, 43744, '\p{^Is_Line_Break: complexcontext}', "");
Expect(1, 43744, '\P{Is_Line_Break: complexcontext}', "");
Expect(0, 43744, '\P{^Is_Line_Break: complexcontext}', "");
Expect(1, 43743, '\p{Is_Line_Break=	 Complex_Context}', "");
Expect(0, 43743, '\p{^Is_Line_Break=	 Complex_Context}', "");
Expect(0, 43743, '\P{Is_Line_Break=	 Complex_Context}', "");
Expect(1, 43743, '\P{^Is_Line_Break=	 Complex_Context}', "");
Expect(0, 43744, '\p{Is_Line_Break=	 Complex_Context}', "");
Expect(1, 43744, '\p{^Is_Line_Break=	 Complex_Context}', "");
Expect(1, 43744, '\P{Is_Line_Break=	 Complex_Context}', "");
Expect(0, 43744, '\P{^Is_Line_Break=	 Complex_Context}', "");
Error('\p{Is_Lb: /a/sa}');
Error('\P{Is_Lb: /a/sa}');
Expect(1, 43743, '\p{Is_Lb: sa}', "");
Expect(0, 43743, '\p{^Is_Lb: sa}', "");
Expect(0, 43743, '\P{Is_Lb: sa}', "");
Expect(1, 43743, '\P{^Is_Lb: sa}', "");
Expect(0, 43744, '\p{Is_Lb: sa}', "");
Expect(1, 43744, '\p{^Is_Lb: sa}', "");
Expect(1, 43744, '\P{Is_Lb: sa}', "");
Expect(0, 43744, '\P{^Is_Lb: sa}', "");
Expect(1, 43743, '\p{Is_Lb:    SA}', "");
Expect(0, 43743, '\p{^Is_Lb:    SA}', "");
Expect(0, 43743, '\P{Is_Lb:    SA}', "");
Expect(1, 43743, '\P{^Is_Lb:    SA}', "");
Expect(0, 43744, '\p{Is_Lb:    SA}', "");
Expect(1, 43744, '\p{^Is_Lb:    SA}', "");
Expect(1, 43744, '\P{Is_Lb:    SA}', "");
Expect(0, 43744, '\P{^Is_Lb:    SA}', "");
Error('\p{Line_Break=-	Surrogate/a/}');
Error('\P{Line_Break=-	Surrogate/a/}');
Expect(1, 57343, '\p{Line_Break=surrogate}', 'deprecated');
Expect(0, 57343, '\p{^Line_Break=surrogate}', 'deprecated');
Expect(0, 57343, '\P{Line_Break=surrogate}', 'deprecated');
Expect(1, 57343, '\P{^Line_Break=surrogate}', 'deprecated');
Expect(0, 57344, '\p{Line_Break=surrogate}', 'deprecated');
Expect(1, 57344, '\p{^Line_Break=surrogate}', 'deprecated');
Expect(1, 57344, '\P{Line_Break=surrogate}', 'deprecated');
Expect(0, 57344, '\P{^Line_Break=surrogate}', 'deprecated');
Expect(1, 57343, '\p{Line_Break=  SURROGATE}', 'deprecated');
Expect(0, 57343, '\p{^Line_Break=  SURROGATE}', 'deprecated');
Expect(0, 57343, '\P{Line_Break=  SURROGATE}', 'deprecated');
Expect(1, 57343, '\P{^Line_Break=  SURROGATE}', 'deprecated');
Expect(0, 57344, '\p{Line_Break=  SURROGATE}', 'deprecated');
Expect(1, 57344, '\p{^Line_Break=  SURROGATE}', 'deprecated');
Expect(1, 57344, '\P{Line_Break=  SURROGATE}', 'deprecated');
Expect(0, 57344, '\P{^Line_Break=  SURROGATE}', 'deprecated');
Error('\p{Lb=-/a/SG}');
Error('\P{Lb=-/a/SG}');
Expect(1, 57343, '\p{Lb=sg}', 'deprecated');
Expect(0, 57343, '\p{^Lb=sg}', 'deprecated');
Expect(0, 57343, '\P{Lb=sg}', 'deprecated');
Expect(1, 57343, '\P{^Lb=sg}', 'deprecated');
Expect(0, 57344, '\p{Lb=sg}', 'deprecated');
Expect(1, 57344, '\p{^Lb=sg}', 'deprecated');
Expect(1, 57344, '\P{Lb=sg}', 'deprecated');
Expect(0, 57344, '\P{^Lb=sg}', 'deprecated');
Expect(1, 57343, '\p{Lb:			sg}', 'deprecated');
Expect(0, 57343, '\p{^Lb:			sg}', 'deprecated');
Expect(0, 57343, '\P{Lb:			sg}', 'deprecated');
Expect(1, 57343, '\P{^Lb:			sg}', 'deprecated');
Expect(0, 57344, '\p{Lb:			sg}', 'deprecated');
Expect(1, 57344, '\p{^Lb:			sg}', 'deprecated');
Expect(1, 57344, '\P{Lb:			sg}', 'deprecated');
Expect(0, 57344, '\P{^Lb:			sg}', 'deprecated');
Error('\p{Is_Line_Break=:=-Surrogate}');
Error('\P{Is_Line_Break=:=-Surrogate}');
Expect(1, 57343, '\p{Is_Line_Break=surrogate}', 'deprecated');
Expect(0, 57343, '\p{^Is_Line_Break=surrogate}', 'deprecated');
Expect(0, 57343, '\P{Is_Line_Break=surrogate}', 'deprecated');
Expect(1, 57343, '\P{^Is_Line_Break=surrogate}', 'deprecated');
Expect(0, 57344, '\p{Is_Line_Break=surrogate}', 'deprecated');
Expect(1, 57344, '\p{^Is_Line_Break=surrogate}', 'deprecated');
Expect(1, 57344, '\P{Is_Line_Break=surrogate}', 'deprecated');
Expect(0, 57344, '\P{^Is_Line_Break=surrogate}', 'deprecated');
Expect(1, 57343, '\p{Is_Line_Break= _SURROGATE}', 'deprecated');
Expect(0, 57343, '\p{^Is_Line_Break= _SURROGATE}', 'deprecated');
Expect(0, 57343, '\P{Is_Line_Break= _SURROGATE}', 'deprecated');
Expect(1, 57343, '\P{^Is_Line_Break= _SURROGATE}', 'deprecated');
Expect(0, 57344, '\p{Is_Line_Break= _SURROGATE}', 'deprecated');
Expect(1, 57344, '\p{^Is_Line_Break= _SURROGATE}', 'deprecated');
Expect(1, 57344, '\P{Is_Line_Break= _SURROGATE}', 'deprecated');
Expect(0, 57344, '\P{^Is_Line_Break= _SURROGATE}', 'deprecated');
Error('\p{Is_Lb=-/a/SG}');
Error('\P{Is_Lb=-/a/SG}');
Expect(1, 57343, '\p{Is_Lb=sg}', 'deprecated');
Expect(0, 57343, '\p{^Is_Lb=sg}', 'deprecated');
Expect(0, 57343, '\P{Is_Lb=sg}', 'deprecated');
Expect(1, 57343, '\P{^Is_Lb=sg}', 'deprecated');
Expect(0, 57344, '\p{Is_Lb=sg}', 'deprecated');
Expect(1, 57344, '\p{^Is_Lb=sg}', 'deprecated');
Expect(1, 57344, '\P{Is_Lb=sg}', 'deprecated');
Expect(0, 57344, '\P{^Is_Lb=sg}', 'deprecated');
Expect(1, 57343, '\p{Is_Lb=-	SG}', 'deprecated');
Expect(0, 57343, '\p{^Is_Lb=-	SG}', 'deprecated');
Expect(0, 57343, '\P{Is_Lb=-	SG}', 'deprecated');
Expect(1, 57343, '\P{^Is_Lb=-	SG}', 'deprecated');
Expect(0, 57344, '\p{Is_Lb=-	SG}', 'deprecated');
Expect(1, 57344, '\p{^Is_Lb=-	SG}', 'deprecated');
Expect(1, 57344, '\P{Is_Lb=-	SG}', 'deprecated');
Expect(0, 57344, '\P{^Is_Lb=-	SG}', 'deprecated');
Error('\p{Line_Break=/a/ SPACE}');
Error('\P{Line_Break=/a/ SPACE}');
Expect(1, 32, '\p{Line_Break=space}', "");
Expect(0, 32, '\p{^Line_Break=space}', "");
Expect(0, 32, '\P{Line_Break=space}', "");
Expect(1, 32, '\P{^Line_Break=space}', "");
Expect(0, 33, '\p{Line_Break=space}', "");
Expect(1, 33, '\p{^Line_Break=space}', "");
Expect(1, 33, '\P{Line_Break=space}', "");
Expect(0, 33, '\P{^Line_Break=space}', "");
Expect(1, 32, '\p{Line_Break=_	Space}', "");
Expect(0, 32, '\p{^Line_Break=_	Space}', "");
Expect(0, 32, '\P{Line_Break=_	Space}', "");
Expect(1, 32, '\P{^Line_Break=_	Space}', "");
Expect(0, 33, '\p{Line_Break=_	Space}', "");
Expect(1, 33, '\p{^Line_Break=_	Space}', "");
Expect(1, 33, '\P{Line_Break=_	Space}', "");
Expect(0, 33, '\P{^Line_Break=_	Space}', "");
Error('\p{Lb=-:=SP}');
Error('\P{Lb=-:=SP}');
Expect(1, 32, '\p{Lb=sp}', "");
Expect(0, 32, '\p{^Lb=sp}', "");
Expect(0, 32, '\P{Lb=sp}', "");
Expect(1, 32, '\P{^Lb=sp}', "");
Expect(0, 33, '\p{Lb=sp}', "");
Expect(1, 33, '\p{^Lb=sp}', "");
Expect(1, 33, '\P{Lb=sp}', "");
Expect(0, 33, '\P{^Lb=sp}', "");
Expect(1, 32, '\p{Lb=-_SP}', "");
Expect(0, 32, '\p{^Lb=-_SP}', "");
Expect(0, 32, '\P{Lb=-_SP}', "");
Expect(1, 32, '\P{^Lb=-_SP}', "");
Expect(0, 33, '\p{Lb=-_SP}', "");
Expect(1, 33, '\p{^Lb=-_SP}', "");
Expect(1, 33, '\P{Lb=-_SP}', "");
Expect(0, 33, '\P{^Lb=-_SP}', "");
Error('\p{Is_Line_Break=/a/ Space}');
Error('\P{Is_Line_Break=/a/ Space}');
Expect(1, 32, '\p{Is_Line_Break=space}', "");
Expect(0, 32, '\p{^Is_Line_Break=space}', "");
Expect(0, 32, '\P{Is_Line_Break=space}', "");
Expect(1, 32, '\P{^Is_Line_Break=space}', "");
Expect(0, 33, '\p{Is_Line_Break=space}', "");
Expect(1, 33, '\p{^Is_Line_Break=space}', "");
Expect(1, 33, '\P{Is_Line_Break=space}', "");
Expect(0, 33, '\P{^Is_Line_Break=space}', "");
Expect(1, 32, '\p{Is_Line_Break=	 Space}', "");
Expect(0, 32, '\p{^Is_Line_Break=	 Space}', "");
Expect(0, 32, '\P{Is_Line_Break=	 Space}', "");
Expect(1, 32, '\P{^Is_Line_Break=	 Space}', "");
Expect(0, 33, '\p{Is_Line_Break=	 Space}', "");
Expect(1, 33, '\p{^Is_Line_Break=	 Space}', "");
Expect(1, 33, '\P{Is_Line_Break=	 Space}', "");
Expect(0, 33, '\P{^Is_Line_Break=	 Space}', "");
Error('\p{Is_Lb=-/a/SP}');
Error('\P{Is_Lb=-/a/SP}');
Expect(1, 32, '\p{Is_Lb=sp}', "");
Expect(0, 32, '\p{^Is_Lb=sp}', "");
Expect(0, 32, '\P{Is_Lb=sp}', "");
Expect(1, 32, '\P{^Is_Lb=sp}', "");
Expect(0, 33, '\p{Is_Lb=sp}', "");
Expect(1, 33, '\p{^Is_Lb=sp}', "");
Expect(1, 33, '\P{Is_Lb=sp}', "");
Expect(0, 33, '\P{^Is_Lb=sp}', "");
Expect(1, 32, '\p{Is_Lb=SP}', "");
Expect(0, 32, '\p{^Is_Lb=SP}', "");
Expect(0, 32, '\P{Is_Lb=SP}', "");
Expect(1, 32, '\P{^Is_Lb=SP}', "");
Expect(0, 33, '\p{Is_Lb=SP}', "");
Expect(1, 33, '\p{^Is_Lb=SP}', "");
Expect(1, 33, '\P{Is_Lb=SP}', "");
Expect(0, 33, '\P{^Is_Lb=SP}', "");
Error('\p{Line_Break=:=Break_SYMBOLS}');
Error('\P{Line_Break=:=Break_SYMBOLS}');
Expect(1, 47, '\p{Line_Break=breaksymbols}', "");
Expect(0, 47, '\p{^Line_Break=breaksymbols}', "");
Expect(0, 47, '\P{Line_Break=breaksymbols}', "");
Expect(1, 47, '\P{^Line_Break=breaksymbols}', "");
Expect(0, 48, '\p{Line_Break=breaksymbols}', "");
Expect(1, 48, '\p{^Line_Break=breaksymbols}', "");
Expect(1, 48, '\P{Line_Break=breaksymbols}', "");
Expect(0, 48, '\P{^Line_Break=breaksymbols}', "");
Expect(1, 47, '\p{Line_Break= break_SYMBOLS}', "");
Expect(0, 47, '\p{^Line_Break= break_SYMBOLS}', "");
Expect(0, 47, '\P{Line_Break= break_SYMBOLS}', "");
Expect(1, 47, '\P{^Line_Break= break_SYMBOLS}', "");
Expect(0, 48, '\p{Line_Break= break_SYMBOLS}', "");
Expect(1, 48, '\p{^Line_Break= break_SYMBOLS}', "");
Expect(1, 48, '\P{Line_Break= break_SYMBOLS}', "");
Expect(0, 48, '\P{^Line_Break= break_SYMBOLS}', "");
Error('\p{Lb=:=sy}');
Error('\P{Lb=:=sy}');
Expect(1, 47, '\p{Lb=sy}', "");
Expect(0, 47, '\p{^Lb=sy}', "");
Expect(0, 47, '\P{Lb=sy}', "");
Expect(1, 47, '\P{^Lb=sy}', "");
Expect(0, 48, '\p{Lb=sy}', "");
Expect(1, 48, '\p{^Lb=sy}', "");
Expect(1, 48, '\P{Lb=sy}', "");
Expect(0, 48, '\P{^Lb=sy}', "");
Expect(1, 47, '\p{Lb= SY}', "");
Expect(0, 47, '\p{^Lb= SY}', "");
Expect(0, 47, '\P{Lb= SY}', "");
Expect(1, 47, '\P{^Lb= SY}', "");
Expect(0, 48, '\p{Lb= SY}', "");
Expect(1, 48, '\p{^Lb= SY}', "");
Expect(1, 48, '\P{Lb= SY}', "");
Expect(0, 48, '\P{^Lb= SY}', "");
Error('\p{Is_Line_Break=--break_SYMBOLS:=}');
Error('\P{Is_Line_Break=--break_SYMBOLS:=}');
Expect(1, 47, '\p{Is_Line_Break=breaksymbols}', "");
Expect(0, 47, '\p{^Is_Line_Break=breaksymbols}', "");
Expect(0, 47, '\P{Is_Line_Break=breaksymbols}', "");
Expect(1, 47, '\P{^Is_Line_Break=breaksymbols}', "");
Expect(0, 48, '\p{Is_Line_Break=breaksymbols}', "");
Expect(1, 48, '\p{^Is_Line_Break=breaksymbols}', "");
Expect(1, 48, '\P{Is_Line_Break=breaksymbols}', "");
Expect(0, 48, '\P{^Is_Line_Break=breaksymbols}', "");
Expect(1, 47, '\p{Is_Line_Break=--BREAK_Symbols}', "");
Expect(0, 47, '\p{^Is_Line_Break=--BREAK_Symbols}', "");
Expect(0, 47, '\P{Is_Line_Break=--BREAK_Symbols}', "");
Expect(1, 47, '\P{^Is_Line_Break=--BREAK_Symbols}', "");
Expect(0, 48, '\p{Is_Line_Break=--BREAK_Symbols}', "");
Expect(1, 48, '\p{^Is_Line_Break=--BREAK_Symbols}', "");
Expect(1, 48, '\P{Is_Line_Break=--BREAK_Symbols}', "");
Expect(0, 48, '\P{^Is_Line_Break=--BREAK_Symbols}', "");
Error('\p{Is_Lb=:=_sy}');
Error('\P{Is_Lb=:=_sy}');
Expect(1, 47, '\p{Is_Lb=sy}', "");
Expect(0, 47, '\p{^Is_Lb=sy}', "");
Expect(0, 47, '\P{Is_Lb=sy}', "");
Expect(1, 47, '\P{^Is_Lb=sy}', "");
Expect(0, 48, '\p{Is_Lb=sy}', "");
Expect(1, 48, '\p{^Is_Lb=sy}', "");
Expect(1, 48, '\P{Is_Lb=sy}', "");
Expect(0, 48, '\P{^Is_Lb=sy}', "");
Expect(1, 47, '\p{Is_Lb=- SY}', "");
Expect(0, 47, '\p{^Is_Lb=- SY}', "");
Expect(0, 47, '\P{Is_Lb=- SY}', "");
Expect(1, 47, '\P{^Is_Lb=- SY}', "");
Expect(0, 48, '\p{Is_Lb=- SY}', "");
Expect(1, 48, '\p{^Is_Lb=- SY}', "");
Expect(1, 48, '\P{Is_Lb=- SY}', "");
Expect(0, 48, '\P{^Is_Lb=- SY}', "");
Error('\p{Line_Break:	_:=word_joiner}');
Error('\P{Line_Break:	_:=word_joiner}');
Expect(1, 65279, '\p{Line_Break=wordjoiner}', "");
Expect(0, 65279, '\p{^Line_Break=wordjoiner}', "");
Expect(0, 65279, '\P{Line_Break=wordjoiner}', "");
Expect(1, 65279, '\P{^Line_Break=wordjoiner}', "");
Expect(0, 65280, '\p{Line_Break=wordjoiner}', "");
Expect(1, 65280, '\p{^Line_Break=wordjoiner}', "");
Expect(1, 65280, '\P{Line_Break=wordjoiner}', "");
Expect(0, 65280, '\P{^Line_Break=wordjoiner}', "");
Expect(1, 65279, '\p{Line_Break= -WORD_joiner}', "");
Expect(0, 65279, '\p{^Line_Break= -WORD_joiner}', "");
Expect(0, 65279, '\P{Line_Break= -WORD_joiner}', "");
Expect(1, 65279, '\P{^Line_Break= -WORD_joiner}', "");
Expect(0, 65280, '\p{Line_Break= -WORD_joiner}', "");
Expect(1, 65280, '\p{^Line_Break= -WORD_joiner}', "");
Expect(1, 65280, '\P{Line_Break= -WORD_joiner}', "");
Expect(0, 65280, '\P{^Line_Break= -WORD_joiner}', "");
Error('\p{Lb=_/a/WJ}');
Error('\P{Lb=_/a/WJ}');
Expect(1, 65279, '\p{Lb=wj}', "");
Expect(0, 65279, '\p{^Lb=wj}', "");
Expect(0, 65279, '\P{Lb=wj}', "");
Expect(1, 65279, '\P{^Lb=wj}', "");
Expect(0, 65280, '\p{Lb=wj}', "");
Expect(1, 65280, '\p{^Lb=wj}', "");
Expect(1, 65280, '\P{Lb=wj}', "");
Expect(0, 65280, '\P{^Lb=wj}', "");
Expect(1, 65279, '\p{Lb=_wj}', "");
Expect(0, 65279, '\p{^Lb=_wj}', "");
Expect(0, 65279, '\P{Lb=_wj}', "");
Expect(1, 65279, '\P{^Lb=_wj}', "");
Expect(0, 65280, '\p{Lb=_wj}', "");
Expect(1, 65280, '\p{^Lb=_wj}', "");
Expect(1, 65280, '\P{Lb=_wj}', "");
Expect(0, 65280, '\P{^Lb=_wj}', "");
Error('\p{Is_Line_Break=_:=WORD_joiner}');
Error('\P{Is_Line_Break=_:=WORD_joiner}');
Expect(1, 65279, '\p{Is_Line_Break=wordjoiner}', "");
Expect(0, 65279, '\p{^Is_Line_Break=wordjoiner}', "");
Expect(0, 65279, '\P{Is_Line_Break=wordjoiner}', "");
Expect(1, 65279, '\P{^Is_Line_Break=wordjoiner}', "");
Expect(0, 65280, '\p{Is_Line_Break=wordjoiner}', "");
Expect(1, 65280, '\p{^Is_Line_Break=wordjoiner}', "");
Expect(1, 65280, '\P{Is_Line_Break=wordjoiner}', "");
Expect(0, 65280, '\P{^Is_Line_Break=wordjoiner}', "");
Expect(1, 65279, '\p{Is_Line_Break=	Word_Joiner}', "");
Expect(0, 65279, '\p{^Is_Line_Break=	Word_Joiner}', "");
Expect(0, 65279, '\P{Is_Line_Break=	Word_Joiner}', "");
Expect(1, 65279, '\P{^Is_Line_Break=	Word_Joiner}', "");
Expect(0, 65280, '\p{Is_Line_Break=	Word_Joiner}', "");
Expect(1, 65280, '\p{^Is_Line_Break=	Word_Joiner}', "");
Expect(1, 65280, '\P{Is_Line_Break=	Word_Joiner}', "");
Expect(0, 65280, '\P{^Is_Line_Break=	Word_Joiner}', "");
Error('\p{Is_Lb=-	WJ:=}');
Error('\P{Is_Lb=-	WJ:=}');
Expect(1, 65279, '\p{Is_Lb:   wj}', "");
Expect(0, 65279, '\p{^Is_Lb:   wj}', "");
Expect(0, 65279, '\P{Is_Lb:   wj}', "");
Expect(1, 65279, '\P{^Is_Lb:   wj}', "");
Expect(0, 65280, '\p{Is_Lb:   wj}', "");
Expect(1, 65280, '\p{^Is_Lb:   wj}', "");
Expect(1, 65280, '\P{Is_Lb:   wj}', "");
Expect(0, 65280, '\P{^Is_Lb:   wj}', "");
Expect(1, 65279, '\p{Is_Lb=  WJ}', "");
Expect(0, 65279, '\p{^Is_Lb=  WJ}', "");
Expect(0, 65279, '\P{Is_Lb=  WJ}', "");
Expect(1, 65279, '\P{^Is_Lb=  WJ}', "");
Expect(0, 65280, '\p{Is_Lb=  WJ}', "");
Expect(1, 65280, '\p{^Is_Lb=  WJ}', "");
Expect(1, 65280, '\P{Is_Lb=  WJ}', "");
Expect(0, 65280, '\P{^Is_Lb=  WJ}', "");
Error('\p{Line_Break=_Unknown/a/}');
Error('\P{Line_Break=_Unknown/a/}');
Expect(1, 918000, '\p{Line_Break=unknown}', "");
Expect(0, 918000, '\p{^Line_Break=unknown}', "");
Expect(0, 918000, '\P{Line_Break=unknown}', "");
Expect(1, 918000, '\P{^Line_Break=unknown}', "");
Expect(0, 917999, '\p{Line_Break=unknown}', "");
Expect(1, 917999, '\p{^Line_Break=unknown}', "");
Expect(1, 917999, '\P{Line_Break=unknown}', "");
Expect(0, 917999, '\P{^Line_Break=unknown}', "");
Expect(1, 918000, '\p{Line_Break=	-Unknown}', "");
Expect(0, 918000, '\p{^Line_Break=	-Unknown}', "");
Expect(0, 918000, '\P{Line_Break=	-Unknown}', "");
Expect(1, 918000, '\P{^Line_Break=	-Unknown}', "");
Expect(0, 917999, '\p{Line_Break=	-Unknown}', "");
Expect(1, 917999, '\p{^Line_Break=	-Unknown}', "");
Expect(1, 917999, '\P{Line_Break=	-Unknown}', "");
Expect(0, 917999, '\P{^Line_Break=	-Unknown}', "");
Error('\p{Lb=-	XX:=}');
Error('\P{Lb=-	XX:=}');
Expect(1, 918000, '\p{Lb=xx}', "");
Expect(0, 918000, '\p{^Lb=xx}', "");
Expect(0, 918000, '\P{Lb=xx}', "");
Expect(1, 918000, '\P{^Lb=xx}', "");
Expect(0, 917999, '\p{Lb=xx}', "");
Expect(1, 917999, '\p{^Lb=xx}', "");
Expect(1, 917999, '\P{Lb=xx}', "");
Expect(0, 917999, '\P{^Lb=xx}', "");
Expect(1, 918000, '\p{Lb=- XX}', "");
Expect(0, 918000, '\p{^Lb=- XX}', "");
Expect(0, 918000, '\P{Lb=- XX}', "");
Expect(1, 918000, '\P{^Lb=- XX}', "");
Expect(0, 917999, '\p{Lb=- XX}', "");
Expect(1, 917999, '\p{^Lb=- XX}', "");
Expect(1, 917999, '\P{Lb=- XX}', "");
Expect(0, 917999, '\P{^Lb=- XX}', "");
Error('\p{Is_Line_Break=:=-	unknown}');
Error('\P{Is_Line_Break=:=-	unknown}');
Expect(1, 918000, '\p{Is_Line_Break=unknown}', "");
Expect(0, 918000, '\p{^Is_Line_Break=unknown}', "");
Expect(0, 918000, '\P{Is_Line_Break=unknown}', "");
Expect(1, 918000, '\P{^Is_Line_Break=unknown}', "");
Expect(0, 917999, '\p{Is_Line_Break=unknown}', "");
Expect(1, 917999, '\p{^Is_Line_Break=unknown}', "");
Expect(1, 917999, '\P{Is_Line_Break=unknown}', "");
Expect(0, 917999, '\P{^Is_Line_Break=unknown}', "");
Expect(1, 918000, '\p{Is_Line_Break=--Unknown}', "");
Expect(0, 918000, '\p{^Is_Line_Break=--Unknown}', "");
Expect(0, 918000, '\P{Is_Line_Break=--Unknown}', "");
Expect(1, 918000, '\P{^Is_Line_Break=--Unknown}', "");
Expect(0, 917999, '\p{Is_Line_Break=--Unknown}', "");
Expect(1, 917999, '\p{^Is_Line_Break=--Unknown}', "");
Expect(1, 917999, '\P{Is_Line_Break=--Unknown}', "");
Expect(0, 917999, '\P{^Is_Line_Break=--Unknown}', "");
Error('\p{Is_Lb=-	XX:=}');
Error('\P{Is_Lb=-	XX:=}');
Expect(1, 918000, '\p{Is_Lb=xx}', "");
Expect(0, 918000, '\p{^Is_Lb=xx}', "");
Expect(0, 918000, '\P{Is_Lb=xx}', "");
Expect(1, 918000, '\P{^Is_Lb=xx}', "");
Expect(0, 917999, '\p{Is_Lb=xx}', "");
Expect(1, 917999, '\p{^Is_Lb=xx}', "");
Expect(1, 917999, '\P{Is_Lb=xx}', "");
Expect(0, 917999, '\P{^Is_Lb=xx}', "");
Expect(1, 918000, '\p{Is_Lb:   _xx}', "");
Expect(0, 918000, '\p{^Is_Lb:   _xx}', "");
Expect(0, 918000, '\P{Is_Lb:   _xx}', "");
Expect(1, 918000, '\P{^Is_Lb:   _xx}', "");
Expect(0, 917999, '\p{Is_Lb:   _xx}', "");
Expect(1, 917999, '\p{^Is_Lb:   _xx}', "");
Expect(1, 917999, '\P{Is_Lb:   _xx}', "");
Expect(0, 917999, '\P{^Is_Lb:   _xx}', "");
Error('\p{Line_Break=:=ZWSPACE}');
Error('\P{Line_Break=:=ZWSPACE}');
Expect(1, 8203, '\p{Line_Break=zwspace}', "");
Expect(0, 8203, '\p{^Line_Break=zwspace}', "");
Expect(0, 8203, '\P{Line_Break=zwspace}', "");
Expect(1, 8203, '\P{^Line_Break=zwspace}', "");
Expect(0, 8204, '\p{Line_Break=zwspace}', "");
Expect(1, 8204, '\p{^Line_Break=zwspace}', "");
Expect(1, 8204, '\P{Line_Break=zwspace}', "");
Expect(0, 8204, '\P{^Line_Break=zwspace}', "");
Expect(1, 8203, '\p{Line_Break=	zwspace}', "");
Expect(0, 8203, '\p{^Line_Break=	zwspace}', "");
Expect(0, 8203, '\P{Line_Break=	zwspace}', "");
Expect(1, 8203, '\P{^Line_Break=	zwspace}', "");
Expect(0, 8204, '\p{Line_Break=	zwspace}', "");
Expect(1, 8204, '\p{^Line_Break=	zwspace}', "");
Expect(1, 8204, '\P{Line_Break=	zwspace}', "");
Expect(0, 8204, '\P{^Line_Break=	zwspace}', "");
Error('\p{Lb: :=ZW}');
Error('\P{Lb: :=ZW}');
Expect(1, 8203, '\p{Lb=zw}', "");
Expect(0, 8203, '\p{^Lb=zw}', "");
Expect(0, 8203, '\P{Lb=zw}', "");
Expect(1, 8203, '\P{^Lb=zw}', "");
Expect(0, 8204, '\p{Lb=zw}', "");
Expect(1, 8204, '\p{^Lb=zw}', "");
Expect(1, 8204, '\P{Lb=zw}', "");
Expect(0, 8204, '\P{^Lb=zw}', "");
Expect(1, 8203, '\p{Lb=ZW}', "");
Expect(0, 8203, '\p{^Lb=ZW}', "");
Expect(0, 8203, '\P{Lb=ZW}', "");
Expect(1, 8203, '\P{^Lb=ZW}', "");
Expect(0, 8204, '\p{Lb=ZW}', "");
Expect(1, 8204, '\p{^Lb=ZW}', "");
Expect(1, 8204, '\P{Lb=ZW}', "");
Expect(0, 8204, '\P{^Lb=ZW}', "");
Error('\p{Is_Line_Break=:=-	ZWSpace}');
Error('\P{Is_Line_Break=:=-	ZWSpace}');
Expect(1, 8203, '\p{Is_Line_Break=zwspace}', "");
Expect(0, 8203, '\p{^Is_Line_Break=zwspace}', "");
Expect(0, 8203, '\P{Is_Line_Break=zwspace}', "");
Expect(1, 8203, '\P{^Is_Line_Break=zwspace}', "");
Expect(0, 8204, '\p{Is_Line_Break=zwspace}', "");
Expect(1, 8204, '\p{^Is_Line_Break=zwspace}', "");
Expect(1, 8204, '\P{Is_Line_Break=zwspace}', "");
Expect(0, 8204, '\P{^Is_Line_Break=zwspace}', "");
Expect(1, 8203, '\p{Is_Line_Break=		ZWSpace}', "");
Expect(0, 8203, '\p{^Is_Line_Break=		ZWSpace}', "");
Expect(0, 8203, '\P{Is_Line_Break=		ZWSpace}', "");
Expect(1, 8203, '\P{^Is_Line_Break=		ZWSpace}', "");
Expect(0, 8204, '\p{Is_Line_Break=		ZWSpace}', "");
Expect(1, 8204, '\p{^Is_Line_Break=		ZWSpace}', "");
Expect(1, 8204, '\P{Is_Line_Break=		ZWSpace}', "");
Expect(0, 8204, '\P{^Is_Line_Break=		ZWSpace}', "");
Error('\p{Is_Lb=/a/	ZW}');
Error('\P{Is_Lb=/a/	ZW}');
Expect(1, 8203, '\p{Is_Lb=zw}', "");
Expect(0, 8203, '\p{^Is_Lb=zw}', "");
Expect(0, 8203, '\P{Is_Lb=zw}', "");
Expect(1, 8203, '\P{^Is_Lb=zw}', "");
Expect(0, 8204, '\p{Is_Lb=zw}', "");
Expect(1, 8204, '\p{^Is_Lb=zw}', "");
Expect(1, 8204, '\P{Is_Lb=zw}', "");
Expect(0, 8204, '\P{^Is_Lb=zw}', "");
Expect(1, 8203, '\p{Is_Lb=-ZW}', "");
Expect(0, 8203, '\p{^Is_Lb=-ZW}', "");
Expect(0, 8203, '\P{Is_Lb=-ZW}', "");
Expect(1, 8203, '\P{^Is_Lb=-ZW}', "");
Expect(0, 8204, '\p{Is_Lb=-ZW}', "");
Expect(1, 8204, '\p{^Is_Lb=-ZW}', "");
Expect(1, 8204, '\P{Is_Lb=-ZW}', "");
Expect(0, 8204, '\P{^Is_Lb=-ZW}', "");
Error('\p{Numeric_Type=DECIMAL:=}');
Error('\P{Numeric_Type=DECIMAL:=}');
Expect(1, 120831, '\p{Numeric_Type=decimal}', "");
Expect(0, 120831, '\p{^Numeric_Type=decimal}', "");
Expect(0, 120831, '\P{Numeric_Type=decimal}', "");
Expect(1, 120831, '\P{^Numeric_Type=decimal}', "");
Expect(0, 120832, '\p{Numeric_Type=decimal}', "");
Expect(1, 120832, '\p{^Numeric_Type=decimal}', "");
Expect(1, 120832, '\P{Numeric_Type=decimal}', "");
Expect(0, 120832, '\P{^Numeric_Type=decimal}', "");
Expect(1, 120831, '\p{Numeric_Type=	DECIMAL}', "");
Expect(0, 120831, '\p{^Numeric_Type=	DECIMAL}', "");
Expect(0, 120831, '\P{Numeric_Type=	DECIMAL}', "");
Expect(1, 120831, '\P{^Numeric_Type=	DECIMAL}', "");
Expect(0, 120832, '\p{Numeric_Type=	DECIMAL}', "");
Expect(1, 120832, '\p{^Numeric_Type=	DECIMAL}', "");
Expect(1, 120832, '\P{Numeric_Type=	DECIMAL}', "");
Expect(0, 120832, '\P{^Numeric_Type=	DECIMAL}', "");
Error('\p{Nt=_:=de}');
Error('\P{Nt=_:=de}');
Expect(1, 120831, '\p{Nt=de}', "");
Expect(0, 120831, '\p{^Nt=de}', "");
Expect(0, 120831, '\P{Nt=de}', "");
Expect(1, 120831, '\P{^Nt=de}', "");
Expect(0, 120832, '\p{Nt=de}', "");
Expect(1, 120832, '\p{^Nt=de}', "");
Expect(1, 120832, '\P{Nt=de}', "");
Expect(0, 120832, '\P{^Nt=de}', "");
Expect(1, 120831, '\p{Nt=	De}', "");
Expect(0, 120831, '\p{^Nt=	De}', "");
Expect(0, 120831, '\P{Nt=	De}', "");
Expect(1, 120831, '\P{^Nt=	De}', "");
Expect(0, 120832, '\p{Nt=	De}', "");
Expect(1, 120832, '\p{^Nt=	De}', "");
Expect(1, 120832, '\P{Nt=	De}', "");
Expect(0, 120832, '\P{^Nt=	De}', "");
Error('\p{Is_Numeric_Type=/a/_-Decimal}');
Error('\P{Is_Numeric_Type=/a/_-Decimal}');
Expect(1, 120831, '\p{Is_Numeric_Type=decimal}', "");
Expect(0, 120831, '\p{^Is_Numeric_Type=decimal}', "");
Expect(0, 120831, '\P{Is_Numeric_Type=decimal}', "");
Expect(1, 120831, '\P{^Is_Numeric_Type=decimal}', "");
Expect(0, 120832, '\p{Is_Numeric_Type=decimal}', "");
Expect(1, 120832, '\p{^Is_Numeric_Type=decimal}', "");
Expect(1, 120832, '\P{Is_Numeric_Type=decimal}', "");
Expect(0, 120832, '\P{^Is_Numeric_Type=decimal}', "");
Expect(1, 120831, '\p{Is_Numeric_Type=_Decimal}', "");
Expect(0, 120831, '\p{^Is_Numeric_Type=_Decimal}', "");
Expect(0, 120831, '\P{Is_Numeric_Type=_Decimal}', "");
Expect(1, 120831, '\P{^Is_Numeric_Type=_Decimal}', "");
Expect(0, 120832, '\p{Is_Numeric_Type=_Decimal}', "");
Expect(1, 120832, '\p{^Is_Numeric_Type=_Decimal}', "");
Expect(1, 120832, '\P{Is_Numeric_Type=_Decimal}', "");
Expect(0, 120832, '\P{^Is_Numeric_Type=_Decimal}', "");
Error('\p{Is_Nt=	De/a/}');
Error('\P{Is_Nt=	De/a/}');
Expect(1, 120831, '\p{Is_Nt:de}', "");
Expect(0, 120831, '\p{^Is_Nt:de}', "");
Expect(0, 120831, '\P{Is_Nt:de}', "");
Expect(1, 120831, '\P{^Is_Nt:de}', "");
Expect(0, 120832, '\p{Is_Nt:de}', "");
Expect(1, 120832, '\p{^Is_Nt:de}', "");
Expect(1, 120832, '\P{Is_Nt:de}', "");
Expect(0, 120832, '\P{^Is_Nt:de}', "");
Expect(1, 120831, '\p{Is_Nt=	De}', "");
Expect(0, 120831, '\p{^Is_Nt=	De}', "");
Expect(0, 120831, '\P{Is_Nt=	De}', "");
Expect(1, 120831, '\P{^Is_Nt=	De}', "");
Expect(0, 120832, '\p{Is_Nt=	De}', "");
Expect(1, 120832, '\p{^Is_Nt=	De}', "");
Expect(1, 120832, '\P{Is_Nt=	De}', "");
Expect(0, 120832, '\P{^Is_Nt=	De}', "");
Error('\p{Numeric_Type:   _:=DIGIT}');
Error('\P{Numeric_Type:   _:=DIGIT}');
Expect(1, 127242, '\p{Numeric_Type:   digit}', "");
Expect(0, 127242, '\p{^Numeric_Type:   digit}', "");
Expect(0, 127242, '\P{Numeric_Type:   digit}', "");
Expect(1, 127242, '\P{^Numeric_Type:   digit}', "");
Expect(0, 127243, '\p{Numeric_Type:   digit}', "");
Expect(1, 127243, '\p{^Numeric_Type:   digit}', "");
Expect(1, 127243, '\P{Numeric_Type:   digit}', "");
Expect(0, 127243, '\P{^Numeric_Type:   digit}', "");
Expect(1, 127242, '\p{Numeric_Type=		digit}', "");
Expect(0, 127242, '\p{^Numeric_Type=		digit}', "");
Expect(0, 127242, '\P{Numeric_Type=		digit}', "");
Expect(1, 127242, '\P{^Numeric_Type=		digit}', "");
Expect(0, 127243, '\p{Numeric_Type=		digit}', "");
Expect(1, 127243, '\p{^Numeric_Type=		digit}', "");
Expect(1, 127243, '\P{Numeric_Type=		digit}', "");
Expect(0, 127243, '\P{^Numeric_Type=		digit}', "");
Error('\p{Nt: _di:=}');
Error('\P{Nt: _di:=}');
Expect(1, 127242, '\p{Nt=di}', "");
Expect(0, 127242, '\p{^Nt=di}', "");
Expect(0, 127242, '\P{Nt=di}', "");
Expect(1, 127242, '\P{^Nt=di}', "");
Expect(0, 127243, '\p{Nt=di}', "");
Expect(1, 127243, '\p{^Nt=di}', "");
Expect(1, 127243, '\P{Nt=di}', "");
Expect(0, 127243, '\P{^Nt=di}', "");
Expect(1, 127242, '\p{Nt=_Di}', "");
Expect(0, 127242, '\p{^Nt=_Di}', "");
Expect(0, 127242, '\P{Nt=_Di}', "");
Expect(1, 127242, '\P{^Nt=_Di}', "");
Expect(0, 127243, '\p{Nt=_Di}', "");
Expect(1, 127243, '\p{^Nt=_Di}', "");
Expect(1, 127243, '\P{Nt=_Di}', "");
Expect(0, 127243, '\P{^Nt=_Di}', "");
Error('\p{Is_Numeric_Type= -Digit:=}');
Error('\P{Is_Numeric_Type= -Digit:=}');
Expect(1, 127242, '\p{Is_Numeric_Type=digit}', "");
Expect(0, 127242, '\p{^Is_Numeric_Type=digit}', "");
Expect(0, 127242, '\P{Is_Numeric_Type=digit}', "");
Expect(1, 127242, '\P{^Is_Numeric_Type=digit}', "");
Expect(0, 127243, '\p{Is_Numeric_Type=digit}', "");
Expect(1, 127243, '\p{^Is_Numeric_Type=digit}', "");
Expect(1, 127243, '\P{Is_Numeric_Type=digit}', "");
Expect(0, 127243, '\P{^Is_Numeric_Type=digit}', "");
Expect(1, 127242, '\p{Is_Numeric_Type=-_Digit}', "");
Expect(0, 127242, '\p{^Is_Numeric_Type=-_Digit}', "");
Expect(0, 127242, '\P{Is_Numeric_Type=-_Digit}', "");
Expect(1, 127242, '\P{^Is_Numeric_Type=-_Digit}', "");
Expect(0, 127243, '\p{Is_Numeric_Type=-_Digit}', "");
Expect(1, 127243, '\p{^Is_Numeric_Type=-_Digit}', "");
Expect(1, 127243, '\P{Is_Numeric_Type=-_Digit}', "");
Expect(0, 127243, '\P{^Is_Numeric_Type=-_Digit}', "");
Error('\p{Is_Nt=-:=DI}');
Error('\P{Is_Nt=-:=DI}');
Expect(1, 127242, '\p{Is_Nt=di}', "");
Expect(0, 127242, '\p{^Is_Nt=di}', "");
Expect(0, 127242, '\P{Is_Nt=di}', "");
Expect(1, 127242, '\P{^Is_Nt=di}', "");
Expect(0, 127243, '\p{Is_Nt=di}', "");
Expect(1, 127243, '\p{^Is_Nt=di}', "");
Expect(1, 127243, '\P{Is_Nt=di}', "");
Expect(0, 127243, '\P{^Is_Nt=di}', "");
Expect(1, 127242, '\p{Is_Nt=	di}', "");
Expect(0, 127242, '\p{^Is_Nt=	di}', "");
Expect(0, 127242, '\P{Is_Nt=	di}', "");
Expect(1, 127242, '\P{^Is_Nt=	di}', "");
Expect(0, 127243, '\p{Is_Nt=	di}', "");
Expect(1, 127243, '\p{^Is_Nt=	di}', "");
Expect(1, 127243, '\P{Is_Nt=	di}', "");
Expect(0, 127243, '\P{^Is_Nt=	di}', "");
Error('\p{Numeric_Type=/a/- None}');
Error('\P{Numeric_Type=/a/- None}');
Expect(1, 194705, '\p{Numeric_Type=none}', "");
Expect(0, 194705, '\p{^Numeric_Type=none}', "");
Expect(0, 194705, '\P{Numeric_Type=none}', "");
Expect(1, 194705, '\P{^Numeric_Type=none}', "");
Expect(0, 194704, '\p{Numeric_Type=none}', "");
Expect(1, 194704, '\p{^Numeric_Type=none}', "");
Expect(1, 194704, '\P{Numeric_Type=none}', "");
Expect(0, 194704, '\P{^Numeric_Type=none}', "");
Expect(1, 194705, '\p{Numeric_Type= None}', "");
Expect(0, 194705, '\p{^Numeric_Type= None}', "");
Expect(0, 194705, '\P{Numeric_Type= None}', "");
Expect(1, 194705, '\P{^Numeric_Type= None}', "");
Expect(0, 194704, '\p{Numeric_Type= None}', "");
Expect(1, 194704, '\p{^Numeric_Type= None}', "");
Expect(1, 194704, '\P{Numeric_Type= None}', "");
Expect(0, 194704, '\P{^Numeric_Type= None}', "");
Error('\p{Nt= :=None}');
Error('\P{Nt= :=None}');
Expect(1, 194705, '\p{Nt=none}', "");
Expect(0, 194705, '\p{^Nt=none}', "");
Expect(0, 194705, '\P{Nt=none}', "");
Expect(1, 194705, '\P{^Nt=none}', "");
Expect(0, 194704, '\p{Nt=none}', "");
Expect(1, 194704, '\p{^Nt=none}', "");
Expect(1, 194704, '\P{Nt=none}', "");
Expect(0, 194704, '\P{^Nt=none}', "");
Expect(1, 194705, '\p{Nt=	NONE}', "");
Expect(0, 194705, '\p{^Nt=	NONE}', "");
Expect(0, 194705, '\P{Nt=	NONE}', "");
Expect(1, 194705, '\P{^Nt=	NONE}', "");
Expect(0, 194704, '\p{Nt=	NONE}', "");
Expect(1, 194704, '\p{^Nt=	NONE}', "");
Expect(1, 194704, '\P{Nt=	NONE}', "");
Expect(0, 194704, '\P{^Nt=	NONE}', "");
Error('\p{Is_Numeric_Type=-None/a/}');
Error('\P{Is_Numeric_Type=-None/a/}');
Expect(1, 194705, '\p{Is_Numeric_Type=none}', "");
Expect(0, 194705, '\p{^Is_Numeric_Type=none}', "");
Expect(0, 194705, '\P{Is_Numeric_Type=none}', "");
Expect(1, 194705, '\P{^Is_Numeric_Type=none}', "");
Expect(0, 194704, '\p{Is_Numeric_Type=none}', "");
Expect(1, 194704, '\p{^Is_Numeric_Type=none}', "");
Expect(1, 194704, '\P{Is_Numeric_Type=none}', "");
Expect(0, 194704, '\P{^Is_Numeric_Type=none}', "");
Expect(1, 194705, '\p{Is_Numeric_Type=-_none}', "");
Expect(0, 194705, '\p{^Is_Numeric_Type=-_none}', "");
Expect(0, 194705, '\P{Is_Numeric_Type=-_none}', "");
Expect(1, 194705, '\P{^Is_Numeric_Type=-_none}', "");
Expect(0, 194704, '\p{Is_Numeric_Type=-_none}', "");
Expect(1, 194704, '\p{^Is_Numeric_Type=-_none}', "");
Expect(1, 194704, '\P{Is_Numeric_Type=-_none}', "");
Expect(0, 194704, '\P{^Is_Numeric_Type=-_none}', "");
Error('\p{Is_Nt=/a/-_None}');
Error('\P{Is_Nt=/a/-_None}');
Expect(1, 194705, '\p{Is_Nt=none}', "");
Expect(0, 194705, '\p{^Is_Nt=none}', "");
Expect(0, 194705, '\P{Is_Nt=none}', "");
Expect(1, 194705, '\P{^Is_Nt=none}', "");
Expect(0, 194704, '\p{Is_Nt=none}', "");
Expect(1, 194704, '\p{^Is_Nt=none}', "");
Expect(1, 194704, '\P{Is_Nt=none}', "");
Expect(0, 194704, '\P{^Is_Nt=none}', "");
Expect(1, 194705, '\p{Is_Nt=NONE}', "");
Expect(0, 194705, '\p{^Is_Nt=NONE}', "");
Expect(0, 194705, '\P{Is_Nt=NONE}', "");
Expect(1, 194705, '\P{^Is_Nt=NONE}', "");
Expect(0, 194704, '\p{Is_Nt=NONE}', "");
Expect(1, 194704, '\p{^Is_Nt=NONE}', "");
Expect(1, 194704, '\P{Is_Nt=NONE}', "");
Expect(0, 194704, '\P{^Is_Nt=NONE}', "");
Error('\p{Numeric_Type= numeric:=}');
Error('\P{Numeric_Type= numeric:=}');
Expect(1, 194704, '\p{Numeric_Type=numeric}', "");
Expect(0, 194704, '\p{^Numeric_Type=numeric}', "");
Expect(0, 194704, '\P{Numeric_Type=numeric}', "");
Expect(1, 194704, '\P{^Numeric_Type=numeric}', "");
Expect(0, 194705, '\p{Numeric_Type=numeric}', "");
Expect(1, 194705, '\p{^Numeric_Type=numeric}', "");
Expect(1, 194705, '\P{Numeric_Type=numeric}', "");
Expect(0, 194705, '\P{^Numeric_Type=numeric}', "");
Expect(1, 194704, '\p{Numeric_Type=		Numeric}', "");
Expect(0, 194704, '\p{^Numeric_Type=		Numeric}', "");
Expect(0, 194704, '\P{Numeric_Type=		Numeric}', "");
Expect(1, 194704, '\P{^Numeric_Type=		Numeric}', "");
Expect(0, 194705, '\p{Numeric_Type=		Numeric}', "");
Expect(1, 194705, '\p{^Numeric_Type=		Numeric}', "");
Expect(1, 194705, '\P{Numeric_Type=		Numeric}', "");
Expect(0, 194705, '\P{^Numeric_Type=		Numeric}', "");
Error('\p{Nt=/a/__Nu}');
Error('\P{Nt=/a/__Nu}');
Expect(1, 194704, '\p{Nt=nu}', "");
Expect(0, 194704, '\p{^Nt=nu}', "");
Expect(0, 194704, '\P{Nt=nu}', "");
Expect(1, 194704, '\P{^Nt=nu}', "");
Expect(0, 194705, '\p{Nt=nu}', "");
Expect(1, 194705, '\p{^Nt=nu}', "");
Expect(1, 194705, '\P{Nt=nu}', "");
Expect(0, 194705, '\P{^Nt=nu}', "");
Expect(1, 194704, '\p{Nt=	-nu}', "");
Expect(0, 194704, '\p{^Nt=	-nu}', "");
Expect(0, 194704, '\P{Nt=	-nu}', "");
Expect(1, 194704, '\P{^Nt=	-nu}', "");
Expect(0, 194705, '\p{Nt=	-nu}', "");
Expect(1, 194705, '\p{^Nt=	-nu}', "");
Expect(1, 194705, '\P{Nt=	-nu}', "");
Expect(0, 194705, '\P{^Nt=	-nu}', "");
Error('\p{Is_Numeric_Type:	/a/	-NUMERIC}');
Error('\P{Is_Numeric_Type:	/a/	-NUMERIC}');
Expect(1, 194704, '\p{Is_Numeric_Type=numeric}', "");
Expect(0, 194704, '\p{^Is_Numeric_Type=numeric}', "");
Expect(0, 194704, '\P{Is_Numeric_Type=numeric}', "");
Expect(1, 194704, '\P{^Is_Numeric_Type=numeric}', "");
Expect(0, 194705, '\p{Is_Numeric_Type=numeric}', "");
Expect(1, 194705, '\p{^Is_Numeric_Type=numeric}', "");
Expect(1, 194705, '\P{Is_Numeric_Type=numeric}', "");
Expect(0, 194705, '\P{^Is_Numeric_Type=numeric}', "");
Expect(1, 194704, '\p{Is_Numeric_Type=	Numeric}', "");
Expect(0, 194704, '\p{^Is_Numeric_Type=	Numeric}', "");
Expect(0, 194704, '\P{Is_Numeric_Type=	Numeric}', "");
Expect(1, 194704, '\P{^Is_Numeric_Type=	Numeric}', "");
Expect(0, 194705, '\p{Is_Numeric_Type=	Numeric}', "");
Expect(1, 194705, '\p{^Is_Numeric_Type=	Numeric}', "");
Expect(1, 194705, '\P{Is_Numeric_Type=	Numeric}', "");
Expect(0, 194705, '\P{^Is_Numeric_Type=	Numeric}', "");
Error('\p{Is_Nt:-:=Nu}');
Error('\P{Is_Nt:-:=Nu}');
Expect(1, 194704, '\p{Is_Nt=nu}', "");
Expect(0, 194704, '\p{^Is_Nt=nu}', "");
Expect(0, 194704, '\P{Is_Nt=nu}', "");
Expect(1, 194704, '\P{^Is_Nt=nu}', "");
Expect(0, 194705, '\p{Is_Nt=nu}', "");
Expect(1, 194705, '\p{^Is_Nt=nu}', "");
Expect(1, 194705, '\P{Is_Nt=nu}', "");
Expect(0, 194705, '\P{^Is_Nt=nu}', "");
Expect(1, 194704, '\p{Is_Nt=	 nu}', "");
Expect(0, 194704, '\p{^Is_Nt=	 nu}', "");
Expect(0, 194704, '\P{Is_Nt=	 nu}', "");
Expect(1, 194704, '\P{^Is_Nt=	 nu}', "");
Expect(0, 194705, '\p{Is_Nt=	 nu}', "");
Expect(1, 194705, '\p{^Is_Nt=	 nu}', "");
Expect(1, 194705, '\P{Is_Nt=	 nu}', "");
Expect(0, 194705, '\P{^Is_Nt=	 nu}', "");
Error('\p{Numeric_Value=:=	--000000001/0000000002}');
Error('\P{Numeric_Value=:=	--000000001/0000000002}');
Expect(1, 3891, '\p{Numeric_Value=-0000000001/2}', "");
Expect(0, 3891, '\p{^Numeric_Value=-0000000001/2}', "");
Expect(0, 3891, '\P{Numeric_Value=-0000000001/2}', "");
Expect(1, 3891, '\P{^Numeric_Value=-0000000001/2}', "");
Expect(0, 3892, '\p{Numeric_Value=-0000000001/2}', "");
Expect(1, 3892, '\p{^Numeric_Value=-0000000001/2}', "");
Expect(1, 3892, '\P{Numeric_Value=-0000000001/2}', "");
Expect(0, 3892, '\P{^Numeric_Value=-0000000001/2}', "");
Expect(1, 3891, '\p{Numeric_Value=-0.500}', "");
Expect(0, 3891, '\p{^Numeric_Value=-0.500}', "");
Expect(0, 3891, '\P{Numeric_Value=-0.500}', "");
Expect(1, 3891, '\P{^Numeric_Value=-0.500}', "");
Expect(0, 3892, '\p{Numeric_Value=-0.500}', "");
Expect(1, 3892, '\p{^Numeric_Value=-0.500}', "");
Expect(1, 3892, '\P{Numeric_Value=-0.500}', "");
Expect(0, 3892, '\P{^Numeric_Value=-0.500}', "");
Error('\p{Nv: -000000001/0000000002/a/}');
Error('\P{Nv: -000000001/0000000002/a/}');
Expect(1, 3891, '\p{Nv=-000000001/000002}', "");
Expect(0, 3891, '\p{^Nv=-000000001/000002}', "");
Expect(0, 3891, '\P{Nv=-000000001/000002}', "");
Expect(1, 3891, '\P{^Nv=-000000001/000002}', "");
Expect(0, 3892, '\p{Nv=-000000001/000002}', "");
Expect(1, 3892, '\p{^Nv=-000000001/000002}', "");
Expect(1, 3892, '\P{Nv=-000000001/000002}', "");
Expect(0, 3892, '\P{^Nv=-000000001/000002}', "");
Expect(1, 3891, '\p{Nv=-0.500}', "");
Expect(0, 3891, '\p{^Nv=-0.500}', "");
Expect(0, 3891, '\P{Nv=-0.500}', "");
Expect(1, 3891, '\P{^Nv=-0.500}', "");
Expect(0, 3892, '\p{Nv=-0.500}', "");
Expect(1, 3892, '\p{^Nv=-0.500}', "");
Expect(1, 3892, '\P{Nv=-0.500}', "");
Expect(0, 3892, '\P{^Nv=-0.500}', "");
Error('\p{Is_Numeric_Value=/a/_	-001/2}');
Error('\P{Is_Numeric_Value=/a/_	-001/2}');
Expect(1, 3891, '\p{Is_Numeric_Value=-00000001/02}', "");
Expect(0, 3891, '\p{^Is_Numeric_Value=-00000001/02}', "");
Expect(0, 3891, '\P{Is_Numeric_Value=-00000001/02}', "");
Expect(1, 3891, '\P{^Is_Numeric_Value=-00000001/02}', "");
Expect(0, 3892, '\p{Is_Numeric_Value=-00000001/02}', "");
Expect(1, 3892, '\p{^Is_Numeric_Value=-00000001/02}', "");
Expect(1, 3892, '\P{Is_Numeric_Value=-00000001/02}', "");
Expect(0, 3892, '\P{^Is_Numeric_Value=-00000001/02}', "");
Expect(1, 3891, '\p{Is_Numeric_Value=-0.500}', "");
Expect(0, 3891, '\p{^Is_Numeric_Value=-0.500}', "");
Expect(0, 3891, '\P{Is_Numeric_Value=-0.500}', "");
Expect(1, 3891, '\P{^Is_Numeric_Value=-0.500}', "");
Expect(0, 3892, '\p{Is_Numeric_Value=-0.500}', "");
Expect(1, 3892, '\p{^Is_Numeric_Value=-0.500}', "");
Expect(1, 3892, '\P{Is_Numeric_Value=-0.500}', "");
Expect(0, 3892, '\P{^Is_Numeric_Value=-0.500}', "");
Error('\p{Is_Nv=:=	_-000001/02}');
Error('\P{Is_Nv=:=	_-000001/02}');
Expect(1, 3891, '\p{Is_Nv=-000000001/0000000002}', "");
Expect(0, 3891, '\p{^Is_Nv=-000000001/0000000002}', "");
Expect(0, 3891, '\P{Is_Nv=-000000001/0000000002}', "");
Expect(1, 3891, '\P{^Is_Nv=-000000001/0000000002}', "");
Expect(0, 3892, '\p{Is_Nv=-000000001/0000000002}', "");
Expect(1, 3892, '\p{^Is_Nv=-000000001/0000000002}', "");
Expect(1, 3892, '\P{Is_Nv=-000000001/0000000002}', "");
Expect(0, 3892, '\P{^Is_Nv=-000000001/0000000002}', "");
Expect(1, 3891, '\p{Is_Nv=-0.500}', "");
Expect(0, 3891, '\p{^Is_Nv=-0.500}', "");
Expect(0, 3891, '\P{Is_Nv=-0.500}', "");
Expect(1, 3891, '\P{^Is_Nv=-0.500}', "");
Expect(0, 3892, '\p{Is_Nv=-0.500}', "");
Expect(1, 3892, '\p{^Is_Nv=-0.500}', "");
Expect(1, 3892, '\P{Is_Nv=-0.500}', "");
Expect(0, 3892, '\P{^Is_Nv=-0.500}', "");
Error('\p{Numeric_Value=_	000000/a/}');
Error('\P{Numeric_Value=_	000000/a/}');
Expect(1, 127233, '\p{Numeric_Value=000_0}', "");
Expect(0, 127233, '\p{^Numeric_Value=000_0}', "");
Expect(0, 127233, '\P{Numeric_Value=000_0}', "");
Expect(1, 127233, '\P{^Numeric_Value=000_0}', "");
Expect(0, 127234, '\p{Numeric_Value=000_0}', "");
Expect(1, 127234, '\p{^Numeric_Value=000_0}', "");
Expect(1, 127234, '\P{Numeric_Value=000_0}', "");
Expect(0, 127234, '\P{^Numeric_Value=000_0}', "");
Error('\p{Nv=	 0:=}');
Error('\P{Nv=	 0:=}');
Expect(1, 127233, '\p{Nv=0_0_0_0_0_000}', "");
Expect(0, 127233, '\p{^Nv=0_0_0_0_0_000}', "");
Expect(0, 127233, '\P{Nv=0_0_0_0_0_000}', "");
Expect(1, 127233, '\P{^Nv=0_0_0_0_0_000}', "");
Expect(0, 127234, '\p{Nv=0_0_0_0_0_000}', "");
Expect(1, 127234, '\p{^Nv=0_0_0_0_0_000}', "");
Expect(1, 127234, '\P{Nv=0_0_0_0_0_000}', "");
Expect(0, 127234, '\P{^Nv=0_0_0_0_0_000}', "");
Error('\p{Is_Numeric_Value=/a/00}');
Error('\P{Is_Numeric_Value=/a/00}');
Expect(1, 127233, '\p{Is_Numeric_Value=+0_0}', "");
Expect(0, 127233, '\p{^Is_Numeric_Value=+0_0}', "");
Expect(0, 127233, '\P{Is_Numeric_Value=+0_0}', "");
Expect(1, 127233, '\P{^Is_Numeric_Value=+0_0}', "");
Expect(0, 127234, '\p{Is_Numeric_Value=+0_0}', "");
Expect(1, 127234, '\p{^Is_Numeric_Value=+0_0}', "");
Expect(1, 127234, '\P{Is_Numeric_Value=+0_0}', "");
Expect(0, 127234, '\P{^Is_Numeric_Value=+0_0}', "");
Error('\p{Is_Nv= 0_0/a/}');
Error('\P{Is_Nv= 0_0/a/}');
Expect(1, 127233, '\p{Is_Nv=+00000000}', "");
Expect(0, 127233, '\p{^Is_Nv=+00000000}', "");
Expect(0, 127233, '\P{Is_Nv=+00000000}', "");
Expect(1, 127233, '\P{^Is_Nv=+00000000}', "");
Expect(0, 127234, '\p{Is_Nv=+00000000}', "");
Expect(1, 127234, '\p{^Is_Nv=+00000000}', "");
Expect(1, 127234, '\P{Is_Nv=+00000000}', "");
Expect(0, 127234, '\P{^Is_Nv=+00000000}', "");
Error('\p{Numeric_Value=	:=+001}');
Error('\P{Numeric_Value=	:=+001}');
Expect(1, 133418, '\p{Numeric_Value=+0000001}', "");
Expect(0, 133418, '\p{^Numeric_Value=+0000001}', "");
Expect(0, 133418, '\P{Numeric_Value=+0000001}', "");
Expect(1, 133418, '\P{^Numeric_Value=+0000001}', "");
Expect(0, 133419, '\p{Numeric_Value=+0000001}', "");
Expect(1, 133419, '\p{^Numeric_Value=+0000001}', "");
Expect(1, 133419, '\P{Numeric_Value=+0000001}', "");
Expect(0, 133419, '\P{^Numeric_Value=+0000001}', "");
Error('\p{Nv=/a/	 +000000_1}');
Error('\P{Nv=/a/	 +000000_1}');
Expect(1, 133418, '\p{Nv=+00000_1}', "");
Expect(0, 133418, '\p{^Nv=+00000_1}', "");
Expect(0, 133418, '\P{Nv=+00000_1}', "");
Expect(1, 133418, '\P{^Nv=+00000_1}', "");
Expect(0, 133419, '\p{Nv=+00000_1}', "");
Expect(1, 133419, '\p{^Nv=+00000_1}', "");
Expect(1, 133419, '\P{Nv=+00000_1}', "");
Expect(0, 133419, '\P{^Nv=+00000_1}', "");
Error('\p{Is_Numeric_Value=_01:=}');
Error('\P{Is_Numeric_Value=_01:=}');
Expect(1, 133418, '\p{Is_Numeric_Value=000000001}', "");
Expect(0, 133418, '\p{^Is_Numeric_Value=000000001}', "");
Expect(0, 133418, '\P{Is_Numeric_Value=000000001}', "");
Expect(1, 133418, '\P{^Is_Numeric_Value=000000001}', "");
Expect(0, 133419, '\p{Is_Numeric_Value=000000001}', "");
Expect(1, 133419, '\p{^Is_Numeric_Value=000000001}', "");
Expect(1, 133419, '\P{Is_Numeric_Value=000000001}', "");
Expect(0, 133419, '\P{^Is_Numeric_Value=000000001}', "");
Error('\p{Is_Nv= _00000001:=}');
Error('\P{Is_Nv= _00000001:=}');
Expect(1, 133418, '\p{Is_Nv=+00_1}', "");
Expect(0, 133418, '\p{^Is_Nv=+00_1}', "");
Expect(0, 133418, '\P{Is_Nv=+00_1}', "");
Expect(1, 133418, '\P{^Is_Nv=+00_1}', "");
Expect(0, 133419, '\p{Is_Nv=+00_1}', "");
Expect(1, 133419, '\p{^Is_Nv=+00_1}', "");
Expect(1, 133419, '\P{Is_Nv=+00_1}', "");
Expect(0, 133419, '\P{^Is_Nv=+00_1}', "");
Error('\p{Numeric_Value=-:=000000001/00000010}');
Error('\P{Numeric_Value=-:=000000001/00000010}');
Expect(1, 8530, '\p{Numeric_Value=1/0000010}', "");
Expect(0, 8530, '\p{^Numeric_Value=1/0000010}', "");
Expect(0, 8530, '\P{Numeric_Value=1/0000010}', "");
Expect(1, 8530, '\P{^Numeric_Value=1/0000010}', "");
Expect(0, 8531, '\p{Numeric_Value=1/0000010}', "");
Expect(1, 8531, '\p{^Numeric_Value=1/0000010}', "");
Expect(1, 8531, '\P{Numeric_Value=1/0000010}', "");
Expect(0, 8531, '\P{^Numeric_Value=1/0000010}', "");
Expect(1, 8530, '\p{Numeric_Value=0.100}', "");
Expect(0, 8530, '\p{^Numeric_Value=0.100}', "");
Expect(0, 8530, '\P{Numeric_Value=0.100}', "");
Expect(1, 8530, '\P{^Numeric_Value=0.100}', "");
Expect(0, 8531, '\p{Numeric_Value=0.100}', "");
Expect(1, 8531, '\p{^Numeric_Value=0.100}', "");
Expect(1, 8531, '\P{Numeric_Value=0.100}', "");
Expect(0, 8531, '\P{^Numeric_Value=0.100}', "");
Error('\p{Nv=	 001/0000010:=}');
Error('\P{Nv=	 001/0000010:=}');
Expect(1, 8530, '\p{Nv=0001/000000010}', "");
Expect(0, 8530, '\p{^Nv=0001/000000010}', "");
Expect(0, 8530, '\P{Nv=0001/000000010}', "");
Expect(1, 8530, '\P{^Nv=0001/000000010}', "");
Expect(0, 8531, '\p{Nv=0001/000000010}', "");
Expect(1, 8531, '\p{^Nv=0001/000000010}', "");
Expect(1, 8531, '\P{Nv=0001/000000010}', "");
Expect(0, 8531, '\P{^Nv=0001/000000010}', "");
Expect(1, 8530, '\p{Nv=0.100}', "");
Expect(0, 8530, '\p{^Nv=0.100}', "");
Expect(0, 8530, '\P{Nv=0.100}', "");
Expect(1, 8530, '\P{^Nv=0.100}', "");
Expect(0, 8531, '\p{Nv=0.100}', "");
Expect(1, 8531, '\p{^Nv=0.100}', "");
Expect(1, 8531, '\P{Nv=0.100}', "");
Expect(0, 8531, '\P{^Nv=0.100}', "");
Error('\p{Is_Numeric_Value=/a/_	00001/0000000010}');
Error('\P{Is_Numeric_Value=/a/_	00001/0000000010}');
Expect(1, 8530, '\p{Is_Numeric_Value:	+0000000001/0000000010}', "");
Expect(0, 8530, '\p{^Is_Numeric_Value:	+0000000001/0000000010}', "");
Expect(0, 8530, '\P{Is_Numeric_Value:	+0000000001/0000000010}', "");
Expect(1, 8530, '\P{^Is_Numeric_Value:	+0000000001/0000000010}', "");
Expect(0, 8531, '\p{Is_Numeric_Value:	+0000000001/0000000010}', "");
Expect(1, 8531, '\p{^Is_Numeric_Value:	+0000000001/0000000010}', "");
Expect(1, 8531, '\P{Is_Numeric_Value:	+0000000001/0000000010}', "");
Expect(0, 8531, '\P{^Is_Numeric_Value:	+0000000001/0000000010}', "");
Expect(1, 8530, '\p{Is_Numeric_Value=0.100}', "");
Expect(0, 8530, '\p{^Is_Numeric_Value=0.100}', "");
Expect(0, 8530, '\P{Is_Numeric_Value=0.100}', "");
Expect(1, 8530, '\P{^Is_Numeric_Value=0.100}', "");
Expect(0, 8531, '\p{Is_Numeric_Value=0.100}', "");
Expect(1, 8531, '\p{^Is_Numeric_Value=0.100}', "");
Expect(1, 8531, '\P{Is_Numeric_Value=0.100}', "");
Expect(0, 8531, '\P{^Is_Numeric_Value=0.100}', "");
Error('\p{Is_Nv=	00001/10/a/}');
Error('\P{Is_Nv=	00001/10/a/}');
Expect(1, 8530, '\p{Is_Nv=0000000001/0000000010}', "");
Expect(0, 8530, '\p{^Is_Nv=0000000001/0000000010}', "");
Expect(0, 8530, '\P{Is_Nv=0000000001/0000000010}', "");
Expect(1, 8530, '\P{^Is_Nv=0000000001/0000000010}', "");
Expect(0, 8531, '\p{Is_Nv=0000000001/0000000010}', "");
Expect(1, 8531, '\p{^Is_Nv=0000000001/0000000010}', "");
Expect(1, 8531, '\P{Is_Nv=0000000001/0000000010}', "");
Expect(0, 8531, '\P{^Is_Nv=0000000001/0000000010}', "");
Expect(1, 8530, '\p{Is_Nv=0.100}', "");
Expect(0, 8530, '\p{^Is_Nv=0.100}', "");
Expect(0, 8530, '\P{Is_Nv=0.100}', "");
Expect(1, 8530, '\P{^Is_Nv=0.100}', "");
Expect(0, 8531, '\p{Is_Nv=0.100}', "");
Expect(1, 8531, '\p{^Is_Nv=0.100}', "");
Expect(1, 8531, '\P{Is_Nv=0.100}', "");
Expect(0, 8531, '\P{^Is_Nv=0.100}', "");
Error('\p{Numeric_Value= /a/000001/000000016}');
Error('\P{Numeric_Value= /a/000001/000000016}');
Expect(1, 43059, '\p{Numeric_Value=1/00000016}', "");
Expect(0, 43059, '\p{^Numeric_Value=1/00000016}', "");
Expect(0, 43059, '\P{Numeric_Value=1/00000016}', "");
Expect(1, 43059, '\P{^Numeric_Value=1/00000016}', "");
Expect(0, 43060, '\p{Numeric_Value=1/00000016}', "");
Expect(1, 43060, '\p{^Numeric_Value=1/00000016}', "");
Expect(1, 43060, '\P{Numeric_Value=1/00000016}', "");
Expect(0, 43060, '\P{^Numeric_Value=1/00000016}', "");
Error('\p{Numeric_Value=0.06}');
Error('\P{Numeric_Value=0.06}');
Expect(1, 43059, '\p{Numeric_Value=0.062}', "");
Expect(0, 43059, '\p{^Numeric_Value=0.062}', "");
Expect(0, 43059, '\P{Numeric_Value=0.062}', "");
Expect(1, 43059, '\P{^Numeric_Value=0.062}', "");
Expect(0, 43060, '\p{Numeric_Value=0.062}', "");
Expect(1, 43060, '\p{^Numeric_Value=0.062}', "");
Expect(1, 43060, '\P{Numeric_Value=0.062}', "");
Expect(0, 43060, '\P{^Numeric_Value=0.062}', "");
Error('\p{Nv=_00000001/16/a/}');
Error('\P{Nv=_00000001/16/a/}');
Expect(1, 43059, '\p{Nv=000001/00000016}', "");
Expect(0, 43059, '\p{^Nv=000001/00000016}', "");
Expect(0, 43059, '\P{Nv=000001/00000016}', "");
Expect(1, 43059, '\P{^Nv=000001/00000016}', "");
Expect(0, 43060, '\p{Nv=000001/00000016}', "");
Expect(1, 43060, '\p{^Nv=000001/00000016}', "");
Expect(1, 43060, '\P{Nv=000001/00000016}', "");
Expect(0, 43060, '\P{^Nv=000001/00000016}', "");
Error('\p{Nv=0.06}');
Error('\P{Nv=0.06}');
Expect(1, 43059, '\p{Nv=0.062}', "");
Expect(0, 43059, '\p{^Nv=0.062}', "");
Expect(0, 43059, '\P{Nv=0.062}', "");
Expect(1, 43059, '\P{^Nv=0.062}', "");
Expect(0, 43060, '\p{Nv=0.062}', "");
Expect(1, 43060, '\p{^Nv=0.062}', "");
Expect(1, 43060, '\P{Nv=0.062}', "");
Expect(0, 43060, '\P{^Nv=0.062}', "");
Error('\p{Is_Numeric_Value=/a/0000001/0000000016}');
Error('\P{Is_Numeric_Value=/a/0000001/0000000016}');
Expect(1, 43059, '\p{Is_Numeric_Value=+0000001/00016}', "");
Expect(0, 43059, '\p{^Is_Numeric_Value=+0000001/00016}', "");
Expect(0, 43059, '\P{Is_Numeric_Value=+0000001/00016}', "");
Expect(1, 43059, '\P{^Is_Numeric_Value=+0000001/00016}', "");
Expect(0, 43060, '\p{Is_Numeric_Value=+0000001/00016}', "");
Expect(1, 43060, '\p{^Is_Numeric_Value=+0000001/00016}', "");
Expect(1, 43060, '\P{Is_Numeric_Value=+0000001/00016}', "");
Expect(0, 43060, '\P{^Is_Numeric_Value=+0000001/00016}', "");
Error('\p{Is_Numeric_Value=0.06}');
Error('\P{Is_Numeric_Value=0.06}');
Expect(1, 43059, '\p{Is_Numeric_Value=0.062}', "");
Expect(0, 43059, '\p{^Is_Numeric_Value=0.062}', "");
Expect(0, 43059, '\P{Is_Numeric_Value=0.062}', "");
Expect(1, 43059, '\P{^Is_Numeric_Value=0.062}', "");
Expect(0, 43060, '\p{Is_Numeric_Value=0.062}', "");
Expect(1, 43060, '\p{^Is_Numeric_Value=0.062}', "");
Expect(1, 43060, '\P{Is_Numeric_Value=0.062}', "");
Expect(0, 43060, '\P{^Is_Numeric_Value=0.062}', "");
Error('\p{Is_Nv=	/a/+0000001/0000000016}');
Error('\P{Is_Nv=	/a/+0000001/0000000016}');
Expect(1, 43059, '\p{Is_Nv=00001/000016}', "");
Expect(0, 43059, '\p{^Is_Nv=00001/000016}', "");
Expect(0, 43059, '\P{Is_Nv=00001/000016}', "");
Expect(1, 43059, '\P{^Is_Nv=00001/000016}', "");
Expect(0, 43060, '\p{Is_Nv=00001/000016}', "");
Expect(1, 43060, '\p{^Is_Nv=00001/000016}', "");
Expect(1, 43060, '\P{Is_Nv=00001/000016}', "");
Expect(0, 43060, '\P{^Is_Nv=00001/000016}', "");
Error('\p{Is_Nv=0.06}');
Error('\P{Is_Nv=0.06}');
Expect(1, 43059, '\p{Is_Nv=0.062}', "");
Expect(0, 43059, '\p{^Is_Nv=0.062}', "");
Expect(0, 43059, '\P{Is_Nv=0.062}', "");
Expect(1, 43059, '\P{^Is_Nv=0.062}', "");
Expect(0, 43060, '\p{Is_Nv=0.062}', "");
Expect(1, 43060, '\p{^Is_Nv=0.062}', "");
Expect(1, 43060, '\P{Is_Nv=0.062}', "");
Expect(0, 43060, '\P{^Is_Nv=0.062}', "");
Error('\p{Numeric_Value=		+0000000001/00000002:=}');
Error('\P{Numeric_Value=		+0000000001/00000002:=}');
Expect(1, 69243, '\p{Numeric_Value: 0000001/0002}', "");
Expect(0, 69243, '\p{^Numeric_Value: 0000001/0002}', "");
Expect(0, 69243, '\P{Numeric_Value: 0000001/0002}', "");
Expect(1, 69243, '\P{^Numeric_Value: 0000001/0002}', "");
Expect(0, 69244, '\p{Numeric_Value: 0000001/0002}', "");
Expect(1, 69244, '\p{^Numeric_Value: 0000001/0002}', "");
Expect(1, 69244, '\P{Numeric_Value: 0000001/0002}', "");
Expect(0, 69244, '\P{^Numeric_Value: 0000001/0002}', "");
Expect(1, 69243, '\p{Numeric_Value=0.500}', "");
Expect(0, 69243, '\p{^Numeric_Value=0.500}', "");
Expect(0, 69243, '\P{Numeric_Value=0.500}', "");
Expect(1, 69243, '\P{^Numeric_Value=0.500}', "");
Expect(0, 69244, '\p{Numeric_Value=0.500}', "");
Expect(1, 69244, '\p{^Numeric_Value=0.500}', "");
Expect(1, 69244, '\P{Numeric_Value=0.500}', "");
Expect(0, 69244, '\P{^Numeric_Value=0.500}', "");
Error('\p{Nv= _00000001/0002:=}');
Error('\P{Nv= _00000001/0002:=}');
Expect(1, 69243, '\p{Nv=00001/02}', "");
Expect(0, 69243, '\p{^Nv=00001/02}', "");
Expect(0, 69243, '\P{Nv=00001/02}', "");
Expect(1, 69243, '\P{^Nv=00001/02}', "");
Expect(0, 69244, '\p{Nv=00001/02}', "");
Expect(1, 69244, '\p{^Nv=00001/02}', "");
Expect(1, 69244, '\P{Nv=00001/02}', "");
Expect(0, 69244, '\P{^Nv=00001/02}', "");
Expect(1, 69243, '\p{Nv=0.500}', "");
Expect(0, 69243, '\p{^Nv=0.500}', "");
Expect(0, 69243, '\P{Nv=0.500}', "");
Expect(1, 69243, '\P{^Nv=0.500}', "");
Expect(0, 69244, '\p{Nv=0.500}', "");
Expect(1, 69244, '\p{^Nv=0.500}', "");
Expect(1, 69244, '\P{Nv=0.500}', "");
Expect(0, 69244, '\P{^Nv=0.500}', "");
Error('\p{Is_Numeric_Value=-:=00000001/002}');
Error('\P{Is_Numeric_Value=-:=00000001/002}');
Expect(1, 69243, '\p{Is_Numeric_Value=+0001/0002}', "");
Expect(0, 69243, '\p{^Is_Numeric_Value=+0001/0002}', "");
Expect(0, 69243, '\P{Is_Numeric_Value=+0001/0002}', "");
Expect(1, 69243, '\P{^Is_Numeric_Value=+0001/0002}', "");
Expect(0, 69244, '\p{Is_Numeric_Value=+0001/0002}', "");
Expect(1, 69244, '\p{^Is_Numeric_Value=+0001/0002}', "");
Expect(1, 69244, '\P{Is_Numeric_Value=+0001/0002}', "");
Expect(0, 69244, '\P{^Is_Numeric_Value=+0001/0002}', "");
Expect(1, 69243, '\p{Is_Numeric_Value=0.500}', "");
Expect(0, 69243, '\p{^Is_Numeric_Value=0.500}', "");
Expect(0, 69243, '\P{Is_Numeric_Value=0.500}', "");
Expect(1, 69243, '\P{^Is_Numeric_Value=0.500}', "");
Expect(0, 69244, '\p{Is_Numeric_Value=0.500}', "");
Expect(1, 69244, '\p{^Is_Numeric_Value=0.500}', "");
Expect(1, 69244, '\P{Is_Numeric_Value=0.500}', "");
Expect(0, 69244, '\P{^Is_Numeric_Value=0.500}', "");
Error('\p{Is_Nv=:=-00001/0000000002}');
Error('\P{Is_Nv=:=-00001/0000000002}');
Expect(1, 69243, '\p{Is_Nv=+001/002}', "");
Expect(0, 69243, '\p{^Is_Nv=+001/002}', "");
Expect(0, 69243, '\P{Is_Nv=+001/002}', "");
Expect(1, 69243, '\P{^Is_Nv=+001/002}', "");
Expect(0, 69244, '\p{Is_Nv=+001/002}', "");
Expect(1, 69244, '\p{^Is_Nv=+001/002}', "");
Expect(1, 69244, '\P{Is_Nv=+001/002}', "");
Expect(0, 69244, '\P{^Is_Nv=+001/002}', "");
Expect(1, 69243, '\p{Is_Nv=0.500}', "");
Expect(0, 69243, '\p{^Is_Nv=0.500}', "");
Expect(0, 69243, '\P{Is_Nv=0.500}', "");
Expect(1, 69243, '\P{^Is_Nv=0.500}', "");
Expect(0, 69244, '\p{Is_Nv=0.500}', "");
Expect(1, 69244, '\p{^Is_Nv=0.500}', "");
Expect(1, 69244, '\P{Is_Nv=0.500}', "");
Expect(0, 69244, '\P{^Is_Nv=0.500}', "");
Error('\p{Numeric_Value: -/a/+000001/00000003}');
Error('\P{Numeric_Value: -/a/+000001/00000003}');
Expect(1, 74845, '\p{Numeric_Value=000000001/3}', "");
Expect(0, 74845, '\p{^Numeric_Value=000000001/3}', "");
Expect(0, 74845, '\P{Numeric_Value=000000001/3}', "");
Expect(1, 74845, '\P{^Numeric_Value=000000001/3}', "");
Expect(0, 74846, '\p{Numeric_Value=000000001/3}', "");
Expect(1, 74846, '\p{^Numeric_Value=000000001/3}', "");
Expect(1, 74846, '\P{Numeric_Value=000000001/3}', "");
Expect(0, 74846, '\P{^Numeric_Value=000000001/3}', "");
Error('\p{Numeric_Value=0.3}');
Error('\P{Numeric_Value=0.3}');
Error('\p{Numeric_Value=0.33}');
Error('\P{Numeric_Value=0.33}');
Expect(1, 74845, '\p{Numeric_Value=0.333}', "");
Expect(0, 74845, '\p{^Numeric_Value=0.333}', "");
Expect(0, 74845, '\P{Numeric_Value=0.333}', "");
Expect(1, 74845, '\P{^Numeric_Value=0.333}', "");
Expect(0, 74846, '\p{Numeric_Value=0.333}', "");
Expect(1, 74846, '\p{^Numeric_Value=0.333}', "");
Expect(1, 74846, '\P{Numeric_Value=0.333}', "");
Expect(0, 74846, '\P{^Numeric_Value=0.333}', "");
Error('\p{Nv=-0000001/00003:=}');
Error('\P{Nv=-0000001/00003:=}');
Expect(1, 74845, '\p{Nv=0000001/0003}', "");
Expect(0, 74845, '\p{^Nv=0000001/0003}', "");
Expect(0, 74845, '\P{Nv=0000001/0003}', "");
Expect(1, 74845, '\P{^Nv=0000001/0003}', "");
Expect(0, 74846, '\p{Nv=0000001/0003}', "");
Expect(1, 74846, '\p{^Nv=0000001/0003}', "");
Expect(1, 74846, '\P{Nv=0000001/0003}', "");
Expect(0, 74846, '\P{^Nv=0000001/0003}', "");
Error('\p{Nv=0.3}');
Error('\P{Nv=0.3}');
Error('\p{Nv=0.33}');
Error('\P{Nv=0.33}');
Expect(1, 74845, '\p{Nv=0.333}', "");
Expect(0, 74845, '\p{^Nv=0.333}', "");
Expect(0, 74845, '\P{Nv=0.333}', "");
Expect(1, 74845, '\P{^Nv=0.333}', "");
Expect(0, 74846, '\p{Nv=0.333}', "");
Expect(1, 74846, '\p{^Nv=0.333}', "");
Expect(1, 74846, '\P{Nv=0.333}', "");
Expect(0, 74846, '\P{^Nv=0.333}', "");
Error('\p{Is_Numeric_Value=:= -000001/3}');
Error('\P{Is_Numeric_Value=:= -000001/3}');
Expect(1, 74845, '\p{Is_Numeric_Value=0001/003}', "");
Expect(0, 74845, '\p{^Is_Numeric_Value=0001/003}', "");
Expect(0, 74845, '\P{Is_Numeric_Value=0001/003}', "");
Expect(1, 74845, '\P{^Is_Numeric_Value=0001/003}', "");
Expect(0, 74846, '\p{Is_Numeric_Value=0001/003}', "");
Expect(1, 74846, '\p{^Is_Numeric_Value=0001/003}', "");
Expect(1, 74846, '\P{Is_Numeric_Value=0001/003}', "");
Expect(0, 74846, '\P{^Is_Numeric_Value=0001/003}', "");
Error('\p{Is_Numeric_Value=0.3}');
Error('\P{Is_Numeric_Value=0.3}');
Error('\p{Is_Numeric_Value=0.33}');
Error('\P{Is_Numeric_Value=0.33}');
Expect(1, 74845, '\p{Is_Numeric_Value=0.333}', "");
Expect(0, 74845, '\p{^Is_Numeric_Value=0.333}', "");
Expect(0, 74845, '\P{Is_Numeric_Value=0.333}', "");
Expect(1, 74845, '\P{^Is_Numeric_Value=0.333}', "");
Expect(0, 74846, '\p{Is_Numeric_Value=0.333}', "");
Expect(1, 74846, '\p{^Is_Numeric_Value=0.333}', "");
Expect(1, 74846, '\P{Is_Numeric_Value=0.333}', "");
Expect(0, 74846, '\P{^Is_Numeric_Value=0.333}', "");
Error('\p{Is_Nv=	+0000001/3:=}');
Error('\P{Is_Nv=	+0000001/3:=}');
Expect(1, 74845, '\p{Is_Nv=001/0000003}', "");
Expect(0, 74845, '\p{^Is_Nv=001/0000003}', "");
Expect(0, 74845, '\P{Is_Nv=001/0000003}', "");
Expect(1, 74845, '\P{^Is_Nv=001/0000003}', "");
Expect(0, 74846, '\p{Is_Nv=001/0000003}', "");
Expect(1, 74846, '\p{^Is_Nv=001/0000003}', "");
Expect(1, 74846, '\P{Is_Nv=001/0000003}', "");
Expect(0, 74846, '\P{^Is_Nv=001/0000003}', "");
Error('\p{Is_Nv=0.3}');
Error('\P{Is_Nv=0.3}');
Error('\p{Is_Nv=0.33}');
Error('\P{Is_Nv=0.33}');
Expect(1, 74845, '\p{Is_Nv=0.333}', "");
Expect(0, 74845, '\p{^Is_Nv=0.333}', "");
Expect(0, 74845, '\P{Is_Nv=0.333}', "");
Expect(1, 74845, '\P{^Is_Nv=0.333}', "");
Expect(0, 74846, '\p{Is_Nv=0.333}', "");
Expect(1, 74846, '\p{^Is_Nv=0.333}', "");
Expect(1, 74846, '\P{Is_Nv=0.333}', "");
Expect(0, 74846, '\P{^Is_Nv=0.333}', "");
Error('\p{Numeric_Value=/a/-_+0001/0000000004}');
Error('\P{Numeric_Value=/a/-_+0001/0000000004}');
Expect(1, 74850, '\p{Numeric_Value=+01/4}', "");
Expect(0, 74850, '\p{^Numeric_Value=+01/4}', "");
Expect(0, 74850, '\P{Numeric_Value=+01/4}', "");
Expect(1, 74850, '\P{^Numeric_Value=+01/4}', "");
Expect(0, 74851, '\p{Numeric_Value=+01/4}', "");
Expect(1, 74851, '\p{^Numeric_Value=+01/4}', "");
Expect(1, 74851, '\P{Numeric_Value=+01/4}', "");
Expect(0, 74851, '\P{^Numeric_Value=+01/4}', "");
Expect(1, 74850, '\p{Numeric_Value=0.250}', "");
Expect(0, 74850, '\p{^Numeric_Value=0.250}', "");
Expect(0, 74850, '\P{Numeric_Value=0.250}', "");
Expect(1, 74850, '\P{^Numeric_Value=0.250}', "");
Expect(0, 74851, '\p{Numeric_Value=0.250}', "");
Expect(1, 74851, '\p{^Numeric_Value=0.250}', "");
Expect(1, 74851, '\P{Numeric_Value=0.250}', "");
Expect(0, 74851, '\P{^Numeric_Value=0.250}', "");
Error('\p{Nv=	:=+01/04}');
Error('\P{Nv=	:=+01/04}');
Expect(1, 74850, '\p{Nv=00001/0000004}', "");
Expect(0, 74850, '\p{^Nv=00001/0000004}', "");
Expect(0, 74850, '\P{Nv=00001/0000004}', "");
Expect(1, 74850, '\P{^Nv=00001/0000004}', "");
Expect(0, 74851, '\p{Nv=00001/0000004}', "");
Expect(1, 74851, '\p{^Nv=00001/0000004}', "");
Expect(1, 74851, '\P{Nv=00001/0000004}', "");
Expect(0, 74851, '\P{^Nv=00001/0000004}', "");
Expect(1, 74850, '\p{Nv=0.250}', "");
Expect(0, 74850, '\p{^Nv=0.250}', "");
Expect(0, 74850, '\P{Nv=0.250}', "");
Expect(1, 74850, '\P{^Nv=0.250}', "");
Expect(0, 74851, '\p{Nv=0.250}', "");
Expect(1, 74851, '\p{^Nv=0.250}', "");
Expect(1, 74851, '\P{Nv=0.250}', "");
Expect(0, 74851, '\P{^Nv=0.250}', "");
Error('\p{Is_Numeric_Value=/a/		000001/004}');
Error('\P{Is_Numeric_Value=/a/		000001/004}');
Expect(1, 74850, '\p{Is_Numeric_Value=+0000001/000004}', "");
Expect(0, 74850, '\p{^Is_Numeric_Value=+0000001/000004}', "");
Expect(0, 74850, '\P{Is_Numeric_Value=+0000001/000004}', "");
Expect(1, 74850, '\P{^Is_Numeric_Value=+0000001/000004}', "");
Expect(0, 74851, '\p{Is_Numeric_Value=+0000001/000004}', "");
Expect(1, 74851, '\p{^Is_Numeric_Value=+0000001/000004}', "");
Expect(1, 74851, '\P{Is_Numeric_Value=+0000001/000004}', "");
Expect(0, 74851, '\P{^Is_Numeric_Value=+0000001/000004}', "");
Expect(1, 74850, '\p{Is_Numeric_Value: 0.250}', "");
Expect(0, 74850, '\p{^Is_Numeric_Value: 0.250}', "");
Expect(0, 74850, '\P{Is_Numeric_Value: 0.250}', "");
Expect(1, 74850, '\P{^Is_Numeric_Value: 0.250}', "");
Expect(0, 74851, '\p{Is_Numeric_Value: 0.250}', "");
Expect(1, 74851, '\p{^Is_Numeric_Value: 0.250}', "");
Expect(1, 74851, '\P{Is_Numeric_Value: 0.250}', "");
Expect(0, 74851, '\P{^Is_Numeric_Value: 0.250}', "");
Error('\p{Is_Nv=	:=000001/0004}');
Error('\P{Is_Nv=	:=000001/0004}');
Expect(1, 74850, '\p{Is_Nv=001/000000004}', "");
Expect(0, 74850, '\p{^Is_Nv=001/000000004}', "");
Expect(0, 74850, '\P{Is_Nv=001/000000004}', "");
Expect(1, 74850, '\P{^Is_Nv=001/000000004}', "");
Expect(0, 74851, '\p{Is_Nv=001/000000004}', "");
Expect(1, 74851, '\p{^Is_Nv=001/000000004}', "");
Expect(1, 74851, '\P{Is_Nv=001/000000004}', "");
Expect(0, 74851, '\P{^Is_Nv=001/000000004}', "");
Expect(1, 74850, '\p{Is_Nv=0.250}', "");
Expect(0, 74850, '\p{^Is_Nv=0.250}', "");
Expect(0, 74850, '\P{Is_Nv=0.250}', "");
Expect(1, 74850, '\P{^Is_Nv=0.250}', "");
Expect(0, 74851, '\p{Is_Nv=0.250}', "");
Expect(1, 74851, '\p{^Is_Nv=0.250}', "");
Expect(1, 74851, '\P{Is_Nv=0.250}', "");
Expect(0, 74851, '\P{^Is_Nv=0.250}', "");
Error('\p{Numeric_Value=:=- +0000001/00005}');
Error('\P{Numeric_Value=:=- +0000001/00005}');
Expect(1, 8533, '\p{Numeric_Value=+001/05}', "");
Expect(0, 8533, '\p{^Numeric_Value=+001/05}', "");
Expect(0, 8533, '\P{Numeric_Value=+001/05}', "");
Expect(1, 8533, '\P{^Numeric_Value=+001/05}', "");
Expect(0, 8534, '\p{Numeric_Value=+001/05}', "");
Expect(1, 8534, '\p{^Numeric_Value=+001/05}', "");
Expect(1, 8534, '\P{Numeric_Value=+001/05}', "");
Expect(0, 8534, '\P{^Numeric_Value=+001/05}', "");
Expect(1, 8533, '\p{Numeric_Value=0.200}', "");
Expect(0, 8533, '\p{^Numeric_Value=0.200}', "");
Expect(0, 8533, '\P{Numeric_Value=0.200}', "");
Expect(1, 8533, '\P{^Numeric_Value=0.200}', "");
Expect(0, 8534, '\p{Numeric_Value=0.200}', "");
Expect(1, 8534, '\p{^Numeric_Value=0.200}', "");
Expect(1, 8534, '\P{Numeric_Value=0.200}', "");
Expect(0, 8534, '\P{^Numeric_Value=0.200}', "");
Error('\p{Nv: --+0000001/0000000005:=}');
Error('\P{Nv: --+0000001/0000000005:=}');
Expect(1, 8533, '\p{Nv=01/0005}', "");
Expect(0, 8533, '\p{^Nv=01/0005}', "");
Expect(0, 8533, '\P{Nv=01/0005}', "");
Expect(1, 8533, '\P{^Nv=01/0005}', "");
Expect(0, 8534, '\p{Nv=01/0005}', "");
Expect(1, 8534, '\p{^Nv=01/0005}', "");
Expect(1, 8534, '\P{Nv=01/0005}', "");
Expect(0, 8534, '\P{^Nv=01/0005}', "");
Expect(1, 8533, '\p{Nv=0.200}', "");
Expect(0, 8533, '\p{^Nv=0.200}', "");
Expect(0, 8533, '\P{Nv=0.200}', "");
Expect(1, 8533, '\P{^Nv=0.200}', "");
Expect(0, 8534, '\p{Nv=0.200}', "");
Expect(1, 8534, '\p{^Nv=0.200}', "");
Expect(1, 8534, '\P{Nv=0.200}', "");
Expect(0, 8534, '\P{^Nv=0.200}', "");
Error('\p{Is_Numeric_Value= :=000001/5}');
Error('\P{Is_Numeric_Value= :=000001/5}');
Expect(1, 8533, '\p{Is_Numeric_Value=1/000000005}', "");
Expect(0, 8533, '\p{^Is_Numeric_Value=1/000000005}', "");
Expect(0, 8533, '\P{Is_Numeric_Value=1/000000005}', "");
Expect(1, 8533, '\P{^Is_Numeric_Value=1/000000005}', "");
Expect(0, 8534, '\p{Is_Numeric_Value=1/000000005}', "");
Expect(1, 8534, '\p{^Is_Numeric_Value=1/000000005}', "");
Expect(1, 8534, '\P{Is_Numeric_Value=1/000000005}', "");
Expect(0, 8534, '\P{^Is_Numeric_Value=1/000000005}', "");
Expect(1, 8533, '\p{Is_Numeric_Value=0.200}', "");
Expect(0, 8533, '\p{^Is_Numeric_Value=0.200}', "");
Expect(0, 8533, '\P{Is_Numeric_Value=0.200}', "");
Expect(1, 8533, '\P{^Is_Numeric_Value=0.200}', "");
Expect(0, 8534, '\p{Is_Numeric_Value=0.200}', "");
Expect(1, 8534, '\p{^Is_Numeric_Value=0.200}', "");
Expect(1, 8534, '\P{Is_Numeric_Value=0.200}', "");
Expect(0, 8534, '\P{^Is_Numeric_Value=0.200}', "");
Error('\p{Is_Nv= -00001/00000005:=}');
Error('\P{Is_Nv= -00001/00000005:=}');
Expect(1, 8533, '\p{Is_Nv=0000001/5}', "");
Expect(0, 8533, '\p{^Is_Nv=0000001/5}', "");
Expect(0, 8533, '\P{Is_Nv=0000001/5}', "");
Expect(1, 8533, '\P{^Is_Nv=0000001/5}', "");
Expect(0, 8534, '\p{Is_Nv=0000001/5}', "");
Expect(1, 8534, '\p{^Is_Nv=0000001/5}', "");
Expect(1, 8534, '\P{Is_Nv=0000001/5}', "");
Expect(0, 8534, '\P{^Is_Nv=0000001/5}', "");
Expect(1, 8533, '\p{Is_Nv=0.200}', "");
Expect(0, 8533, '\p{^Is_Nv=0.200}', "");
Expect(0, 8533, '\P{Is_Nv=0.200}', "");
Expect(1, 8533, '\P{^Is_Nv=0.200}', "");
Expect(0, 8534, '\p{Is_Nv=0.200}', "");
Expect(1, 8534, '\p{^Is_Nv=0.200}', "");
Expect(1, 8534, '\P{Is_Nv=0.200}', "");
Expect(0, 8534, '\P{^Is_Nv=0.200}', "");
Error('\p{Numeric_Value:   :=	01/000006}');
Error('\P{Numeric_Value:   :=	01/000006}');
Expect(1, 74849, '\p{Numeric_Value=0000000001/0000000006}', "");
Expect(0, 74849, '\p{^Numeric_Value=0000000001/0000000006}', "");
Expect(0, 74849, '\P{Numeric_Value=0000000001/0000000006}', "");
Expect(1, 74849, '\P{^Numeric_Value=0000000001/0000000006}', "");
Expect(0, 74850, '\p{Numeric_Value=0000000001/0000000006}', "");
Expect(1, 74850, '\p{^Numeric_Value=0000000001/0000000006}', "");
Expect(1, 74850, '\P{Numeric_Value=0000000001/0000000006}', "");
Expect(0, 74850, '\P{^Numeric_Value=0000000001/0000000006}', "");
Error('\p{Numeric_Value=0.17}');
Error('\P{Numeric_Value=0.17}');
Expect(1, 74849, '\p{Numeric_Value=0.167}', "");
Expect(0, 74849, '\p{^Numeric_Value=0.167}', "");
Expect(0, 74849, '\P{Numeric_Value=0.167}', "");
Expect(1, 74849, '\P{^Numeric_Value=0.167}', "");
Expect(0, 74850, '\p{Numeric_Value=0.167}', "");
Expect(1, 74850, '\p{^Numeric_Value=0.167}', "");
Expect(1, 74850, '\P{Numeric_Value=0.167}', "");
Expect(0, 74850, '\P{^Numeric_Value=0.167}', "");
Error('\p{Nv=/a/__00000001/0000000006}');
Error('\P{Nv=/a/__00000001/0000000006}');
Expect(1, 74849, '\p{Nv=0000000001/006}', "");
Expect(0, 74849, '\p{^Nv=0000000001/006}', "");
Expect(0, 74849, '\P{Nv=0000000001/006}', "");
Expect(1, 74849, '\P{^Nv=0000000001/006}', "");
Expect(0, 74850, '\p{Nv=0000000001/006}', "");
Expect(1, 74850, '\p{^Nv=0000000001/006}', "");
Expect(1, 74850, '\P{Nv=0000000001/006}', "");
Expect(0, 74850, '\P{^Nv=0000000001/006}', "");
Error('\p{Nv=0.17}');
Error('\P{Nv=0.17}');
Expect(1, 74849, '\p{Nv=0.167}', "");
Expect(0, 74849, '\p{^Nv=0.167}', "");
Expect(0, 74849, '\P{Nv=0.167}', "");
Expect(1, 74849, '\P{^Nv=0.167}', "");
Expect(0, 74850, '\p{Nv=0.167}', "");
Expect(1, 74850, '\p{^Nv=0.167}', "");
Expect(1, 74850, '\P{Nv=0.167}', "");
Expect(0, 74850, '\P{^Nv=0.167}', "");
Error('\p{Is_Numeric_Value:   _+0000001/0000000006:=}');
Error('\P{Is_Numeric_Value:   _+0000001/0000000006:=}');
Expect(1, 74849, '\p{Is_Numeric_Value=00000001/0000006}', "");
Expect(0, 74849, '\p{^Is_Numeric_Value=00000001/0000006}', "");
Expect(0, 74849, '\P{Is_Numeric_Value=00000001/0000006}', "");
Expect(1, 74849, '\P{^Is_Numeric_Value=00000001/0000006}', "");
Expect(0, 74850, '\p{Is_Numeric_Value=00000001/0000006}', "");
Expect(1, 74850, '\p{^Is_Numeric_Value=00000001/0000006}', "");
Expect(1, 74850, '\P{Is_Numeric_Value=00000001/0000006}', "");
Expect(0, 74850, '\P{^Is_Numeric_Value=00000001/0000006}', "");
Error('\p{Is_Numeric_Value=0.17}');
Error('\P{Is_Numeric_Value=0.17}');
Expect(1, 74849, '\p{Is_Numeric_Value=0.167}', "");
Expect(0, 74849, '\p{^Is_Numeric_Value=0.167}', "");
Expect(0, 74849, '\P{Is_Numeric_Value=0.167}', "");
Expect(1, 74849, '\P{^Is_Numeric_Value=0.167}', "");
Expect(0, 74850, '\p{Is_Numeric_Value=0.167}', "");
Expect(1, 74850, '\p{^Is_Numeric_Value=0.167}', "");
Expect(1, 74850, '\P{Is_Numeric_Value=0.167}', "");
Expect(0, 74850, '\P{^Is_Numeric_Value=0.167}', "");
Error('\p{Is_Nv=/a/_-0001/000000006}');
Error('\P{Is_Nv=/a/_-0001/000000006}');
Expect(1, 74849, '\p{Is_Nv:000001/00006}', "");
Expect(0, 74849, '\p{^Is_Nv:000001/00006}', "");
Expect(0, 74849, '\P{Is_Nv:000001/00006}', "");
Expect(1, 74849, '\P{^Is_Nv:000001/00006}', "");
Expect(0, 74850, '\p{Is_Nv:000001/00006}', "");
Expect(1, 74850, '\p{^Is_Nv:000001/00006}', "");
Expect(1, 74850, '\P{Is_Nv:000001/00006}', "");
Expect(0, 74850, '\P{^Is_Nv:000001/00006}', "");
Error('\p{Is_Nv=0.17}');
Error('\P{Is_Nv=0.17}');
Expect(1, 74849, '\p{Is_Nv=0.167}', "");
Expect(0, 74849, '\p{^Is_Nv=0.167}', "");
Expect(0, 74849, '\P{Is_Nv=0.167}', "");
Expect(1, 74849, '\P{^Is_Nv=0.167}', "");
Expect(0, 74850, '\p{Is_Nv=0.167}', "");
Expect(1, 74850, '\p{^Is_Nv=0.167}', "");
Expect(1, 74850, '\P{Is_Nv=0.167}', "");
Expect(0, 74850, '\P{^Is_Nv=0.167}', "");
Error('\p{Numeric_Value=	001/07/a/}');
Error('\P{Numeric_Value=	001/07/a/}');
Expect(1, 8528, '\p{Numeric_Value=0000000001/000007}', "");
Expect(0, 8528, '\p{^Numeric_Value=0000000001/000007}', "");
Expect(0, 8528, '\P{Numeric_Value=0000000001/000007}', "");
Expect(1, 8528, '\P{^Numeric_Value=0000000001/000007}', "");
Expect(0, 8529, '\p{Numeric_Value=0000000001/000007}', "");
Expect(1, 8529, '\p{^Numeric_Value=0000000001/000007}', "");
Expect(1, 8529, '\P{Numeric_Value=0000000001/000007}', "");
Expect(0, 8529, '\P{^Numeric_Value=0000000001/000007}', "");
Error('\p{Numeric_Value=0.14}');
Error('\P{Numeric_Value=0.14}');
Expect(1, 8528, '\p{Numeric_Value:0.143}', "");
Expect(0, 8528, '\p{^Numeric_Value:0.143}', "");
Expect(0, 8528, '\P{Numeric_Value:0.143}', "");
Expect(1, 8528, '\P{^Numeric_Value:0.143}', "");
Expect(0, 8529, '\p{Numeric_Value:0.143}', "");
Expect(1, 8529, '\p{^Numeric_Value:0.143}', "");
Expect(1, 8529, '\P{Numeric_Value:0.143}', "");
Expect(0, 8529, '\P{^Numeric_Value:0.143}', "");
Error('\p{Nv:		 1/07/a/}');
Error('\P{Nv:		 1/07/a/}');
Expect(1, 8528, '\p{Nv=000001/0007}', "");
Expect(0, 8528, '\p{^Nv=000001/0007}', "");
Expect(0, 8528, '\P{Nv=000001/0007}', "");
Expect(1, 8528, '\P{^Nv=000001/0007}', "");
Expect(0, 8529, '\p{Nv=000001/0007}', "");
Expect(1, 8529, '\p{^Nv=000001/0007}', "");
Expect(1, 8529, '\P{Nv=000001/0007}', "");
Expect(0, 8529, '\P{^Nv=000001/0007}', "");
Error('\p{Nv=0.14}');
Error('\P{Nv=0.14}');
Expect(1, 8528, '\p{Nv=0.143}', "");
Expect(0, 8528, '\p{^Nv=0.143}', "");
Expect(0, 8528, '\P{Nv=0.143}', "");
Expect(1, 8528, '\P{^Nv=0.143}', "");
Expect(0, 8529, '\p{Nv=0.143}', "");
Expect(1, 8529, '\p{^Nv=0.143}', "");
Expect(1, 8529, '\P{Nv=0.143}', "");
Expect(0, 8529, '\P{^Nv=0.143}', "");
Error('\p{Is_Numeric_Value=:=_ 000001/0007}');
Error('\P{Is_Numeric_Value=:=_ 000001/0007}');
Expect(1, 8528, '\p{Is_Numeric_Value=+00000001/07}', "");
Expect(0, 8528, '\p{^Is_Numeric_Value=+00000001/07}', "");
Expect(0, 8528, '\P{Is_Numeric_Value=+00000001/07}', "");
Expect(1, 8528, '\P{^Is_Numeric_Value=+00000001/07}', "");
Expect(0, 8529, '\p{Is_Numeric_Value=+00000001/07}', "");
Expect(1, 8529, '\p{^Is_Numeric_Value=+00000001/07}', "");
Expect(1, 8529, '\P{Is_Numeric_Value=+00000001/07}', "");
Expect(0, 8529, '\P{^Is_Numeric_Value=+00000001/07}', "");
Error('\p{Is_Numeric_Value=0.14}');
Error('\P{Is_Numeric_Value=0.14}');
Expect(1, 8528, '\p{Is_Numeric_Value=0.143}', "");
Expect(0, 8528, '\p{^Is_Numeric_Value=0.143}', "");
Expect(0, 8528, '\P{Is_Numeric_Value=0.143}', "");
Expect(1, 8528, '\P{^Is_Numeric_Value=0.143}', "");
Expect(0, 8529, '\p{Is_Numeric_Value=0.143}', "");
Expect(1, 8529, '\p{^Is_Numeric_Value=0.143}', "");
Expect(1, 8529, '\P{Is_Numeric_Value=0.143}', "");
Expect(0, 8529, '\P{^Is_Numeric_Value=0.143}', "");
Error('\p{Is_Nv=:=--01/7}');
Error('\P{Is_Nv=:=--01/7}');
Expect(1, 8528, '\p{Is_Nv:00001/0007}', "");
Expect(0, 8528, '\p{^Is_Nv:00001/0007}', "");
Expect(0, 8528, '\P{Is_Nv:00001/0007}', "");
Expect(1, 8528, '\P{^Is_Nv:00001/0007}', "");
Expect(0, 8529, '\p{Is_Nv:00001/0007}', "");
Expect(1, 8529, '\p{^Is_Nv:00001/0007}', "");
Expect(1, 8529, '\P{Is_Nv:00001/0007}', "");
Expect(0, 8529, '\P{^Is_Nv:00001/0007}', "");
Error('\p{Is_Nv:	0.14}');
Error('\P{Is_Nv:	0.14}');
Expect(1, 8528, '\p{Is_Nv=0.143}', "");
Expect(0, 8528, '\p{^Is_Nv=0.143}', "");
Expect(0, 8528, '\P{Is_Nv=0.143}', "");
Expect(1, 8528, '\P{^Is_Nv=0.143}', "");
Expect(0, 8529, '\p{Is_Nv=0.143}', "");
Expect(1, 8529, '\p{^Is_Nv=0.143}', "");
Expect(1, 8529, '\P{Is_Nv=0.143}', "");
Expect(0, 8529, '\P{^Is_Nv=0.143}', "");
Error('\p{Numeric_Value=	-0000000001/000000008/a/}');
Error('\P{Numeric_Value=	-0000000001/000000008/a/}');
Expect(1, 74847, '\p{Numeric_Value:   1/0000000008}', "");
Expect(0, 74847, '\p{^Numeric_Value:   1/0000000008}', "");
Expect(0, 74847, '\P{Numeric_Value:   1/0000000008}', "");
Expect(1, 74847, '\P{^Numeric_Value:   1/0000000008}', "");
Expect(0, 74848, '\p{Numeric_Value:   1/0000000008}', "");
Expect(1, 74848, '\p{^Numeric_Value:   1/0000000008}', "");
Expect(1, 74848, '\P{Numeric_Value:   1/0000000008}', "");
Expect(0, 74848, '\P{^Numeric_Value:   1/0000000008}', "");
Error('\p{Numeric_Value=0.12}');
Error('\P{Numeric_Value=0.12}');
Expect(1, 74847, '\p{Numeric_Value=0.125}', "");
Expect(0, 74847, '\p{^Numeric_Value=0.125}', "");
Expect(0, 74847, '\P{Numeric_Value=0.125}', "");
Expect(1, 74847, '\P{^Numeric_Value=0.125}', "");
Expect(0, 74848, '\p{Numeric_Value=0.125}', "");
Expect(1, 74848, '\p{^Numeric_Value=0.125}', "");
Expect(1, 74848, '\P{Numeric_Value=0.125}', "");
Expect(0, 74848, '\P{^Numeric_Value=0.125}', "");
Error('\p{Nv=:=+0001/008}');
Error('\P{Nv=:=+0001/008}');
Expect(1, 74847, '\p{Nv=0000000001/000008}', "");
Expect(0, 74847, '\p{^Nv=0000000001/000008}', "");
Expect(0, 74847, '\P{Nv=0000000001/000008}', "");
Expect(1, 74847, '\P{^Nv=0000000001/000008}', "");
Expect(0, 74848, '\p{Nv=0000000001/000008}', "");
Expect(1, 74848, '\p{^Nv=0000000001/000008}', "");
Expect(1, 74848, '\P{Nv=0000000001/000008}', "");
Expect(0, 74848, '\P{^Nv=0000000001/000008}', "");
Error('\p{Nv=0.12}');
Error('\P{Nv=0.12}');
Expect(1, 74847, '\p{Nv=0.125}', "");
Expect(0, 74847, '\p{^Nv=0.125}', "");
Expect(0, 74847, '\P{Nv=0.125}', "");
Expect(1, 74847, '\P{^Nv=0.125}', "");
Expect(0, 74848, '\p{Nv=0.125}', "");
Expect(1, 74848, '\p{^Nv=0.125}', "");
Expect(1, 74848, '\P{Nv=0.125}', "");
Expect(0, 74848, '\P{^Nv=0.125}', "");
Error('\p{Is_Numeric_Value=-:=00001/008}');
Error('\P{Is_Numeric_Value=-:=00001/008}');
Expect(1, 74847, '\p{Is_Numeric_Value=+000000001/0008}', "");
Expect(0, 74847, '\p{^Is_Numeric_Value=+000000001/0008}', "");
Expect(0, 74847, '\P{Is_Numeric_Value=+000000001/0008}', "");
Expect(1, 74847, '\P{^Is_Numeric_Value=+000000001/0008}', "");
Expect(0, 74848, '\p{Is_Numeric_Value=+000000001/0008}', "");
Expect(1, 74848, '\p{^Is_Numeric_Value=+000000001/0008}', "");
Expect(1, 74848, '\P{Is_Numeric_Value=+000000001/0008}', "");
Expect(0, 74848, '\P{^Is_Numeric_Value=+000000001/0008}', "");
Error('\p{Is_Numeric_Value=0.12}');
Error('\P{Is_Numeric_Value=0.12}');
Expect(1, 74847, '\p{Is_Numeric_Value=0.125}', "");
Expect(0, 74847, '\p{^Is_Numeric_Value=0.125}', "");
Expect(0, 74847, '\P{Is_Numeric_Value=0.125}', "");
Expect(1, 74847, '\P{^Is_Numeric_Value=0.125}', "");
Expect(0, 74848, '\p{Is_Numeric_Value=0.125}', "");
Expect(1, 74848, '\p{^Is_Numeric_Value=0.125}', "");
Expect(1, 74848, '\P{Is_Numeric_Value=0.125}', "");
Expect(0, 74848, '\P{^Is_Numeric_Value=0.125}', "");
Error('\p{Is_Nv:   _/a/00000001/0000000008}');
Error('\P{Is_Nv:   _/a/00000001/0000000008}');
Expect(1, 74847, '\p{Is_Nv=000000001/00000008}', "");
Expect(0, 74847, '\p{^Is_Nv=000000001/00000008}', "");
Expect(0, 74847, '\P{Is_Nv=000000001/00000008}', "");
Expect(1, 74847, '\P{^Is_Nv=000000001/00000008}', "");
Expect(0, 74848, '\p{Is_Nv=000000001/00000008}', "");
Expect(1, 74848, '\p{^Is_Nv=000000001/00000008}', "");
Expect(1, 74848, '\P{Is_Nv=000000001/00000008}', "");
Expect(0, 74848, '\P{^Is_Nv=000000001/00000008}', "");
Error('\p{Is_Nv=0.12}');
Error('\P{Is_Nv=0.12}');
Expect(1, 74847, '\p{Is_Nv=0.125}', "");
Expect(0, 74847, '\p{^Is_Nv=0.125}', "");
Expect(0, 74847, '\P{Is_Nv=0.125}', "");
Expect(1, 74847, '\P{^Is_Nv=0.125}', "");
Expect(0, 74848, '\p{Is_Nv=0.125}', "");
Expect(1, 74848, '\p{^Is_Nv=0.125}', "");
Expect(1, 74848, '\P{Is_Nv=0.125}', "");
Expect(0, 74848, '\P{^Is_Nv=0.125}', "");
Error('\p{Numeric_Value=/a/ -00000001/0000009}');
Error('\P{Numeric_Value=/a/ -00000001/0000009}');
Expect(1, 8529, '\p{Numeric_Value=001/000009}', "");
Expect(0, 8529, '\p{^Numeric_Value=001/000009}', "");
Expect(0, 8529, '\P{Numeric_Value=001/000009}', "");
Expect(1, 8529, '\P{^Numeric_Value=001/000009}', "");
Expect(0, 8530, '\p{Numeric_Value=001/000009}', "");
Expect(1, 8530, '\p{^Numeric_Value=001/000009}', "");
Expect(1, 8530, '\P{Numeric_Value=001/000009}', "");
Expect(0, 8530, '\P{^Numeric_Value=001/000009}', "");
Error('\p{Numeric_Value=0.11}');
Error('\P{Numeric_Value=0.11}');
Expect(1, 8529, '\p{Numeric_Value: 0.111}', "");
Expect(0, 8529, '\p{^Numeric_Value: 0.111}', "");
Expect(0, 8529, '\P{Numeric_Value: 0.111}', "");
Expect(1, 8529, '\P{^Numeric_Value: 0.111}', "");
Expect(0, 8530, '\p{Numeric_Value: 0.111}', "");
Expect(1, 8530, '\p{^Numeric_Value: 0.111}', "");
Expect(1, 8530, '\P{Numeric_Value: 0.111}', "");
Expect(0, 8530, '\P{^Numeric_Value: 0.111}', "");
Error('\p{Nv=__+1/0000000009:=}');
Error('\P{Nv=__+1/0000000009:=}');
Expect(1, 8529, '\p{Nv=+1/9}', "");
Expect(0, 8529, '\p{^Nv=+1/9}', "");
Expect(0, 8529, '\P{Nv=+1/9}', "");
Expect(1, 8529, '\P{^Nv=+1/9}', "");
Expect(0, 8530, '\p{Nv=+1/9}', "");
Expect(1, 8530, '\p{^Nv=+1/9}', "");
Expect(1, 8530, '\P{Nv=+1/9}', "");
Expect(0, 8530, '\P{^Nv=+1/9}', "");
Error('\p{Nv=0.11}');
Error('\P{Nv=0.11}');
Expect(1, 8529, '\p{Nv=0.111}', "");
Expect(0, 8529, '\p{^Nv=0.111}', "");
Expect(0, 8529, '\P{Nv=0.111}', "");
Expect(1, 8529, '\P{^Nv=0.111}', "");
Expect(0, 8530, '\p{Nv=0.111}', "");
Expect(1, 8530, '\p{^Nv=0.111}', "");
Expect(1, 8530, '\P{Nv=0.111}', "");
Expect(0, 8530, '\P{^Nv=0.111}', "");
Error('\p{Is_Numeric_Value=  +000001/00009:=}');
Error('\P{Is_Numeric_Value=  +000001/00009:=}');
Expect(1, 8529, '\p{Is_Numeric_Value=+000000001/09}', "");
Expect(0, 8529, '\p{^Is_Numeric_Value=+000000001/09}', "");
Expect(0, 8529, '\P{Is_Numeric_Value=+000000001/09}', "");
Expect(1, 8529, '\P{^Is_Numeric_Value=+000000001/09}', "");
Expect(0, 8530, '\p{Is_Numeric_Value=+000000001/09}', "");
Expect(1, 8530, '\p{^Is_Numeric_Value=+000000001/09}', "");
Expect(1, 8530, '\P{Is_Numeric_Value=+000000001/09}', "");
Expect(0, 8530, '\P{^Is_Numeric_Value=+000000001/09}', "");
Error('\p{Is_Numeric_Value=0.11}');
Error('\P{Is_Numeric_Value=0.11}');
Expect(1, 8529, '\p{Is_Numeric_Value=0.111}', "");
Expect(0, 8529, '\p{^Is_Numeric_Value=0.111}', "");
Expect(0, 8529, '\P{Is_Numeric_Value=0.111}', "");
Expect(1, 8529, '\P{^Is_Numeric_Value=0.111}', "");
Expect(0, 8530, '\p{Is_Numeric_Value=0.111}', "");
Expect(1, 8530, '\p{^Is_Numeric_Value=0.111}', "");
Expect(1, 8530, '\P{Is_Numeric_Value=0.111}', "");
Expect(0, 8530, '\P{^Is_Numeric_Value=0.111}', "");
Error('\p{Is_Nv=/a/	001/0000009}');
Error('\P{Is_Nv=/a/	001/0000009}');
Expect(1, 8529, '\p{Is_Nv=0000001/9}', "");
Expect(0, 8529, '\p{^Is_Nv=0000001/9}', "");
Expect(0, 8529, '\P{Is_Nv=0000001/9}', "");
Expect(1, 8529, '\P{^Is_Nv=0000001/9}', "");
Expect(0, 8530, '\p{Is_Nv=0000001/9}', "");
Expect(1, 8530, '\p{^Is_Nv=0000001/9}', "");
Expect(1, 8530, '\P{Is_Nv=0000001/9}', "");
Expect(0, 8530, '\P{^Is_Nv=0000001/9}', "");
Error('\p{Is_Nv:	0.11}');
Error('\P{Is_Nv:	0.11}');
Expect(1, 8529, '\p{Is_Nv=0.111}', "");
Expect(0, 8529, '\p{^Is_Nv=0.111}', "");
Expect(0, 8529, '\P{Is_Nv=0.111}', "");
Expect(1, 8529, '\P{^Is_Nv=0.111}', "");
Expect(0, 8530, '\p{Is_Nv=0.111}', "");
Expect(1, 8530, '\p{^Is_Nv=0.111}', "");
Expect(1, 8530, '\P{Is_Nv=0.111}', "");
Expect(0, 8530, '\P{^Is_Nv=0.111}', "");
Error('\p{Numeric_Value=_/a/+0010}');
Error('\P{Numeric_Value=_/a/+0010}');
Expect(1, 119657, '\p{Numeric_Value=010}', "");
Expect(0, 119657, '\p{^Numeric_Value=010}', "");
Expect(0, 119657, '\P{Numeric_Value=010}', "");
Expect(1, 119657, '\P{^Numeric_Value=010}', "");
Expect(0, 119658, '\p{Numeric_Value=010}', "");
Expect(1, 119658, '\p{^Numeric_Value=010}', "");
Expect(1, 119658, '\P{Numeric_Value=010}', "");
Expect(0, 119658, '\P{^Numeric_Value=010}', "");
Error('\p{Nv= :=0000010}');
Error('\P{Nv= :=0000010}');
Expect(1, 119657, '\p{Nv=0_0_0_0_0_00010}', "");
Expect(0, 119657, '\p{^Nv=0_0_0_0_0_00010}', "");
Expect(0, 119657, '\P{Nv=0_0_0_0_0_00010}', "");
Expect(1, 119657, '\P{^Nv=0_0_0_0_0_00010}', "");
Expect(0, 119658, '\p{Nv=0_0_0_0_0_00010}', "");
Expect(1, 119658, '\p{^Nv=0_0_0_0_0_00010}', "");
Expect(1, 119658, '\P{Nv=0_0_0_0_0_00010}', "");
Expect(0, 119658, '\P{^Nv=0_0_0_0_0_00010}', "");
Error('\p{Is_Numeric_Value=	/a/+000000010}');
Error('\P{Is_Numeric_Value=	/a/+000000010}');
Expect(1, 119657, '\p{Is_Numeric_Value:	+0000000010}', "");
Expect(0, 119657, '\p{^Is_Numeric_Value:	+0000000010}', "");
Expect(0, 119657, '\P{Is_Numeric_Value:	+0000000010}', "");
Expect(1, 119657, '\P{^Is_Numeric_Value:	+0000000010}', "");
Expect(0, 119658, '\p{Is_Numeric_Value:	+0000000010}', "");
Expect(1, 119658, '\p{^Is_Numeric_Value:	+0000000010}', "");
Expect(1, 119658, '\P{Is_Numeric_Value:	+0000000010}', "");
Expect(0, 119658, '\P{^Is_Numeric_Value:	+0000000010}', "");
Error('\p{Is_Nv=:=	_00000000010}');
Error('\P{Is_Nv=:=	_00000000010}');
Expect(1, 119657, '\p{Is_Nv=10}', "");
Expect(0, 119657, '\p{^Is_Nv=10}', "");
Expect(0, 119657, '\P{Is_Nv=10}', "");
Expect(1, 119657, '\P{^Is_Nv=10}', "");
Expect(0, 119658, '\p{Is_Nv=10}', "");
Expect(1, 119658, '\p{^Is_Nv=10}', "");
Expect(1, 119658, '\P{Is_Nv=10}', "");
Expect(0, 119658, '\P{^Is_Nv=10}', "");
Error('\p{Numeric_Value=--0_0_1_00:=}');
Error('\P{Numeric_Value=--0_0_1_00:=}');
Expect(1, 69732, '\p{Numeric_Value=+0000100}', "");
Expect(0, 69732, '\p{^Numeric_Value=+0000100}', "");
Expect(0, 69732, '\P{Numeric_Value=+0000100}', "");
Expect(1, 69732, '\P{^Numeric_Value=+0000100}', "");
Expect(0, 69733, '\p{Numeric_Value=+0000100}', "");
Expect(1, 69733, '\p{^Numeric_Value=+0000100}', "");
Expect(1, 69733, '\P{Numeric_Value=+0000100}', "");
Expect(0, 69733, '\P{^Numeric_Value=+0000100}', "");
Error('\p{Nv= -000100:=}');
Error('\P{Nv= -000100:=}');
Expect(1, 69732, '\p{Nv:	00000_00001_00}', "");
Expect(0, 69732, '\p{^Nv:	00000_00001_00}', "");
Expect(0, 69732, '\P{Nv:	00000_00001_00}', "");
Expect(1, 69732, '\P{^Nv:	00000_00001_00}', "");
Expect(0, 69733, '\p{Nv:	00000_00001_00}', "");
Expect(1, 69733, '\p{^Nv:	00000_00001_00}', "");
Expect(1, 69733, '\P{Nv:	00000_00001_00}', "");
Expect(0, 69733, '\P{^Nv:	00000_00001_00}', "");
Error('\p{Is_Numeric_Value=/a/ -0_0_0_0_1_00}');
Error('\P{Is_Numeric_Value=/a/ -0_0_0_0_1_00}');
Expect(1, 69732, '\p{Is_Numeric_Value=+00100}', "");
Expect(0, 69732, '\p{^Is_Numeric_Value=+00100}', "");
Expect(0, 69732, '\P{Is_Numeric_Value=+00100}', "");
Expect(1, 69732, '\P{^Is_Numeric_Value=+00100}', "");
Expect(0, 69733, '\p{Is_Numeric_Value=+00100}', "");
Expect(1, 69733, '\p{^Is_Numeric_Value=+00100}', "");
Expect(1, 69733, '\P{Is_Numeric_Value=+00100}', "");
Expect(0, 69733, '\P{^Is_Numeric_Value=+00100}', "");
Error('\p{Is_Nv=-+010_0/a/}');
Error('\P{Is_Nv=-+010_0/a/}');
Expect(1, 69732, '\p{Is_Nv=+00000000100}', "");
Expect(0, 69732, '\p{^Is_Nv=+00000000100}', "");
Expect(0, 69732, '\P{Is_Nv=+00000000100}', "");
Expect(1, 69732, '\P{^Is_Nv=+00000000100}', "");
Expect(0, 69733, '\p{Is_Nv=+00000000100}', "");
Expect(1, 69733, '\p{^Is_Nv=+00000000100}', "");
Expect(1, 69733, '\P{Is_Nv=+00000000100}', "");
Expect(0, 69733, '\P{^Is_Nv=+00000000100}', "");
Error('\p{Numeric_Value=	_0000001000:=}');
Error('\P{Numeric_Value=	_0000001000:=}');
Expect(1, 69733, '\p{Numeric_Value=100_0}', "");
Expect(0, 69733, '\p{^Numeric_Value=100_0}', "");
Expect(0, 69733, '\P{Numeric_Value=100_0}', "");
Expect(1, 69733, '\P{^Numeric_Value=100_0}', "");
Expect(0, 69734, '\p{Numeric_Value=100_0}', "");
Expect(1, 69734, '\p{^Numeric_Value=100_0}', "");
Expect(1, 69734, '\P{Numeric_Value=100_0}', "");
Expect(0, 69734, '\P{^Numeric_Value=100_0}', "");
Error('\p{Nv: _-000000100_0/a/}');
Error('\P{Nv: _-000000100_0/a/}');
Expect(1, 69733, '\p{Nv=+1000}', "");
Expect(0, 69733, '\p{^Nv=+1000}', "");
Expect(0, 69733, '\P{Nv=+1000}', "");
Expect(1, 69733, '\P{^Nv=+1000}', "");
Expect(0, 69734, '\p{Nv=+1000}', "");
Expect(1, 69734, '\p{^Nv=+1000}', "");
Expect(1, 69734, '\P{Nv=+1000}', "");
Expect(0, 69734, '\P{^Nv=+1000}', "");
Error('\p{Is_Numeric_Value=	+0_0_0_0_1_0_00:=}');
Error('\P{Is_Numeric_Value=	+0_0_0_0_1_0_00:=}');
Expect(1, 69733, '\p{Is_Numeric_Value=+000001000}', "");
Expect(0, 69733, '\p{^Is_Numeric_Value=+000001000}', "");
Expect(0, 69733, '\P{Is_Numeric_Value=+000001000}', "");
Expect(1, 69733, '\P{^Is_Numeric_Value=+000001000}', "");
Expect(0, 69734, '\p{Is_Numeric_Value=+000001000}', "");
Expect(1, 69734, '\p{^Is_Numeric_Value=+000001000}', "");
Expect(1, 69734, '\P{Is_Numeric_Value=+000001000}', "");
Expect(0, 69734, '\P{^Is_Numeric_Value=+000001000}', "");
Error('\p{Is_Nv=	/a/001000}');
Error('\P{Is_Nv=	/a/001000}');
Expect(1, 69733, '\p{Is_Nv=+0_0_0_0_0_0_0_0_0_1_000}', "");
Expect(0, 69733, '\p{^Is_Nv=+0_0_0_0_0_0_0_0_0_1_000}', "");
Expect(0, 69733, '\P{Is_Nv=+0_0_0_0_0_0_0_0_0_1_000}', "");
Expect(1, 69733, '\P{^Is_Nv=+0_0_0_0_0_0_0_0_0_1_000}', "");
Expect(0, 69734, '\p{Is_Nv=+0_0_0_0_0_0_0_0_0_1_000}', "");
Expect(1, 69734, '\p{^Is_Nv=+0_0_0_0_0_0_0_0_0_1_000}', "");
Expect(1, 69734, '\P{Is_Nv=+0_0_0_0_0_0_0_0_0_1_000}', "");
Expect(0, 69734, '\P{^Is_Nv=+0_0_0_0_0_0_0_0_0_1_000}', "");
Error('\p{Numeric_Value=_:=0_0_1_0_0_00}');
Error('\P{Numeric_Value=_:=0_0_1_0_0_00}');
Expect(1, 67679, '\p{Numeric_Value=010000}', "");
Expect(0, 67679, '\p{^Numeric_Value=010000}', "");
Expect(0, 67679, '\P{Numeric_Value=010000}', "");
Expect(1, 67679, '\P{^Numeric_Value=010000}', "");
Expect(0, 67680, '\p{Numeric_Value=010000}', "");
Expect(1, 67680, '\p{^Numeric_Value=010000}', "");
Expect(1, 67680, '\P{Numeric_Value=010000}', "");
Expect(0, 67680, '\P{^Numeric_Value=010000}', "");
Error('\p{Nv=/a/-_+0_1_0_000}');
Error('\P{Nv=/a/-_+0_1_0_000}');
Expect(1, 67679, '\p{Nv=0000000010000}', "");
Expect(0, 67679, '\p{^Nv=0000000010000}', "");
Expect(0, 67679, '\P{Nv=0000000010000}', "");
Expect(1, 67679, '\P{^Nv=0000000010000}', "");
Expect(0, 67680, '\p{Nv=0000000010000}', "");
Expect(1, 67680, '\p{^Nv=0000000010000}', "");
Expect(1, 67680, '\P{Nv=0000000010000}', "");
Expect(0, 67680, '\P{^Nv=0000000010000}', "");
Error('\p{Is_Numeric_Value=	/a/00000010000}');
Error('\P{Is_Numeric_Value=	/a/00000010000}');
Expect(1, 67679, '\p{Is_Numeric_Value=+0_0_0_0_0_10000}', "");
Expect(0, 67679, '\p{^Is_Numeric_Value=+0_0_0_0_0_10000}', "");
Expect(0, 67679, '\P{Is_Numeric_Value=+0_0_0_0_0_10000}', "");
Expect(1, 67679, '\P{^Is_Numeric_Value=+0_0_0_0_0_10000}', "");
Expect(0, 67680, '\p{Is_Numeric_Value=+0_0_0_0_0_10000}', "");
Expect(1, 67680, '\p{^Is_Numeric_Value=+0_0_0_0_0_10000}', "");
Expect(1, 67680, '\P{Is_Numeric_Value=+0_0_0_0_0_10000}', "");
Expect(0, 67680, '\P{^Is_Numeric_Value=+0_0_0_0_0_10000}', "");
Error('\p{Is_Nv=/a/	 +000_100_00}');
Error('\P{Is_Nv=/a/	 +000_100_00}');
Expect(1, 67679, '\p{Is_Nv=+1000_0}', "");
Expect(0, 67679, '\p{^Is_Nv=+1000_0}', "");
Expect(0, 67679, '\P{Is_Nv=+1000_0}', "");
Expect(1, 67679, '\P{^Is_Nv=+1000_0}', "");
Expect(0, 67680, '\p{Is_Nv=+1000_0}', "");
Expect(1, 67680, '\p{^Is_Nv=+1000_0}', "");
Expect(1, 67680, '\P{Is_Nv=+1000_0}', "");
Expect(0, 67680, '\P{^Is_Nv=+1000_0}', "");
Error('\p{Numeric_Value=  0000000100000/a/}');
Error('\P{Numeric_Value=  0000000100000/a/}');
Expect(1, 8584, '\p{Numeric_Value=100000}', "");
Expect(0, 8584, '\p{^Numeric_Value=100000}', "");
Expect(0, 8584, '\P{Numeric_Value=100000}', "");
Expect(1, 8584, '\P{^Numeric_Value=100000}', "");
Expect(0, 8585, '\p{Numeric_Value=100000}', "");
Expect(1, 8585, '\p{^Numeric_Value=100000}', "");
Expect(1, 8585, '\P{Numeric_Value=100000}', "");
Expect(0, 8585, '\P{^Numeric_Value=100000}', "");
Error('\p{Nv:	_0100000/a/}');
Error('\P{Nv:	_0100000/a/}');
Expect(1, 8584, '\p{Nv=00000100000}', "");
Expect(0, 8584, '\p{^Nv=00000100000}', "");
Expect(0, 8584, '\P{Nv=00000100000}', "");
Expect(1, 8584, '\P{^Nv=00000100000}', "");
Expect(0, 8585, '\p{Nv=00000100000}', "");
Expect(1, 8585, '\p{^Nv=00000100000}', "");
Expect(1, 8585, '\P{Nv=00000100000}', "");
Expect(0, 8585, '\P{^Nv=00000100000}', "");
Error('\p{Is_Numeric_Value= /a/0_0_0_0_0_0_0_0_1_0_0000}');
Error('\P{Is_Numeric_Value= /a/0_0_0_0_0_0_0_0_1_0_0000}');
Expect(1, 8584, '\p{Is_Numeric_Value=+000000100000}', "");
Expect(0, 8584, '\p{^Is_Numeric_Value=+000000100000}', "");
Expect(0, 8584, '\P{Is_Numeric_Value=+000000100000}', "");
Expect(1, 8584, '\P{^Is_Numeric_Value=+000000100000}', "");
Expect(0, 8585, '\p{Is_Numeric_Value=+000000100000}', "");
Expect(1, 8585, '\p{^Is_Numeric_Value=+000000100000}', "");
Expect(1, 8585, '\P{Is_Numeric_Value=+000000100000}', "");
Expect(0, 8585, '\P{^Is_Numeric_Value=+000000100000}', "");
Error('\p{Is_Nv=--0_0_0_0_0_0_0_0100000:=}');
Error('\P{Is_Nv=--0_0_0_0_0_0_0_0100000:=}');
Expect(1, 8584, '\p{Is_Nv=1_0_0_0_00}', "");
Expect(0, 8584, '\p{^Is_Nv=1_0_0_0_00}', "");
Expect(0, 8584, '\P{Is_Nv=1_0_0_0_00}', "");
Expect(1, 8584, '\P{^Is_Nv=1_0_0_0_00}', "");
Expect(0, 8585, '\p{Is_Nv=1_0_0_0_00}', "");
Expect(1, 8585, '\p{^Is_Nv=1_0_0_0_00}', "");
Expect(1, 8585, '\P{Is_Nv=1_0_0_0_00}', "");
Expect(0, 8585, '\P{^Is_Nv=1_0_0_0_00}', "");
Error('\p{Numeric_Value=	:=+000100000000}');
Error('\P{Numeric_Value=	:=+000100000000}');
Expect(1, 20740, '\p{Numeric_Value=0_0_1_0_0_0_0_0000}', "");
Expect(0, 20740, '\p{^Numeric_Value=0_0_1_0_0_0_0_0000}', "");
Expect(0, 20740, '\P{Numeric_Value=0_0_1_0_0_0_0_0000}', "");
Expect(1, 20740, '\P{^Numeric_Value=0_0_1_0_0_0_0_0000}', "");
Expect(0, 20741, '\p{Numeric_Value=0_0_1_0_0_0_0_0000}', "");
Expect(1, 20741, '\p{^Numeric_Value=0_0_1_0_0_0_0_0000}', "");
Expect(1, 20741, '\P{Numeric_Value=0_0_1_0_0_0_0_0000}', "");
Expect(0, 20741, '\P{^Numeric_Value=0_0_1_0_0_0_0_0000}', "");
Error('\p{Nv=_	+00_00_00_00_01_00_00_00_00/a/}');
Error('\P{Nv=_	+00_00_00_00_01_00_00_00_00/a/}');
Expect(1, 20740, '\p{Nv=000100000000}', "");
Expect(0, 20740, '\p{^Nv=000100000000}', "");
Expect(0, 20740, '\P{Nv=000100000000}', "");
Expect(1, 20740, '\P{^Nv=000100000000}', "");
Expect(0, 20741, '\p{Nv=000100000000}', "");
Expect(1, 20741, '\p{^Nv=000100000000}', "");
Expect(1, 20741, '\P{Nv=000100000000}', "");
Expect(0, 20741, '\P{^Nv=000100000000}', "");
Error('\p{Is_Numeric_Value=_	10_00_00_00_0:=}');
Error('\P{Is_Numeric_Value=_	10_00_00_00_0:=}');
Expect(1, 20740, '\p{Is_Numeric_Value=+000000010000000_0}', "");
Expect(0, 20740, '\p{^Is_Numeric_Value=+000000010000000_0}', "");
Expect(0, 20740, '\P{Is_Numeric_Value=+000000010000000_0}', "");
Expect(1, 20740, '\P{^Is_Numeric_Value=+000000010000000_0}', "");
Expect(0, 20741, '\p{Is_Numeric_Value=+000000010000000_0}', "");
Expect(1, 20741, '\p{^Is_Numeric_Value=+000000010000000_0}', "");
Expect(1, 20741, '\P{Is_Numeric_Value=+000000010000000_0}', "");
Expect(0, 20741, '\P{^Is_Numeric_Value=+000000010000000_0}', "");
Error('\p{Is_Nv:   	 +0000100000000:=}');
Error('\P{Is_Nv:   	 +0000100000000:=}');
Expect(1, 20740, '\p{Is_Nv=01_00_00_00_00}', "");
Expect(0, 20740, '\p{^Is_Nv=01_00_00_00_00}', "");
Expect(0, 20740, '\P{Is_Nv=01_00_00_00_00}', "");
Expect(1, 20740, '\P{^Is_Nv=01_00_00_00_00}', "");
Expect(0, 20741, '\p{Is_Nv=01_00_00_00_00}', "");
Expect(1, 20741, '\p{^Is_Nv=01_00_00_00_00}', "");
Expect(1, 20741, '\P{Is_Nv=01_00_00_00_00}', "");
Expect(0, 20741, '\P{^Is_Nv=01_00_00_00_00}', "");
Error('\p{Numeric_Value:   :=_00000001000000000000}');
Error('\P{Numeric_Value:   :=_00000001000000000000}');
Expect(1, 20806, '\p{Numeric_Value=00000001000000000000}', "");
Expect(0, 20806, '\p{^Numeric_Value=00000001000000000000}', "");
Expect(0, 20806, '\P{Numeric_Value=00000001000000000000}', "");
Expect(1, 20806, '\P{^Numeric_Value=00000001000000000000}', "");
Expect(0, 20807, '\p{Numeric_Value=00000001000000000000}', "");
Expect(1, 20807, '\p{^Numeric_Value=00000001000000000000}', "");
Expect(1, 20807, '\P{Numeric_Value=00000001000000000000}', "");
Expect(0, 20807, '\P{^Numeric_Value=00000001000000000000}', "");
Error('\p{Nv=/a/ -+001_000_000_000_000}');
Error('\P{Nv=/a/ -+001_000_000_000_000}');
Expect(1, 20806, '\p{Nv=+00000001000000000000}', "");
Expect(0, 20806, '\p{^Nv=+00000001000000000000}', "");
Expect(0, 20806, '\P{Nv=+00000001000000000000}', "");
Expect(1, 20806, '\P{^Nv=+00000001000000000000}', "");
Expect(0, 20807, '\p{Nv=+00000001000000000000}', "");
Expect(1, 20807, '\p{^Nv=+00000001000000000000}', "");
Expect(1, 20807, '\P{Nv=+00000001000000000000}', "");
Expect(0, 20807, '\P{^Nv=+00000001000000000000}', "");
Error('\p{Is_Numeric_Value=_+000001000000000000:=}');
Error('\P{Is_Numeric_Value=_+000001000000000000:=}');
Expect(1, 20806, '\p{Is_Numeric_Value=10_00_00_00_00_00_0}', "");
Expect(0, 20806, '\p{^Is_Numeric_Value=10_00_00_00_00_00_0}', "");
Expect(0, 20806, '\P{Is_Numeric_Value=10_00_00_00_00_00_0}', "");
Expect(1, 20806, '\P{^Is_Numeric_Value=10_00_00_00_00_00_0}', "");
Expect(0, 20807, '\p{Is_Numeric_Value=10_00_00_00_00_00_0}', "");
Expect(1, 20807, '\p{^Is_Numeric_Value=10_00_00_00_00_00_0}', "");
Expect(1, 20807, '\P{Is_Numeric_Value=10_00_00_00_00_00_0}', "");
Expect(0, 20807, '\P{^Is_Numeric_Value=10_00_00_00_00_00_0}', "");
Error('\p{Is_Nv=--00_00_00_00_01_00_00_00_00_00_00:=}');
Error('\P{Is_Nv=--00_00_00_00_01_00_00_00_00_00_00:=}');
Expect(1, 20806, '\p{Is_Nv=0_0_0_0_0_0_0_0_0_1_0_0_0_000000000}', "");
Expect(0, 20806, '\p{^Is_Nv=0_0_0_0_0_0_0_0_0_1_0_0_0_000000000}', "");
Expect(0, 20806, '\P{Is_Nv=0_0_0_0_0_0_0_0_0_1_0_0_0_000000000}', "");
Expect(1, 20806, '\P{^Is_Nv=0_0_0_0_0_0_0_0_0_1_0_0_0_000000000}', "");
Expect(0, 20807, '\p{Is_Nv=0_0_0_0_0_0_0_0_0_1_0_0_0_000000000}', "");
Expect(1, 20807, '\p{^Is_Nv=0_0_0_0_0_0_0_0_0_1_0_0_0_000000000}', "");
Expect(1, 20807, '\P{Is_Nv=0_0_0_0_0_0_0_0_0_1_0_0_0_000000000}', "");
Expect(0, 20807, '\P{^Is_Nv=0_0_0_0_0_0_0_0_0_1_0_0_0_000000000}', "");
Error('\p{Numeric_Value=:= _1_1}');
Error('\P{Numeric_Value=:= _1_1}');
Expect(1, 9451, '\p{Numeric_Value=+1_1}', "");
Expect(0, 9451, '\p{^Numeric_Value=+1_1}', "");
Expect(0, 9451, '\P{Numeric_Value=+1_1}', "");
Expect(1, 9451, '\P{^Numeric_Value=+1_1}', "");
Expect(0, 9452, '\p{Numeric_Value=+1_1}', "");
Expect(1, 9452, '\p{^Numeric_Value=+1_1}', "");
Expect(1, 9452, '\P{Numeric_Value=+1_1}', "");
Expect(0, 9452, '\P{^Numeric_Value=+1_1}', "");
Error('\p{Nv=  +0001_1:=}');
Error('\P{Nv=  +0001_1:=}');
Expect(1, 9451, '\p{Nv=11}', "");
Expect(0, 9451, '\p{^Nv=11}', "");
Expect(0, 9451, '\P{Nv=11}', "");
Expect(1, 9451, '\P{^Nv=11}', "");
Expect(0, 9452, '\p{Nv=11}', "");
Expect(1, 9452, '\p{^Nv=11}', "");
Expect(1, 9452, '\P{Nv=11}', "");
Expect(0, 9452, '\P{^Nv=11}', "");
Error('\p{Is_Numeric_Value=/a/_-0000000011}');
Error('\P{Is_Numeric_Value=/a/_-0000000011}');
Expect(1, 9451, '\p{Is_Numeric_Value=11}', "");
Expect(0, 9451, '\p{^Is_Numeric_Value=11}', "");
Expect(0, 9451, '\P{Is_Numeric_Value=11}', "");
Expect(1, 9451, '\P{^Is_Numeric_Value=11}', "");
Expect(0, 9452, '\p{Is_Numeric_Value=11}', "");
Expect(1, 9452, '\p{^Is_Numeric_Value=11}', "");
Expect(1, 9452, '\P{Is_Numeric_Value=11}', "");
Expect(0, 9452, '\P{^Is_Numeric_Value=11}', "");
Error('\p{Is_Nv=	/a/00000011}');
Error('\P{Is_Nv=	/a/00000011}');
Expect(1, 9451, '\p{Is_Nv=000011}', "");
Expect(0, 9451, '\p{^Is_Nv=000011}', "");
Expect(0, 9451, '\P{Is_Nv=000011}', "");
Expect(1, 9451, '\P{^Is_Nv=000011}', "");
Expect(0, 9452, '\p{Is_Nv=000011}', "");
Expect(1, 9452, '\p{^Is_Nv=000011}', "");
Expect(1, 9452, '\P{Is_Nv=000011}', "");
Expect(0, 9452, '\P{^Is_Nv=000011}', "");
Error('\p{Numeric_Value=:=	-0000000011/000000002}');
Error('\P{Numeric_Value=:=	-0000000011/000000002}');
Expect(1, 3887, '\p{Numeric_Value=0000000011/000000002}', "");
Expect(0, 3887, '\p{^Numeric_Value=0000000011/000000002}', "");
Expect(0, 3887, '\P{Numeric_Value=0000000011/000000002}', "");
Expect(1, 3887, '\P{^Numeric_Value=0000000011/000000002}', "");
Expect(0, 3888, '\p{Numeric_Value=0000000011/000000002}', "");
Expect(1, 3888, '\p{^Numeric_Value=0000000011/000000002}', "");
Expect(1, 3888, '\P{Numeric_Value=0000000011/000000002}', "");
Expect(0, 3888, '\P{^Numeric_Value=0000000011/000000002}', "");
Expect(1, 3887, '\p{Numeric_Value=5.500}', "");
Expect(0, 3887, '\p{^Numeric_Value=5.500}', "");
Expect(0, 3887, '\P{Numeric_Value=5.500}', "");
Expect(1, 3887, '\P{^Numeric_Value=5.500}', "");
Expect(0, 3888, '\p{Numeric_Value=5.500}', "");
Expect(1, 3888, '\p{^Numeric_Value=5.500}', "");
Expect(1, 3888, '\P{Numeric_Value=5.500}', "");
Expect(0, 3888, '\P{^Numeric_Value=5.500}', "");
Error('\p{Nv=	00000000011/0002/a/}');
Error('\P{Nv=	00000000011/0002/a/}');
Expect(1, 3887, '\p{Nv=00011/002}', "");
Expect(0, 3887, '\p{^Nv=00011/002}', "");
Expect(0, 3887, '\P{Nv=00011/002}', "");
Expect(1, 3887, '\P{^Nv=00011/002}', "");
Expect(0, 3888, '\p{Nv=00011/002}', "");
Expect(1, 3888, '\p{^Nv=00011/002}', "");
Expect(1, 3888, '\P{Nv=00011/002}', "");
Expect(0, 3888, '\P{^Nv=00011/002}', "");
Expect(1, 3887, '\p{Nv=5.500}', "");
Expect(0, 3887, '\p{^Nv=5.500}', "");
Expect(0, 3887, '\P{Nv=5.500}', "");
Expect(1, 3887, '\P{^Nv=5.500}', "");
Expect(0, 3888, '\p{Nv=5.500}', "");
Expect(1, 3888, '\p{^Nv=5.500}', "");
Expect(1, 3888, '\P{Nv=5.500}', "");
Expect(0, 3888, '\P{^Nv=5.500}', "");
Error('\p{Is_Numeric_Value= 	0000000011/2/a/}');
Error('\P{Is_Numeric_Value= 	0000000011/2/a/}');
Expect(1, 3887, '\p{Is_Numeric_Value:+000011/0000000002}', "");
Expect(0, 3887, '\p{^Is_Numeric_Value:+000011/0000000002}', "");
Expect(0, 3887, '\P{Is_Numeric_Value:+000011/0000000002}', "");
Expect(1, 3887, '\P{^Is_Numeric_Value:+000011/0000000002}', "");
Expect(0, 3888, '\p{Is_Numeric_Value:+000011/0000000002}', "");
Expect(1, 3888, '\p{^Is_Numeric_Value:+000011/0000000002}', "");
Expect(1, 3888, '\P{Is_Numeric_Value:+000011/0000000002}', "");
Expect(0, 3888, '\P{^Is_Numeric_Value:+000011/0000000002}', "");
Expect(1, 3887, '\p{Is_Numeric_Value=5.500}', "");
Expect(0, 3887, '\p{^Is_Numeric_Value=5.500}', "");
Expect(0, 3887, '\P{Is_Numeric_Value=5.500}', "");
Expect(1, 3887, '\P{^Is_Numeric_Value=5.500}', "");
Expect(0, 3888, '\p{Is_Numeric_Value=5.500}', "");
Expect(1, 3888, '\p{^Is_Numeric_Value=5.500}', "");
Expect(1, 3888, '\P{Is_Numeric_Value=5.500}', "");
Expect(0, 3888, '\P{^Is_Numeric_Value=5.500}', "");
Error('\p{Is_Nv=/a/-+000000011/002}');
Error('\P{Is_Nv=/a/-+000000011/002}');
Expect(1, 3887, '\p{Is_Nv=00000011/0002}', "");
Expect(0, 3887, '\p{^Is_Nv=00000011/0002}', "");
Expect(0, 3887, '\P{Is_Nv=00000011/0002}', "");
Expect(1, 3887, '\P{^Is_Nv=00000011/0002}', "");
Expect(0, 3888, '\p{Is_Nv=00000011/0002}', "");
Expect(1, 3888, '\p{^Is_Nv=00000011/0002}', "");
Expect(1, 3888, '\P{Is_Nv=00000011/0002}', "");
Expect(0, 3888, '\P{^Is_Nv=00000011/0002}', "");
Expect(1, 3887, '\p{Is_Nv=5.500}', "");
Expect(0, 3887, '\p{^Is_Nv=5.500}', "");
Expect(0, 3887, '\P{Is_Nv=5.500}', "");
Expect(1, 3887, '\P{^Is_Nv=5.500}', "");
Expect(0, 3888, '\p{Is_Nv=5.500}', "");
Expect(1, 3888, '\p{^Is_Nv=5.500}', "");
Expect(1, 3888, '\P{Is_Nv=5.500}', "");
Expect(0, 3888, '\P{^Is_Nv=5.500}', "");
Error('\p{Numeric_Value= -+0_0_0_0_0_0_0_0012/a/}');
Error('\P{Numeric_Value= -+0_0_0_0_0_0_0_0012/a/}');
Expect(1, 9452, '\p{Numeric_Value=01_2}', "");
Expect(0, 9452, '\p{^Numeric_Value=01_2}', "");
Expect(0, 9452, '\P{Numeric_Value=01_2}', "");
Expect(1, 9452, '\P{^Numeric_Value=01_2}', "");
Expect(0, 9453, '\p{Numeric_Value=01_2}', "");
Expect(1, 9453, '\p{^Numeric_Value=01_2}', "");
Expect(1, 9453, '\P{Numeric_Value=01_2}', "");
Expect(0, 9453, '\P{^Numeric_Value=01_2}', "");
Error('\p{Nv=:= 000012}');
Error('\P{Nv=:= 000012}');
Expect(1, 9452, '\p{Nv=0000012}', "");
Expect(0, 9452, '\p{^Nv=0000012}', "");
Expect(0, 9452, '\P{Nv=0000012}', "");
Expect(1, 9452, '\P{^Nv=0000012}', "");
Expect(0, 9453, '\p{Nv=0000012}', "");
Expect(1, 9453, '\p{^Nv=0000012}', "");
Expect(1, 9453, '\P{Nv=0000012}', "");
Expect(0, 9453, '\P{^Nv=0000012}', "");
Error('\p{Is_Numeric_Value=-+1_2/a/}');
Error('\P{Is_Numeric_Value=-+1_2/a/}');
Expect(1, 9452, '\p{Is_Numeric_Value=01_2}', "");
Expect(0, 9452, '\p{^Is_Numeric_Value=01_2}', "");
Expect(0, 9452, '\P{Is_Numeric_Value=01_2}', "");
Expect(1, 9452, '\P{^Is_Numeric_Value=01_2}', "");
Expect(0, 9453, '\p{Is_Numeric_Value=01_2}', "");
Expect(1, 9453, '\p{^Is_Numeric_Value=01_2}', "");
Expect(1, 9453, '\P{Is_Numeric_Value=01_2}', "");
Expect(0, 9453, '\P{^Is_Numeric_Value=01_2}', "");
Error('\p{Is_Nv= 00012:=}');
Error('\P{Is_Nv= 00012:=}');
Expect(1, 9452, '\p{Is_Nv: +1_2}', "");
Expect(0, 9452, '\p{^Is_Nv: +1_2}', "");
Expect(0, 9452, '\P{Is_Nv: +1_2}', "");
Expect(1, 9452, '\P{^Is_Nv: +1_2}', "");
Expect(0, 9453, '\p{Is_Nv: +1_2}', "");
Expect(1, 9453, '\p{^Is_Nv: +1_2}', "");
Expect(1, 9453, '\P{Is_Nv: +1_2}', "");
Expect(0, 9453, '\P{^Is_Nv: +1_2}', "");
Error('\p{Numeric_Value=:=0_0_0_13}');
Error('\P{Numeric_Value=:=0_0_0_13}');
Expect(1, 9453, '\p{Numeric_Value=000013}', "");
Expect(0, 9453, '\p{^Numeric_Value=000013}', "");
Expect(0, 9453, '\P{Numeric_Value=000013}', "");
Expect(1, 9453, '\P{^Numeric_Value=000013}', "");
Expect(0, 9454, '\p{Numeric_Value=000013}', "");
Expect(1, 9454, '\p{^Numeric_Value=000013}', "");
Expect(1, 9454, '\P{Numeric_Value=000013}', "");
Expect(0, 9454, '\P{^Numeric_Value=000013}', "");
Error('\p{Nv=	:=+0000013}');
Error('\P{Nv=	:=+0000013}');
Expect(1, 9453, '\p{Nv=00_00_00_00_01_3}', "");
Expect(0, 9453, '\p{^Nv=00_00_00_00_01_3}', "");
Expect(0, 9453, '\P{Nv=00_00_00_00_01_3}', "");
Expect(1, 9453, '\P{^Nv=00_00_00_00_01_3}', "");
Expect(0, 9454, '\p{Nv=00_00_00_00_01_3}', "");
Expect(1, 9454, '\p{^Nv=00_00_00_00_01_3}', "");
Expect(1, 9454, '\P{Nv=00_00_00_00_01_3}', "");
Expect(0, 9454, '\P{^Nv=00_00_00_00_01_3}', "");
Error('\p{Is_Numeric_Value=		00000000013:=}');
Error('\P{Is_Numeric_Value=		00000000013:=}');
Expect(1, 9453, '\p{Is_Numeric_Value=0_0_0_0_0_0_0_0_013}', "");
Expect(0, 9453, '\p{^Is_Numeric_Value=0_0_0_0_0_0_0_0_013}', "");
Expect(0, 9453, '\P{Is_Numeric_Value=0_0_0_0_0_0_0_0_013}', "");
Expect(1, 9453, '\P{^Is_Numeric_Value=0_0_0_0_0_0_0_0_013}', "");
Expect(0, 9454, '\p{Is_Numeric_Value=0_0_0_0_0_0_0_0_013}', "");
Expect(1, 9454, '\p{^Is_Numeric_Value=0_0_0_0_0_0_0_0_013}', "");
Expect(1, 9454, '\P{Is_Numeric_Value=0_0_0_0_0_0_0_0_013}', "");
Expect(0, 9454, '\P{^Is_Numeric_Value=0_0_0_0_0_0_0_0_013}', "");
Error('\p{Is_Nv= _+013/a/}');
Error('\P{Is_Nv= _+013/a/}');
Expect(1, 9453, '\p{Is_Nv=0000000013}', "");
Expect(0, 9453, '\p{^Is_Nv=0000000013}', "");
Expect(0, 9453, '\P{Is_Nv=0000000013}', "");
Expect(1, 9453, '\P{^Is_Nv=0000000013}', "");
Expect(0, 9454, '\p{Is_Nv=0000000013}', "");
Expect(1, 9454, '\p{^Is_Nv=0000000013}', "");
Expect(1, 9454, '\P{Is_Nv=0000000013}', "");
Expect(0, 9454, '\P{^Is_Nv=0000000013}', "");
Error('\p{Numeric_Value=/a/0013/02}');
Error('\P{Numeric_Value=/a/0013/02}');
Expect(1, 3888, '\p{Numeric_Value:00013/000000002}', "");
Expect(0, 3888, '\p{^Numeric_Value:00013/000000002}', "");
Expect(0, 3888, '\P{Numeric_Value:00013/000000002}', "");
Expect(1, 3888, '\P{^Numeric_Value:00013/000000002}', "");
Expect(0, 3889, '\p{Numeric_Value:00013/000000002}', "");
Expect(1, 3889, '\p{^Numeric_Value:00013/000000002}', "");
Expect(1, 3889, '\P{Numeric_Value:00013/000000002}', "");
Expect(0, 3889, '\P{^Numeric_Value:00013/000000002}', "");
Expect(1, 3888, '\p{Numeric_Value=6.500}', "");
Expect(0, 3888, '\p{^Numeric_Value=6.500}', "");
Expect(0, 3888, '\P{Numeric_Value=6.500}', "");
Expect(1, 3888, '\P{^Numeric_Value=6.500}', "");
Expect(0, 3889, '\p{Numeric_Value=6.500}', "");
Expect(1, 3889, '\p{^Numeric_Value=6.500}', "");
Expect(1, 3889, '\P{Numeric_Value=6.500}', "");
Expect(0, 3889, '\P{^Numeric_Value=6.500}', "");
Error('\p{Nv:	/a/_013/2}');
Error('\P{Nv:	/a/_013/2}');
Expect(1, 3888, '\p{Nv=000000013/2}', "");
Expect(0, 3888, '\p{^Nv=000000013/2}', "");
Expect(0, 3888, '\P{Nv=000000013/2}', "");
Expect(1, 3888, '\P{^Nv=000000013/2}', "");
Expect(0, 3889, '\p{Nv=000000013/2}', "");
Expect(1, 3889, '\p{^Nv=000000013/2}', "");
Expect(1, 3889, '\P{Nv=000000013/2}', "");
Expect(0, 3889, '\P{^Nv=000000013/2}', "");
Expect(1, 3888, '\p{Nv=6.500}', "");
Expect(0, 3888, '\p{^Nv=6.500}', "");
Expect(0, 3888, '\P{Nv=6.500}', "");
Expect(1, 3888, '\P{^Nv=6.500}', "");
Expect(0, 3889, '\p{Nv=6.500}', "");
Expect(1, 3889, '\p{^Nv=6.500}', "");
Expect(1, 3889, '\P{Nv=6.500}', "");
Expect(0, 3889, '\P{^Nv=6.500}', "");
Error('\p{Is_Numeric_Value=:=_-0000000013/002}');
Error('\P{Is_Numeric_Value=:=_-0000000013/002}');
Expect(1, 3888, '\p{Is_Numeric_Value=13/000002}', "");
Expect(0, 3888, '\p{^Is_Numeric_Value=13/000002}', "");
Expect(0, 3888, '\P{Is_Numeric_Value=13/000002}', "");
Expect(1, 3888, '\P{^Is_Numeric_Value=13/000002}', "");
Expect(0, 3889, '\p{Is_Numeric_Value=13/000002}', "");
Expect(1, 3889, '\p{^Is_Numeric_Value=13/000002}', "");
Expect(1, 3889, '\P{Is_Numeric_Value=13/000002}', "");
Expect(0, 3889, '\P{^Is_Numeric_Value=13/000002}', "");
Expect(1, 3888, '\p{Is_Numeric_Value=6.500}', "");
Expect(0, 3888, '\p{^Is_Numeric_Value=6.500}', "");
Expect(0, 3888, '\P{Is_Numeric_Value=6.500}', "");
Expect(1, 3888, '\P{^Is_Numeric_Value=6.500}', "");
Expect(0, 3889, '\p{Is_Numeric_Value=6.500}', "");
Expect(1, 3889, '\p{^Is_Numeric_Value=6.500}', "");
Expect(1, 3889, '\P{Is_Numeric_Value=6.500}', "");
Expect(0, 3889, '\P{^Is_Numeric_Value=6.500}', "");
Error('\p{Is_Nv=/a/  +0000013/00000002}');
Error('\P{Is_Nv=/a/  +0000013/00000002}');
Expect(1, 3888, '\p{Is_Nv=00000013/002}', "");
Expect(0, 3888, '\p{^Is_Nv=00000013/002}', "");
Expect(0, 3888, '\P{Is_Nv=00000013/002}', "");
Expect(1, 3888, '\P{^Is_Nv=00000013/002}', "");
Expect(0, 3889, '\p{Is_Nv=00000013/002}', "");
Expect(1, 3889, '\p{^Is_Nv=00000013/002}', "");
Expect(1, 3889, '\P{Is_Nv=00000013/002}', "");
Expect(0, 3889, '\P{^Is_Nv=00000013/002}', "");
Expect(1, 3888, '\p{Is_Nv:6.500}', "");
Expect(0, 3888, '\p{^Is_Nv:6.500}', "");
Expect(0, 3888, '\P{Is_Nv:6.500}', "");
Expect(1, 3888, '\P{^Is_Nv:6.500}', "");
Expect(0, 3889, '\p{Is_Nv:6.500}', "");
Expect(1, 3889, '\p{^Is_Nv:6.500}', "");
Expect(1, 3889, '\P{Is_Nv:6.500}', "");
Expect(0, 3889, '\P{^Is_Nv:6.500}', "");
Error('\p{Numeric_Value=/a/-	000_000_14}');
Error('\P{Numeric_Value=/a/-	000_000_14}');
Expect(1, 9454, '\p{Numeric_Value=01_4}', "");
Expect(0, 9454, '\p{^Numeric_Value=01_4}', "");
Expect(0, 9454, '\P{Numeric_Value=01_4}', "");
Expect(1, 9454, '\P{^Numeric_Value=01_4}', "");
Expect(0, 9455, '\p{Numeric_Value=01_4}', "");
Expect(1, 9455, '\p{^Numeric_Value=01_4}', "");
Expect(1, 9455, '\P{Numeric_Value=01_4}', "");
Expect(0, 9455, '\P{^Numeric_Value=01_4}', "");
Error('\p{Nv=:=-_+0000014}');
Error('\P{Nv=:=-_+0000014}');
Expect(1, 9454, '\p{Nv=+014}', "");
Expect(0, 9454, '\p{^Nv=+014}', "");
Expect(0, 9454, '\P{Nv=+014}', "");
Expect(1, 9454, '\P{^Nv=+014}', "");
Expect(0, 9455, '\p{Nv=+014}', "");
Expect(1, 9455, '\p{^Nv=+014}', "");
Expect(1, 9455, '\P{Nv=+014}', "");
Expect(0, 9455, '\P{^Nv=+014}', "");
Error('\p{Is_Numeric_Value= _00_00_01_4:=}');
Error('\P{Is_Numeric_Value= _00_00_01_4:=}');
Expect(1, 9454, '\p{Is_Numeric_Value=+0014}', "");
Expect(0, 9454, '\p{^Is_Numeric_Value=+0014}', "");
Expect(0, 9454, '\P{Is_Numeric_Value=+0014}', "");
Expect(1, 9454, '\P{^Is_Numeric_Value=+0014}', "");
Expect(0, 9455, '\p{Is_Numeric_Value=+0014}', "");
Expect(1, 9455, '\p{^Is_Numeric_Value=+0014}', "");
Expect(1, 9455, '\P{Is_Numeric_Value=+0014}', "");
Expect(0, 9455, '\P{^Is_Numeric_Value=+0014}', "");
Error('\p{Is_Nv=:=+0_0_0_0_0_0_0014}');
Error('\P{Is_Nv=:=+0_0_0_0_0_0_0014}');
Expect(1, 9454, '\p{Is_Nv=+001_4}', "");
Expect(0, 9454, '\p{^Is_Nv=+001_4}', "");
Expect(0, 9454, '\P{Is_Nv=+001_4}', "");
Expect(1, 9454, '\P{^Is_Nv=+001_4}', "");
Expect(0, 9455, '\p{Is_Nv=+001_4}', "");
Expect(1, 9455, '\p{^Is_Nv=+001_4}', "");
Expect(1, 9455, '\P{Is_Nv=+001_4}', "");
Expect(0, 9455, '\P{^Is_Nv=+001_4}', "");
Error('\p{Numeric_Value= /a/+000015}');
Error('\P{Numeric_Value= /a/+000015}');
Expect(1, 9455, '\p{Numeric_Value=+1_5}', "");
Expect(0, 9455, '\p{^Numeric_Value=+1_5}', "");
Expect(0, 9455, '\P{Numeric_Value=+1_5}', "");
Expect(1, 9455, '\P{^Numeric_Value=+1_5}', "");
Expect(0, 9456, '\p{Numeric_Value=+1_5}', "");
Expect(1, 9456, '\p{^Numeric_Value=+1_5}', "");
Expect(1, 9456, '\P{Numeric_Value=+1_5}', "");
Expect(0, 9456, '\P{^Numeric_Value=+1_5}', "");
Error('\p{Nv=-+0015:=}');
Error('\P{Nv=-+0015:=}');
Expect(1, 9455, '\p{Nv=0_0_15}', "");
Expect(0, 9455, '\p{^Nv=0_0_15}', "");
Expect(0, 9455, '\P{Nv=0_0_15}', "");
Expect(1, 9455, '\P{^Nv=0_0_15}', "");
Expect(0, 9456, '\p{Nv=0_0_15}', "");
Expect(1, 9456, '\p{^Nv=0_0_15}', "");
Expect(1, 9456, '\P{Nv=0_0_15}', "");
Expect(0, 9456, '\P{^Nv=0_0_15}', "");
Error('\p{Is_Numeric_Value:_	+00015:=}');
Error('\P{Is_Numeric_Value:_	+00015:=}');
Expect(1, 9455, '\p{Is_Numeric_Value=000000001_5}', "");
Expect(0, 9455, '\p{^Is_Numeric_Value=000000001_5}', "");
Expect(0, 9455, '\P{Is_Numeric_Value=000000001_5}', "");
Expect(1, 9455, '\P{^Is_Numeric_Value=000000001_5}', "");
Expect(0, 9456, '\p{Is_Numeric_Value=000000001_5}', "");
Expect(1, 9456, '\p{^Is_Numeric_Value=000000001_5}', "");
Expect(1, 9456, '\P{Is_Numeric_Value=000000001_5}', "");
Expect(0, 9456, '\P{^Is_Numeric_Value=000000001_5}', "");
Error('\p{Is_Nv= /a/00000000015}');
Error('\P{Is_Nv= /a/00000000015}');
Expect(1, 9455, '\p{Is_Nv=+0_0_0_0_0_015}', "");
Expect(0, 9455, '\p{^Is_Nv=+0_0_0_0_0_015}', "");
Expect(0, 9455, '\P{Is_Nv=+0_0_0_0_0_015}', "");
Expect(1, 9455, '\P{^Is_Nv=+0_0_0_0_0_015}', "");
Expect(0, 9456, '\p{Is_Nv=+0_0_0_0_0_015}', "");
Expect(1, 9456, '\p{^Is_Nv=+0_0_0_0_0_015}', "");
Expect(1, 9456, '\P{Is_Nv=+0_0_0_0_0_015}', "");
Expect(0, 9456, '\P{^Is_Nv=+0_0_0_0_0_015}', "");
Error('\p{Numeric_Value:	 015/000000002/a/}');
Error('\P{Numeric_Value:	 015/000000002/a/}');
Expect(1, 3889, '\p{Numeric_Value=015/2}', "");
Expect(0, 3889, '\p{^Numeric_Value=015/2}', "");
Expect(0, 3889, '\P{Numeric_Value=015/2}', "");
Expect(1, 3889, '\P{^Numeric_Value=015/2}', "");
Expect(0, 3890, '\p{Numeric_Value=015/2}', "");
Expect(1, 3890, '\p{^Numeric_Value=015/2}', "");
Expect(1, 3890, '\P{Numeric_Value=015/2}', "");
Expect(0, 3890, '\P{^Numeric_Value=015/2}', "");
Expect(1, 3889, '\p{Numeric_Value=7.500}', "");
Expect(0, 3889, '\p{^Numeric_Value=7.500}', "");
Expect(0, 3889, '\P{Numeric_Value=7.500}', "");
Expect(1, 3889, '\P{^Numeric_Value=7.500}', "");
Expect(0, 3890, '\p{Numeric_Value=7.500}', "");
Expect(1, 3890, '\p{^Numeric_Value=7.500}', "");
Expect(1, 3890, '\P{Numeric_Value=7.500}', "");
Expect(0, 3890, '\P{^Numeric_Value=7.500}', "");
Error('\p{Nv=--15/0000000002/a/}');
Error('\P{Nv=--15/0000000002/a/}');
Expect(1, 3889, '\p{Nv=15/0000002}', "");
Expect(0, 3889, '\p{^Nv=15/0000002}', "");
Expect(0, 3889, '\P{Nv=15/0000002}', "");
Expect(1, 3889, '\P{^Nv=15/0000002}', "");
Expect(0, 3890, '\p{Nv=15/0000002}', "");
Expect(1, 3890, '\p{^Nv=15/0000002}', "");
Expect(1, 3890, '\P{Nv=15/0000002}', "");
Expect(0, 3890, '\P{^Nv=15/0000002}', "");
Expect(1, 3889, '\p{Nv=7.500}', "");
Expect(0, 3889, '\p{^Nv=7.500}', "");
Expect(0, 3889, '\P{Nv=7.500}', "");
Expect(1, 3889, '\P{^Nv=7.500}', "");
Expect(0, 3890, '\p{Nv=7.500}', "");
Expect(1, 3890, '\p{^Nv=7.500}', "");
Expect(1, 3890, '\P{Nv=7.500}', "");
Expect(0, 3890, '\P{^Nv=7.500}', "");
Error('\p{Is_Numeric_Value=:=__00000000015/002}');
Error('\P{Is_Numeric_Value=:=__00000000015/002}');
Expect(1, 3889, '\p{Is_Numeric_Value=0000015/002}', "");
Expect(0, 3889, '\p{^Is_Numeric_Value=0000015/002}', "");
Expect(0, 3889, '\P{Is_Numeric_Value=0000015/002}', "");
Expect(1, 3889, '\P{^Is_Numeric_Value=0000015/002}', "");
Expect(0, 3890, '\p{Is_Numeric_Value=0000015/002}', "");
Expect(1, 3890, '\p{^Is_Numeric_Value=0000015/002}', "");
Expect(1, 3890, '\P{Is_Numeric_Value=0000015/002}', "");
Expect(0, 3890, '\P{^Is_Numeric_Value=0000015/002}', "");
Expect(1, 3889, '\p{Is_Numeric_Value=7.500}', "");
Expect(0, 3889, '\p{^Is_Numeric_Value=7.500}', "");
Expect(0, 3889, '\P{Is_Numeric_Value=7.500}', "");
Expect(1, 3889, '\P{^Is_Numeric_Value=7.500}', "");
Expect(0, 3890, '\p{Is_Numeric_Value=7.500}', "");
Expect(1, 3890, '\p{^Is_Numeric_Value=7.500}', "");
Expect(1, 3890, '\P{Is_Numeric_Value=7.500}', "");
Expect(0, 3890, '\P{^Is_Numeric_Value=7.500}', "");
Error('\p{Is_Nv=:= _+00015/0000002}');
Error('\P{Is_Nv=:= _+00015/0000002}');
Expect(1, 3889, '\p{Is_Nv=00000015/0000002}', "");
Expect(0, 3889, '\p{^Is_Nv=00000015/0000002}', "");
Expect(0, 3889, '\P{Is_Nv=00000015/0000002}', "");
Expect(1, 3889, '\P{^Is_Nv=00000015/0000002}', "");
Expect(0, 3890, '\p{Is_Nv=00000015/0000002}', "");
Expect(1, 3890, '\p{^Is_Nv=00000015/0000002}', "");
Expect(1, 3890, '\P{Is_Nv=00000015/0000002}', "");
Expect(0, 3890, '\P{^Is_Nv=00000015/0000002}', "");
Expect(1, 3889, '\p{Is_Nv=7.500}', "");
Expect(0, 3889, '\p{^Is_Nv=7.500}', "");
Expect(0, 3889, '\P{Is_Nv=7.500}', "");
Expect(1, 3889, '\P{^Is_Nv=7.500}', "");
Expect(0, 3890, '\p{Is_Nv=7.500}', "");
Expect(1, 3890, '\p{^Is_Nv=7.500}', "");
Expect(1, 3890, '\P{Is_Nv=7.500}', "");
Expect(0, 3890, '\P{^Is_Nv=7.500}', "");
Error('\p{Numeric_Value=_:=+0_0_0_0_0_16}');
Error('\P{Numeric_Value=_:=+0_0_0_0_0_16}');
Expect(1, 9456, '\p{Numeric_Value=0016}', "");
Expect(0, 9456, '\p{^Numeric_Value=0016}', "");
Expect(0, 9456, '\P{Numeric_Value=0016}', "");
Expect(1, 9456, '\P{^Numeric_Value=0016}', "");
Expect(0, 9457, '\p{Numeric_Value=0016}', "");
Expect(1, 9457, '\p{^Numeric_Value=0016}', "");
Expect(1, 9457, '\P{Numeric_Value=0016}', "");
Expect(0, 9457, '\P{^Numeric_Value=0016}', "");
Error('\p{Nv=/a/_ +00000016}');
Error('\P{Nv=/a/_ +00000016}');
Expect(1, 9456, '\p{Nv=016}', "");
Expect(0, 9456, '\p{^Nv=016}', "");
Expect(0, 9456, '\P{Nv=016}', "");
Expect(1, 9456, '\P{^Nv=016}', "");
Expect(0, 9457, '\p{Nv=016}', "");
Expect(1, 9457, '\p{^Nv=016}', "");
Expect(1, 9457, '\P{Nv=016}', "");
Expect(0, 9457, '\P{^Nv=016}', "");
Error('\p{Is_Numeric_Value: /a/ 000000016}');
Error('\P{Is_Numeric_Value: /a/ 000000016}');
Expect(1, 9456, '\p{Is_Numeric_Value=00000_00001_6}', "");
Expect(0, 9456, '\p{^Is_Numeric_Value=00000_00001_6}', "");
Expect(0, 9456, '\P{Is_Numeric_Value=00000_00001_6}', "");
Expect(1, 9456, '\P{^Is_Numeric_Value=00000_00001_6}', "");
Expect(0, 9457, '\p{Is_Numeric_Value=00000_00001_6}', "");
Expect(1, 9457, '\p{^Is_Numeric_Value=00000_00001_6}', "");
Expect(1, 9457, '\P{Is_Numeric_Value=00000_00001_6}', "");
Expect(0, 9457, '\P{^Is_Numeric_Value=00000_00001_6}', "");
Error('\p{Is_Nv= 0_0_0_0_0_0_16/a/}');
Error('\P{Is_Nv= 0_0_0_0_0_0_16/a/}');
Expect(1, 9456, '\p{Is_Nv=0_0_16}', "");
Expect(0, 9456, '\p{^Is_Nv=0_0_16}', "");
Expect(0, 9456, '\P{Is_Nv=0_0_16}', "");
Expect(1, 9456, '\P{^Is_Nv=0_0_16}', "");
Expect(0, 9457, '\p{Is_Nv=0_0_16}', "");
Expect(1, 9457, '\p{^Is_Nv=0_0_16}', "");
Expect(1, 9457, '\P{Is_Nv=0_0_16}', "");
Expect(0, 9457, '\P{^Is_Nv=0_0_16}', "");
Error('\p{Numeric_Value= :=0017}');
Error('\P{Numeric_Value= :=0017}');
Expect(1, 9457, '\p{Numeric_Value=00000017}', "");
Expect(0, 9457, '\p{^Numeric_Value=00000017}', "");
Expect(0, 9457, '\P{Numeric_Value=00000017}', "");
Expect(1, 9457, '\P{^Numeric_Value=00000017}', "");
Expect(0, 9458, '\p{Numeric_Value=00000017}', "");
Expect(1, 9458, '\p{^Numeric_Value=00000017}', "");
Expect(1, 9458, '\P{Numeric_Value=00000017}', "");
Expect(0, 9458, '\P{^Numeric_Value=00000017}', "");
Error('\p{Nv=	-000017:=}');
Error('\P{Nv=	-000017:=}');
Expect(1, 9457, '\p{Nv=00_00_00_01_7}', "");
Expect(0, 9457, '\p{^Nv=00_00_00_01_7}', "");
Expect(0, 9457, '\P{Nv=00_00_00_01_7}', "");
Expect(1, 9457, '\P{^Nv=00_00_00_01_7}', "");
Expect(0, 9458, '\p{Nv=00_00_00_01_7}', "");
Expect(1, 9458, '\p{^Nv=00_00_00_01_7}', "");
Expect(1, 9458, '\P{Nv=00_00_00_01_7}', "");
Expect(0, 9458, '\P{^Nv=00_00_00_01_7}', "");
Error('\p{Is_Numeric_Value= /a/0_0_0_0_0_0_0_017}');
Error('\P{Is_Numeric_Value= /a/0_0_0_0_0_0_0_017}');
Expect(1, 9457, '\p{Is_Numeric_Value:	0_0_0_17}', "");
Expect(0, 9457, '\p{^Is_Numeric_Value:	0_0_0_17}', "");
Expect(0, 9457, '\P{Is_Numeric_Value:	0_0_0_17}', "");
Expect(1, 9457, '\P{^Is_Numeric_Value:	0_0_0_17}', "");
Expect(0, 9458, '\p{Is_Numeric_Value:	0_0_0_17}', "");
Expect(1, 9458, '\p{^Is_Numeric_Value:	0_0_0_17}', "");
Expect(1, 9458, '\P{Is_Numeric_Value:	0_0_0_17}', "");
Expect(0, 9458, '\P{^Is_Numeric_Value:	0_0_0_17}', "");
Error('\p{Is_Nv=/a/ -0017}');
Error('\P{Is_Nv=/a/ -0017}');
Expect(1, 9457, '\p{Is_Nv=000_000_001_7}', "");
Expect(0, 9457, '\p{^Is_Nv=000_000_001_7}', "");
Expect(0, 9457, '\P{Is_Nv=000_000_001_7}', "");
Expect(1, 9457, '\P{^Is_Nv=000_000_001_7}', "");
Expect(0, 9458, '\p{Is_Nv=000_000_001_7}', "");
Expect(1, 9458, '\p{^Is_Nv=000_000_001_7}', "");
Expect(1, 9458, '\P{Is_Nv=000_000_001_7}', "");
Expect(0, 9458, '\P{^Is_Nv=000_000_001_7}', "");
Error('\p{Numeric_Value=_-17/00000002:=}');
Error('\P{Numeric_Value=_-17/00000002:=}');
Expect(1, 3890, '\p{Numeric_Value=017/0002}', "");
Expect(0, 3890, '\p{^Numeric_Value=017/0002}', "");
Expect(0, 3890, '\P{Numeric_Value=017/0002}', "");
Expect(1, 3890, '\P{^Numeric_Value=017/0002}', "");
Expect(0, 3891, '\p{Numeric_Value=017/0002}', "");
Expect(1, 3891, '\p{^Numeric_Value=017/0002}', "");
Expect(1, 3891, '\P{Numeric_Value=017/0002}', "");
Expect(0, 3891, '\P{^Numeric_Value=017/0002}', "");
Expect(1, 3890, '\p{Numeric_Value=8.500}', "");
Expect(0, 3890, '\p{^Numeric_Value=8.500}', "");
Expect(0, 3890, '\P{Numeric_Value=8.500}', "");
Expect(1, 3890, '\P{^Numeric_Value=8.500}', "");
Expect(0, 3891, '\p{Numeric_Value=8.500}', "");
Expect(1, 3891, '\p{^Numeric_Value=8.500}', "");
Expect(1, 3891, '\P{Numeric_Value=8.500}', "");
Expect(0, 3891, '\P{^Numeric_Value=8.500}', "");
Error('\p{Nv=/a/	 00000017/00002}');
Error('\P{Nv=/a/	 00000017/00002}');
Expect(1, 3890, '\p{Nv:	+017/0000000002}', "");
Expect(0, 3890, '\p{^Nv:	+017/0000000002}', "");
Expect(0, 3890, '\P{Nv:	+017/0000000002}', "");
Expect(1, 3890, '\P{^Nv:	+017/0000000002}', "");
Expect(0, 3891, '\p{Nv:	+017/0000000002}', "");
Expect(1, 3891, '\p{^Nv:	+017/0000000002}', "");
Expect(1, 3891, '\P{Nv:	+017/0000000002}', "");
Expect(0, 3891, '\P{^Nv:	+017/0000000002}', "");
Expect(1, 3890, '\p{Nv: 8.500}', "");
Expect(0, 3890, '\p{^Nv: 8.500}', "");
Expect(0, 3890, '\P{Nv: 8.500}', "");
Expect(1, 3890, '\P{^Nv: 8.500}', "");
Expect(0, 3891, '\p{Nv: 8.500}', "");
Expect(1, 3891, '\p{^Nv: 8.500}', "");
Expect(1, 3891, '\P{Nv: 8.500}', "");
Expect(0, 3891, '\P{^Nv: 8.500}', "");
Error('\p{Is_Numeric_Value: /a/	17/00000002}');
Error('\P{Is_Numeric_Value: /a/	17/00000002}');
Expect(1, 3890, '\p{Is_Numeric_Value=0000000017/000000002}', "");
Expect(0, 3890, '\p{^Is_Numeric_Value=0000000017/000000002}', "");
Expect(0, 3890, '\P{Is_Numeric_Value=0000000017/000000002}', "");
Expect(1, 3890, '\P{^Is_Numeric_Value=0000000017/000000002}', "");
Expect(0, 3891, '\p{Is_Numeric_Value=0000000017/000000002}', "");
Expect(1, 3891, '\p{^Is_Numeric_Value=0000000017/000000002}', "");
Expect(1, 3891, '\P{Is_Numeric_Value=0000000017/000000002}', "");
Expect(0, 3891, '\P{^Is_Numeric_Value=0000000017/000000002}', "");
Expect(1, 3890, '\p{Is_Numeric_Value=8.500}', "");
Expect(0, 3890, '\p{^Is_Numeric_Value=8.500}', "");
Expect(0, 3890, '\P{Is_Numeric_Value=8.500}', "");
Expect(1, 3890, '\P{^Is_Numeric_Value=8.500}', "");
Expect(0, 3891, '\p{Is_Numeric_Value=8.500}', "");
Expect(1, 3891, '\p{^Is_Numeric_Value=8.500}', "");
Expect(1, 3891, '\P{Is_Numeric_Value=8.500}', "");
Expect(0, 3891, '\P{^Is_Numeric_Value=8.500}', "");
Error('\p{Is_Nv=		000017/002/a/}');
Error('\P{Is_Nv=		000017/002/a/}');
Expect(1, 3890, '\p{Is_Nv=17/0000000002}', "");
Expect(0, 3890, '\p{^Is_Nv=17/0000000002}', "");
Expect(0, 3890, '\P{Is_Nv=17/0000000002}', "");
Expect(1, 3890, '\P{^Is_Nv=17/0000000002}', "");
Expect(0, 3891, '\p{Is_Nv=17/0000000002}', "");
Expect(1, 3891, '\p{^Is_Nv=17/0000000002}', "");
Expect(1, 3891, '\P{Is_Nv=17/0000000002}', "");
Expect(0, 3891, '\P{^Is_Nv=17/0000000002}', "");
Expect(1, 3890, '\p{Is_Nv=8.500}', "");
Expect(0, 3890, '\p{^Is_Nv=8.500}', "");
Expect(0, 3890, '\P{Is_Nv=8.500}', "");
Expect(1, 3890, '\P{^Is_Nv=8.500}', "");
Expect(0, 3891, '\p{Is_Nv=8.500}', "");
Expect(1, 3891, '\p{^Is_Nv=8.500}', "");
Expect(1, 3891, '\P{Is_Nv=8.500}', "");
Expect(0, 3891, '\P{^Is_Nv=8.500}', "");
Error('\p{Numeric_Value=/a/01_8}');
Error('\P{Numeric_Value=/a/01_8}');
Expect(1, 9458, '\p{Numeric_Value=01_8}', "");
Expect(0, 9458, '\p{^Numeric_Value=01_8}', "");
Expect(0, 9458, '\P{Numeric_Value=01_8}', "");
Expect(1, 9458, '\P{^Numeric_Value=01_8}', "");
Expect(0, 9459, '\p{Numeric_Value=01_8}', "");
Expect(1, 9459, '\p{^Numeric_Value=01_8}', "");
Expect(1, 9459, '\P{Numeric_Value=01_8}', "");
Expect(0, 9459, '\P{^Numeric_Value=01_8}', "");
Error('\p{Nv:   	-000000018/a/}');
Error('\P{Nv:   	-000000018/a/}');
Expect(1, 9458, '\p{Nv=+0_0_0_0_0_0_018}', "");
Expect(0, 9458, '\p{^Nv=+0_0_0_0_0_0_018}', "");
Expect(0, 9458, '\P{Nv=+0_0_0_0_0_0_018}', "");
Expect(1, 9458, '\P{^Nv=+0_0_0_0_0_0_018}', "");
Expect(0, 9459, '\p{Nv=+0_0_0_0_0_0_018}', "");
Expect(1, 9459, '\p{^Nv=+0_0_0_0_0_0_018}', "");
Expect(1, 9459, '\P{Nv=+0_0_0_0_0_0_018}', "");
Expect(0, 9459, '\P{^Nv=+0_0_0_0_0_0_018}', "");
Error('\p{Is_Numeric_Value=_/a/+0_0_0_0_0018}');
Error('\P{Is_Numeric_Value=_/a/+0_0_0_0_0018}');
Expect(1, 9458, '\p{Is_Numeric_Value=018}', "");
Expect(0, 9458, '\p{^Is_Numeric_Value=018}', "");
Expect(0, 9458, '\P{Is_Numeric_Value=018}', "");
Expect(1, 9458, '\P{^Is_Numeric_Value=018}', "");
Expect(0, 9459, '\p{Is_Numeric_Value=018}', "");
Expect(1, 9459, '\p{^Is_Numeric_Value=018}', "");
Expect(1, 9459, '\P{Is_Numeric_Value=018}', "");
Expect(0, 9459, '\P{^Is_Numeric_Value=018}', "");
Error('\p{Is_Nv=	+018/a/}');
Error('\P{Is_Nv=	+018/a/}');
Expect(1, 9458, '\p{Is_Nv=0000_0001_8}', "");
Expect(0, 9458, '\p{^Is_Nv=0000_0001_8}', "");
Expect(0, 9458, '\P{Is_Nv=0000_0001_8}', "");
Expect(1, 9458, '\P{^Is_Nv=0000_0001_8}', "");
Expect(0, 9459, '\p{Is_Nv=0000_0001_8}', "");
Expect(1, 9459, '\p{^Is_Nv=0000_0001_8}', "");
Expect(1, 9459, '\P{Is_Nv=0000_0001_8}', "");
Expect(0, 9459, '\P{^Is_Nv=0000_0001_8}', "");
Error('\p{Numeric_Value=  0_0_0_0_0_0019:=}');
Error('\P{Numeric_Value=  0_0_0_0_0_0019:=}');
Expect(1, 9459, '\p{Numeric_Value=+000000019}', "");
Expect(0, 9459, '\p{^Numeric_Value=+000000019}', "");
Expect(0, 9459, '\P{Numeric_Value=+000000019}', "");
Expect(1, 9459, '\P{^Numeric_Value=+000000019}', "");
Expect(0, 9460, '\p{Numeric_Value=+000000019}', "");
Expect(1, 9460, '\p{^Numeric_Value=+000000019}', "");
Expect(1, 9460, '\P{Numeric_Value=+000000019}', "");
Expect(0, 9460, '\P{^Numeric_Value=+000000019}', "");
Error('\p{Nv=/a/	_+0_0_19}');
Error('\P{Nv=/a/	_+0_0_19}');
Expect(1, 9459, '\p{Nv=+0_0_0_0_0_0019}', "");
Expect(0, 9459, '\p{^Nv=+0_0_0_0_0_0019}', "");
Expect(0, 9459, '\P{Nv=+0_0_0_0_0_0019}', "");
Expect(1, 9459, '\P{^Nv=+0_0_0_0_0_0019}', "");
Expect(0, 9460, '\p{Nv=+0_0_0_0_0_0019}', "");
Expect(1, 9460, '\p{^Nv=+0_0_0_0_0_0019}', "");
Expect(1, 9460, '\P{Nv=+0_0_0_0_0_0019}', "");
Expect(0, 9460, '\P{^Nv=+0_0_0_0_0_0019}', "");
Error('\p{Is_Numeric_Value=:=_ 000019}');
Error('\P{Is_Numeric_Value=:=_ 000019}');
Expect(1, 9459, '\p{Is_Numeric_Value=+000_001_9}', "");
Expect(0, 9459, '\p{^Is_Numeric_Value=+000_001_9}', "");
Expect(0, 9459, '\P{Is_Numeric_Value=+000_001_9}', "");
Expect(1, 9459, '\P{^Is_Numeric_Value=+000_001_9}', "");
Expect(0, 9460, '\p{Is_Numeric_Value=+000_001_9}', "");
Expect(1, 9460, '\p{^Is_Numeric_Value=+000_001_9}', "");
Expect(1, 9460, '\P{Is_Numeric_Value=+000_001_9}', "");
Expect(0, 9460, '\P{^Is_Numeric_Value=+000_001_9}', "");
Error('\p{Is_Nv=/a/+0_0_0_0_0_0_00019}');
Error('\P{Is_Nv=/a/+0_0_0_0_0_0_00019}');
Expect(1, 9459, '\p{Is_Nv:+0_0_0_19}', "");
Expect(0, 9459, '\p{^Is_Nv:+0_0_0_19}', "");
Expect(0, 9459, '\P{Is_Nv:+0_0_0_19}', "");
Expect(1, 9459, '\P{^Is_Nv:+0_0_0_19}', "");
Expect(0, 9460, '\p{Is_Nv:+0_0_0_19}', "");
Expect(1, 9460, '\p{^Is_Nv:+0_0_0_19}', "");
Expect(1, 9460, '\P{Is_Nv:+0_0_0_19}', "");
Expect(0, 9460, '\P{^Is_Nv:+0_0_0_19}', "");
Error('\p{Numeric_Value=--+0002/a/}');
Error('\P{Numeric_Value=--+0002/a/}');
Expect(1, 140176, '\p{Numeric_Value=02}', "");
Expect(0, 140176, '\p{^Numeric_Value=02}', "");
Expect(0, 140176, '\P{Numeric_Value=02}', "");
Expect(1, 140176, '\P{^Numeric_Value=02}', "");
Expect(0, 140177, '\p{Numeric_Value=02}', "");
Expect(1, 140177, '\p{^Numeric_Value=02}', "");
Expect(1, 140177, '\P{Numeric_Value=02}', "");
Expect(0, 140177, '\P{^Numeric_Value=02}', "");
Error('\p{Nv=/a/	-000002}');
Error('\P{Nv=/a/	-000002}');
Expect(1, 140176, '\p{Nv=0000000002}', "");
Expect(0, 140176, '\p{^Nv=0000000002}', "");
Expect(0, 140176, '\P{Nv=0000000002}', "");
Expect(1, 140176, '\P{^Nv=0000000002}', "");
Expect(0, 140177, '\p{Nv=0000000002}', "");
Expect(1, 140177, '\p{^Nv=0000000002}', "");
Expect(1, 140177, '\P{Nv=0000000002}', "");
Expect(0, 140177, '\P{^Nv=0000000002}', "");
Error('\p{Is_Numeric_Value:   	_0000_2/a/}');
Error('\P{Is_Numeric_Value:   	_0000_2/a/}');
Expect(1, 140176, '\p{Is_Numeric_Value=0_2}', "");
Expect(0, 140176, '\p{^Is_Numeric_Value=0_2}', "");
Expect(0, 140176, '\P{Is_Numeric_Value=0_2}', "");
Expect(1, 140176, '\P{^Is_Numeric_Value=0_2}', "");
Expect(0, 140177, '\p{Is_Numeric_Value=0_2}', "");
Expect(1, 140177, '\p{^Is_Numeric_Value=0_2}', "");
Expect(1, 140177, '\P{Is_Numeric_Value=0_2}', "");
Expect(0, 140177, '\P{^Is_Numeric_Value=0_2}', "");
Error('\p{Is_Nv:   -/a/+0_0_0_0_0_0_0_0_02}');
Error('\P{Is_Nv:   -/a/+0_0_0_0_0_0_0_0_02}');
Expect(1, 140176, '\p{Is_Nv=+000000002}', "");
Expect(0, 140176, '\p{^Is_Nv=+000000002}', "");
Expect(0, 140176, '\P{Is_Nv=+000000002}', "");
Expect(1, 140176, '\P{^Is_Nv=+000000002}', "");
Expect(0, 140177, '\p{Is_Nv=+000000002}', "");
Expect(1, 140177, '\p{^Is_Nv=+000000002}', "");
Expect(1, 140177, '\P{Is_Nv=+000000002}', "");
Expect(0, 140177, '\P{^Is_Nv=+000000002}', "");
Error('\p{Numeric_Value=/a/ 000000002/003}');
Error('\P{Numeric_Value=/a/ 000000002/003}');
Expect(1, 74846, '\p{Numeric_Value=0000002/3}', "");
Expect(0, 74846, '\p{^Numeric_Value=0000002/3}', "");
Expect(0, 74846, '\P{Numeric_Value=0000002/3}', "");
Expect(1, 74846, '\P{^Numeric_Value=0000002/3}', "");
Expect(0, 74847, '\p{Numeric_Value=0000002/3}', "");
Expect(1, 74847, '\p{^Numeric_Value=0000002/3}', "");
Expect(1, 74847, '\P{Numeric_Value=0000002/3}', "");
Expect(0, 74847, '\P{^Numeric_Value=0000002/3}', "");
Error('\p{Numeric_Value:0.7}');
Error('\P{Numeric_Value:0.7}');
Error('\p{Numeric_Value=0.67}');
Error('\P{Numeric_Value=0.67}');
Expect(1, 74846, '\p{Numeric_Value=0.667}', "");
Expect(0, 74846, '\p{^Numeric_Value=0.667}', "");
Expect(0, 74846, '\P{Numeric_Value=0.667}', "");
Expect(1, 74846, '\P{^Numeric_Value=0.667}', "");
Expect(0, 74847, '\p{Numeric_Value=0.667}', "");
Expect(1, 74847, '\p{^Numeric_Value=0.667}', "");
Expect(1, 74847, '\P{Numeric_Value=0.667}', "");
Expect(0, 74847, '\P{^Numeric_Value=0.667}', "");
Error('\p{Nv=	 02/0003/a/}');
Error('\P{Nv=	 02/0003/a/}');
Expect(1, 74846, '\p{Nv=02/3}', "");
Expect(0, 74846, '\p{^Nv=02/3}', "");
Expect(0, 74846, '\P{Nv=02/3}', "");
Expect(1, 74846, '\P{^Nv=02/3}', "");
Expect(0, 74847, '\p{Nv=02/3}', "");
Expect(1, 74847, '\p{^Nv=02/3}', "");
Expect(1, 74847, '\P{Nv=02/3}', "");
Expect(0, 74847, '\P{^Nv=02/3}', "");
Error('\p{Nv=0.7}');
Error('\P{Nv=0.7}');
Error('\p{Nv=0.67}');
Error('\P{Nv=0.67}');
Expect(1, 74846, '\p{Nv=0.667}', "");
Expect(0, 74846, '\p{^Nv=0.667}', "");
Expect(0, 74846, '\P{Nv=0.667}', "");
Expect(1, 74846, '\P{^Nv=0.667}', "");
Expect(0, 74847, '\p{Nv=0.667}', "");
Expect(1, 74847, '\p{^Nv=0.667}', "");
Expect(1, 74847, '\P{Nv=0.667}', "");
Expect(0, 74847, '\P{^Nv=0.667}', "");
Error('\p{Is_Numeric_Value=_-+000002/03:=}');
Error('\P{Is_Numeric_Value=_-+000002/03:=}');
Expect(1, 74846, '\p{Is_Numeric_Value=+000000002/000000003}', "");
Expect(0, 74846, '\p{^Is_Numeric_Value=+000000002/000000003}', "");
Expect(0, 74846, '\P{Is_Numeric_Value=+000000002/000000003}', "");
Expect(1, 74846, '\P{^Is_Numeric_Value=+000000002/000000003}', "");
Expect(0, 74847, '\p{Is_Numeric_Value=+000000002/000000003}', "");
Expect(1, 74847, '\p{^Is_Numeric_Value=+000000002/000000003}', "");
Expect(1, 74847, '\P{Is_Numeric_Value=+000000002/000000003}', "");
Expect(0, 74847, '\P{^Is_Numeric_Value=+000000002/000000003}', "");
Error('\p{Is_Numeric_Value:	0.7}');
Error('\P{Is_Numeric_Value:	0.7}');
Error('\p{Is_Numeric_Value=0.67}');
Error('\P{Is_Numeric_Value=0.67}');
Expect(1, 74846, '\p{Is_Numeric_Value: 0.667}', "");
Expect(0, 74846, '\p{^Is_Numeric_Value: 0.667}', "");
Expect(0, 74846, '\P{Is_Numeric_Value: 0.667}', "");
Expect(1, 74846, '\P{^Is_Numeric_Value: 0.667}', "");
Expect(0, 74847, '\p{Is_Numeric_Value: 0.667}', "");
Expect(1, 74847, '\p{^Is_Numeric_Value: 0.667}', "");
Expect(1, 74847, '\P{Is_Numeric_Value: 0.667}', "");
Expect(0, 74847, '\P{^Is_Numeric_Value: 0.667}', "");
Error('\p{Is_Nv=:=- +002/000000003}');
Error('\P{Is_Nv=:=- +002/000000003}');
Expect(1, 74846, '\p{Is_Nv=02/0003}', "");
Expect(0, 74846, '\p{^Is_Nv=02/0003}', "");
Expect(0, 74846, '\P{Is_Nv=02/0003}', "");
Expect(1, 74846, '\P{^Is_Nv=02/0003}', "");
Expect(0, 74847, '\p{Is_Nv=02/0003}', "");
Expect(1, 74847, '\p{^Is_Nv=02/0003}', "");
Expect(1, 74847, '\P{Is_Nv=02/0003}', "");
Expect(0, 74847, '\P{^Is_Nv=02/0003}', "");
Error('\p{Is_Nv=0.7}');
Error('\P{Is_Nv=0.7}');
Error('\p{Is_Nv=0.67}');
Error('\P{Is_Nv=0.67}');
Expect(1, 74846, '\p{Is_Nv=0.667}', "");
Expect(0, 74846, '\p{^Is_Nv=0.667}', "");
Expect(0, 74846, '\P{Is_Nv=0.667}', "");
Expect(1, 74846, '\P{^Is_Nv=0.667}', "");
Expect(0, 74847, '\p{Is_Nv=0.667}', "");
Expect(1, 74847, '\p{^Is_Nv=0.667}', "");
Expect(1, 74847, '\P{Is_Nv=0.667}', "");
Expect(0, 74847, '\P{^Is_Nv=0.667}', "");
Error('\p{Numeric_Value=/a/	00002/0005}');
Error('\P{Numeric_Value=/a/	00002/0005}');
Expect(1, 8534, '\p{Numeric_Value=00000002/0000005}', "");
Expect(0, 8534, '\p{^Numeric_Value=00000002/0000005}', "");
Expect(0, 8534, '\P{Numeric_Value=00000002/0000005}', "");
Expect(1, 8534, '\P{^Numeric_Value=00000002/0000005}', "");
Expect(0, 8535, '\p{Numeric_Value=00000002/0000005}', "");
Expect(1, 8535, '\p{^Numeric_Value=00000002/0000005}', "");
Expect(1, 8535, '\P{Numeric_Value=00000002/0000005}', "");
Expect(0, 8535, '\P{^Numeric_Value=00000002/0000005}', "");
Expect(1, 8534, '\p{Numeric_Value=0.400}', "");
Expect(0, 8534, '\p{^Numeric_Value=0.400}', "");
Expect(0, 8534, '\P{Numeric_Value=0.400}', "");
Expect(1, 8534, '\P{^Numeric_Value=0.400}', "");
Expect(0, 8535, '\p{Numeric_Value=0.400}', "");
Expect(1, 8535, '\p{^Numeric_Value=0.400}', "");
Expect(1, 8535, '\P{Numeric_Value=0.400}', "");
Expect(0, 8535, '\P{^Numeric_Value=0.400}', "");
Error('\p{Nv=_	2/0000005/a/}');
Error('\P{Nv=_	2/0000005/a/}');
Expect(1, 8534, '\p{Nv=+000002/5}', "");
Expect(0, 8534, '\p{^Nv=+000002/5}', "");
Expect(0, 8534, '\P{Nv=+000002/5}', "");
Expect(1, 8534, '\P{^Nv=+000002/5}', "");
Expect(0, 8535, '\p{Nv=+000002/5}', "");
Expect(1, 8535, '\p{^Nv=+000002/5}', "");
Expect(1, 8535, '\P{Nv=+000002/5}', "");
Expect(0, 8535, '\P{^Nv=+000002/5}', "");
Expect(1, 8534, '\p{Nv:   0.400}', "");
Expect(0, 8534, '\p{^Nv:   0.400}', "");
Expect(0, 8534, '\P{Nv:   0.400}', "");
Expect(1, 8534, '\P{^Nv:   0.400}', "");
Expect(0, 8535, '\p{Nv:   0.400}', "");
Expect(1, 8535, '\p{^Nv:   0.400}', "");
Expect(1, 8535, '\P{Nv:   0.400}', "");
Expect(0, 8535, '\P{^Nv:   0.400}', "");
Error('\p{Is_Numeric_Value=_	02/000005:=}');
Error('\P{Is_Numeric_Value=_	02/000005:=}');
Expect(1, 8534, '\p{Is_Numeric_Value=000002/05}', "");
Expect(0, 8534, '\p{^Is_Numeric_Value=000002/05}', "");
Expect(0, 8534, '\P{Is_Numeric_Value=000002/05}', "");
Expect(1, 8534, '\P{^Is_Numeric_Value=000002/05}', "");
Expect(0, 8535, '\p{Is_Numeric_Value=000002/05}', "");
Expect(1, 8535, '\p{^Is_Numeric_Value=000002/05}', "");
Expect(1, 8535, '\P{Is_Numeric_Value=000002/05}', "");
Expect(0, 8535, '\P{^Is_Numeric_Value=000002/05}', "");
Expect(1, 8534, '\p{Is_Numeric_Value=0.400}', "");
Expect(0, 8534, '\p{^Is_Numeric_Value=0.400}', "");
Expect(0, 8534, '\P{Is_Numeric_Value=0.400}', "");
Expect(1, 8534, '\P{^Is_Numeric_Value=0.400}', "");
Expect(0, 8535, '\p{Is_Numeric_Value=0.400}', "");
Expect(1, 8535, '\p{^Is_Numeric_Value=0.400}', "");
Expect(1, 8535, '\P{Is_Numeric_Value=0.400}', "");
Expect(0, 8535, '\P{^Is_Numeric_Value=0.400}', "");
Error('\p{Is_Nv=/a/-	2/000005}');
Error('\P{Is_Nv=/a/-	2/000005}');
Expect(1, 8534, '\p{Is_Nv=0002/000000005}', "");
Expect(0, 8534, '\p{^Is_Nv=0002/000000005}', "");
Expect(0, 8534, '\P{Is_Nv=0002/000000005}', "");
Expect(1, 8534, '\P{^Is_Nv=0002/000000005}', "");
Expect(0, 8535, '\p{Is_Nv=0002/000000005}', "");
Expect(1, 8535, '\p{^Is_Nv=0002/000000005}', "");
Expect(1, 8535, '\P{Is_Nv=0002/000000005}', "");
Expect(0, 8535, '\P{^Is_Nv=0002/000000005}', "");
Expect(1, 8534, '\p{Is_Nv=0.400}', "");
Expect(0, 8534, '\p{^Is_Nv=0.400}', "");
Expect(0, 8534, '\P{Is_Nv=0.400}', "");
Expect(1, 8534, '\P{^Is_Nv=0.400}', "");
Expect(0, 8535, '\p{Is_Nv=0.400}', "");
Expect(1, 8535, '\p{^Is_Nv=0.400}', "");
Expect(1, 8535, '\P{Is_Nv=0.400}', "");
Expect(0, 8535, '\P{^Is_Nv=0.400}', "");
Error('\p{Numeric_Value=-0_0_0_020/a/}');
Error('\P{Numeric_Value=-0_0_0_020/a/}');
Expect(1, 119658, '\p{Numeric_Value=0_0_0_20}', "");
Expect(0, 119658, '\p{^Numeric_Value=0_0_0_20}', "");
Expect(0, 119658, '\P{Numeric_Value=0_0_0_20}', "");
Expect(1, 119658, '\P{^Numeric_Value=0_0_0_20}', "");
Expect(0, 119659, '\p{Numeric_Value=0_0_0_20}', "");
Expect(1, 119659, '\p{^Numeric_Value=0_0_0_20}', "");
Expect(1, 119659, '\P{Numeric_Value=0_0_0_20}', "");
Expect(0, 119659, '\P{^Numeric_Value=0_0_0_20}', "");
Error('\p{Nv=-:=00000000020}');
Error('\P{Nv=-:=00000000020}');
Expect(1, 119658, '\p{Nv=000020}', "");
Expect(0, 119658, '\p{^Nv=000020}', "");
Expect(0, 119658, '\P{Nv=000020}', "");
Expect(1, 119658, '\P{^Nv=000020}', "");
Expect(0, 119659, '\p{Nv=000020}', "");
Expect(1, 119659, '\p{^Nv=000020}', "");
Expect(1, 119659, '\P{Nv=000020}', "");
Expect(0, 119659, '\P{^Nv=000020}', "");
Error('\p{Is_Numeric_Value=		00_00_00_020:=}');
Error('\P{Is_Numeric_Value=		00_00_00_020:=}');
Expect(1, 119658, '\p{Is_Numeric_Value=00020}', "");
Expect(0, 119658, '\p{^Is_Numeric_Value=00020}', "");
Expect(0, 119658, '\P{Is_Numeric_Value=00020}', "");
Expect(1, 119658, '\P{^Is_Numeric_Value=00020}', "");
Expect(0, 119659, '\p{Is_Numeric_Value=00020}', "");
Expect(1, 119659, '\p{^Is_Numeric_Value=00020}', "");
Expect(1, 119659, '\P{Is_Numeric_Value=00020}', "");
Expect(0, 119659, '\P{^Is_Numeric_Value=00020}', "");
Error('\p{Is_Nv=:= 	00000020}');
Error('\P{Is_Nv=:= 	00000020}');
Expect(1, 119658, '\p{Is_Nv=00020}', "");
Expect(0, 119658, '\p{^Is_Nv=00020}', "");
Expect(0, 119658, '\P{Is_Nv=00020}', "");
Expect(1, 119658, '\P{^Is_Nv=00020}', "");
Expect(0, 119659, '\p{Is_Nv=00020}', "");
Expect(1, 119659, '\p{^Is_Nv=00020}', "");
Expect(1, 119659, '\P{Is_Nv=00020}', "");
Expect(0, 119659, '\P{^Is_Nv=00020}', "");
Error('\p{Numeric_Value=/a/-+0_0_0_0_2_00}');
Error('\P{Numeric_Value=/a/-+0_0_0_0_2_00}');
Expect(1, 69235, '\p{Numeric_Value: 0000000200}', "");
Expect(0, 69235, '\p{^Numeric_Value: 0000000200}', "");
Expect(0, 69235, '\P{Numeric_Value: 0000000200}', "");
Expect(1, 69235, '\P{^Numeric_Value: 0000000200}', "");
Expect(0, 69236, '\p{Numeric_Value: 0000000200}', "");
Expect(1, 69236, '\p{^Numeric_Value: 0000000200}', "");
Expect(1, 69236, '\P{Numeric_Value: 0000000200}', "");
Expect(0, 69236, '\P{^Numeric_Value: 0000000200}', "");
Error('\p{Nv=:=__+00020_0}');
Error('\P{Nv=:=__+00020_0}');
Expect(1, 69235, '\p{Nv=0_0_0_0_0_0200}', "");
Expect(0, 69235, '\p{^Nv=0_0_0_0_0_0200}', "");
Expect(0, 69235, '\P{Nv=0_0_0_0_0_0200}', "");
Expect(1, 69235, '\P{^Nv=0_0_0_0_0_0200}', "");
Expect(0, 69236, '\p{Nv=0_0_0_0_0_0200}', "");
Expect(1, 69236, '\p{^Nv=0_0_0_0_0_0200}', "");
Expect(1, 69236, '\P{Nv=0_0_0_0_0_0200}', "");
Expect(0, 69236, '\P{^Nv=0_0_0_0_0_0200}', "");
Error('\p{Is_Numeric_Value=:=-+0200}');
Error('\P{Is_Numeric_Value=:=-+0200}');
Expect(1, 69235, '\p{Is_Numeric_Value=000000000200}', "");
Expect(0, 69235, '\p{^Is_Numeric_Value=000000000200}', "");
Expect(0, 69235, '\P{Is_Numeric_Value=000000000200}', "");
Expect(1, 69235, '\P{^Is_Numeric_Value=000000000200}', "");
Expect(0, 69236, '\p{Is_Numeric_Value=000000000200}', "");
Expect(1, 69236, '\p{^Is_Numeric_Value=000000000200}', "");
Expect(1, 69236, '\P{Is_Numeric_Value=000000000200}', "");
Expect(0, 69236, '\P{^Is_Numeric_Value=000000000200}', "");
Error('\p{Is_Nv=_/a/0000200}');
Error('\P{Is_Nv=_/a/0000200}');
Expect(1, 69235, '\p{Is_Nv=+20_0}', "");
Expect(0, 69235, '\p{^Is_Nv=+20_0}', "");
Expect(0, 69235, '\P{Is_Nv=+20_0}', "");
Expect(1, 69235, '\P{^Is_Nv=+20_0}', "");
Expect(0, 69236, '\p{Is_Nv=+20_0}', "");
Expect(1, 69236, '\p{^Is_Nv=+20_0}', "");
Expect(1, 69236, '\P{Is_Nv=+20_0}', "");
Expect(0, 69236, '\P{^Is_Nv=+20_0}', "");
Error('\p{Numeric_Value=_/a/2000}');
Error('\P{Numeric_Value=_/a/2000}');
Expect(1, 65827, '\p{Numeric_Value=000000002000}', "");
Expect(0, 65827, '\p{^Numeric_Value=000000002000}', "");
Expect(0, 65827, '\P{Numeric_Value=000000002000}', "");
Expect(1, 65827, '\P{^Numeric_Value=000000002000}', "");
Expect(0, 65828, '\p{Numeric_Value=000000002000}', "");
Expect(1, 65828, '\p{^Numeric_Value=000000002000}', "");
Expect(1, 65828, '\P{Numeric_Value=000000002000}', "");
Expect(0, 65828, '\P{^Numeric_Value=000000002000}', "");
Error('\p{Nv=	 0000002000:=}');
Error('\P{Nv=	 0000002000:=}');
Expect(1, 65827, '\p{Nv=00000002000}', "");
Expect(0, 65827, '\p{^Nv=00000002000}', "");
Expect(0, 65827, '\P{Nv=00000002000}', "");
Expect(1, 65827, '\P{^Nv=00000002000}', "");
Expect(0, 65828, '\p{Nv=00000002000}', "");
Expect(1, 65828, '\p{^Nv=00000002000}', "");
Expect(1, 65828, '\P{Nv=00000002000}', "");
Expect(0, 65828, '\P{^Nv=00000002000}', "");
Error('\p{Is_Numeric_Value=:=_-00000002000}');
Error('\P{Is_Numeric_Value=:=_-00000002000}');
Expect(1, 65827, '\p{Is_Numeric_Value=+000_000_020_00}', "");
Expect(0, 65827, '\p{^Is_Numeric_Value=+000_000_020_00}', "");
Expect(0, 65827, '\P{Is_Numeric_Value=+000_000_020_00}', "");
Expect(1, 65827, '\P{^Is_Numeric_Value=+000_000_020_00}', "");
Expect(0, 65828, '\p{Is_Numeric_Value=+000_000_020_00}', "");
Expect(1, 65828, '\p{^Is_Numeric_Value=+000_000_020_00}', "");
Expect(1, 65828, '\P{Is_Numeric_Value=+000_000_020_00}', "");
Expect(0, 65828, '\P{^Is_Numeric_Value=+000_000_020_00}', "");
Error('\p{Is_Nv=_:=02000}');
Error('\P{Is_Nv=_:=02000}');
Expect(1, 65827, '\p{Is_Nv=02000}', "");
Expect(0, 65827, '\p{^Is_Nv=02000}', "");
Expect(0, 65827, '\P{Is_Nv=02000}', "");
Expect(1, 65827, '\P{^Is_Nv=02000}', "");
Expect(0, 65828, '\p{Is_Nv=02000}', "");
Expect(1, 65828, '\p{^Is_Nv=02000}', "");
Expect(1, 65828, '\P{Is_Nv=02000}', "");
Expect(0, 65828, '\P{^Is_Nv=02000}', "");
Error('\p{Numeric_Value=-:=20000}');
Error('\P{Numeric_Value=-:=20000}');
Expect(1, 65836, '\p{Numeric_Value=00000020000}', "");
Expect(0, 65836, '\p{^Numeric_Value=00000020000}', "");
Expect(0, 65836, '\P{Numeric_Value=00000020000}', "");
Expect(1, 65836, '\P{^Numeric_Value=00000020000}', "");
Expect(0, 65837, '\p{Numeric_Value=00000020000}', "");
Expect(1, 65837, '\p{^Numeric_Value=00000020000}', "");
Expect(1, 65837, '\P{Numeric_Value=00000020000}', "");
Expect(0, 65837, '\P{^Numeric_Value=00000020000}', "");
Error('\p{Nv=:=  0_0_0_2_0_0_00}');
Error('\P{Nv=:=  0_0_0_2_0_0_00}');
Expect(1, 65836, '\p{Nv=0000002000_0}', "");
Expect(0, 65836, '\p{^Nv=0000002000_0}', "");
Expect(0, 65836, '\P{Nv=0000002000_0}', "");
Expect(1, 65836, '\P{^Nv=0000002000_0}', "");
Expect(0, 65837, '\p{Nv=0000002000_0}', "");
Expect(1, 65837, '\p{^Nv=0000002000_0}', "");
Expect(1, 65837, '\P{Nv=0000002000_0}', "");
Expect(0, 65837, '\P{^Nv=0000002000_0}', "");
Error('\p{Is_Numeric_Value=/a/	+0000020000}');
Error('\P{Is_Numeric_Value=/a/	+0000020000}');
Expect(1, 65836, '\p{Is_Numeric_Value=+0_0_0_0_2_0_0_00}', "");
Expect(0, 65836, '\p{^Is_Numeric_Value=+0_0_0_0_2_0_0_00}', "");
Expect(0, 65836, '\P{Is_Numeric_Value=+0_0_0_0_2_0_0_00}', "");
Expect(1, 65836, '\P{^Is_Numeric_Value=+0_0_0_0_2_0_0_00}', "");
Expect(0, 65837, '\p{Is_Numeric_Value=+0_0_0_0_2_0_0_00}', "");
Expect(1, 65837, '\p{^Is_Numeric_Value=+0_0_0_0_2_0_0_00}', "");
Expect(1, 65837, '\P{Is_Numeric_Value=+0_0_0_0_2_0_0_00}', "");
Expect(0, 65837, '\P{^Is_Numeric_Value=+0_0_0_0_2_0_0_00}', "");
Error('\p{Is_Nv=00000_00200_00:=}');
Error('\P{Is_Nv=00000_00200_00:=}');
Expect(1, 65836, '\p{Is_Nv=0_2_0_000}', "");
Expect(0, 65836, '\p{^Is_Nv=0_2_0_000}', "");
Expect(0, 65836, '\P{Is_Nv=0_2_0_000}', "");
Expect(1, 65836, '\P{^Is_Nv=0_2_0_000}', "");
Expect(0, 65837, '\p{Is_Nv=0_2_0_000}', "");
Expect(1, 65837, '\p{^Is_Nv=0_2_0_000}', "");
Expect(1, 65837, '\P{Is_Nv=0_2_0_000}', "");
Expect(0, 65837, '\P{^Is_Nv=0_2_0_000}', "");
Error('\p{Numeric_Value= -0_0_0_0_0_021:=}');
Error('\P{Numeric_Value= -0_0_0_0_0_021:=}');
Expect(1, 12881, '\p{Numeric_Value=0_0_0_0_021}', "");
Expect(0, 12881, '\p{^Numeric_Value=0_0_0_0_021}', "");
Expect(0, 12881, '\P{Numeric_Value=0_0_0_0_021}', "");
Expect(1, 12881, '\P{^Numeric_Value=0_0_0_0_021}', "");
Expect(0, 12882, '\p{Numeric_Value=0_0_0_0_021}', "");
Expect(1, 12882, '\p{^Numeric_Value=0_0_0_0_021}', "");
Expect(1, 12882, '\P{Numeric_Value=0_0_0_0_021}', "");
Expect(0, 12882, '\P{^Numeric_Value=0_0_0_0_021}', "");
Error('\p{Nv= -+000_000_002_1:=}');
Error('\P{Nv= -+000_000_002_1:=}');
Expect(1, 12881, '\p{Nv=+00000000021}', "");
Expect(0, 12881, '\p{^Nv=+00000000021}', "");
Expect(0, 12881, '\P{Nv=+00000000021}', "");
Expect(1, 12881, '\P{^Nv=+00000000021}', "");
Expect(0, 12882, '\p{Nv=+00000000021}', "");
Expect(1, 12882, '\p{^Nv=+00000000021}', "");
Expect(1, 12882, '\P{Nv=+00000000021}', "");
Expect(0, 12882, '\P{^Nv=+00000000021}', "");
Error('\p{Is_Numeric_Value=	 0000021/a/}');
Error('\P{Is_Numeric_Value=	 0000021/a/}');
Expect(1, 12881, '\p{Is_Numeric_Value=02_1}', "");
Expect(0, 12881, '\p{^Is_Numeric_Value=02_1}', "");
Expect(0, 12881, '\P{Is_Numeric_Value=02_1}', "");
Expect(1, 12881, '\P{^Is_Numeric_Value=02_1}', "");
Expect(0, 12882, '\p{Is_Numeric_Value=02_1}', "");
Expect(1, 12882, '\p{^Is_Numeric_Value=02_1}', "");
Expect(1, 12882, '\P{Is_Numeric_Value=02_1}', "");
Expect(0, 12882, '\P{^Is_Numeric_Value=02_1}', "");
Error('\p{Is_Nv=/a/	0_0_0_0_0_0021}');
Error('\P{Is_Nv=/a/	0_0_0_0_0_0021}');
Expect(1, 12881, '\p{Is_Nv=00000000021}', "");
Expect(0, 12881, '\p{^Is_Nv=00000000021}', "");
Expect(0, 12881, '\P{Is_Nv=00000000021}', "");
Expect(1, 12881, '\P{^Is_Nv=00000000021}', "");
Expect(0, 12882, '\p{Is_Nv=00000000021}', "");
Expect(1, 12882, '\p{^Is_Nv=00000000021}', "");
Expect(1, 12882, '\P{Is_Nv=00000000021}', "");
Expect(0, 12882, '\P{^Is_Nv=00000000021}', "");
Error('\p{Numeric_Value=/a/0_0_0_0_0_0_0_0_0_2_1_6_000}');
Error('\P{Numeric_Value=/a/0_0_0_0_0_0_0_0_0_2_1_6_000}');
Expect(1, 74802, '\p{Numeric_Value=00000216000}', "");
Expect(0, 74802, '\p{^Numeric_Value=00000216000}', "");
Expect(0, 74802, '\P{Numeric_Value=00000216000}', "");
Expect(1, 74802, '\P{^Numeric_Value=00000216000}', "");
Expect(0, 74803, '\p{Numeric_Value=00000216000}', "");
Expect(1, 74803, '\p{^Numeric_Value=00000216000}', "");
Expect(1, 74803, '\P{Numeric_Value=00000216000}', "");
Expect(0, 74803, '\P{^Numeric_Value=00000216000}', "");
Error('\p{Nv:   	/a/000000000216000}');
Error('\P{Nv:   	/a/000000000216000}');
Expect(1, 74802, '\p{Nv=+216000}', "");
Expect(0, 74802, '\p{^Nv=+216000}', "");
Expect(0, 74802, '\P{Nv=+216000}', "");
Expect(1, 74802, '\P{^Nv=+216000}', "");
Expect(0, 74803, '\p{Nv=+216000}', "");
Expect(1, 74803, '\p{^Nv=+216000}', "");
Expect(1, 74803, '\P{Nv=+216000}', "");
Expect(0, 74803, '\P{^Nv=+216000}', "");
Error('\p{Is_Numeric_Value=_-+0_0_0_0_0_0_0_0_216000/a/}');
Error('\P{Is_Numeric_Value=_-+0_0_0_0_0_0_0_0_216000/a/}');
Expect(1, 74802, '\p{Is_Numeric_Value=000_021_600_0}', "");
Expect(0, 74802, '\p{^Is_Numeric_Value=000_021_600_0}', "");
Expect(0, 74802, '\P{Is_Numeric_Value=000_021_600_0}', "");
Expect(1, 74802, '\P{^Is_Numeric_Value=000_021_600_0}', "");
Expect(0, 74803, '\p{Is_Numeric_Value=000_021_600_0}', "");
Expect(1, 74803, '\p{^Is_Numeric_Value=000_021_600_0}', "");
Expect(1, 74803, '\P{Is_Numeric_Value=000_021_600_0}', "");
Expect(0, 74803, '\P{^Is_Numeric_Value=000_021_600_0}', "");
Error('\p{Is_Nv=  2_1_6_0_00/a/}');
Error('\P{Is_Nv=  2_1_6_0_00/a/}');
Expect(1, 74802, '\p{Is_Nv=0_0_0_0_0_0_0_0_0_2_1_6_000}', "");
Expect(0, 74802, '\p{^Is_Nv=0_0_0_0_0_0_0_0_0_2_1_6_000}', "");
Expect(0, 74802, '\P{Is_Nv=0_0_0_0_0_0_0_0_0_2_1_6_000}', "");
Expect(1, 74802, '\P{^Is_Nv=0_0_0_0_0_0_0_0_0_2_1_6_000}', "");
Expect(0, 74803, '\p{Is_Nv=0_0_0_0_0_0_0_0_0_2_1_6_000}', "");
Expect(1, 74803, '\p{^Is_Nv=0_0_0_0_0_0_0_0_0_2_1_6_000}', "");
Expect(1, 74803, '\P{Is_Nv=0_0_0_0_0_0_0_0_0_2_1_6_000}', "");
Expect(0, 74803, '\P{^Is_Nv=0_0_0_0_0_0_0_0_0_2_1_6_000}', "");
Error('\p{Numeric_Value:   /a/ 	0000002_2}');
Error('\P{Numeric_Value:   /a/ 	0000002_2}');
Expect(1, 12882, '\p{Numeric_Value:   0_0_0_0_0_0_0_0_0_22}', "");
Expect(0, 12882, '\p{^Numeric_Value:   0_0_0_0_0_0_0_0_0_22}', "");
Expect(0, 12882, '\P{Numeric_Value:   0_0_0_0_0_0_0_0_0_22}', "");
Expect(1, 12882, '\P{^Numeric_Value:   0_0_0_0_0_0_0_0_0_22}', "");
Expect(0, 12883, '\p{Numeric_Value:   0_0_0_0_0_0_0_0_0_22}', "");
Expect(1, 12883, '\p{^Numeric_Value:   0_0_0_0_0_0_0_0_0_22}', "");
Expect(1, 12883, '\P{Numeric_Value:   0_0_0_0_0_0_0_0_0_22}', "");
Expect(0, 12883, '\P{^Numeric_Value:   0_0_0_0_0_0_0_0_0_22}', "");
Error('\p{Nv=:=-22}');
Error('\P{Nv=:=-22}');
Expect(1, 12882, '\p{Nv=0000_0002_2}', "");
Expect(0, 12882, '\p{^Nv=0000_0002_2}', "");
Expect(0, 12882, '\P{Nv=0000_0002_2}', "");
Expect(1, 12882, '\P{^Nv=0000_0002_2}', "");
Expect(0, 12883, '\p{Nv=0000_0002_2}', "");
Expect(1, 12883, '\p{^Nv=0000_0002_2}', "");
Expect(1, 12883, '\P{Nv=0000_0002_2}', "");
Expect(0, 12883, '\P{^Nv=0000_0002_2}', "");
Error('\p{Is_Numeric_Value=-/a/00000022}');
Error('\P{Is_Numeric_Value=-/a/00000022}');
Expect(1, 12882, '\p{Is_Numeric_Value=00_00_00_022}', "");
Expect(0, 12882, '\p{^Is_Numeric_Value=00_00_00_022}', "");
Expect(0, 12882, '\P{Is_Numeric_Value=00_00_00_022}', "");
Expect(1, 12882, '\P{^Is_Numeric_Value=00_00_00_022}', "");
Expect(0, 12883, '\p{Is_Numeric_Value=00_00_00_022}', "");
Expect(1, 12883, '\p{^Is_Numeric_Value=00_00_00_022}', "");
Expect(1, 12883, '\P{Is_Numeric_Value=00_00_00_022}', "");
Expect(0, 12883, '\P{^Is_Numeric_Value=00_00_00_022}', "");
Error('\p{Is_Nv=-:=+0000_0000_22}');
Error('\P{Is_Nv=-:=+0000_0000_22}');
Expect(1, 12882, '\p{Is_Nv=0000002_2}', "");
Expect(0, 12882, '\p{^Is_Nv=0000002_2}', "");
Expect(0, 12882, '\P{Is_Nv=0000002_2}', "");
Expect(1, 12882, '\P{^Is_Nv=0000002_2}', "");
Expect(0, 12883, '\p{Is_Nv=0000002_2}', "");
Expect(1, 12883, '\p{^Is_Nv=0000002_2}', "");
Expect(1, 12883, '\P{Is_Nv=0000002_2}', "");
Expect(0, 12883, '\P{^Is_Nv=0000002_2}', "");
Error('\p{Numeric_Value=- 000_000_002_3:=}');
Error('\P{Numeric_Value=- 000_000_002_3:=}');
Expect(1, 12883, '\p{Numeric_Value=2_3}', "");
Expect(0, 12883, '\p{^Numeric_Value=2_3}', "");
Expect(0, 12883, '\P{Numeric_Value=2_3}', "");
Expect(1, 12883, '\P{^Numeric_Value=2_3}', "");
Expect(0, 12884, '\p{Numeric_Value=2_3}', "");
Expect(1, 12884, '\p{^Numeric_Value=2_3}', "");
Expect(1, 12884, '\P{Numeric_Value=2_3}', "");
Expect(0, 12884, '\P{^Numeric_Value=2_3}', "");
Error('\p{Nv=-	+0_0_0_0_0_0_00023/a/}');
Error('\P{Nv=-	+0_0_0_0_0_0_00023/a/}');
Expect(1, 12883, '\p{Nv=+00000002_3}', "");
Expect(0, 12883, '\p{^Nv=+00000002_3}', "");
Expect(0, 12883, '\P{Nv=+00000002_3}', "");
Expect(1, 12883, '\P{^Nv=+00000002_3}', "");
Expect(0, 12884, '\p{Nv=+00000002_3}', "");
Expect(1, 12884, '\p{^Nv=+00000002_3}', "");
Expect(1, 12884, '\P{Nv=+00000002_3}', "");
Expect(0, 12884, '\P{^Nv=+00000002_3}', "");
Error('\p{Is_Numeric_Value:	:=	+23}');
Error('\P{Is_Numeric_Value:	:=	+23}');
Expect(1, 12883, '\p{Is_Numeric_Value: +00000023}', "");
Expect(0, 12883, '\p{^Is_Numeric_Value: +00000023}', "");
Expect(0, 12883, '\P{Is_Numeric_Value: +00000023}', "");
Expect(1, 12883, '\P{^Is_Numeric_Value: +00000023}', "");
Expect(0, 12884, '\p{Is_Numeric_Value: +00000023}', "");
Expect(1, 12884, '\p{^Is_Numeric_Value: +00000023}', "");
Expect(1, 12884, '\P{Is_Numeric_Value: +00000023}', "");
Expect(0, 12884, '\P{^Is_Numeric_Value: +00000023}', "");
Error('\p{Is_Nv=	:=00023}');
Error('\P{Is_Nv=	:=00023}');
Expect(1, 12883, '\p{Is_Nv=+023}', "");
Expect(0, 12883, '\p{^Is_Nv=+023}', "");
Expect(0, 12883, '\P{Is_Nv=+023}', "");
Expect(1, 12883, '\P{^Is_Nv=+023}', "");
Expect(0, 12884, '\p{Is_Nv=+023}', "");
Expect(1, 12884, '\p{^Is_Nv=+023}', "");
Expect(1, 12884, '\P{Is_Nv=+023}', "");
Expect(0, 12884, '\P{^Is_Nv=+023}', "");
Error('\p{Numeric_Value=--000024/a/}');
Error('\P{Numeric_Value=--000024/a/}');
Expect(1, 12884, '\p{Numeric_Value:+24}', "");
Expect(0, 12884, '\p{^Numeric_Value:+24}', "");
Expect(0, 12884, '\P{Numeric_Value:+24}', "");
Expect(1, 12884, '\P{^Numeric_Value:+24}', "");
Expect(0, 12885, '\p{Numeric_Value:+24}', "");
Expect(1, 12885, '\p{^Numeric_Value:+24}', "");
Expect(1, 12885, '\P{Numeric_Value:+24}', "");
Expect(0, 12885, '\P{^Numeric_Value:+24}', "");
Error('\p{Nv=_-024:=}');
Error('\P{Nv=_-024:=}');
Expect(1, 12884, '\p{Nv=+0000000024}', "");
Expect(0, 12884, '\p{^Nv=+0000000024}', "");
Expect(0, 12884, '\P{Nv=+0000000024}', "");
Expect(1, 12884, '\P{^Nv=+0000000024}', "");
Expect(0, 12885, '\p{Nv=+0000000024}', "");
Expect(1, 12885, '\p{^Nv=+0000000024}', "");
Expect(1, 12885, '\P{Nv=+0000000024}', "");
Expect(0, 12885, '\P{^Nv=+0000000024}', "");
Error('\p{Is_Numeric_Value:   	/a/0_0_0_024}');
Error('\P{Is_Numeric_Value:   	/a/0_0_0_024}');
Expect(1, 12884, '\p{Is_Numeric_Value=+0_0_0_0_0_0_0024}', "");
Expect(0, 12884, '\p{^Is_Numeric_Value=+0_0_0_0_0_0_0024}', "");
Expect(0, 12884, '\P{Is_Numeric_Value=+0_0_0_0_0_0_0024}', "");
Expect(1, 12884, '\P{^Is_Numeric_Value=+0_0_0_0_0_0_0024}', "");
Expect(0, 12885, '\p{Is_Numeric_Value=+0_0_0_0_0_0_0024}', "");
Expect(1, 12885, '\p{^Is_Numeric_Value=+0_0_0_0_0_0_0024}', "");
Expect(1, 12885, '\P{Is_Numeric_Value=+0_0_0_0_0_0_0024}', "");
Expect(0, 12885, '\P{^Is_Numeric_Value=+0_0_0_0_0_0_0024}', "");
Error('\p{Is_Nv=:=	-+24}');
Error('\P{Is_Nv=:=	-+24}');
Expect(1, 12884, '\p{Is_Nv=02_4}', "");
Expect(0, 12884, '\p{^Is_Nv=02_4}', "");
Expect(0, 12884, '\P{Is_Nv=02_4}', "");
Expect(1, 12884, '\P{^Is_Nv=02_4}', "");
Expect(0, 12885, '\p{Is_Nv=02_4}', "");
Expect(1, 12885, '\p{^Is_Nv=02_4}', "");
Expect(1, 12885, '\P{Is_Nv=02_4}', "");
Expect(0, 12885, '\P{^Is_Nv=02_4}', "");
Error('\p{Numeric_Value=/a/_-0_0_0_0_0_25}');
Error('\P{Numeric_Value=/a/_-0_0_0_0_0_25}');
Expect(1, 12885, '\p{Numeric_Value=+0000025}', "");
Expect(0, 12885, '\p{^Numeric_Value=+0000025}', "");
Expect(0, 12885, '\P{Numeric_Value=+0000025}', "");
Expect(1, 12885, '\P{^Numeric_Value=+0000025}', "");
Expect(0, 12886, '\p{Numeric_Value=+0000025}', "");
Expect(1, 12886, '\p{^Numeric_Value=+0000025}', "");
Expect(1, 12886, '\P{Numeric_Value=+0000025}', "");
Expect(0, 12886, '\P{^Numeric_Value=+0000025}', "");
Error('\p{Nv= 0_0_25/a/}');
Error('\P{Nv= 0_0_25/a/}');
Expect(1, 12885, '\p{Nv=+2_5}', "");
Expect(0, 12885, '\p{^Nv=+2_5}', "");
Expect(0, 12885, '\P{Nv=+2_5}', "");
Expect(1, 12885, '\P{^Nv=+2_5}', "");
Expect(0, 12886, '\p{Nv=+2_5}', "");
Expect(1, 12886, '\p{^Nv=+2_5}', "");
Expect(1, 12886, '\P{Nv=+2_5}', "");
Expect(0, 12886, '\P{^Nv=+2_5}', "");
Error('\p{Is_Numeric_Value=	:=+02_5}');
Error('\P{Is_Numeric_Value=	:=+02_5}');
Expect(1, 12885, '\p{Is_Numeric_Value=00_02_5}', "");
Expect(0, 12885, '\p{^Is_Numeric_Value=00_02_5}', "");
Expect(0, 12885, '\P{Is_Numeric_Value=00_02_5}', "");
Expect(1, 12885, '\P{^Is_Numeric_Value=00_02_5}', "");
Expect(0, 12886, '\p{Is_Numeric_Value=00_02_5}', "");
Expect(1, 12886, '\p{^Is_Numeric_Value=00_02_5}', "");
Expect(1, 12886, '\P{Is_Numeric_Value=00_02_5}', "");
Expect(0, 12886, '\P{^Is_Numeric_Value=00_02_5}', "");
Error('\p{Is_Nv=:=	_0000025}');
Error('\P{Is_Nv=:=	_0000025}');
Expect(1, 12885, '\p{Is_Nv=0_0_0_0_0_0_0_0_025}', "");
Expect(0, 12885, '\p{^Is_Nv=0_0_0_0_0_0_0_0_025}', "");
Expect(0, 12885, '\P{Is_Nv=0_0_0_0_0_0_0_0_025}', "");
Expect(1, 12885, '\P{^Is_Nv=0_0_0_0_0_0_0_0_025}', "");
Expect(0, 12886, '\p{Is_Nv=0_0_0_0_0_0_0_0_025}', "");
Expect(1, 12886, '\p{^Is_Nv=0_0_0_0_0_0_0_0_025}', "");
Expect(1, 12886, '\P{Is_Nv=0_0_0_0_0_0_0_0_025}', "");
Expect(0, 12886, '\P{^Is_Nv=0_0_0_0_0_0_0_0_025}', "");
Error('\p{Numeric_Value=	/a/0000_0000_26}');
Error('\P{Numeric_Value=	/a/0000_0000_26}');
Expect(1, 12886, '\p{Numeric_Value=0_0_26}', "");
Expect(0, 12886, '\p{^Numeric_Value=0_0_26}', "");
Expect(0, 12886, '\P{Numeric_Value=0_0_26}', "");
Expect(1, 12886, '\P{^Numeric_Value=0_0_26}', "");
Expect(0, 12887, '\p{Numeric_Value=0_0_26}', "");
Expect(1, 12887, '\p{^Numeric_Value=0_0_26}', "");
Expect(1, 12887, '\P{Numeric_Value=0_0_26}', "");
Expect(0, 12887, '\P{^Numeric_Value=0_0_26}', "");
Error('\p{Nv=/a/  0000026}');
Error('\P{Nv=/a/  0000026}');
Expect(1, 12886, '\p{Nv=0000000026}', "");
Expect(0, 12886, '\p{^Nv=0000000026}', "");
Expect(0, 12886, '\P{Nv=0000000026}', "");
Expect(1, 12886, '\P{^Nv=0000000026}', "");
Expect(0, 12887, '\p{Nv=0000000026}', "");
Expect(1, 12887, '\p{^Nv=0000000026}', "");
Expect(1, 12887, '\P{Nv=0000000026}', "");
Expect(0, 12887, '\P{^Nv=0000000026}', "");
Error('\p{Is_Numeric_Value=:=00_00_00_02_6}');
Error('\P{Is_Numeric_Value=:=00_00_00_02_6}');
Expect(1, 12886, '\p{Is_Numeric_Value=+00002_6}', "");
Expect(0, 12886, '\p{^Is_Numeric_Value=+00002_6}', "");
Expect(0, 12886, '\P{Is_Numeric_Value=+00002_6}', "");
Expect(1, 12886, '\P{^Is_Numeric_Value=+00002_6}', "");
Expect(0, 12887, '\p{Is_Numeric_Value=+00002_6}', "");
Expect(1, 12887, '\p{^Is_Numeric_Value=+00002_6}', "");
Expect(1, 12887, '\P{Is_Numeric_Value=+00002_6}', "");
Expect(0, 12887, '\P{^Is_Numeric_Value=+00002_6}', "");
Error('\p{Is_Nv=/a/_2_6}');
Error('\P{Is_Nv=/a/_2_6}');
Expect(1, 12886, '\p{Is_Nv=000000026}', "");
Expect(0, 12886, '\p{^Is_Nv=000000026}', "");
Expect(0, 12886, '\P{Is_Nv=000000026}', "");
Expect(1, 12886, '\P{^Is_Nv=000000026}', "");
Expect(0, 12887, '\p{Is_Nv=000000026}', "");
Expect(1, 12887, '\p{^Is_Nv=000000026}', "");
Expect(1, 12887, '\P{Is_Nv=000000026}', "");
Expect(0, 12887, '\P{^Is_Nv=000000026}', "");
Error('\p{Numeric_Value=	0000000027/a/}');
Error('\P{Numeric_Value=	0000000027/a/}');
Expect(1, 12887, '\p{Numeric_Value:00027}', "");
Expect(0, 12887, '\p{^Numeric_Value:00027}', "");
Expect(0, 12887, '\P{Numeric_Value:00027}', "");
Expect(1, 12887, '\P{^Numeric_Value:00027}', "");
Expect(0, 12888, '\p{Numeric_Value:00027}', "");
Expect(1, 12888, '\p{^Numeric_Value:00027}', "");
Expect(1, 12888, '\P{Numeric_Value:00027}', "");
Expect(0, 12888, '\P{^Numeric_Value:00027}', "");
Error('\p{Nv=	+027:=}');
Error('\P{Nv=	+027:=}');
Expect(1, 12887, '\p{Nv=+00_00_00_27}', "");
Expect(0, 12887, '\p{^Nv=+00_00_00_27}', "");
Expect(0, 12887, '\P{Nv=+00_00_00_27}', "");
Expect(1, 12887, '\P{^Nv=+00_00_00_27}', "");
Expect(0, 12888, '\p{Nv=+00_00_00_27}', "");
Expect(1, 12888, '\p{^Nv=+00_00_00_27}', "");
Expect(1, 12888, '\P{Nv=+00_00_00_27}', "");
Expect(0, 12888, '\P{^Nv=+00_00_00_27}', "");
Error('\p{Is_Numeric_Value=000_000_002_7/a/}');
Error('\P{Is_Numeric_Value=000_000_002_7/a/}');
Expect(1, 12887, '\p{Is_Numeric_Value: 0000027}', "");
Expect(0, 12887, '\p{^Is_Numeric_Value: 0000027}', "");
Expect(0, 12887, '\P{Is_Numeric_Value: 0000027}', "");
Expect(1, 12887, '\P{^Is_Numeric_Value: 0000027}', "");
Expect(0, 12888, '\p{Is_Numeric_Value: 0000027}', "");
Expect(1, 12888, '\p{^Is_Numeric_Value: 0000027}', "");
Expect(1, 12888, '\P{Is_Numeric_Value: 0000027}', "");
Expect(0, 12888, '\P{^Is_Numeric_Value: 0000027}', "");
Error('\p{Is_Nv=:=00_00_27}');
Error('\P{Is_Nv=:=00_00_27}');
Expect(1, 12887, '\p{Is_Nv=00027}', "");
Expect(0, 12887, '\p{^Is_Nv=00027}', "");
Expect(0, 12887, '\P{Is_Nv=00027}', "");
Expect(1, 12887, '\P{^Is_Nv=00027}', "");
Expect(0, 12888, '\p{Is_Nv=00027}', "");
Expect(1, 12888, '\p{^Is_Nv=00027}', "");
Expect(1, 12888, '\P{Is_Nv=00027}', "");
Expect(0, 12888, '\P{^Is_Nv=00027}', "");
Error('\p{Numeric_Value=/a/_-+2_8}');
Error('\P{Numeric_Value=/a/_-+2_8}');
Expect(1, 12888, '\p{Numeric_Value=+0028}', "");
Expect(0, 12888, '\p{^Numeric_Value=+0028}', "");
Expect(0, 12888, '\P{Numeric_Value=+0028}', "");
Expect(1, 12888, '\P{^Numeric_Value=+0028}', "");
Expect(0, 12889, '\p{Numeric_Value=+0028}', "");
Expect(1, 12889, '\p{^Numeric_Value=+0028}', "");
Expect(1, 12889, '\P{Numeric_Value=+0028}', "");
Expect(0, 12889, '\P{^Numeric_Value=+0028}', "");
Error('\p{Nv= _0000000028/a/}');
Error('\P{Nv= _0000000028/a/}');
Expect(1, 12888, '\p{Nv=00000028}', "");
Expect(0, 12888, '\p{^Nv=00000028}', "");
Expect(0, 12888, '\P{Nv=00000028}', "");
Expect(1, 12888, '\P{^Nv=00000028}', "");
Expect(0, 12889, '\p{Nv=00000028}', "");
Expect(1, 12889, '\p{^Nv=00000028}', "");
Expect(1, 12889, '\P{Nv=00000028}', "");
Expect(0, 12889, '\P{^Nv=00000028}', "");
Error('\p{Is_Numeric_Value=_/a/0_0_0_0_0_0_28}');
Error('\P{Is_Numeric_Value=_/a/0_0_0_0_0_0_28}');
Expect(1, 12888, '\p{Is_Numeric_Value=00028}', "");
Expect(0, 12888, '\p{^Is_Numeric_Value=00028}', "");
Expect(0, 12888, '\P{Is_Numeric_Value=00028}', "");
Expect(1, 12888, '\P{^Is_Numeric_Value=00028}', "");
Expect(0, 12889, '\p{Is_Numeric_Value=00028}', "");
Expect(1, 12889, '\p{^Is_Numeric_Value=00028}', "");
Expect(1, 12889, '\P{Is_Numeric_Value=00028}', "");
Expect(0, 12889, '\P{^Is_Numeric_Value=00028}', "");
Error('\p{Is_Nv= 000028/a/}');
Error('\P{Is_Nv= 000028/a/}');
Expect(1, 12888, '\p{Is_Nv:000000028}', "");
Expect(0, 12888, '\p{^Is_Nv:000000028}', "");
Expect(0, 12888, '\P{Is_Nv:000000028}', "");
Expect(1, 12888, '\P{^Is_Nv:000000028}', "");
Expect(0, 12889, '\p{Is_Nv:000000028}', "");
Expect(1, 12889, '\p{^Is_Nv:000000028}', "");
Expect(1, 12889, '\P{Is_Nv:000000028}', "");
Expect(0, 12889, '\P{^Is_Nv:000000028}', "");
Error('\p{Numeric_Value=/a/000029}');
Error('\P{Numeric_Value=/a/000029}');
Expect(1, 12889, '\p{Numeric_Value: +0000029}', "");
Expect(0, 12889, '\p{^Numeric_Value: +0000029}', "");
Expect(0, 12889, '\P{Numeric_Value: +0000029}', "");
Expect(1, 12889, '\P{^Numeric_Value: +0000029}', "");
Expect(0, 12890, '\p{Numeric_Value: +0000029}', "");
Expect(1, 12890, '\p{^Numeric_Value: +0000029}', "");
Expect(1, 12890, '\P{Numeric_Value: +0000029}', "");
Expect(0, 12890, '\P{^Numeric_Value: +0000029}', "");
Error('\p{Nv=-	00_00_29:=}');
Error('\P{Nv=-	00_00_29:=}');
Expect(1, 12889, '\p{Nv:   0000029}', "");
Expect(0, 12889, '\p{^Nv:   0000029}', "");
Expect(0, 12889, '\P{Nv:   0000029}', "");
Expect(1, 12889, '\P{^Nv:   0000029}', "");
Expect(0, 12890, '\p{Nv:   0000029}', "");
Expect(1, 12890, '\p{^Nv:   0000029}', "");
Expect(1, 12890, '\P{Nv:   0000029}', "");
Expect(0, 12890, '\P{^Nv:   0000029}', "");
Error('\p{Is_Numeric_Value=:=-	0002_9}');
Error('\P{Is_Numeric_Value=:=-	0002_9}');
Expect(1, 12889, '\p{Is_Numeric_Value=00_00_02_9}', "");
Expect(0, 12889, '\p{^Is_Numeric_Value=00_00_02_9}', "");
Expect(0, 12889, '\P{Is_Numeric_Value=00_00_02_9}', "");
Expect(1, 12889, '\P{^Is_Numeric_Value=00_00_02_9}', "");
Expect(0, 12890, '\p{Is_Numeric_Value=00_00_02_9}', "");
Expect(1, 12890, '\p{^Is_Numeric_Value=00_00_02_9}', "");
Expect(1, 12890, '\P{Is_Numeric_Value=00_00_02_9}', "");
Expect(0, 12890, '\P{^Is_Numeric_Value=00_00_02_9}', "");
Error('\p{Is_Nv=/a/-+2_9}');
Error('\P{Is_Nv=/a/-+2_9}');
Expect(1, 12889, '\p{Is_Nv=0000002_9}', "");
Expect(0, 12889, '\p{^Is_Nv=0000002_9}', "");
Expect(0, 12889, '\P{Is_Nv=0000002_9}', "");
Expect(1, 12889, '\P{^Is_Nv=0000002_9}', "");
Expect(0, 12890, '\p{Is_Nv=0000002_9}', "");
Expect(1, 12890, '\p{^Is_Nv=0000002_9}', "");
Expect(1, 12890, '\P{Is_Nv=0000002_9}', "");
Expect(0, 12890, '\P{^Is_Nv=0000002_9}', "");
Error('\p{Numeric_Value=--0003/a/}');
Error('\P{Numeric_Value=--0003/a/}');
Expect(1, 146203, '\p{Numeric_Value=+00_00_3}', "");
Expect(0, 146203, '\p{^Numeric_Value=+00_00_3}', "");
Expect(0, 146203, '\P{Numeric_Value=+00_00_3}', "");
Expect(1, 146203, '\P{^Numeric_Value=+00_00_3}', "");
Expect(0, 146204, '\p{Numeric_Value=+00_00_3}', "");
Expect(1, 146204, '\p{^Numeric_Value=+00_00_3}', "");
Expect(1, 146204, '\P{Numeric_Value=+00_00_3}', "");
Expect(0, 146204, '\P{^Numeric_Value=+00_00_3}', "");
Error('\p{Nv= -0000003:=}');
Error('\P{Nv= -0000003:=}');
Expect(1, 146203, '\p{Nv=000_000_03}', "");
Expect(0, 146203, '\p{^Nv=000_000_03}', "");
Expect(0, 146203, '\P{Nv=000_000_03}', "");
Expect(1, 146203, '\P{^Nv=000_000_03}', "");
Expect(0, 146204, '\p{Nv=000_000_03}', "");
Expect(1, 146204, '\p{^Nv=000_000_03}', "");
Expect(1, 146204, '\P{Nv=000_000_03}', "");
Expect(0, 146204, '\P{^Nv=000_000_03}', "");
Error('\p{Is_Numeric_Value=/a/		03}');
Error('\P{Is_Numeric_Value=/a/		03}');
Expect(1, 146203, '\p{Is_Numeric_Value=+0_3}', "");
Expect(0, 146203, '\p{^Is_Numeric_Value=+0_3}', "");
Expect(0, 146203, '\P{Is_Numeric_Value=+0_3}', "");
Expect(1, 146203, '\P{^Is_Numeric_Value=+0_3}', "");
Expect(0, 146204, '\p{Is_Numeric_Value=+0_3}', "");
Expect(1, 146204, '\p{^Is_Numeric_Value=+0_3}', "");
Expect(1, 146204, '\P{Is_Numeric_Value=+0_3}', "");
Expect(0, 146204, '\P{^Is_Numeric_Value=+0_3}', "");
Error('\p{Is_Nv=/a/+0_3}');
Error('\P{Is_Nv=/a/+0_3}');
Expect(1, 146203, '\p{Is_Nv=000000003}', "");
Expect(0, 146203, '\p{^Is_Nv=000000003}', "");
Expect(0, 146203, '\P{Is_Nv=000000003}', "");
Expect(1, 146203, '\P{^Is_Nv=000000003}', "");
Expect(0, 146204, '\p{Is_Nv=000000003}', "");
Expect(1, 146204, '\p{^Is_Nv=000000003}', "");
Expect(1, 146204, '\P{Is_Nv=000000003}', "");
Expect(0, 146204, '\P{^Is_Nv=000000003}', "");
Error('\p{Numeric_Value:	_003/0016:=}');
Error('\P{Numeric_Value:	_003/0016:=}');
Expect(1, 43061, '\p{Numeric_Value=+0003/016}', "");
Expect(0, 43061, '\p{^Numeric_Value=+0003/016}', "");
Expect(0, 43061, '\P{Numeric_Value=+0003/016}', "");
Expect(1, 43061, '\P{^Numeric_Value=+0003/016}', "");
Expect(0, 43062, '\p{Numeric_Value=+0003/016}', "");
Expect(1, 43062, '\p{^Numeric_Value=+0003/016}', "");
Expect(1, 43062, '\P{Numeric_Value=+0003/016}', "");
Expect(0, 43062, '\P{^Numeric_Value=+0003/016}', "");
Error('\p{Numeric_Value=0.19}');
Error('\P{Numeric_Value=0.19}');
Expect(1, 43061, '\p{Numeric_Value=0.188}', "");
Expect(0, 43061, '\p{^Numeric_Value=0.188}', "");
Expect(0, 43061, '\P{Numeric_Value=0.188}', "");
Expect(1, 43061, '\P{^Numeric_Value=0.188}', "");
Expect(0, 43062, '\p{Numeric_Value=0.188}', "");
Expect(1, 43062, '\p{^Numeric_Value=0.188}', "");
Expect(1, 43062, '\P{Numeric_Value=0.188}', "");
Expect(0, 43062, '\P{^Numeric_Value=0.188}', "");
Error('\p{Nv=/a/	00000003/00000000016}');
Error('\P{Nv=/a/	00000003/00000000016}');
Expect(1, 43061, '\p{Nv=+00000003/0000000016}', "");
Expect(0, 43061, '\p{^Nv=+00000003/0000000016}', "");
Expect(0, 43061, '\P{Nv=+00000003/0000000016}', "");
Expect(1, 43061, '\P{^Nv=+00000003/0000000016}', "");
Expect(0, 43062, '\p{Nv=+00000003/0000000016}', "");
Expect(1, 43062, '\p{^Nv=+00000003/0000000016}', "");
Expect(1, 43062, '\P{Nv=+00000003/0000000016}', "");
Expect(0, 43062, '\P{^Nv=+00000003/0000000016}', "");
Error('\p{Nv=0.19}');
Error('\P{Nv=0.19}');
Expect(1, 43061, '\p{Nv=0.188}', "");
Expect(0, 43061, '\p{^Nv=0.188}', "");
Expect(0, 43061, '\P{Nv=0.188}', "");
Expect(1, 43061, '\P{^Nv=0.188}', "");
Expect(0, 43062, '\p{Nv=0.188}', "");
Expect(1, 43062, '\p{^Nv=0.188}', "");
Expect(1, 43062, '\P{Nv=0.188}', "");
Expect(0, 43062, '\P{^Nv=0.188}', "");
Error('\p{Is_Numeric_Value=	/a/0000003/00000000016}');
Error('\P{Is_Numeric_Value=	/a/0000003/00000000016}');
Expect(1, 43061, '\p{Is_Numeric_Value=0000003/00016}', "");
Expect(0, 43061, '\p{^Is_Numeric_Value=0000003/00016}', "");
Expect(0, 43061, '\P{Is_Numeric_Value=0000003/00016}', "");
Expect(1, 43061, '\P{^Is_Numeric_Value=0000003/00016}', "");
Expect(0, 43062, '\p{Is_Numeric_Value=0000003/00016}', "");
Expect(1, 43062, '\p{^Is_Numeric_Value=0000003/00016}', "");
Expect(1, 43062, '\P{Is_Numeric_Value=0000003/00016}', "");
Expect(0, 43062, '\P{^Is_Numeric_Value=0000003/00016}', "");
Error('\p{Is_Numeric_Value=0.19}');
Error('\P{Is_Numeric_Value=0.19}');
Expect(1, 43061, '\p{Is_Numeric_Value=0.188}', "");
Expect(0, 43061, '\p{^Is_Numeric_Value=0.188}', "");
Expect(0, 43061, '\P{Is_Numeric_Value=0.188}', "");
Expect(1, 43061, '\P{^Is_Numeric_Value=0.188}', "");
Expect(0, 43062, '\p{Is_Numeric_Value=0.188}', "");
Expect(1, 43062, '\p{^Is_Numeric_Value=0.188}', "");
Expect(1, 43062, '\P{Is_Numeric_Value=0.188}', "");
Expect(0, 43062, '\P{^Is_Numeric_Value=0.188}', "");
Error('\p{Is_Nv=	0000003/016:=}');
Error('\P{Is_Nv=	0000003/016:=}');
Expect(1, 43061, '\p{Is_Nv=+0000003/00000016}', "");
Expect(0, 43061, '\p{^Is_Nv=+0000003/00000016}', "");
Expect(0, 43061, '\P{Is_Nv=+0000003/00000016}', "");
Expect(1, 43061, '\P{^Is_Nv=+0000003/00000016}', "");
Expect(0, 43062, '\p{Is_Nv=+0000003/00000016}', "");
Expect(1, 43062, '\p{^Is_Nv=+0000003/00000016}', "");
Expect(1, 43062, '\P{Is_Nv=+0000003/00000016}', "");
Expect(0, 43062, '\P{^Is_Nv=+0000003/00000016}', "");
Error('\p{Is_Nv=0.19}');
Error('\P{Is_Nv=0.19}');
Expect(1, 43061, '\p{Is_Nv=0.188}', "");
Expect(0, 43061, '\p{^Is_Nv=0.188}', "");
Expect(0, 43061, '\P{Is_Nv=0.188}', "");
Expect(1, 43061, '\P{^Is_Nv=0.188}', "");
Expect(0, 43062, '\p{Is_Nv=0.188}', "");
Expect(1, 43062, '\p{^Is_Nv=0.188}', "");
Expect(1, 43062, '\P{Is_Nv=0.188}', "");
Expect(0, 43062, '\P{^Is_Nv=0.188}', "");
Error('\p{Numeric_Value:		/a/00003/00000002}');
Error('\P{Numeric_Value:		/a/00003/00000002}');
Expect(1, 3883, '\p{Numeric_Value=0000003/2}', "");
Expect(0, 3883, '\p{^Numeric_Value=0000003/2}', "");
Expect(0, 3883, '\P{Numeric_Value=0000003/2}', "");
Expect(1, 3883, '\P{^Numeric_Value=0000003/2}', "");
Expect(0, 3884, '\p{Numeric_Value=0000003/2}', "");
Expect(1, 3884, '\p{^Numeric_Value=0000003/2}', "");
Expect(1, 3884, '\P{Numeric_Value=0000003/2}', "");
Expect(0, 3884, '\P{^Numeric_Value=0000003/2}', "");
Expect(1, 3883, '\p{Numeric_Value=1.500}', "");
Expect(0, 3883, '\p{^Numeric_Value=1.500}', "");
Expect(0, 3883, '\P{Numeric_Value=1.500}', "");
Expect(1, 3883, '\P{^Numeric_Value=1.500}', "");
Expect(0, 3884, '\p{Numeric_Value=1.500}', "");
Expect(1, 3884, '\p{^Numeric_Value=1.500}', "");
Expect(1, 3884, '\P{Numeric_Value=1.500}', "");
Expect(0, 3884, '\P{^Numeric_Value=1.500}', "");
Error('\p{Nv=	:=00003/0000000002}');
Error('\P{Nv=	:=00003/0000000002}');
Expect(1, 3883, '\p{Nv=00003/00000002}', "");
Expect(0, 3883, '\p{^Nv=00003/00000002}', "");
Expect(0, 3883, '\P{Nv=00003/00000002}', "");
Expect(1, 3883, '\P{^Nv=00003/00000002}', "");
Expect(0, 3884, '\p{Nv=00003/00000002}', "");
Expect(1, 3884, '\p{^Nv=00003/00000002}', "");
Expect(1, 3884, '\P{Nv=00003/00000002}', "");
Expect(0, 3884, '\P{^Nv=00003/00000002}', "");
Expect(1, 3883, '\p{Nv=1.500}', "");
Expect(0, 3883, '\p{^Nv=1.500}', "");
Expect(0, 3883, '\P{Nv=1.500}', "");
Expect(1, 3883, '\P{^Nv=1.500}', "");
Expect(0, 3884, '\p{Nv=1.500}', "");
Expect(1, 3884, '\p{^Nv=1.500}', "");
Expect(1, 3884, '\P{Nv=1.500}', "");
Expect(0, 3884, '\P{^Nv=1.500}', "");
Error('\p{Is_Numeric_Value=_ +00000003/02:=}');
Error('\P{Is_Numeric_Value=_ +00000003/02:=}');
Expect(1, 3883, '\p{Is_Numeric_Value=00003/2}', "");
Expect(0, 3883, '\p{^Is_Numeric_Value=00003/2}', "");
Expect(0, 3883, '\P{Is_Numeric_Value=00003/2}', "");
Expect(1, 3883, '\P{^Is_Numeric_Value=00003/2}', "");
Expect(0, 3884, '\p{Is_Numeric_Value=00003/2}', "");
Expect(1, 3884, '\p{^Is_Numeric_Value=00003/2}', "");
Expect(1, 3884, '\P{Is_Numeric_Value=00003/2}', "");
Expect(0, 3884, '\P{^Is_Numeric_Value=00003/2}', "");
Expect(1, 3883, '\p{Is_Numeric_Value=1.500}', "");
Expect(0, 3883, '\p{^Is_Numeric_Value=1.500}', "");
Expect(0, 3883, '\P{Is_Numeric_Value=1.500}', "");
Expect(1, 3883, '\P{^Is_Numeric_Value=1.500}', "");
Expect(0, 3884, '\p{Is_Numeric_Value=1.500}', "");
Expect(1, 3884, '\p{^Is_Numeric_Value=1.500}', "");
Expect(1, 3884, '\P{Is_Numeric_Value=1.500}', "");
Expect(0, 3884, '\P{^Is_Numeric_Value=1.500}', "");
Error('\p{Is_Nv=:=+0003/0000000002}');
Error('\P{Is_Nv=:=+0003/0000000002}');
Expect(1, 3883, '\p{Is_Nv=+00000003/0000000002}', "");
Expect(0, 3883, '\p{^Is_Nv=+00000003/0000000002}', "");
Expect(0, 3883, '\P{Is_Nv=+00000003/0000000002}', "");
Expect(1, 3883, '\P{^Is_Nv=+00000003/0000000002}', "");
Expect(0, 3884, '\p{Is_Nv=+00000003/0000000002}', "");
Expect(1, 3884, '\p{^Is_Nv=+00000003/0000000002}', "");
Expect(1, 3884, '\P{Is_Nv=+00000003/0000000002}', "");
Expect(0, 3884, '\P{^Is_Nv=+00000003/0000000002}', "");
Expect(1, 3883, '\p{Is_Nv=1.500}', "");
Expect(0, 3883, '\p{^Is_Nv=1.500}', "");
Expect(0, 3883, '\P{Is_Nv=1.500}', "");
Expect(1, 3883, '\P{^Is_Nv=1.500}', "");
Expect(0, 3884, '\p{Is_Nv=1.500}', "");
Expect(1, 3884, '\p{^Is_Nv=1.500}', "");
Expect(1, 3884, '\P{Is_Nv=1.500}', "");
Expect(0, 3884, '\P{^Is_Nv=1.500}', "");
Error('\p{Numeric_Value=/a/+03/000000004}');
Error('\P{Numeric_Value=/a/+03/000000004}');
Expect(1, 65912, '\p{Numeric_Value=+03/0000004}', "");
Expect(0, 65912, '\p{^Numeric_Value=+03/0000004}', "");
Expect(0, 65912, '\P{Numeric_Value=+03/0000004}', "");
Expect(1, 65912, '\P{^Numeric_Value=+03/0000004}', "");
Expect(0, 65913, '\p{Numeric_Value=+03/0000004}', "");
Expect(1, 65913, '\p{^Numeric_Value=+03/0000004}', "");
Expect(1, 65913, '\P{Numeric_Value=+03/0000004}', "");
Expect(0, 65913, '\P{^Numeric_Value=+03/0000004}', "");
Expect(1, 65912, '\p{Numeric_Value=0.750}', "");
Expect(0, 65912, '\p{^Numeric_Value=0.750}', "");
Expect(0, 65912, '\P{Numeric_Value=0.750}', "");
Expect(1, 65912, '\P{^Numeric_Value=0.750}', "");
Expect(0, 65913, '\p{Numeric_Value=0.750}', "");
Expect(1, 65913, '\p{^Numeric_Value=0.750}', "");
Expect(1, 65913, '\P{Numeric_Value=0.750}', "");
Expect(0, 65913, '\P{^Numeric_Value=0.750}', "");
Error('\p{Nv=:=-0003/000004}');
Error('\P{Nv=:=-0003/000004}');
Expect(1, 65912, '\p{Nv=+0003/4}', "");
Expect(0, 65912, '\p{^Nv=+0003/4}', "");
Expect(0, 65912, '\P{Nv=+0003/4}', "");
Expect(1, 65912, '\P{^Nv=+0003/4}', "");
Expect(0, 65913, '\p{Nv=+0003/4}', "");
Expect(1, 65913, '\p{^Nv=+0003/4}', "");
Expect(1, 65913, '\P{Nv=+0003/4}', "");
Expect(0, 65913, '\P{^Nv=+0003/4}', "");
Expect(1, 65912, '\p{Nv=0.750}', "");
Expect(0, 65912, '\p{^Nv=0.750}', "");
Expect(0, 65912, '\P{Nv=0.750}', "");
Expect(1, 65912, '\P{^Nv=0.750}', "");
Expect(0, 65913, '\p{Nv=0.750}', "");
Expect(1, 65913, '\p{^Nv=0.750}', "");
Expect(1, 65913, '\P{Nv=0.750}', "");
Expect(0, 65913, '\P{^Nv=0.750}', "");
Error('\p{Is_Numeric_Value=	 +000003/0004:=}');
Error('\P{Is_Numeric_Value=	 +000003/0004:=}');
Expect(1, 65912, '\p{Is_Numeric_Value=0003/04}', "");
Expect(0, 65912, '\p{^Is_Numeric_Value=0003/04}', "");
Expect(0, 65912, '\P{Is_Numeric_Value=0003/04}', "");
Expect(1, 65912, '\P{^Is_Numeric_Value=0003/04}', "");
Expect(0, 65913, '\p{Is_Numeric_Value=0003/04}', "");
Expect(1, 65913, '\p{^Is_Numeric_Value=0003/04}', "");
Expect(1, 65913, '\P{Is_Numeric_Value=0003/04}', "");
Expect(0, 65913, '\P{^Is_Numeric_Value=0003/04}', "");
Expect(1, 65912, '\p{Is_Numeric_Value=0.750}', "");
Expect(0, 65912, '\p{^Is_Numeric_Value=0.750}', "");
Expect(0, 65912, '\P{Is_Numeric_Value=0.750}', "");
Expect(1, 65912, '\P{^Is_Numeric_Value=0.750}', "");
Expect(0, 65913, '\p{Is_Numeric_Value=0.750}', "");
Expect(1, 65913, '\p{^Is_Numeric_Value=0.750}', "");
Expect(1, 65913, '\P{Is_Numeric_Value=0.750}', "");
Expect(0, 65913, '\P{^Is_Numeric_Value=0.750}', "");
Error('\p{Is_Nv=/a/	 000000003/004}');
Error('\P{Is_Nv=/a/	 000000003/004}');
Expect(1, 65912, '\p{Is_Nv:	000003/04}', "");
Expect(0, 65912, '\p{^Is_Nv:	000003/04}', "");
Expect(0, 65912, '\P{Is_Nv:	000003/04}', "");
Expect(1, 65912, '\P{^Is_Nv:	000003/04}', "");
Expect(0, 65913, '\p{Is_Nv:	000003/04}', "");
Expect(1, 65913, '\p{^Is_Nv:	000003/04}', "");
Expect(1, 65913, '\P{Is_Nv:	000003/04}', "");
Expect(0, 65913, '\P{^Is_Nv:	000003/04}', "");
Expect(1, 65912, '\p{Is_Nv=0.750}', "");
Expect(0, 65912, '\p{^Is_Nv=0.750}', "");
Expect(0, 65912, '\P{Is_Nv=0.750}', "");
Expect(1, 65912, '\P{^Is_Nv=0.750}', "");
Expect(0, 65913, '\p{Is_Nv=0.750}', "");
Expect(1, 65913, '\p{^Is_Nv=0.750}', "");
Expect(1, 65913, '\P{Is_Nv=0.750}', "");
Expect(0, 65913, '\P{^Is_Nv=0.750}', "");
Error('\p{Numeric_Value=-:=+000003/000000005}');
Error('\P{Numeric_Value=-:=+000003/000000005}');
Expect(1, 8535, '\p{Numeric_Value=0000003/00000005}', "");
Expect(0, 8535, '\p{^Numeric_Value=0000003/00000005}', "");
Expect(0, 8535, '\P{Numeric_Value=0000003/00000005}', "");
Expect(1, 8535, '\P{^Numeric_Value=0000003/00000005}', "");
Expect(0, 8536, '\p{Numeric_Value=0000003/00000005}', "");
Expect(1, 8536, '\p{^Numeric_Value=0000003/00000005}', "");
Expect(1, 8536, '\P{Numeric_Value=0000003/00000005}', "");
Expect(0, 8536, '\P{^Numeric_Value=0000003/00000005}', "");
Expect(1, 8535, '\p{Numeric_Value=0.600}', "");
Expect(0, 8535, '\p{^Numeric_Value=0.600}', "");
Expect(0, 8535, '\P{Numeric_Value=0.600}', "");
Expect(1, 8535, '\P{^Numeric_Value=0.600}', "");
Expect(0, 8536, '\p{Numeric_Value=0.600}', "");
Expect(1, 8536, '\p{^Numeric_Value=0.600}', "");
Expect(1, 8536, '\P{Numeric_Value=0.600}', "");
Expect(0, 8536, '\P{^Numeric_Value=0.600}', "");
Error('\p{Nv=_000000003/00005:=}');
Error('\P{Nv=_000000003/00005:=}');
Expect(1, 8535, '\p{Nv=0003/000000005}', "");
Expect(0, 8535, '\p{^Nv=0003/000000005}', "");
Expect(0, 8535, '\P{Nv=0003/000000005}', "");
Expect(1, 8535, '\P{^Nv=0003/000000005}', "");
Expect(0, 8536, '\p{Nv=0003/000000005}', "");
Expect(1, 8536, '\p{^Nv=0003/000000005}', "");
Expect(1, 8536, '\P{Nv=0003/000000005}', "");
Expect(0, 8536, '\P{^Nv=0003/000000005}', "");
Expect(1, 8535, '\p{Nv=0.600}', "");
Expect(0, 8535, '\p{^Nv=0.600}', "");
Expect(0, 8535, '\P{Nv=0.600}', "");
Expect(1, 8535, '\P{^Nv=0.600}', "");
Expect(0, 8536, '\p{Nv=0.600}', "");
Expect(1, 8536, '\p{^Nv=0.600}', "");
Expect(1, 8536, '\P{Nv=0.600}', "");
Expect(0, 8536, '\P{^Nv=0.600}', "");
Error('\p{Is_Numeric_Value=:=_ 00003/0000005}');
Error('\P{Is_Numeric_Value=:=_ 00003/0000005}');
Expect(1, 8535, '\p{Is_Numeric_Value: +00000003/00000005}', "");
Expect(0, 8535, '\p{^Is_Numeric_Value: +00000003/00000005}', "");
Expect(0, 8535, '\P{Is_Numeric_Value: +00000003/00000005}', "");
Expect(1, 8535, '\P{^Is_Numeric_Value: +00000003/00000005}', "");
Expect(0, 8536, '\p{Is_Numeric_Value: +00000003/00000005}', "");
Expect(1, 8536, '\p{^Is_Numeric_Value: +00000003/00000005}', "");
Expect(1, 8536, '\P{Is_Numeric_Value: +00000003/00000005}', "");
Expect(0, 8536, '\P{^Is_Numeric_Value: +00000003/00000005}', "");
Expect(1, 8535, '\p{Is_Numeric_Value=0.600}', "");
Expect(0, 8535, '\p{^Is_Numeric_Value=0.600}', "");
Expect(0, 8535, '\P{Is_Numeric_Value=0.600}', "");
Expect(1, 8535, '\P{^Is_Numeric_Value=0.600}', "");
Expect(0, 8536, '\p{Is_Numeric_Value=0.600}', "");
Expect(1, 8536, '\p{^Is_Numeric_Value=0.600}', "");
Expect(1, 8536, '\P{Is_Numeric_Value=0.600}', "");
Expect(0, 8536, '\P{^Is_Numeric_Value=0.600}', "");
Error('\p{Is_Nv=:= +003/05}');
Error('\P{Is_Nv=:= +003/05}');
Expect(1, 8535, '\p{Is_Nv=0000003/0005}', "");
Expect(0, 8535, '\p{^Is_Nv=0000003/0005}', "");
Expect(0, 8535, '\P{Is_Nv=0000003/0005}', "");
Expect(1, 8535, '\P{^Is_Nv=0000003/0005}', "");
Expect(0, 8536, '\p{Is_Nv=0000003/0005}', "");
Expect(1, 8536, '\p{^Is_Nv=0000003/0005}', "");
Expect(1, 8536, '\P{Is_Nv=0000003/0005}', "");
Expect(0, 8536, '\P{^Is_Nv=0000003/0005}', "");
Expect(1, 8535, '\p{Is_Nv=0.600}', "");
Expect(0, 8535, '\p{^Is_Nv=0.600}', "");
Expect(0, 8535, '\P{Is_Nv=0.600}', "");
Expect(1, 8535, '\P{^Is_Nv=0.600}', "");
Expect(0, 8536, '\p{Is_Nv=0.600}', "");
Expect(1, 8536, '\p{^Is_Nv=0.600}', "");
Expect(1, 8536, '\P{Is_Nv=0.600}', "");
Expect(0, 8536, '\P{^Is_Nv=0.600}', "");
Error('\p{Numeric_Value=_/a/000003/000000008}');
Error('\P{Numeric_Value=_/a/000003/000000008}');
Expect(1, 8540, '\p{Numeric_Value=00000003/0008}', "");
Expect(0, 8540, '\p{^Numeric_Value=00000003/0008}', "");
Expect(0, 8540, '\P{Numeric_Value=00000003/0008}', "");
Expect(1, 8540, '\P{^Numeric_Value=00000003/0008}', "");
Expect(0, 8541, '\p{Numeric_Value=00000003/0008}', "");
Expect(1, 8541, '\p{^Numeric_Value=00000003/0008}', "");
Expect(1, 8541, '\P{Numeric_Value=00000003/0008}', "");
Expect(0, 8541, '\P{^Numeric_Value=00000003/0008}', "");
Error('\p{Numeric_Value: 0.38}');
Error('\P{Numeric_Value: 0.38}');
Expect(1, 8540, '\p{Numeric_Value=0.375}', "");
Expect(0, 8540, '\p{^Numeric_Value=0.375}', "");
Expect(0, 8540, '\P{Numeric_Value=0.375}', "");
Expect(1, 8540, '\P{^Numeric_Value=0.375}', "");
Expect(0, 8541, '\p{Numeric_Value=0.375}', "");
Expect(1, 8541, '\p{^Numeric_Value=0.375}', "");
Expect(1, 8541, '\P{Numeric_Value=0.375}', "");
Expect(0, 8541, '\P{^Numeric_Value=0.375}', "");
Error('\p{Nv=	00000003/008:=}');
Error('\P{Nv=	00000003/008:=}');
Expect(1, 8540, '\p{Nv=3/000000008}', "");
Expect(0, 8540, '\p{^Nv=3/000000008}', "");
Expect(0, 8540, '\P{Nv=3/000000008}', "");
Expect(1, 8540, '\P{^Nv=3/000000008}', "");
Expect(0, 8541, '\p{Nv=3/000000008}', "");
Expect(1, 8541, '\p{^Nv=3/000000008}', "");
Expect(1, 8541, '\P{Nv=3/000000008}', "");
Expect(0, 8541, '\P{^Nv=3/000000008}', "");
Error('\p{Nv=0.38}');
Error('\P{Nv=0.38}');
Expect(1, 8540, '\p{Nv=0.375}', "");
Expect(0, 8540, '\p{^Nv=0.375}', "");
Expect(0, 8540, '\P{Nv=0.375}', "");
Expect(1, 8540, '\P{^Nv=0.375}', "");
Expect(0, 8541, '\p{Nv=0.375}', "");
Expect(1, 8541, '\p{^Nv=0.375}', "");
Expect(1, 8541, '\P{Nv=0.375}', "");
Expect(0, 8541, '\P{^Nv=0.375}', "");
Error('\p{Is_Numeric_Value=-	+03/08:=}');
Error('\P{Is_Numeric_Value=-	+03/08:=}');
Expect(1, 8540, '\p{Is_Numeric_Value:	000000003/0000008}', "");
Expect(0, 8540, '\p{^Is_Numeric_Value:	000000003/0000008}', "");
Expect(0, 8540, '\P{Is_Numeric_Value:	000000003/0000008}', "");
Expect(1, 8540, '\P{^Is_Numeric_Value:	000000003/0000008}', "");
Expect(0, 8541, '\p{Is_Numeric_Value:	000000003/0000008}', "");
Expect(1, 8541, '\p{^Is_Numeric_Value:	000000003/0000008}', "");
Expect(1, 8541, '\P{Is_Numeric_Value:	000000003/0000008}', "");
Expect(0, 8541, '\P{^Is_Numeric_Value:	000000003/0000008}', "");
Error('\p{Is_Numeric_Value=0.38}');
Error('\P{Is_Numeric_Value=0.38}');
Expect(1, 8540, '\p{Is_Numeric_Value: 0.375}', "");
Expect(0, 8540, '\p{^Is_Numeric_Value: 0.375}', "");
Expect(0, 8540, '\P{Is_Numeric_Value: 0.375}', "");
Expect(1, 8540, '\P{^Is_Numeric_Value: 0.375}', "");
Expect(0, 8541, '\p{Is_Numeric_Value: 0.375}', "");
Expect(1, 8541, '\p{^Is_Numeric_Value: 0.375}', "");
Expect(1, 8541, '\P{Is_Numeric_Value: 0.375}', "");
Expect(0, 8541, '\P{^Is_Numeric_Value: 0.375}', "");
Error('\p{Is_Nv:-	+03/8/a/}');
Error('\P{Is_Nv:-	+03/8/a/}');
Expect(1, 8540, '\p{Is_Nv=00003/08}', "");
Expect(0, 8540, '\p{^Is_Nv=00003/08}', "");
Expect(0, 8540, '\P{Is_Nv=00003/08}', "");
Expect(1, 8540, '\P{^Is_Nv=00003/08}', "");
Expect(0, 8541, '\p{Is_Nv=00003/08}', "");
Expect(1, 8541, '\p{^Is_Nv=00003/08}', "");
Expect(1, 8541, '\P{Is_Nv=00003/08}', "");
Expect(0, 8541, '\P{^Is_Nv=00003/08}', "");
Error('\p{Is_Nv:0.38}');
Error('\P{Is_Nv:0.38}');
Expect(1, 8540, '\p{Is_Nv=0.375}', "");
Expect(0, 8540, '\p{^Is_Nv=0.375}', "");
Expect(0, 8540, '\P{Is_Nv=0.375}', "");
Expect(1, 8540, '\P{^Is_Nv=0.375}', "");
Expect(0, 8541, '\p{Is_Nv=0.375}', "");
Expect(1, 8541, '\p{^Is_Nv=0.375}', "");
Expect(1, 8541, '\P{Is_Nv=0.375}', "");
Expect(0, 8541, '\P{^Is_Nv=0.375}', "");
Error('\p{Numeric_Value=/a/ -030}');
Error('\P{Numeric_Value=/a/ -030}');
Expect(1, 133507, '\p{Numeric_Value=+0_0_0_0_0_0_0_0030}', "");
Expect(0, 133507, '\p{^Numeric_Value=+0_0_0_0_0_0_0_0030}', "");
Expect(0, 133507, '\P{Numeric_Value=+0_0_0_0_0_0_0_0030}', "");
Expect(1, 133507, '\P{^Numeric_Value=+0_0_0_0_0_0_0_0030}', "");
Expect(0, 133508, '\p{Numeric_Value=+0_0_0_0_0_0_0_0030}', "");
Expect(1, 133508, '\p{^Numeric_Value=+0_0_0_0_0_0_0_0030}', "");
Expect(1, 133508, '\P{Numeric_Value=+0_0_0_0_0_0_0_0030}', "");
Expect(0, 133508, '\P{^Numeric_Value=+0_0_0_0_0_0_0_0030}', "");
Error('\p{Nv=_:=+00_00_03_0}');
Error('\P{Nv=_:=+00_00_03_0}');
Expect(1, 133507, '\p{Nv: 00_00_30}', "");
Expect(0, 133507, '\p{^Nv: 00_00_30}', "");
Expect(0, 133507, '\P{Nv: 00_00_30}', "");
Expect(1, 133507, '\P{^Nv: 00_00_30}', "");
Expect(0, 133508, '\p{Nv: 00_00_30}', "");
Expect(1, 133508, '\p{^Nv: 00_00_30}', "");
Expect(1, 133508, '\P{Nv: 00_00_30}', "");
Expect(0, 133508, '\P{^Nv: 00_00_30}', "");
Error('\p{Is_Numeric_Value=/a/__00003_0}');
Error('\P{Is_Numeric_Value=/a/__00003_0}');
Expect(1, 133507, '\p{Is_Numeric_Value=+0_0_0_030}', "");
Expect(0, 133507, '\p{^Is_Numeric_Value=+0_0_0_030}', "");
Expect(0, 133507, '\P{Is_Numeric_Value=+0_0_0_030}', "");
Expect(1, 133507, '\P{^Is_Numeric_Value=+0_0_0_030}', "");
Expect(0, 133508, '\p{Is_Numeric_Value=+0_0_0_030}', "");
Expect(1, 133508, '\p{^Is_Numeric_Value=+0_0_0_030}', "");
Expect(1, 133508, '\P{Is_Numeric_Value=+0_0_0_030}', "");
Expect(0, 133508, '\P{^Is_Numeric_Value=+0_0_0_030}', "");
Error('\p{Is_Nv:	_:=0030}');
Error('\P{Is_Nv:	_:=0030}');
Expect(1, 133507, '\p{Is_Nv: 00_00_00_30}', "");
Expect(0, 133507, '\p{^Is_Nv: 00_00_00_30}', "");
Expect(0, 133507, '\P{Is_Nv: 00_00_00_30}', "");
Expect(1, 133507, '\P{^Is_Nv: 00_00_00_30}', "");
Expect(0, 133508, '\p{Is_Nv: 00_00_00_30}', "");
Expect(1, 133508, '\p{^Is_Nv: 00_00_00_30}', "");
Expect(1, 133508, '\P{Is_Nv: 00_00_00_30}', "");
Expect(0, 133508, '\P{^Is_Nv: 00_00_00_30}', "");
Error('\p{Numeric_Value=:=  00000000300}');
Error('\P{Numeric_Value=:=  00000000300}');
Expect(1, 69236, '\p{Numeric_Value=300}', "");
Expect(0, 69236, '\p{^Numeric_Value=300}', "");
Expect(0, 69236, '\P{Numeric_Value=300}', "");
Expect(1, 69236, '\P{^Numeric_Value=300}', "");
Expect(0, 69237, '\p{Numeric_Value=300}', "");
Expect(1, 69237, '\p{^Numeric_Value=300}', "");
Expect(1, 69237, '\P{Numeric_Value=300}', "");
Expect(0, 69237, '\P{^Numeric_Value=300}', "");
Error('\p{Nv=:=- +000000300}');
Error('\P{Nv=:=- +000000300}');
Expect(1, 69236, '\p{Nv=+000_003_00}', "");
Expect(0, 69236, '\p{^Nv=+000_003_00}', "");
Expect(0, 69236, '\P{Nv=+000_003_00}', "");
Expect(1, 69236, '\P{^Nv=+000_003_00}', "");
Expect(0, 69237, '\p{Nv=+000_003_00}', "");
Expect(1, 69237, '\p{^Nv=+000_003_00}', "");
Expect(1, 69237, '\P{Nv=+000_003_00}', "");
Expect(0, 69237, '\P{^Nv=+000_003_00}', "");
Error('\p{Is_Numeric_Value: :=00300}');
Error('\P{Is_Numeric_Value: :=00300}');
Expect(1, 69236, '\p{Is_Numeric_Value=00030_0}', "");
Expect(0, 69236, '\p{^Is_Numeric_Value=00030_0}', "");
Expect(0, 69236, '\P{Is_Numeric_Value=00030_0}', "");
Expect(1, 69236, '\P{^Is_Numeric_Value=00030_0}', "");
Expect(0, 69237, '\p{Is_Numeric_Value=00030_0}', "");
Expect(1, 69237, '\p{^Is_Numeric_Value=00030_0}', "");
Expect(1, 69237, '\P{Is_Numeric_Value=00030_0}', "");
Expect(0, 69237, '\P{^Is_Numeric_Value=00030_0}', "");
Error('\p{Is_Nv=/a/-0000_0030_0}');
Error('\P{Is_Nv=/a/-0000_0030_0}');
Expect(1, 69236, '\p{Is_Nv=+0000000300}', "");
Expect(0, 69236, '\p{^Is_Nv=+0000000300}', "");
Expect(0, 69236, '\P{Is_Nv=+0000000300}', "");
Expect(1, 69236, '\P{^Is_Nv=+0000000300}', "");
Expect(0, 69237, '\p{Is_Nv=+0000000300}', "");
Expect(1, 69237, '\p{^Is_Nv=+0000000300}', "");
Expect(1, 69237, '\P{Is_Nv=+0000000300}', "");
Expect(0, 69237, '\P{^Is_Nv=+0000000300}', "");
Error('\p{Numeric_Value=_ +03_00_0/a/}');
Error('\P{Numeric_Value=_ +03_00_0/a/}');
Expect(1, 65828, '\p{Numeric_Value=+003000}', "");
Expect(0, 65828, '\p{^Numeric_Value=+003000}', "");
Expect(0, 65828, '\P{Numeric_Value=+003000}', "");
Expect(1, 65828, '\P{^Numeric_Value=+003000}', "");
Expect(0, 65829, '\p{Numeric_Value=+003000}', "");
Expect(1, 65829, '\p{^Numeric_Value=+003000}', "");
Expect(1, 65829, '\P{Numeric_Value=+003000}', "");
Expect(0, 65829, '\P{^Numeric_Value=+003000}', "");
Error('\p{Nv=/a/  +00000003000}');
Error('\P{Nv=/a/  +00000003000}');
Expect(1, 65828, '\p{Nv=0_0_0_0_3_000}', "");
Expect(0, 65828, '\p{^Nv=0_0_0_0_3_000}', "");
Expect(0, 65828, '\P{Nv=0_0_0_0_3_000}', "");
Expect(1, 65828, '\P{^Nv=0_0_0_0_3_000}', "");
Expect(0, 65829, '\p{Nv=0_0_0_0_3_000}', "");
Expect(1, 65829, '\p{^Nv=0_0_0_0_3_000}', "");
Expect(1, 65829, '\P{Nv=0_0_0_0_3_000}', "");
Expect(0, 65829, '\P{^Nv=0_0_0_0_3_000}', "");
Error('\p{Is_Numeric_Value=/a/ 0_0_0_0_0_0_0_0_03000}');
Error('\P{Is_Numeric_Value=/a/ 0_0_0_0_0_0_0_0_03000}');
Expect(1, 65828, '\p{Is_Numeric_Value=+00003000}', "");
Expect(0, 65828, '\p{^Is_Numeric_Value=+00003000}', "");
Expect(0, 65828, '\P{Is_Numeric_Value=+00003000}', "");
Expect(1, 65828, '\P{^Is_Numeric_Value=+00003000}', "");
Expect(0, 65829, '\p{Is_Numeric_Value=+00003000}', "");
Expect(1, 65829, '\p{^Is_Numeric_Value=+00003000}', "");
Expect(1, 65829, '\P{Is_Numeric_Value=+00003000}', "");
Expect(0, 65829, '\P{^Is_Numeric_Value=+00003000}', "");
Error('\p{Is_Nv=:=_ +00003000}');
Error('\P{Is_Nv=:=_ +00003000}');
Expect(1, 65828, '\p{Is_Nv=300_0}', "");
Expect(0, 65828, '\p{^Is_Nv=300_0}', "");
Expect(0, 65828, '\P{Is_Nv=300_0}', "");
Expect(1, 65828, '\P{^Is_Nv=300_0}', "");
Expect(0, 65829, '\p{Is_Nv=300_0}', "");
Expect(1, 65829, '\p{^Is_Nv=300_0}', "");
Expect(1, 65829, '\P{Is_Nv=300_0}', "");
Expect(0, 65829, '\P{^Is_Nv=300_0}', "");
Error('\p{Numeric_Value=-0_0_0_0_0_0_0_3_0_000:=}');
Error('\P{Numeric_Value=-0_0_0_0_0_0_0_3_0_000:=}');
Expect(1, 65837, '\p{Numeric_Value=0_0_0_0_0_0_0_0_3_0_000}', "");
Expect(0, 65837, '\p{^Numeric_Value=0_0_0_0_0_0_0_0_3_0_000}', "");
Expect(0, 65837, '\P{Numeric_Value=0_0_0_0_0_0_0_0_3_0_000}', "");
Expect(1, 65837, '\P{^Numeric_Value=0_0_0_0_0_0_0_0_3_0_000}', "");
Expect(0, 65838, '\p{Numeric_Value=0_0_0_0_0_0_0_0_3_0_000}', "");
Expect(1, 65838, '\p{^Numeric_Value=0_0_0_0_0_0_0_0_3_0_000}', "");
Expect(1, 65838, '\P{Numeric_Value=0_0_0_0_0_0_0_0_3_0_000}', "");
Expect(0, 65838, '\P{^Numeric_Value=0_0_0_0_0_0_0_0_3_0_000}', "");
Error('\p{Nv=:=000030000}');
Error('\P{Nv=:=000030000}');
Expect(1, 65837, '\p{Nv=+3_0_0_00}', "");
Expect(0, 65837, '\p{^Nv=+3_0_0_00}', "");
Expect(0, 65837, '\P{Nv=+3_0_0_00}', "");
Expect(1, 65837, '\P{^Nv=+3_0_0_00}', "");
Expect(0, 65838, '\p{Nv=+3_0_0_00}', "");
Expect(1, 65838, '\p{^Nv=+3_0_0_00}', "");
Expect(1, 65838, '\P{Nv=+3_0_0_00}', "");
Expect(0, 65838, '\P{^Nv=+3_0_0_00}', "");
Error('\p{Is_Numeric_Value=	:=0030000}');
Error('\P{Is_Numeric_Value=	:=0030000}');
Expect(1, 65837, '\p{Is_Numeric_Value: 030000}', "");
Expect(0, 65837, '\p{^Is_Numeric_Value: 030000}', "");
Expect(0, 65837, '\P{Is_Numeric_Value: 030000}', "");
Expect(1, 65837, '\P{^Is_Numeric_Value: 030000}', "");
Expect(0, 65838, '\p{Is_Numeric_Value: 030000}', "");
Expect(1, 65838, '\p{^Is_Numeric_Value: 030000}', "");
Expect(1, 65838, '\P{Is_Numeric_Value: 030000}', "");
Expect(0, 65838, '\P{^Is_Numeric_Value: 030000}', "");
Error('\p{Is_Nv=:=- +00030000}');
Error('\P{Is_Nv=:=- +00030000}');
Expect(1, 65837, '\p{Is_Nv=000_000_300_00}', "");
Expect(0, 65837, '\p{^Is_Nv=000_000_300_00}', "");
Expect(0, 65837, '\P{Is_Nv=000_000_300_00}', "");
Expect(1, 65837, '\P{^Is_Nv=000_000_300_00}', "");
Expect(0, 65838, '\p{Is_Nv=000_000_300_00}', "");
Expect(1, 65838, '\p{^Is_Nv=000_000_300_00}', "");
Expect(1, 65838, '\P{Is_Nv=000_000_300_00}', "");
Expect(0, 65838, '\P{^Is_Nv=000_000_300_00}', "");
Error('\p{Numeric_Value=/a/ _031}');
Error('\P{Numeric_Value=/a/ _031}');
Expect(1, 12891, '\p{Numeric_Value=0_0_31}', "");
Expect(0, 12891, '\p{^Numeric_Value=0_0_31}', "");
Expect(0, 12891, '\P{Numeric_Value=0_0_31}', "");
Expect(1, 12891, '\P{^Numeric_Value=0_0_31}', "");
Expect(0, 12892, '\p{Numeric_Value=0_0_31}', "");
Expect(1, 12892, '\p{^Numeric_Value=0_0_31}', "");
Expect(1, 12892, '\P{Numeric_Value=0_0_31}', "");
Expect(0, 12892, '\P{^Numeric_Value=0_0_31}', "");
Error('\p{Nv=	03_1/a/}');
Error('\P{Nv=	03_1/a/}');
Expect(1, 12891, '\p{Nv=00_00_00_00_031}', "");
Expect(0, 12891, '\p{^Nv=00_00_00_00_031}', "");
Expect(0, 12891, '\P{Nv=00_00_00_00_031}', "");
Expect(1, 12891, '\P{^Nv=00_00_00_00_031}', "");
Expect(0, 12892, '\p{Nv=00_00_00_00_031}', "");
Expect(1, 12892, '\p{^Nv=00_00_00_00_031}', "");
Expect(1, 12892, '\P{Nv=00_00_00_00_031}', "");
Expect(0, 12892, '\P{^Nv=00_00_00_00_031}', "");
Error('\p{Is_Numeric_Value= :=000031}');
Error('\P{Is_Numeric_Value= :=000031}');
Expect(1, 12891, '\p{Is_Numeric_Value=0000031}', "");
Expect(0, 12891, '\p{^Is_Numeric_Value=0000031}', "");
Expect(0, 12891, '\P{Is_Numeric_Value=0000031}', "");
Expect(1, 12891, '\P{^Is_Numeric_Value=0000031}', "");
Expect(0, 12892, '\p{Is_Numeric_Value=0000031}', "");
Expect(1, 12892, '\p{^Is_Numeric_Value=0000031}', "");
Expect(1, 12892, '\P{Is_Numeric_Value=0000031}', "");
Expect(0, 12892, '\P{^Is_Numeric_Value=0000031}', "");
Error('\p{Is_Nv=/a/		+0_0_0_0_0_0_031}');
Error('\P{Is_Nv=/a/		+0_0_0_0_0_0_031}');
Expect(1, 12891, '\p{Is_Nv=0031}', "");
Expect(0, 12891, '\p{^Is_Nv=0031}', "");
Expect(0, 12891, '\P{Is_Nv=0031}', "");
Expect(1, 12891, '\P{^Is_Nv=0031}', "");
Expect(0, 12892, '\p{Is_Nv=0031}', "");
Expect(1, 12892, '\p{^Is_Nv=0031}', "");
Expect(1, 12892, '\P{Is_Nv=0031}', "");
Expect(0, 12892, '\P{^Is_Nv=0031}', "");
Error('\p{Numeric_Value=-:=0032}');
Error('\P{Numeric_Value=-:=0032}');
Expect(1, 12892, '\p{Numeric_Value=0000_0003_2}', "");
Expect(0, 12892, '\p{^Numeric_Value=0000_0003_2}', "");
Expect(0, 12892, '\P{Numeric_Value=0000_0003_2}', "");
Expect(1, 12892, '\P{^Numeric_Value=0000_0003_2}', "");
Expect(0, 12893, '\p{Numeric_Value=0000_0003_2}', "");
Expect(1, 12893, '\p{^Numeric_Value=0000_0003_2}', "");
Expect(1, 12893, '\P{Numeric_Value=0000_0003_2}', "");
Expect(0, 12893, '\P{^Numeric_Value=0000_0003_2}', "");
Error('\p{Nv: - 0000000032:=}');
Error('\P{Nv: - 0000000032:=}');
Expect(1, 12892, '\p{Nv=+000032}', "");
Expect(0, 12892, '\p{^Nv=+000032}', "");
Expect(0, 12892, '\P{Nv=+000032}', "");
Expect(1, 12892, '\P{^Nv=+000032}', "");
Expect(0, 12893, '\p{Nv=+000032}', "");
Expect(1, 12893, '\p{^Nv=+000032}', "");
Expect(1, 12893, '\P{Nv=+000032}', "");
Expect(0, 12893, '\P{^Nv=+000032}', "");
Error('\p{Is_Numeric_Value=_/a/0_0_0_0_32}');
Error('\P{Is_Numeric_Value=_/a/0_0_0_0_32}');
Expect(1, 12892, '\p{Is_Numeric_Value=+000000032}', "");
Expect(0, 12892, '\p{^Is_Numeric_Value=+000000032}', "");
Expect(0, 12892, '\P{Is_Numeric_Value=+000000032}', "");
Expect(1, 12892, '\P{^Is_Numeric_Value=+000000032}', "");
Expect(0, 12893, '\p{Is_Numeric_Value=+000000032}', "");
Expect(1, 12893, '\p{^Is_Numeric_Value=+000000032}', "");
Expect(1, 12893, '\P{Is_Numeric_Value=+000000032}', "");
Expect(0, 12893, '\P{^Is_Numeric_Value=+000000032}', "");
Error('\p{Is_Nv=	/a/0_0_0_0_0_0_0_0032}');
Error('\P{Is_Nv=	/a/0_0_0_0_0_0_0_0032}');
Expect(1, 12892, '\p{Is_Nv:0_0_0_0_0_0_32}', "");
Expect(0, 12892, '\p{^Is_Nv:0_0_0_0_0_0_32}', "");
Expect(0, 12892, '\P{Is_Nv:0_0_0_0_0_0_32}', "");
Expect(1, 12892, '\P{^Is_Nv:0_0_0_0_0_0_32}', "");
Expect(0, 12893, '\p{Is_Nv:0_0_0_0_0_0_32}', "");
Expect(1, 12893, '\p{^Is_Nv:0_0_0_0_0_0_32}', "");
Expect(1, 12893, '\P{Is_Nv:0_0_0_0_0_0_32}', "");
Expect(0, 12893, '\P{^Is_Nv:0_0_0_0_0_0_32}', "");
Error('\p{Numeric_Value=:=  +0000033}');
Error('\P{Numeric_Value=:=  +0000033}');
Expect(1, 12893, '\p{Numeric_Value=003_3}', "");
Expect(0, 12893, '\p{^Numeric_Value=003_3}', "");
Expect(0, 12893, '\P{Numeric_Value=003_3}', "");
Expect(1, 12893, '\P{^Numeric_Value=003_3}', "");
Expect(0, 12894, '\p{Numeric_Value=003_3}', "");
Expect(1, 12894, '\p{^Numeric_Value=003_3}', "");
Expect(1, 12894, '\P{Numeric_Value=003_3}', "");
Expect(0, 12894, '\P{^Numeric_Value=003_3}', "");
Error('\p{Nv=	 0000_0003_3:=}');
Error('\P{Nv=	 0000_0003_3:=}');
Expect(1, 12893, '\p{Nv=0_0_0_0_0_0_0033}', "");
Expect(0, 12893, '\p{^Nv=0_0_0_0_0_0_0033}', "");
Expect(0, 12893, '\P{Nv=0_0_0_0_0_0_0033}', "");
Expect(1, 12893, '\P{^Nv=0_0_0_0_0_0_0033}', "");
Expect(0, 12894, '\p{Nv=0_0_0_0_0_0_0033}', "");
Expect(1, 12894, '\p{^Nv=0_0_0_0_0_0_0033}', "");
Expect(1, 12894, '\P{Nv=0_0_0_0_0_0_0033}', "");
Expect(0, 12894, '\P{^Nv=0_0_0_0_0_0_0033}', "");
Error('\p{Is_Numeric_Value= -+03_3:=}');
Error('\P{Is_Numeric_Value= -+03_3:=}');
Expect(1, 12893, '\p{Is_Numeric_Value:   000000033}', "");
Expect(0, 12893, '\p{^Is_Numeric_Value:   000000033}', "");
Expect(0, 12893, '\P{Is_Numeric_Value:   000000033}', "");
Expect(1, 12893, '\P{^Is_Numeric_Value:   000000033}', "");
Expect(0, 12894, '\p{Is_Numeric_Value:   000000033}', "");
Expect(1, 12894, '\p{^Is_Numeric_Value:   000000033}', "");
Expect(1, 12894, '\P{Is_Numeric_Value:   000000033}', "");
Expect(0, 12894, '\P{^Is_Numeric_Value:   000000033}', "");
Error('\p{Is_Nv=-/a/00_00_03_3}');
Error('\P{Is_Nv=-/a/00_00_03_3}');
Expect(1, 12893, '\p{Is_Nv:	+00033}', "");
Expect(0, 12893, '\p{^Is_Nv:	+00033}', "");
Expect(0, 12893, '\P{Is_Nv:	+00033}', "");
Expect(1, 12893, '\P{^Is_Nv:	+00033}', "");
Expect(0, 12894, '\p{Is_Nv:	+00033}', "");
Expect(1, 12894, '\p{^Is_Nv:	+00033}', "");
Expect(1, 12894, '\P{Is_Nv:	+00033}', "");
Expect(0, 12894, '\P{^Is_Nv:	+00033}', "");
Error('\p{Numeric_Value=:=-	3_4}');
Error('\P{Numeric_Value=:=-	3_4}');
Expect(1, 12894, '\p{Numeric_Value=000000034}', "");
Expect(0, 12894, '\p{^Numeric_Value=000000034}', "");
Expect(0, 12894, '\P{Numeric_Value=000000034}', "");
Expect(1, 12894, '\P{^Numeric_Value=000000034}', "");
Expect(0, 12895, '\p{Numeric_Value=000000034}', "");
Expect(1, 12895, '\p{^Numeric_Value=000000034}', "");
Expect(1, 12895, '\P{Numeric_Value=000000034}', "");
Expect(0, 12895, '\P{^Numeric_Value=000000034}', "");
Error('\p{Nv=:=	00003_4}');
Error('\P{Nv=:=	00003_4}');
Expect(1, 12894, '\p{Nv=0000034}', "");
Expect(0, 12894, '\p{^Nv=0000034}', "");
Expect(0, 12894, '\P{Nv=0000034}', "");
Expect(1, 12894, '\P{^Nv=0000034}', "");
Expect(0, 12895, '\p{Nv=0000034}', "");
Expect(1, 12895, '\p{^Nv=0000034}', "");
Expect(1, 12895, '\P{Nv=0000034}', "");
Expect(0, 12895, '\P{^Nv=0000034}', "");
Error('\p{Is_Numeric_Value=	00000034/a/}');
Error('\P{Is_Numeric_Value=	00000034/a/}');
Expect(1, 12894, '\p{Is_Numeric_Value=0000034}', "");
Expect(0, 12894, '\p{^Is_Numeric_Value=0000034}', "");
Expect(0, 12894, '\P{Is_Numeric_Value=0000034}', "");
Expect(1, 12894, '\P{^Is_Numeric_Value=0000034}', "");
Expect(0, 12895, '\p{Is_Numeric_Value=0000034}', "");
Expect(1, 12895, '\p{^Is_Numeric_Value=0000034}', "");
Expect(1, 12895, '\P{Is_Numeric_Value=0000034}', "");
Expect(0, 12895, '\P{^Is_Numeric_Value=0000034}', "");
Error('\p{Is_Nv=:=-00034}');
Error('\P{Is_Nv=:=-00034}');
Expect(1, 12894, '\p{Is_Nv=+000034}', "");
Expect(0, 12894, '\p{^Is_Nv=+000034}', "");
Expect(0, 12894, '\P{Is_Nv=+000034}', "");
Expect(1, 12894, '\P{^Is_Nv=+000034}', "");
Expect(0, 12895, '\p{Is_Nv=+000034}', "");
Expect(1, 12895, '\p{^Is_Nv=+000034}', "");
Expect(1, 12895, '\P{Is_Nv=+000034}', "");
Expect(0, 12895, '\P{^Is_Nv=+000034}', "");
Error('\p{Numeric_Value= _+000000035/a/}');
Error('\P{Numeric_Value= _+000000035/a/}');
Expect(1, 12895, '\p{Numeric_Value=0000035}', "");
Expect(0, 12895, '\p{^Numeric_Value=0000035}', "");
Expect(0, 12895, '\P{Numeric_Value=0000035}', "");
Expect(1, 12895, '\P{^Numeric_Value=0000035}', "");
Expect(0, 12896, '\p{Numeric_Value=0000035}', "");
Expect(1, 12896, '\p{^Numeric_Value=0000035}', "");
Expect(1, 12896, '\P{Numeric_Value=0000035}', "");
Expect(0, 12896, '\P{^Numeric_Value=0000035}', "");
Error('\p{Nv=_/a/+03_5}');
Error('\P{Nv=_/a/+03_5}');
Expect(1, 12895, '\p{Nv:   +0000_0003_5}', "");
Expect(0, 12895, '\p{^Nv:   +0000_0003_5}', "");
Expect(0, 12895, '\P{Nv:   +0000_0003_5}', "");
Expect(1, 12895, '\P{^Nv:   +0000_0003_5}', "");
Expect(0, 12896, '\p{Nv:   +0000_0003_5}', "");
Expect(1, 12896, '\p{^Nv:   +0000_0003_5}', "");
Expect(1, 12896, '\P{Nv:   +0000_0003_5}', "");
Expect(0, 12896, '\P{^Nv:   +0000_0003_5}', "");
Error('\p{Is_Numeric_Value:/a/- 0000000035}');
Error('\P{Is_Numeric_Value:/a/- 0000000035}');
Expect(1, 12895, '\p{Is_Numeric_Value=00000003_5}', "");
Expect(0, 12895, '\p{^Is_Numeric_Value=00000003_5}', "");
Expect(0, 12895, '\P{Is_Numeric_Value=00000003_5}', "");
Expect(1, 12895, '\P{^Is_Numeric_Value=00000003_5}', "");
Expect(0, 12896, '\p{Is_Numeric_Value=00000003_5}', "");
Expect(1, 12896, '\p{^Is_Numeric_Value=00000003_5}', "");
Expect(1, 12896, '\P{Is_Numeric_Value=00000003_5}', "");
Expect(0, 12896, '\P{^Is_Numeric_Value=00000003_5}', "");
Error('\p{Is_Nv=_-+000_003_5:=}');
Error('\P{Is_Nv=_-+000_003_5:=}');
Expect(1, 12895, '\p{Is_Nv=00000000035}', "");
Expect(0, 12895, '\p{^Is_Nv=00000000035}', "");
Expect(0, 12895, '\P{Is_Nv=00000000035}', "");
Expect(1, 12895, '\P{^Is_Nv=00000000035}', "");
Expect(0, 12896, '\p{Is_Nv=00000000035}', "");
Expect(1, 12896, '\p{^Is_Nv=00000000035}', "");
Expect(1, 12896, '\P{Is_Nv=00000000035}', "");
Expect(0, 12896, '\P{^Is_Nv=00000000035}', "");
Error('\p{Numeric_Value=-_0000_0003_6/a/}');
Error('\P{Numeric_Value=-_0000_0003_6/a/}');
Expect(1, 12977, '\p{Numeric_Value=03_6}', "");
Expect(0, 12977, '\p{^Numeric_Value=03_6}', "");
Expect(0, 12977, '\P{Numeric_Value=03_6}', "");
Expect(1, 12977, '\P{^Numeric_Value=03_6}', "");
Expect(0, 12978, '\p{Numeric_Value=03_6}', "");
Expect(1, 12978, '\p{^Numeric_Value=03_6}', "");
Expect(1, 12978, '\P{Numeric_Value=03_6}', "");
Expect(0, 12978, '\P{^Numeric_Value=03_6}', "");
Error('\p{Nv:   -:=0_0_0_0_0_0_0_0_036}');
Error('\P{Nv:   -:=0_0_0_0_0_0_0_0_036}');
Expect(1, 12977, '\p{Nv=00000000036}', "");
Expect(0, 12977, '\p{^Nv=00000000036}', "");
Expect(0, 12977, '\P{Nv=00000000036}', "");
Expect(1, 12977, '\P{^Nv=00000000036}', "");
Expect(0, 12978, '\p{Nv=00000000036}', "");
Expect(1, 12978, '\p{^Nv=00000000036}', "");
Expect(1, 12978, '\P{Nv=00000000036}', "");
Expect(0, 12978, '\P{^Nv=00000000036}', "");
Error('\p{Is_Numeric_Value=-+00000003_6:=}');
Error('\P{Is_Numeric_Value=-+00000003_6:=}');
Expect(1, 12977, '\p{Is_Numeric_Value=036}', "");
Expect(0, 12977, '\p{^Is_Numeric_Value=036}', "");
Expect(0, 12977, '\P{Is_Numeric_Value=036}', "");
Expect(1, 12977, '\P{^Is_Numeric_Value=036}', "");
Expect(0, 12978, '\p{Is_Numeric_Value=036}', "");
Expect(1, 12978, '\p{^Is_Numeric_Value=036}', "");
Expect(1, 12978, '\P{Is_Numeric_Value=036}', "");
Expect(0, 12978, '\P{^Is_Numeric_Value=036}', "");
Error('\p{Is_Nv=/a/-000036}');
Error('\P{Is_Nv=/a/-000036}');
Expect(1, 12977, '\p{Is_Nv=03_6}', "");
Expect(0, 12977, '\p{^Is_Nv=03_6}', "");
Expect(0, 12977, '\P{Is_Nv=03_6}', "");
Expect(1, 12977, '\P{^Is_Nv=03_6}', "");
Expect(0, 12978, '\p{Is_Nv=03_6}', "");
Expect(1, 12978, '\p{^Is_Nv=03_6}', "");
Expect(1, 12978, '\P{Is_Nv=03_6}', "");
Expect(0, 12978, '\P{^Is_Nv=03_6}', "");
Error('\p{Numeric_Value= :=+00000003_7}');
Error('\P{Numeric_Value= :=+00000003_7}');
Expect(1, 12978, '\p{Numeric_Value=0003_7}', "");
Expect(0, 12978, '\p{^Numeric_Value=0003_7}', "");
Expect(0, 12978, '\P{Numeric_Value=0003_7}', "");
Expect(1, 12978, '\P{^Numeric_Value=0003_7}', "");
Expect(0, 12979, '\p{Numeric_Value=0003_7}', "");
Expect(1, 12979, '\p{^Numeric_Value=0003_7}', "");
Expect(1, 12979, '\P{Numeric_Value=0003_7}', "");
Expect(0, 12979, '\P{^Numeric_Value=0003_7}', "");
Error('\p{Nv=--+3_7/a/}');
Error('\P{Nv=--+3_7/a/}');
Expect(1, 12978, '\p{Nv=000_003_7}', "");
Expect(0, 12978, '\p{^Nv=000_003_7}', "");
Expect(0, 12978, '\P{Nv=000_003_7}', "");
Expect(1, 12978, '\P{^Nv=000_003_7}', "");
Expect(0, 12979, '\p{Nv=000_003_7}', "");
Expect(1, 12979, '\p{^Nv=000_003_7}', "");
Expect(1, 12979, '\P{Nv=000_003_7}', "");
Expect(0, 12979, '\P{^Nv=000_003_7}', "");
Error('\p{Is_Numeric_Value=:=+000003_7}');
Error('\P{Is_Numeric_Value=:=+000003_7}');
Expect(1, 12978, '\p{Is_Numeric_Value=+0_0_0_0_0_37}', "");
Expect(0, 12978, '\p{^Is_Numeric_Value=+0_0_0_0_0_37}', "");
Expect(0, 12978, '\P{Is_Numeric_Value=+0_0_0_0_0_37}', "");
Expect(1, 12978, '\P{^Is_Numeric_Value=+0_0_0_0_0_37}', "");
Expect(0, 12979, '\p{Is_Numeric_Value=+0_0_0_0_0_37}', "");
Expect(1, 12979, '\p{^Is_Numeric_Value=+0_0_0_0_0_37}', "");
Expect(1, 12979, '\P{Is_Numeric_Value=+0_0_0_0_0_37}', "");
Expect(0, 12979, '\P{^Is_Numeric_Value=+0_0_0_0_0_37}', "");
Error('\p{Is_Nv=  03_7:=}');
Error('\P{Is_Nv=  03_7:=}');
Expect(1, 12978, '\p{Is_Nv=0_0_0_0_0_0_0_0_037}', "");
Expect(0, 12978, '\p{^Is_Nv=0_0_0_0_0_0_0_0_037}', "");
Expect(0, 12978, '\P{Is_Nv=0_0_0_0_0_0_0_0_037}', "");
Expect(1, 12978, '\P{^Is_Nv=0_0_0_0_0_0_0_0_037}', "");
Expect(0, 12979, '\p{Is_Nv=0_0_0_0_0_0_0_0_037}', "");
Expect(1, 12979, '\p{^Is_Nv=0_0_0_0_0_0_0_0_037}', "");
Expect(1, 12979, '\P{Is_Nv=0_0_0_0_0_0_0_0_037}', "");
Expect(0, 12979, '\P{^Is_Nv=0_0_0_0_0_0_0_0_037}', "");
Error('\p{Numeric_Value=:=- +3_8}');
Error('\P{Numeric_Value=:=- +3_8}');
Expect(1, 12979, '\p{Numeric_Value:   00000_00003_8}', "");
Expect(0, 12979, '\p{^Numeric_Value:   00000_00003_8}', "");
Expect(0, 12979, '\P{Numeric_Value:   00000_00003_8}', "");
Expect(1, 12979, '\P{^Numeric_Value:   00000_00003_8}', "");
Expect(0, 12980, '\p{Numeric_Value:   00000_00003_8}', "");
Expect(1, 12980, '\p{^Numeric_Value:   00000_00003_8}', "");
Expect(1, 12980, '\P{Numeric_Value:   00000_00003_8}', "");
Expect(0, 12980, '\P{^Numeric_Value:   00000_00003_8}', "");
Error('\p{Nv=:=_00038}');
Error('\P{Nv=:=_00038}');
Expect(1, 12979, '\p{Nv=00_00_38}', "");
Expect(0, 12979, '\p{^Nv=00_00_38}', "");
Expect(0, 12979, '\P{Nv=00_00_38}', "");
Expect(1, 12979, '\P{^Nv=00_00_38}', "");
Expect(0, 12980, '\p{Nv=00_00_38}', "");
Expect(1, 12980, '\p{^Nv=00_00_38}', "");
Expect(1, 12980, '\P{Nv=00_00_38}', "");
Expect(0, 12980, '\P{^Nv=00_00_38}', "");
Error('\p{Is_Numeric_Value=--0038:=}');
Error('\P{Is_Numeric_Value=--0038:=}');
Expect(1, 12979, '\p{Is_Numeric_Value=0_0_0_0_0_38}', "");
Expect(0, 12979, '\p{^Is_Numeric_Value=0_0_0_0_0_38}', "");
Expect(0, 12979, '\P{Is_Numeric_Value=0_0_0_0_0_38}', "");
Expect(1, 12979, '\P{^Is_Numeric_Value=0_0_0_0_0_38}', "");
Expect(0, 12980, '\p{Is_Numeric_Value=0_0_0_0_0_38}', "");
Expect(1, 12980, '\p{^Is_Numeric_Value=0_0_0_0_0_38}', "");
Expect(1, 12980, '\P{Is_Numeric_Value=0_0_0_0_0_38}', "");
Expect(0, 12980, '\P{^Is_Numeric_Value=0_0_0_0_0_38}', "");
Error('\p{Is_Nv:  -0_0_0_0_0_0_0_38/a/}');
Error('\P{Is_Nv:  -0_0_0_0_0_0_0_38/a/}');
Expect(1, 12979, '\p{Is_Nv=0_0_0_0_038}', "");
Expect(0, 12979, '\p{^Is_Nv=0_0_0_0_038}', "");
Expect(0, 12979, '\P{Is_Nv=0_0_0_0_038}', "");
Expect(1, 12979, '\P{^Is_Nv=0_0_0_0_038}', "");
Expect(0, 12980, '\p{Is_Nv=0_0_0_0_038}', "");
Expect(1, 12980, '\p{^Is_Nv=0_0_0_0_038}', "");
Expect(1, 12980, '\P{Is_Nv=0_0_0_0_038}', "");
Expect(0, 12980, '\P{^Is_Nv=0_0_0_0_038}', "");
Error('\p{Numeric_Value=+000000039:=}');
Error('\P{Numeric_Value=+000000039:=}');
Expect(1, 12980, '\p{Numeric_Value=+0_0_0_0_039}', "");
Expect(0, 12980, '\p{^Numeric_Value=+0_0_0_0_039}', "");
Expect(0, 12980, '\P{Numeric_Value=+0_0_0_0_039}', "");
Expect(1, 12980, '\P{^Numeric_Value=+0_0_0_0_039}', "");
Expect(0, 12981, '\p{Numeric_Value=+0_0_0_0_039}', "");
Expect(1, 12981, '\p{^Numeric_Value=+0_0_0_0_039}', "");
Expect(1, 12981, '\P{Numeric_Value=+0_0_0_0_039}', "");
Expect(0, 12981, '\P{^Numeric_Value=+0_0_0_0_039}', "");
Error('\p{Nv=/a/ 	+0_0_0_0_39}');
Error('\P{Nv=/a/ 	+0_0_0_0_39}');
Expect(1, 12980, '\p{Nv=000_000_39}', "");
Expect(0, 12980, '\p{^Nv=000_000_39}', "");
Expect(0, 12980, '\P{Nv=000_000_39}', "");
Expect(1, 12980, '\P{^Nv=000_000_39}', "");
Expect(0, 12981, '\p{Nv=000_000_39}', "");
Expect(1, 12981, '\p{^Nv=000_000_39}', "");
Expect(1, 12981, '\P{Nv=000_000_39}', "");
Expect(0, 12981, '\P{^Nv=000_000_39}', "");
Error('\p{Is_Numeric_Value=/a/		00000000039}');
Error('\P{Is_Numeric_Value=/a/		00000000039}');
Expect(1, 12980, '\p{Is_Numeric_Value=000000039}', "");
Expect(0, 12980, '\p{^Is_Numeric_Value=000000039}', "");
Expect(0, 12980, '\P{Is_Numeric_Value=000000039}', "");
Expect(1, 12980, '\P{^Is_Numeric_Value=000000039}', "");
Expect(0, 12981, '\p{Is_Numeric_Value=000000039}', "");
Expect(1, 12981, '\p{^Is_Numeric_Value=000000039}', "");
Expect(1, 12981, '\P{Is_Numeric_Value=000000039}', "");
Expect(0, 12981, '\P{^Is_Numeric_Value=000000039}', "");
Error('\p{Is_Nv=/a/- 00_00_39}');
Error('\P{Is_Nv=/a/- 00_00_39}');
Expect(1, 12980, '\p{Is_Nv=3_9}', "");
Expect(0, 12980, '\p{^Is_Nv=3_9}', "");
Expect(0, 12980, '\P{Is_Nv=3_9}', "");
Expect(1, 12980, '\P{^Is_Nv=3_9}', "");
Expect(0, 12981, '\p{Is_Nv=3_9}', "");
Expect(1, 12981, '\p{^Is_Nv=3_9}', "");
Expect(1, 12981, '\P{Is_Nv=3_9}', "");
Expect(0, 12981, '\P{^Is_Nv=3_9}', "");
Error('\p{Numeric_Value= 	0000000004/a/}');
Error('\P{Numeric_Value= 	0000000004/a/}');
Expect(1, 156269, '\p{Numeric_Value=+00000_4}', "");
Expect(0, 156269, '\p{^Numeric_Value=+00000_4}', "");
Expect(0, 156269, '\P{Numeric_Value=+00000_4}', "");
Expect(1, 156269, '\P{^Numeric_Value=+00000_4}', "");
Expect(0, 156270, '\p{Numeric_Value=+00000_4}', "");
Expect(1, 156270, '\p{^Numeric_Value=+00000_4}', "");
Expect(1, 156270, '\P{Numeric_Value=+00000_4}', "");
Expect(0, 156270, '\P{^Numeric_Value=+00000_4}', "");
Error('\p{Nv=:=0_0_0_0_0_00004}');
Error('\P{Nv=:=0_0_0_0_0_00004}');
Expect(1, 156269, '\p{Nv=000000004}', "");
Expect(0, 156269, '\p{^Nv=000000004}', "");
Expect(0, 156269, '\P{Nv=000000004}', "");
Expect(1, 156269, '\P{^Nv=000000004}', "");
Expect(0, 156270, '\p{Nv=000000004}', "");
Expect(1, 156270, '\p{^Nv=000000004}', "");
Expect(1, 156270, '\P{Nv=000000004}', "");
Expect(0, 156270, '\P{^Nv=000000004}', "");
Error('\p{Is_Numeric_Value=-_4/a/}');
Error('\P{Is_Numeric_Value=-_4/a/}');
Expect(1, 156269, '\p{Is_Numeric_Value:   0000_0000_04}', "");
Expect(0, 156269, '\p{^Is_Numeric_Value:   0000_0000_04}', "");
Expect(0, 156269, '\P{Is_Numeric_Value:   0000_0000_04}', "");
Expect(1, 156269, '\P{^Is_Numeric_Value:   0000_0000_04}', "");
Expect(0, 156270, '\p{Is_Numeric_Value:   0000_0000_04}', "");
Expect(1, 156270, '\p{^Is_Numeric_Value:   0000_0000_04}', "");
Expect(1, 156270, '\P{Is_Numeric_Value:   0000_0000_04}', "");
Expect(0, 156270, '\P{^Is_Numeric_Value:   0000_0000_04}', "");
Error('\p{Is_Nv=:= 	04}');
Error('\P{Is_Nv=:= 	04}');
Expect(1, 156269, '\p{Is_Nv=0_0_0_004}', "");
Expect(0, 156269, '\p{^Is_Nv=0_0_0_004}', "");
Expect(0, 156269, '\P{Is_Nv=0_0_0_004}', "");
Expect(1, 156269, '\P{^Is_Nv=0_0_0_004}', "");
Expect(0, 156270, '\p{Is_Nv=0_0_0_004}', "");
Expect(1, 156270, '\p{^Is_Nv=0_0_0_004}', "");
Expect(1, 156270, '\P{Is_Nv=0_0_0_004}', "");
Expect(0, 156270, '\P{^Is_Nv=0_0_0_004}', "");
Error('\p{Numeric_Value=	/a/0000000004/0000005}');
Error('\P{Numeric_Value=	/a/0000000004/0000005}');
Expect(1, 8536, '\p{Numeric_Value=000000004/000000005}', "");
Expect(0, 8536, '\p{^Numeric_Value=000000004/000000005}', "");
Expect(0, 8536, '\P{Numeric_Value=000000004/000000005}', "");
Expect(1, 8536, '\P{^Numeric_Value=000000004/000000005}', "");
Expect(0, 8537, '\p{Numeric_Value=000000004/000000005}', "");
Expect(1, 8537, '\p{^Numeric_Value=000000004/000000005}', "");
Expect(1, 8537, '\P{Numeric_Value=000000004/000000005}', "");
Expect(0, 8537, '\P{^Numeric_Value=000000004/000000005}', "");
Expect(1, 8536, '\p{Numeric_Value=0.800}', "");
Expect(0, 8536, '\p{^Numeric_Value=0.800}', "");
Expect(0, 8536, '\P{Numeric_Value=0.800}', "");
Expect(1, 8536, '\P{^Numeric_Value=0.800}', "");
Expect(0, 8537, '\p{Numeric_Value=0.800}', "");
Expect(1, 8537, '\p{^Numeric_Value=0.800}', "");
Expect(1, 8537, '\P{Numeric_Value=0.800}', "");
Expect(0, 8537, '\P{^Numeric_Value=0.800}', "");
Error('\p{Nv=/a/	 04/000000005}');
Error('\P{Nv=/a/	 04/000000005}');
Expect(1, 8536, '\p{Nv=00004/000000005}', "");
Expect(0, 8536, '\p{^Nv=00004/000000005}', "");
Expect(0, 8536, '\P{Nv=00004/000000005}', "");
Expect(1, 8536, '\P{^Nv=00004/000000005}', "");
Expect(0, 8537, '\p{Nv=00004/000000005}', "");
Expect(1, 8537, '\p{^Nv=00004/000000005}', "");
Expect(1, 8537, '\P{Nv=00004/000000005}', "");
Expect(0, 8537, '\P{^Nv=00004/000000005}', "");
Expect(1, 8536, '\p{Nv=0.800}', "");
Expect(0, 8536, '\p{^Nv=0.800}', "");
Expect(0, 8536, '\P{Nv=0.800}', "");
Expect(1, 8536, '\P{^Nv=0.800}', "");
Expect(0, 8537, '\p{Nv=0.800}', "");
Expect(1, 8537, '\p{^Nv=0.800}', "");
Expect(1, 8537, '\P{Nv=0.800}', "");
Expect(0, 8537, '\P{^Nv=0.800}', "");
Error('\p{Is_Numeric_Value=	_+00004/00005:=}');
Error('\P{Is_Numeric_Value=	_+00004/00005:=}');
Expect(1, 8536, '\p{Is_Numeric_Value=0004/0000000005}', "");
Expect(0, 8536, '\p{^Is_Numeric_Value=0004/0000000005}', "");
Expect(0, 8536, '\P{Is_Numeric_Value=0004/0000000005}', "");
Expect(1, 8536, '\P{^Is_Numeric_Value=0004/0000000005}', "");
Expect(0, 8537, '\p{Is_Numeric_Value=0004/0000000005}', "");
Expect(1, 8537, '\p{^Is_Numeric_Value=0004/0000000005}', "");
Expect(1, 8537, '\P{Is_Numeric_Value=0004/0000000005}', "");
Expect(0, 8537, '\P{^Is_Numeric_Value=0004/0000000005}', "");
Expect(1, 8536, '\p{Is_Numeric_Value=0.800}', "");
Expect(0, 8536, '\p{^Is_Numeric_Value=0.800}', "");
Expect(0, 8536, '\P{Is_Numeric_Value=0.800}', "");
Expect(1, 8536, '\P{^Is_Numeric_Value=0.800}', "");
Expect(0, 8537, '\p{Is_Numeric_Value=0.800}', "");
Expect(1, 8537, '\p{^Is_Numeric_Value=0.800}', "");
Expect(1, 8537, '\P{Is_Numeric_Value=0.800}', "");
Expect(0, 8537, '\P{^Is_Numeric_Value=0.800}', "");
Error('\p{Is_Nv=:=--4/0005}');
Error('\P{Is_Nv=:=--4/0005}');
Expect(1, 8536, '\p{Is_Nv=004/00000005}', "");
Expect(0, 8536, '\p{^Is_Nv=004/00000005}', "");
Expect(0, 8536, '\P{Is_Nv=004/00000005}', "");
Expect(1, 8536, '\P{^Is_Nv=004/00000005}', "");
Expect(0, 8537, '\p{Is_Nv=004/00000005}', "");
Expect(1, 8537, '\p{^Is_Nv=004/00000005}', "");
Expect(1, 8537, '\P{Is_Nv=004/00000005}', "");
Expect(0, 8537, '\P{^Is_Nv=004/00000005}', "");
Expect(1, 8536, '\p{Is_Nv=0.800}', "");
Expect(0, 8536, '\p{^Is_Nv=0.800}', "");
Expect(0, 8536, '\P{Is_Nv=0.800}', "");
Expect(1, 8536, '\P{^Is_Nv=0.800}', "");
Expect(0, 8537, '\p{Is_Nv=0.800}', "");
Expect(1, 8537, '\p{^Is_Nv=0.800}', "");
Expect(1, 8537, '\P{Is_Nv=0.800}', "");
Expect(0, 8537, '\P{^Is_Nv=0.800}', "");
Error('\p{Numeric_Value:   :=+000000040}');
Error('\P{Numeric_Value:   :=+000000040}');
Expect(1, 133532, '\p{Numeric_Value:	+0004_0}', "");
Expect(0, 133532, '\p{^Numeric_Value:	+0004_0}', "");
Expect(0, 133532, '\P{Numeric_Value:	+0004_0}', "");
Expect(1, 133532, '\P{^Numeric_Value:	+0004_0}', "");
Expect(0, 133533, '\p{Numeric_Value:	+0004_0}', "");
Expect(1, 133533, '\p{^Numeric_Value:	+0004_0}', "");
Expect(1, 133533, '\P{Numeric_Value:	+0004_0}', "");
Expect(0, 133533, '\P{^Numeric_Value:	+0004_0}', "");
Error('\p{Nv=/a/-	+0000040}');
Error('\P{Nv=/a/-	+0000040}');
Expect(1, 133532, '\p{Nv=40}', "");
Expect(0, 133532, '\p{^Nv=40}', "");
Expect(0, 133532, '\P{Nv=40}', "");
Expect(1, 133532, '\P{^Nv=40}', "");
Expect(0, 133533, '\p{Nv=40}', "");
Expect(1, 133533, '\p{^Nv=40}', "");
Expect(1, 133533, '\P{Nv=40}', "");
Expect(0, 133533, '\P{^Nv=40}', "");
Error('\p{Is_Numeric_Value=_-0_0_0_0_040/a/}');
Error('\P{Is_Numeric_Value=_-0_0_0_0_040/a/}');
Expect(1, 133532, '\p{Is_Numeric_Value=+0040}', "");
Expect(0, 133532, '\p{^Is_Numeric_Value=+0040}', "");
Expect(0, 133532, '\P{Is_Numeric_Value=+0040}', "");
Expect(1, 133532, '\P{^Is_Numeric_Value=+0040}', "");
Expect(0, 133533, '\p{Is_Numeric_Value=+0040}', "");
Expect(1, 133533, '\p{^Is_Numeric_Value=+0040}', "");
Expect(1, 133533, '\P{Is_Numeric_Value=+0040}', "");
Expect(0, 133533, '\P{^Is_Numeric_Value=+0040}', "");
Error('\p{Is_Nv=	/a/00000040}');
Error('\P{Is_Nv=	/a/00000040}');
Expect(1, 133532, '\p{Is_Nv=000000004_0}', "");
Expect(0, 133532, '\p{^Is_Nv=000000004_0}', "");
Expect(0, 133532, '\P{Is_Nv=000000004_0}', "");
Expect(1, 133532, '\P{^Is_Nv=000000004_0}', "");
Expect(0, 133533, '\p{Is_Nv=000000004_0}', "");
Expect(1, 133533, '\p{^Is_Nv=000000004_0}', "");
Expect(1, 133533, '\P{Is_Nv=000000004_0}', "");
Expect(0, 133533, '\P{^Is_Nv=000000004_0}', "");
Error('\p{Numeric_Value=/a/	 000000400}');
Error('\P{Numeric_Value=/a/	 000000400}');
Expect(1, 69237, '\p{Numeric_Value=+00040_0}', "");
Expect(0, 69237, '\p{^Numeric_Value=+00040_0}', "");
Expect(0, 69237, '\P{Numeric_Value=+00040_0}', "");
Expect(1, 69237, '\P{^Numeric_Value=+00040_0}', "");
Expect(0, 69238, '\p{Numeric_Value=+00040_0}', "");
Expect(1, 69238, '\p{^Numeric_Value=+00040_0}', "");
Expect(1, 69238, '\P{Numeric_Value=+00040_0}', "");
Expect(0, 69238, '\P{^Numeric_Value=+00040_0}', "");
Error('\p{Nv=:= 0_0_0_4_00}');
Error('\P{Nv=:= 0_0_0_4_00}');
Expect(1, 69237, '\p{Nv=+0_0_0_400}', "");
Expect(0, 69237, '\p{^Nv=+0_0_0_400}', "");
Expect(0, 69237, '\P{Nv=+0_0_0_400}', "");
Expect(1, 69237, '\P{^Nv=+0_0_0_400}', "");
Expect(0, 69238, '\p{Nv=+0_0_0_400}', "");
Expect(1, 69238, '\p{^Nv=+0_0_0_400}', "");
Expect(1, 69238, '\P{Nv=+0_0_0_400}', "");
Expect(0, 69238, '\P{^Nv=+0_0_0_400}', "");
Error('\p{Is_Numeric_Value=_/a/0000040_0}');
Error('\P{Is_Numeric_Value=_/a/0000040_0}');
Expect(1, 69237, '\p{Is_Numeric_Value=+000040_0}', "");
Expect(0, 69237, '\p{^Is_Numeric_Value=+000040_0}', "");
Expect(0, 69237, '\P{Is_Numeric_Value=+000040_0}', "");
Expect(1, 69237, '\P{^Is_Numeric_Value=+000040_0}', "");
Expect(0, 69238, '\p{Is_Numeric_Value=+000040_0}', "");
Expect(1, 69238, '\p{^Is_Numeric_Value=+000040_0}', "");
Expect(1, 69238, '\P{Is_Numeric_Value=+000040_0}', "");
Expect(0, 69238, '\P{^Is_Numeric_Value=+000040_0}', "");
Error('\p{Is_Nv=:= 0400}');
Error('\P{Is_Nv=:= 0400}');
Expect(1, 69237, '\p{Is_Nv=+040_0}', "");
Expect(0, 69237, '\p{^Is_Nv=+040_0}', "");
Expect(0, 69237, '\P{Is_Nv=+040_0}', "");
Expect(1, 69237, '\P{^Is_Nv=+040_0}', "");
Expect(0, 69238, '\p{Is_Nv=+040_0}', "");
Expect(1, 69238, '\p{^Is_Nv=+040_0}', "");
Expect(1, 69238, '\P{Is_Nv=+040_0}', "");
Expect(0, 69238, '\P{^Is_Nv=+040_0}', "");
Error('\p{Numeric_Value=/a/	-0_0_0_4_000}');
Error('\P{Numeric_Value=/a/	-0_0_0_4_000}');
Expect(1, 65829, '\p{Numeric_Value=000000400_0}', "");
Expect(0, 65829, '\p{^Numeric_Value=000000400_0}', "");
Expect(0, 65829, '\P{Numeric_Value=000000400_0}', "");
Expect(1, 65829, '\P{^Numeric_Value=000000400_0}', "");
Expect(0, 65830, '\p{Numeric_Value=000000400_0}', "");
Expect(1, 65830, '\p{^Numeric_Value=000000400_0}', "");
Expect(1, 65830, '\P{Numeric_Value=000000400_0}', "");
Expect(0, 65830, '\P{^Numeric_Value=000000400_0}', "");
Error('\p{Nv=:=00004000}');
Error('\P{Nv=:=00004000}');
Expect(1, 65829, '\p{Nv:00004000}', "");
Expect(0, 65829, '\p{^Nv:00004000}', "");
Expect(0, 65829, '\P{Nv:00004000}', "");
Expect(1, 65829, '\P{^Nv:00004000}', "");
Expect(0, 65830, '\p{Nv:00004000}', "");
Expect(1, 65830, '\p{^Nv:00004000}', "");
Expect(1, 65830, '\P{Nv:00004000}', "");
Expect(0, 65830, '\P{^Nv:00004000}', "");
Error('\p{Is_Numeric_Value=__0_0_0_0_4000:=}');
Error('\P{Is_Numeric_Value=__0_0_0_0_4000:=}');
Expect(1, 65829, '\p{Is_Numeric_Value=+0_0_0_0_0_0_0_0_4_000}', "");
Expect(0, 65829, '\p{^Is_Numeric_Value=+0_0_0_0_0_0_0_0_4_000}', "");
Expect(0, 65829, '\P{Is_Numeric_Value=+0_0_0_0_0_0_0_0_4_000}', "");
Expect(1, 65829, '\P{^Is_Numeric_Value=+0_0_0_0_0_0_0_0_4_000}', "");
Expect(0, 65830, '\p{Is_Numeric_Value=+0_0_0_0_0_0_0_0_4_000}', "");
Expect(1, 65830, '\p{^Is_Numeric_Value=+0_0_0_0_0_0_0_0_4_000}', "");
Expect(1, 65830, '\P{Is_Numeric_Value=+0_0_0_0_0_0_0_0_4_000}', "");
Expect(0, 65830, '\P{^Is_Numeric_Value=+0_0_0_0_0_0_0_0_4_000}', "");
Error('\p{Is_Nv=	000004000:=}');
Error('\P{Is_Nv=	000004000:=}');
Expect(1, 65829, '\p{Is_Nv=0_0_4_0_00}', "");
Expect(0, 65829, '\p{^Is_Nv=0_0_4_0_00}', "");
Expect(0, 65829, '\P{Is_Nv=0_0_4_0_00}', "");
Expect(1, 65829, '\P{^Is_Nv=0_0_4_0_00}', "");
Expect(0, 65830, '\p{Is_Nv=0_0_4_0_00}', "");
Expect(1, 65830, '\p{^Is_Nv=0_0_4_0_00}', "");
Expect(1, 65830, '\P{Is_Nv=0_0_4_0_00}', "");
Expect(0, 65830, '\P{^Is_Nv=0_0_4_0_00}', "");
Error('\p{Numeric_Value=	 0000_4000_0:=}');
Error('\P{Numeric_Value=	 0000_4000_0:=}');
Expect(1, 65838, '\p{Numeric_Value=+000040000}', "");
Expect(0, 65838, '\p{^Numeric_Value=+000040000}', "");
Expect(0, 65838, '\P{Numeric_Value=+000040000}', "");
Expect(1, 65838, '\P{^Numeric_Value=+000040000}', "");
Expect(0, 65839, '\p{Numeric_Value=+000040000}', "");
Expect(1, 65839, '\p{^Numeric_Value=+000040000}', "");
Expect(1, 65839, '\P{Numeric_Value=+000040000}', "");
Expect(0, 65839, '\P{^Numeric_Value=+000040000}', "");
Error('\p{Nv=:=	00000040000}');
Error('\P{Nv=:=	00000040000}');
Expect(1, 65838, '\p{Nv=00004000_0}', "");
Expect(0, 65838, '\p{^Nv=00004000_0}', "");
Expect(0, 65838, '\P{Nv=00004000_0}', "");
Expect(1, 65838, '\P{^Nv=00004000_0}', "");
Expect(0, 65839, '\p{Nv=00004000_0}', "");
Expect(1, 65839, '\p{^Nv=00004000_0}', "");
Expect(1, 65839, '\P{Nv=00004000_0}', "");
Expect(0, 65839, '\P{^Nv=00004000_0}', "");
Error('\p{Is_Numeric_Value: :=- +000_000_040_000}');
Error('\P{Is_Numeric_Value: :=- +000_000_040_000}');
Expect(1, 65838, '\p{Is_Numeric_Value=00_00_00_00_40_000}', "");
Expect(0, 65838, '\p{^Is_Numeric_Value=00_00_00_00_40_000}', "");
Expect(0, 65838, '\P{Is_Numeric_Value=00_00_00_00_40_000}', "");
Expect(1, 65838, '\P{^Is_Numeric_Value=00_00_00_00_40_000}', "");
Expect(0, 65839, '\p{Is_Numeric_Value=00_00_00_00_40_000}', "");
Expect(1, 65839, '\p{^Is_Numeric_Value=00_00_00_00_40_000}', "");
Expect(1, 65839, '\P{Is_Numeric_Value=00_00_00_00_40_000}', "");
Expect(0, 65839, '\P{^Is_Numeric_Value=00_00_00_00_40_000}', "");
Error('\p{Is_Nv=_/a/+0_0_0_0_0_0_0_4_0_000}');
Error('\P{Is_Nv=_/a/+0_0_0_0_0_0_0_4_0_000}');
Expect(1, 65838, '\p{Is_Nv=000000040000}', "");
Expect(0, 65838, '\p{^Is_Nv=000000040000}', "");
Expect(0, 65838, '\P{Is_Nv=000000040000}', "");
Expect(1, 65838, '\P{^Is_Nv=000000040000}', "");
Expect(0, 65839, '\p{Is_Nv=000000040000}', "");
Expect(1, 65839, '\p{^Is_Nv=000000040000}', "");
Expect(1, 65839, '\P{Is_Nv=000000040000}', "");
Expect(0, 65839, '\P{^Is_Nv=000000040000}', "");
Error('\p{Numeric_Value=:= +0_0_0_041}');
Error('\P{Numeric_Value=:= +0_0_0_041}');
Expect(1, 12982, '\p{Numeric_Value=00000000041}', "");
Expect(0, 12982, '\p{^Numeric_Value=00000000041}', "");
Expect(0, 12982, '\P{Numeric_Value=00000000041}', "");
Expect(1, 12982, '\P{^Numeric_Value=00000000041}', "");
Expect(0, 12983, '\p{Numeric_Value=00000000041}', "");
Expect(1, 12983, '\p{^Numeric_Value=00000000041}', "");
Expect(1, 12983, '\P{Numeric_Value=00000000041}', "");
Expect(0, 12983, '\P{^Numeric_Value=00000000041}', "");
Error('\p{Nv=/a/-00004_1}');
Error('\P{Nv=/a/-00004_1}');
Expect(1, 12982, '\p{Nv=0_0_0_0_0_0_0_41}', "");
Expect(0, 12982, '\p{^Nv=0_0_0_0_0_0_0_41}', "");
Expect(0, 12982, '\P{Nv=0_0_0_0_0_0_0_41}', "");
Expect(1, 12982, '\P{^Nv=0_0_0_0_0_0_0_41}', "");
Expect(0, 12983, '\p{Nv=0_0_0_0_0_0_0_41}', "");
Expect(1, 12983, '\p{^Nv=0_0_0_0_0_0_0_41}', "");
Expect(1, 12983, '\P{Nv=0_0_0_0_0_0_0_41}', "");
Expect(0, 12983, '\P{^Nv=0_0_0_0_0_0_0_41}', "");
Error('\p{Is_Numeric_Value= /a/4_1}');
Error('\P{Is_Numeric_Value= /a/4_1}');
Expect(1, 12982, '\p{Is_Numeric_Value=0004_1}', "");
Expect(0, 12982, '\p{^Is_Numeric_Value=0004_1}', "");
Expect(0, 12982, '\P{Is_Numeric_Value=0004_1}', "");
Expect(1, 12982, '\P{^Is_Numeric_Value=0004_1}', "");
Expect(0, 12983, '\p{Is_Numeric_Value=0004_1}', "");
Expect(1, 12983, '\p{^Is_Numeric_Value=0004_1}', "");
Expect(1, 12983, '\P{Is_Numeric_Value=0004_1}', "");
Expect(0, 12983, '\P{^Is_Numeric_Value=0004_1}', "");
Error('\p{Is_Nv=	041:=}');
Error('\P{Is_Nv=	041:=}');
Expect(1, 12982, '\p{Is_Nv=4_1}', "");
Expect(0, 12982, '\p{^Is_Nv=4_1}', "");
Expect(0, 12982, '\P{Is_Nv=4_1}', "");
Expect(1, 12982, '\P{^Is_Nv=4_1}', "");
Expect(0, 12983, '\p{Is_Nv=4_1}', "");
Expect(1, 12983, '\p{^Is_Nv=4_1}', "");
Expect(1, 12983, '\P{Is_Nv=4_1}', "");
Expect(0, 12983, '\P{^Is_Nv=4_1}', "");
Error('\p{Numeric_Value:	-+0000004_2/a/}');
Error('\P{Numeric_Value:	-+0000004_2/a/}');
Expect(1, 12983, '\p{Numeric_Value=00_00_00_04_2}', "");
Expect(0, 12983, '\p{^Numeric_Value=00_00_00_04_2}', "");
Expect(0, 12983, '\P{Numeric_Value=00_00_00_04_2}', "");
Expect(1, 12983, '\P{^Numeric_Value=00_00_00_04_2}', "");
Expect(0, 12984, '\p{Numeric_Value=00_00_00_04_2}', "");
Expect(1, 12984, '\p{^Numeric_Value=00_00_00_04_2}', "");
Expect(1, 12984, '\P{Numeric_Value=00_00_00_04_2}', "");
Expect(0, 12984, '\P{^Numeric_Value=00_00_00_04_2}', "");
Error('\p{Nv=_+000_004_2/a/}');
Error('\P{Nv=_+000_004_2/a/}');
Expect(1, 12983, '\p{Nv=000042}', "");
Expect(0, 12983, '\p{^Nv=000042}', "");
Expect(0, 12983, '\P{Nv=000042}', "");
Expect(1, 12983, '\P{^Nv=000042}', "");
Expect(0, 12984, '\p{Nv=000042}', "");
Expect(1, 12984, '\p{^Nv=000042}', "");
Expect(1, 12984, '\P{Nv=000042}', "");
Expect(0, 12984, '\P{^Nv=000042}', "");
Error('\p{Is_Numeric_Value: 	-000_000_000_42:=}');
Error('\P{Is_Numeric_Value: 	-000_000_000_42:=}');
Expect(1, 12983, '\p{Is_Numeric_Value:	0_0_0_0_0_00042}', "");
Expect(0, 12983, '\p{^Is_Numeric_Value:	0_0_0_0_0_00042}', "");
Expect(0, 12983, '\P{Is_Numeric_Value:	0_0_0_0_0_00042}', "");
Expect(1, 12983, '\P{^Is_Numeric_Value:	0_0_0_0_0_00042}', "");
Expect(0, 12984, '\p{Is_Numeric_Value:	0_0_0_0_0_00042}', "");
Expect(1, 12984, '\p{^Is_Numeric_Value:	0_0_0_0_0_00042}', "");
Expect(1, 12984, '\P{Is_Numeric_Value:	0_0_0_0_0_00042}', "");
Expect(0, 12984, '\P{^Is_Numeric_Value:	0_0_0_0_0_00042}', "");
Error('\p{Is_Nv=/a/		+0042}');
Error('\P{Is_Nv=/a/		+0042}');
Expect(1, 12983, '\p{Is_Nv: 0_0_42}', "");
Expect(0, 12983, '\p{^Is_Nv: 0_0_42}', "");
Expect(0, 12983, '\P{Is_Nv: 0_0_42}', "");
Expect(1, 12983, '\P{^Is_Nv: 0_0_42}', "");
Expect(0, 12984, '\p{Is_Nv: 0_0_42}', "");
Expect(1, 12984, '\p{^Is_Nv: 0_0_42}', "");
Expect(1, 12984, '\P{Is_Nv: 0_0_42}', "");
Expect(0, 12984, '\P{^Is_Nv: 0_0_42}', "");
Error('\p{Numeric_Value=_	00000043:=}');
Error('\P{Numeric_Value=_	00000043:=}');
Expect(1, 12984, '\p{Numeric_Value=000043}', "");
Expect(0, 12984, '\p{^Numeric_Value=000043}', "");
Expect(0, 12984, '\P{Numeric_Value=000043}', "");
Expect(1, 12984, '\P{^Numeric_Value=000043}', "");
Expect(0, 12985, '\p{Numeric_Value=000043}', "");
Expect(1, 12985, '\p{^Numeric_Value=000043}', "");
Expect(1, 12985, '\P{Numeric_Value=000043}', "");
Expect(0, 12985, '\P{^Numeric_Value=000043}', "");
Error('\p{Nv=:=00043}');
Error('\P{Nv=:=00043}');
Expect(1, 12984, '\p{Nv=0000000043}', "");
Expect(0, 12984, '\p{^Nv=0000000043}', "");
Expect(0, 12984, '\P{Nv=0000000043}', "");
Expect(1, 12984, '\P{^Nv=0000000043}', "");
Expect(0, 12985, '\p{Nv=0000000043}', "");
Expect(1, 12985, '\p{^Nv=0000000043}', "");
Expect(1, 12985, '\P{Nv=0000000043}', "");
Expect(0, 12985, '\P{^Nv=0000000043}', "");
Error('\p{Is_Numeric_Value= +004_3/a/}');
Error('\P{Is_Numeric_Value= +004_3/a/}');
Expect(1, 12984, '\p{Is_Numeric_Value=000000043}', "");
Expect(0, 12984, '\p{^Is_Numeric_Value=000000043}', "");
Expect(0, 12984, '\P{Is_Numeric_Value=000000043}', "");
Expect(1, 12984, '\P{^Is_Numeric_Value=000000043}', "");
Expect(0, 12985, '\p{Is_Numeric_Value=000000043}', "");
Expect(1, 12985, '\p{^Is_Numeric_Value=000000043}', "");
Expect(1, 12985, '\P{Is_Numeric_Value=000000043}', "");
Expect(0, 12985, '\P{^Is_Numeric_Value=000000043}', "");
Error('\p{Is_Nv=--+000_000_43/a/}');
Error('\P{Is_Nv=--+000_000_43/a/}');
Expect(1, 12984, '\p{Is_Nv=0_0_0_0_0_43}', "");
Expect(0, 12984, '\p{^Is_Nv=0_0_0_0_0_43}', "");
Expect(0, 12984, '\P{Is_Nv=0_0_0_0_0_43}', "");
Expect(1, 12984, '\P{^Is_Nv=0_0_0_0_0_43}', "");
Expect(0, 12985, '\p{Is_Nv=0_0_0_0_0_43}', "");
Expect(1, 12985, '\p{^Is_Nv=0_0_0_0_0_43}', "");
Expect(1, 12985, '\P{Is_Nv=0_0_0_0_0_43}', "");
Expect(0, 12985, '\P{^Is_Nv=0_0_0_0_0_43}', "");
Error('\p{Numeric_Value=:=-_432000}');
Error('\P{Numeric_Value=:=-_432000}');
Expect(1, 74803, '\p{Numeric_Value=00_00_00_00_43_2000}', "");
Expect(0, 74803, '\p{^Numeric_Value=00_00_00_00_43_2000}', "");
Expect(0, 74803, '\P{Numeric_Value=00_00_00_00_43_2000}', "");
Expect(1, 74803, '\P{^Numeric_Value=00_00_00_00_43_2000}', "");
Expect(0, 74804, '\p{Numeric_Value=00_00_00_00_43_2000}', "");
Expect(1, 74804, '\p{^Numeric_Value=00_00_00_00_43_2000}', "");
Expect(1, 74804, '\P{Numeric_Value=00_00_00_00_43_2000}', "");
Expect(0, 74804, '\P{^Numeric_Value=00_00_00_00_43_2000}', "");
Error('\p{Nv=	-+432000:=}');
Error('\P{Nv=	-+432000:=}');
Expect(1, 74803, '\p{Nv=+000_000_004_320_00}', "");
Expect(0, 74803, '\p{^Nv=+000_000_004_320_00}', "");
Expect(0, 74803, '\P{Nv=+000_000_004_320_00}', "");
Expect(1, 74803, '\P{^Nv=+000_000_004_320_00}', "");
Expect(0, 74804, '\p{Nv=+000_000_004_320_00}', "");
Expect(1, 74804, '\p{^Nv=+000_000_004_320_00}', "");
Expect(1, 74804, '\P{Nv=+000_000_004_320_00}', "");
Expect(0, 74804, '\P{^Nv=+000_000_004_320_00}', "");
Error('\p{Is_Numeric_Value=:=0_0_0_0_4_3_2_000}');
Error('\P{Is_Numeric_Value=:=0_0_0_0_4_3_2_000}');
Expect(1, 74803, '\p{Is_Numeric_Value=00_04_32_000}', "");
Expect(0, 74803, '\p{^Is_Numeric_Value=00_04_32_000}', "");
Expect(0, 74803, '\P{Is_Numeric_Value=00_04_32_000}', "");
Expect(1, 74803, '\P{^Is_Numeric_Value=00_04_32_000}', "");
Expect(0, 74804, '\p{Is_Numeric_Value=00_04_32_000}', "");
Expect(1, 74804, '\p{^Is_Numeric_Value=00_04_32_000}', "");
Expect(1, 74804, '\P{Is_Numeric_Value=00_04_32_000}', "");
Expect(0, 74804, '\P{^Is_Numeric_Value=00_04_32_000}', "");
Error('\p{Is_Nv=/a/ 0_0_0_0_0_4_32000}');
Error('\P{Is_Nv=/a/ 0_0_0_0_0_4_32000}');
Expect(1, 74803, '\p{Is_Nv=+0000043200_0}', "");
Expect(0, 74803, '\p{^Is_Nv=+0000043200_0}', "");
Expect(0, 74803, '\P{Is_Nv=+0000043200_0}', "");
Expect(1, 74803, '\P{^Is_Nv=+0000043200_0}', "");
Expect(0, 74804, '\p{Is_Nv=+0000043200_0}', "");
Expect(1, 74804, '\p{^Is_Nv=+0000043200_0}', "");
Expect(1, 74804, '\P{Is_Nv=+0000043200_0}', "");
Expect(0, 74804, '\P{^Is_Nv=+0000043200_0}', "");
Error('\p{Numeric_Value=:=--+000000044}');
Error('\P{Numeric_Value=:=--+000000044}');
Expect(1, 12985, '\p{Numeric_Value=0_0_0_0_44}', "");
Expect(0, 12985, '\p{^Numeric_Value=0_0_0_0_44}', "");
Expect(0, 12985, '\P{Numeric_Value=0_0_0_0_44}', "");
Expect(1, 12985, '\P{^Numeric_Value=0_0_0_0_44}', "");
Expect(0, 12986, '\p{Numeric_Value=0_0_0_0_44}', "");
Expect(1, 12986, '\p{^Numeric_Value=0_0_0_0_44}', "");
Expect(1, 12986, '\P{Numeric_Value=0_0_0_0_44}', "");
Expect(0, 12986, '\P{^Numeric_Value=0_0_0_0_44}', "");
Error('\p{Nv=--0000000044:=}');
Error('\P{Nv=--0000000044:=}');
Expect(1, 12985, '\p{Nv=0_0_0_0_0_0_0044}', "");
Expect(0, 12985, '\p{^Nv=0_0_0_0_0_0_0044}', "");
Expect(0, 12985, '\P{Nv=0_0_0_0_0_0_0044}', "");
Expect(1, 12985, '\P{^Nv=0_0_0_0_0_0_0044}', "");
Expect(0, 12986, '\p{Nv=0_0_0_0_0_0_0044}', "");
Expect(1, 12986, '\p{^Nv=0_0_0_0_0_0_0044}', "");
Expect(1, 12986, '\P{Nv=0_0_0_0_0_0_0044}', "");
Expect(0, 12986, '\P{^Nv=0_0_0_0_0_0_0044}', "");
Error('\p{Is_Numeric_Value=	/a/4_4}');
Error('\P{Is_Numeric_Value=	/a/4_4}');
Expect(1, 12985, '\p{Is_Numeric_Value=0000000044}', "");
Expect(0, 12985, '\p{^Is_Numeric_Value=0000000044}', "");
Expect(0, 12985, '\P{Is_Numeric_Value=0000000044}', "");
Expect(1, 12985, '\P{^Is_Numeric_Value=0000000044}', "");
Expect(0, 12986, '\p{Is_Numeric_Value=0000000044}', "");
Expect(1, 12986, '\p{^Is_Numeric_Value=0000000044}', "");
Expect(1, 12986, '\P{Is_Numeric_Value=0000000044}', "");
Expect(0, 12986, '\P{^Is_Numeric_Value=0000000044}', "");
Error('\p{Is_Nv=/a/-	0_0_0_0_0_0_0_0_0_44}');
Error('\P{Is_Nv=/a/-	0_0_0_0_0_0_0_0_0_44}');
Expect(1, 12985, '\p{Is_Nv=044}', "");
Expect(0, 12985, '\p{^Is_Nv=044}', "");
Expect(0, 12985, '\P{Is_Nv=044}', "");
Expect(1, 12985, '\P{^Is_Nv=044}', "");
Expect(0, 12986, '\p{Is_Nv=044}', "");
Expect(1, 12986, '\p{^Is_Nv=044}', "");
Expect(1, 12986, '\P{Is_Nv=044}', "");
Expect(0, 12986, '\P{^Is_Nv=044}', "");
Error('\p{Numeric_Value=- 0004_5:=}');
Error('\P{Numeric_Value=- 0004_5:=}');
Expect(1, 12986, '\p{Numeric_Value:0045}', "");
Expect(0, 12986, '\p{^Numeric_Value:0045}', "");
Expect(0, 12986, '\P{Numeric_Value:0045}', "");
Expect(1, 12986, '\P{^Numeric_Value:0045}', "");
Expect(0, 12987, '\p{Numeric_Value:0045}', "");
Expect(1, 12987, '\p{^Numeric_Value:0045}', "");
Expect(1, 12987, '\P{Numeric_Value:0045}', "");
Expect(0, 12987, '\P{^Numeric_Value:0045}', "");
Error('\p{Nv=:=_0_0_0_0_45}');
Error('\P{Nv=:=_0_0_0_0_45}');
Expect(1, 12986, '\p{Nv=0000000045}', "");
Expect(0, 12986, '\p{^Nv=0000000045}', "");
Expect(0, 12986, '\P{Nv=0000000045}', "");
Expect(1, 12986, '\P{^Nv=0000000045}', "");
Expect(0, 12987, '\p{Nv=0000000045}', "");
Expect(1, 12987, '\p{^Nv=0000000045}', "");
Expect(1, 12987, '\P{Nv=0000000045}', "");
Expect(0, 12987, '\P{^Nv=0000000045}', "");
Error('\p{Is_Numeric_Value=/a/0_0_45}');
Error('\P{Is_Numeric_Value=/a/0_0_45}');
Expect(1, 12986, '\p{Is_Numeric_Value=+0000045}', "");
Expect(0, 12986, '\p{^Is_Numeric_Value=+0000045}', "");
Expect(0, 12986, '\P{Is_Numeric_Value=+0000045}', "");
Expect(1, 12986, '\P{^Is_Numeric_Value=+0000045}', "");
Expect(0, 12987, '\p{Is_Numeric_Value=+0000045}', "");
Expect(1, 12987, '\p{^Is_Numeric_Value=+0000045}', "");
Expect(1, 12987, '\P{Is_Numeric_Value=+0000045}', "");
Expect(0, 12987, '\P{^Is_Numeric_Value=+0000045}', "");
Error('\p{Is_Nv=:=_ 0000000045}');
Error('\P{Is_Nv=:=_ 0000000045}');
Expect(1, 12986, '\p{Is_Nv=+4_5}', "");
Expect(0, 12986, '\p{^Is_Nv=+4_5}', "");
Expect(0, 12986, '\P{Is_Nv=+4_5}', "");
Expect(1, 12986, '\P{^Is_Nv=+4_5}', "");
Expect(0, 12987, '\p{Is_Nv=+4_5}', "");
Expect(1, 12987, '\p{^Is_Nv=+4_5}', "");
Expect(1, 12987, '\P{Is_Nv=+4_5}', "");
Expect(0, 12987, '\P{^Is_Nv=+4_5}', "");
Error('\p{Numeric_Value= -000_000_000_46/a/}');
Error('\P{Numeric_Value= -000_000_000_46/a/}');
Expect(1, 12987, '\p{Numeric_Value=+0_0_0_0_0_0046}', "");
Expect(0, 12987, '\p{^Numeric_Value=+0_0_0_0_0_0046}', "");
Expect(0, 12987, '\P{Numeric_Value=+0_0_0_0_0_0046}', "");
Expect(1, 12987, '\P{^Numeric_Value=+0_0_0_0_0_0046}', "");
Expect(0, 12988, '\p{Numeric_Value=+0_0_0_0_0_0046}', "");
Expect(1, 12988, '\p{^Numeric_Value=+0_0_0_0_0_0046}', "");
Expect(1, 12988, '\P{Numeric_Value=+0_0_0_0_0_0046}', "");
Expect(0, 12988, '\P{^Numeric_Value=+0_0_0_0_0_0046}', "");
Error('\p{Nv=:=_ 0000000046}');
Error('\P{Nv=:=_ 0000000046}');
Expect(1, 12987, '\p{Nv=0000004_6}', "");
Expect(0, 12987, '\p{^Nv=0000004_6}', "");
Expect(0, 12987, '\P{Nv=0000004_6}', "");
Expect(1, 12987, '\P{^Nv=0000004_6}', "");
Expect(0, 12988, '\p{Nv=0000004_6}', "");
Expect(1, 12988, '\p{^Nv=0000004_6}', "");
Expect(1, 12988, '\P{Nv=0000004_6}', "");
Expect(0, 12988, '\P{^Nv=0000004_6}', "");
Error('\p{Is_Numeric_Value=		0_0_0_46/a/}');
Error('\P{Is_Numeric_Value=		0_0_0_46/a/}');
Expect(1, 12987, '\p{Is_Numeric_Value=46}', "");
Expect(0, 12987, '\p{^Is_Numeric_Value=46}', "");
Expect(0, 12987, '\P{Is_Numeric_Value=46}', "");
Expect(1, 12987, '\P{^Is_Numeric_Value=46}', "");
Expect(0, 12988, '\p{Is_Numeric_Value=46}', "");
Expect(1, 12988, '\p{^Is_Numeric_Value=46}', "");
Expect(1, 12988, '\P{Is_Numeric_Value=46}', "");
Expect(0, 12988, '\P{^Is_Numeric_Value=46}', "");
Error('\p{Is_Nv=_/a/+4_6}');
Error('\P{Is_Nv=_/a/+4_6}');
Expect(1, 12987, '\p{Is_Nv=00000046}', "");
Expect(0, 12987, '\p{^Is_Nv=00000046}', "");
Expect(0, 12987, '\P{Is_Nv=00000046}', "");
Expect(1, 12987, '\P{^Is_Nv=00000046}', "");
Expect(0, 12988, '\p{Is_Nv=00000046}', "");
Expect(1, 12988, '\p{^Is_Nv=00000046}', "");
Expect(1, 12988, '\P{Is_Nv=00000046}', "");
Expect(0, 12988, '\P{^Is_Nv=00000046}', "");
Error('\p{Numeric_Value=:= +000000047}');
Error('\P{Numeric_Value=:= +000000047}');
Expect(1, 12988, '\p{Numeric_Value=0_0_0_0_0_0_0_0_47}', "");
Expect(0, 12988, '\p{^Numeric_Value=0_0_0_0_0_0_0_0_47}', "");
Expect(0, 12988, '\P{Numeric_Value=0_0_0_0_0_0_0_0_47}', "");
Expect(1, 12988, '\P{^Numeric_Value=0_0_0_0_0_0_0_0_47}', "");
Expect(0, 12989, '\p{Numeric_Value=0_0_0_0_0_0_0_0_47}', "");
Expect(1, 12989, '\p{^Numeric_Value=0_0_0_0_0_0_0_0_47}', "");
Expect(1, 12989, '\P{Numeric_Value=0_0_0_0_0_0_0_0_47}', "");
Expect(0, 12989, '\P{^Numeric_Value=0_0_0_0_0_0_0_0_47}', "");
Error('\p{Nv=_0000000047:=}');
Error('\P{Nv=_0000000047:=}');
Expect(1, 12988, '\p{Nv=0047}', "");
Expect(0, 12988, '\p{^Nv=0047}', "");
Expect(0, 12988, '\P{Nv=0047}', "");
Expect(1, 12988, '\P{^Nv=0047}', "");
Expect(0, 12989, '\p{Nv=0047}', "");
Expect(1, 12989, '\p{^Nv=0047}', "");
Expect(1, 12989, '\P{Nv=0047}', "");
Expect(0, 12989, '\P{^Nv=0047}', "");
Error('\p{Is_Numeric_Value=__47:=}');
Error('\P{Is_Numeric_Value=__47:=}');
Expect(1, 12988, '\p{Is_Numeric_Value=+4_7}', "");
Expect(0, 12988, '\p{^Is_Numeric_Value=+4_7}', "");
Expect(0, 12988, '\P{Is_Numeric_Value=+4_7}', "");
Expect(1, 12988, '\P{^Is_Numeric_Value=+4_7}', "");
Expect(0, 12989, '\p{Is_Numeric_Value=+4_7}', "");
Expect(1, 12989, '\p{^Is_Numeric_Value=+4_7}', "");
Expect(1, 12989, '\P{Is_Numeric_Value=+4_7}', "");
Expect(0, 12989, '\P{^Is_Numeric_Value=+4_7}', "");
Error('\p{Is_Nv=/a/-	0047}');
Error('\P{Is_Nv=/a/-	0047}');
Expect(1, 12988, '\p{Is_Nv=+000004_7}', "");
Expect(0, 12988, '\p{^Is_Nv=+000004_7}', "");
Expect(0, 12988, '\P{Is_Nv=+000004_7}', "");
Expect(1, 12988, '\P{^Is_Nv=+000004_7}', "");
Expect(0, 12989, '\p{Is_Nv=+000004_7}', "");
Expect(1, 12989, '\p{^Is_Nv=+000004_7}', "");
Expect(1, 12989, '\P{Is_Nv=+000004_7}', "");
Expect(0, 12989, '\P{^Is_Nv=+000004_7}', "");
Error('\p{Numeric_Value= :=+0_0_0_0_048}');
Error('\P{Numeric_Value= :=+0_0_0_0_048}');
Expect(1, 12989, '\p{Numeric_Value=00_00_48}', "");
Expect(0, 12989, '\p{^Numeric_Value=00_00_48}', "");
Expect(0, 12989, '\P{Numeric_Value=00_00_48}', "");
Expect(1, 12989, '\P{^Numeric_Value=00_00_48}', "");
Expect(0, 12990, '\p{Numeric_Value=00_00_48}', "");
Expect(1, 12990, '\p{^Numeric_Value=00_00_48}', "");
Expect(1, 12990, '\P{Numeric_Value=00_00_48}', "");
Expect(0, 12990, '\P{^Numeric_Value=00_00_48}', "");
Error('\p{Nv=_:=+0_0_48}');
Error('\P{Nv=_:=+0_0_48}');
Expect(1, 12989, '\p{Nv:   48}', "");
Expect(0, 12989, '\p{^Nv:   48}', "");
Expect(0, 12989, '\P{Nv:   48}', "");
Expect(1, 12989, '\P{^Nv:   48}', "");
Expect(0, 12990, '\p{Nv:   48}', "");
Expect(1, 12990, '\p{^Nv:   48}', "");
Expect(1, 12990, '\P{Nv:   48}', "");
Expect(0, 12990, '\P{^Nv:   48}', "");
Error('\p{Is_Numeric_Value= /a/0_0_0_0_0_48}');
Error('\P{Is_Numeric_Value= /a/0_0_0_0_0_48}');
Expect(1, 12989, '\p{Is_Numeric_Value:+04_8}', "");
Expect(0, 12989, '\p{^Is_Numeric_Value:+04_8}', "");
Expect(0, 12989, '\P{Is_Numeric_Value:+04_8}', "");
Expect(1, 12989, '\P{^Is_Numeric_Value:+04_8}', "");
Expect(0, 12990, '\p{Is_Numeric_Value:+04_8}', "");
Expect(1, 12990, '\p{^Is_Numeric_Value:+04_8}', "");
Expect(1, 12990, '\P{Is_Numeric_Value:+04_8}', "");
Expect(0, 12990, '\P{^Is_Numeric_Value:+04_8}', "");
Error('\p{Is_Nv=	+000000048/a/}');
Error('\P{Is_Nv=	+000000048/a/}');
Expect(1, 12989, '\p{Is_Nv=+0_0_0_0_0_0048}', "");
Expect(0, 12989, '\p{^Is_Nv=+0_0_0_0_0_0048}', "");
Expect(0, 12989, '\P{Is_Nv=+0_0_0_0_0_0048}', "");
Expect(1, 12989, '\P{^Is_Nv=+0_0_0_0_0_0048}', "");
Expect(0, 12990, '\p{Is_Nv=+0_0_0_0_0_0048}', "");
Expect(1, 12990, '\p{^Is_Nv=+0_0_0_0_0_0048}', "");
Expect(1, 12990, '\P{Is_Nv=+0_0_0_0_0_0048}', "");
Expect(0, 12990, '\P{^Is_Nv=+0_0_0_0_0_0048}', "");
Error('\p{Numeric_Value=/a/-	+49}');
Error('\P{Numeric_Value=/a/-	+49}');
Expect(1, 12990, '\p{Numeric_Value=0_0_49}', "");
Expect(0, 12990, '\p{^Numeric_Value=0_0_49}', "");
Expect(0, 12990, '\P{Numeric_Value=0_0_49}', "");
Expect(1, 12990, '\P{^Numeric_Value=0_0_49}', "");
Expect(0, 12991, '\p{Numeric_Value=0_0_49}', "");
Expect(1, 12991, '\p{^Numeric_Value=0_0_49}', "");
Expect(1, 12991, '\P{Numeric_Value=0_0_49}', "");
Expect(0, 12991, '\P{^Numeric_Value=0_0_49}', "");
Error('\p{Nv=/a/	 00_00_00_04_9}');
Error('\P{Nv=/a/	 00_00_00_04_9}');
Expect(1, 12990, '\p{Nv=0000000049}', "");
Expect(0, 12990, '\p{^Nv=0000000049}', "");
Expect(0, 12990, '\P{Nv=0000000049}', "");
Expect(1, 12990, '\P{^Nv=0000000049}', "");
Expect(0, 12991, '\p{Nv=0000000049}', "");
Expect(1, 12991, '\p{^Nv=0000000049}', "");
Expect(1, 12991, '\P{Nv=0000000049}', "");
Expect(0, 12991, '\P{^Nv=0000000049}', "");
Error('\p{Is_Numeric_Value=	 +000000049:=}');
Error('\P{Is_Numeric_Value=	 +000000049:=}');
Expect(1, 12990, '\p{Is_Numeric_Value=49}', "");
Expect(0, 12990, '\p{^Is_Numeric_Value=49}', "");
Expect(0, 12990, '\P{Is_Numeric_Value=49}', "");
Expect(1, 12990, '\P{^Is_Numeric_Value=49}', "");
Expect(0, 12991, '\p{Is_Numeric_Value=49}', "");
Expect(1, 12991, '\p{^Is_Numeric_Value=49}', "");
Expect(1, 12991, '\P{Is_Numeric_Value=49}', "");
Expect(0, 12991, '\P{^Is_Numeric_Value=49}', "");
Error('\p{Is_Nv= -004_9/a/}');
Error('\P{Is_Nv= -004_9/a/}');
Expect(1, 12990, '\p{Is_Nv=00_00_00_00_49}', "");
Expect(0, 12990, '\p{^Is_Nv=00_00_00_00_49}', "");
Expect(0, 12990, '\P{Is_Nv=00_00_00_00_49}', "");
Expect(1, 12990, '\P{^Is_Nv=00_00_00_00_49}', "");
Expect(0, 12991, '\p{Is_Nv=00_00_00_00_49}', "");
Expect(1, 12991, '\p{^Is_Nv=00_00_00_00_49}', "");
Expect(1, 12991, '\P{Is_Nv=00_00_00_00_49}', "");
Expect(0, 12991, '\P{^Is_Nv=00_00_00_00_49}', "");
Error('\p{Numeric_Value=  +5/a/}');
Error('\P{Numeric_Value=  +5/a/}');
Expect(1, 131361, '\p{Numeric_Value=0005}', "");
Expect(0, 131361, '\p{^Numeric_Value=0005}', "");
Expect(0, 131361, '\P{Numeric_Value=0005}', "");
Expect(1, 131361, '\P{^Numeric_Value=0005}', "");
Expect(0, 131362, '\p{Numeric_Value=0005}', "");
Expect(1, 131362, '\p{^Numeric_Value=0005}', "");
Expect(1, 131362, '\P{Numeric_Value=0005}', "");
Expect(0, 131362, '\P{^Numeric_Value=0005}', "");
Error('\p{Nv= :=05}');
Error('\P{Nv= :=05}');
Expect(1, 131361, '\p{Nv=05}', "");
Expect(0, 131361, '\p{^Nv=05}', "");
Expect(0, 131361, '\P{Nv=05}', "");
Expect(1, 131361, '\P{^Nv=05}', "");
Expect(0, 131362, '\p{Nv=05}', "");
Expect(1, 131362, '\p{^Nv=05}', "");
Expect(1, 131362, '\P{Nv=05}', "");
Expect(0, 131362, '\P{^Nv=05}', "");
Error('\p{Is_Numeric_Value=/a/_-5}');
Error('\P{Is_Numeric_Value=/a/_-5}');
Expect(1, 131361, '\p{Is_Numeric_Value=+5}', "");
Expect(0, 131361, '\p{^Is_Numeric_Value=+5}', "");
Expect(0, 131361, '\P{Is_Numeric_Value=+5}', "");
Expect(1, 131361, '\P{^Is_Numeric_Value=+5}', "");
Expect(0, 131362, '\p{Is_Numeric_Value=+5}', "");
Expect(1, 131362, '\p{^Is_Numeric_Value=+5}', "");
Expect(1, 131362, '\P{Is_Numeric_Value=+5}', "");
Expect(0, 131362, '\P{^Is_Numeric_Value=+5}', "");
Error('\p{Is_Nv=	/a/00005}');
Error('\P{Is_Nv=	/a/00005}');
Expect(1, 131361, '\p{Is_Nv:   00000_5}', "");
Expect(0, 131361, '\p{^Is_Nv:   00000_5}', "");
Expect(0, 131361, '\P{Is_Nv:   00000_5}', "");
Expect(1, 131361, '\P{^Is_Nv:   00000_5}', "");
Expect(0, 131362, '\p{Is_Nv:   00000_5}', "");
Expect(1, 131362, '\p{^Is_Nv:   00000_5}', "");
Expect(1, 131362, '\P{Is_Nv:   00000_5}', "");
Expect(0, 131362, '\P{^Is_Nv:   00000_5}', "");
Error('\p{Numeric_Value=__+5/02:=}');
Error('\P{Numeric_Value=__+5/02:=}');
Expect(1, 3884, '\p{Numeric_Value=+000000005/0000000002}', "");
Expect(0, 3884, '\p{^Numeric_Value=+000000005/0000000002}', "");
Expect(0, 3884, '\P{Numeric_Value=+000000005/0000000002}', "");
Expect(1, 3884, '\P{^Numeric_Value=+000000005/0000000002}', "");
Expect(0, 3885, '\p{Numeric_Value=+000000005/0000000002}', "");
Expect(1, 3885, '\p{^Numeric_Value=+000000005/0000000002}', "");
Expect(1, 3885, '\P{Numeric_Value=+000000005/0000000002}', "");
Expect(0, 3885, '\P{^Numeric_Value=+000000005/0000000002}', "");
Expect(1, 3884, '\p{Numeric_Value=2.500}', "");
Expect(0, 3884, '\p{^Numeric_Value=2.500}', "");
Expect(0, 3884, '\P{Numeric_Value=2.500}', "");
Expect(1, 3884, '\P{^Numeric_Value=2.500}', "");
Expect(0, 3885, '\p{Numeric_Value=2.500}', "");
Expect(1, 3885, '\p{^Numeric_Value=2.500}', "");
Expect(1, 3885, '\P{Numeric_Value=2.500}', "");
Expect(0, 3885, '\P{^Numeric_Value=2.500}', "");
Error('\p{Nv=-:=5/000000002}');
Error('\P{Nv=-:=5/000000002}');
Expect(1, 3884, '\p{Nv:000000005/00000002}', "");
Expect(0, 3884, '\p{^Nv:000000005/00000002}', "");
Expect(0, 3884, '\P{Nv:000000005/00000002}', "");
Expect(1, 3884, '\P{^Nv:000000005/00000002}', "");
Expect(0, 3885, '\p{Nv:000000005/00000002}', "");
Expect(1, 3885, '\p{^Nv:000000005/00000002}', "");
Expect(1, 3885, '\P{Nv:000000005/00000002}', "");
Expect(0, 3885, '\P{^Nv:000000005/00000002}', "");
Expect(1, 3884, '\p{Nv=2.500}', "");
Expect(0, 3884, '\p{^Nv=2.500}', "");
Expect(0, 3884, '\P{Nv=2.500}', "");
Expect(1, 3884, '\P{^Nv=2.500}', "");
Expect(0, 3885, '\p{Nv=2.500}', "");
Expect(1, 3885, '\p{^Nv=2.500}', "");
Expect(1, 3885, '\P{Nv=2.500}', "");
Expect(0, 3885, '\P{^Nv=2.500}', "");
Error('\p{Is_Numeric_Value=	0000005/000000002:=}');
Error('\P{Is_Numeric_Value=	0000005/000000002:=}');
Expect(1, 3884, '\p{Is_Numeric_Value=05/00002}', "");
Expect(0, 3884, '\p{^Is_Numeric_Value=05/00002}', "");
Expect(0, 3884, '\P{Is_Numeric_Value=05/00002}', "");
Expect(1, 3884, '\P{^Is_Numeric_Value=05/00002}', "");
Expect(0, 3885, '\p{Is_Numeric_Value=05/00002}', "");
Expect(1, 3885, '\p{^Is_Numeric_Value=05/00002}', "");
Expect(1, 3885, '\P{Is_Numeric_Value=05/00002}', "");
Expect(0, 3885, '\P{^Is_Numeric_Value=05/00002}', "");
Expect(1, 3884, '\p{Is_Numeric_Value=2.500}', "");
Expect(0, 3884, '\p{^Is_Numeric_Value=2.500}', "");
Expect(0, 3884, '\P{Is_Numeric_Value=2.500}', "");
Expect(1, 3884, '\P{^Is_Numeric_Value=2.500}', "");
Expect(0, 3885, '\p{Is_Numeric_Value=2.500}', "");
Expect(1, 3885, '\p{^Is_Numeric_Value=2.500}', "");
Expect(1, 3885, '\P{Is_Numeric_Value=2.500}', "");
Expect(0, 3885, '\P{^Is_Numeric_Value=2.500}', "");
Error('\p{Is_Nv=	:=000000005/0002}');
Error('\P{Is_Nv=	:=000000005/0002}');
Expect(1, 3884, '\p{Is_Nv: +0000000005/000000002}', "");
Expect(0, 3884, '\p{^Is_Nv: +0000000005/000000002}', "");
Expect(0, 3884, '\P{Is_Nv: +0000000005/000000002}', "");
Expect(1, 3884, '\P{^Is_Nv: +0000000005/000000002}', "");
Expect(0, 3885, '\p{Is_Nv: +0000000005/000000002}', "");
Expect(1, 3885, '\p{^Is_Nv: +0000000005/000000002}', "");
Expect(1, 3885, '\P{Is_Nv: +0000000005/000000002}', "");
Expect(0, 3885, '\P{^Is_Nv: +0000000005/000000002}', "");
Expect(1, 3884, '\p{Is_Nv=2.500}', "");
Expect(0, 3884, '\p{^Is_Nv=2.500}', "");
Expect(0, 3884, '\P{Is_Nv=2.500}', "");
Expect(1, 3884, '\P{^Is_Nv=2.500}', "");
Expect(0, 3885, '\p{Is_Nv=2.500}', "");
Expect(1, 3885, '\p{^Is_Nv=2.500}', "");
Expect(1, 3885, '\P{Is_Nv=2.500}', "");
Expect(0, 3885, '\P{^Is_Nv=2.500}', "");
Error('\p{Numeric_Value=/a/	 +0000005/006}');
Error('\P{Numeric_Value=/a/	 +0000005/006}');
Expect(1, 74844, '\p{Numeric_Value=000005/06}', "");
Expect(0, 74844, '\p{^Numeric_Value=000005/06}', "");
Expect(0, 74844, '\P{Numeric_Value=000005/06}', "");
Expect(1, 74844, '\P{^Numeric_Value=000005/06}', "");
Expect(0, 74845, '\p{Numeric_Value=000005/06}', "");
Expect(1, 74845, '\p{^Numeric_Value=000005/06}', "");
Expect(1, 74845, '\P{Numeric_Value=000005/06}', "");
Expect(0, 74845, '\P{^Numeric_Value=000005/06}', "");
Error('\p{Numeric_Value=0.83}');
Error('\P{Numeric_Value=0.83}');
Expect(1, 74844, '\p{Numeric_Value=0.833}', "");
Expect(0, 74844, '\p{^Numeric_Value=0.833}', "");
Expect(0, 74844, '\P{Numeric_Value=0.833}', "");
Expect(1, 74844, '\P{^Numeric_Value=0.833}', "");
Expect(0, 74845, '\p{Numeric_Value=0.833}', "");
Expect(1, 74845, '\p{^Numeric_Value=0.833}', "");
Expect(1, 74845, '\P{Numeric_Value=0.833}', "");
Expect(0, 74845, '\P{^Numeric_Value=0.833}', "");
Error('\p{Nv=/a/- +0005/00000006}');
Error('\P{Nv=/a/- +0005/00000006}');
Expect(1, 74844, '\p{Nv=0005/0000006}', "");
Expect(0, 74844, '\p{^Nv=0005/0000006}', "");
Expect(0, 74844, '\P{Nv=0005/0000006}', "");
Expect(1, 74844, '\P{^Nv=0005/0000006}', "");
Expect(0, 74845, '\p{Nv=0005/0000006}', "");
Expect(1, 74845, '\p{^Nv=0005/0000006}', "");
Expect(1, 74845, '\P{Nv=0005/0000006}', "");
Expect(0, 74845, '\P{^Nv=0005/0000006}', "");
Error('\p{Nv=0.83}');
Error('\P{Nv=0.83}');
Expect(1, 74844, '\p{Nv=0.833}', "");
Expect(0, 74844, '\p{^Nv=0.833}', "");
Expect(0, 74844, '\P{Nv=0.833}', "");
Expect(1, 74844, '\P{^Nv=0.833}', "");
Expect(0, 74845, '\p{Nv=0.833}', "");
Expect(1, 74845, '\p{^Nv=0.833}', "");
Expect(1, 74845, '\P{Nv=0.833}', "");
Expect(0, 74845, '\P{^Nv=0.833}', "");
Error('\p{Is_Numeric_Value=--+005/00006:=}');
Error('\P{Is_Numeric_Value=--+005/00006:=}');
Expect(1, 74844, '\p{Is_Numeric_Value=0000000005/0000006}', "");
Expect(0, 74844, '\p{^Is_Numeric_Value=0000000005/0000006}', "");
Expect(0, 74844, '\P{Is_Numeric_Value=0000000005/0000006}', "");
Expect(1, 74844, '\P{^Is_Numeric_Value=0000000005/0000006}', "");
Expect(0, 74845, '\p{Is_Numeric_Value=0000000005/0000006}', "");
Expect(1, 74845, '\p{^Is_Numeric_Value=0000000005/0000006}', "");
Expect(1, 74845, '\P{Is_Numeric_Value=0000000005/0000006}', "");
Expect(0, 74845, '\P{^Is_Numeric_Value=0000000005/0000006}', "");
Error('\p{Is_Numeric_Value=0.83}');
Error('\P{Is_Numeric_Value=0.83}');
Expect(1, 74844, '\p{Is_Numeric_Value=0.833}', "");
Expect(0, 74844, '\p{^Is_Numeric_Value=0.833}', "");
Expect(0, 74844, '\P{Is_Numeric_Value=0.833}', "");
Expect(1, 74844, '\P{^Is_Numeric_Value=0.833}', "");
Expect(0, 74845, '\p{Is_Numeric_Value=0.833}', "");
Expect(1, 74845, '\p{^Is_Numeric_Value=0.833}', "");
Expect(1, 74845, '\P{Is_Numeric_Value=0.833}', "");
Expect(0, 74845, '\P{^Is_Numeric_Value=0.833}', "");
Error('\p{Is_Nv:	/a/-	005/00006}');
Error('\P{Is_Nv:	/a/-	005/00006}');
Expect(1, 74844, '\p{Is_Nv=0000000005/006}', "");
Expect(0, 74844, '\p{^Is_Nv=0000000005/006}', "");
Expect(0, 74844, '\P{Is_Nv=0000000005/006}', "");
Expect(1, 74844, '\P{^Is_Nv=0000000005/006}', "");
Expect(0, 74845, '\p{Is_Nv=0000000005/006}', "");
Expect(1, 74845, '\p{^Is_Nv=0000000005/006}', "");
Expect(1, 74845, '\P{Is_Nv=0000000005/006}', "");
Expect(0, 74845, '\P{^Is_Nv=0000000005/006}', "");
Error('\p{Is_Nv:0.83}');
Error('\P{Is_Nv:0.83}');
Expect(1, 74844, '\p{Is_Nv=0.833}', "");
Expect(0, 74844, '\p{^Is_Nv=0.833}', "");
Expect(0, 74844, '\P{Is_Nv=0.833}', "");
Expect(1, 74844, '\P{^Is_Nv=0.833}', "");
Expect(0, 74845, '\p{Is_Nv=0.833}', "");
Expect(1, 74845, '\p{^Is_Nv=0.833}', "");
Expect(1, 74845, '\P{Is_Nv=0.833}', "");
Expect(0, 74845, '\P{^Is_Nv=0.833}', "");
Error('\p{Numeric_Value=_-+5/00000008/a/}');
Error('\P{Numeric_Value=_-+5/00000008/a/}');
Expect(1, 8541, '\p{Numeric_Value=05/8}', "");
Expect(0, 8541, '\p{^Numeric_Value=05/8}', "");
Expect(0, 8541, '\P{Numeric_Value=05/8}', "");
Expect(1, 8541, '\P{^Numeric_Value=05/8}', "");
Expect(0, 8542, '\p{Numeric_Value=05/8}', "");
Expect(1, 8542, '\p{^Numeric_Value=05/8}', "");
Expect(1, 8542, '\P{Numeric_Value=05/8}', "");
Expect(0, 8542, '\P{^Numeric_Value=05/8}', "");
Error('\p{Numeric_Value=0.62}');
Error('\P{Numeric_Value=0.62}');
Expect(1, 8541, '\p{Numeric_Value=0.625}', "");
Expect(0, 8541, '\p{^Numeric_Value=0.625}', "");
Expect(0, 8541, '\P{Numeric_Value=0.625}', "");
Expect(1, 8541, '\P{^Numeric_Value=0.625}', "");
Expect(0, 8542, '\p{Numeric_Value=0.625}', "");
Expect(1, 8542, '\p{^Numeric_Value=0.625}', "");
Expect(1, 8542, '\P{Numeric_Value=0.625}', "");
Expect(0, 8542, '\P{^Numeric_Value=0.625}', "");
Error('\p{Nv:   /a/--+05/8}');
Error('\P{Nv:   /a/--+05/8}');
Expect(1, 8541, '\p{Nv=+0000000005/0000008}', "");
Expect(0, 8541, '\p{^Nv=+0000000005/0000008}', "");
Expect(0, 8541, '\P{Nv=+0000000005/0000008}', "");
Expect(1, 8541, '\P{^Nv=+0000000005/0000008}', "");
Expect(0, 8542, '\p{Nv=+0000000005/0000008}', "");
Expect(1, 8542, '\p{^Nv=+0000000005/0000008}', "");
Expect(1, 8542, '\P{Nv=+0000000005/0000008}', "");
Expect(0, 8542, '\P{^Nv=+0000000005/0000008}', "");
Error('\p{Nv=0.62}');
Error('\P{Nv=0.62}');
Expect(1, 8541, '\p{Nv=0.625}', "");
Expect(0, 8541, '\p{^Nv=0.625}', "");
Expect(0, 8541, '\P{Nv=0.625}', "");
Expect(1, 8541, '\P{^Nv=0.625}', "");
Expect(0, 8542, '\p{Nv=0.625}', "");
Expect(1, 8542, '\p{^Nv=0.625}', "");
Expect(1, 8542, '\P{Nv=0.625}', "");
Expect(0, 8542, '\P{^Nv=0.625}', "");
Error('\p{Is_Numeric_Value=	00005/00000008/a/}');
Error('\P{Is_Numeric_Value=	00005/00000008/a/}');
Expect(1, 8541, '\p{Is_Numeric_Value=5/0000000008}', "");
Expect(0, 8541, '\p{^Is_Numeric_Value=5/0000000008}', "");
Expect(0, 8541, '\P{Is_Numeric_Value=5/0000000008}', "");
Expect(1, 8541, '\P{^Is_Numeric_Value=5/0000000008}', "");
Expect(0, 8542, '\p{Is_Numeric_Value=5/0000000008}', "");
Expect(1, 8542, '\p{^Is_Numeric_Value=5/0000000008}', "");
Expect(1, 8542, '\P{Is_Numeric_Value=5/0000000008}', "");
Expect(0, 8542, '\P{^Is_Numeric_Value=5/0000000008}', "");
Error('\p{Is_Numeric_Value=0.62}');
Error('\P{Is_Numeric_Value=0.62}');
Expect(1, 8541, '\p{Is_Numeric_Value=0.625}', "");
Expect(0, 8541, '\p{^Is_Numeric_Value=0.625}', "");
Expect(0, 8541, '\P{Is_Numeric_Value=0.625}', "");
Expect(1, 8541, '\P{^Is_Numeric_Value=0.625}', "");
Expect(0, 8542, '\p{Is_Numeric_Value=0.625}', "");
Expect(1, 8542, '\p{^Is_Numeric_Value=0.625}', "");
Expect(1, 8542, '\P{Is_Numeric_Value=0.625}', "");
Expect(0, 8542, '\P{^Is_Numeric_Value=0.625}', "");
Error('\p{Is_Nv=/a/--000000005/00000008}');
Error('\P{Is_Nv=/a/--000000005/00000008}');
Expect(1, 8541, '\p{Is_Nv:0005/000000008}', "");
Expect(0, 8541, '\p{^Is_Nv:0005/000000008}', "");
Expect(0, 8541, '\P{Is_Nv:0005/000000008}', "");
Expect(1, 8541, '\P{^Is_Nv:0005/000000008}', "");
Expect(0, 8542, '\p{Is_Nv:0005/000000008}', "");
Expect(1, 8542, '\p{^Is_Nv:0005/000000008}', "");
Expect(1, 8542, '\P{Is_Nv:0005/000000008}', "");
Expect(0, 8542, '\P{^Is_Nv:0005/000000008}', "");
Error('\p{Is_Nv=0.62}');
Error('\P{Is_Nv=0.62}');
Expect(1, 8541, '\p{Is_Nv=0.625}', "");
Expect(0, 8541, '\p{^Is_Nv=0.625}', "");
Expect(0, 8541, '\P{Is_Nv=0.625}', "");
Expect(1, 8541, '\P{^Is_Nv=0.625}', "");
Expect(0, 8542, '\p{Is_Nv=0.625}', "");
Expect(1, 8542, '\p{^Is_Nv=0.625}', "");
Expect(1, 8542, '\P{Is_Nv=0.625}', "");
Expect(0, 8542, '\P{^Is_Nv=0.625}', "");
Error('\p{Numeric_Value=:=--+050}');
Error('\P{Numeric_Value=:=--+050}');
Expect(1, 119661, '\p{Numeric_Value=0_0_0_0_0_0_0_0_050}', "");
Expect(0, 119661, '\p{^Numeric_Value=0_0_0_0_0_0_0_0_050}', "");
Expect(0, 119661, '\P{Numeric_Value=0_0_0_0_0_0_0_0_050}', "");
Expect(1, 119661, '\P{^Numeric_Value=0_0_0_0_0_0_0_0_050}', "");
Expect(0, 119662, '\p{Numeric_Value=0_0_0_0_0_0_0_0_050}', "");
Expect(1, 119662, '\p{^Numeric_Value=0_0_0_0_0_0_0_0_050}', "");
Expect(1, 119662, '\P{Numeric_Value=0_0_0_0_0_0_0_0_050}', "");
Expect(0, 119662, '\P{^Numeric_Value=0_0_0_0_0_0_0_0_050}', "");
Error('\p{Nv=/a/_ 0_0_0_0_0_0_0_0050}');
Error('\P{Nv=/a/_ 0_0_0_0_0_0_0_0050}');
Expect(1, 119661, '\p{Nv=000050}', "");
Expect(0, 119661, '\p{^Nv=000050}', "");
Expect(0, 119661, '\P{Nv=000050}', "");
Expect(1, 119661, '\P{^Nv=000050}', "");
Expect(0, 119662, '\p{Nv=000050}', "");
Expect(1, 119662, '\p{^Nv=000050}', "");
Expect(1, 119662, '\P{Nv=000050}', "");
Expect(0, 119662, '\P{^Nv=000050}', "");
Error('\p{Is_Numeric_Value=	/a/+0_0_0_0_0_0_050}');
Error('\P{Is_Numeric_Value=	/a/+0_0_0_0_0_0_050}');
Expect(1, 119661, '\p{Is_Numeric_Value=5_0}', "");
Expect(0, 119661, '\p{^Is_Numeric_Value=5_0}', "");
Expect(0, 119661, '\P{Is_Numeric_Value=5_0}', "");
Expect(1, 119661, '\P{^Is_Numeric_Value=5_0}', "");
Expect(0, 119662, '\p{Is_Numeric_Value=5_0}', "");
Expect(1, 119662, '\p{^Is_Numeric_Value=5_0}', "");
Expect(1, 119662, '\P{Is_Numeric_Value=5_0}', "");
Expect(0, 119662, '\P{^Is_Numeric_Value=5_0}', "");
Error('\p{Is_Nv=--00000000050/a/}');
Error('\P{Is_Nv=--00000000050/a/}');
Expect(1, 119661, '\p{Is_Nv=00000050}', "");
Expect(0, 119661, '\p{^Is_Nv=00000050}', "");
Expect(0, 119661, '\P{Is_Nv=00000050}', "");
Expect(1, 119661, '\P{^Is_Nv=00000050}', "");
Expect(0, 119662, '\p{Is_Nv=00000050}', "");
Expect(1, 119662, '\p{^Is_Nv=00000050}', "");
Expect(1, 119662, '\P{Is_Nv=00000050}', "");
Expect(0, 119662, '\P{^Is_Nv=00000050}', "");
Error('\p{Numeric_Value=/a/50_0}');
Error('\P{Numeric_Value=/a/50_0}');
Expect(1, 69238, '\p{Numeric_Value=000_005_00}', "");
Expect(0, 69238, '\p{^Numeric_Value=000_005_00}', "");
Expect(0, 69238, '\P{Numeric_Value=000_005_00}', "");
Expect(1, 69238, '\P{^Numeric_Value=000_005_00}', "");
Expect(0, 69239, '\p{Numeric_Value=000_005_00}', "");
Expect(1, 69239, '\p{^Numeric_Value=000_005_00}', "");
Expect(1, 69239, '\P{Numeric_Value=000_005_00}', "");
Expect(0, 69239, '\P{^Numeric_Value=000_005_00}', "");
Error('\p{Nv=/a/--+0_0_0_0_0_0_0_00500}');
Error('\P{Nv=/a/--+0_0_0_0_0_0_0_00500}');
Expect(1, 69238, '\p{Nv=000000500}', "");
Expect(0, 69238, '\p{^Nv=000000500}', "");
Expect(0, 69238, '\P{Nv=000000500}', "");
Expect(1, 69238, '\P{^Nv=000000500}', "");
Expect(0, 69239, '\p{Nv=000000500}', "");
Expect(1, 69239, '\p{^Nv=000000500}', "");
Expect(1, 69239, '\P{Nv=000000500}', "");
Expect(0, 69239, '\P{^Nv=000000500}', "");
Error('\p{Is_Numeric_Value=/a/  +00_00_00_00_50_0}');
Error('\P{Is_Numeric_Value=/a/  +00_00_00_00_50_0}');
Expect(1, 69238, '\p{Is_Numeric_Value=+0000500}', "");
Expect(0, 69238, '\p{^Is_Numeric_Value=+0000500}', "");
Expect(0, 69238, '\P{Is_Numeric_Value=+0000500}', "");
Expect(1, 69238, '\P{^Is_Numeric_Value=+0000500}', "");
Expect(0, 69239, '\p{Is_Numeric_Value=+0000500}', "");
Expect(1, 69239, '\p{^Is_Numeric_Value=+0000500}', "");
Expect(1, 69239, '\P{Is_Numeric_Value=+0000500}', "");
Expect(0, 69239, '\P{^Is_Numeric_Value=+0000500}', "");
Error('\p{Is_Nv=- 0_0_0_0_0_0_0_0_0500:=}');
Error('\P{Is_Nv=- 0_0_0_0_0_0_0_0_0500:=}');
Expect(1, 69238, '\p{Is_Nv=000000000500}', "");
Expect(0, 69238, '\p{^Is_Nv=000000000500}', "");
Expect(0, 69238, '\P{Is_Nv=000000000500}', "");
Expect(1, 69238, '\P{^Is_Nv=000000000500}', "");
Expect(0, 69239, '\p{Is_Nv=000000000500}', "");
Expect(1, 69239, '\p{^Is_Nv=000000000500}', "");
Expect(1, 69239, '\P{Is_Nv=000000000500}', "");
Expect(0, 69239, '\P{^Is_Nv=000000000500}', "");
Error('\p{Numeric_Value=/a/	 +00_00_00_00_05_000}');
Error('\P{Numeric_Value=/a/	 +00_00_00_00_05_000}');
Expect(1, 65906, '\p{Numeric_Value=000500_0}', "");
Expect(0, 65906, '\p{^Numeric_Value=000500_0}', "");
Expect(0, 65906, '\P{Numeric_Value=000500_0}', "");
Expect(1, 65906, '\P{^Numeric_Value=000500_0}', "");
Expect(0, 65907, '\p{Numeric_Value=000500_0}', "");
Expect(1, 65907, '\p{^Numeric_Value=000500_0}', "");
Expect(1, 65907, '\P{Numeric_Value=000500_0}', "");
Expect(0, 65907, '\P{^Numeric_Value=000500_0}', "");
Error('\p{Nv: -00_50_00:=}');
Error('\P{Nv: -00_50_00:=}');
Expect(1, 65906, '\p{Nv=+0000005000}', "");
Expect(0, 65906, '\p{^Nv=+0000005000}', "");
Expect(0, 65906, '\P{Nv=+0000005000}', "");
Expect(1, 65906, '\P{^Nv=+0000005000}', "");
Expect(0, 65907, '\p{Nv=+0000005000}', "");
Expect(1, 65907, '\p{^Nv=+0000005000}', "");
Expect(1, 65907, '\P{Nv=+0000005000}', "");
Expect(0, 65907, '\P{^Nv=+0000005000}', "");
Error('\p{Is_Numeric_Value=/a/	0_0_0_0_0_5_000}');
Error('\P{Is_Numeric_Value=/a/	0_0_0_0_0_5_000}');
Expect(1, 65906, '\p{Is_Numeric_Value=5_0_00}', "");
Expect(0, 65906, '\p{^Is_Numeric_Value=5_0_00}', "");
Expect(0, 65906, '\P{Is_Numeric_Value=5_0_00}', "");
Expect(1, 65906, '\P{^Is_Numeric_Value=5_0_00}', "");
Expect(0, 65907, '\p{Is_Numeric_Value=5_0_00}', "");
Expect(1, 65907, '\p{^Is_Numeric_Value=5_0_00}', "");
Expect(1, 65907, '\P{Is_Numeric_Value=5_0_00}', "");
Expect(0, 65907, '\P{^Is_Numeric_Value=5_0_00}', "");
Error('\p{Is_Nv=/a/	000000500_0}');
Error('\P{Is_Nv=/a/	000000500_0}');
Expect(1, 65906, '\p{Is_Nv=+000005000}', "");
Expect(0, 65906, '\p{^Is_Nv=+000005000}', "");
Expect(0, 65906, '\P{Is_Nv=+000005000}', "");
Expect(1, 65906, '\P{^Is_Nv=+000005000}', "");
Expect(0, 65907, '\p{Is_Nv=+000005000}', "");
Expect(1, 65907, '\p{^Is_Nv=+000005000}', "");
Expect(1, 65907, '\P{Is_Nv=+000005000}', "");
Expect(0, 65907, '\P{^Is_Nv=+000005000}', "");
Error('\p{Numeric_Value= /a/00000050000}');
Error('\P{Numeric_Value= /a/00000050000}');
Expect(1, 65878, '\p{Numeric_Value=00005000_0}', "");
Expect(0, 65878, '\p{^Numeric_Value=00005000_0}', "");
Expect(0, 65878, '\P{Numeric_Value=00005000_0}', "");
Expect(1, 65878, '\P{^Numeric_Value=00005000_0}', "");
Expect(0, 65879, '\p{Numeric_Value=00005000_0}', "");
Expect(1, 65879, '\p{^Numeric_Value=00005000_0}', "");
Expect(1, 65879, '\P{Numeric_Value=00005000_0}', "");
Expect(0, 65879, '\P{^Numeric_Value=00005000_0}', "");
Error('\p{Nv: :=	 +50_00_0}');
Error('\P{Nv: :=	 +50_00_0}');
Expect(1, 65878, '\p{Nv=+0_0_0_5_0_000}', "");
Expect(0, 65878, '\p{^Nv=+0_0_0_5_0_000}', "");
Expect(0, 65878, '\P{Nv=+0_0_0_5_0_000}', "");
Expect(1, 65878, '\P{^Nv=+0_0_0_5_0_000}', "");
Expect(0, 65879, '\p{Nv=+0_0_0_5_0_000}', "");
Expect(1, 65879, '\p{^Nv=+0_0_0_5_0_000}', "");
Expect(1, 65879, '\P{Nv=+0_0_0_5_0_000}', "");
Expect(0, 65879, '\P{^Nv=+0_0_0_5_0_000}', "");
Error('\p{Is_Numeric_Value=_	00050000:=}');
Error('\P{Is_Numeric_Value=_	00050000:=}');
Expect(1, 65878, '\p{Is_Numeric_Value=00050000}', "");
Expect(0, 65878, '\p{^Is_Numeric_Value=00050000}', "");
Expect(0, 65878, '\P{Is_Numeric_Value=00050000}', "");
Expect(1, 65878, '\P{^Is_Numeric_Value=00050000}', "");
Expect(0, 65879, '\p{Is_Numeric_Value=00050000}', "");
Expect(1, 65879, '\p{^Is_Numeric_Value=00050000}', "");
Expect(1, 65879, '\P{Is_Numeric_Value=00050000}', "");
Expect(0, 65879, '\P{^Is_Numeric_Value=00050000}', "");
Error('\p{Is_Nv=/a/__05_00_00}');
Error('\P{Is_Nv=/a/__05_00_00}');
Expect(1, 65878, '\p{Is_Nv:   0005000_0}', "");
Expect(0, 65878, '\p{^Is_Nv:   0005000_0}', "");
Expect(0, 65878, '\P{Is_Nv:   0005000_0}', "");
Expect(1, 65878, '\P{^Is_Nv:   0005000_0}', "");
Expect(0, 65879, '\p{Is_Nv:   0005000_0}', "");
Expect(1, 65879, '\p{^Is_Nv:   0005000_0}', "");
Expect(1, 65879, '\P{Is_Nv:   0005000_0}', "");
Expect(0, 65879, '\P{^Is_Nv:   0005000_0}', "");
Error('\p{Numeric_Value=_+00006/a/}');
Error('\P{Numeric_Value=_+00006/a/}');
Expect(1, 133866, '\p{Numeric_Value=+0_0_0_0_0_006}', "");
Expect(0, 133866, '\p{^Numeric_Value=+0_0_0_0_0_006}', "");
Expect(0, 133866, '\P{Numeric_Value=+0_0_0_0_0_006}', "");
Expect(1, 133866, '\P{^Numeric_Value=+0_0_0_0_0_006}', "");
Expect(0, 133867, '\p{Numeric_Value=+0_0_0_0_0_006}', "");
Expect(1, 133867, '\p{^Numeric_Value=+0_0_0_0_0_006}', "");
Expect(1, 133867, '\P{Numeric_Value=+0_0_0_0_0_006}', "");
Expect(0, 133867, '\P{^Numeric_Value=+0_0_0_0_0_006}', "");
Error('\p{Nv=	/a/00000000_6}');
Error('\P{Nv=	/a/00000000_6}');
Expect(1, 133866, '\p{Nv=+0_6}', "");
Expect(0, 133866, '\p{^Nv=+0_6}', "");
Expect(0, 133866, '\P{Nv=+0_6}', "");
Expect(1, 133866, '\P{^Nv=+0_6}', "");
Expect(0, 133867, '\p{Nv=+0_6}', "");
Expect(1, 133867, '\p{^Nv=+0_6}', "");
Expect(1, 133867, '\P{Nv=+0_6}', "");
Expect(0, 133867, '\P{^Nv=+0_6}', "");
Error('\p{Is_Numeric_Value=:=		000_6}');
Error('\P{Is_Numeric_Value=:=		000_6}');
Expect(1, 133866, '\p{Is_Numeric_Value=0_6}', "");
Expect(0, 133866, '\p{^Is_Numeric_Value=0_6}', "");
Expect(0, 133866, '\P{Is_Numeric_Value=0_6}', "");
Expect(1, 133866, '\P{^Is_Numeric_Value=0_6}', "");
Expect(0, 133867, '\p{Is_Numeric_Value=0_6}', "");
Expect(1, 133867, '\p{^Is_Numeric_Value=0_6}', "");
Expect(1, 133867, '\P{Is_Numeric_Value=0_6}', "");
Expect(0, 133867, '\P{^Is_Numeric_Value=0_6}', "");
Error('\p{Is_Nv::=--+0006}');
Error('\P{Is_Nv::=--+0006}');
Expect(1, 133866, '\p{Is_Nv=+6}', "");
Expect(0, 133866, '\p{^Is_Nv=+6}', "");
Expect(0, 133866, '\P{Is_Nv=+6}', "");
Expect(1, 133866, '\P{^Is_Nv=+6}', "");
Expect(0, 133867, '\p{Is_Nv=+6}', "");
Expect(1, 133867, '\p{^Is_Nv=+6}', "");
Expect(1, 133867, '\P{Is_Nv=+6}', "");
Expect(0, 133867, '\P{^Is_Nv=+6}', "");
Error('\p{Numeric_Value=/a/  00000060}');
Error('\P{Numeric_Value=/a/  00000060}');
Expect(1, 119662, '\p{Numeric_Value=6_0}', "");
Expect(0, 119662, '\p{^Numeric_Value=6_0}', "");
Expect(0, 119662, '\P{Numeric_Value=6_0}', "");
Expect(1, 119662, '\P{^Numeric_Value=6_0}', "");
Expect(0, 119663, '\p{Numeric_Value=6_0}', "");
Expect(1, 119663, '\p{^Numeric_Value=6_0}', "");
Expect(1, 119663, '\P{Numeric_Value=6_0}', "");
Expect(0, 119663, '\P{^Numeric_Value=6_0}', "");
Error('\p{Nv= :=0000_0006_0}');
Error('\P{Nv= :=0000_0006_0}');
Expect(1, 119662, '\p{Nv=+6_0}', "");
Expect(0, 119662, '\p{^Nv=+6_0}', "");
Expect(0, 119662, '\P{Nv=+6_0}', "");
Expect(1, 119662, '\P{^Nv=+6_0}', "");
Expect(0, 119663, '\p{Nv=+6_0}', "");
Expect(1, 119663, '\p{^Nv=+6_0}', "");
Expect(1, 119663, '\P{Nv=+6_0}', "");
Expect(0, 119663, '\P{^Nv=+6_0}', "");
Error('\p{Is_Numeric_Value:/a/	_000060}');
Error('\P{Is_Numeric_Value:/a/	_000060}');
Expect(1, 119662, '\p{Is_Numeric_Value=00060}', "");
Expect(0, 119662, '\p{^Is_Numeric_Value=00060}', "");
Expect(0, 119662, '\P{Is_Numeric_Value=00060}', "");
Expect(1, 119662, '\P{^Is_Numeric_Value=00060}', "");
Expect(0, 119663, '\p{Is_Numeric_Value=00060}', "");
Expect(1, 119663, '\p{^Is_Numeric_Value=00060}', "");
Expect(1, 119663, '\P{Is_Numeric_Value=00060}', "");
Expect(0, 119663, '\P{^Is_Numeric_Value=00060}', "");
Error('\p{Is_Nv:   -:=+0_0_60}');
Error('\P{Is_Nv:   -:=+0_0_60}');
Expect(1, 119662, '\p{Is_Nv=60}', "");
Expect(0, 119662, '\p{^Is_Nv=60}', "");
Expect(0, 119662, '\P{Is_Nv=60}', "");
Expect(1, 119662, '\P{^Is_Nv=60}', "");
Expect(0, 119663, '\p{Is_Nv=60}', "");
Expect(1, 119663, '\p{^Is_Nv=60}', "");
Expect(1, 119663, '\P{Is_Nv=60}', "");
Expect(0, 119663, '\P{^Is_Nv=60}', "");
Error('\p{Numeric_Value=	:=00000600}');
Error('\P{Numeric_Value=	:=00000600}');
Expect(1, 69239, '\p{Numeric_Value=+0_6_00}', "");
Expect(0, 69239, '\p{^Numeric_Value=+0_6_00}', "");
Expect(0, 69239, '\P{Numeric_Value=+0_6_00}', "");
Expect(1, 69239, '\P{^Numeric_Value=+0_6_00}', "");
Expect(0, 69240, '\p{Numeric_Value=+0_6_00}', "");
Expect(1, 69240, '\p{^Numeric_Value=+0_6_00}', "");
Expect(1, 69240, '\P{Numeric_Value=+0_6_00}', "");
Expect(0, 69240, '\P{^Numeric_Value=+0_6_00}', "");
Error('\p{Nv=:=	 0000_0006_00}');
Error('\P{Nv=:=	 0000_0006_00}');
Expect(1, 69239, '\p{Nv=00600}', "");
Expect(0, 69239, '\p{^Nv=00600}', "");
Expect(0, 69239, '\P{Nv=00600}', "");
Expect(1, 69239, '\P{^Nv=00600}', "");
Expect(0, 69240, '\p{Nv=00600}', "");
Expect(1, 69240, '\p{^Nv=00600}', "");
Expect(1, 69240, '\P{Nv=00600}', "");
Expect(0, 69240, '\P{^Nv=00600}', "");
Error('\p{Is_Numeric_Value=/a/	 00_00_60_0}');
Error('\P{Is_Numeric_Value=/a/	 00_00_60_0}');
Expect(1, 69239, '\p{Is_Numeric_Value=000600}', "");
Expect(0, 69239, '\p{^Is_Numeric_Value=000600}', "");
Expect(0, 69239, '\P{Is_Numeric_Value=000600}', "");
Expect(1, 69239, '\P{^Is_Numeric_Value=000600}', "");
Expect(0, 69240, '\p{Is_Numeric_Value=000600}', "");
Expect(1, 69240, '\p{^Is_Numeric_Value=000600}', "");
Expect(1, 69240, '\P{Is_Numeric_Value=000600}', "");
Expect(0, 69240, '\P{^Is_Numeric_Value=000600}', "");
Error('\p{Is_Nv=:=-	00_60_0}');
Error('\P{Is_Nv=:=-	00_60_0}');
Expect(1, 69239, '\p{Is_Nv=+000000600}', "");
Expect(0, 69239, '\p{^Is_Nv=+000000600}', "");
Expect(0, 69239, '\P{Is_Nv=+000000600}', "");
Expect(1, 69239, '\P{^Is_Nv=+000000600}', "");
Expect(0, 69240, '\p{Is_Nv=+000000600}', "");
Expect(1, 69240, '\p{^Is_Nv=+000000600}', "");
Expect(1, 69240, '\P{Is_Nv=+000000600}', "");
Expect(0, 69240, '\P{^Is_Nv=+000000600}', "");
Error('\p{Numeric_Value=	0_0_0_0_0_0_0_6_000/a/}');
Error('\P{Numeric_Value=	0_0_0_0_0_0_0_6_000/a/}');
Expect(1, 65831, '\p{Numeric_Value=00600_0}', "");
Expect(0, 65831, '\p{^Numeric_Value=00600_0}', "");
Expect(0, 65831, '\P{Numeric_Value=00600_0}', "");
Expect(1, 65831, '\P{^Numeric_Value=00600_0}', "");
Expect(0, 65832, '\p{Numeric_Value=00600_0}', "");
Expect(1, 65832, '\p{^Numeric_Value=00600_0}', "");
Expect(1, 65832, '\P{Numeric_Value=00600_0}', "");
Expect(0, 65832, '\P{^Numeric_Value=00600_0}', "");
Error('\p{Nv=	-+0_0_0_0_0_0_6000:=}');
Error('\P{Nv=	-+0_0_0_0_0_0_6000:=}');
Expect(1, 65831, '\p{Nv=+06000}', "");
Expect(0, 65831, '\p{^Nv=+06000}', "");
Expect(0, 65831, '\P{Nv=+06000}', "");
Expect(1, 65831, '\P{^Nv=+06000}', "");
Expect(0, 65832, '\p{Nv=+06000}', "");
Expect(1, 65832, '\p{^Nv=+06000}', "");
Expect(1, 65832, '\P{Nv=+06000}', "");
Expect(0, 65832, '\P{^Nv=+06000}', "");
Error('\p{Is_Numeric_Value=	/a/00000006000}');
Error('\P{Is_Numeric_Value=	/a/00000006000}');
Expect(1, 65831, '\p{Is_Numeric_Value=+00006000}', "");
Expect(0, 65831, '\p{^Is_Numeric_Value=+00006000}', "");
Expect(0, 65831, '\P{Is_Numeric_Value=+00006000}', "");
Expect(1, 65831, '\P{^Is_Numeric_Value=+00006000}', "");
Expect(0, 65832, '\p{Is_Numeric_Value=+00006000}', "");
Expect(1, 65832, '\p{^Is_Numeric_Value=+00006000}', "");
Expect(1, 65832, '\P{Is_Numeric_Value=+00006000}', "");
Expect(0, 65832, '\P{^Is_Numeric_Value=+00006000}', "");
Error('\p{Is_Nv=:= 6_0_00}');
Error('\P{Is_Nv=:= 6_0_00}');
Expect(1, 65831, '\p{Is_Nv=0_0_0_0_0_0_0_006000}', "");
Expect(0, 65831, '\p{^Is_Nv=0_0_0_0_0_0_0_006000}', "");
Expect(0, 65831, '\P{Is_Nv=0_0_0_0_0_0_0_006000}', "");
Expect(1, 65831, '\P{^Is_Nv=0_0_0_0_0_0_0_006000}', "");
Expect(0, 65832, '\p{Is_Nv=0_0_0_0_0_0_0_006000}', "");
Expect(1, 65832, '\p{^Is_Nv=0_0_0_0_0_0_0_006000}', "");
Expect(1, 65832, '\P{Is_Nv=0_0_0_0_0_0_0_006000}', "");
Expect(0, 65832, '\P{^Is_Nv=0_0_0_0_0_0_0_006000}', "");
Error('\p{Numeric_Value=__0_0_6_0_0_00/a/}');
Error('\P{Numeric_Value=__0_0_6_0_0_00/a/}');
Expect(1, 65840, '\p{Numeric_Value=0060000}', "");
Expect(0, 65840, '\p{^Numeric_Value=0060000}', "");
Expect(0, 65840, '\P{Numeric_Value=0060000}', "");
Expect(1, 65840, '\P{^Numeric_Value=0060000}', "");
Expect(0, 65841, '\p{Numeric_Value=0060000}', "");
Expect(1, 65841, '\p{^Numeric_Value=0060000}', "");
Expect(1, 65841, '\P{Numeric_Value=0060000}', "");
Expect(0, 65841, '\P{^Numeric_Value=0060000}', "");
Error('\p{Nv=- 6_0_0_00:=}');
Error('\P{Nv=- 6_0_0_00:=}');
Expect(1, 65840, '\p{Nv=+000060000}', "");
Expect(0, 65840, '\p{^Nv=+000060000}', "");
Expect(0, 65840, '\P{Nv=+000060000}', "");
Expect(1, 65840, '\P{^Nv=+000060000}', "");
Expect(0, 65841, '\p{Nv=+000060000}', "");
Expect(1, 65841, '\p{^Nv=+000060000}', "");
Expect(1, 65841, '\P{Nv=+000060000}', "");
Expect(0, 65841, '\P{^Nv=+000060000}', "");
Error('\p{Is_Numeric_Value=/a/ _0000000060000}');
Error('\P{Is_Numeric_Value=/a/ _0000000060000}');
Expect(1, 65840, '\p{Is_Numeric_Value=+000000060000}', "");
Expect(0, 65840, '\p{^Is_Numeric_Value=+000000060000}', "");
Expect(0, 65840, '\P{Is_Numeric_Value=+000000060000}', "");
Expect(1, 65840, '\P{^Is_Numeric_Value=+000000060000}', "");
Expect(0, 65841, '\p{Is_Numeric_Value=+000000060000}', "");
Expect(1, 65841, '\p{^Is_Numeric_Value=+000000060000}', "");
Expect(1, 65841, '\P{Is_Numeric_Value=+000000060000}', "");
Expect(0, 65841, '\P{^Is_Numeric_Value=+000000060000}', "");
Error('\p{Is_Nv=/a/- 00000000060000}');
Error('\P{Is_Nv=/a/- 00000000060000}');
Expect(1, 65840, '\p{Is_Nv=000006000_0}', "");
Expect(0, 65840, '\p{^Is_Nv=000006000_0}', "");
Expect(0, 65840, '\P{Is_Nv=000006000_0}', "");
Expect(1, 65840, '\P{^Is_Nv=000006000_0}', "");
Expect(0, 65841, '\p{Is_Nv=000006000_0}', "");
Expect(1, 65841, '\p{^Is_Nv=000006000_0}', "");
Expect(1, 65841, '\P{Is_Nv=000006000_0}', "");
Expect(0, 65841, '\P{^Is_Nv=000006000_0}', "");
Error('\p{Numeric_Value=_	+000007:=}');
Error('\P{Numeric_Value=_	+000007:=}');
Expect(1, 131073, '\p{Numeric_Value=00000_7}', "");
Expect(0, 131073, '\p{^Numeric_Value=00000_7}', "");
Expect(0, 131073, '\P{Numeric_Value=00000_7}', "");
Expect(1, 131073, '\P{^Numeric_Value=00000_7}', "");
Expect(0, 131074, '\p{Numeric_Value=00000_7}', "");
Expect(1, 131074, '\p{^Numeric_Value=00000_7}', "");
Expect(1, 131074, '\P{Numeric_Value=00000_7}', "");
Expect(0, 131074, '\P{^Numeric_Value=00000_7}', "");
Error('\p{Nv= _0_0_0_0_07:=}');
Error('\P{Nv= _0_0_0_0_07:=}');
Expect(1, 131073, '\p{Nv=00_00_00_7}', "");
Expect(0, 131073, '\p{^Nv=00_00_00_7}', "");
Expect(0, 131073, '\P{Nv=00_00_00_7}', "");
Expect(1, 131073, '\P{^Nv=00_00_00_7}', "");
Expect(0, 131074, '\p{Nv=00_00_00_7}', "");
Expect(1, 131074, '\p{^Nv=00_00_00_7}', "");
Expect(1, 131074, '\P{Nv=00_00_00_7}', "");
Expect(0, 131074, '\P{^Nv=00_00_00_7}', "");
Error('\p{Is_Numeric_Value: -0000007/a/}');
Error('\P{Is_Numeric_Value: -0000007/a/}');
Expect(1, 131073, '\p{Is_Numeric_Value=+0_0_0_07}', "");
Expect(0, 131073, '\p{^Is_Numeric_Value=+0_0_0_07}', "");
Expect(0, 131073, '\P{Is_Numeric_Value=+0_0_0_07}', "");
Expect(1, 131073, '\P{^Is_Numeric_Value=+0_0_0_07}', "");
Expect(0, 131074, '\p{Is_Numeric_Value=+0_0_0_07}', "");
Expect(1, 131074, '\p{^Is_Numeric_Value=+0_0_0_07}', "");
Expect(1, 131074, '\P{Is_Numeric_Value=+0_0_0_07}', "");
Expect(0, 131074, '\P{^Is_Numeric_Value=+0_0_0_07}', "");
Error('\p{Is_Nv=:=	00007}');
Error('\P{Is_Nv=:=	00007}');
Expect(1, 131073, '\p{Is_Nv=+007}', "");
Expect(0, 131073, '\p{^Is_Nv=+007}', "");
Expect(0, 131073, '\P{Is_Nv=+007}', "");
Expect(1, 131073, '\P{^Is_Nv=+007}', "");
Expect(0, 131074, '\p{Is_Nv=+007}', "");
Expect(1, 131074, '\p{^Is_Nv=+007}', "");
Expect(1, 131074, '\P{Is_Nv=+007}', "");
Expect(0, 131074, '\P{^Is_Nv=+007}', "");
Error('\p{Numeric_Value=	/a/+07/000002}');
Error('\P{Numeric_Value=	/a/+07/000002}');
Expect(1, 3885, '\p{Numeric_Value=00007/000000002}', "");
Expect(0, 3885, '\p{^Numeric_Value=00007/000000002}', "");
Expect(0, 3885, '\P{Numeric_Value=00007/000000002}', "");
Expect(1, 3885, '\P{^Numeric_Value=00007/000000002}', "");
Expect(0, 3886, '\p{Numeric_Value=00007/000000002}', "");
Expect(1, 3886, '\p{^Numeric_Value=00007/000000002}', "");
Expect(1, 3886, '\P{Numeric_Value=00007/000000002}', "");
Expect(0, 3886, '\P{^Numeric_Value=00007/000000002}', "");
Expect(1, 3885, '\p{Numeric_Value=3.500}', "");
Expect(0, 3885, '\p{^Numeric_Value=3.500}', "");
Expect(0, 3885, '\P{Numeric_Value=3.500}', "");
Expect(1, 3885, '\P{^Numeric_Value=3.500}', "");
Expect(0, 3886, '\p{Numeric_Value=3.500}', "");
Expect(1, 3886, '\p{^Numeric_Value=3.500}', "");
Expect(1, 3886, '\P{Numeric_Value=3.500}', "");
Expect(0, 3886, '\P{^Numeric_Value=3.500}', "");
Error('\p{Nv=-/a/0000007/000000002}');
Error('\P{Nv=-/a/0000007/000000002}');
Expect(1, 3885, '\p{Nv=000000007/0002}', "");
Expect(0, 3885, '\p{^Nv=000000007/0002}', "");
Expect(0, 3885, '\P{Nv=000000007/0002}', "");
Expect(1, 3885, '\P{^Nv=000000007/0002}', "");
Expect(0, 3886, '\p{Nv=000000007/0002}', "");
Expect(1, 3886, '\p{^Nv=000000007/0002}', "");
Expect(1, 3886, '\P{Nv=000000007/0002}', "");
Expect(0, 3886, '\P{^Nv=000000007/0002}', "");
Expect(1, 3885, '\p{Nv=3.500}', "");
Expect(0, 3885, '\p{^Nv=3.500}', "");
Expect(0, 3885, '\P{Nv=3.500}', "");
Expect(1, 3885, '\P{^Nv=3.500}', "");
Expect(0, 3886, '\p{Nv=3.500}', "");
Expect(1, 3886, '\p{^Nv=3.500}', "");
Expect(1, 3886, '\P{Nv=3.500}', "");
Expect(0, 3886, '\P{^Nv=3.500}', "");
Error('\p{Is_Numeric_Value=/a/_-007/00000002}');
Error('\P{Is_Numeric_Value=/a/_-007/00000002}');
Expect(1, 3885, '\p{Is_Numeric_Value:+00007/02}', "");
Expect(0, 3885, '\p{^Is_Numeric_Value:+00007/02}', "");
Expect(0, 3885, '\P{Is_Numeric_Value:+00007/02}', "");
Expect(1, 3885, '\P{^Is_Numeric_Value:+00007/02}', "");
Expect(0, 3886, '\p{Is_Numeric_Value:+00007/02}', "");
Expect(1, 3886, '\p{^Is_Numeric_Value:+00007/02}', "");
Expect(1, 3886, '\P{Is_Numeric_Value:+00007/02}', "");
Expect(0, 3886, '\P{^Is_Numeric_Value:+00007/02}', "");
Expect(1, 3885, '\p{Is_Numeric_Value=3.500}', "");
Expect(0, 3885, '\p{^Is_Numeric_Value=3.500}', "");
Expect(0, 3885, '\P{Is_Numeric_Value=3.500}', "");
Expect(1, 3885, '\P{^Is_Numeric_Value=3.500}', "");
Expect(0, 3886, '\p{Is_Numeric_Value=3.500}', "");
Expect(1, 3886, '\p{^Is_Numeric_Value=3.500}', "");
Expect(1, 3886, '\P{Is_Numeric_Value=3.500}', "");
Expect(0, 3886, '\P{^Is_Numeric_Value=3.500}', "");
Error('\p{Is_Nv=/a/_-000000007/000000002}');
Error('\P{Is_Nv=/a/_-000000007/000000002}');
Expect(1, 3885, '\p{Is_Nv=00000007/0000000002}', "");
Expect(0, 3885, '\p{^Is_Nv=00000007/0000000002}', "");
Expect(0, 3885, '\P{Is_Nv=00000007/0000000002}', "");
Expect(1, 3885, '\P{^Is_Nv=00000007/0000000002}', "");
Expect(0, 3886, '\p{Is_Nv=00000007/0000000002}', "");
Expect(1, 3886, '\p{^Is_Nv=00000007/0000000002}', "");
Expect(1, 3886, '\P{Is_Nv=00000007/0000000002}', "");
Expect(0, 3886, '\P{^Is_Nv=00000007/0000000002}', "");
Expect(1, 3885, '\p{Is_Nv=3.500}', "");
Expect(0, 3885, '\p{^Is_Nv=3.500}', "");
Expect(0, 3885, '\P{Is_Nv=3.500}', "");
Expect(1, 3885, '\P{^Is_Nv=3.500}', "");
Expect(0, 3886, '\p{Is_Nv=3.500}', "");
Expect(1, 3886, '\p{^Is_Nv=3.500}', "");
Expect(1, 3886, '\P{Is_Nv=3.500}', "");
Expect(0, 3886, '\P{^Is_Nv=3.500}', "");
Error('\p{Numeric_Value= /a/000007/008}');
Error('\P{Numeric_Value= /a/000007/008}');
Expect(1, 8542, '\p{Numeric_Value:	007/0008}', "");
Expect(0, 8542, '\p{^Numeric_Value:	007/0008}', "");
Expect(0, 8542, '\P{Numeric_Value:	007/0008}', "");
Expect(1, 8542, '\P{^Numeric_Value:	007/0008}', "");
Expect(0, 8543, '\p{Numeric_Value:	007/0008}', "");
Expect(1, 8543, '\p{^Numeric_Value:	007/0008}', "");
Expect(1, 8543, '\P{Numeric_Value:	007/0008}', "");
Expect(0, 8543, '\P{^Numeric_Value:	007/0008}', "");
Error('\p{Numeric_Value:	0.9}');
Error('\P{Numeric_Value:	0.9}');
Error('\p{Numeric_Value=0.88}');
Error('\P{Numeric_Value=0.88}');
Expect(1, 8542, '\p{Numeric_Value=0.875}', "");
Expect(0, 8542, '\p{^Numeric_Value=0.875}', "");
Expect(0, 8542, '\P{Numeric_Value=0.875}', "");
Expect(1, 8542, '\P{^Numeric_Value=0.875}', "");
Expect(0, 8543, '\p{Numeric_Value=0.875}', "");
Expect(1, 8543, '\p{^Numeric_Value=0.875}', "");
Expect(1, 8543, '\P{Numeric_Value=0.875}', "");
Expect(0, 8543, '\P{^Numeric_Value=0.875}', "");
Error('\p{Nv=-/a/7/000008}');
Error('\P{Nv=-/a/7/000008}');
Expect(1, 8542, '\p{Nv: +07/0008}', "");
Expect(0, 8542, '\p{^Nv: +07/0008}', "");
Expect(0, 8542, '\P{Nv: +07/0008}', "");
Expect(1, 8542, '\P{^Nv: +07/0008}', "");
Expect(0, 8543, '\p{Nv: +07/0008}', "");
Expect(1, 8543, '\p{^Nv: +07/0008}', "");
Expect(1, 8543, '\P{Nv: +07/0008}', "");
Expect(0, 8543, '\P{^Nv: +07/0008}', "");
Error('\p{Nv=0.9}');
Error('\P{Nv=0.9}');
Error('\p{Nv:	0.88}');
Error('\P{Nv:	0.88}');
Expect(1, 8542, '\p{Nv=0.875}', "");
Expect(0, 8542, '\p{^Nv=0.875}', "");
Expect(0, 8542, '\P{Nv=0.875}', "");
Expect(1, 8542, '\P{^Nv=0.875}', "");
Expect(0, 8543, '\p{Nv=0.875}', "");
Expect(1, 8543, '\p{^Nv=0.875}', "");
Expect(1, 8543, '\P{Nv=0.875}', "");
Expect(0, 8543, '\P{^Nv=0.875}', "");
Error('\p{Is_Numeric_Value=:=	-+0000000007/0000008}');
Error('\P{Is_Numeric_Value=:=	-+0000000007/0000008}');
Expect(1, 8542, '\p{Is_Numeric_Value=00007/000000008}', "");
Expect(0, 8542, '\p{^Is_Numeric_Value=00007/000000008}', "");
Expect(0, 8542, '\P{Is_Numeric_Value=00007/000000008}', "");
Expect(1, 8542, '\P{^Is_Numeric_Value=00007/000000008}', "");
Expect(0, 8543, '\p{Is_Numeric_Value=00007/000000008}', "");
Expect(1, 8543, '\p{^Is_Numeric_Value=00007/000000008}', "");
Expect(1, 8543, '\P{Is_Numeric_Value=00007/000000008}', "");
Expect(0, 8543, '\P{^Is_Numeric_Value=00007/000000008}', "");
Error('\p{Is_Numeric_Value: 0.9}');
Error('\P{Is_Numeric_Value: 0.9}');
Error('\p{Is_Numeric_Value:0.88}');
Error('\P{Is_Numeric_Value:0.88}');
Expect(1, 8542, '\p{Is_Numeric_Value=0.875}', "");
Expect(0, 8542, '\p{^Is_Numeric_Value=0.875}', "");
Expect(0, 8542, '\P{Is_Numeric_Value=0.875}', "");
Expect(1, 8542, '\P{^Is_Numeric_Value=0.875}', "");
Expect(0, 8543, '\p{Is_Numeric_Value=0.875}', "");
Expect(1, 8543, '\p{^Is_Numeric_Value=0.875}', "");
Expect(1, 8543, '\P{Is_Numeric_Value=0.875}', "");
Expect(0, 8543, '\P{^Is_Numeric_Value=0.875}', "");
Error('\p{Is_Nv=	0000007/00008:=}');
Error('\P{Is_Nv=	0000007/00008:=}');
Expect(1, 8542, '\p{Is_Nv=+07/000000008}', "");
Expect(0, 8542, '\p{^Is_Nv=+07/000000008}', "");
Expect(0, 8542, '\P{Is_Nv=+07/000000008}', "");
Expect(1, 8542, '\P{^Is_Nv=+07/000000008}', "");
Expect(0, 8543, '\p{Is_Nv=+07/000000008}', "");
Expect(1, 8543, '\p{^Is_Nv=+07/000000008}', "");
Expect(1, 8543, '\P{Is_Nv=+07/000000008}', "");
Expect(0, 8543, '\P{^Is_Nv=+07/000000008}', "");
Error('\p{Is_Nv=0.9}');
Error('\P{Is_Nv=0.9}');
Error('\p{Is_Nv=0.88}');
Error('\P{Is_Nv=0.88}');
Expect(1, 8542, '\p{Is_Nv=0.875}', "");
Expect(0, 8542, '\p{^Is_Nv=0.875}', "");
Expect(0, 8542, '\P{Is_Nv=0.875}', "");
Expect(1, 8542, '\P{^Is_Nv=0.875}', "");
Expect(0, 8543, '\p{Is_Nv=0.875}', "");
Expect(1, 8543, '\p{^Is_Nv=0.875}', "");
Expect(1, 8543, '\P{Is_Nv=0.875}', "");
Expect(0, 8543, '\P{^Is_Nv=0.875}', "");
Error('\p{Numeric_Value:   /a/_ 00070}');
Error('\P{Numeric_Value:   /a/_ 00070}');
Expect(1, 119663, '\p{Numeric_Value=00070}', "");
Expect(0, 119663, '\p{^Numeric_Value=00070}', "");
Expect(0, 119663, '\P{Numeric_Value=00070}', "");
Expect(1, 119663, '\P{^Numeric_Value=00070}', "");
Expect(0, 119664, '\p{Numeric_Value=00070}', "");
Expect(1, 119664, '\p{^Numeric_Value=00070}', "");
Expect(1, 119664, '\P{Numeric_Value=00070}', "");
Expect(0, 119664, '\P{^Numeric_Value=00070}', "");
Error('\p{Nv= 0_0_0_0_70:=}');
Error('\P{Nv= 0_0_0_0_70:=}');
Expect(1, 119663, '\p{Nv=+070}', "");
Expect(0, 119663, '\p{^Nv=+070}', "");
Expect(0, 119663, '\P{Nv=+070}', "");
Expect(1, 119663, '\P{^Nv=+070}', "");
Expect(0, 119664, '\p{Nv=+070}', "");
Expect(1, 119664, '\p{^Nv=+070}', "");
Expect(1, 119664, '\P{Nv=+070}', "");
Expect(0, 119664, '\P{^Nv=+070}', "");
Error('\p{Is_Numeric_Value=  007_0/a/}');
Error('\P{Is_Numeric_Value=  007_0/a/}');
Expect(1, 119663, '\p{Is_Numeric_Value=+0_0_0_0_0_0_00070}', "");
Expect(0, 119663, '\p{^Is_Numeric_Value=+0_0_0_0_0_0_00070}', "");
Expect(0, 119663, '\P{Is_Numeric_Value=+0_0_0_0_0_0_00070}', "");
Expect(1, 119663, '\P{^Is_Numeric_Value=+0_0_0_0_0_0_00070}', "");
Expect(0, 119664, '\p{Is_Numeric_Value=+0_0_0_0_0_0_00070}', "");
Expect(1, 119664, '\p{^Is_Numeric_Value=+0_0_0_0_0_0_00070}', "");
Expect(1, 119664, '\P{Is_Numeric_Value=+0_0_0_0_0_0_00070}', "");
Expect(0, 119664, '\P{^Is_Numeric_Value=+0_0_0_0_0_0_00070}', "");
Error('\p{Is_Nv=-	00000070:=}');
Error('\P{Is_Nv=-	00000070:=}');
Expect(1, 119663, '\p{Is_Nv=+7_0}', "");
Expect(0, 119663, '\p{^Is_Nv=+7_0}', "");
Expect(0, 119663, '\P{Is_Nv=+7_0}', "");
Expect(1, 119663, '\P{^Is_Nv=+7_0}', "");
Expect(0, 119664, '\p{Is_Nv=+7_0}', "");
Expect(1, 119664, '\p{^Is_Nv=+7_0}', "");
Expect(1, 119664, '\P{Is_Nv=+7_0}', "");
Expect(0, 119664, '\P{^Is_Nv=+7_0}', "");
Error('\p{Numeric_Value= /a/00_00_00_700}');
Error('\P{Numeric_Value= /a/00_00_00_700}');
Expect(1, 69240, '\p{Numeric_Value=0_7_00}', "");
Expect(0, 69240, '\p{^Numeric_Value=0_7_00}', "");
Expect(0, 69240, '\P{Numeric_Value=0_7_00}', "");
Expect(1, 69240, '\P{^Numeric_Value=0_7_00}', "");
Expect(0, 69241, '\p{Numeric_Value=0_7_00}', "");
Expect(1, 69241, '\p{^Numeric_Value=0_7_00}', "");
Expect(1, 69241, '\P{Numeric_Value=0_7_00}', "");
Expect(0, 69241, '\P{^Numeric_Value=0_7_00}', "");
Error('\p{Nv= -70_0/a/}');
Error('\P{Nv= -70_0/a/}');
Expect(1, 69240, '\p{Nv=0_0_0_0_0_00700}', "");
Expect(0, 69240, '\p{^Nv=0_0_0_0_0_00700}', "");
Expect(0, 69240, '\P{Nv=0_0_0_0_0_00700}', "");
Expect(1, 69240, '\P{^Nv=0_0_0_0_0_00700}', "");
Expect(0, 69241, '\p{Nv=0_0_0_0_0_00700}', "");
Expect(1, 69241, '\p{^Nv=0_0_0_0_0_00700}', "");
Expect(1, 69241, '\P{Nv=0_0_0_0_0_00700}', "");
Expect(0, 69241, '\P{^Nv=0_0_0_0_0_00700}', "");
Error('\p{Is_Numeric_Value=-/a/0_0_7_00}');
Error('\P{Is_Numeric_Value=-/a/0_0_7_00}');
Expect(1, 69240, '\p{Is_Numeric_Value=0_0_0_0_0700}', "");
Expect(0, 69240, '\p{^Is_Numeric_Value=0_0_0_0_0700}', "");
Expect(0, 69240, '\P{Is_Numeric_Value=0_0_0_0_0700}', "");
Expect(1, 69240, '\P{^Is_Numeric_Value=0_0_0_0_0700}', "");
Expect(0, 69241, '\p{Is_Numeric_Value=0_0_0_0_0700}', "");
Expect(1, 69241, '\p{^Is_Numeric_Value=0_0_0_0_0700}', "");
Expect(1, 69241, '\P{Is_Numeric_Value=0_0_0_0_0700}', "");
Expect(0, 69241, '\P{^Is_Numeric_Value=0_0_0_0_0700}', "");
Error('\p{Is_Nv=/a/		0_0_0_0_0_0_7_00}');
Error('\P{Is_Nv=/a/		0_0_0_0_0_0_7_00}');
Expect(1, 69240, '\p{Is_Nv=00_07_00}', "");
Expect(0, 69240, '\p{^Is_Nv=00_07_00}', "");
Expect(0, 69240, '\P{Is_Nv=00_07_00}', "");
Expect(1, 69240, '\P{^Is_Nv=00_07_00}', "");
Expect(0, 69241, '\p{Is_Nv=00_07_00}', "");
Expect(1, 69241, '\p{^Is_Nv=00_07_00}', "");
Expect(1, 69241, '\P{Is_Nv=00_07_00}', "");
Expect(0, 69241, '\P{^Is_Nv=00_07_00}', "");
Error('\p{Numeric_Value=:= 000000007000}');
Error('\P{Numeric_Value=:= 000000007000}');
Expect(1, 65832, '\p{Numeric_Value=0_0_0_0_0_0_007000}', "");
Expect(0, 65832, '\p{^Numeric_Value=0_0_0_0_0_0_007000}', "");
Expect(0, 65832, '\P{Numeric_Value=0_0_0_0_0_0_007000}', "");
Expect(1, 65832, '\P{^Numeric_Value=0_0_0_0_0_0_007000}', "");
Expect(0, 65833, '\p{Numeric_Value=0_0_0_0_0_0_007000}', "");
Expect(1, 65833, '\p{^Numeric_Value=0_0_0_0_0_0_007000}', "");
Expect(1, 65833, '\P{Numeric_Value=0_0_0_0_0_0_007000}', "");
Expect(0, 65833, '\P{^Numeric_Value=0_0_0_0_0_0_007000}', "");
Error('\p{Nv=/a/ 000007000}');
Error('\P{Nv=/a/ 000007000}');
Expect(1, 65832, '\p{Nv=+0_0_0_0_0_7000}', "");
Expect(0, 65832, '\p{^Nv=+0_0_0_0_0_7000}', "");
Expect(0, 65832, '\P{Nv=+0_0_0_0_0_7000}', "");
Expect(1, 65832, '\P{^Nv=+0_0_0_0_0_7000}', "");
Expect(0, 65833, '\p{Nv=+0_0_0_0_0_7000}', "");
Expect(1, 65833, '\p{^Nv=+0_0_0_0_0_7000}', "");
Expect(1, 65833, '\P{Nv=+0_0_0_0_0_7000}', "");
Expect(0, 65833, '\P{^Nv=+0_0_0_0_0_7000}', "");
Error('\p{Is_Numeric_Value=/a/-0000700_0}');
Error('\P{Is_Numeric_Value=/a/-0000700_0}');
Expect(1, 65832, '\p{Is_Numeric_Value=000007000}', "");
Expect(0, 65832, '\p{^Is_Numeric_Value=000007000}', "");
Expect(0, 65832, '\P{Is_Numeric_Value=000007000}', "");
Expect(1, 65832, '\P{^Is_Numeric_Value=000007000}', "");
Expect(0, 65833, '\p{Is_Numeric_Value=000007000}', "");
Expect(1, 65833, '\p{^Is_Numeric_Value=000007000}', "");
Expect(1, 65833, '\P{Is_Numeric_Value=000007000}', "");
Expect(0, 65833, '\P{^Is_Numeric_Value=000007000}', "");
Error('\p{Is_Nv=:=00000007000}');
Error('\P{Is_Nv=:=00000007000}');
Expect(1, 65832, '\p{Is_Nv: 7000}', "");
Expect(0, 65832, '\p{^Is_Nv: 7000}', "");
Expect(0, 65832, '\P{Is_Nv: 7000}', "");
Expect(1, 65832, '\P{^Is_Nv: 7000}', "");
Expect(0, 65833, '\p{Is_Nv: 7000}', "");
Expect(1, 65833, '\p{^Is_Nv: 7000}', "");
Expect(1, 65833, '\P{Is_Nv: 7000}', "");
Expect(0, 65833, '\P{^Is_Nv: 7000}', "");
Error('\p{Numeric_Value= /a/00000070000}');
Error('\P{Numeric_Value= /a/00000070000}');
Expect(1, 65841, '\p{Numeric_Value: 00_00_00_70_000}', "");
Expect(0, 65841, '\p{^Numeric_Value: 00_00_00_70_000}', "");
Expect(0, 65841, '\P{Numeric_Value: 00_00_00_70_000}', "");
Expect(1, 65841, '\P{^Numeric_Value: 00_00_00_70_000}', "");
Expect(0, 65842, '\p{Numeric_Value: 00_00_00_70_000}', "");
Expect(1, 65842, '\p{^Numeric_Value: 00_00_00_70_000}', "");
Expect(1, 65842, '\P{Numeric_Value: 00_00_00_70_000}', "");
Expect(0, 65842, '\P{^Numeric_Value: 00_00_00_70_000}', "");
Error('\p{Nv=:=0_7_0_000}');
Error('\P{Nv=:=0_7_0_000}');
Expect(1, 65841, '\p{Nv=000000070000}', "");
Expect(0, 65841, '\p{^Nv=000000070000}', "");
Expect(0, 65841, '\P{Nv=000000070000}', "");
Expect(1, 65841, '\P{^Nv=000000070000}', "");
Expect(0, 65842, '\p{Nv=000000070000}', "");
Expect(1, 65842, '\p{^Nv=000000070000}', "");
Expect(1, 65842, '\P{Nv=000000070000}', "");
Expect(0, 65842, '\P{^Nv=000000070000}', "");
Error('\p{Is_Numeric_Value= -0_0_0_0_0_0_70000/a/}');
Error('\P{Is_Numeric_Value= -0_0_0_0_0_0_70000/a/}');
Expect(1, 65841, '\p{Is_Numeric_Value:+0000000070000}', "");
Expect(0, 65841, '\p{^Is_Numeric_Value:+0000000070000}', "");
Expect(0, 65841, '\P{Is_Numeric_Value:+0000000070000}', "");
Expect(1, 65841, '\P{^Is_Numeric_Value:+0000000070000}', "");
Expect(0, 65842, '\p{Is_Numeric_Value:+0000000070000}', "");
Expect(1, 65842, '\p{^Is_Numeric_Value:+0000000070000}', "");
Expect(1, 65842, '\P{Is_Numeric_Value:+0000000070000}', "");
Expect(0, 65842, '\P{^Is_Numeric_Value:+0000000070000}', "");
Error('\p{Is_Nv=_/a/+00_70_00_0}');
Error('\P{Is_Nv=_/a/+00_70_00_0}');
Expect(1, 65841, '\p{Is_Nv=070000}', "");
Expect(0, 65841, '\p{^Is_Nv=070000}', "");
Expect(0, 65841, '\P{Is_Nv=070000}', "");
Expect(1, 65841, '\P{^Is_Nv=070000}', "");
Expect(0, 65842, '\p{Is_Nv=070000}', "");
Expect(1, 65842, '\p{^Is_Nv=070000}', "");
Expect(1, 65842, '\P{Is_Nv=070000}', "");
Expect(0, 65842, '\P{^Is_Nv=070000}', "");
Error('\p{Numeric_Value= -000_000_08:=}');
Error('\P{Numeric_Value= -000_000_08:=}');
Expect(1, 127241, '\p{Numeric_Value=0008}', "");
Expect(0, 127241, '\p{^Numeric_Value=0008}', "");
Expect(0, 127241, '\P{Numeric_Value=0008}', "");
Expect(1, 127241, '\P{^Numeric_Value=0008}', "");
Expect(0, 127242, '\p{Numeric_Value=0008}', "");
Expect(1, 127242, '\p{^Numeric_Value=0008}', "");
Expect(1, 127242, '\P{Numeric_Value=0008}', "");
Expect(0, 127242, '\P{^Numeric_Value=0008}', "");
Error('\p{Nv=/a/00008}');
Error('\P{Nv=/a/00008}');
Expect(1, 127241, '\p{Nv: 00_00_00_08}', "");
Expect(0, 127241, '\p{^Nv: 00_00_00_08}', "");
Expect(0, 127241, '\P{Nv: 00_00_00_08}', "");
Expect(1, 127241, '\P{^Nv: 00_00_00_08}', "");
Expect(0, 127242, '\p{Nv: 00_00_00_08}', "");
Expect(1, 127242, '\p{^Nv: 00_00_00_08}', "");
Expect(1, 127242, '\P{Nv: 00_00_00_08}', "");
Expect(0, 127242, '\P{^Nv: 00_00_00_08}', "");
Error('\p{Is_Numeric_Value: 		+000008:=}');
Error('\P{Is_Numeric_Value: 		+000008:=}');
Expect(1, 127241, '\p{Is_Numeric_Value:0_8}', "");
Expect(0, 127241, '\p{^Is_Numeric_Value:0_8}', "");
Expect(0, 127241, '\P{Is_Numeric_Value:0_8}', "");
Expect(1, 127241, '\P{^Is_Numeric_Value:0_8}', "");
Expect(0, 127242, '\p{Is_Numeric_Value:0_8}', "");
Expect(1, 127242, '\p{^Is_Numeric_Value:0_8}', "");
Expect(1, 127242, '\P{Is_Numeric_Value:0_8}', "");
Expect(0, 127242, '\P{^Is_Numeric_Value:0_8}', "");
Error('\p{Is_Nv=-/a/0_8}');
Error('\P{Is_Nv=-/a/0_8}');
Expect(1, 127241, '\p{Is_Nv=0000008}', "");
Expect(0, 127241, '\p{^Is_Nv=0000008}', "");
Expect(0, 127241, '\P{Is_Nv=0000008}', "");
Expect(1, 127241, '\P{^Is_Nv=0000008}', "");
Expect(0, 127242, '\p{Is_Nv=0000008}', "");
Expect(1, 127242, '\p{^Is_Nv=0000008}', "");
Expect(1, 127242, '\P{Is_Nv=0000008}', "");
Expect(0, 127242, '\P{^Is_Nv=0000008}', "");
Error('\p{Numeric_Value=-:=0000000080}');
Error('\P{Numeric_Value=-:=0000000080}');
Expect(1, 119664, '\p{Numeric_Value=+00000080}', "");
Expect(0, 119664, '\p{^Numeric_Value=+00000080}', "");
Expect(0, 119664, '\P{Numeric_Value=+00000080}', "");
Expect(1, 119664, '\P{^Numeric_Value=+00000080}', "");
Expect(0, 119665, '\p{Numeric_Value=+00000080}', "");
Expect(1, 119665, '\p{^Numeric_Value=+00000080}', "");
Expect(1, 119665, '\P{Numeric_Value=+00000080}', "");
Expect(0, 119665, '\P{^Numeric_Value=+00000080}', "");
Error('\p{Nv=/a/	-+0008_0}');
Error('\P{Nv=/a/	-+0008_0}');
Expect(1, 119664, '\p{Nv=0000000080}', "");
Expect(0, 119664, '\p{^Nv=0000000080}', "");
Expect(0, 119664, '\P{Nv=0000000080}', "");
Expect(1, 119664, '\P{^Nv=0000000080}', "");
Expect(0, 119665, '\p{Nv=0000000080}', "");
Expect(1, 119665, '\p{^Nv=0000000080}', "");
Expect(1, 119665, '\P{Nv=0000000080}', "");
Expect(0, 119665, '\P{^Nv=0000000080}', "");
Error('\p{Is_Numeric_Value=:=00_00_00_080}');
Error('\P{Is_Numeric_Value=:=00_00_00_080}');
Expect(1, 119664, '\p{Is_Numeric_Value=0000000080}', "");
Expect(0, 119664, '\p{^Is_Numeric_Value=0000000080}', "");
Expect(0, 119664, '\P{Is_Numeric_Value=0000000080}', "");
Expect(1, 119664, '\P{^Is_Numeric_Value=0000000080}', "");
Expect(0, 119665, '\p{Is_Numeric_Value=0000000080}', "");
Expect(1, 119665, '\p{^Is_Numeric_Value=0000000080}', "");
Expect(1, 119665, '\P{Is_Numeric_Value=0000000080}', "");
Expect(0, 119665, '\P{^Is_Numeric_Value=0000000080}', "");
Error('\p{Is_Nv:   _/a/0000000080}');
Error('\P{Is_Nv:   _/a/0000000080}');
Expect(1, 119664, '\p{Is_Nv=0_0_0_0_80}', "");
Expect(0, 119664, '\p{^Is_Nv=0_0_0_0_80}', "");
Expect(0, 119664, '\P{Is_Nv=0_0_0_0_80}', "");
Expect(1, 119664, '\P{^Is_Nv=0_0_0_0_80}', "");
Expect(0, 119665, '\p{Is_Nv=0_0_0_0_80}', "");
Expect(1, 119665, '\p{^Is_Nv=0_0_0_0_80}', "");
Expect(1, 119665, '\P{Is_Nv=0_0_0_0_80}', "");
Expect(0, 119665, '\P{^Is_Nv=0_0_0_0_80}', "");
Error('\p{Numeric_Value=_/a/000_080_0}');
Error('\P{Numeric_Value=_/a/000_080_0}');
Expect(1, 69241, '\p{Numeric_Value=+800}', "");
Expect(0, 69241, '\p{^Numeric_Value=+800}', "");
Expect(0, 69241, '\P{Numeric_Value=+800}', "");
Expect(1, 69241, '\P{^Numeric_Value=+800}', "");
Expect(0, 69242, '\p{Numeric_Value=+800}', "");
Expect(1, 69242, '\p{^Numeric_Value=+800}', "");
Expect(1, 69242, '\P{Numeric_Value=+800}', "");
Expect(0, 69242, '\P{^Numeric_Value=+800}', "");
Error('\p{Nv= 000000800/a/}');
Error('\P{Nv= 000000800/a/}');
Expect(1, 69241, '\p{Nv:+0_0_0_0_800}', "");
Expect(0, 69241, '\p{^Nv:+0_0_0_0_800}', "");
Expect(0, 69241, '\P{Nv:+0_0_0_0_800}', "");
Expect(1, 69241, '\P{^Nv:+0_0_0_0_800}', "");
Expect(0, 69242, '\p{Nv:+0_0_0_0_800}', "");
Expect(1, 69242, '\p{^Nv:+0_0_0_0_800}', "");
Expect(1, 69242, '\P{Nv:+0_0_0_0_800}', "");
Expect(0, 69242, '\P{^Nv:+0_0_0_0_800}', "");
Error('\p{Is_Numeric_Value= -00000_00080_0/a/}');
Error('\P{Is_Numeric_Value= -00000_00080_0/a/}');
Expect(1, 69241, '\p{Is_Numeric_Value:   +00_00_00_00_80_0}', "");
Expect(0, 69241, '\p{^Is_Numeric_Value:   +00_00_00_00_80_0}', "");
Expect(0, 69241, '\P{Is_Numeric_Value:   +00_00_00_00_80_0}', "");
Expect(1, 69241, '\P{^Is_Numeric_Value:   +00_00_00_00_80_0}', "");
Expect(0, 69242, '\p{Is_Numeric_Value:   +00_00_00_00_80_0}', "");
Expect(1, 69242, '\p{^Is_Numeric_Value:   +00_00_00_00_80_0}', "");
Expect(1, 69242, '\P{Is_Numeric_Value:   +00_00_00_00_80_0}', "");
Expect(0, 69242, '\P{^Is_Numeric_Value:   +00_00_00_00_80_0}', "");
Error('\p{Is_Nv: :=+0_0_0_0_800}');
Error('\P{Is_Nv: :=+0_0_0_0_800}');
Expect(1, 69241, '\p{Is_Nv=00000000800}', "");
Expect(0, 69241, '\p{^Is_Nv=00000000800}', "");
Expect(0, 69241, '\P{Is_Nv=00000000800}', "");
Expect(1, 69241, '\P{^Is_Nv=00000000800}', "");
Expect(0, 69242, '\p{Is_Nv=00000000800}', "");
Expect(1, 69242, '\p{^Is_Nv=00000000800}', "");
Expect(1, 69242, '\P{Is_Nv=00000000800}', "");
Expect(0, 69242, '\P{^Is_Nv=00000000800}', "");
Error('\p{Numeric_Value=_	+000_800_0/a/}');
Error('\P{Numeric_Value=_	+000_800_0/a/}');
Expect(1, 65833, '\p{Numeric_Value:   00_08_00_0}', "");
Expect(0, 65833, '\p{^Numeric_Value:   00_08_00_0}', "");
Expect(0, 65833, '\P{Numeric_Value:   00_08_00_0}', "");
Expect(1, 65833, '\P{^Numeric_Value:   00_08_00_0}', "");
Expect(0, 65834, '\p{Numeric_Value:   00_08_00_0}', "");
Expect(1, 65834, '\p{^Numeric_Value:   00_08_00_0}', "");
Expect(1, 65834, '\P{Numeric_Value:   00_08_00_0}', "");
Expect(0, 65834, '\P{^Numeric_Value:   00_08_00_0}', "");
Error('\p{Nv= 008000:=}');
Error('\P{Nv= 008000:=}');
Expect(1, 65833, '\p{Nv=+0800_0}', "");
Expect(0, 65833, '\p{^Nv=+0800_0}', "");
Expect(0, 65833, '\P{Nv=+0800_0}', "");
Expect(1, 65833, '\P{^Nv=+0800_0}', "");
Expect(0, 65834, '\p{Nv=+0800_0}', "");
Expect(1, 65834, '\p{^Nv=+0800_0}', "");
Expect(1, 65834, '\P{Nv=+0800_0}', "");
Expect(0, 65834, '\P{^Nv=+0800_0}', "");
Error('\p{Is_Numeric_Value=/a/+008000}');
Error('\P{Is_Numeric_Value=/a/+008000}');
Expect(1, 65833, '\p{Is_Numeric_Value=0008000}', "");
Expect(0, 65833, '\p{^Is_Numeric_Value=0008000}', "");
Expect(0, 65833, '\P{Is_Numeric_Value=0008000}', "");
Expect(1, 65833, '\P{^Is_Numeric_Value=0008000}', "");
Expect(0, 65834, '\p{Is_Numeric_Value=0008000}', "");
Expect(1, 65834, '\p{^Is_Numeric_Value=0008000}', "");
Expect(1, 65834, '\P{Is_Numeric_Value=0008000}', "");
Expect(0, 65834, '\P{^Is_Numeric_Value=0008000}', "");
Error('\p{Is_Nv=	000000008000/a/}');
Error('\P{Is_Nv=	000000008000/a/}');
Expect(1, 65833, '\p{Is_Nv:0_0_0_8_0_00}', "");
Expect(0, 65833, '\p{^Is_Nv:0_0_0_8_0_00}', "");
Expect(0, 65833, '\P{Is_Nv:0_0_0_8_0_00}', "");
Expect(1, 65833, '\P{^Is_Nv:0_0_0_8_0_00}', "");
Expect(0, 65834, '\p{Is_Nv:0_0_0_8_0_00}', "");
Expect(1, 65834, '\p{^Is_Nv:0_0_0_8_0_00}', "");
Expect(1, 65834, '\P{Is_Nv:0_0_0_8_0_00}', "");
Expect(0, 65834, '\P{^Is_Nv:0_0_0_8_0_00}', "");
Error('\p{Numeric_Value=__+0_0_0_0_0_0_0_0_0_8_0_0_00:=}');
Error('\P{Numeric_Value=__+0_0_0_0_0_0_0_0_0_8_0_0_00:=}');
Expect(1, 65842, '\p{Numeric_Value=+0_0_8_0_0_00}', "");
Expect(0, 65842, '\p{^Numeric_Value=+0_0_8_0_0_00}', "");
Expect(0, 65842, '\P{Numeric_Value=+0_0_8_0_0_00}', "");
Expect(1, 65842, '\P{^Numeric_Value=+0_0_8_0_0_00}', "");
Expect(0, 65843, '\p{Numeric_Value=+0_0_8_0_0_00}', "");
Expect(1, 65843, '\p{^Numeric_Value=+0_0_8_0_0_00}', "");
Expect(1, 65843, '\P{Numeric_Value=+0_0_8_0_0_00}', "");
Expect(0, 65843, '\P{^Numeric_Value=+0_0_8_0_0_00}', "");
Error('\p{Nv=-:=8000_0}');
Error('\P{Nv=-:=8000_0}');
Expect(1, 65842, '\p{Nv=00000080000}', "");
Expect(0, 65842, '\p{^Nv=00000080000}', "");
Expect(0, 65842, '\P{Nv=00000080000}', "");
Expect(1, 65842, '\P{^Nv=00000080000}', "");
Expect(0, 65843, '\p{Nv=00000080000}', "");
Expect(1, 65843, '\p{^Nv=00000080000}', "");
Expect(1, 65843, '\P{Nv=00000080000}', "");
Expect(0, 65843, '\P{^Nv=00000080000}', "");
Error('\p{Is_Numeric_Value=		00_80_00_0/a/}');
Error('\P{Is_Numeric_Value=		00_80_00_0/a/}');
Expect(1, 65842, '\p{Is_Numeric_Value=+0_0_0_8_0_000}', "");
Expect(0, 65842, '\p{^Is_Numeric_Value=+0_0_0_8_0_000}', "");
Expect(0, 65842, '\P{Is_Numeric_Value=+0_0_0_8_0_000}', "");
Expect(1, 65842, '\P{^Is_Numeric_Value=+0_0_0_8_0_000}', "");
Expect(0, 65843, '\p{Is_Numeric_Value=+0_0_0_8_0_000}', "");
Expect(1, 65843, '\p{^Is_Numeric_Value=+0_0_0_8_0_000}', "");
Expect(1, 65843, '\P{Is_Numeric_Value=+0_0_0_8_0_000}', "");
Expect(0, 65843, '\P{^Is_Numeric_Value=+0_0_0_8_0_000}', "");
Error('\p{Is_Nv=:=__80000}');
Error('\P{Is_Nv=:=__80000}');
Expect(1, 65842, '\p{Is_Nv=+0_0_0_0_0_0_8_0_0_00}', "");
Expect(0, 65842, '\p{^Is_Nv=+0_0_0_0_0_0_8_0_0_00}', "");
Expect(0, 65842, '\P{Is_Nv=+0_0_0_0_0_0_8_0_0_00}', "");
Expect(1, 65842, '\P{^Is_Nv=+0_0_0_0_0_0_8_0_0_00}', "");
Expect(0, 65843, '\p{Is_Nv=+0_0_0_0_0_0_8_0_0_00}', "");
Expect(1, 65843, '\p{^Is_Nv=+0_0_0_0_0_0_8_0_0_00}', "");
Expect(1, 65843, '\P{Is_Nv=+0_0_0_0_0_0_8_0_0_00}', "");
Expect(0, 65843, '\P{^Is_Nv=+0_0_0_0_0_0_8_0_0_00}', "");
Error('\p{Numeric_Value:   /a/0_9}');
Error('\P{Numeric_Value:   /a/0_9}');
Expect(1, 194704, '\p{Numeric_Value=0000_9}', "");
Expect(0, 194704, '\p{^Numeric_Value=0000_9}', "");
Expect(0, 194704, '\P{Numeric_Value=0000_9}', "");
Expect(1, 194704, '\P{^Numeric_Value=0000_9}', "");
Expect(0, 194705, '\p{Numeric_Value=0000_9}', "");
Expect(1, 194705, '\p{^Numeric_Value=0000_9}', "");
Expect(1, 194705, '\P{Numeric_Value=0000_9}', "");
Expect(0, 194705, '\P{^Numeric_Value=0000_9}', "");
Error('\p{Nv=/a/-_0000_9}');
Error('\P{Nv=/a/-_0000_9}');
Expect(1, 194704, '\p{Nv=+0_0_0_0_0_0_009}', "");
Expect(0, 194704, '\p{^Nv=+0_0_0_0_0_0_009}', "");
Expect(0, 194704, '\P{Nv=+0_0_0_0_0_0_009}', "");
Expect(1, 194704, '\P{^Nv=+0_0_0_0_0_0_009}', "");
Expect(0, 194705, '\p{Nv=+0_0_0_0_0_0_009}', "");
Expect(1, 194705, '\p{^Nv=+0_0_0_0_0_0_009}', "");
Expect(1, 194705, '\P{Nv=+0_0_0_0_0_0_009}', "");
Expect(0, 194705, '\P{^Nv=+0_0_0_0_0_0_009}', "");
Error('\p{Is_Numeric_Value=/a/00000009}');
Error('\P{Is_Numeric_Value=/a/00000009}');
Expect(1, 194704, '\p{Is_Numeric_Value=00_00_00_00_9}', "");
Expect(0, 194704, '\p{^Is_Numeric_Value=00_00_00_00_9}', "");
Expect(0, 194704, '\P{Is_Numeric_Value=00_00_00_00_9}', "");
Expect(1, 194704, '\P{^Is_Numeric_Value=00_00_00_00_9}', "");
Expect(0, 194705, '\p{Is_Numeric_Value=00_00_00_00_9}', "");
Expect(1, 194705, '\p{^Is_Numeric_Value=00_00_00_00_9}', "");
Expect(1, 194705, '\P{Is_Numeric_Value=00_00_00_00_9}', "");
Expect(0, 194705, '\P{^Is_Numeric_Value=00_00_00_00_9}', "");
Error('\p{Is_Nv= 	+000000009:=}');
Error('\P{Is_Nv= 	+000000009:=}');
Expect(1, 194704, '\p{Is_Nv=00009}', "");
Expect(0, 194704, '\p{^Is_Nv=00009}', "");
Expect(0, 194704, '\P{Is_Nv=00009}', "");
Expect(1, 194704, '\P{^Is_Nv=00009}', "");
Expect(0, 194705, '\p{Is_Nv=00009}', "");
Expect(1, 194705, '\p{^Is_Nv=00009}', "");
Expect(1, 194705, '\P{Is_Nv=00009}', "");
Expect(0, 194705, '\P{^Is_Nv=00009}', "");
Error('\p{Numeric_Value=_009/02/a/}');
Error('\P{Numeric_Value=_009/02/a/}');
Expect(1, 3886, '\p{Numeric_Value=000009/02}', "");
Expect(0, 3886, '\p{^Numeric_Value=000009/02}', "");
Expect(0, 3886, '\P{Numeric_Value=000009/02}', "");
Expect(1, 3886, '\P{^Numeric_Value=000009/02}', "");
Expect(0, 3887, '\p{Numeric_Value=000009/02}', "");
Expect(1, 3887, '\p{^Numeric_Value=000009/02}', "");
Expect(1, 3887, '\P{Numeric_Value=000009/02}', "");
Expect(0, 3887, '\P{^Numeric_Value=000009/02}', "");
Expect(1, 3886, '\p{Numeric_Value=4.500}', "");
Expect(0, 3886, '\p{^Numeric_Value=4.500}', "");
Expect(0, 3886, '\P{Numeric_Value=4.500}', "");
Expect(1, 3886, '\P{^Numeric_Value=4.500}', "");
Expect(0, 3887, '\p{Numeric_Value=4.500}', "");
Expect(1, 3887, '\p{^Numeric_Value=4.500}', "");
Expect(1, 3887, '\P{Numeric_Value=4.500}', "");
Expect(0, 3887, '\P{^Numeric_Value=4.500}', "");
Error('\p{Nv:		-00000009/0000000002:=}');
Error('\P{Nv:		-00000009/0000000002:=}');
Expect(1, 3886, '\p{Nv=+0000000009/002}', "");
Expect(0, 3886, '\p{^Nv=+0000000009/002}', "");
Expect(0, 3886, '\P{Nv=+0000000009/002}', "");
Expect(1, 3886, '\P{^Nv=+0000000009/002}', "");
Expect(0, 3887, '\p{Nv=+0000000009/002}', "");
Expect(1, 3887, '\p{^Nv=+0000000009/002}', "");
Expect(1, 3887, '\P{Nv=+0000000009/002}', "");
Expect(0, 3887, '\P{^Nv=+0000000009/002}', "");
Expect(1, 3886, '\p{Nv:	4.500}', "");
Expect(0, 3886, '\p{^Nv:	4.500}', "");
Expect(0, 3886, '\P{Nv:	4.500}', "");
Expect(1, 3886, '\P{^Nv:	4.500}', "");
Expect(0, 3887, '\p{Nv:	4.500}', "");
Expect(1, 3887, '\p{^Nv:	4.500}', "");
Expect(1, 3887, '\P{Nv:	4.500}', "");
Expect(0, 3887, '\P{^Nv:	4.500}', "");
Error('\p{Is_Numeric_Value=_000009/0002/a/}');
Error('\P{Is_Numeric_Value=_000009/0002/a/}');
Expect(1, 3886, '\p{Is_Numeric_Value=0009/0000002}', "");
Expect(0, 3886, '\p{^Is_Numeric_Value=0009/0000002}', "");
Expect(0, 3886, '\P{Is_Numeric_Value=0009/0000002}', "");
Expect(1, 3886, '\P{^Is_Numeric_Value=0009/0000002}', "");
Expect(0, 3887, '\p{Is_Numeric_Value=0009/0000002}', "");
Expect(1, 3887, '\p{^Is_Numeric_Value=0009/0000002}', "");
Expect(1, 3887, '\P{Is_Numeric_Value=0009/0000002}', "");
Expect(0, 3887, '\P{^Is_Numeric_Value=0009/0000002}', "");
Expect(1, 3886, '\p{Is_Numeric_Value=4.500}', "");
Expect(0, 3886, '\p{^Is_Numeric_Value=4.500}', "");
Expect(0, 3886, '\P{Is_Numeric_Value=4.500}', "");
Expect(1, 3886, '\P{^Is_Numeric_Value=4.500}', "");
Expect(0, 3887, '\p{Is_Numeric_Value=4.500}', "");
Expect(1, 3887, '\p{^Is_Numeric_Value=4.500}', "");
Expect(1, 3887, '\P{Is_Numeric_Value=4.500}', "");
Expect(0, 3887, '\P{^Is_Numeric_Value=4.500}', "");
Error('\p{Is_Nv=_/a/009/02}');
Error('\P{Is_Nv=_/a/009/02}');
Expect(1, 3886, '\p{Is_Nv=+0009/000000002}', "");
Expect(0, 3886, '\p{^Is_Nv=+0009/000000002}', "");
Expect(0, 3886, '\P{Is_Nv=+0009/000000002}', "");
Expect(1, 3886, '\P{^Is_Nv=+0009/000000002}', "");
Expect(0, 3887, '\p{Is_Nv=+0009/000000002}', "");
Expect(1, 3887, '\p{^Is_Nv=+0009/000000002}', "");
Expect(1, 3887, '\P{Is_Nv=+0009/000000002}', "");
Expect(0, 3887, '\P{^Is_Nv=+0009/000000002}', "");
Expect(1, 3886, '\p{Is_Nv=4.500}', "");
Expect(0, 3886, '\p{^Is_Nv=4.500}', "");
Expect(0, 3886, '\P{Is_Nv=4.500}', "");
Expect(1, 3886, '\P{^Is_Nv=4.500}', "");
Expect(0, 3887, '\p{Is_Nv=4.500}', "");
Expect(1, 3887, '\p{^Is_Nv=4.500}', "");
Expect(1, 3887, '\P{Is_Nv=4.500}', "");
Expect(0, 3887, '\P{^Is_Nv=4.500}', "");
Error('\p{Numeric_Value= :=000_000_009_0}');
Error('\P{Numeric_Value= :=000_000_009_0}');
Expect(1, 119665, '\p{Numeric_Value=000090}', "");
Expect(0, 119665, '\p{^Numeric_Value=000090}', "");
Expect(0, 119665, '\P{Numeric_Value=000090}', "");
Expect(1, 119665, '\P{^Numeric_Value=000090}', "");
Expect(0, 119666, '\p{Numeric_Value=000090}', "");
Expect(1, 119666, '\p{^Numeric_Value=000090}', "");
Expect(1, 119666, '\P{Numeric_Value=000090}', "");
Expect(0, 119666, '\P{^Numeric_Value=000090}', "");
Error('\p{Nv= /a/000000090}');
Error('\P{Nv= /a/000000090}');
Expect(1, 119665, '\p{Nv=00_09_0}', "");
Expect(0, 119665, '\p{^Nv=00_09_0}', "");
Expect(0, 119665, '\P{Nv=00_09_0}', "");
Expect(1, 119665, '\P{^Nv=00_09_0}', "");
Expect(0, 119666, '\p{Nv=00_09_0}', "");
Expect(1, 119666, '\p{^Nv=00_09_0}', "");
Expect(1, 119666, '\P{Nv=00_09_0}', "");
Expect(0, 119666, '\P{^Nv=00_09_0}', "");
Error('\p{Is_Numeric_Value:_0000090/a/}');
Error('\P{Is_Numeric_Value:_0000090/a/}');
Expect(1, 119665, '\p{Is_Numeric_Value:+0_0_0_0_090}', "");
Expect(0, 119665, '\p{^Is_Numeric_Value:+0_0_0_0_090}', "");
Expect(0, 119665, '\P{Is_Numeric_Value:+0_0_0_0_090}', "");
Expect(1, 119665, '\P{^Is_Numeric_Value:+0_0_0_0_090}', "");
Expect(0, 119666, '\p{Is_Numeric_Value:+0_0_0_0_090}', "");
Expect(1, 119666, '\p{^Is_Numeric_Value:+0_0_0_0_090}', "");
Expect(1, 119666, '\P{Is_Numeric_Value:+0_0_0_0_090}', "");
Expect(0, 119666, '\P{^Is_Numeric_Value:+0_0_0_0_090}', "");
Error('\p{Is_Nv=:=-00_00_00_00_90}');
Error('\P{Is_Nv=:=-00_00_00_00_90}');
Expect(1, 119665, '\p{Is_Nv=09_0}', "");
Expect(0, 119665, '\p{^Is_Nv=09_0}', "");
Expect(0, 119665, '\P{Is_Nv=09_0}', "");
Expect(1, 119665, '\P{^Is_Nv=09_0}', "");
Expect(0, 119666, '\p{Is_Nv=09_0}', "");
Expect(1, 119666, '\p{^Is_Nv=09_0}', "");
Expect(1, 119666, '\P{Is_Nv=09_0}', "");
Expect(0, 119666, '\P{^Is_Nv=09_0}', "");
Error('\p{Numeric_Value::= 0000900}');
Error('\P{Numeric_Value::= 0000900}');
Expect(1, 69242, '\p{Numeric_Value=900}', "");
Expect(0, 69242, '\p{^Numeric_Value=900}', "");
Expect(0, 69242, '\P{Numeric_Value=900}', "");
Expect(1, 69242, '\P{^Numeric_Value=900}', "");
Expect(0, 69243, '\p{Numeric_Value=900}', "");
Expect(1, 69243, '\p{^Numeric_Value=900}', "");
Expect(1, 69243, '\P{Numeric_Value=900}', "");
Expect(0, 69243, '\P{^Numeric_Value=900}', "");
Error('\p{Nv:   /a/00000000900}');
Error('\P{Nv:   /a/00000000900}');
Expect(1, 69242, '\p{Nv:   0_0_0_0_0_9_00}', "");
Expect(0, 69242, '\p{^Nv:   0_0_0_0_0_9_00}', "");
Expect(0, 69242, '\P{Nv:   0_0_0_0_0_9_00}', "");
Expect(1, 69242, '\P{^Nv:   0_0_0_0_0_9_00}', "");
Expect(0, 69243, '\p{Nv:   0_0_0_0_0_9_00}', "");
Expect(1, 69243, '\p{^Nv:   0_0_0_0_0_9_00}', "");
Expect(1, 69243, '\P{Nv:   0_0_0_0_0_9_00}', "");
Expect(0, 69243, '\P{^Nv:   0_0_0_0_0_9_00}', "");
Error('\p{Is_Numeric_Value= 000900:=}');
Error('\P{Is_Numeric_Value= 000900:=}');
Expect(1, 69242, '\p{Is_Numeric_Value=+0_9_00}', "");
Expect(0, 69242, '\p{^Is_Numeric_Value=+0_9_00}', "");
Expect(0, 69242, '\P{Is_Numeric_Value=+0_9_00}', "");
Expect(1, 69242, '\P{^Is_Numeric_Value=+0_9_00}', "");
Expect(0, 69243, '\p{Is_Numeric_Value=+0_9_00}', "");
Expect(1, 69243, '\p{^Is_Numeric_Value=+0_9_00}', "");
Expect(1, 69243, '\P{Is_Numeric_Value=+0_9_00}', "");
Expect(0, 69243, '\P{^Is_Numeric_Value=+0_9_00}', "");
Error('\p{Is_Nv:	/a/_	00000900}');
Error('\P{Is_Nv:	/a/_	00000900}');
Expect(1, 69242, '\p{Is_Nv=00000000900}', "");
Expect(0, 69242, '\p{^Is_Nv=00000000900}', "");
Expect(0, 69242, '\P{Is_Nv=00000000900}', "");
Expect(1, 69242, '\P{^Is_Nv=00000000900}', "");
Expect(0, 69243, '\p{Is_Nv=00000000900}', "");
Expect(1, 69243, '\p{^Is_Nv=00000000900}', "");
Expect(1, 69243, '\P{Is_Nv=00000000900}', "");
Expect(0, 69243, '\P{^Is_Nv=00000000900}', "");
Error('\p{Numeric_Value=	/a/9000}');
Error('\P{Numeric_Value=	/a/9000}');
Expect(1, 65834, '\p{Numeric_Value=0000000009000}', "");
Expect(0, 65834, '\p{^Numeric_Value=0000000009000}', "");
Expect(0, 65834, '\P{Numeric_Value=0000000009000}', "");
Expect(1, 65834, '\P{^Numeric_Value=0000000009000}', "");
Expect(0, 65835, '\p{Numeric_Value=0000000009000}', "");
Expect(1, 65835, '\p{^Numeric_Value=0000000009000}', "");
Expect(1, 65835, '\P{Numeric_Value=0000000009000}', "");
Expect(0, 65835, '\P{^Numeric_Value=0000000009000}', "");
Error('\p{Nv=:=9000}');
Error('\P{Nv=:=9000}');
Expect(1, 65834, '\p{Nv=900_0}', "");
Expect(0, 65834, '\p{^Nv=900_0}', "");
Expect(0, 65834, '\P{Nv=900_0}', "");
Expect(1, 65834, '\P{^Nv=900_0}', "");
Expect(0, 65835, '\p{Nv=900_0}', "");
Expect(1, 65835, '\p{^Nv=900_0}', "");
Expect(1, 65835, '\P{Nv=900_0}', "");
Expect(0, 65835, '\P{^Nv=900_0}', "");
Error('\p{Is_Numeric_Value= :=+0009000}');
Error('\P{Is_Numeric_Value= :=+0009000}');
Expect(1, 65834, '\p{Is_Numeric_Value=000009000}', "");
Expect(0, 65834, '\p{^Is_Numeric_Value=000009000}', "");
Expect(0, 65834, '\P{Is_Numeric_Value=000009000}', "");
Expect(1, 65834, '\P{^Is_Numeric_Value=000009000}', "");
Expect(0, 65835, '\p{Is_Numeric_Value=000009000}', "");
Expect(1, 65835, '\p{^Is_Numeric_Value=000009000}', "");
Expect(1, 65835, '\P{Is_Numeric_Value=000009000}', "");
Expect(0, 65835, '\P{^Is_Numeric_Value=000009000}', "");
Error('\p{Is_Nv=_	00009000:=}');
Error('\P{Is_Nv=_	00009000:=}');
Expect(1, 65834, '\p{Is_Nv=000900_0}', "");
Expect(0, 65834, '\p{^Is_Nv=000900_0}', "");
Expect(0, 65834, '\P{Is_Nv=000900_0}', "");
Expect(1, 65834, '\P{^Is_Nv=000900_0}', "");
Expect(0, 65835, '\p{Is_Nv=000900_0}', "");
Expect(1, 65835, '\p{^Is_Nv=000900_0}', "");
Expect(1, 65835, '\P{Is_Nv=000900_0}', "");
Expect(0, 65835, '\P{^Is_Nv=000900_0}', "");
Error('\p{Numeric_Value=	:=9000_0}');
Error('\P{Numeric_Value=	:=9000_0}');
Expect(1, 65843, '\p{Numeric_Value=0000090000}', "");
Expect(0, 65843, '\p{^Numeric_Value=0000090000}', "");
Expect(0, 65843, '\P{Numeric_Value=0000090000}', "");
Expect(1, 65843, '\P{^Numeric_Value=0000090000}', "");
Expect(0, 65844, '\p{Numeric_Value=0000090000}', "");
Expect(1, 65844, '\p{^Numeric_Value=0000090000}', "");
Expect(1, 65844, '\P{Numeric_Value=0000090000}', "");
Expect(0, 65844, '\P{^Numeric_Value=0000090000}', "");
Error('\p{Nv=		00000090000:=}');
Error('\P{Nv=		00000090000:=}');
Expect(1, 65843, '\p{Nv=090000}', "");
Expect(0, 65843, '\p{^Nv=090000}', "");
Expect(0, 65843, '\P{Nv=090000}', "");
Expect(1, 65843, '\P{^Nv=090000}', "");
Expect(0, 65844, '\p{Nv=090000}', "");
Expect(1, 65844, '\p{^Nv=090000}', "");
Expect(1, 65844, '\P{Nv=090000}', "");
Expect(0, 65844, '\P{^Nv=090000}', "");
Error('\p{Is_Numeric_Value=--+00000000090000:=}');
Error('\P{Is_Numeric_Value=--+00000000090000:=}');
Expect(1, 65843, '\p{Is_Numeric_Value=009000_0}', "");
Expect(0, 65843, '\p{^Is_Numeric_Value=009000_0}', "");
Expect(0, 65843, '\P{Is_Numeric_Value=009000_0}', "");
Expect(1, 65843, '\P{^Is_Numeric_Value=009000_0}', "");
Expect(0, 65844, '\p{Is_Numeric_Value=009000_0}', "");
Expect(1, 65844, '\p{^Is_Numeric_Value=009000_0}', "");
Expect(1, 65844, '\P{Is_Numeric_Value=009000_0}', "");
Expect(0, 65844, '\P{^Is_Numeric_Value=009000_0}', "");
Error('\p{Is_Nv=	-000090000:=}');
Error('\P{Is_Nv=	-000090000:=}');
Expect(1, 65843, '\p{Is_Nv=0_0_0_9_0_000}', "");
Expect(0, 65843, '\p{^Is_Nv=0_0_0_9_0_000}', "");
Expect(0, 65843, '\P{Is_Nv=0_0_0_9_0_000}', "");
Expect(1, 65843, '\P{^Is_Nv=0_0_0_9_0_000}', "");
Expect(0, 65844, '\p{Is_Nv=0_0_0_9_0_000}', "");
Expect(1, 65844, '\p{^Is_Nv=0_0_0_9_0_000}', "");
Expect(1, 65844, '\P{Is_Nv=0_0_0_9_0_000}', "");
Expect(0, 65844, '\P{^Is_Nv=0_0_0_9_0_000}', "");
Error('\p{Numeric_Value=/a/_ NaN}');
Error('\P{Numeric_Value=/a/_ NaN}');
Expect(1, 194705, '\p{Numeric_Value=nan}', "");
Expect(0, 194705, '\p{^Numeric_Value=nan}', "");
Expect(0, 194705, '\P{Numeric_Value=nan}', "");
Expect(1, 194705, '\P{^Numeric_Value=nan}', "");
Expect(0, 194704, '\p{Numeric_Value=nan}', "");
Expect(1, 194704, '\p{^Numeric_Value=nan}', "");
Expect(1, 194704, '\P{Numeric_Value=nan}', "");
Expect(0, 194704, '\P{^Numeric_Value=nan}', "");
Expect(1, 194705, '\p{Numeric_Value=  NaN}', "");
Expect(0, 194705, '\p{^Numeric_Value=  NaN}', "");
Expect(0, 194705, '\P{Numeric_Value=  NaN}', "");
Expect(1, 194705, '\P{^Numeric_Value=  NaN}', "");
Expect(0, 194704, '\p{Numeric_Value=  NaN}', "");
Expect(1, 194704, '\p{^Numeric_Value=  NaN}', "");
Expect(1, 194704, '\P{Numeric_Value=  NaN}', "");
Expect(0, 194704, '\P{^Numeric_Value=  NaN}', "");
Error('\p{Nv=_-NaN/a/}');
Error('\P{Nv=_-NaN/a/}');
Expect(1, 194705, '\p{Nv=nan}', "");
Expect(0, 194705, '\p{^Nv=nan}', "");
Expect(0, 194705, '\P{Nv=nan}', "");
Expect(1, 194705, '\P{^Nv=nan}', "");
Expect(0, 194704, '\p{Nv=nan}', "");
Expect(1, 194704, '\p{^Nv=nan}', "");
Expect(1, 194704, '\P{Nv=nan}', "");
Expect(0, 194704, '\P{^Nv=nan}', "");
Expect(1, 194705, '\p{Nv=_ NaN}', "");
Expect(0, 194705, '\p{^Nv=_ NaN}', "");
Expect(0, 194705, '\P{Nv=_ NaN}', "");
Expect(1, 194705, '\P{^Nv=_ NaN}', "");
Expect(0, 194704, '\p{Nv=_ NaN}', "");
Expect(1, 194704, '\p{^Nv=_ NaN}', "");
Expect(1, 194704, '\P{Nv=_ NaN}', "");
Expect(0, 194704, '\P{^Nv=_ NaN}', "");
Error('\p{Is_Numeric_Value:   :=_	nan}');
Error('\P{Is_Numeric_Value:   :=_	nan}');
Expect(1, 194705, '\p{Is_Numeric_Value=nan}', "");
Expect(0, 194705, '\p{^Is_Numeric_Value=nan}', "");
Expect(0, 194705, '\P{Is_Numeric_Value=nan}', "");
Expect(1, 194705, '\P{^Is_Numeric_Value=nan}', "");
Expect(0, 194704, '\p{Is_Numeric_Value=nan}', "");
Expect(1, 194704, '\p{^Is_Numeric_Value=nan}', "");
Expect(1, 194704, '\P{Is_Numeric_Value=nan}', "");
Expect(0, 194704, '\P{^Is_Numeric_Value=nan}', "");
Expect(1, 194705, '\p{Is_Numeric_Value:  NAN}', "");
Expect(0, 194705, '\p{^Is_Numeric_Value:  NAN}', "");
Expect(0, 194705, '\P{Is_Numeric_Value:  NAN}', "");
Expect(1, 194705, '\P{^Is_Numeric_Value:  NAN}', "");
Expect(0, 194704, '\p{Is_Numeric_Value:  NAN}', "");
Expect(1, 194704, '\p{^Is_Numeric_Value:  NAN}', "");
Expect(1, 194704, '\P{Is_Numeric_Value:  NAN}', "");
Expect(0, 194704, '\P{^Is_Numeric_Value:  NAN}', "");
Error('\p{Is_Nv=-nan:=}');
Error('\P{Is_Nv=-nan:=}');
Expect(1, 194705, '\p{Is_Nv:	nan}', "");
Expect(0, 194705, '\p{^Is_Nv:	nan}', "");
Expect(0, 194705, '\P{Is_Nv:	nan}', "");
Expect(1, 194705, '\P{^Is_Nv:	nan}', "");
Expect(0, 194704, '\p{Is_Nv:	nan}', "");
Expect(1, 194704, '\p{^Is_Nv:	nan}', "");
Expect(1, 194704, '\P{Is_Nv:	nan}', "");
Expect(0, 194704, '\P{^Is_Nv:	nan}', "");
Expect(1, 194705, '\p{Is_Nv=__NaN}', "");
Expect(0, 194705, '\p{^Is_Nv=__NaN}', "");
Expect(0, 194705, '\P{Is_Nv=__NaN}', "");
Expect(1, 194705, '\P{^Is_Nv=__NaN}', "");
Expect(0, 194704, '\p{Is_Nv=__NaN}', "");
Expect(1, 194704, '\p{^Is_Nv=__NaN}', "");
Expect(1, 194704, '\P{Is_Nv=__NaN}', "");
Expect(0, 194704, '\P{^Is_Nv=__NaN}', "");
Error('\p{/a/ -ASCII}');
Error('\P{/a/ -ASCII}');
Expect(1, 127, '\p{ascii}', "");
Expect(0, 127, '\p{^ascii}', "");
Expect(0, 127, '\P{ascii}', "");
Expect(1, 127, '\P{^ascii}', "");
Expect(0, 128, '\p{ascii}', "");
Expect(1, 128, '\p{^ascii}', "");
Expect(1, 128, '\P{ascii}', "");
Expect(0, 128, '\P{^ascii}', "");
Expect(1, 127, '\p{		ascii}', "");
Expect(0, 127, '\p{^		ascii}', "");
Expect(0, 127, '\P{		ascii}', "");
Expect(1, 127, '\P{^		ascii}', "");
Expect(0, 128, '\p{		ascii}', "");
Expect(1, 128, '\p{^		ascii}', "");
Expect(1, 128, '\P{		ascii}', "");
Expect(0, 128, '\P{^		ascii}', "");
Error('\p{		IS_ASCII:=}');
Error('\P{		IS_ASCII:=}');
Expect(1, 127, '\p{isascii}', "");
Expect(0, 127, '\p{^isascii}', "");
Expect(0, 127, '\P{isascii}', "");
Expect(1, 127, '\P{^isascii}', "");
Expect(0, 128, '\p{isascii}', "");
Expect(1, 128, '\p{^isascii}', "");
Expect(1, 128, '\P{isascii}', "");
Expect(0, 128, '\P{^isascii}', "");
Expect(1, 127, '\p{IS_ASCII}', "");
Expect(0, 127, '\p{^IS_ASCII}', "");
Expect(0, 127, '\P{IS_ASCII}', "");
Expect(1, 127, '\P{^IS_ASCII}', "");
Expect(0, 128, '\p{IS_ASCII}', "");
Expect(1, 128, '\p{^IS_ASCII}', "");
Expect(1, 128, '\P{IS_ASCII}', "");
Expect(0, 128, '\P{^IS_ASCII}', "");
Error('\p{/a/-_Basic_Latin}');
Error('\P{/a/-_Basic_Latin}');
Expect(1, 127, '\p{basiclatin}', "");
Expect(0, 127, '\p{^basiclatin}', "");
Expect(0, 127, '\P{basiclatin}', "");
Expect(1, 127, '\P{^basiclatin}', "");
Expect(0, 128, '\p{basiclatin}', "");
Expect(1, 128, '\p{^basiclatin}', "");
Expect(1, 128, '\P{basiclatin}', "");
Expect(0, 128, '\P{^basiclatin}', "");
Expect(1, 127, '\p{_Basic_Latin}', "");
Expect(0, 127, '\p{^_Basic_Latin}', "");
Expect(0, 127, '\P{_Basic_Latin}', "");
Expect(1, 127, '\P{^_Basic_Latin}', "");
Expect(0, 128, '\p{_Basic_Latin}', "");
Expect(1, 128, '\p{^_Basic_Latin}', "");
Expect(1, 128, '\P{_Basic_Latin}', "");
Expect(0, 128, '\P{^_Basic_Latin}', "");
Error('\p{__IS_Basic_LATIN:=}');
Error('\P{__IS_Basic_LATIN:=}');
Expect(1, 127, '\p{isbasiclatin}', "");
Expect(0, 127, '\p{^isbasiclatin}', "");
Expect(0, 127, '\P{isbasiclatin}', "");
Expect(1, 127, '\P{^isbasiclatin}', "");
Expect(0, 128, '\p{isbasiclatin}', "");
Expect(1, 128, '\p{^isbasiclatin}', "");
Expect(1, 128, '\P{isbasiclatin}', "");
Expect(0, 128, '\P{^isbasiclatin}', "");
Expect(1, 127, '\p{ 	is_Basic_Latin}', "");
Expect(0, 127, '\p{^ 	is_Basic_Latin}', "");
Expect(0, 127, '\P{ 	is_Basic_Latin}', "");
Expect(1, 127, '\P{^ 	is_Basic_Latin}', "");
Expect(0, 128, '\p{ 	is_Basic_Latin}', "");
Expect(1, 128, '\p{^ 	is_Basic_Latin}', "");
Expect(1, 128, '\P{ 	is_Basic_Latin}', "");
Expect(0, 128, '\P{^ 	is_Basic_Latin}', "");
Error('\p{:=IN_Basic_Latin}');
Error('\P{:=IN_Basic_Latin}');
Expect(1, 127, '\p{inbasiclatin}', "");
Expect(0, 127, '\p{^inbasiclatin}', "");
Expect(0, 127, '\P{inbasiclatin}', "");
Expect(1, 127, '\P{^inbasiclatin}', "");
Expect(0, 128, '\p{inbasiclatin}', "");
Expect(1, 128, '\p{^inbasiclatin}', "");
Expect(1, 128, '\P{inbasiclatin}', "");
Expect(0, 128, '\P{^inbasiclatin}', "");
Expect(1, 127, '\p{ _In_BASIC_Latin}', "");
Expect(0, 127, '\p{^ _In_BASIC_Latin}', "");
Expect(0, 127, '\P{ _In_BASIC_Latin}', "");
Expect(1, 127, '\P{^ _In_BASIC_Latin}', "");
Expect(0, 128, '\p{ _In_BASIC_Latin}', "");
Expect(1, 128, '\p{^ _In_BASIC_Latin}', "");
Expect(1, 128, '\P{ _In_BASIC_Latin}', "");
Expect(0, 128, '\P{^ _In_BASIC_Latin}', "");
Error('\p{/a/	In_ascii}');
Error('\P{/a/	In_ascii}');
Expect(1, 127, '\p{inascii}', "");
Expect(0, 127, '\p{^inascii}', "");
Expect(0, 127, '\P{inascii}', "");
Expect(1, 127, '\P{^inascii}', "");
Expect(0, 128, '\p{inascii}', "");
Expect(1, 128, '\p{^inascii}', "");
Expect(1, 128, '\P{inascii}', "");
Expect(0, 128, '\P{^inascii}', "");
Expect(1, 127, '\p{	in_ASCII}', "");
Expect(0, 127, '\p{^	in_ASCII}', "");
Expect(0, 127, '\P{	in_ASCII}', "");
Expect(1, 127, '\P{^	in_ASCII}', "");
Expect(0, 128, '\p{	in_ASCII}', "");
Expect(1, 128, '\p{^	in_ASCII}', "");
Expect(1, 128, '\P{	in_ASCII}', "");
Expect(0, 128, '\P{^	in_ASCII}', "");
Error('\p{-:=aegean_Numbers}');
Error('\P{-:=aegean_Numbers}');
Expect(1, 65855, '\p{aegeannumbers}', "");
Expect(0, 65855, '\p{^aegeannumbers}', "");
Expect(0, 65855, '\P{aegeannumbers}', "");
Expect(1, 65855, '\P{^aegeannumbers}', "");
Expect(0, 65856, '\p{aegeannumbers}', "");
Expect(1, 65856, '\p{^aegeannumbers}', "");
Expect(1, 65856, '\P{aegeannumbers}', "");
Expect(0, 65856, '\P{^aegeannumbers}', "");
Expect(1, 65855, '\p{ 	Aegean_Numbers}', "");
Expect(0, 65855, '\p{^ 	Aegean_Numbers}', "");
Expect(0, 65855, '\P{ 	Aegean_Numbers}', "");
Expect(1, 65855, '\P{^ 	Aegean_Numbers}', "");
Expect(0, 65856, '\p{ 	Aegean_Numbers}', "");
Expect(1, 65856, '\p{^ 	Aegean_Numbers}', "");
Expect(1, 65856, '\P{ 	Aegean_Numbers}', "");
Expect(0, 65856, '\P{^ 	Aegean_Numbers}', "");
Error('\p{:=-	is_Aegean_numbers}');
Error('\P{:=-	is_Aegean_numbers}');
Expect(1, 65855, '\p{isaegeannumbers}', "");
Expect(0, 65855, '\p{^isaegeannumbers}', "");
Expect(0, 65855, '\P{isaegeannumbers}', "");
Expect(1, 65855, '\P{^isaegeannumbers}', "");
Expect(0, 65856, '\p{isaegeannumbers}', "");
Expect(1, 65856, '\p{^isaegeannumbers}', "");
Expect(1, 65856, '\P{isaegeannumbers}', "");
Expect(0, 65856, '\P{^isaegeannumbers}', "");
Expect(1, 65855, '\p{--Is_aegean_NUMBERS}', "");
Expect(0, 65855, '\p{^--Is_aegean_NUMBERS}', "");
Expect(0, 65855, '\P{--Is_aegean_NUMBERS}', "");
Expect(1, 65855, '\P{^--Is_aegean_NUMBERS}', "");
Expect(0, 65856, '\p{--Is_aegean_NUMBERS}', "");
Expect(1, 65856, '\p{^--Is_aegean_NUMBERS}', "");
Expect(1, 65856, '\P{--Is_aegean_NUMBERS}', "");
Expect(0, 65856, '\P{^--Is_aegean_NUMBERS}', "");
Error('\p{:=IN_aegean_NUMBERS}');
Error('\P{:=IN_aegean_NUMBERS}');
Expect(1, 65855, '\p{inaegeannumbers}', "");
Expect(0, 65855, '\p{^inaegeannumbers}', "");
Expect(0, 65855, '\P{inaegeannumbers}', "");
Expect(1, 65855, '\P{^inaegeannumbers}', "");
Expect(0, 65856, '\p{inaegeannumbers}', "");
Expect(1, 65856, '\p{^inaegeannumbers}', "");
Expect(1, 65856, '\P{inaegeannumbers}', "");
Expect(0, 65856, '\P{^inaegeannumbers}', "");
Expect(1, 65855, '\p{ 	in_aegean_NUMBERS}', "");
Expect(0, 65855, '\p{^ 	in_aegean_NUMBERS}', "");
Expect(0, 65855, '\P{ 	in_aegean_NUMBERS}', "");
Expect(1, 65855, '\P{^ 	in_aegean_NUMBERS}', "");
Expect(0, 65856, '\p{ 	in_aegean_NUMBERS}', "");
Expect(1, 65856, '\p{^ 	in_aegean_NUMBERS}', "");
Expect(1, 65856, '\P{ 	in_aegean_NUMBERS}', "");
Expect(0, 65856, '\P{^ 	in_aegean_NUMBERS}', "");
Error('\p{	/a/alchemical_symbols}');
Error('\P{	/a/alchemical_symbols}');
Expect(1, 128895, '\p{alchemicalsymbols}', "");
Expect(0, 128895, '\p{^alchemicalsymbols}', "");
Expect(0, 128895, '\P{alchemicalsymbols}', "");
Expect(1, 128895, '\P{^alchemicalsymbols}', "");
Expect(0, 128896, '\p{alchemicalsymbols}', "");
Expect(1, 128896, '\p{^alchemicalsymbols}', "");
Expect(1, 128896, '\P{alchemicalsymbols}', "");
Expect(0, 128896, '\P{^alchemicalsymbols}', "");
Expect(1, 128895, '\p{ Alchemical_Symbols}', "");
Expect(0, 128895, '\p{^ Alchemical_Symbols}', "");
Expect(0, 128895, '\P{ Alchemical_Symbols}', "");
Expect(1, 128895, '\P{^ Alchemical_Symbols}', "");
Expect(0, 128896, '\p{ Alchemical_Symbols}', "");
Expect(1, 128896, '\p{^ Alchemical_Symbols}', "");
Expect(1, 128896, '\P{ Alchemical_Symbols}', "");
Expect(0, 128896, '\P{^ Alchemical_Symbols}', "");
Error('\p{_:=Is_Alchemical_Symbols}');
Error('\P{_:=Is_Alchemical_Symbols}');
Expect(1, 128895, '\p{isalchemicalsymbols}', "");
Expect(0, 128895, '\p{^isalchemicalsymbols}', "");
Expect(0, 128895, '\P{isalchemicalsymbols}', "");
Expect(1, 128895, '\P{^isalchemicalsymbols}', "");
Expect(0, 128896, '\p{isalchemicalsymbols}', "");
Expect(1, 128896, '\p{^isalchemicalsymbols}', "");
Expect(1, 128896, '\P{isalchemicalsymbols}', "");
Expect(0, 128896, '\P{^isalchemicalsymbols}', "");
Expect(1, 128895, '\p{- IS_ALCHEMICAL_SYMBOLS}', "");
Expect(0, 128895, '\p{^- IS_ALCHEMICAL_SYMBOLS}', "");
Expect(0, 128895, '\P{- IS_ALCHEMICAL_SYMBOLS}', "");
Expect(1, 128895, '\P{^- IS_ALCHEMICAL_SYMBOLS}', "");
Expect(0, 128896, '\p{- IS_ALCHEMICAL_SYMBOLS}', "");
Expect(1, 128896, '\p{^- IS_ALCHEMICAL_SYMBOLS}', "");
Expect(1, 128896, '\P{- IS_ALCHEMICAL_SYMBOLS}', "");
Expect(0, 128896, '\P{^- IS_ALCHEMICAL_SYMBOLS}', "");
Error('\p{	-In_Alchemical_Symbols:=}');
Error('\P{	-In_Alchemical_Symbols:=}');
Expect(1, 128895, '\p{inalchemicalsymbols}', "");
Expect(0, 128895, '\p{^inalchemicalsymbols}', "");
Expect(0, 128895, '\P{inalchemicalsymbols}', "");
Expect(1, 128895, '\P{^inalchemicalsymbols}', "");
Expect(0, 128896, '\p{inalchemicalsymbols}', "");
Expect(1, 128896, '\p{^inalchemicalsymbols}', "");
Expect(1, 128896, '\P{inalchemicalsymbols}', "");
Expect(0, 128896, '\P{^inalchemicalsymbols}', "");
Expect(1, 128895, '\p{--IN_alchemical_symbols}', "");
Expect(0, 128895, '\p{^--IN_alchemical_symbols}', "");
Expect(0, 128895, '\P{--IN_alchemical_symbols}', "");
Expect(1, 128895, '\P{^--IN_alchemical_symbols}', "");
Expect(0, 128896, '\p{--IN_alchemical_symbols}', "");
Expect(1, 128896, '\p{^--IN_alchemical_symbols}', "");
Expect(1, 128896, '\P{--IN_alchemical_symbols}', "");
Expect(0, 128896, '\P{^--IN_alchemical_symbols}', "");
Error('\p{	 Alchemical/a/}');
Error('\P{	 Alchemical/a/}');
Expect(1, 128895, '\p{alchemical}', "");
Expect(0, 128895, '\p{^alchemical}', "");
Expect(0, 128895, '\P{alchemical}', "");
Expect(1, 128895, '\P{^alchemical}', "");
Expect(0, 128896, '\p{alchemical}', "");
Expect(1, 128896, '\p{^alchemical}', "");
Expect(1, 128896, '\P{alchemical}', "");
Expect(0, 128896, '\P{^alchemical}', "");
Expect(1, 128895, '\p{ Alchemical}', "");
Expect(0, 128895, '\p{^ Alchemical}', "");
Expect(0, 128895, '\P{ Alchemical}', "");
Expect(1, 128895, '\P{^ Alchemical}', "");
Expect(0, 128896, '\p{ Alchemical}', "");
Expect(1, 128896, '\p{^ Alchemical}', "");
Expect(1, 128896, '\P{ Alchemical}', "");
Expect(0, 128896, '\P{^ Alchemical}', "");
Error('\p{-is_Alchemical/a/}');
Error('\P{-is_Alchemical/a/}');
Expect(1, 128895, '\p{isalchemical}', "");
Expect(0, 128895, '\p{^isalchemical}', "");
Expect(0, 128895, '\P{isalchemical}', "");
Expect(1, 128895, '\P{^isalchemical}', "");
Expect(0, 128896, '\p{isalchemical}', "");
Expect(1, 128896, '\p{^isalchemical}', "");
Expect(1, 128896, '\P{isalchemical}', "");
Expect(0, 128896, '\P{^isalchemical}', "");
Expect(1, 128895, '\p{	Is_Alchemical}', "");
Expect(0, 128895, '\p{^	Is_Alchemical}', "");
Expect(0, 128895, '\P{	Is_Alchemical}', "");
Expect(1, 128895, '\P{^	Is_Alchemical}', "");
Expect(0, 128896, '\p{	Is_Alchemical}', "");
Expect(1, 128896, '\p{^	Is_Alchemical}', "");
Expect(1, 128896, '\P{	Is_Alchemical}', "");
Expect(0, 128896, '\P{^	Is_Alchemical}', "");
Error('\p{	-In_Alchemical/a/}');
Error('\P{	-In_Alchemical/a/}');
Expect(1, 128895, '\p{inalchemical}', "");
Expect(0, 128895, '\p{^inalchemical}', "");
Expect(0, 128895, '\P{inalchemical}', "");
Expect(1, 128895, '\P{^inalchemical}', "");
Expect(0, 128896, '\p{inalchemical}', "");
Expect(1, 128896, '\p{^inalchemical}', "");
Expect(1, 128896, '\P{inalchemical}', "");
Expect(0, 128896, '\P{^inalchemical}', "");
Expect(1, 128895, '\p{	_IN_Alchemical}', "");
Expect(0, 128895, '\p{^	_IN_Alchemical}', "");
Expect(0, 128895, '\P{	_IN_Alchemical}', "");
Expect(1, 128895, '\P{^	_IN_Alchemical}', "");
Expect(0, 128896, '\p{	_IN_Alchemical}', "");
Expect(1, 128896, '\p{^	_IN_Alchemical}', "");
Expect(1, 128896, '\P{	_IN_Alchemical}', "");
Expect(0, 128896, '\P{^	_IN_Alchemical}', "");
Error('\p{_:=all}');
Error('\P{_:=all}');
Expect(1, 1, '\p{all}', "");
Expect(0, 1, '\p{^all}', "");
Expect(0, 1, '\P{all}', "");
Expect(1, 1, '\P{^all}', "");
Expect(1, 1, '\p{__All}', "");
Expect(0, 1, '\p{^__All}', "");
Expect(0, 1, '\P{__All}', "");
Expect(1, 1, '\P{^__All}', "");
Error('\p{- IS_All/a/}');
Error('\P{- IS_All/a/}');
Expect(1, 1, '\p{isall}', "");
Expect(0, 1, '\p{^isall}', "");
Expect(0, 1, '\P{isall}', "");
Expect(1, 1, '\P{^isall}', "");
Expect(1, 1, '\p{ is_all}', "");
Expect(0, 1, '\p{^ is_all}', "");
Expect(0, 1, '\P{ is_all}', "");
Expect(1, 1, '\P{^ is_all}', "");
Error('\p{:=	 alnum}');
Error('\P{:=	 alnum}');
Expect(1, 195101, '\p{alnum}', "");
Expect(0, 195101, '\p{^alnum}', "");
Expect(0, 195101, '\P{alnum}', "");
Expect(1, 195101, '\P{^alnum}', "");
Expect(0, 195102, '\p{alnum}', "");
Expect(1, 195102, '\p{^alnum}', "");
Expect(1, 195102, '\P{alnum}', "");
Expect(0, 195102, '\P{^alnum}', "");
Expect(1, 195101, '\p{ 	alnum}', "");
Expect(0, 195101, '\p{^ 	alnum}', "");
Expect(0, 195101, '\P{ 	alnum}', "");
Expect(1, 195101, '\P{^ 	alnum}', "");
Expect(0, 195102, '\p{ 	alnum}', "");
Expect(1, 195102, '\p{^ 	alnum}', "");
Expect(1, 195102, '\P{ 	alnum}', "");
Expect(0, 195102, '\P{^ 	alnum}', "");
Error('\p{:=	_XPosixAlnum}');
Error('\P{:=	_XPosixAlnum}');
Expect(1, 195101, '\p{xposixalnum}', "");
Expect(0, 195101, '\p{^xposixalnum}', "");
Expect(0, 195101, '\P{xposixalnum}', "");
Expect(1, 195101, '\P{^xposixalnum}', "");
Expect(0, 195102, '\p{xposixalnum}', "");
Expect(1, 195102, '\p{^xposixalnum}', "");
Expect(1, 195102, '\P{xposixalnum}', "");
Expect(0, 195102, '\P{^xposixalnum}', "");
Expect(1, 195101, '\p{-_xposixalnum}', "");
Expect(0, 195101, '\p{^-_xposixalnum}', "");
Expect(0, 195101, '\P{-_xposixalnum}', "");
Expect(1, 195101, '\P{^-_xposixalnum}', "");
Expect(0, 195102, '\p{-_xposixalnum}', "");
Expect(1, 195102, '\p{^-_xposixalnum}', "");
Expect(1, 195102, '\P{-_xposixalnum}', "");
Expect(0, 195102, '\P{^-_xposixalnum}', "");
Error('\p{__is_ALNUM:=}');
Error('\P{__is_ALNUM:=}');
Expect(1, 195101, '\p{isalnum}', "");
Expect(0, 195101, '\p{^isalnum}', "");
Expect(0, 195101, '\P{isalnum}', "");
Expect(1, 195101, '\P{^isalnum}', "");
Expect(0, 195102, '\p{isalnum}', "");
Expect(1, 195102, '\p{^isalnum}', "");
Expect(1, 195102, '\P{isalnum}', "");
Expect(0, 195102, '\P{^isalnum}', "");
Expect(1, 195101, '\p{	_IS_Alnum}', "");
Expect(0, 195101, '\p{^	_IS_Alnum}', "");
Expect(0, 195101, '\P{	_IS_Alnum}', "");
Expect(1, 195101, '\P{^	_IS_Alnum}', "");
Expect(0, 195102, '\p{	_IS_Alnum}', "");
Expect(1, 195102, '\p{^	_IS_Alnum}', "");
Expect(1, 195102, '\P{	_IS_Alnum}', "");
Expect(0, 195102, '\P{^	_IS_Alnum}', "");
Error('\p{:=-	IS_XPOSIXALNUM}');
Error('\P{:=-	IS_XPOSIXALNUM}');
Expect(1, 195101, '\p{isxposixalnum}', "");
Expect(0, 195101, '\p{^isxposixalnum}', "");
Expect(0, 195101, '\P{isxposixalnum}', "");
Expect(1, 195101, '\P{^isxposixalnum}', "");
Expect(0, 195102, '\p{isxposixalnum}', "");
Expect(1, 195102, '\p{^isxposixalnum}', "");
Expect(1, 195102, '\P{isxposixalnum}', "");
Expect(0, 195102, '\P{^isxposixalnum}', "");
Expect(1, 195101, '\p{	 is_XPOSIXALNUM}', "");
Expect(0, 195101, '\p{^	 is_XPOSIXALNUM}', "");
Expect(0, 195101, '\P{	 is_XPOSIXALNUM}', "");
Expect(1, 195101, '\P{^	 is_XPOSIXALNUM}', "");
Expect(0, 195102, '\p{	 is_XPOSIXALNUM}', "");
Expect(1, 195102, '\p{^	 is_XPOSIXALNUM}', "");
Expect(1, 195102, '\P{	 is_XPOSIXALNUM}', "");
Expect(0, 195102, '\P{^	 is_XPOSIXALNUM}', "");
Error('\p{/a/	 ALPHA}');
Error('\P{/a/	 ALPHA}');
Expect(1, 195101, '\p{alpha}', "");
Expect(0, 195101, '\p{^alpha}', "");
Expect(0, 195101, '\P{alpha}', "");
Expect(1, 195101, '\P{^alpha}', "");
Expect(0, 195102, '\p{alpha}', "");
Expect(1, 195102, '\p{^alpha}', "");
Expect(1, 195102, '\P{alpha}', "");
Expect(0, 195102, '\P{^alpha}', "");
Expect(1, 195101, '\p{Alpha}', "");
Expect(0, 195101, '\p{^Alpha}', "");
Expect(0, 195101, '\P{Alpha}', "");
Expect(1, 195101, '\P{^Alpha}', "");
Expect(0, 195102, '\p{Alpha}', "");
Expect(1, 195102, '\p{^Alpha}', "");
Expect(1, 195102, '\P{Alpha}', "");
Expect(0, 195102, '\P{^Alpha}', "");
Error('\p{ /a/XPOSIXALPHA}');
Error('\P{ /a/XPOSIXALPHA}');
Expect(1, 195101, '\p{xposixalpha}', "");
Expect(0, 195101, '\p{^xposixalpha}', "");
Expect(0, 195101, '\P{xposixalpha}', "");
Expect(1, 195101, '\P{^xposixalpha}', "");
Expect(0, 195102, '\p{xposixalpha}', "");
Expect(1, 195102, '\p{^xposixalpha}', "");
Expect(1, 195102, '\P{xposixalpha}', "");
Expect(0, 195102, '\P{^xposixalpha}', "");
Expect(1, 195101, '\p{-	xposixalpha}', "");
Expect(0, 195101, '\p{^-	xposixalpha}', "");
Expect(0, 195101, '\P{-	xposixalpha}', "");
Expect(1, 195101, '\P{^-	xposixalpha}', "");
Expect(0, 195102, '\p{-	xposixalpha}', "");
Expect(1, 195102, '\p{^-	xposixalpha}', "");
Expect(1, 195102, '\P{-	xposixalpha}', "");
Expect(0, 195102, '\P{^-	xposixalpha}', "");
Error('\p{/a/Is_ALPHA}');
Error('\P{/a/Is_ALPHA}');
Expect(1, 195101, '\p{isalpha}', "");
Expect(0, 195101, '\p{^isalpha}', "");
Expect(0, 195101, '\P{isalpha}', "");
Expect(1, 195101, '\P{^isalpha}', "");
Expect(0, 195102, '\p{isalpha}', "");
Expect(1, 195102, '\p{^isalpha}', "");
Expect(1, 195102, '\P{isalpha}', "");
Expect(0, 195102, '\P{^isalpha}', "");
Expect(1, 195101, '\p{	Is_Alpha}', "");
Expect(0, 195101, '\p{^	Is_Alpha}', "");
Expect(0, 195101, '\P{	Is_Alpha}', "");
Expect(1, 195101, '\P{^	Is_Alpha}', "");
Expect(0, 195102, '\p{	Is_Alpha}', "");
Expect(1, 195102, '\p{^	Is_Alpha}', "");
Expect(1, 195102, '\P{	Is_Alpha}', "");
Expect(0, 195102, '\P{^	Is_Alpha}', "");
Error('\p{ -is_XPOSIXALPHA:=}');
Error('\P{ -is_XPOSIXALPHA:=}');
Expect(1, 195101, '\p{isxposixalpha}', "");
Expect(0, 195101, '\p{^isxposixalpha}', "");
Expect(0, 195101, '\P{isxposixalpha}', "");
Expect(1, 195101, '\P{^isxposixalpha}', "");
Expect(0, 195102, '\p{isxposixalpha}', "");
Expect(1, 195102, '\p{^isxposixalpha}', "");
Expect(1, 195102, '\P{isxposixalpha}', "");
Expect(0, 195102, '\P{^isxposixalpha}', "");
Expect(1, 195101, '\p{- Is_XPosixAlpha}', "");
Expect(0, 195101, '\p{^- Is_XPosixAlpha}', "");
Expect(0, 195101, '\P{- Is_XPosixAlpha}', "");
Expect(1, 195101, '\P{^- Is_XPosixAlpha}', "");
Expect(0, 195102, '\p{- Is_XPosixAlpha}', "");
Expect(1, 195102, '\p{^- Is_XPosixAlpha}', "");
Expect(1, 195102, '\P{- Is_XPosixAlpha}', "");
Expect(0, 195102, '\P{^- Is_XPosixAlpha}', "");
Error('\p{:= -Alphabetic}');
Error('\P{:= -Alphabetic}');
Expect(1, 195101, '\p{alphabetic}', "");
Expect(0, 195101, '\p{^alphabetic}', "");
Expect(0, 195101, '\P{alphabetic}', "");
Expect(1, 195101, '\P{^alphabetic}', "");
Expect(0, 195102, '\p{alphabetic}', "");
Expect(1, 195102, '\p{^alphabetic}', "");
Expect(1, 195102, '\P{alphabetic}', "");
Expect(0, 195102, '\P{^alphabetic}', "");
Expect(1, 195101, '\p{	Alphabetic}', "");
Expect(0, 195101, '\p{^	Alphabetic}', "");
Expect(0, 195101, '\P{	Alphabetic}', "");
Expect(1, 195101, '\P{^	Alphabetic}', "");
Expect(0, 195102, '\p{	Alphabetic}', "");
Expect(1, 195102, '\p{^	Alphabetic}', "");
Expect(1, 195102, '\P{	Alphabetic}', "");
Expect(0, 195102, '\P{^	Alphabetic}', "");
Error('\p{/a/ Is_Alphabetic}');
Error('\P{/a/ Is_Alphabetic}');
Expect(1, 195101, '\p{isalphabetic}', "");
Expect(0, 195101, '\p{^isalphabetic}', "");
Expect(0, 195101, '\P{isalphabetic}', "");
Expect(1, 195101, '\P{^isalphabetic}', "");
Expect(0, 195102, '\p{isalphabetic}', "");
Expect(1, 195102, '\p{^isalphabetic}', "");
Expect(1, 195102, '\P{isalphabetic}', "");
Expect(0, 195102, '\P{^isalphabetic}', "");
Expect(1, 195101, '\p{ is_ALPHABETIC}', "");
Expect(0, 195101, '\p{^ is_ALPHABETIC}', "");
Expect(0, 195101, '\P{ is_ALPHABETIC}', "");
Expect(1, 195101, '\P{^ is_ALPHABETIC}', "");
Expect(0, 195102, '\p{ is_ALPHABETIC}', "");
Expect(1, 195102, '\p{^ is_ALPHABETIC}', "");
Expect(1, 195102, '\P{ is_ALPHABETIC}', "");
Expect(0, 195102, '\P{^ is_ALPHABETIC}', "");
Error('\p{:=- Alphabetic_Presentation_Forms}');
Error('\P{:=- Alphabetic_Presentation_Forms}');
Expect(1, 64335, '\p{alphabeticpresentationforms}', "");
Expect(0, 64335, '\p{^alphabeticpresentationforms}', "");
Expect(0, 64335, '\P{alphabeticpresentationforms}', "");
Expect(1, 64335, '\P{^alphabeticpresentationforms}', "");
Expect(0, 64336, '\p{alphabeticpresentationforms}', "");
Expect(1, 64336, '\p{^alphabeticpresentationforms}', "");
Expect(1, 64336, '\P{alphabeticpresentationforms}', "");
Expect(0, 64336, '\P{^alphabeticpresentationforms}', "");
Expect(1, 64335, '\p{-	ALPHABETIC_PRESENTATION_forms}', "");
Expect(0, 64335, '\p{^-	ALPHABETIC_PRESENTATION_forms}', "");
Expect(0, 64335, '\P{-	ALPHABETIC_PRESENTATION_forms}', "");
Expect(1, 64335, '\P{^-	ALPHABETIC_PRESENTATION_forms}', "");
Expect(0, 64336, '\p{-	ALPHABETIC_PRESENTATION_forms}', "");
Expect(1, 64336, '\p{^-	ALPHABETIC_PRESENTATION_forms}', "");
Expect(1, 64336, '\P{-	ALPHABETIC_PRESENTATION_forms}', "");
Expect(0, 64336, '\P{^-	ALPHABETIC_PRESENTATION_forms}', "");
Error('\p{	:=Is_alphabetic_presentation_Forms}');
Error('\P{	:=Is_alphabetic_presentation_Forms}');
Expect(1, 64335, '\p{isalphabeticpresentationforms}', "");
Expect(0, 64335, '\p{^isalphabeticpresentationforms}', "");
Expect(0, 64335, '\P{isalphabeticpresentationforms}', "");
Expect(1, 64335, '\P{^isalphabeticpresentationforms}', "");
Expect(0, 64336, '\p{isalphabeticpresentationforms}', "");
Expect(1, 64336, '\p{^isalphabeticpresentationforms}', "");
Expect(1, 64336, '\P{isalphabeticpresentationforms}', "");
Expect(0, 64336, '\P{^isalphabeticpresentationforms}', "");
Expect(1, 64335, '\p{ -Is_Alphabetic_PRESENTATION_FORMS}', "");
Expect(0, 64335, '\p{^ -Is_Alphabetic_PRESENTATION_FORMS}', "");
Expect(0, 64335, '\P{ -Is_Alphabetic_PRESENTATION_FORMS}', "");
Expect(1, 64335, '\P{^ -Is_Alphabetic_PRESENTATION_FORMS}', "");
Expect(0, 64336, '\p{ -Is_Alphabetic_PRESENTATION_FORMS}', "");
Expect(1, 64336, '\p{^ -Is_Alphabetic_PRESENTATION_FORMS}', "");
Expect(1, 64336, '\P{ -Is_Alphabetic_PRESENTATION_FORMS}', "");
Expect(0, 64336, '\P{^ -Is_Alphabetic_PRESENTATION_FORMS}', "");
Error('\p{:=_-In_Alphabetic_Presentation_forms}');
Error('\P{:=_-In_Alphabetic_Presentation_forms}');
Expect(1, 64335, '\p{inalphabeticpresentationforms}', "");
Expect(0, 64335, '\p{^inalphabeticpresentationforms}', "");
Expect(0, 64335, '\P{inalphabeticpresentationforms}', "");
Expect(1, 64335, '\P{^inalphabeticpresentationforms}', "");
Expect(0, 64336, '\p{inalphabeticpresentationforms}', "");
Expect(1, 64336, '\p{^inalphabeticpresentationforms}', "");
Expect(1, 64336, '\P{inalphabeticpresentationforms}', "");
Expect(0, 64336, '\P{^inalphabeticpresentationforms}', "");
Expect(1, 64335, '\p{	-In_ALPHABETIC_Presentation_Forms}', "");
Expect(0, 64335, '\p{^	-In_ALPHABETIC_Presentation_Forms}', "");
Expect(0, 64335, '\P{	-In_ALPHABETIC_Presentation_Forms}', "");
Expect(1, 64335, '\P{^	-In_ALPHABETIC_Presentation_Forms}', "");
Expect(0, 64336, '\p{	-In_ALPHABETIC_Presentation_Forms}', "");
Expect(1, 64336, '\p{^	-In_ALPHABETIC_Presentation_Forms}', "");
Expect(1, 64336, '\P{	-In_ALPHABETIC_Presentation_Forms}', "");
Expect(0, 64336, '\P{^	-In_ALPHABETIC_Presentation_Forms}', "");
Error('\p{	/a/Alphabetic_PF}');
Error('\P{	/a/Alphabetic_PF}');
Expect(1, 64335, '\p{alphabeticpf}', "");
Expect(0, 64335, '\p{^alphabeticpf}', "");
Expect(0, 64335, '\P{alphabeticpf}', "");
Expect(1, 64335, '\P{^alphabeticpf}', "");
Expect(0, 64336, '\p{alphabeticpf}', "");
Expect(1, 64336, '\p{^alphabeticpf}', "");
Expect(1, 64336, '\P{alphabeticpf}', "");
Expect(0, 64336, '\P{^alphabeticpf}', "");
Expect(1, 64335, '\p{-_alphabetic_PF}', "");
Expect(0, 64335, '\p{^-_alphabetic_PF}', "");
Expect(0, 64335, '\P{-_alphabetic_PF}', "");
Expect(1, 64335, '\P{^-_alphabetic_PF}', "");
Expect(0, 64336, '\p{-_alphabetic_PF}', "");
Expect(1, 64336, '\p{^-_alphabetic_PF}', "");
Expect(1, 64336, '\P{-_alphabetic_PF}', "");
Expect(0, 64336, '\P{^-_alphabetic_PF}', "");
Error('\p{--is_Alphabetic_PF/a/}');
Error('\P{--is_Alphabetic_PF/a/}');
Expect(1, 64335, '\p{isalphabeticpf}', "");
Expect(0, 64335, '\p{^isalphabeticpf}', "");
Expect(0, 64335, '\P{isalphabeticpf}', "");
Expect(1, 64335, '\P{^isalphabeticpf}', "");
Expect(0, 64336, '\p{isalphabeticpf}', "");
Expect(1, 64336, '\p{^isalphabeticpf}', "");
Expect(1, 64336, '\P{isalphabeticpf}', "");
Expect(0, 64336, '\P{^isalphabeticpf}', "");
Expect(1, 64335, '\p{ _IS_Alphabetic_PF}', "");
Expect(0, 64335, '\p{^ _IS_Alphabetic_PF}', "");
Expect(0, 64335, '\P{ _IS_Alphabetic_PF}', "");
Expect(1, 64335, '\P{^ _IS_Alphabetic_PF}', "");
Expect(0, 64336, '\p{ _IS_Alphabetic_PF}', "");
Expect(1, 64336, '\p{^ _IS_Alphabetic_PF}', "");
Expect(1, 64336, '\P{ _IS_Alphabetic_PF}', "");
Expect(0, 64336, '\P{^ _IS_Alphabetic_PF}', "");
Error('\p{ in_Alphabetic_PF/a/}');
Error('\P{ in_Alphabetic_PF/a/}');
Expect(1, 64335, '\p{inalphabeticpf}', "");
Expect(0, 64335, '\p{^inalphabeticpf}', "");
Expect(0, 64335, '\P{inalphabeticpf}', "");
Expect(1, 64335, '\P{^inalphabeticpf}', "");
Expect(0, 64336, '\p{inalphabeticpf}', "");
Expect(1, 64336, '\p{^inalphabeticpf}', "");
Expect(1, 64336, '\P{inalphabeticpf}', "");
Expect(0, 64336, '\P{^inalphabeticpf}', "");
Expect(1, 64335, '\p{_ IN_ALPHABETIC_PF}', "");
Expect(0, 64335, '\p{^_ IN_ALPHABETIC_PF}', "");
Expect(0, 64335, '\P{_ IN_ALPHABETIC_PF}', "");
Expect(1, 64335, '\P{^_ IN_ALPHABETIC_PF}', "");
Expect(0, 64336, '\p{_ IN_ALPHABETIC_PF}', "");
Expect(1, 64336, '\p{^_ IN_ALPHABETIC_PF}', "");
Expect(1, 64336, '\P{_ IN_ALPHABETIC_PF}', "");
Expect(0, 64336, '\P{^_ IN_ALPHABETIC_PF}', "");
Error('\p{:=		ancient_Greek_MUSICAL_NOTATION}');
Error('\P{:=		ancient_Greek_MUSICAL_NOTATION}');
Expect(1, 119375, '\p{ancientgreekmusicalnotation}', "");
Expect(0, 119375, '\p{^ancientgreekmusicalnotation}', "");
Expect(0, 119375, '\P{ancientgreekmusicalnotation}', "");
Expect(1, 119375, '\P{^ancientgreekmusicalnotation}', "");
Expect(0, 119376, '\p{ancientgreekmusicalnotation}', "");
Expect(1, 119376, '\p{^ancientgreekmusicalnotation}', "");
Expect(1, 119376, '\P{ancientgreekmusicalnotation}', "");
Expect(0, 119376, '\P{^ancientgreekmusicalnotation}', "");
Expect(1, 119375, '\p{__ancient_Greek_Musical_NOTATION}', "");
Expect(0, 119375, '\p{^__ancient_Greek_Musical_NOTATION}', "");
Expect(0, 119375, '\P{__ancient_Greek_Musical_NOTATION}', "");
Expect(1, 119375, '\P{^__ancient_Greek_Musical_NOTATION}', "");
Expect(0, 119376, '\p{__ancient_Greek_Musical_NOTATION}', "");
Expect(1, 119376, '\p{^__ancient_Greek_Musical_NOTATION}', "");
Expect(1, 119376, '\P{__ancient_Greek_Musical_NOTATION}', "");
Expect(0, 119376, '\P{^__ancient_Greek_Musical_NOTATION}', "");
Error('\p{:=_ is_Ancient_Greek_musical_Notation}');
Error('\P{:=_ is_Ancient_Greek_musical_Notation}');
Expect(1, 119375, '\p{isancientgreekmusicalnotation}', "");
Expect(0, 119375, '\p{^isancientgreekmusicalnotation}', "");
Expect(0, 119375, '\P{isancientgreekmusicalnotation}', "");
Expect(1, 119375, '\P{^isancientgreekmusicalnotation}', "");
Expect(0, 119376, '\p{isancientgreekmusicalnotation}', "");
Expect(1, 119376, '\p{^isancientgreekmusicalnotation}', "");
Expect(1, 119376, '\P{isancientgreekmusicalnotation}', "");
Expect(0, 119376, '\P{^isancientgreekmusicalnotation}', "");
Expect(1, 119375, '\p{-IS_ANCIENT_GREEK_Musical_Notation}', "");
Expect(0, 119375, '\p{^-IS_ANCIENT_GREEK_Musical_Notation}', "");
Expect(0, 119375, '\P{-IS_ANCIENT_GREEK_Musical_Notation}', "");
Expect(1, 119375, '\P{^-IS_ANCIENT_GREEK_Musical_Notation}', "");
Expect(0, 119376, '\p{-IS_ANCIENT_GREEK_Musical_Notation}', "");
Expect(1, 119376, '\p{^-IS_ANCIENT_GREEK_Musical_Notation}', "");
Expect(1, 119376, '\P{-IS_ANCIENT_GREEK_Musical_Notation}', "");
Expect(0, 119376, '\P{^-IS_ANCIENT_GREEK_Musical_Notation}', "");
Error('\p{	/a/In_ANCIENT_GREEK_Musical_Notation}');
Error('\P{	/a/In_ANCIENT_GREEK_Musical_Notation}');
Expect(1, 119375, '\p{inancientgreekmusicalnotation}', "");
Expect(0, 119375, '\p{^inancientgreekmusicalnotation}', "");
Expect(0, 119375, '\P{inancientgreekmusicalnotation}', "");
Expect(1, 119375, '\P{^inancientgreekmusicalnotation}', "");
Expect(0, 119376, '\p{inancientgreekmusicalnotation}', "");
Expect(1, 119376, '\p{^inancientgreekmusicalnotation}', "");
Expect(1, 119376, '\P{inancientgreekmusicalnotation}', "");
Expect(0, 119376, '\P{^inancientgreekmusicalnotation}', "");
Expect(1, 119375, '\p{ _In_Ancient_greek_musical_notation}', "");
Expect(0, 119375, '\p{^ _In_Ancient_greek_musical_notation}', "");
Expect(0, 119375, '\P{ _In_Ancient_greek_musical_notation}', "");
Expect(1, 119375, '\P{^ _In_Ancient_greek_musical_notation}', "");
Expect(0, 119376, '\p{ _In_Ancient_greek_musical_notation}', "");
Expect(1, 119376, '\p{^ _In_Ancient_greek_musical_notation}', "");
Expect(1, 119376, '\P{ _In_Ancient_greek_musical_notation}', "");
Expect(0, 119376, '\P{^ _In_Ancient_greek_musical_notation}', "");
Error('\p{:= Ancient_greek_MUSIC}');
Error('\P{:= Ancient_greek_MUSIC}');
Expect(1, 119375, '\p{ancientgreekmusic}', "");
Expect(0, 119375, '\p{^ancientgreekmusic}', "");
Expect(0, 119375, '\P{ancientgreekmusic}', "");
Expect(1, 119375, '\P{^ancientgreekmusic}', "");
Expect(0, 119376, '\p{ancientgreekmusic}', "");
Expect(1, 119376, '\p{^ancientgreekmusic}', "");
Expect(1, 119376, '\P{ancientgreekmusic}', "");
Expect(0, 119376, '\P{^ancientgreekmusic}', "");
Expect(1, 119375, '\p{  ancient_greek_MUSIC}', "");
Expect(0, 119375, '\p{^  ancient_greek_MUSIC}', "");
Expect(0, 119375, '\P{  ancient_greek_MUSIC}', "");
Expect(1, 119375, '\P{^  ancient_greek_MUSIC}', "");
Expect(0, 119376, '\p{  ancient_greek_MUSIC}', "");
Expect(1, 119376, '\p{^  ancient_greek_MUSIC}', "");
Expect(1, 119376, '\P{  ancient_greek_MUSIC}', "");
Expect(0, 119376, '\P{^  ancient_greek_MUSIC}', "");
Error('\p{_Is_ANCIENT_Greek_music:=}');
Error('\P{_Is_ANCIENT_Greek_music:=}');
Expect(1, 119375, '\p{isancientgreekmusic}', "");
Expect(0, 119375, '\p{^isancientgreekmusic}', "");
Expect(0, 119375, '\P{isancientgreekmusic}', "");
Expect(1, 119375, '\P{^isancientgreekmusic}', "");
Expect(0, 119376, '\p{isancientgreekmusic}', "");
Expect(1, 119376, '\p{^isancientgreekmusic}', "");
Expect(1, 119376, '\P{isancientgreekmusic}', "");
Expect(0, 119376, '\P{^isancientgreekmusic}', "");
Expect(1, 119375, '\p{  Is_ancient_Greek_Music}', "");
Expect(0, 119375, '\p{^  Is_ancient_Greek_Music}', "");
Expect(0, 119375, '\P{  Is_ancient_Greek_Music}', "");
Expect(1, 119375, '\P{^  Is_ancient_Greek_Music}', "");
Expect(0, 119376, '\p{  Is_ancient_Greek_Music}', "");
Expect(1, 119376, '\p{^  Is_ancient_Greek_Music}', "");
Expect(1, 119376, '\P{  Is_ancient_Greek_Music}', "");
Expect(0, 119376, '\P{^  Is_ancient_Greek_Music}', "");
Error('\p{--In_Ancient_greek_music/a/}');
Error('\P{--In_Ancient_greek_music/a/}');
Expect(1, 119375, '\p{inancientgreekmusic}', "");
Expect(0, 119375, '\p{^inancientgreekmusic}', "");
Expect(0, 119375, '\P{inancientgreekmusic}', "");
Expect(1, 119375, '\P{^inancientgreekmusic}', "");
Expect(0, 119376, '\p{inancientgreekmusic}', "");
Expect(1, 119376, '\p{^inancientgreekmusic}', "");
Expect(1, 119376, '\P{inancientgreekmusic}', "");
Expect(0, 119376, '\P{^inancientgreekmusic}', "");
Expect(1, 119375, '\p{_	In_Ancient_greek_Music}', "");
Expect(0, 119375, '\p{^_	In_Ancient_greek_Music}', "");
Expect(0, 119375, '\P{_	In_Ancient_greek_Music}', "");
Expect(1, 119375, '\P{^_	In_Ancient_greek_Music}', "");
Expect(0, 119376, '\p{_	In_Ancient_greek_Music}', "");
Expect(1, 119376, '\p{^_	In_Ancient_greek_Music}', "");
Expect(1, 119376, '\P{_	In_Ancient_greek_Music}', "");
Expect(0, 119376, '\P{^_	In_Ancient_greek_Music}', "");
Error('\p{/a/_ANCIENT_GREEK_Numbers}');
Error('\P{/a/_ANCIENT_GREEK_Numbers}');
Expect(1, 65935, '\p{ancientgreeknumbers}', "");
Expect(0, 65935, '\p{^ancientgreeknumbers}', "");
Expect(0, 65935, '\P{ancientgreeknumbers}', "");
Expect(1, 65935, '\P{^ancientgreeknumbers}', "");
Expect(0, 65936, '\p{ancientgreeknumbers}', "");
Expect(1, 65936, '\p{^ancientgreeknumbers}', "");
Expect(1, 65936, '\P{ancientgreeknumbers}', "");
Expect(0, 65936, '\P{^ancientgreeknumbers}', "");
Expect(1, 65935, '\p{ -Ancient_greek_Numbers}', "");
Expect(0, 65935, '\p{^ -Ancient_greek_Numbers}', "");
Expect(0, 65935, '\P{ -Ancient_greek_Numbers}', "");
Expect(1, 65935, '\P{^ -Ancient_greek_Numbers}', "");
Expect(0, 65936, '\p{ -Ancient_greek_Numbers}', "");
Expect(1, 65936, '\p{^ -Ancient_greek_Numbers}', "");
Expect(1, 65936, '\P{ -Ancient_greek_Numbers}', "");
Expect(0, 65936, '\P{^ -Ancient_greek_Numbers}', "");
Error('\p{-/a/Is_ANCIENT_Greek_Numbers}');
Error('\P{-/a/Is_ANCIENT_Greek_Numbers}');
Expect(1, 65935, '\p{isancientgreeknumbers}', "");
Expect(0, 65935, '\p{^isancientgreeknumbers}', "");
Expect(0, 65935, '\P{isancientgreeknumbers}', "");
Expect(1, 65935, '\P{^isancientgreeknumbers}', "");
Expect(0, 65936, '\p{isancientgreeknumbers}', "");
Expect(1, 65936, '\p{^isancientgreeknumbers}', "");
Expect(1, 65936, '\P{isancientgreeknumbers}', "");
Expect(0, 65936, '\P{^isancientgreeknumbers}', "");
Expect(1, 65935, '\p{ 	Is_Ancient_Greek_NUMBERS}', "");
Expect(0, 65935, '\p{^ 	Is_Ancient_Greek_NUMBERS}', "");
Expect(0, 65935, '\P{ 	Is_Ancient_Greek_NUMBERS}', "");
Expect(1, 65935, '\P{^ 	Is_Ancient_Greek_NUMBERS}', "");
Expect(0, 65936, '\p{ 	Is_Ancient_Greek_NUMBERS}', "");
Expect(1, 65936, '\p{^ 	Is_Ancient_Greek_NUMBERS}', "");
Expect(1, 65936, '\P{ 	Is_Ancient_Greek_NUMBERS}', "");
Expect(0, 65936, '\P{^ 	Is_Ancient_Greek_NUMBERS}', "");
Error('\p{:=_In_Ancient_Greek_Numbers}');
Error('\P{:=_In_Ancient_Greek_Numbers}');
Expect(1, 65935, '\p{inancientgreeknumbers}', "");
Expect(0, 65935, '\p{^inancientgreeknumbers}', "");
Expect(0, 65935, '\P{inancientgreeknumbers}', "");
Expect(1, 65935, '\P{^inancientgreeknumbers}', "");
Expect(0, 65936, '\p{inancientgreeknumbers}', "");
Expect(1, 65936, '\p{^inancientgreeknumbers}', "");
Expect(1, 65936, '\P{inancientgreeknumbers}', "");
Expect(0, 65936, '\P{^inancientgreeknumbers}', "");
Expect(1, 65935, '\p{_in_ancient_GREEK_Numbers}', "");
Expect(0, 65935, '\p{^_in_ancient_GREEK_Numbers}', "");
Expect(0, 65935, '\P{_in_ancient_GREEK_Numbers}', "");
Expect(1, 65935, '\P{^_in_ancient_GREEK_Numbers}', "");
Expect(0, 65936, '\p{_in_ancient_GREEK_Numbers}', "");
Expect(1, 65936, '\p{^_in_ancient_GREEK_Numbers}', "");
Expect(1, 65936, '\P{_in_ancient_GREEK_Numbers}', "");
Expect(0, 65936, '\P{^_in_ancient_GREEK_Numbers}', "");
Error('\p{ ancient_symbols:=}');
Error('\P{ ancient_symbols:=}');
Expect(1, 65999, '\p{ancientsymbols}', "");
Expect(0, 65999, '\p{^ancientsymbols}', "");
Expect(0, 65999, '\P{ancientsymbols}', "");
Expect(1, 65999, '\P{^ancientsymbols}', "");
Expect(0, 66000, '\p{ancientsymbols}', "");
Expect(1, 66000, '\p{^ancientsymbols}', "");
Expect(1, 66000, '\P{ancientsymbols}', "");
Expect(0, 66000, '\P{^ancientsymbols}', "");
Expect(1, 65999, '\p{ _ANCIENT_symbols}', "");
Expect(0, 65999, '\p{^ _ANCIENT_symbols}', "");
Expect(0, 65999, '\P{ _ANCIENT_symbols}', "");
Expect(1, 65999, '\P{^ _ANCIENT_symbols}', "");
Expect(0, 66000, '\p{ _ANCIENT_symbols}', "");
Expect(1, 66000, '\p{^ _ANCIENT_symbols}', "");
Expect(1, 66000, '\P{ _ANCIENT_symbols}', "");
Expect(0, 66000, '\P{^ _ANCIENT_symbols}', "");
Error('\p{:=Is_Ancient_Symbols}');
Error('\P{:=Is_Ancient_Symbols}');
Expect(1, 65999, '\p{isancientsymbols}', "");
Expect(0, 65999, '\p{^isancientsymbols}', "");
Expect(0, 65999, '\P{isancientsymbols}', "");
Expect(1, 65999, '\P{^isancientsymbols}', "");
Expect(0, 66000, '\p{isancientsymbols}', "");
Expect(1, 66000, '\p{^isancientsymbols}', "");
Expect(1, 66000, '\P{isancientsymbols}', "");
Expect(0, 66000, '\P{^isancientsymbols}', "");
Expect(1, 65999, '\p{	is_ANCIENT_symbols}', "");
Expect(0, 65999, '\p{^	is_ANCIENT_symbols}', "");
Expect(0, 65999, '\P{	is_ANCIENT_symbols}', "");
Expect(1, 65999, '\P{^	is_ANCIENT_symbols}', "");
Expect(0, 66000, '\p{	is_ANCIENT_symbols}', "");
Expect(1, 66000, '\p{^	is_ANCIENT_symbols}', "");
Expect(1, 66000, '\P{	is_ANCIENT_symbols}', "");
Expect(0, 66000, '\P{^	is_ANCIENT_symbols}', "");
Error('\p{	In_Ancient_SYMBOLS:=}');
Error('\P{	In_Ancient_SYMBOLS:=}');
Expect(1, 65999, '\p{inancientsymbols}', "");
Expect(0, 65999, '\p{^inancientsymbols}', "");
Expect(0, 65999, '\P{inancientsymbols}', "");
Expect(1, 65999, '\P{^inancientsymbols}', "");
Expect(0, 66000, '\p{inancientsymbols}', "");
Expect(1, 66000, '\p{^inancientsymbols}', "");
Expect(1, 66000, '\P{inancientsymbols}', "");
Expect(0, 66000, '\P{^inancientsymbols}', "");
Expect(1, 65999, '\p{	_IN_Ancient_Symbols}', "");
Expect(0, 65999, '\p{^	_IN_Ancient_Symbols}', "");
Expect(0, 65999, '\P{	_IN_Ancient_Symbols}', "");
Expect(1, 65999, '\P{^	_IN_Ancient_Symbols}', "");
Expect(0, 66000, '\p{	_IN_Ancient_Symbols}', "");
Expect(1, 66000, '\p{^	_IN_Ancient_Symbols}', "");
Expect(1, 66000, '\P{	_IN_Ancient_Symbols}', "");
Expect(0, 66000, '\P{^	_IN_Ancient_Symbols}', "");
Error('\p{:=__any}');
Error('\P{:=__any}');
Expect(1, 1, '\p{any}', "");
Expect(0, 1, '\p{^any}', "");
Expect(0, 1, '\P{any}', "");
Expect(1, 1, '\P{^any}', "");
Expect(0, 8912887, '\p{any}', "");
Expect(1, 8912887, '\p{^any}', "");
Expect(1, 8912887, '\P{any}', "");
Expect(0, 8912887, '\P{^any}', "");
Expect(1, 1, '\p{_ Any}', "");
Expect(0, 1, '\p{^_ Any}', "");
Expect(0, 1, '\P{_ Any}', "");
Expect(1, 1, '\P{^_ Any}', "");
Expect(0, 8912887, '\p{_ Any}', "");
Expect(1, 8912887, '\p{^_ Any}', "");
Expect(1, 8912887, '\P{_ Any}', "");
Expect(0, 8912887, '\P{^_ Any}', "");
Error('\p{:=unicode}');
Error('\P{:=unicode}');
Expect(1, 1, '\p{unicode}', "");
Expect(0, 1, '\p{^unicode}', "");
Expect(0, 1, '\P{unicode}', "");
Expect(1, 1, '\P{^unicode}', "");
Expect(0, 8912887, '\p{unicode}', "");
Expect(1, 8912887, '\p{^unicode}', "");
Expect(1, 8912887, '\P{unicode}', "");
Expect(0, 8912887, '\P{^unicode}', "");
Expect(1, 1, '\p{-	Unicode}', "");
Expect(0, 1, '\p{^-	Unicode}', "");
Expect(0, 1, '\P{-	Unicode}', "");
Expect(1, 1, '\P{^-	Unicode}', "");
Expect(0, 8912887, '\p{-	Unicode}', "");
Expect(1, 8912887, '\p{^-	Unicode}', "");
Expect(1, 8912887, '\P{-	Unicode}', "");
Expect(0, 8912887, '\P{^-	Unicode}', "");
Error('\p{_:=is_any}');
Error('\P{_:=is_any}');
Expect(1, 1, '\p{isany}', "");
Expect(0, 1, '\p{^isany}', "");
Expect(0, 1, '\P{isany}', "");
Expect(1, 1, '\P{^isany}', "");
Expect(0, 8912887, '\p{isany}', "");
Expect(1, 8912887, '\p{^isany}', "");
Expect(1, 8912887, '\P{isany}', "");
Expect(0, 8912887, '\P{^isany}', "");
Expect(1, 1, '\p{ Is_any}', "");
Expect(0, 1, '\p{^ Is_any}', "");
Expect(0, 1, '\P{ Is_any}', "");
Expect(1, 1, '\P{^ Is_any}', "");
Expect(0, 8912887, '\p{ Is_any}', "");
Expect(1, 8912887, '\p{^ Is_any}', "");
Expect(1, 8912887, '\P{ Is_any}', "");
Expect(0, 8912887, '\P{^ Is_any}', "");
Error('\p{ -is_Unicode/a/}');
Error('\P{ -is_Unicode/a/}');
Expect(1, 1, '\p{isunicode}', "");
Expect(0, 1, '\p{^isunicode}', "");
Expect(0, 1, '\P{isunicode}', "");
Expect(1, 1, '\P{^isunicode}', "");
Expect(0, 8912887, '\p{isunicode}', "");
Expect(1, 8912887, '\p{^isunicode}', "");
Expect(1, 8912887, '\P{isunicode}', "");
Expect(0, 8912887, '\P{^isunicode}', "");
Expect(1, 1, '\p{_-Is_unicode}', "");
Expect(0, 1, '\p{^_-Is_unicode}', "");
Expect(0, 1, '\P{_-Is_unicode}', "");
Expect(1, 1, '\P{^_-Is_unicode}', "");
Expect(0, 8912887, '\p{_-Is_unicode}', "");
Expect(1, 8912887, '\p{^_-Is_unicode}', "");
Expect(1, 8912887, '\P{_-Is_unicode}', "");
Expect(0, 8912887, '\P{^_-Is_unicode}', "");
Error('\p{-:=ARABIC}');
Error('\P{-:=ARABIC}');
Expect(1, 126705, '\p{arabic}', "");
Expect(0, 126705, '\p{^arabic}', "");
Expect(0, 126705, '\P{arabic}', "");
Expect(1, 126705, '\P{^arabic}', "");
Expect(0, 126706, '\p{arabic}', "");
Expect(1, 126706, '\p{^arabic}', "");
Expect(1, 126706, '\P{arabic}', "");
Expect(0, 126706, '\P{^arabic}', "");
Expect(1, 126705, '\p{	ARABIC}', "");
Expect(0, 126705, '\p{^	ARABIC}', "");
Expect(0, 126705, '\P{	ARABIC}', "");
Expect(1, 126705, '\P{^	ARABIC}', "");
Expect(0, 126706, '\p{	ARABIC}', "");
Expect(1, 126706, '\p{^	ARABIC}', "");
Expect(1, 126706, '\P{	ARABIC}', "");
Expect(0, 126706, '\P{^	ARABIC}', "");
Error('\p{--IS_ARABIC:=}');
Error('\P{--IS_ARABIC:=}');
Expect(1, 126705, '\p{isarabic}', "");
Expect(0, 126705, '\p{^isarabic}', "");
Expect(0, 126705, '\P{isarabic}', "");
Expect(1, 126705, '\P{^isarabic}', "");
Expect(0, 126706, '\p{isarabic}', "");
Expect(1, 126706, '\p{^isarabic}', "");
Expect(1, 126706, '\P{isarabic}', "");
Expect(0, 126706, '\P{^isarabic}', "");
Expect(1, 126705, '\p{-Is_ARABIC}', "");
Expect(0, 126705, '\p{^-Is_ARABIC}', "");
Expect(0, 126705, '\P{-Is_ARABIC}', "");
Expect(1, 126705, '\P{^-Is_ARABIC}', "");
Expect(0, 126706, '\p{-Is_ARABIC}', "");
Expect(1, 126706, '\p{^-Is_ARABIC}', "");
Expect(1, 126706, '\P{-Is_ARABIC}', "");
Expect(0, 126706, '\P{^-Is_ARABIC}', "");
Error('\p{		arab:=}');
Error('\P{		arab:=}');
Expect(1, 126705, '\p{arab}', "");
Expect(0, 126705, '\p{^arab}', "");
Expect(0, 126705, '\P{arab}', "");
Expect(1, 126705, '\P{^arab}', "");
Expect(0, 126706, '\p{arab}', "");
Expect(1, 126706, '\p{^arab}', "");
Expect(1, 126706, '\P{arab}', "");
Expect(0, 126706, '\P{^arab}', "");
Expect(1, 126705, '\p{	ARAB}', "");
Expect(0, 126705, '\p{^	ARAB}', "");
Expect(0, 126705, '\P{	ARAB}', "");
Expect(1, 126705, '\P{^	ARAB}', "");
Expect(0, 126706, '\p{	ARAB}', "");
Expect(1, 126706, '\p{^	ARAB}', "");
Expect(1, 126706, '\P{	ARAB}', "");
Expect(0, 126706, '\P{^	ARAB}', "");
Error('\p{:=  IS_arab}');
Error('\P{:=  IS_arab}');
Expect(1, 126705, '\p{isarab}', "");
Expect(0, 126705, '\p{^isarab}', "");
Expect(0, 126705, '\P{isarab}', "");
Expect(1, 126705, '\P{^isarab}', "");
Expect(0, 126706, '\p{isarab}', "");
Expect(1, 126706, '\p{^isarab}', "");
Expect(1, 126706, '\P{isarab}', "");
Expect(0, 126706, '\P{^isarab}', "");
Expect(1, 126705, '\p{-_is_Arab}', "");
Expect(0, 126705, '\p{^-_is_Arab}', "");
Expect(0, 126705, '\P{-_is_Arab}', "");
Expect(1, 126705, '\P{^-_is_Arab}', "");
Expect(0, 126706, '\p{-_is_Arab}', "");
Expect(1, 126706, '\p{^-_is_Arab}', "");
Expect(1, 126706, '\P{-_is_Arab}', "");
Expect(0, 126706, '\P{^-_is_Arab}', "");
Error('\p{ -Arabic_extended_a/a/}');
Error('\P{ -Arabic_extended_a/a/}');
Expect(1, 2303, '\p{arabicextendeda}', "");
Expect(0, 2303, '\p{^arabicextendeda}', "");
Expect(0, 2303, '\P{arabicextendeda}', "");
Expect(1, 2303, '\P{^arabicextendeda}', "");
Expect(0, 2304, '\p{arabicextendeda}', "");
Expect(1, 2304, '\p{^arabicextendeda}', "");
Expect(1, 2304, '\P{arabicextendeda}', "");
Expect(0, 2304, '\P{^arabicextendeda}', "");
Expect(1, 2303, '\p{_Arabic_extended_A}', "");
Expect(0, 2303, '\p{^_Arabic_extended_A}', "");
Expect(0, 2303, '\P{_Arabic_extended_A}', "");
Expect(1, 2303, '\P{^_Arabic_extended_A}', "");
Expect(0, 2304, '\p{_Arabic_extended_A}', "");
Expect(1, 2304, '\p{^_Arabic_extended_A}', "");
Expect(1, 2304, '\P{_Arabic_extended_A}', "");
Expect(0, 2304, '\P{^_Arabic_extended_A}', "");
Error('\p{_-Is_Arabic_EXTENDED_A/a/}');
Error('\P{_-Is_Arabic_EXTENDED_A/a/}');
Expect(1, 2303, '\p{isarabicextendeda}', "");
Expect(0, 2303, '\p{^isarabicextendeda}', "");
Expect(0, 2303, '\P{isarabicextendeda}', "");
Expect(1, 2303, '\P{^isarabicextendeda}', "");
Expect(0, 2304, '\p{isarabicextendeda}', "");
Expect(1, 2304, '\p{^isarabicextendeda}', "");
Expect(1, 2304, '\P{isarabicextendeda}', "");
Expect(0, 2304, '\P{^isarabicextendeda}', "");
Expect(1, 2303, '\p{_IS_ARABIC_EXTENDED_A}', "");
Expect(0, 2303, '\p{^_IS_ARABIC_EXTENDED_A}', "");
Expect(0, 2303, '\P{_IS_ARABIC_EXTENDED_A}', "");
Expect(1, 2303, '\P{^_IS_ARABIC_EXTENDED_A}', "");
Expect(0, 2304, '\p{_IS_ARABIC_EXTENDED_A}', "");
Expect(1, 2304, '\p{^_IS_ARABIC_EXTENDED_A}', "");
Expect(1, 2304, '\P{_IS_ARABIC_EXTENDED_A}', "");
Expect(0, 2304, '\P{^_IS_ARABIC_EXTENDED_A}', "");
Error('\p{_:=In_ARABIC_extended_A}');
Error('\P{_:=In_ARABIC_extended_A}');
Expect(1, 2303, '\p{inarabicextendeda}', "");
Expect(0, 2303, '\p{^inarabicextendeda}', "");
Expect(0, 2303, '\P{inarabicextendeda}', "");
Expect(1, 2303, '\P{^inarabicextendeda}', "");
Expect(0, 2304, '\p{inarabicextendeda}', "");
Expect(1, 2304, '\p{^inarabicextendeda}', "");
Expect(1, 2304, '\P{inarabicextendeda}', "");
Expect(0, 2304, '\P{^inarabicextendeda}', "");
Expect(1, 2303, '\p{ In_Arabic_extended_a}', "");
Expect(0, 2303, '\p{^ In_Arabic_extended_a}', "");
Expect(0, 2303, '\P{ In_Arabic_extended_a}', "");
Expect(1, 2303, '\P{^ In_Arabic_extended_a}', "");
Expect(0, 2304, '\p{ In_Arabic_extended_a}', "");
Expect(1, 2304, '\p{^ In_Arabic_extended_a}', "");
Expect(1, 2304, '\P{ In_Arabic_extended_a}', "");
Expect(0, 2304, '\P{^ In_Arabic_extended_a}', "");
Error('\p{_:=arabic_Ext_a}');
Error('\P{_:=arabic_Ext_a}');
Expect(1, 2303, '\p{arabicexta}', "");
Expect(0, 2303, '\p{^arabicexta}', "");
Expect(0, 2303, '\P{arabicexta}', "");
Expect(1, 2303, '\P{^arabicexta}', "");
Expect(0, 2304, '\p{arabicexta}', "");
Expect(1, 2304, '\p{^arabicexta}', "");
Expect(1, 2304, '\P{arabicexta}', "");
Expect(0, 2304, '\P{^arabicexta}', "");
Expect(1, 2303, '\p{ Arabic_ext_A}', "");
Expect(0, 2303, '\p{^ Arabic_ext_A}', "");
Expect(0, 2303, '\P{ Arabic_ext_A}', "");
Expect(1, 2303, '\P{^ Arabic_ext_A}', "");
Expect(0, 2304, '\p{ Arabic_ext_A}', "");
Expect(1, 2304, '\p{^ Arabic_ext_A}', "");
Expect(1, 2304, '\P{ Arabic_ext_A}', "");
Expect(0, 2304, '\P{^ Arabic_ext_A}', "");
Error('\p{ -Is_Arabic_ext_a:=}');
Error('\P{ -Is_Arabic_ext_a:=}');
Expect(1, 2303, '\p{isarabicexta}', "");
Expect(0, 2303, '\p{^isarabicexta}', "");
Expect(0, 2303, '\P{isarabicexta}', "");
Expect(1, 2303, '\P{^isarabicexta}', "");
Expect(0, 2304, '\p{isarabicexta}', "");
Expect(1, 2304, '\p{^isarabicexta}', "");
Expect(1, 2304, '\P{isarabicexta}', "");
Expect(0, 2304, '\P{^isarabicexta}', "");
Expect(1, 2303, '\p{	IS_Arabic_ext_A}', "");
Expect(0, 2303, '\p{^	IS_Arabic_ext_A}', "");
Expect(0, 2303, '\P{	IS_Arabic_ext_A}', "");
Expect(1, 2303, '\P{^	IS_Arabic_ext_A}', "");
Expect(0, 2304, '\p{	IS_Arabic_ext_A}', "");
Expect(1, 2304, '\p{^	IS_Arabic_ext_A}', "");
Expect(1, 2304, '\P{	IS_Arabic_ext_A}', "");
Expect(0, 2304, '\P{^	IS_Arabic_ext_A}', "");
Error('\p{:=	In_Arabic_ext_A}');
Error('\P{:=	In_Arabic_ext_A}');
Expect(1, 2303, '\p{inarabicexta}', "");
Expect(0, 2303, '\p{^inarabicexta}', "");
Expect(0, 2303, '\P{inarabicexta}', "");
Expect(1, 2303, '\P{^inarabicexta}', "");
Expect(0, 2304, '\p{inarabicexta}', "");
Expect(1, 2304, '\p{^inarabicexta}', "");
Expect(1, 2304, '\P{inarabicexta}', "");
Expect(0, 2304, '\P{^inarabicexta}', "");
Expect(1, 2303, '\p{in_ARABIC_Ext_A}', "");
Expect(0, 2303, '\p{^in_ARABIC_Ext_A}', "");
Expect(0, 2303, '\P{in_ARABIC_Ext_A}', "");
Expect(1, 2303, '\P{^in_ARABIC_Ext_A}', "");
Expect(0, 2304, '\p{in_ARABIC_Ext_A}', "");
Expect(1, 2304, '\p{^in_ARABIC_Ext_A}', "");
Expect(1, 2304, '\P{in_ARABIC_Ext_A}', "");
Expect(0, 2304, '\P{^in_ARABIC_Ext_A}', "");
Error('\p{Arabic_Mathematical_alphabetic_Symbols/a/}');
Error('\P{Arabic_Mathematical_alphabetic_Symbols/a/}');
Expect(1, 126719, '\p{arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\p{^arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\P{arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\P{^arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\p{arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\p{^arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\P{arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\P{^arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\p{_	Arabic_Mathematical_ALPHABETIC_symbols}', "");
Expect(0, 126719, '\p{^_	Arabic_Mathematical_ALPHABETIC_symbols}', "");
Expect(0, 126719, '\P{_	Arabic_Mathematical_ALPHABETIC_symbols}', "");
Expect(1, 126719, '\P{^_	Arabic_Mathematical_ALPHABETIC_symbols}', "");
Expect(0, 126720, '\p{_	Arabic_Mathematical_ALPHABETIC_symbols}', "");
Expect(1, 126720, '\p{^_	Arabic_Mathematical_ALPHABETIC_symbols}', "");
Expect(1, 126720, '\P{_	Arabic_Mathematical_ALPHABETIC_symbols}', "");
Expect(0, 126720, '\P{^_	Arabic_Mathematical_ALPHABETIC_symbols}', "");
Error('\p{:=-_is_arabic_Mathematical_Alphabetic_symbols}');
Error('\P{:=-_is_arabic_Mathematical_Alphabetic_symbols}');
Expect(1, 126719, '\p{isarabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\p{^isarabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\P{isarabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\P{^isarabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\p{isarabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\p{^isarabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\P{isarabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\P{^isarabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\p{ 	Is_arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(0, 126719, '\p{^ 	Is_arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(0, 126719, '\P{ 	Is_arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(1, 126719, '\P{^ 	Is_arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(0, 126720, '\p{ 	Is_arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(1, 126720, '\p{^ 	Is_arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(1, 126720, '\P{ 	Is_arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(0, 126720, '\P{^ 	Is_arabic_Mathematical_Alphabetic_Symbols}', "");
Error('\p{/a/-	In_Arabic_Mathematical_Alphabetic_symbols}');
Error('\P{/a/-	In_Arabic_Mathematical_Alphabetic_symbols}');
Expect(1, 126719, '\p{inarabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\p{^inarabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\P{inarabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\P{^inarabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\p{inarabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\p{^inarabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\P{inarabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\P{^inarabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\p{_ IN_Arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(0, 126719, '\p{^_ IN_Arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(0, 126719, '\P{_ IN_Arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(1, 126719, '\P{^_ IN_Arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(0, 126720, '\p{_ IN_Arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(1, 126720, '\p{^_ IN_Arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(1, 126720, '\P{_ IN_Arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(0, 126720, '\P{^_ IN_Arabic_Mathematical_Alphabetic_Symbols}', "");
Error('\p{-_ARABIC_Math:=}');
Error('\P{-_ARABIC_Math:=}');
Expect(1, 126719, '\p{arabicmath}', "");
Expect(0, 126719, '\p{^arabicmath}', "");
Expect(0, 126719, '\P{arabicmath}', "");
Expect(1, 126719, '\P{^arabicmath}', "");
Expect(0, 126720, '\p{arabicmath}', "");
Expect(1, 126720, '\p{^arabicmath}', "");
Expect(1, 126720, '\P{arabicmath}', "");
Expect(0, 126720, '\P{^arabicmath}', "");
Expect(1, 126719, '\p{-_arabic_MATH}', "");
Expect(0, 126719, '\p{^-_arabic_MATH}', "");
Expect(0, 126719, '\P{-_arabic_MATH}', "");
Expect(1, 126719, '\P{^-_arabic_MATH}', "");
Expect(0, 126720, '\p{-_arabic_MATH}', "");
Expect(1, 126720, '\p{^-_arabic_MATH}', "");
Expect(1, 126720, '\P{-_arabic_MATH}', "");
Expect(0, 126720, '\P{^-_arabic_MATH}', "");
Error('\p{:=	Is_Arabic_Math}');
Error('\P{:=	Is_Arabic_Math}');
Expect(1, 126719, '\p{isarabicmath}', "");
Expect(0, 126719, '\p{^isarabicmath}', "");
Expect(0, 126719, '\P{isarabicmath}', "");
Expect(1, 126719, '\P{^isarabicmath}', "");
Expect(0, 126720, '\p{isarabicmath}', "");
Expect(1, 126720, '\p{^isarabicmath}', "");
Expect(1, 126720, '\P{isarabicmath}', "");
Expect(0, 126720, '\P{^isarabicmath}', "");
Expect(1, 126719, '\p{		is_arabic_MATH}', "");
Expect(0, 126719, '\p{^		is_arabic_MATH}', "");
Expect(0, 126719, '\P{		is_arabic_MATH}', "");
Expect(1, 126719, '\P{^		is_arabic_MATH}', "");
Expect(0, 126720, '\p{		is_arabic_MATH}', "");
Expect(1, 126720, '\p{^		is_arabic_MATH}', "");
Expect(1, 126720, '\P{		is_arabic_MATH}', "");
Expect(0, 126720, '\P{^		is_arabic_MATH}', "");
Error('\p{:=-In_Arabic_Math}');
Error('\P{:=-In_Arabic_Math}');
Expect(1, 126719, '\p{inarabicmath}', "");
Expect(0, 126719, '\p{^inarabicmath}', "");
Expect(0, 126719, '\P{inarabicmath}', "");
Expect(1, 126719, '\P{^inarabicmath}', "");
Expect(0, 126720, '\p{inarabicmath}', "");
Expect(1, 126720, '\p{^inarabicmath}', "");
Expect(1, 126720, '\P{inarabicmath}', "");
Expect(0, 126720, '\P{^inarabicmath}', "");
Expect(1, 126719, '\p{_IN_ARABIC_Math}', "");
Expect(0, 126719, '\p{^_IN_ARABIC_Math}', "");
Expect(0, 126719, '\P{_IN_ARABIC_Math}', "");
Expect(1, 126719, '\P{^_IN_ARABIC_Math}', "");
Expect(0, 126720, '\p{_IN_ARABIC_Math}', "");
Expect(1, 126720, '\p{^_IN_ARABIC_Math}', "");
Expect(1, 126720, '\P{_IN_ARABIC_Math}', "");
Expect(0, 126720, '\P{^_IN_ARABIC_Math}', "");
Error('\p{:=  Arabic_Presentation_forms_A}');
Error('\P{:=  Arabic_Presentation_forms_A}');
Expect(1, 65023, '\p{arabicpresentationformsa}', "");
Expect(0, 65023, '\p{^arabicpresentationformsa}', "");
Expect(0, 65023, '\P{arabicpresentationformsa}', "");
Expect(1, 65023, '\P{^arabicpresentationformsa}', "");
Expect(0, 65024, '\p{arabicpresentationformsa}', "");
Expect(1, 65024, '\p{^arabicpresentationformsa}', "");
Expect(1, 65024, '\P{arabicpresentationformsa}', "");
Expect(0, 65024, '\P{^arabicpresentationformsa}', "");
Expect(1, 65023, '\p{ 	Arabic_Presentation_Forms_A}', "");
Expect(0, 65023, '\p{^ 	Arabic_Presentation_Forms_A}', "");
Expect(0, 65023, '\P{ 	Arabic_Presentation_Forms_A}', "");
Expect(1, 65023, '\P{^ 	Arabic_Presentation_Forms_A}', "");
Expect(0, 65024, '\p{ 	Arabic_Presentation_Forms_A}', "");
Expect(1, 65024, '\p{^ 	Arabic_Presentation_Forms_A}', "");
Expect(1, 65024, '\P{ 	Arabic_Presentation_Forms_A}', "");
Expect(0, 65024, '\P{^ 	Arabic_Presentation_Forms_A}', "");
Error('\p{-:=Is_ARABIC_Presentation_FORMS_A}');
Error('\P{-:=Is_ARABIC_Presentation_FORMS_A}');
Expect(1, 65023, '\p{isarabicpresentationformsa}', "");
Expect(0, 65023, '\p{^isarabicpresentationformsa}', "");
Expect(0, 65023, '\P{isarabicpresentationformsa}', "");
Expect(1, 65023, '\P{^isarabicpresentationformsa}', "");
Expect(0, 65024, '\p{isarabicpresentationformsa}', "");
Expect(1, 65024, '\p{^isarabicpresentationformsa}', "");
Expect(1, 65024, '\P{isarabicpresentationformsa}', "");
Expect(0, 65024, '\P{^isarabicpresentationformsa}', "");
Expect(1, 65023, '\p{_	Is_arabic_presentation_FORMS_A}', "");
Expect(0, 65023, '\p{^_	Is_arabic_presentation_FORMS_A}', "");
Expect(0, 65023, '\P{_	Is_arabic_presentation_FORMS_A}', "");
Expect(1, 65023, '\P{^_	Is_arabic_presentation_FORMS_A}', "");
Expect(0, 65024, '\p{_	Is_arabic_presentation_FORMS_A}', "");
Expect(1, 65024, '\p{^_	Is_arabic_presentation_FORMS_A}', "");
Expect(1, 65024, '\P{_	Is_arabic_presentation_FORMS_A}', "");
Expect(0, 65024, '\P{^_	Is_arabic_presentation_FORMS_A}', "");
Error('\p{_/a/In_arabic_presentation_forms_a}');
Error('\P{_/a/In_arabic_presentation_forms_a}');
Expect(1, 65023, '\p{inarabicpresentationformsa}', "");
Expect(0, 65023, '\p{^inarabicpresentationformsa}', "");
Expect(0, 65023, '\P{inarabicpresentationformsa}', "");
Expect(1, 65023, '\P{^inarabicpresentationformsa}', "");
Expect(0, 65024, '\p{inarabicpresentationformsa}', "");
Expect(1, 65024, '\p{^inarabicpresentationformsa}', "");
Expect(1, 65024, '\P{inarabicpresentationformsa}', "");
Expect(0, 65024, '\P{^inarabicpresentationformsa}', "");
Expect(1, 65023, '\p{ 	IN_arabic_PRESENTATION_Forms_A}', "");
Expect(0, 65023, '\p{^ 	IN_arabic_PRESENTATION_Forms_A}', "");
Expect(0, 65023, '\P{ 	IN_arabic_PRESENTATION_Forms_A}', "");
Expect(1, 65023, '\P{^ 	IN_arabic_PRESENTATION_Forms_A}', "");
Expect(0, 65024, '\p{ 	IN_arabic_PRESENTATION_Forms_A}', "");
Expect(1, 65024, '\p{^ 	IN_arabic_PRESENTATION_Forms_A}', "");
Expect(1, 65024, '\P{ 	IN_arabic_PRESENTATION_Forms_A}', "");
Expect(0, 65024, '\P{^ 	IN_arabic_PRESENTATION_Forms_A}', "");
Error('\p{-	Arabic_pf_a:=}');
Error('\P{-	Arabic_pf_a:=}');
Expect(1, 65023, '\p{arabicpfa}', "");
Expect(0, 65023, '\p{^arabicpfa}', "");
Expect(0, 65023, '\P{arabicpfa}', "");
Expect(1, 65023, '\P{^arabicpfa}', "");
Expect(0, 65024, '\p{arabicpfa}', "");
Expect(1, 65024, '\p{^arabicpfa}', "");
Expect(1, 65024, '\P{arabicpfa}', "");
Expect(0, 65024, '\P{^arabicpfa}', "");
Expect(1, 65023, '\p{	arabic_PF_A}', "");
Expect(0, 65023, '\p{^	arabic_PF_A}', "");
Expect(0, 65023, '\P{	arabic_PF_A}', "");
Expect(1, 65023, '\P{^	arabic_PF_A}', "");
Expect(0, 65024, '\p{	arabic_PF_A}', "");
Expect(1, 65024, '\p{^	arabic_PF_A}', "");
Expect(1, 65024, '\P{	arabic_PF_A}', "");
Expect(0, 65024, '\P{^	arabic_PF_A}', "");
Error('\p{/a/_-Is_Arabic_pf_a}');
Error('\P{/a/_-Is_Arabic_pf_a}');
Expect(1, 65023, '\p{isarabicpfa}', "");
Expect(0, 65023, '\p{^isarabicpfa}', "");
Expect(0, 65023, '\P{isarabicpfa}', "");
Expect(1, 65023, '\P{^isarabicpfa}', "");
Expect(0, 65024, '\p{isarabicpfa}', "");
Expect(1, 65024, '\p{^isarabicpfa}', "");
Expect(1, 65024, '\P{isarabicpfa}', "");
Expect(0, 65024, '\P{^isarabicpfa}', "");
Expect(1, 65023, '\p{_	Is_Arabic_PF_a}', "");
Expect(0, 65023, '\p{^_	Is_Arabic_PF_a}', "");
Expect(0, 65023, '\P{_	Is_Arabic_PF_a}', "");
Expect(1, 65023, '\P{^_	Is_Arabic_PF_a}', "");
Expect(0, 65024, '\p{_	Is_Arabic_PF_a}', "");
Expect(1, 65024, '\p{^_	Is_Arabic_PF_a}', "");
Expect(1, 65024, '\P{_	Is_Arabic_PF_a}', "");
Expect(0, 65024, '\P{^_	Is_Arabic_PF_a}', "");
Error('\p{	/a/IN_Arabic_PF_A}');
Error('\P{	/a/IN_Arabic_PF_A}');
Expect(1, 65023, '\p{inarabicpfa}', "");
Expect(0, 65023, '\p{^inarabicpfa}', "");
Expect(0, 65023, '\P{inarabicpfa}', "");
Expect(1, 65023, '\P{^inarabicpfa}', "");
Expect(0, 65024, '\p{inarabicpfa}', "");
Expect(1, 65024, '\p{^inarabicpfa}', "");
Expect(1, 65024, '\P{inarabicpfa}', "");
Expect(0, 65024, '\P{^inarabicpfa}', "");
Expect(1, 65023, '\p{	In_ARABIC_pf_A}', "");
Expect(0, 65023, '\p{^	In_ARABIC_pf_A}', "");
Expect(0, 65023, '\P{	In_ARABIC_pf_A}', "");
Expect(1, 65023, '\P{^	In_ARABIC_pf_A}', "");
Expect(0, 65024, '\p{	In_ARABIC_pf_A}', "");
Expect(1, 65024, '\p{^	In_ARABIC_pf_A}', "");
Expect(1, 65024, '\P{	In_ARABIC_pf_A}', "");
Expect(0, 65024, '\P{^	In_ARABIC_pf_A}', "");
Error('\p{-:=Arabic_presentation_Forms_B}');
Error('\P{-:=Arabic_presentation_Forms_B}');
Expect(1, 65279, '\p{arabicpresentationformsb}', "");
Expect(0, 65279, '\p{^arabicpresentationformsb}', "");
Expect(0, 65279, '\P{arabicpresentationformsb}', "");
Expect(1, 65279, '\P{^arabicpresentationformsb}', "");
Expect(0, 65280, '\p{arabicpresentationformsb}', "");
Expect(1, 65280, '\p{^arabicpresentationformsb}', "");
Expect(1, 65280, '\P{arabicpresentationformsb}', "");
Expect(0, 65280, '\P{^arabicpresentationformsb}', "");
Expect(1, 65279, '\p{--Arabic_PRESENTATION_Forms_B}', "");
Expect(0, 65279, '\p{^--Arabic_PRESENTATION_Forms_B}', "");
Expect(0, 65279, '\P{--Arabic_PRESENTATION_Forms_B}', "");
Expect(1, 65279, '\P{^--Arabic_PRESENTATION_Forms_B}', "");
Expect(0, 65280, '\p{--Arabic_PRESENTATION_Forms_B}', "");
Expect(1, 65280, '\p{^--Arabic_PRESENTATION_Forms_B}', "");
Expect(1, 65280, '\P{--Arabic_PRESENTATION_Forms_B}', "");
Expect(0, 65280, '\P{^--Arabic_PRESENTATION_Forms_B}', "");
Error('\p{ /a/Is_arabic_PRESENTATION_Forms_B}');
Error('\P{ /a/Is_arabic_PRESENTATION_Forms_B}');
Expect(1, 65279, '\p{isarabicpresentationformsb}', "");
Expect(0, 65279, '\p{^isarabicpresentationformsb}', "");
Expect(0, 65279, '\P{isarabicpresentationformsb}', "");
Expect(1, 65279, '\P{^isarabicpresentationformsb}', "");
Expect(0, 65280, '\p{isarabicpresentationformsb}', "");
Expect(1, 65280, '\p{^isarabicpresentationformsb}', "");
Expect(1, 65280, '\P{isarabicpresentationformsb}', "");
Expect(0, 65280, '\P{^isarabicpresentationformsb}', "");
Expect(1, 65279, '\p{-_IS_ARABIC_Presentation_Forms_B}', "");
Expect(0, 65279, '\p{^-_IS_ARABIC_Presentation_Forms_B}', "");
Expect(0, 65279, '\P{-_IS_ARABIC_Presentation_Forms_B}', "");
Expect(1, 65279, '\P{^-_IS_ARABIC_Presentation_Forms_B}', "");
Expect(0, 65280, '\p{-_IS_ARABIC_Presentation_Forms_B}', "");
Expect(1, 65280, '\p{^-_IS_ARABIC_Presentation_Forms_B}', "");
Expect(1, 65280, '\P{-_IS_ARABIC_Presentation_Forms_B}', "");
Expect(0, 65280, '\P{^-_IS_ARABIC_Presentation_Forms_B}', "");
Error('\p{ In_ARABIC_PRESENTATION_Forms_B/a/}');
Error('\P{ In_ARABIC_PRESENTATION_Forms_B/a/}');
Expect(1, 65279, '\p{inarabicpresentationformsb}', "");
Expect(0, 65279, '\p{^inarabicpresentationformsb}', "");
Expect(0, 65279, '\P{inarabicpresentationformsb}', "");
Expect(1, 65279, '\P{^inarabicpresentationformsb}', "");
Expect(0, 65280, '\p{inarabicpresentationformsb}', "");
Expect(1, 65280, '\p{^inarabicpresentationformsb}', "");
Expect(1, 65280, '\P{inarabicpresentationformsb}', "");
Expect(0, 65280, '\P{^inarabicpresentationformsb}', "");
Expect(1, 65279, '\p{  IN_Arabic_PRESENTATION_FORMS_B}', "");
Expect(0, 65279, '\p{^  IN_Arabic_PRESENTATION_FORMS_B}', "");
Expect(0, 65279, '\P{  IN_Arabic_PRESENTATION_FORMS_B}', "");
Expect(1, 65279, '\P{^  IN_Arabic_PRESENTATION_FORMS_B}', "");
Expect(0, 65280, '\p{  IN_Arabic_PRESENTATION_FORMS_B}', "");
Expect(1, 65280, '\p{^  IN_Arabic_PRESENTATION_FORMS_B}', "");
Expect(1, 65280, '\P{  IN_Arabic_PRESENTATION_FORMS_B}', "");
Expect(0, 65280, '\P{^  IN_Arabic_PRESENTATION_FORMS_B}', "");
Error('\p{-	Arabic_pf_B/a/}');
Error('\P{-	Arabic_pf_B/a/}');
Expect(1, 65279, '\p{arabicpfb}', "");
Expect(0, 65279, '\p{^arabicpfb}', "");
Expect(0, 65279, '\P{arabicpfb}', "");
Expect(1, 65279, '\P{^arabicpfb}', "");
Expect(0, 65280, '\p{arabicpfb}', "");
Expect(1, 65280, '\p{^arabicpfb}', "");
Expect(1, 65280, '\P{arabicpfb}', "");
Expect(0, 65280, '\P{^arabicpfb}', "");
Expect(1, 65279, '\p{__ARABIC_PF_B}', "");
Expect(0, 65279, '\p{^__ARABIC_PF_B}', "");
Expect(0, 65279, '\P{__ARABIC_PF_B}', "");
Expect(1, 65279, '\P{^__ARABIC_PF_B}', "");
Expect(0, 65280, '\p{__ARABIC_PF_B}', "");
Expect(1, 65280, '\p{^__ARABIC_PF_B}', "");
Expect(1, 65280, '\P{__ARABIC_PF_B}', "");
Expect(0, 65280, '\P{^__ARABIC_PF_B}', "");
Error('\p{ IS_Arabic_PF_B/a/}');
Error('\P{ IS_Arabic_PF_B/a/}');
Expect(1, 65279, '\p{isarabicpfb}', "");
Expect(0, 65279, '\p{^isarabicpfb}', "");
Expect(0, 65279, '\P{isarabicpfb}', "");
Expect(1, 65279, '\P{^isarabicpfb}', "");
Expect(0, 65280, '\p{isarabicpfb}', "");
Expect(1, 65280, '\p{^isarabicpfb}', "");
Expect(1, 65280, '\P{isarabicpfb}', "");
Expect(0, 65280, '\P{^isarabicpfb}', "");
Expect(1, 65279, '\p{	_Is_Arabic_PF_B}', "");
Expect(0, 65279, '\p{^	_Is_Arabic_PF_B}', "");
Expect(0, 65279, '\P{	_Is_Arabic_PF_B}', "");
Expect(1, 65279, '\P{^	_Is_Arabic_PF_B}', "");
Expect(0, 65280, '\p{	_Is_Arabic_PF_B}', "");
Expect(1, 65280, '\p{^	_Is_Arabic_PF_B}', "");
Expect(1, 65280, '\P{	_Is_Arabic_PF_B}', "");
Expect(0, 65280, '\P{^	_Is_Arabic_PF_B}', "");
Error('\p{ :=in_Arabic_PF_B}');
Error('\P{ :=in_Arabic_PF_B}');
Expect(1, 65279, '\p{inarabicpfb}', "");
Expect(0, 65279, '\p{^inarabicpfb}', "");
Expect(0, 65279, '\P{inarabicpfb}', "");
Expect(1, 65279, '\P{^inarabicpfb}', "");
Expect(0, 65280, '\p{inarabicpfb}', "");
Expect(1, 65280, '\p{^inarabicpfb}', "");
Expect(1, 65280, '\P{inarabicpfb}', "");
Expect(0, 65280, '\P{^inarabicpfb}', "");
Expect(1, 65279, '\p{_-In_arabic_PF_B}', "");
Expect(0, 65279, '\p{^_-In_arabic_PF_B}', "");
Expect(0, 65279, '\P{_-In_arabic_PF_B}', "");
Expect(1, 65279, '\P{^_-In_arabic_PF_B}', "");
Expect(0, 65280, '\p{_-In_arabic_PF_B}', "");
Expect(1, 65280, '\p{^_-In_arabic_PF_B}', "");
Expect(1, 65280, '\P{_-In_arabic_PF_B}', "");
Expect(0, 65280, '\P{^_-In_arabic_PF_B}', "");
Error('\p{	:=Arabic_Supplement}');
Error('\P{	:=Arabic_Supplement}');
Expect(1, 1919, '\p{arabicsupplement}', "");
Expect(0, 1919, '\p{^arabicsupplement}', "");
Expect(0, 1919, '\P{arabicsupplement}', "");
Expect(1, 1919, '\P{^arabicsupplement}', "");
Expect(0, 1920, '\p{arabicsupplement}', "");
Expect(1, 1920, '\p{^arabicsupplement}', "");
Expect(1, 1920, '\P{arabicsupplement}', "");
Expect(0, 1920, '\P{^arabicsupplement}', "");
Expect(1, 1919, '\p{_Arabic_SUPPLEMENT}', "");
Expect(0, 1919, '\p{^_Arabic_SUPPLEMENT}', "");
Expect(0, 1919, '\P{_Arabic_SUPPLEMENT}', "");
Expect(1, 1919, '\P{^_Arabic_SUPPLEMENT}', "");
Expect(0, 1920, '\p{_Arabic_SUPPLEMENT}', "");
Expect(1, 1920, '\p{^_Arabic_SUPPLEMENT}', "");
Expect(1, 1920, '\P{_Arabic_SUPPLEMENT}', "");
Expect(0, 1920, '\P{^_Arabic_SUPPLEMENT}', "");
Error('\p{	-Is_arabic_SUPPLEMENT:=}');
Error('\P{	-Is_arabic_SUPPLEMENT:=}');
Expect(1, 1919, '\p{isarabicsupplement}', "");
Expect(0, 1919, '\p{^isarabicsupplement}', "");
Expect(0, 1919, '\P{isarabicsupplement}', "");
Expect(1, 1919, '\P{^isarabicsupplement}', "");
Expect(0, 1920, '\p{isarabicsupplement}', "");
Expect(1, 1920, '\p{^isarabicsupplement}', "");
Expect(1, 1920, '\P{isarabicsupplement}', "");
Expect(0, 1920, '\P{^isarabicsupplement}', "");
Expect(1, 1919, '\p{ _Is_Arabic_supplement}', "");
Expect(0, 1919, '\p{^ _Is_Arabic_supplement}', "");
Expect(0, 1919, '\P{ _Is_Arabic_supplement}', "");
Expect(1, 1919, '\P{^ _Is_Arabic_supplement}', "");
Expect(0, 1920, '\p{ _Is_Arabic_supplement}', "");
Expect(1, 1920, '\p{^ _Is_Arabic_supplement}', "");
Expect(1, 1920, '\P{ _Is_Arabic_supplement}', "");
Expect(0, 1920, '\P{^ _Is_Arabic_supplement}', "");
Error('\p{:=_IN_arabic_SUPPLEMENT}');
Error('\P{:=_IN_arabic_SUPPLEMENT}');
Expect(1, 1919, '\p{inarabicsupplement}', "");
Expect(0, 1919, '\p{^inarabicsupplement}', "");
Expect(0, 1919, '\P{inarabicsupplement}', "");
Expect(1, 1919, '\P{^inarabicsupplement}', "");
Expect(0, 1920, '\p{inarabicsupplement}', "");
Expect(1, 1920, '\p{^inarabicsupplement}', "");
Expect(1, 1920, '\P{inarabicsupplement}', "");
Expect(0, 1920, '\P{^inarabicsupplement}', "");
Expect(1, 1919, '\p{-_In_Arabic_Supplement}', "");
Expect(0, 1919, '\p{^-_In_Arabic_Supplement}', "");
Expect(0, 1919, '\P{-_In_Arabic_Supplement}', "");
Expect(1, 1919, '\P{^-_In_Arabic_Supplement}', "");
Expect(0, 1920, '\p{-_In_Arabic_Supplement}', "");
Expect(1, 1920, '\p{^-_In_Arabic_Supplement}', "");
Expect(1, 1920, '\P{-_In_Arabic_Supplement}', "");
Expect(0, 1920, '\P{^-_In_Arabic_Supplement}', "");
Error('\p{ -arabic_SUP/a/}');
Error('\P{ -arabic_SUP/a/}');
Expect(1, 1919, '\p{arabicsup}', "");
Expect(0, 1919, '\p{^arabicsup}', "");
Expect(0, 1919, '\P{arabicsup}', "");
Expect(1, 1919, '\P{^arabicsup}', "");
Expect(0, 1920, '\p{arabicsup}', "");
Expect(1, 1920, '\p{^arabicsup}', "");
Expect(1, 1920, '\P{arabicsup}', "");
Expect(0, 1920, '\P{^arabicsup}', "");
Expect(1, 1919, '\p{-ARABIC_Sup}', "");
Expect(0, 1919, '\p{^-ARABIC_Sup}', "");
Expect(0, 1919, '\P{-ARABIC_Sup}', "");
Expect(1, 1919, '\P{^-ARABIC_Sup}', "");
Expect(0, 1920, '\p{-ARABIC_Sup}', "");
Expect(1, 1920, '\p{^-ARABIC_Sup}', "");
Expect(1, 1920, '\P{-ARABIC_Sup}', "");
Expect(0, 1920, '\P{^-ARABIC_Sup}', "");
Error('\p{:=-	is_arabic_Sup}');
Error('\P{:=-	is_arabic_Sup}');
Expect(1, 1919, '\p{isarabicsup}', "");
Expect(0, 1919, '\p{^isarabicsup}', "");
Expect(0, 1919, '\P{isarabicsup}', "");
Expect(1, 1919, '\P{^isarabicsup}', "");
Expect(0, 1920, '\p{isarabicsup}', "");
Expect(1, 1920, '\p{^isarabicsup}', "");
Expect(1, 1920, '\P{isarabicsup}', "");
Expect(0, 1920, '\P{^isarabicsup}', "");
Expect(1, 1919, '\p{ -is_arabic_Sup}', "");
Expect(0, 1919, '\p{^ -is_arabic_Sup}', "");
Expect(0, 1919, '\P{ -is_arabic_Sup}', "");
Expect(1, 1919, '\P{^ -is_arabic_Sup}', "");
Expect(0, 1920, '\p{ -is_arabic_Sup}', "");
Expect(1, 1920, '\p{^ -is_arabic_Sup}', "");
Expect(1, 1920, '\P{ -is_arabic_Sup}', "");
Expect(0, 1920, '\P{^ -is_arabic_Sup}', "");
Error('\p{_/a/IN_ARABIC_sup}');
Error('\P{_/a/IN_ARABIC_sup}');
Expect(1, 1919, '\p{inarabicsup}', "");
Expect(0, 1919, '\p{^inarabicsup}', "");
Expect(0, 1919, '\P{inarabicsup}', "");
Expect(1, 1919, '\P{^inarabicsup}', "");
Expect(0, 1920, '\p{inarabicsup}', "");
Expect(1, 1920, '\p{^inarabicsup}', "");
Expect(1, 1920, '\P{inarabicsup}', "");
Expect(0, 1920, '\P{^inarabicsup}', "");
Expect(1, 1919, '\p{__IN_Arabic_SUP}', "");
Expect(0, 1919, '\p{^__IN_Arabic_SUP}', "");
Expect(0, 1919, '\P{__IN_Arabic_SUP}', "");
Expect(1, 1919, '\P{^__IN_Arabic_SUP}', "");
Expect(0, 1920, '\p{__IN_Arabic_SUP}', "");
Expect(1, 1920, '\p{^__IN_Arabic_SUP}', "");
Expect(1, 1920, '\P{__IN_Arabic_SUP}', "");
Expect(0, 1920, '\P{^__IN_Arabic_SUP}', "");
Error('\p{		armenian:=}');
Error('\P{		armenian:=}');
Expect(1, 64279, '\p{armenian}', "");
Expect(0, 64279, '\p{^armenian}', "");
Expect(0, 64279, '\P{armenian}', "");
Expect(1, 64279, '\P{^armenian}', "");
Expect(0, 64280, '\p{armenian}', "");
Expect(1, 64280, '\p{^armenian}', "");
Expect(1, 64280, '\P{armenian}', "");
Expect(0, 64280, '\P{^armenian}', "");
Expect(1, 64279, '\p{_	Armenian}', "");
Expect(0, 64279, '\p{^_	Armenian}', "");
Expect(0, 64279, '\P{_	Armenian}', "");
Expect(1, 64279, '\P{^_	Armenian}', "");
Expect(0, 64280, '\p{_	Armenian}', "");
Expect(1, 64280, '\p{^_	Armenian}', "");
Expect(1, 64280, '\P{_	Armenian}', "");
Expect(0, 64280, '\P{^_	Armenian}', "");
Error('\p{ :=is_Armenian}');
Error('\P{ :=is_Armenian}');
Expect(1, 64279, '\p{isarmenian}', "");
Expect(0, 64279, '\p{^isarmenian}', "");
Expect(0, 64279, '\P{isarmenian}', "");
Expect(1, 64279, '\P{^isarmenian}', "");
Expect(0, 64280, '\p{isarmenian}', "");
Expect(1, 64280, '\p{^isarmenian}', "");
Expect(1, 64280, '\P{isarmenian}', "");
Expect(0, 64280, '\P{^isarmenian}', "");
Expect(1, 64279, '\p{Is_ARMENIAN}', "");
Expect(0, 64279, '\p{^Is_ARMENIAN}', "");
Expect(0, 64279, '\P{Is_ARMENIAN}', "");
Expect(1, 64279, '\P{^Is_ARMENIAN}', "");
Expect(0, 64280, '\p{Is_ARMENIAN}', "");
Expect(1, 64280, '\p{^Is_ARMENIAN}', "");
Expect(1, 64280, '\P{Is_ARMENIAN}', "");
Expect(0, 64280, '\P{^Is_ARMENIAN}', "");
Error('\p{/a/_-ARMN}');
Error('\P{/a/_-ARMN}');
Expect(1, 64279, '\p{armn}', "");
Expect(0, 64279, '\p{^armn}', "");
Expect(0, 64279, '\P{armn}', "");
Expect(1, 64279, '\P{^armn}', "");
Expect(0, 64280, '\p{armn}', "");
Expect(1, 64280, '\p{^armn}', "");
Expect(1, 64280, '\P{armn}', "");
Expect(0, 64280, '\P{^armn}', "");
Expect(1, 64279, '\p{_-Armn}', "");
Expect(0, 64279, '\p{^_-Armn}', "");
Expect(0, 64279, '\P{_-Armn}', "");
Expect(1, 64279, '\P{^_-Armn}', "");
Expect(0, 64280, '\p{_-Armn}', "");
Expect(1, 64280, '\p{^_-Armn}', "");
Expect(1, 64280, '\P{_-Armn}', "");
Expect(0, 64280, '\P{^_-Armn}', "");
Error('\p{/a/-IS_Armn}');
Error('\P{/a/-IS_Armn}');
Expect(1, 64279, '\p{isarmn}', "");
Expect(0, 64279, '\p{^isarmn}', "");
Expect(0, 64279, '\P{isarmn}', "");
Expect(1, 64279, '\P{^isarmn}', "");
Expect(0, 64280, '\p{isarmn}', "");
Expect(1, 64280, '\p{^isarmn}', "");
Expect(1, 64280, '\P{isarmn}', "");
Expect(0, 64280, '\P{^isarmn}', "");
Expect(1, 64279, '\p{  Is_Armn}', "");
Expect(0, 64279, '\p{^  Is_Armn}', "");
Expect(0, 64279, '\P{  Is_Armn}', "");
Expect(1, 64279, '\P{^  Is_Armn}', "");
Expect(0, 64280, '\p{  Is_Armn}', "");
Expect(1, 64280, '\p{^  Is_Armn}', "");
Expect(1, 64280, '\P{  Is_Armn}', "");
Expect(0, 64280, '\P{^  Is_Armn}', "");
Error('\p{		arrows/a/}');
Error('\P{		arrows/a/}');
Expect(1, 8703, '\p{arrows}', "");
Expect(0, 8703, '\p{^arrows}', "");
Expect(0, 8703, '\P{arrows}', "");
Expect(1, 8703, '\P{^arrows}', "");
Expect(0, 8704, '\p{arrows}', "");
Expect(1, 8704, '\p{^arrows}', "");
Expect(1, 8704, '\P{arrows}', "");
Expect(0, 8704, '\P{^arrows}', "");
Expect(1, 8703, '\p{_Arrows}', "");
Expect(0, 8703, '\p{^_Arrows}', "");
Expect(0, 8703, '\P{_Arrows}', "");
Expect(1, 8703, '\P{^_Arrows}', "");
Expect(0, 8704, '\p{_Arrows}', "");
Expect(1, 8704, '\p{^_Arrows}', "");
Expect(1, 8704, '\P{_Arrows}', "");
Expect(0, 8704, '\P{^_Arrows}', "");
Error('\p{:=IS_Arrows}');
Error('\P{:=IS_Arrows}');
Expect(1, 8703, '\p{isarrows}', "");
Expect(0, 8703, '\p{^isarrows}', "");
Expect(0, 8703, '\P{isarrows}', "");
Expect(1, 8703, '\P{^isarrows}', "");
Expect(0, 8704, '\p{isarrows}', "");
Expect(1, 8704, '\p{^isarrows}', "");
Expect(1, 8704, '\P{isarrows}', "");
Expect(0, 8704, '\P{^isarrows}', "");
Expect(1, 8703, '\p{is_ARROWS}', "");
Expect(0, 8703, '\p{^is_ARROWS}', "");
Expect(0, 8703, '\P{is_ARROWS}', "");
Expect(1, 8703, '\P{^is_ARROWS}', "");
Expect(0, 8704, '\p{is_ARROWS}', "");
Expect(1, 8704, '\p{^is_ARROWS}', "");
Expect(1, 8704, '\P{is_ARROWS}', "");
Expect(0, 8704, '\P{^is_ARROWS}', "");
Error('\p{:=-IN_Arrows}');
Error('\P{:=-IN_Arrows}');
Expect(1, 8703, '\p{inarrows}', "");
Expect(0, 8703, '\p{^inarrows}', "");
Expect(0, 8703, '\P{inarrows}', "");
Expect(1, 8703, '\P{^inarrows}', "");
Expect(0, 8704, '\p{inarrows}', "");
Expect(1, 8704, '\p{^inarrows}', "");
Expect(1, 8704, '\P{inarrows}', "");
Expect(0, 8704, '\P{^inarrows}', "");
Expect(1, 8703, '\p{_In_ARROWS}', "");
Expect(0, 8703, '\p{^_In_ARROWS}', "");
Expect(0, 8703, '\P{_In_ARROWS}', "");
Expect(1, 8703, '\P{^_In_ARROWS}', "");
Expect(0, 8704, '\p{_In_ARROWS}', "");
Expect(1, 8704, '\p{^_In_ARROWS}', "");
Expect(1, 8704, '\P{_In_ARROWS}', "");
Expect(0, 8704, '\P{^_In_ARROWS}', "");
Error('\p{:= _Assigned}');
Error('\P{:= _Assigned}');
Expect(1, 1114109, '\p{assigned}', "");
Expect(0, 1114109, '\p{^assigned}', "");
Expect(0, 1114109, '\P{assigned}', "");
Expect(1, 1114109, '\P{^assigned}', "");
Expect(0, 918000, '\p{assigned}', "");
Expect(1, 918000, '\p{^assigned}', "");
Expect(1, 918000, '\P{assigned}', "");
Expect(0, 918000, '\P{^assigned}', "");
Expect(1, 1114109, '\p{-ASSIGNED}', "");
Expect(0, 1114109, '\p{^-ASSIGNED}', "");
Expect(0, 1114109, '\P{-ASSIGNED}', "");
Expect(1, 1114109, '\P{^-ASSIGNED}', "");
Expect(0, 918000, '\p{-ASSIGNED}', "");
Expect(1, 918000, '\p{^-ASSIGNED}', "");
Expect(1, 918000, '\P{-ASSIGNED}', "");
Expect(0, 918000, '\P{^-ASSIGNED}', "");
Error('\p{/a/-	Is_Assigned}');
Error('\P{/a/-	Is_Assigned}');
Expect(1, 1114109, '\p{isassigned}', "");
Expect(0, 1114109, '\p{^isassigned}', "");
Expect(0, 1114109, '\P{isassigned}', "");
Expect(1, 1114109, '\P{^isassigned}', "");
Expect(0, 918000, '\p{isassigned}', "");
Expect(1, 918000, '\p{^isassigned}', "");
Expect(1, 918000, '\P{isassigned}', "");
Expect(0, 918000, '\P{^isassigned}', "");
Expect(1, 1114109, '\p{-is_ASSIGNED}', "");
Expect(0, 1114109, '\p{^-is_ASSIGNED}', "");
Expect(0, 1114109, '\P{-is_ASSIGNED}', "");
Expect(1, 1114109, '\P{^-is_ASSIGNED}', "");
Expect(0, 918000, '\p{-is_ASSIGNED}', "");
Expect(1, 918000, '\p{^-is_ASSIGNED}', "");
Expect(1, 918000, '\P{-is_ASSIGNED}', "");
Expect(0, 918000, '\P{^-is_ASSIGNED}', "");
Error('\p{:=-_Avestan}');
Error('\P{:=-_Avestan}');
Expect(1, 68415, '\p{avestan}', "");
Expect(0, 68415, '\p{^avestan}', "");
Expect(0, 68415, '\P{avestan}', "");
Expect(1, 68415, '\P{^avestan}', "");
Expect(0, 68416, '\p{avestan}', "");
Expect(1, 68416, '\p{^avestan}', "");
Expect(1, 68416, '\P{avestan}', "");
Expect(0, 68416, '\P{^avestan}', "");
Expect(1, 68415, '\p{_	AVESTAN}', "");
Expect(0, 68415, '\p{^_	AVESTAN}', "");
Expect(0, 68415, '\P{_	AVESTAN}', "");
Expect(1, 68415, '\P{^_	AVESTAN}', "");
Expect(0, 68416, '\p{_	AVESTAN}', "");
Expect(1, 68416, '\p{^_	AVESTAN}', "");
Expect(1, 68416, '\P{_	AVESTAN}', "");
Expect(0, 68416, '\P{^_	AVESTAN}', "");
Error('\p{_Is_Avestan:=}');
Error('\P{_Is_Avestan:=}');
Expect(1, 68415, '\p{isavestan}', "");
Expect(0, 68415, '\p{^isavestan}', "");
Expect(0, 68415, '\P{isavestan}', "");
Expect(1, 68415, '\P{^isavestan}', "");
Expect(0, 68416, '\p{isavestan}', "");
Expect(1, 68416, '\p{^isavestan}', "");
Expect(1, 68416, '\P{isavestan}', "");
Expect(0, 68416, '\P{^isavestan}', "");
Expect(1, 68415, '\p{  IS_avestan}', "");
Expect(0, 68415, '\p{^  IS_avestan}', "");
Expect(0, 68415, '\P{  IS_avestan}', "");
Expect(1, 68415, '\P{^  IS_avestan}', "");
Expect(0, 68416, '\p{  IS_avestan}', "");
Expect(1, 68416, '\p{^  IS_avestan}', "");
Expect(1, 68416, '\P{  IS_avestan}', "");
Expect(0, 68416, '\P{^  IS_avestan}', "");
Error('\p{:=_	Avst}');
Error('\P{:=_	Avst}');
Expect(1, 68415, '\p{avst}', "");
Expect(0, 68415, '\p{^avst}', "");
Expect(0, 68415, '\P{avst}', "");
Expect(1, 68415, '\P{^avst}', "");
Expect(0, 68416, '\p{avst}', "");
Expect(1, 68416, '\p{^avst}', "");
Expect(1, 68416, '\P{avst}', "");
Expect(0, 68416, '\P{^avst}', "");
Expect(1, 68415, '\p{		AVST}', "");
Expect(0, 68415, '\p{^		AVST}', "");
Expect(0, 68415, '\P{		AVST}', "");
Expect(1, 68415, '\P{^		AVST}', "");
Expect(0, 68416, '\p{		AVST}', "");
Expect(1, 68416, '\p{^		AVST}', "");
Expect(1, 68416, '\P{		AVST}', "");
Expect(0, 68416, '\P{^		AVST}', "");
Error('\p{/a/	-Is_Avst}');
Error('\P{/a/	-Is_Avst}');
Expect(1, 68415, '\p{isavst}', "");
Expect(0, 68415, '\p{^isavst}', "");
Expect(0, 68415, '\P{isavst}', "");
Expect(1, 68415, '\P{^isavst}', "");
Expect(0, 68416, '\p{isavst}', "");
Expect(1, 68416, '\p{^isavst}', "");
Expect(1, 68416, '\P{isavst}', "");
Expect(0, 68416, '\P{^isavst}', "");
Expect(1, 68415, '\p{	_Is_avst}', "");
Expect(0, 68415, '\p{^	_Is_avst}', "");
Expect(0, 68415, '\P{	_Is_avst}', "");
Expect(1, 68415, '\P{^	_Is_avst}', "");
Expect(0, 68416, '\p{	_Is_avst}', "");
Expect(1, 68416, '\p{^	_Is_avst}', "");
Expect(1, 68416, '\P{	_Is_avst}', "");
Expect(0, 68416, '\P{^	_Is_avst}', "");
Error('\p{- Balinese:=}');
Error('\P{- Balinese:=}');
Expect(1, 7036, '\p{balinese}', "");
Expect(0, 7036, '\p{^balinese}', "");
Expect(0, 7036, '\P{balinese}', "");
Expect(1, 7036, '\P{^balinese}', "");
Expect(0, 7037, '\p{balinese}', "");
Expect(1, 7037, '\p{^balinese}', "");
Expect(1, 7037, '\P{balinese}', "");
Expect(0, 7037, '\P{^balinese}', "");
Expect(1, 7036, '\p{ balinese}', "");
Expect(0, 7036, '\p{^ balinese}', "");
Expect(0, 7036, '\P{ balinese}', "");
Expect(1, 7036, '\P{^ balinese}', "");
Expect(0, 7037, '\p{ balinese}', "");
Expect(1, 7037, '\p{^ balinese}', "");
Expect(1, 7037, '\P{ balinese}', "");
Expect(0, 7037, '\P{^ balinese}', "");
Error('\p{ /a/Is_Balinese}');
Error('\P{ /a/Is_Balinese}');
Expect(1, 7036, '\p{isbalinese}', "");
Expect(0, 7036, '\p{^isbalinese}', "");
Expect(0, 7036, '\P{isbalinese}', "");
Expect(1, 7036, '\P{^isbalinese}', "");
Expect(0, 7037, '\p{isbalinese}', "");
Expect(1, 7037, '\p{^isbalinese}', "");
Expect(1, 7037, '\P{isbalinese}', "");
Expect(0, 7037, '\P{^isbalinese}', "");
Expect(1, 7036, '\p{_ IS_Balinese}', "");
Expect(0, 7036, '\p{^_ IS_Balinese}', "");
Expect(0, 7036, '\P{_ IS_Balinese}', "");
Expect(1, 7036, '\P{^_ IS_Balinese}', "");
Expect(0, 7037, '\p{_ IS_Balinese}', "");
Expect(1, 7037, '\p{^_ IS_Balinese}', "");
Expect(1, 7037, '\P{_ IS_Balinese}', "");
Expect(0, 7037, '\P{^_ IS_Balinese}', "");
Error('\p{-BALI:=}');
Error('\P{-BALI:=}');
Expect(1, 7036, '\p{bali}', "");
Expect(0, 7036, '\p{^bali}', "");
Expect(0, 7036, '\P{bali}', "");
Expect(1, 7036, '\P{^bali}', "");
Expect(0, 7037, '\p{bali}', "");
Expect(1, 7037, '\p{^bali}', "");
Expect(1, 7037, '\P{bali}', "");
Expect(0, 7037, '\P{^bali}', "");
Expect(1, 7036, '\p{-	Bali}', "");
Expect(0, 7036, '\p{^-	Bali}', "");
Expect(0, 7036, '\P{-	Bali}', "");
Expect(1, 7036, '\P{^-	Bali}', "");
Expect(0, 7037, '\p{-	Bali}', "");
Expect(1, 7037, '\p{^-	Bali}', "");
Expect(1, 7037, '\P{-	Bali}', "");
Expect(0, 7037, '\P{^-	Bali}', "");
Error('\p{	:=Is_bali}');
Error('\P{	:=Is_bali}');
Expect(1, 7036, '\p{isbali}', "");
Expect(0, 7036, '\p{^isbali}', "");
Expect(0, 7036, '\P{isbali}', "");
Expect(1, 7036, '\P{^isbali}', "");
Expect(0, 7037, '\p{isbali}', "");
Expect(1, 7037, '\p{^isbali}', "");
Expect(1, 7037, '\P{isbali}', "");
Expect(0, 7037, '\P{^isbali}', "");
Expect(1, 7036, '\p{-IS_Bali}', "");
Expect(0, 7036, '\p{^-IS_Bali}', "");
Expect(0, 7036, '\P{-IS_Bali}', "");
Expect(1, 7036, '\P{^-IS_Bali}', "");
Expect(0, 7037, '\p{-IS_Bali}', "");
Expect(1, 7037, '\p{^-IS_Bali}', "");
Expect(1, 7037, '\P{-IS_Bali}', "");
Expect(0, 7037, '\P{^-IS_Bali}', "");
Error('\p{_	bamum/a/}');
Error('\P{_	bamum/a/}');
Expect(1, 92728, '\p{bamum}', "");
Expect(0, 92728, '\p{^bamum}', "");
Expect(0, 92728, '\P{bamum}', "");
Expect(1, 92728, '\P{^bamum}', "");
Expect(0, 92729, '\p{bamum}', "");
Expect(1, 92729, '\p{^bamum}', "");
Expect(1, 92729, '\P{bamum}', "");
Expect(0, 92729, '\P{^bamum}', "");
Expect(1, 92728, '\p{_ BAMUM}', "");
Expect(0, 92728, '\p{^_ BAMUM}', "");
Expect(0, 92728, '\P{_ BAMUM}', "");
Expect(1, 92728, '\P{^_ BAMUM}', "");
Expect(0, 92729, '\p{_ BAMUM}', "");
Expect(1, 92729, '\p{^_ BAMUM}', "");
Expect(1, 92729, '\P{_ BAMUM}', "");
Expect(0, 92729, '\P{^_ BAMUM}', "");
Error('\p{ /a/Is_Bamum}');
Error('\P{ /a/Is_Bamum}');
Expect(1, 92728, '\p{isbamum}', "");
Expect(0, 92728, '\p{^isbamum}', "");
Expect(0, 92728, '\P{isbamum}', "");
Expect(1, 92728, '\P{^isbamum}', "");
Expect(0, 92729, '\p{isbamum}', "");
Expect(1, 92729, '\p{^isbamum}', "");
Expect(1, 92729, '\P{isbamum}', "");
Expect(0, 92729, '\P{^isbamum}', "");
Expect(1, 92728, '\p{	Is_BAMUM}', "");
Expect(0, 92728, '\p{^	Is_BAMUM}', "");
Expect(0, 92728, '\P{	Is_BAMUM}', "");
Expect(1, 92728, '\P{^	Is_BAMUM}', "");
Expect(0, 92729, '\p{	Is_BAMUM}', "");
Expect(1, 92729, '\p{^	Is_BAMUM}', "");
Expect(1, 92729, '\P{	Is_BAMUM}', "");
Expect(0, 92729, '\P{^	Is_BAMUM}', "");
Error('\p{/a/ bamu}');
Error('\P{/a/ bamu}');
Expect(1, 92728, '\p{bamu}', "");
Expect(0, 92728, '\p{^bamu}', "");
Expect(0, 92728, '\P{bamu}', "");
Expect(1, 92728, '\P{^bamu}', "");
Expect(0, 92729, '\p{bamu}', "");
Expect(1, 92729, '\p{^bamu}', "");
Expect(1, 92729, '\P{bamu}', "");
Expect(0, 92729, '\P{^bamu}', "");
Expect(1, 92728, '\p{	_Bamu}', "");
Expect(0, 92728, '\p{^	_Bamu}', "");
Expect(0, 92728, '\P{	_Bamu}', "");
Expect(1, 92728, '\P{^	_Bamu}', "");
Expect(0, 92729, '\p{	_Bamu}', "");
Expect(1, 92729, '\p{^	_Bamu}', "");
Expect(1, 92729, '\P{	_Bamu}', "");
Expect(0, 92729, '\P{^	_Bamu}', "");
Error('\p{:=Is_bamu}');
Error('\P{:=Is_bamu}');
Expect(1, 92728, '\p{isbamu}', "");
Expect(0, 92728, '\p{^isbamu}', "");
Expect(0, 92728, '\P{isbamu}', "");
Expect(1, 92728, '\P{^isbamu}', "");
Expect(0, 92729, '\p{isbamu}', "");
Expect(1, 92729, '\p{^isbamu}', "");
Expect(1, 92729, '\P{isbamu}', "");
Expect(0, 92729, '\P{^isbamu}', "");
Expect(1, 92728, '\p{_	is_Bamu}', "");
Expect(0, 92728, '\p{^_	is_Bamu}', "");
Expect(0, 92728, '\P{_	is_Bamu}', "");
Expect(1, 92728, '\P{^_	is_Bamu}', "");
Expect(0, 92729, '\p{_	is_Bamu}', "");
Expect(1, 92729, '\p{^_	is_Bamu}', "");
Expect(1, 92729, '\P{_	is_Bamu}', "");
Expect(0, 92729, '\P{^_	is_Bamu}', "");
Error('\p{	Bamum_SUPPLEMENT:=}');
Error('\P{	Bamum_SUPPLEMENT:=}');
Expect(1, 92735, '\p{bamumsupplement}', "");
Expect(0, 92735, '\p{^bamumsupplement}', "");
Expect(0, 92735, '\P{bamumsupplement}', "");
Expect(1, 92735, '\P{^bamumsupplement}', "");
Expect(0, 92736, '\p{bamumsupplement}', "");
Expect(1, 92736, '\p{^bamumsupplement}', "");
Expect(1, 92736, '\P{bamumsupplement}', "");
Expect(0, 92736, '\P{^bamumsupplement}', "");
Expect(1, 92735, '\p{-bamum_Supplement}', "");
Expect(0, 92735, '\p{^-bamum_Supplement}', "");
Expect(0, 92735, '\P{-bamum_Supplement}', "");
Expect(1, 92735, '\P{^-bamum_Supplement}', "");
Expect(0, 92736, '\p{-bamum_Supplement}', "");
Expect(1, 92736, '\p{^-bamum_Supplement}', "");
Expect(1, 92736, '\P{-bamum_Supplement}', "");
Expect(0, 92736, '\P{^-bamum_Supplement}', "");
Error('\p{  Is_bamum_Supplement:=}');
Error('\P{  Is_bamum_Supplement:=}');
Expect(1, 92735, '\p{isbamumsupplement}', "");
Expect(0, 92735, '\p{^isbamumsupplement}', "");
Expect(0, 92735, '\P{isbamumsupplement}', "");
Expect(1, 92735, '\P{^isbamumsupplement}', "");
Expect(0, 92736, '\p{isbamumsupplement}', "");
Expect(1, 92736, '\p{^isbamumsupplement}', "");
Expect(1, 92736, '\P{isbamumsupplement}', "");
Expect(0, 92736, '\P{^isbamumsupplement}', "");
Expect(1, 92735, '\p{_is_BAMUM_Supplement}', "");
Expect(0, 92735, '\p{^_is_BAMUM_Supplement}', "");
Expect(0, 92735, '\P{_is_BAMUM_Supplement}', "");
Expect(1, 92735, '\P{^_is_BAMUM_Supplement}', "");
Expect(0, 92736, '\p{_is_BAMUM_Supplement}', "");
Expect(1, 92736, '\p{^_is_BAMUM_Supplement}', "");
Expect(1, 92736, '\P{_is_BAMUM_Supplement}', "");
Expect(0, 92736, '\P{^_is_BAMUM_Supplement}', "");
Error('\p{ :=IN_Bamum_supplement}');
Error('\P{ :=IN_Bamum_supplement}');
Expect(1, 92735, '\p{inbamumsupplement}', "");
Expect(0, 92735, '\p{^inbamumsupplement}', "");
Expect(0, 92735, '\P{inbamumsupplement}', "");
Expect(1, 92735, '\P{^inbamumsupplement}', "");
Expect(0, 92736, '\p{inbamumsupplement}', "");
Expect(1, 92736, '\p{^inbamumsupplement}', "");
Expect(1, 92736, '\P{inbamumsupplement}', "");
Expect(0, 92736, '\P{^inbamumsupplement}', "");
Expect(1, 92735, '\p{__in_BAMUM_SUPPLEMENT}', "");
Expect(0, 92735, '\p{^__in_BAMUM_SUPPLEMENT}', "");
Expect(0, 92735, '\P{__in_BAMUM_SUPPLEMENT}', "");
Expect(1, 92735, '\P{^__in_BAMUM_SUPPLEMENT}', "");
Expect(0, 92736, '\p{__in_BAMUM_SUPPLEMENT}', "");
Expect(1, 92736, '\p{^__in_BAMUM_SUPPLEMENT}', "");
Expect(1, 92736, '\P{__in_BAMUM_SUPPLEMENT}', "");
Expect(0, 92736, '\P{^__in_BAMUM_SUPPLEMENT}', "");
Error('\p{	-BAMUM_Sup/a/}');
Error('\P{	-BAMUM_Sup/a/}');
Expect(1, 92735, '\p{bamumsup}', "");
Expect(0, 92735, '\p{^bamumsup}', "");
Expect(0, 92735, '\P{bamumsup}', "");
Expect(1, 92735, '\P{^bamumsup}', "");
Expect(0, 92736, '\p{bamumsup}', "");
Expect(1, 92736, '\p{^bamumsup}', "");
Expect(1, 92736, '\P{bamumsup}', "");
Expect(0, 92736, '\P{^bamumsup}', "");
Expect(1, 92735, '\p{	bamum_Sup}', "");
Expect(0, 92735, '\p{^	bamum_Sup}', "");
Expect(0, 92735, '\P{	bamum_Sup}', "");
Expect(1, 92735, '\P{^	bamum_Sup}', "");
Expect(0, 92736, '\p{	bamum_Sup}', "");
Expect(1, 92736, '\p{^	bamum_Sup}', "");
Expect(1, 92736, '\P{	bamum_Sup}', "");
Expect(0, 92736, '\P{^	bamum_Sup}', "");
Error('\p{/a/-Is_bamum_Sup}');
Error('\P{/a/-Is_bamum_Sup}');
Expect(1, 92735, '\p{isbamumsup}', "");
Expect(0, 92735, '\p{^isbamumsup}', "");
Expect(0, 92735, '\P{isbamumsup}', "");
Expect(1, 92735, '\P{^isbamumsup}', "");
Expect(0, 92736, '\p{isbamumsup}', "");
Expect(1, 92736, '\p{^isbamumsup}', "");
Expect(1, 92736, '\P{isbamumsup}', "");
Expect(0, 92736, '\P{^isbamumsup}', "");
Expect(1, 92735, '\p{-Is_BAMUM_sup}', "");
Expect(0, 92735, '\p{^-Is_BAMUM_sup}', "");
Expect(0, 92735, '\P{-Is_BAMUM_sup}', "");
Expect(1, 92735, '\P{^-Is_BAMUM_sup}', "");
Expect(0, 92736, '\p{-Is_BAMUM_sup}', "");
Expect(1, 92736, '\p{^-Is_BAMUM_sup}', "");
Expect(1, 92736, '\P{-Is_BAMUM_sup}', "");
Expect(0, 92736, '\P{^-Is_BAMUM_sup}', "");
Error('\p{ :=in_Bamum_SUP}');
Error('\P{ :=in_Bamum_SUP}');
Expect(1, 92735, '\p{inbamumsup}', "");
Expect(0, 92735, '\p{^inbamumsup}', "");
Expect(0, 92735, '\P{inbamumsup}', "");
Expect(1, 92735, '\P{^inbamumsup}', "");
Expect(0, 92736, '\p{inbamumsup}', "");
Expect(1, 92736, '\p{^inbamumsup}', "");
Expect(1, 92736, '\P{inbamumsup}', "");
Expect(0, 92736, '\P{^inbamumsup}', "");
Expect(1, 92735, '\p{ -In_Bamum_SUP}', "");
Expect(0, 92735, '\p{^ -In_Bamum_SUP}', "");
Expect(0, 92735, '\P{ -In_Bamum_SUP}', "");
Expect(1, 92735, '\P{^ -In_Bamum_SUP}', "");
Expect(0, 92736, '\p{ -In_Bamum_SUP}', "");
Expect(1, 92736, '\p{^ -In_Bamum_SUP}', "");
Expect(1, 92736, '\P{ -In_Bamum_SUP}', "");
Expect(0, 92736, '\P{^ -In_Bamum_SUP}', "");
Error('\p{	Batak/a/}');
Error('\P{	Batak/a/}');
Expect(1, 7167, '\p{batak}', "");
Expect(0, 7167, '\p{^batak}', "");
Expect(0, 7167, '\P{batak}', "");
Expect(1, 7167, '\P{^batak}', "");
Expect(0, 7168, '\p{batak}', "");
Expect(1, 7168, '\p{^batak}', "");
Expect(1, 7168, '\P{batak}', "");
Expect(0, 7168, '\P{^batak}', "");
Expect(1, 7167, '\p{-Batak}', "");
Expect(0, 7167, '\p{^-Batak}', "");
Expect(0, 7167, '\P{-Batak}', "");
Expect(1, 7167, '\P{^-Batak}', "");
Expect(0, 7168, '\p{-Batak}', "");
Expect(1, 7168, '\p{^-Batak}', "");
Expect(1, 7168, '\P{-Batak}', "");
Expect(0, 7168, '\P{^-Batak}', "");
Error('\p{ _Is_Batak:=}');
Error('\P{ _Is_Batak:=}');
Expect(1, 7167, '\p{isbatak}', "");
Expect(0, 7167, '\p{^isbatak}', "");
Expect(0, 7167, '\P{isbatak}', "");
Expect(1, 7167, '\P{^isbatak}', "");
Expect(0, 7168, '\p{isbatak}', "");
Expect(1, 7168, '\p{^isbatak}', "");
Expect(1, 7168, '\P{isbatak}', "");
Expect(0, 7168, '\P{^isbatak}', "");
Expect(1, 7167, '\p{ is_Batak}', "");
Expect(0, 7167, '\p{^ is_Batak}', "");
Expect(0, 7167, '\P{ is_Batak}', "");
Expect(1, 7167, '\P{^ is_Batak}', "");
Expect(0, 7168, '\p{ is_Batak}', "");
Expect(1, 7168, '\p{^ is_Batak}', "");
Expect(1, 7168, '\P{ is_Batak}', "");
Expect(0, 7168, '\P{^ is_Batak}', "");
Error('\p{	Batk/a/}');
Error('\P{	Batk/a/}');
Expect(1, 7167, '\p{batk}', "");
Expect(0, 7167, '\p{^batk}', "");
Expect(0, 7167, '\P{batk}', "");
Expect(1, 7167, '\P{^batk}', "");
Expect(0, 7168, '\p{batk}', "");
Expect(1, 7168, '\p{^batk}', "");
Expect(1, 7168, '\P{batk}', "");
Expect(0, 7168, '\P{^batk}', "");
Expect(1, 7167, '\p{-batk}', "");
Expect(0, 7167, '\p{^-batk}', "");
Expect(0, 7167, '\P{-batk}', "");
Expect(1, 7167, '\P{^-batk}', "");
Expect(0, 7168, '\p{-batk}', "");
Expect(1, 7168, '\p{^-batk}', "");
Expect(1, 7168, '\P{-batk}', "");
Expect(0, 7168, '\P{^-batk}', "");
Error('\p{-Is_Batk:=}');
Error('\P{-Is_Batk:=}');
Expect(1, 7167, '\p{isbatk}', "");
Expect(0, 7167, '\p{^isbatk}', "");
Expect(0, 7167, '\P{isbatk}', "");
Expect(1, 7167, '\P{^isbatk}', "");
Expect(0, 7168, '\p{isbatk}', "");
Expect(1, 7168, '\p{^isbatk}', "");
Expect(1, 7168, '\P{isbatk}', "");
Expect(0, 7168, '\P{^isbatk}', "");
Expect(1, 7167, '\p{-Is_BATK}', "");
Expect(0, 7167, '\p{^-Is_BATK}', "");
Expect(0, 7167, '\P{-Is_BATK}', "");
Expect(1, 7167, '\P{^-Is_BATK}', "");
Expect(0, 7168, '\p{-Is_BATK}', "");
Expect(1, 7168, '\p{^-Is_BATK}', "");
Expect(1, 7168, '\P{-Is_BATK}', "");
Expect(0, 7168, '\P{^-Is_BATK}', "");
Error('\p{/a/__BENGALI}');
Error('\P{/a/__BENGALI}');
Expect(1, 2555, '\p{bengali}', "");
Expect(0, 2555, '\p{^bengali}', "");
Expect(0, 2555, '\P{bengali}', "");
Expect(1, 2555, '\P{^bengali}', "");
Expect(0, 2556, '\p{bengali}', "");
Expect(1, 2556, '\p{^bengali}', "");
Expect(1, 2556, '\P{bengali}', "");
Expect(0, 2556, '\P{^bengali}', "");
Expect(1, 2555, '\p{-Bengali}', "");
Expect(0, 2555, '\p{^-Bengali}', "");
Expect(0, 2555, '\P{-Bengali}', "");
Expect(1, 2555, '\P{^-Bengali}', "");
Expect(0, 2556, '\p{-Bengali}', "");
Expect(1, 2556, '\p{^-Bengali}', "");
Expect(1, 2556, '\P{-Bengali}', "");
Expect(0, 2556, '\P{^-Bengali}', "");
Error('\p{ -IS_bengali/a/}');
Error('\P{ -IS_bengali/a/}');
Expect(1, 2555, '\p{isbengali}', "");
Expect(0, 2555, '\p{^isbengali}', "");
Expect(0, 2555, '\P{isbengali}', "");
Expect(1, 2555, '\P{^isbengali}', "");
Expect(0, 2556, '\p{isbengali}', "");
Expect(1, 2556, '\p{^isbengali}', "");
Expect(1, 2556, '\P{isbengali}', "");
Expect(0, 2556, '\P{^isbengali}', "");
Expect(1, 2555, '\p{-IS_BENGALI}', "");
Expect(0, 2555, '\p{^-IS_BENGALI}', "");
Expect(0, 2555, '\P{-IS_BENGALI}', "");
Expect(1, 2555, '\P{^-IS_BENGALI}', "");
Expect(0, 2556, '\p{-IS_BENGALI}', "");
Expect(1, 2556, '\p{^-IS_BENGALI}', "");
Expect(1, 2556, '\P{-IS_BENGALI}', "");
Expect(0, 2556, '\P{^-IS_BENGALI}', "");
Error('\p{:=-	beng}');
Error('\P{:=-	beng}');
Expect(1, 2555, '\p{beng}', "");
Expect(0, 2555, '\p{^beng}', "");
Expect(0, 2555, '\P{beng}', "");
Expect(1, 2555, '\P{^beng}', "");
Expect(0, 2556, '\p{beng}', "");
Expect(1, 2556, '\p{^beng}', "");
Expect(1, 2556, '\P{beng}', "");
Expect(0, 2556, '\P{^beng}', "");
Expect(1, 2555, '\p{ Beng}', "");
Expect(0, 2555, '\p{^ Beng}', "");
Expect(0, 2555, '\P{ Beng}', "");
Expect(1, 2555, '\P{^ Beng}', "");
Expect(0, 2556, '\p{ Beng}', "");
Expect(1, 2556, '\p{^ Beng}', "");
Expect(1, 2556, '\P{ Beng}', "");
Expect(0, 2556, '\P{^ Beng}', "");
Error('\p{/a/	-IS_beng}');
Error('\P{/a/	-IS_beng}');
Expect(1, 2555, '\p{isbeng}', "");
Expect(0, 2555, '\p{^isbeng}', "");
Expect(0, 2555, '\P{isbeng}', "");
Expect(1, 2555, '\P{^isbeng}', "");
Expect(0, 2556, '\p{isbeng}', "");
Expect(1, 2556, '\p{^isbeng}', "");
Expect(1, 2556, '\P{isbeng}', "");
Expect(0, 2556, '\P{^isbeng}', "");
Expect(1, 2555, '\p{--Is_Beng}', "");
Expect(0, 2555, '\p{^--Is_Beng}', "");
Expect(0, 2555, '\P{--Is_Beng}', "");
Expect(1, 2555, '\P{^--Is_Beng}', "");
Expect(0, 2556, '\p{--Is_Beng}', "");
Expect(1, 2556, '\p{^--Is_Beng}', "");
Expect(1, 2556, '\P{--Is_Beng}', "");
Expect(0, 2556, '\P{^--Is_Beng}', "");
Error('\p{/a/bidi_CONTROL}');
Error('\P{/a/bidi_CONTROL}');
Expect(1, 8297, '\p{bidicontrol}', "");
Expect(0, 8297, '\p{^bidicontrol}', "");
Expect(0, 8297, '\P{bidicontrol}', "");
Expect(1, 8297, '\P{^bidicontrol}', "");
Expect(0, 8298, '\p{bidicontrol}', "");
Expect(1, 8298, '\p{^bidicontrol}', "");
Expect(1, 8298, '\P{bidicontrol}', "");
Expect(0, 8298, '\P{^bidicontrol}', "");
Expect(1, 8297, '\p{_Bidi_CONTROL}', "");
Expect(0, 8297, '\p{^_Bidi_CONTROL}', "");
Expect(0, 8297, '\P{_Bidi_CONTROL}', "");
Expect(1, 8297, '\P{^_Bidi_CONTROL}', "");
Expect(0, 8298, '\p{_Bidi_CONTROL}', "");
Expect(1, 8298, '\p{^_Bidi_CONTROL}', "");
Expect(1, 8298, '\P{_Bidi_CONTROL}', "");
Expect(0, 8298, '\P{^_Bidi_CONTROL}', "");
Error('\p{ :=is_bidi_CONTROL}');
Error('\P{ :=is_bidi_CONTROL}');
Expect(1, 8297, '\p{isbidicontrol}', "");
Expect(0, 8297, '\p{^isbidicontrol}', "");
Expect(0, 8297, '\P{isbidicontrol}', "");
Expect(1, 8297, '\P{^isbidicontrol}', "");
Expect(0, 8298, '\p{isbidicontrol}', "");
Expect(1, 8298, '\p{^isbidicontrol}', "");
Expect(1, 8298, '\P{isbidicontrol}', "");
Expect(0, 8298, '\P{^isbidicontrol}', "");
Expect(1, 8297, '\p{	Is_bidi_Control}', "");
Expect(0, 8297, '\p{^	Is_bidi_Control}', "");
Expect(0, 8297, '\P{	Is_bidi_Control}', "");
Expect(1, 8297, '\P{^	Is_bidi_Control}', "");
Expect(0, 8298, '\p{	Is_bidi_Control}', "");
Expect(1, 8298, '\p{^	Is_bidi_Control}', "");
Expect(1, 8298, '\P{	Is_bidi_Control}', "");
Expect(0, 8298, '\P{^	Is_bidi_Control}', "");
Error('\p{/a/		Bidi_C}');
Error('\P{/a/		Bidi_C}');
Expect(1, 8297, '\p{bidic}', "");
Expect(0, 8297, '\p{^bidic}', "");
Expect(0, 8297, '\P{bidic}', "");
Expect(1, 8297, '\P{^bidic}', "");
Expect(0, 8298, '\p{bidic}', "");
Expect(1, 8298, '\p{^bidic}', "");
Expect(1, 8298, '\P{bidic}', "");
Expect(0, 8298, '\P{^bidic}', "");
Expect(1, 8297, '\p{	BIDI_C}', "");
Expect(0, 8297, '\p{^	BIDI_C}', "");
Expect(0, 8297, '\P{	BIDI_C}', "");
Expect(1, 8297, '\P{^	BIDI_C}', "");
Expect(0, 8298, '\p{	BIDI_C}', "");
Expect(1, 8298, '\p{^	BIDI_C}', "");
Expect(1, 8298, '\P{	BIDI_C}', "");
Expect(0, 8298, '\P{^	BIDI_C}', "");
Error('\p{	Is_Bidi_c/a/}');
Error('\P{	Is_Bidi_c/a/}');
Expect(1, 8297, '\p{isbidic}', "");
Expect(0, 8297, '\p{^isbidic}', "");
Expect(0, 8297, '\P{isbidic}', "");
Expect(1, 8297, '\P{^isbidic}', "");
Expect(0, 8298, '\p{isbidic}', "");
Expect(1, 8298, '\p{^isbidic}', "");
Expect(1, 8298, '\P{isbidic}', "");
Expect(0, 8298, '\P{^isbidic}', "");
Expect(1, 8297, '\p{-	IS_Bidi_c}', "");
Expect(0, 8297, '\p{^-	IS_Bidi_c}', "");
Expect(0, 8297, '\P{-	IS_Bidi_c}', "");
Expect(1, 8297, '\P{^-	IS_Bidi_c}', "");
Expect(0, 8298, '\p{-	IS_Bidi_c}', "");
Expect(1, 8298, '\p{^-	IS_Bidi_c}', "");
Expect(1, 8298, '\P{-	IS_Bidi_c}', "");
Expect(0, 8298, '\P{^-	IS_Bidi_c}', "");
Error('\p{ /a/Bidi_Mirrored}');
Error('\P{ /a/Bidi_Mirrored}');
Expect(1, 120771, '\p{bidimirrored}', "");
Expect(0, 120771, '\p{^bidimirrored}', "");
Expect(0, 120771, '\P{bidimirrored}', "");
Expect(1, 120771, '\P{^bidimirrored}', "");
Expect(0, 120772, '\p{bidimirrored}', "");
Expect(1, 120772, '\p{^bidimirrored}', "");
Expect(1, 120772, '\P{bidimirrored}', "");
Expect(0, 120772, '\P{^bidimirrored}', "");
Expect(1, 120771, '\p{_bidi_Mirrored}', "");
Expect(0, 120771, '\p{^_bidi_Mirrored}', "");
Expect(0, 120771, '\P{_bidi_Mirrored}', "");
Expect(1, 120771, '\P{^_bidi_Mirrored}', "");
Expect(0, 120772, '\p{_bidi_Mirrored}', "");
Expect(1, 120772, '\p{^_bidi_Mirrored}', "");
Expect(1, 120772, '\P{_bidi_Mirrored}', "");
Expect(0, 120772, '\P{^_bidi_Mirrored}', "");
Error('\p{-/a/IS_Bidi_mirrored}');
Error('\P{-/a/IS_Bidi_mirrored}');
Expect(1, 120771, '\p{isbidimirrored}', "");
Expect(0, 120771, '\p{^isbidimirrored}', "");
Expect(0, 120771, '\P{isbidimirrored}', "");
Expect(1, 120771, '\P{^isbidimirrored}', "");
Expect(0, 120772, '\p{isbidimirrored}', "");
Expect(1, 120772, '\p{^isbidimirrored}', "");
Expect(1, 120772, '\P{isbidimirrored}', "");
Expect(0, 120772, '\P{^isbidimirrored}', "");
Expect(1, 120771, '\p{ Is_bidi_Mirrored}', "");
Expect(0, 120771, '\p{^ Is_bidi_Mirrored}', "");
Expect(0, 120771, '\P{ Is_bidi_Mirrored}', "");
Expect(1, 120771, '\P{^ Is_bidi_Mirrored}', "");
Expect(0, 120772, '\p{ Is_bidi_Mirrored}', "");
Expect(1, 120772, '\p{^ Is_bidi_Mirrored}', "");
Expect(1, 120772, '\P{ Is_bidi_Mirrored}', "");
Expect(0, 120772, '\P{^ Is_bidi_Mirrored}', "");
Error('\p{/a/bidi_M}');
Error('\P{/a/bidi_M}');
Expect(1, 120771, '\p{bidim}', "");
Expect(0, 120771, '\p{^bidim}', "");
Expect(0, 120771, '\P{bidim}', "");
Expect(1, 120771, '\P{^bidim}', "");
Expect(0, 120772, '\p{bidim}', "");
Expect(1, 120772, '\p{^bidim}', "");
Expect(1, 120772, '\P{bidim}', "");
Expect(0, 120772, '\P{^bidim}', "");
Expect(1, 120771, '\p{ _bidi_M}', "");
Expect(0, 120771, '\p{^ _bidi_M}', "");
Expect(0, 120771, '\P{ _bidi_M}', "");
Expect(1, 120771, '\P{^ _bidi_M}', "");
Expect(0, 120772, '\p{ _bidi_M}', "");
Expect(1, 120772, '\p{^ _bidi_M}', "");
Expect(1, 120772, '\P{ _bidi_M}', "");
Expect(0, 120772, '\P{^ _bidi_M}', "");
Error('\p{is_BIDI_M/a/}');
Error('\P{is_BIDI_M/a/}');
Expect(1, 120771, '\p{isbidim}', "");
Expect(0, 120771, '\p{^isbidim}', "");
Expect(0, 120771, '\P{isbidim}', "");
Expect(1, 120771, '\P{^isbidim}', "");
Expect(0, 120772, '\p{isbidim}', "");
Expect(1, 120772, '\p{^isbidim}', "");
Expect(1, 120772, '\P{isbidim}', "");
Expect(0, 120772, '\P{^isbidim}', "");
Expect(1, 120771, '\p{__IS_BIDI_M}', "");
Expect(0, 120771, '\p{^__IS_BIDI_M}', "");
Expect(0, 120771, '\P{__IS_BIDI_M}', "");
Expect(1, 120771, '\P{^__IS_BIDI_M}', "");
Expect(0, 120772, '\p{__IS_BIDI_M}', "");
Expect(1, 120772, '\p{^__IS_BIDI_M}', "");
Expect(1, 120772, '\P{__IS_BIDI_M}', "");
Expect(0, 120772, '\P{^__IS_BIDI_M}', "");
Error('\p{/a/_Blank}');
Error('\P{/a/_Blank}');
Expect(1, 12288, '\p{blank}', "");
Expect(0, 12288, '\p{^blank}', "");
Expect(0, 12288, '\P{blank}', "");
Expect(1, 12288, '\P{^blank}', "");
Expect(0, 12289, '\p{blank}', "");
Expect(1, 12289, '\p{^blank}', "");
Expect(1, 12289, '\P{blank}', "");
Expect(0, 12289, '\P{^blank}', "");
Expect(1, 12288, '\p{	 BLANK}', "");
Expect(0, 12288, '\p{^	 BLANK}', "");
Expect(0, 12288, '\P{	 BLANK}', "");
Expect(1, 12288, '\P{^	 BLANK}', "");
Expect(0, 12289, '\p{	 BLANK}', "");
Expect(1, 12289, '\p{^	 BLANK}', "");
Expect(1, 12289, '\P{	 BLANK}', "");
Expect(0, 12289, '\P{^	 BLANK}', "");
Error('\p{:=horizspace}');
Error('\P{:=horizspace}');
Expect(1, 12288, '\p{horizspace}', "");
Expect(0, 12288, '\p{^horizspace}', "");
Expect(0, 12288, '\P{horizspace}', "");
Expect(1, 12288, '\P{^horizspace}', "");
Expect(0, 12289, '\p{horizspace}', "");
Expect(1, 12289, '\p{^horizspace}', "");
Expect(1, 12289, '\P{horizspace}', "");
Expect(0, 12289, '\P{^horizspace}', "");
Expect(1, 12288, '\p{	HorizSpace}', "");
Expect(0, 12288, '\p{^	HorizSpace}', "");
Expect(0, 12288, '\P{	HorizSpace}', "");
Expect(1, 12288, '\P{^	HorizSpace}', "");
Expect(0, 12289, '\p{	HorizSpace}', "");
Expect(1, 12289, '\p{^	HorizSpace}', "");
Expect(1, 12289, '\P{	HorizSpace}', "");
Expect(0, 12289, '\P{^	HorizSpace}', "");
Error('\p{:= _XPOSIXBLANK}');
Error('\P{:= _XPOSIXBLANK}');
Expect(1, 12288, '\p{xposixblank}', "");
Expect(0, 12288, '\p{^xposixblank}', "");
Expect(0, 12288, '\P{xposixblank}', "");
Expect(1, 12288, '\P{^xposixblank}', "");
Expect(0, 12289, '\p{xposixblank}', "");
Expect(1, 12289, '\p{^xposixblank}', "");
Expect(1, 12289, '\P{xposixblank}', "");
Expect(0, 12289, '\P{^xposixblank}', "");
Expect(1, 12288, '\p{	 XPosixBlank}', "");
Expect(0, 12288, '\p{^	 XPosixBlank}', "");
Expect(0, 12288, '\P{	 XPosixBlank}', "");
Expect(1, 12288, '\P{^	 XPosixBlank}', "");
Expect(0, 12289, '\p{	 XPosixBlank}', "");
Expect(1, 12289, '\p{^	 XPosixBlank}', "");
Expect(1, 12289, '\P{	 XPosixBlank}', "");
Expect(0, 12289, '\P{^	 XPosixBlank}', "");
Error('\p{:=Is_BLANK}');
Error('\P{:=Is_BLANK}');
Expect(1, 12288, '\p{isblank}', "");
Expect(0, 12288, '\p{^isblank}', "");
Expect(0, 12288, '\P{isblank}', "");
Expect(1, 12288, '\P{^isblank}', "");
Expect(0, 12289, '\p{isblank}', "");
Expect(1, 12289, '\p{^isblank}', "");
Expect(1, 12289, '\P{isblank}', "");
Expect(0, 12289, '\P{^isblank}', "");
Expect(1, 12288, '\p{	IS_Blank}', "");
Expect(0, 12288, '\p{^	IS_Blank}', "");
Expect(0, 12288, '\P{	IS_Blank}', "");
Expect(1, 12288, '\P{^	IS_Blank}', "");
Expect(0, 12289, '\p{	IS_Blank}', "");
Expect(1, 12289, '\p{^	IS_Blank}', "");
Expect(1, 12289, '\P{	IS_Blank}', "");
Expect(0, 12289, '\P{^	IS_Blank}', "");
Error('\p{ /a/is_HorizSpace}');
Error('\P{ /a/is_HorizSpace}');
Expect(1, 12288, '\p{ishorizspace}', "");
Expect(0, 12288, '\p{^ishorizspace}', "");
Expect(0, 12288, '\P{ishorizspace}', "");
Expect(1, 12288, '\P{^ishorizspace}', "");
Expect(0, 12289, '\p{ishorizspace}', "");
Expect(1, 12289, '\p{^ishorizspace}', "");
Expect(1, 12289, '\P{ishorizspace}', "");
Expect(0, 12289, '\P{^ishorizspace}', "");
Expect(1, 12288, '\p{	IS_horizspace}', "");
Expect(0, 12288, '\p{^	IS_horizspace}', "");
Expect(0, 12288, '\P{	IS_horizspace}', "");
Expect(1, 12288, '\P{^	IS_horizspace}', "");
Expect(0, 12289, '\p{	IS_horizspace}', "");
Expect(1, 12289, '\p{^	IS_horizspace}', "");
Expect(1, 12289, '\P{	IS_horizspace}', "");
Expect(0, 12289, '\P{^	IS_horizspace}', "");
Error('\p{/a/- is_XPosixBlank}');
Error('\P{/a/- is_XPosixBlank}');
Expect(1, 12288, '\p{isxposixblank}', "");
Expect(0, 12288, '\p{^isxposixblank}', "");
Expect(0, 12288, '\P{isxposixblank}', "");
Expect(1, 12288, '\P{^isxposixblank}', "");
Expect(0, 12289, '\p{isxposixblank}', "");
Expect(1, 12289, '\p{^isxposixblank}', "");
Expect(1, 12289, '\P{isxposixblank}', "");
Expect(0, 12289, '\P{^isxposixblank}', "");
Expect(1, 12288, '\p{_IS_XPosixBlank}', "");
Expect(0, 12288, '\p{^_IS_XPosixBlank}', "");
Expect(0, 12288, '\P{_IS_XPosixBlank}', "");
Expect(1, 12288, '\P{^_IS_XPosixBlank}', "");
Expect(0, 12289, '\p{_IS_XPosixBlank}', "");
Expect(1, 12289, '\p{^_IS_XPosixBlank}', "");
Expect(1, 12289, '\P{_IS_XPosixBlank}', "");
Expect(0, 12289, '\P{^_IS_XPosixBlank}', "");
Error('\p{/a/__Block_Elements}');
Error('\P{/a/__Block_Elements}');
Expect(1, 9631, '\p{blockelements}', "");
Expect(0, 9631, '\p{^blockelements}', "");
Expect(0, 9631, '\P{blockelements}', "");
Expect(1, 9631, '\P{^blockelements}', "");
Expect(0, 9632, '\p{blockelements}', "");
Expect(1, 9632, '\p{^blockelements}', "");
Expect(1, 9632, '\P{blockelements}', "");
Expect(0, 9632, '\P{^blockelements}', "");
Expect(1, 9631, '\p{  BLOCK_ELEMENTS}', "");
Expect(0, 9631, '\p{^  BLOCK_ELEMENTS}', "");
Expect(0, 9631, '\P{  BLOCK_ELEMENTS}', "");
Expect(1, 9631, '\P{^  BLOCK_ELEMENTS}', "");
Expect(0, 9632, '\p{  BLOCK_ELEMENTS}', "");
Expect(1, 9632, '\p{^  BLOCK_ELEMENTS}', "");
Expect(1, 9632, '\P{  BLOCK_ELEMENTS}', "");
Expect(0, 9632, '\P{^  BLOCK_ELEMENTS}', "");
Error('\p{	:=Is_BLOCK_elements}');
Error('\P{	:=Is_BLOCK_elements}');
Expect(1, 9631, '\p{isblockelements}', "");
Expect(0, 9631, '\p{^isblockelements}', "");
Expect(0, 9631, '\P{isblockelements}', "");
Expect(1, 9631, '\P{^isblockelements}', "");
Expect(0, 9632, '\p{isblockelements}', "");
Expect(1, 9632, '\p{^isblockelements}', "");
Expect(1, 9632, '\P{isblockelements}', "");
Expect(0, 9632, '\P{^isblockelements}', "");
Expect(1, 9631, '\p{	-Is_Block_Elements}', "");
Expect(0, 9631, '\p{^	-Is_Block_Elements}', "");
Expect(0, 9631, '\P{	-Is_Block_Elements}', "");
Expect(1, 9631, '\P{^	-Is_Block_Elements}', "");
Expect(0, 9632, '\p{	-Is_Block_Elements}', "");
Expect(1, 9632, '\p{^	-Is_Block_Elements}', "");
Expect(1, 9632, '\P{	-Is_Block_Elements}', "");
Expect(0, 9632, '\P{^	-Is_Block_Elements}', "");
Error('\p{ /a/in_block_elements}');
Error('\P{ /a/in_block_elements}');
Expect(1, 9631, '\p{inblockelements}', "");
Expect(0, 9631, '\p{^inblockelements}', "");
Expect(0, 9631, '\P{inblockelements}', "");
Expect(1, 9631, '\P{^inblockelements}', "");
Expect(0, 9632, '\p{inblockelements}', "");
Expect(1, 9632, '\p{^inblockelements}', "");
Expect(1, 9632, '\P{inblockelements}', "");
Expect(0, 9632, '\P{^inblockelements}', "");
Expect(1, 9631, '\p{ -IN_Block_Elements}', "");
Expect(0, 9631, '\p{^ -IN_Block_Elements}', "");
Expect(0, 9631, '\P{ -IN_Block_Elements}', "");
Expect(1, 9631, '\P{^ -IN_Block_Elements}', "");
Expect(0, 9632, '\p{ -IN_Block_Elements}', "");
Expect(1, 9632, '\p{^ -IN_Block_Elements}', "");
Expect(1, 9632, '\P{ -IN_Block_Elements}', "");
Expect(0, 9632, '\P{^ -IN_Block_Elements}', "");
Error('\p{/a/_bopomofo}');
Error('\P{/a/_bopomofo}');
Expect(1, 12730, '\p{bopomofo}', "");
Expect(0, 12730, '\p{^bopomofo}', "");
Expect(0, 12730, '\P{bopomofo}', "");
Expect(1, 12730, '\P{^bopomofo}', "");
Expect(0, 12731, '\p{bopomofo}', "");
Expect(1, 12731, '\p{^bopomofo}', "");
Expect(1, 12731, '\P{bopomofo}', "");
Expect(0, 12731, '\P{^bopomofo}', "");
Expect(1, 12730, '\p{_ bopomofo}', "");
Expect(0, 12730, '\p{^_ bopomofo}', "");
Expect(0, 12730, '\P{_ bopomofo}', "");
Expect(1, 12730, '\P{^_ bopomofo}', "");
Expect(0, 12731, '\p{_ bopomofo}', "");
Expect(1, 12731, '\p{^_ bopomofo}', "");
Expect(1, 12731, '\P{_ bopomofo}', "");
Expect(0, 12731, '\P{^_ bopomofo}', "");
Error('\p{:=is_Bopomofo}');
Error('\P{:=is_Bopomofo}');
Expect(1, 12730, '\p{isbopomofo}', "");
Expect(0, 12730, '\p{^isbopomofo}', "");
Expect(0, 12730, '\P{isbopomofo}', "");
Expect(1, 12730, '\P{^isbopomofo}', "");
Expect(0, 12731, '\p{isbopomofo}', "");
Expect(1, 12731, '\p{^isbopomofo}', "");
Expect(1, 12731, '\P{isbopomofo}', "");
Expect(0, 12731, '\P{^isbopomofo}', "");
Expect(1, 12730, '\p{ IS_bopomofo}', "");
Expect(0, 12730, '\p{^ IS_bopomofo}', "");
Expect(0, 12730, '\P{ IS_bopomofo}', "");
Expect(1, 12730, '\P{^ IS_bopomofo}', "");
Expect(0, 12731, '\p{ IS_bopomofo}', "");
Expect(1, 12731, '\p{^ IS_bopomofo}', "");
Expect(1, 12731, '\P{ IS_bopomofo}', "");
Expect(0, 12731, '\P{^ IS_bopomofo}', "");
Error('\p{_:=Bopo}');
Error('\P{_:=Bopo}');
Expect(1, 12730, '\p{bopo}', "");
Expect(0, 12730, '\p{^bopo}', "");
Expect(0, 12730, '\P{bopo}', "");
Expect(1, 12730, '\P{^bopo}', "");
Expect(0, 12731, '\p{bopo}', "");
Expect(1, 12731, '\p{^bopo}', "");
Expect(1, 12731, '\P{bopo}', "");
Expect(0, 12731, '\P{^bopo}', "");
Expect(1, 12730, '\p{	-BOPO}', "");
Expect(0, 12730, '\p{^	-BOPO}', "");
Expect(0, 12730, '\P{	-BOPO}', "");
Expect(1, 12730, '\P{^	-BOPO}', "");
Expect(0, 12731, '\p{	-BOPO}', "");
Expect(1, 12731, '\p{^	-BOPO}', "");
Expect(1, 12731, '\P{	-BOPO}', "");
Expect(0, 12731, '\P{^	-BOPO}', "");
Error('\p{ -Is_BOPO:=}');
Error('\P{ -Is_BOPO:=}');
Expect(1, 12730, '\p{isbopo}', "");
Expect(0, 12730, '\p{^isbopo}', "");
Expect(0, 12730, '\P{isbopo}', "");
Expect(1, 12730, '\P{^isbopo}', "");
Expect(0, 12731, '\p{isbopo}', "");
Expect(1, 12731, '\p{^isbopo}', "");
Expect(1, 12731, '\P{isbopo}', "");
Expect(0, 12731, '\P{^isbopo}', "");
Expect(1, 12730, '\p{Is_BOPO}', "");
Expect(0, 12730, '\p{^Is_BOPO}', "");
Expect(0, 12730, '\P{Is_BOPO}', "");
Expect(1, 12730, '\P{^Is_BOPO}', "");
Expect(0, 12731, '\p{Is_BOPO}', "");
Expect(1, 12731, '\p{^Is_BOPO}', "");
Expect(1, 12731, '\P{Is_BOPO}', "");
Expect(0, 12731, '\P{^Is_BOPO}', "");
Error('\p{/a/_ BOPOMOFO_extended}');
Error('\P{/a/_ BOPOMOFO_extended}');
Expect(1, 12735, '\p{bopomofoextended}', "");
Expect(0, 12735, '\p{^bopomofoextended}', "");
Expect(0, 12735, '\P{bopomofoextended}', "");
Expect(1, 12735, '\P{^bopomofoextended}', "");
Expect(0, 12736, '\p{bopomofoextended}', "");
Expect(1, 12736, '\p{^bopomofoextended}', "");
Expect(1, 12736, '\P{bopomofoextended}', "");
Expect(0, 12736, '\P{^bopomofoextended}', "");
Expect(1, 12735, '\p{  BOPOMOFO_Extended}', "");
Expect(0, 12735, '\p{^  BOPOMOFO_Extended}', "");
Expect(0, 12735, '\P{  BOPOMOFO_Extended}', "");
Expect(1, 12735, '\P{^  BOPOMOFO_Extended}', "");
Expect(0, 12736, '\p{  BOPOMOFO_Extended}', "");
Expect(1, 12736, '\p{^  BOPOMOFO_Extended}', "");
Expect(1, 12736, '\P{  BOPOMOFO_Extended}', "");
Expect(0, 12736, '\P{^  BOPOMOFO_Extended}', "");
Error('\p{  Is_Bopomofo_Extended:=}');
Error('\P{  Is_Bopomofo_Extended:=}');
Expect(1, 12735, '\p{isbopomofoextended}', "");
Expect(0, 12735, '\p{^isbopomofoextended}', "");
Expect(0, 12735, '\P{isbopomofoextended}', "");
Expect(1, 12735, '\P{^isbopomofoextended}', "");
Expect(0, 12736, '\p{isbopomofoextended}', "");
Expect(1, 12736, '\p{^isbopomofoextended}', "");
Expect(1, 12736, '\P{isbopomofoextended}', "");
Expect(0, 12736, '\P{^isbopomofoextended}', "");
Expect(1, 12735, '\p{ 	IS_Bopomofo_extended}', "");
Expect(0, 12735, '\p{^ 	IS_Bopomofo_extended}', "");
Expect(0, 12735, '\P{ 	IS_Bopomofo_extended}', "");
Expect(1, 12735, '\P{^ 	IS_Bopomofo_extended}', "");
Expect(0, 12736, '\p{ 	IS_Bopomofo_extended}', "");
Expect(1, 12736, '\p{^ 	IS_Bopomofo_extended}', "");
Expect(1, 12736, '\P{ 	IS_Bopomofo_extended}', "");
Expect(0, 12736, '\P{^ 	IS_Bopomofo_extended}', "");
Error('\p{ :=in_Bopomofo_Extended}');
Error('\P{ :=in_Bopomofo_Extended}');
Expect(1, 12735, '\p{inbopomofoextended}', "");
Expect(0, 12735, '\p{^inbopomofoextended}', "");
Expect(0, 12735, '\P{inbopomofoextended}', "");
Expect(1, 12735, '\P{^inbopomofoextended}', "");
Expect(0, 12736, '\p{inbopomofoextended}', "");
Expect(1, 12736, '\p{^inbopomofoextended}', "");
Expect(1, 12736, '\P{inbopomofoextended}', "");
Expect(0, 12736, '\P{^inbopomofoextended}', "");
Expect(1, 12735, '\p{		in_Bopomofo_extended}', "");
Expect(0, 12735, '\p{^		in_Bopomofo_extended}', "");
Expect(0, 12735, '\P{		in_Bopomofo_extended}', "");
Expect(1, 12735, '\P{^		in_Bopomofo_extended}', "");
Expect(0, 12736, '\p{		in_Bopomofo_extended}', "");
Expect(1, 12736, '\p{^		in_Bopomofo_extended}', "");
Expect(1, 12736, '\P{		in_Bopomofo_extended}', "");
Expect(0, 12736, '\P{^		in_Bopomofo_extended}', "");
Error('\p{_/a/bopomofo_EXT}');
Error('\P{_/a/bopomofo_EXT}');
Expect(1, 12735, '\p{bopomofoext}', "");
Expect(0, 12735, '\p{^bopomofoext}', "");
Expect(0, 12735, '\P{bopomofoext}', "");
Expect(1, 12735, '\P{^bopomofoext}', "");
Expect(0, 12736, '\p{bopomofoext}', "");
Expect(1, 12736, '\p{^bopomofoext}', "");
Expect(1, 12736, '\P{bopomofoext}', "");
Expect(0, 12736, '\P{^bopomofoext}', "");
Expect(1, 12735, '\p{- Bopomofo_Ext}', "");
Expect(0, 12735, '\p{^- Bopomofo_Ext}', "");
Expect(0, 12735, '\P{- Bopomofo_Ext}', "");
Expect(1, 12735, '\P{^- Bopomofo_Ext}', "");
Expect(0, 12736, '\p{- Bopomofo_Ext}', "");
Expect(1, 12736, '\p{^- Bopomofo_Ext}', "");
Expect(1, 12736, '\P{- Bopomofo_Ext}', "");
Expect(0, 12736, '\P{^- Bopomofo_Ext}', "");
Error('\p{ -Is_Bopomofo_EXT:=}');
Error('\P{ -Is_Bopomofo_EXT:=}');
Expect(1, 12735, '\p{isbopomofoext}', "");
Expect(0, 12735, '\p{^isbopomofoext}', "");
Expect(0, 12735, '\P{isbopomofoext}', "");
Expect(1, 12735, '\P{^isbopomofoext}', "");
Expect(0, 12736, '\p{isbopomofoext}', "");
Expect(1, 12736, '\p{^isbopomofoext}', "");
Expect(1, 12736, '\P{isbopomofoext}', "");
Expect(0, 12736, '\P{^isbopomofoext}', "");
Expect(1, 12735, '\p{-_Is_BOPOMOFO_Ext}', "");
Expect(0, 12735, '\p{^-_Is_BOPOMOFO_Ext}', "");
Expect(0, 12735, '\P{-_Is_BOPOMOFO_Ext}', "");
Expect(1, 12735, '\P{^-_Is_BOPOMOFO_Ext}', "");
Expect(0, 12736, '\p{-_Is_BOPOMOFO_Ext}', "");
Expect(1, 12736, '\p{^-_Is_BOPOMOFO_Ext}', "");
Expect(1, 12736, '\P{-_Is_BOPOMOFO_Ext}', "");
Expect(0, 12736, '\P{^-_Is_BOPOMOFO_Ext}', "");
Error('\p{	:=In_Bopomofo_Ext}');
Error('\P{	:=In_Bopomofo_Ext}');
Expect(1, 12735, '\p{inbopomofoext}', "");
Expect(0, 12735, '\p{^inbopomofoext}', "");
Expect(0, 12735, '\P{inbopomofoext}', "");
Expect(1, 12735, '\P{^inbopomofoext}', "");
Expect(0, 12736, '\p{inbopomofoext}', "");
Expect(1, 12736, '\p{^inbopomofoext}', "");
Expect(1, 12736, '\P{inbopomofoext}', "");
Expect(0, 12736, '\P{^inbopomofoext}', "");
Expect(1, 12735, '\p{-	In_Bopomofo_Ext}', "");
Expect(0, 12735, '\p{^-	In_Bopomofo_Ext}', "");
Expect(0, 12735, '\P{-	In_Bopomofo_Ext}', "");
Expect(1, 12735, '\P{^-	In_Bopomofo_Ext}', "");
Expect(0, 12736, '\p{-	In_Bopomofo_Ext}', "");
Expect(1, 12736, '\p{^-	In_Bopomofo_Ext}', "");
Expect(1, 12736, '\P{-	In_Bopomofo_Ext}', "");
Expect(0, 12736, '\P{^-	In_Bopomofo_Ext}', "");
Error('\p{ BOX_drawing/a/}');
Error('\P{ BOX_drawing/a/}');
Expect(1, 9599, '\p{boxdrawing}', "");
Expect(0, 9599, '\p{^boxdrawing}', "");
Expect(0, 9599, '\P{boxdrawing}', "");
Expect(1, 9599, '\P{^boxdrawing}', "");
Expect(0, 9600, '\p{boxdrawing}', "");
Expect(1, 9600, '\p{^boxdrawing}', "");
Expect(1, 9600, '\P{boxdrawing}', "");
Expect(0, 9600, '\P{^boxdrawing}', "");
Expect(1, 9599, '\p{ box_drawing}', "");
Expect(0, 9599, '\p{^ box_drawing}', "");
Expect(0, 9599, '\P{ box_drawing}', "");
Expect(1, 9599, '\P{^ box_drawing}', "");
Expect(0, 9600, '\p{ box_drawing}', "");
Expect(1, 9600, '\p{^ box_drawing}', "");
Expect(1, 9600, '\P{ box_drawing}', "");
Expect(0, 9600, '\P{^ box_drawing}', "");
Error('\p{--Is_BOX_Drawing:=}');
Error('\P{--Is_BOX_Drawing:=}');
Expect(1, 9599, '\p{isboxdrawing}', "");
Expect(0, 9599, '\p{^isboxdrawing}', "");
Expect(0, 9599, '\P{isboxdrawing}', "");
Expect(1, 9599, '\P{^isboxdrawing}', "");
Expect(0, 9600, '\p{isboxdrawing}', "");
Expect(1, 9600, '\p{^isboxdrawing}', "");
Expect(1, 9600, '\P{isboxdrawing}', "");
Expect(0, 9600, '\P{^isboxdrawing}', "");
Expect(1, 9599, '\p{ _Is_box_Drawing}', "");
Expect(0, 9599, '\p{^ _Is_box_Drawing}', "");
Expect(0, 9599, '\P{ _Is_box_Drawing}', "");
Expect(1, 9599, '\P{^ _Is_box_Drawing}', "");
Expect(0, 9600, '\p{ _Is_box_Drawing}', "");
Expect(1, 9600, '\p{^ _Is_box_Drawing}', "");
Expect(1, 9600, '\P{ _Is_box_Drawing}', "");
Expect(0, 9600, '\P{^ _Is_box_Drawing}', "");
Error('\p{	In_Box_DRAWING:=}');
Error('\P{	In_Box_DRAWING:=}');
Expect(1, 9599, '\p{inboxdrawing}', "");
Expect(0, 9599, '\p{^inboxdrawing}', "");
Expect(0, 9599, '\P{inboxdrawing}', "");
Expect(1, 9599, '\P{^inboxdrawing}', "");
Expect(0, 9600, '\p{inboxdrawing}', "");
Expect(1, 9600, '\p{^inboxdrawing}', "");
Expect(1, 9600, '\P{inboxdrawing}', "");
Expect(0, 9600, '\P{^inboxdrawing}', "");
Expect(1, 9599, '\p{-	In_Box_drawing}', "");
Expect(0, 9599, '\p{^-	In_Box_drawing}', "");
Expect(0, 9599, '\P{-	In_Box_drawing}', "");
Expect(1, 9599, '\P{^-	In_Box_drawing}', "");
Expect(0, 9600, '\p{-	In_Box_drawing}', "");
Expect(1, 9600, '\p{^-	In_Box_drawing}', "");
Expect(1, 9600, '\P{-	In_Box_drawing}', "");
Expect(0, 9600, '\P{^-	In_Box_drawing}', "");
Error('\p{ BRAHMI/a/}');
Error('\P{ BRAHMI/a/}');
Expect(1, 69743, '\p{brahmi}', "");
Expect(0, 69743, '\p{^brahmi}', "");
Expect(0, 69743, '\P{brahmi}', "");
Expect(1, 69743, '\P{^brahmi}', "");
Expect(0, 69744, '\p{brahmi}', "");
Expect(1, 69744, '\p{^brahmi}', "");
Expect(1, 69744, '\P{brahmi}', "");
Expect(0, 69744, '\P{^brahmi}', "");
Expect(1, 69743, '\p{_-Brahmi}', "");
Expect(0, 69743, '\p{^_-Brahmi}', "");
Expect(0, 69743, '\P{_-Brahmi}', "");
Expect(1, 69743, '\P{^_-Brahmi}', "");
Expect(0, 69744, '\p{_-Brahmi}', "");
Expect(1, 69744, '\p{^_-Brahmi}', "");
Expect(1, 69744, '\P{_-Brahmi}', "");
Expect(0, 69744, '\P{^_-Brahmi}', "");
Error('\p{	 IS_BRAHMI:=}');
Error('\P{	 IS_BRAHMI:=}');
Expect(1, 69743, '\p{isbrahmi}', "");
Expect(0, 69743, '\p{^isbrahmi}', "");
Expect(0, 69743, '\P{isbrahmi}', "");
Expect(1, 69743, '\P{^isbrahmi}', "");
Expect(0, 69744, '\p{isbrahmi}', "");
Expect(1, 69744, '\p{^isbrahmi}', "");
Expect(1, 69744, '\P{isbrahmi}', "");
Expect(0, 69744, '\P{^isbrahmi}', "");
Expect(1, 69743, '\p{-	is_BRAHMI}', "");
Expect(0, 69743, '\p{^-	is_BRAHMI}', "");
Expect(0, 69743, '\P{-	is_BRAHMI}', "");
Expect(1, 69743, '\P{^-	is_BRAHMI}', "");
Expect(0, 69744, '\p{-	is_BRAHMI}', "");
Expect(1, 69744, '\p{^-	is_BRAHMI}', "");
Expect(1, 69744, '\P{-	is_BRAHMI}', "");
Expect(0, 69744, '\P{^-	is_BRAHMI}', "");
Error('\p{ brah:=}');
Error('\P{ brah:=}');
Expect(1, 69743, '\p{brah}', "");
Expect(0, 69743, '\p{^brah}', "");
Expect(0, 69743, '\P{brah}', "");
Expect(1, 69743, '\P{^brah}', "");
Expect(0, 69744, '\p{brah}', "");
Expect(1, 69744, '\p{^brah}', "");
Expect(1, 69744, '\P{brah}', "");
Expect(0, 69744, '\P{^brah}', "");
Expect(1, 69743, '\p{- Brah}', "");
Expect(0, 69743, '\p{^- Brah}', "");
Expect(0, 69743, '\P{- Brah}', "");
Expect(1, 69743, '\P{^- Brah}', "");
Expect(0, 69744, '\p{- Brah}', "");
Expect(1, 69744, '\p{^- Brah}', "");
Expect(1, 69744, '\P{- Brah}', "");
Expect(0, 69744, '\P{^- Brah}', "");
Error('\p{ -is_Brah:=}');
Error('\P{ -is_Brah:=}');
Expect(1, 69743, '\p{isbrah}', "");
Expect(0, 69743, '\p{^isbrah}', "");
Expect(0, 69743, '\P{isbrah}', "");
Expect(1, 69743, '\P{^isbrah}', "");
Expect(0, 69744, '\p{isbrah}', "");
Expect(1, 69744, '\p{^isbrah}', "");
Expect(1, 69744, '\P{isbrah}', "");
Expect(0, 69744, '\P{^isbrah}', "");
Expect(1, 69743, '\p{ _Is_BRAH}', "");
Expect(0, 69743, '\p{^ _Is_BRAH}', "");
Expect(0, 69743, '\P{ _Is_BRAH}', "");
Expect(1, 69743, '\P{^ _Is_BRAH}', "");
Expect(0, 69744, '\p{ _Is_BRAH}', "");
Expect(1, 69744, '\p{^ _Is_BRAH}', "");
Expect(1, 69744, '\P{ _Is_BRAH}', "");
Expect(0, 69744, '\P{^ _Is_BRAH}', "");
Error('\p{-:=Braille}');
Error('\P{-:=Braille}');
Expect(1, 10495, '\p{braille}', "");
Expect(0, 10495, '\p{^braille}', "");
Expect(0, 10495, '\P{braille}', "");
Expect(1, 10495, '\P{^braille}', "");
Expect(0, 10496, '\p{braille}', "");
Expect(1, 10496, '\p{^braille}', "");
Expect(1, 10496, '\P{braille}', "");
Expect(0, 10496, '\P{^braille}', "");
Expect(1, 10495, '\p{--BRAILLE}', "");
Expect(0, 10495, '\p{^--BRAILLE}', "");
Expect(0, 10495, '\P{--BRAILLE}', "");
Expect(1, 10495, '\P{^--BRAILLE}', "");
Expect(0, 10496, '\p{--BRAILLE}', "");
Expect(1, 10496, '\p{^--BRAILLE}', "");
Expect(1, 10496, '\P{--BRAILLE}', "");
Expect(0, 10496, '\P{^--BRAILLE}', "");
Error('\p{_:=IS_Braille}');
Error('\P{_:=IS_Braille}');
Expect(1, 10495, '\p{isbraille}', "");
Expect(0, 10495, '\p{^isbraille}', "");
Expect(0, 10495, '\P{isbraille}', "");
Expect(1, 10495, '\P{^isbraille}', "");
Expect(0, 10496, '\p{isbraille}', "");
Expect(1, 10496, '\p{^isbraille}', "");
Expect(1, 10496, '\P{isbraille}', "");
Expect(0, 10496, '\P{^isbraille}', "");
Expect(1, 10495, '\p{_-is_braille}', "");
Expect(0, 10495, '\p{^_-is_braille}', "");
Expect(0, 10495, '\P{_-is_braille}', "");
Expect(1, 10495, '\P{^_-is_braille}', "");
Expect(0, 10496, '\p{_-is_braille}', "");
Expect(1, 10496, '\p{^_-is_braille}', "");
Expect(1, 10496, '\P{_-is_braille}', "");
Expect(0, 10496, '\P{^_-is_braille}', "");
Error('\p{:= _brai}');
Error('\P{:= _brai}');
Expect(1, 10495, '\p{brai}', "");
Expect(0, 10495, '\p{^brai}', "");
Expect(0, 10495, '\P{brai}', "");
Expect(1, 10495, '\P{^brai}', "");
Expect(0, 10496, '\p{brai}', "");
Expect(1, 10496, '\p{^brai}', "");
Expect(1, 10496, '\P{brai}', "");
Expect(0, 10496, '\P{^brai}', "");
Expect(1, 10495, '\p{_-brai}', "");
Expect(0, 10495, '\p{^_-brai}', "");
Expect(0, 10495, '\P{_-brai}', "");
Expect(1, 10495, '\P{^_-brai}', "");
Expect(0, 10496, '\p{_-brai}', "");
Expect(1, 10496, '\p{^_-brai}', "");
Expect(1, 10496, '\P{_-brai}', "");
Expect(0, 10496, '\P{^_-brai}', "");
Error('\p{-_Is_Brai/a/}');
Error('\P{-_Is_Brai/a/}');
Expect(1, 10495, '\p{isbrai}', "");
Expect(0, 10495, '\p{^isbrai}', "");
Expect(0, 10495, '\P{isbrai}', "");
Expect(1, 10495, '\P{^isbrai}', "");
Expect(0, 10496, '\p{isbrai}', "");
Expect(1, 10496, '\p{^isbrai}', "");
Expect(1, 10496, '\P{isbrai}', "");
Expect(0, 10496, '\P{^isbrai}', "");
Expect(1, 10495, '\p{	Is_BRAI}', "");
Expect(0, 10495, '\p{^	Is_BRAI}', "");
Expect(0, 10495, '\P{	Is_BRAI}', "");
Expect(1, 10495, '\P{^	Is_BRAI}', "");
Expect(0, 10496, '\p{	Is_BRAI}', "");
Expect(1, 10496, '\p{^	Is_BRAI}', "");
Expect(1, 10496, '\P{	Is_BRAI}', "");
Expect(0, 10496, '\P{^	Is_BRAI}', "");
Error('\p{Braille_patterns/a/}');
Error('\P{Braille_patterns/a/}');
Expect(1, 10495, '\p{braillepatterns}', "");
Expect(0, 10495, '\p{^braillepatterns}', "");
Expect(0, 10495, '\P{braillepatterns}', "");
Expect(1, 10495, '\P{^braillepatterns}', "");
Expect(0, 10496, '\p{braillepatterns}', "");
Expect(1, 10496, '\p{^braillepatterns}', "");
Expect(1, 10496, '\P{braillepatterns}', "");
Expect(0, 10496, '\P{^braillepatterns}', "");
Expect(1, 10495, '\p{		Braille_Patterns}', "");
Expect(0, 10495, '\p{^		Braille_Patterns}', "");
Expect(0, 10495, '\P{		Braille_Patterns}', "");
Expect(1, 10495, '\P{^		Braille_Patterns}', "");
Expect(0, 10496, '\p{		Braille_Patterns}', "");
Expect(1, 10496, '\p{^		Braille_Patterns}', "");
Expect(1, 10496, '\P{		Braille_Patterns}', "");
Expect(0, 10496, '\P{^		Braille_Patterns}', "");
Error('\p{ /a/IS_BRAILLE_Patterns}');
Error('\P{ /a/IS_BRAILLE_Patterns}');
Expect(1, 10495, '\p{isbraillepatterns}', "");
Expect(0, 10495, '\p{^isbraillepatterns}', "");
Expect(0, 10495, '\P{isbraillepatterns}', "");
Expect(1, 10495, '\P{^isbraillepatterns}', "");
Expect(0, 10496, '\p{isbraillepatterns}', "");
Expect(1, 10496, '\p{^isbraillepatterns}', "");
Expect(1, 10496, '\P{isbraillepatterns}', "");
Expect(0, 10496, '\P{^isbraillepatterns}', "");
Expect(1, 10495, '\p{	Is_braille_PATTERNS}', "");
Expect(0, 10495, '\p{^	Is_braille_PATTERNS}', "");
Expect(0, 10495, '\P{	Is_braille_PATTERNS}', "");
Expect(1, 10495, '\P{^	Is_braille_PATTERNS}', "");
Expect(0, 10496, '\p{	Is_braille_PATTERNS}', "");
Expect(1, 10496, '\p{^	Is_braille_PATTERNS}', "");
Expect(1, 10496, '\P{	Is_braille_PATTERNS}', "");
Expect(0, 10496, '\P{^	Is_braille_PATTERNS}', "");
Error('\p{- in_Braille_PATTERNS:=}');
Error('\P{- in_Braille_PATTERNS:=}');
Expect(1, 10495, '\p{inbraillepatterns}', "");
Expect(0, 10495, '\p{^inbraillepatterns}', "");
Expect(0, 10495, '\P{inbraillepatterns}', "");
Expect(1, 10495, '\P{^inbraillepatterns}', "");
Expect(0, 10496, '\p{inbraillepatterns}', "");
Expect(1, 10496, '\p{^inbraillepatterns}', "");
Expect(1, 10496, '\P{inbraillepatterns}', "");
Expect(0, 10496, '\P{^inbraillepatterns}', "");
Expect(1, 10495, '\p{	In_BRAILLE_patterns}', "");
Expect(0, 10495, '\p{^	In_BRAILLE_patterns}', "");
Expect(0, 10495, '\P{	In_BRAILLE_patterns}', "");
Expect(1, 10495, '\P{^	In_BRAILLE_patterns}', "");
Expect(0, 10496, '\p{	In_BRAILLE_patterns}', "");
Expect(1, 10496, '\p{^	In_BRAILLE_patterns}', "");
Expect(1, 10496, '\P{	In_BRAILLE_patterns}', "");
Expect(0, 10496, '\P{^	In_BRAILLE_patterns}', "");
Error('\p{_In_braille/a/}');
Error('\P{_In_braille/a/}');
Expect(1, 10495, '\p{inbraille}', "");
Expect(0, 10495, '\p{^inbraille}', "");
Expect(0, 10495, '\P{inbraille}', "");
Expect(1, 10495, '\P{^inbraille}', "");
Expect(0, 10496, '\p{inbraille}', "");
Expect(1, 10496, '\p{^inbraille}', "");
Expect(1, 10496, '\P{inbraille}', "");
Expect(0, 10496, '\P{^inbraille}', "");
Expect(1, 10495, '\p{In_BRAILLE}', "");
Expect(0, 10495, '\p{^In_BRAILLE}', "");
Expect(0, 10495, '\P{In_BRAILLE}', "");
Expect(1, 10495, '\P{^In_BRAILLE}', "");
Expect(0, 10496, '\p{In_BRAILLE}', "");
Expect(1, 10496, '\p{^In_BRAILLE}', "");
Expect(1, 10496, '\P{In_BRAILLE}', "");
Expect(0, 10496, '\P{^In_BRAILLE}', "");
Error('\p{:=- buginese}');
Error('\P{:=- buginese}');
Expect(1, 6687, '\p{buginese}', "");
Expect(0, 6687, '\p{^buginese}', "");
Expect(0, 6687, '\P{buginese}', "");
Expect(1, 6687, '\P{^buginese}', "");
Expect(0, 6688, '\p{buginese}', "");
Expect(1, 6688, '\p{^buginese}', "");
Expect(1, 6688, '\P{buginese}', "");
Expect(0, 6688, '\P{^buginese}', "");
Expect(1, 6687, '\p{__Buginese}', "");
Expect(0, 6687, '\p{^__Buginese}', "");
Expect(0, 6687, '\P{__Buginese}', "");
Expect(1, 6687, '\P{^__Buginese}', "");
Expect(0, 6688, '\p{__Buginese}', "");
Expect(1, 6688, '\p{^__Buginese}', "");
Expect(1, 6688, '\P{__Buginese}', "");
Expect(0, 6688, '\P{^__Buginese}', "");
Error('\p{	IS_BUGINESE/a/}');
Error('\P{	IS_BUGINESE/a/}');
Expect(1, 6687, '\p{isbuginese}', "");
Expect(0, 6687, '\p{^isbuginese}', "");
Expect(0, 6687, '\P{isbuginese}', "");
Expect(1, 6687, '\P{^isbuginese}', "");
Expect(0, 6688, '\p{isbuginese}', "");
Expect(1, 6688, '\p{^isbuginese}', "");
Expect(1, 6688, '\P{isbuginese}', "");
Expect(0, 6688, '\P{^isbuginese}', "");
Expect(1, 6687, '\p{Is_Buginese}', "");
Expect(0, 6687, '\p{^Is_Buginese}', "");
Expect(0, 6687, '\P{Is_Buginese}', "");
Expect(1, 6687, '\P{^Is_Buginese}', "");
Expect(0, 6688, '\p{Is_Buginese}', "");
Expect(1, 6688, '\p{^Is_Buginese}', "");
Expect(1, 6688, '\P{Is_Buginese}', "");
Expect(0, 6688, '\P{^Is_Buginese}', "");
Error('\p{_ BUGI/a/}');
Error('\P{_ BUGI/a/}');
Expect(1, 6687, '\p{bugi}', "");
Expect(0, 6687, '\p{^bugi}', "");
Expect(0, 6687, '\P{bugi}', "");
Expect(1, 6687, '\P{^bugi}', "");
Expect(0, 6688, '\p{bugi}', "");
Expect(1, 6688, '\p{^bugi}', "");
Expect(1, 6688, '\P{bugi}', "");
Expect(0, 6688, '\P{^bugi}', "");
Expect(1, 6687, '\p{	 BUGI}', "");
Expect(0, 6687, '\p{^	 BUGI}', "");
Expect(0, 6687, '\P{	 BUGI}', "");
Expect(1, 6687, '\P{^	 BUGI}', "");
Expect(0, 6688, '\p{	 BUGI}', "");
Expect(1, 6688, '\p{^	 BUGI}', "");
Expect(1, 6688, '\P{	 BUGI}', "");
Expect(0, 6688, '\P{^	 BUGI}', "");
Error('\p{ _IS_Bugi:=}');
Error('\P{ _IS_Bugi:=}');
Expect(1, 6687, '\p{isbugi}', "");
Expect(0, 6687, '\p{^isbugi}', "");
Expect(0, 6687, '\P{isbugi}', "");
Expect(1, 6687, '\P{^isbugi}', "");
Expect(0, 6688, '\p{isbugi}', "");
Expect(1, 6688, '\p{^isbugi}', "");
Expect(1, 6688, '\P{isbugi}', "");
Expect(0, 6688, '\P{^isbugi}', "");
Expect(1, 6687, '\p{Is_Bugi}', "");
Expect(0, 6687, '\p{^Is_Bugi}', "");
Expect(0, 6687, '\P{Is_Bugi}', "");
Expect(1, 6687, '\P{^Is_Bugi}', "");
Expect(0, 6688, '\p{Is_Bugi}', "");
Expect(1, 6688, '\p{^Is_Bugi}', "");
Expect(1, 6688, '\P{Is_Bugi}', "");
Expect(0, 6688, '\P{^Is_Bugi}', "");
Error('\p{-:=Buhid}');
Error('\P{-:=Buhid}');
Expect(1, 5971, '\p{buhid}', "");
Expect(0, 5971, '\p{^buhid}', "");
Expect(0, 5971, '\P{buhid}', "");
Expect(1, 5971, '\P{^buhid}', "");
Expect(0, 5972, '\p{buhid}', "");
Expect(1, 5972, '\p{^buhid}', "");
Expect(1, 5972, '\P{buhid}', "");
Expect(0, 5972, '\P{^buhid}', "");
Expect(1, 5971, '\p{-_buhid}', "");
Expect(0, 5971, '\p{^-_buhid}', "");
Expect(0, 5971, '\P{-_buhid}', "");
Expect(1, 5971, '\P{^-_buhid}', "");
Expect(0, 5972, '\p{-_buhid}', "");
Expect(1, 5972, '\p{^-_buhid}', "");
Expect(1, 5972, '\P{-_buhid}', "");
Expect(0, 5972, '\P{^-_buhid}', "");
Error('\p{  Is_Buhid/a/}');
Error('\P{  Is_Buhid/a/}');
Expect(1, 5971, '\p{isbuhid}', "");
Expect(0, 5971, '\p{^isbuhid}', "");
Expect(0, 5971, '\P{isbuhid}', "");
Expect(1, 5971, '\P{^isbuhid}', "");
Expect(0, 5972, '\p{isbuhid}', "");
Expect(1, 5972, '\p{^isbuhid}', "");
Expect(1, 5972, '\P{isbuhid}', "");
Expect(0, 5972, '\P{^isbuhid}', "");
Expect(1, 5971, '\p{	 is_buhid}', "");
Expect(0, 5971, '\p{^	 is_buhid}', "");
Expect(0, 5971, '\P{	 is_buhid}', "");
Expect(1, 5971, '\P{^	 is_buhid}', "");
Expect(0, 5972, '\p{	 is_buhid}', "");
Expect(1, 5972, '\p{^	 is_buhid}', "");
Expect(1, 5972, '\P{	 is_buhid}', "");
Expect(0, 5972, '\P{^	 is_buhid}', "");
Error('\p{  BUHD:=}');
Error('\P{  BUHD:=}');
Expect(1, 5971, '\p{buhd}', "");
Expect(0, 5971, '\p{^buhd}', "");
Expect(0, 5971, '\P{buhd}', "");
Expect(1, 5971, '\P{^buhd}', "");
Expect(0, 5972, '\p{buhd}', "");
Expect(1, 5972, '\p{^buhd}', "");
Expect(1, 5972, '\P{buhd}', "");
Expect(0, 5972, '\P{^buhd}', "");
Expect(1, 5971, '\p{_	buhd}', "");
Expect(0, 5971, '\p{^_	buhd}', "");
Expect(0, 5971, '\P{_	buhd}', "");
Expect(1, 5971, '\P{^_	buhd}', "");
Expect(0, 5972, '\p{_	buhd}', "");
Expect(1, 5972, '\p{^_	buhd}', "");
Expect(1, 5972, '\P{_	buhd}', "");
Expect(0, 5972, '\P{^_	buhd}', "");
Error('\p{__is_BUHD/a/}');
Error('\P{__is_BUHD/a/}');
Expect(1, 5971, '\p{isbuhd}', "");
Expect(0, 5971, '\p{^isbuhd}', "");
Expect(0, 5971, '\P{isbuhd}', "");
Expect(1, 5971, '\P{^isbuhd}', "");
Expect(0, 5972, '\p{isbuhd}', "");
Expect(1, 5972, '\p{^isbuhd}', "");
Expect(1, 5972, '\P{isbuhd}', "");
Expect(0, 5972, '\P{^isbuhd}', "");
Expect(1, 5971, '\p{_	Is_Buhd}', "");
Expect(0, 5971, '\p{^_	Is_Buhd}', "");
Expect(0, 5971, '\P{_	Is_Buhd}', "");
Expect(1, 5971, '\P{^_	Is_Buhd}', "");
Expect(0, 5972, '\p{_	Is_Buhd}', "");
Expect(1, 5972, '\p{^_	Is_Buhd}', "");
Expect(1, 5972, '\P{_	Is_Buhd}', "");
Expect(0, 5972, '\P{^_	Is_Buhd}', "");
Error('\p{ byzantine_MUSICAL_Symbols/a/}');
Error('\P{ byzantine_MUSICAL_Symbols/a/}');
Expect(1, 119039, '\p{byzantinemusicalsymbols}', "");
Expect(0, 119039, '\p{^byzantinemusicalsymbols}', "");
Expect(0, 119039, '\P{byzantinemusicalsymbols}', "");
Expect(1, 119039, '\P{^byzantinemusicalsymbols}', "");
Expect(0, 119040, '\p{byzantinemusicalsymbols}', "");
Expect(1, 119040, '\p{^byzantinemusicalsymbols}', "");
Expect(1, 119040, '\P{byzantinemusicalsymbols}', "");
Expect(0, 119040, '\P{^byzantinemusicalsymbols}', "");
Expect(1, 119039, '\p{__Byzantine_Musical_Symbols}', "");
Expect(0, 119039, '\p{^__Byzantine_Musical_Symbols}', "");
Expect(0, 119039, '\P{__Byzantine_Musical_Symbols}', "");
Expect(1, 119039, '\P{^__Byzantine_Musical_Symbols}', "");
Expect(0, 119040, '\p{__Byzantine_Musical_Symbols}', "");
Expect(1, 119040, '\p{^__Byzantine_Musical_Symbols}', "");
Expect(1, 119040, '\P{__Byzantine_Musical_Symbols}', "");
Expect(0, 119040, '\P{^__Byzantine_Musical_Symbols}', "");
Error('\p{- Is_byzantine_Musical_SYMBOLS/a/}');
Error('\P{- Is_byzantine_Musical_SYMBOLS/a/}');
Expect(1, 119039, '\p{isbyzantinemusicalsymbols}', "");
Expect(0, 119039, '\p{^isbyzantinemusicalsymbols}', "");
Expect(0, 119039, '\P{isbyzantinemusicalsymbols}', "");
Expect(1, 119039, '\P{^isbyzantinemusicalsymbols}', "");
Expect(0, 119040, '\p{isbyzantinemusicalsymbols}', "");
Expect(1, 119040, '\p{^isbyzantinemusicalsymbols}', "");
Expect(1, 119040, '\P{isbyzantinemusicalsymbols}', "");
Expect(0, 119040, '\P{^isbyzantinemusicalsymbols}', "");
Expect(1, 119039, '\p{-_IS_BYZANTINE_MUSICAL_symbols}', "");
Expect(0, 119039, '\p{^-_IS_BYZANTINE_MUSICAL_symbols}', "");
Expect(0, 119039, '\P{-_IS_BYZANTINE_MUSICAL_symbols}', "");
Expect(1, 119039, '\P{^-_IS_BYZANTINE_MUSICAL_symbols}', "");
Expect(0, 119040, '\p{-_IS_BYZANTINE_MUSICAL_symbols}', "");
Expect(1, 119040, '\p{^-_IS_BYZANTINE_MUSICAL_symbols}', "");
Expect(1, 119040, '\P{-_IS_BYZANTINE_MUSICAL_symbols}', "");
Expect(0, 119040, '\P{^-_IS_BYZANTINE_MUSICAL_symbols}', "");
Error('\p{_In_Byzantine_Musical_Symbols:=}');
Error('\P{_In_Byzantine_Musical_Symbols:=}');
Expect(1, 119039, '\p{inbyzantinemusicalsymbols}', "");
Expect(0, 119039, '\p{^inbyzantinemusicalsymbols}', "");
Expect(0, 119039, '\P{inbyzantinemusicalsymbols}', "");
Expect(1, 119039, '\P{^inbyzantinemusicalsymbols}', "");
Expect(0, 119040, '\p{inbyzantinemusicalsymbols}', "");
Expect(1, 119040, '\p{^inbyzantinemusicalsymbols}', "");
Expect(1, 119040, '\P{inbyzantinemusicalsymbols}', "");
Expect(0, 119040, '\P{^inbyzantinemusicalsymbols}', "");
Expect(1, 119039, '\p{_IN_BYZANTINE_Musical_SYMBOLS}', "");
Expect(0, 119039, '\p{^_IN_BYZANTINE_Musical_SYMBOLS}', "");
Expect(0, 119039, '\P{_IN_BYZANTINE_Musical_SYMBOLS}', "");
Expect(1, 119039, '\P{^_IN_BYZANTINE_Musical_SYMBOLS}', "");
Expect(0, 119040, '\p{_IN_BYZANTINE_Musical_SYMBOLS}', "");
Expect(1, 119040, '\p{^_IN_BYZANTINE_Musical_SYMBOLS}', "");
Expect(1, 119040, '\P{_IN_BYZANTINE_Musical_SYMBOLS}', "");
Expect(0, 119040, '\P{^_IN_BYZANTINE_Musical_SYMBOLS}', "");
Error('\p{--Byzantine_music/a/}');
Error('\P{--Byzantine_music/a/}');
Expect(1, 119039, '\p{byzantinemusic}', "");
Expect(0, 119039, '\p{^byzantinemusic}', "");
Expect(0, 119039, '\P{byzantinemusic}', "");
Expect(1, 119039, '\P{^byzantinemusic}', "");
Expect(0, 119040, '\p{byzantinemusic}', "");
Expect(1, 119040, '\p{^byzantinemusic}', "");
Expect(1, 119040, '\P{byzantinemusic}', "");
Expect(0, 119040, '\P{^byzantinemusic}', "");
Expect(1, 119039, '\p{  Byzantine_Music}', "");
Expect(0, 119039, '\p{^  Byzantine_Music}', "");
Expect(0, 119039, '\P{  Byzantine_Music}', "");
Expect(1, 119039, '\P{^  Byzantine_Music}', "");
Expect(0, 119040, '\p{  Byzantine_Music}', "");
Expect(1, 119040, '\p{^  Byzantine_Music}', "");
Expect(1, 119040, '\P{  Byzantine_Music}', "");
Expect(0, 119040, '\P{^  Byzantine_Music}', "");
Error('\p{__Is_Byzantine_Music/a/}');
Error('\P{__Is_Byzantine_Music/a/}');
Expect(1, 119039, '\p{isbyzantinemusic}', "");
Expect(0, 119039, '\p{^isbyzantinemusic}', "");
Expect(0, 119039, '\P{isbyzantinemusic}', "");
Expect(1, 119039, '\P{^isbyzantinemusic}', "");
Expect(0, 119040, '\p{isbyzantinemusic}', "");
Expect(1, 119040, '\p{^isbyzantinemusic}', "");
Expect(1, 119040, '\P{isbyzantinemusic}', "");
Expect(0, 119040, '\P{^isbyzantinemusic}', "");
Expect(1, 119039, '\p{__Is_byzantine_Music}', "");
Expect(0, 119039, '\p{^__Is_byzantine_Music}', "");
Expect(0, 119039, '\P{__Is_byzantine_Music}', "");
Expect(1, 119039, '\P{^__Is_byzantine_Music}', "");
Expect(0, 119040, '\p{__Is_byzantine_Music}', "");
Expect(1, 119040, '\p{^__Is_byzantine_Music}', "");
Expect(1, 119040, '\P{__Is_byzantine_Music}', "");
Expect(0, 119040, '\P{^__Is_byzantine_Music}', "");
Error('\p{_	IN_Byzantine_music:=}');
Error('\P{_	IN_Byzantine_music:=}');
Expect(1, 119039, '\p{inbyzantinemusic}', "");
Expect(0, 119039, '\p{^inbyzantinemusic}', "");
Expect(0, 119039, '\P{inbyzantinemusic}', "");
Expect(1, 119039, '\P{^inbyzantinemusic}', "");
Expect(0, 119040, '\p{inbyzantinemusic}', "");
Expect(1, 119040, '\p{^inbyzantinemusic}', "");
Expect(1, 119040, '\P{inbyzantinemusic}', "");
Expect(0, 119040, '\P{^inbyzantinemusic}', "");
Expect(1, 119039, '\p{	 In_Byzantine_music}', "");
Expect(0, 119039, '\p{^	 In_Byzantine_music}', "");
Expect(0, 119039, '\P{	 In_Byzantine_music}', "");
Expect(1, 119039, '\P{^	 In_Byzantine_music}', "");
Expect(0, 119040, '\p{	 In_Byzantine_music}', "");
Expect(1, 119040, '\p{^	 In_Byzantine_music}', "");
Expect(1, 119040, '\P{	 In_Byzantine_music}', "");
Expect(0, 119040, '\P{^	 In_Byzantine_music}', "");
Error('\p{/a/-cjk_Compatibility}');
Error('\P{/a/-cjk_Compatibility}');
Expect(1, 13311, '\p{cjkcompatibility}', "");
Expect(0, 13311, '\p{^cjkcompatibility}', "");
Expect(0, 13311, '\P{cjkcompatibility}', "");
Expect(1, 13311, '\P{^cjkcompatibility}', "");
Expect(0, 13312, '\p{cjkcompatibility}', "");
Expect(1, 13312, '\p{^cjkcompatibility}', "");
Expect(1, 13312, '\P{cjkcompatibility}', "");
Expect(0, 13312, '\P{^cjkcompatibility}', "");
Expect(1, 13311, '\p{-	cjk_COMPATIBILITY}', "");
Expect(0, 13311, '\p{^-	cjk_COMPATIBILITY}', "");
Expect(0, 13311, '\P{-	cjk_COMPATIBILITY}', "");
Expect(1, 13311, '\P{^-	cjk_COMPATIBILITY}', "");
Expect(0, 13312, '\p{-	cjk_COMPATIBILITY}', "");
Expect(1, 13312, '\p{^-	cjk_COMPATIBILITY}', "");
Expect(1, 13312, '\P{-	cjk_COMPATIBILITY}', "");
Expect(0, 13312, '\P{^-	cjk_COMPATIBILITY}', "");
Error('\p{:=--Is_CJK_compatibility}');
Error('\P{:=--Is_CJK_compatibility}');
Expect(1, 13311, '\p{iscjkcompatibility}', "");
Expect(0, 13311, '\p{^iscjkcompatibility}', "");
Expect(0, 13311, '\P{iscjkcompatibility}', "");
Expect(1, 13311, '\P{^iscjkcompatibility}', "");
Expect(0, 13312, '\p{iscjkcompatibility}', "");
Expect(1, 13312, '\p{^iscjkcompatibility}', "");
Expect(1, 13312, '\P{iscjkcompatibility}', "");
Expect(0, 13312, '\P{^iscjkcompatibility}', "");
Expect(1, 13311, '\p{ _IS_CJK_compatibility}', "");
Expect(0, 13311, '\p{^ _IS_CJK_compatibility}', "");
Expect(0, 13311, '\P{ _IS_CJK_compatibility}', "");
Expect(1, 13311, '\P{^ _IS_CJK_compatibility}', "");
Expect(0, 13312, '\p{ _IS_CJK_compatibility}', "");
Expect(1, 13312, '\p{^ _IS_CJK_compatibility}', "");
Expect(1, 13312, '\P{ _IS_CJK_compatibility}', "");
Expect(0, 13312, '\P{^ _IS_CJK_compatibility}', "");
Error('\p{_in_CJK_Compatibility/a/}');
Error('\P{_in_CJK_Compatibility/a/}');
Expect(1, 13311, '\p{incjkcompatibility}', "");
Expect(0, 13311, '\p{^incjkcompatibility}', "");
Expect(0, 13311, '\P{incjkcompatibility}', "");
Expect(1, 13311, '\P{^incjkcompatibility}', "");
Expect(0, 13312, '\p{incjkcompatibility}', "");
Expect(1, 13312, '\p{^incjkcompatibility}', "");
Expect(1, 13312, '\P{incjkcompatibility}', "");
Expect(0, 13312, '\P{^incjkcompatibility}', "");
Expect(1, 13311, '\p{	In_cjk_COMPATIBILITY}', "");
Expect(0, 13311, '\p{^	In_cjk_COMPATIBILITY}', "");
Expect(0, 13311, '\P{	In_cjk_COMPATIBILITY}', "");
Expect(1, 13311, '\P{^	In_cjk_COMPATIBILITY}', "");
Expect(0, 13312, '\p{	In_cjk_COMPATIBILITY}', "");
Expect(1, 13312, '\p{^	In_cjk_COMPATIBILITY}', "");
Expect(1, 13312, '\P{	In_cjk_COMPATIBILITY}', "");
Expect(0, 13312, '\P{^	In_cjk_COMPATIBILITY}', "");
Error('\p{_:=CJK_compat}');
Error('\P{_:=CJK_compat}');
Expect(1, 13311, '\p{cjkcompat}', "");
Expect(0, 13311, '\p{^cjkcompat}', "");
Expect(0, 13311, '\P{cjkcompat}', "");
Expect(1, 13311, '\P{^cjkcompat}', "");
Expect(0, 13312, '\p{cjkcompat}', "");
Expect(1, 13312, '\p{^cjkcompat}', "");
Expect(1, 13312, '\P{cjkcompat}', "");
Expect(0, 13312, '\P{^cjkcompat}', "");
Expect(1, 13311, '\p{	CJK_Compat}', "");
Expect(0, 13311, '\p{^	CJK_Compat}', "");
Expect(0, 13311, '\P{	CJK_Compat}', "");
Expect(1, 13311, '\P{^	CJK_Compat}', "");
Expect(0, 13312, '\p{	CJK_Compat}', "");
Expect(1, 13312, '\p{^	CJK_Compat}', "");
Expect(1, 13312, '\P{	CJK_Compat}', "");
Expect(0, 13312, '\P{^	CJK_Compat}', "");
Error('\p{/a/_is_CJK_Compat}');
Error('\P{/a/_is_CJK_Compat}');
Expect(1, 13311, '\p{iscjkcompat}', "");
Expect(0, 13311, '\p{^iscjkcompat}', "");
Expect(0, 13311, '\P{iscjkcompat}', "");
Expect(1, 13311, '\P{^iscjkcompat}', "");
Expect(0, 13312, '\p{iscjkcompat}', "");
Expect(1, 13312, '\p{^iscjkcompat}', "");
Expect(1, 13312, '\P{iscjkcompat}', "");
Expect(0, 13312, '\P{^iscjkcompat}', "");
Expect(1, 13311, '\p{is_CJK_Compat}', "");
Expect(0, 13311, '\p{^is_CJK_Compat}', "");
Expect(0, 13311, '\P{is_CJK_Compat}', "");
Expect(1, 13311, '\P{^is_CJK_Compat}', "");
Expect(0, 13312, '\p{is_CJK_Compat}', "");
Expect(1, 13312, '\p{^is_CJK_Compat}', "");
Expect(1, 13312, '\P{is_CJK_Compat}', "");
Expect(0, 13312, '\P{^is_CJK_Compat}', "");
Error('\p{/a/	_In_cjk_COMPAT}');
Error('\P{/a/	_In_cjk_COMPAT}');
Expect(1, 13311, '\p{incjkcompat}', "");
Expect(0, 13311, '\p{^incjkcompat}', "");
Expect(0, 13311, '\P{incjkcompat}', "");
Expect(1, 13311, '\P{^incjkcompat}', "");
Expect(0, 13312, '\p{incjkcompat}', "");
Expect(1, 13312, '\p{^incjkcompat}', "");
Expect(1, 13312, '\P{incjkcompat}', "");
Expect(0, 13312, '\P{^incjkcompat}', "");
Expect(1, 13311, '\p{	-In_CJK_Compat}', "");
Expect(0, 13311, '\p{^	-In_CJK_Compat}', "");
Expect(0, 13311, '\P{	-In_CJK_Compat}', "");
Expect(1, 13311, '\P{^	-In_CJK_Compat}', "");
Expect(0, 13312, '\p{	-In_CJK_Compat}', "");
Expect(1, 13312, '\p{^	-In_CJK_Compat}', "");
Expect(1, 13312, '\P{	-In_CJK_Compat}', "");
Expect(0, 13312, '\P{^	-In_CJK_Compat}', "");
Error('\p{ cjk_Compatibility_Forms/a/}');
Error('\P{ cjk_Compatibility_Forms/a/}');
Expect(1, 65103, '\p{cjkcompatibilityforms}', "");
Expect(0, 65103, '\p{^cjkcompatibilityforms}', "");
Expect(0, 65103, '\P{cjkcompatibilityforms}', "");
Expect(1, 65103, '\P{^cjkcompatibilityforms}', "");
Expect(0, 65104, '\p{cjkcompatibilityforms}', "");
Expect(1, 65104, '\p{^cjkcompatibilityforms}', "");
Expect(1, 65104, '\P{cjkcompatibilityforms}', "");
Expect(0, 65104, '\P{^cjkcompatibilityforms}', "");
Expect(1, 65103, '\p{		CJK_Compatibility_forms}', "");
Expect(0, 65103, '\p{^		CJK_Compatibility_forms}', "");
Expect(0, 65103, '\P{		CJK_Compatibility_forms}', "");
Expect(1, 65103, '\P{^		CJK_Compatibility_forms}', "");
Expect(0, 65104, '\p{		CJK_Compatibility_forms}', "");
Expect(1, 65104, '\p{^		CJK_Compatibility_forms}', "");
Expect(1, 65104, '\P{		CJK_Compatibility_forms}', "");
Expect(0, 65104, '\P{^		CJK_Compatibility_forms}', "");
Error('\p{  Is_cjk_COMPATIBILITY_FORMS:=}');
Error('\P{  Is_cjk_COMPATIBILITY_FORMS:=}');
Expect(1, 65103, '\p{iscjkcompatibilityforms}', "");
Expect(0, 65103, '\p{^iscjkcompatibilityforms}', "");
Expect(0, 65103, '\P{iscjkcompatibilityforms}', "");
Expect(1, 65103, '\P{^iscjkcompatibilityforms}', "");
Expect(0, 65104, '\p{iscjkcompatibilityforms}', "");
Expect(1, 65104, '\p{^iscjkcompatibilityforms}', "");
Expect(1, 65104, '\P{iscjkcompatibilityforms}', "");
Expect(0, 65104, '\P{^iscjkcompatibilityforms}', "");
Expect(1, 65103, '\p{- is_CJK_Compatibility_forms}', "");
Expect(0, 65103, '\p{^- is_CJK_Compatibility_forms}', "");
Expect(0, 65103, '\P{- is_CJK_Compatibility_forms}', "");
Expect(1, 65103, '\P{^- is_CJK_Compatibility_forms}', "");
Expect(0, 65104, '\p{- is_CJK_Compatibility_forms}', "");
Expect(1, 65104, '\p{^- is_CJK_Compatibility_forms}', "");
Expect(1, 65104, '\P{- is_CJK_Compatibility_forms}', "");
Expect(0, 65104, '\P{^- is_CJK_Compatibility_forms}', "");
Error('\p{/a/In_cjk_Compatibility_Forms}');
Error('\P{/a/In_cjk_Compatibility_Forms}');
Expect(1, 65103, '\p{incjkcompatibilityforms}', "");
Expect(0, 65103, '\p{^incjkcompatibilityforms}', "");
Expect(0, 65103, '\P{incjkcompatibilityforms}', "");
Expect(1, 65103, '\P{^incjkcompatibilityforms}', "");
Expect(0, 65104, '\p{incjkcompatibilityforms}', "");
Expect(1, 65104, '\p{^incjkcompatibilityforms}', "");
Expect(1, 65104, '\P{incjkcompatibilityforms}', "");
Expect(0, 65104, '\P{^incjkcompatibilityforms}', "");
Expect(1, 65103, '\p{-IN_CJK_COMPATIBILITY_FORMS}', "");
Expect(0, 65103, '\p{^-IN_CJK_COMPATIBILITY_FORMS}', "");
Expect(0, 65103, '\P{-IN_CJK_COMPATIBILITY_FORMS}', "");
Expect(1, 65103, '\P{^-IN_CJK_COMPATIBILITY_FORMS}', "");
Expect(0, 65104, '\p{-IN_CJK_COMPATIBILITY_FORMS}', "");
Expect(1, 65104, '\p{^-IN_CJK_COMPATIBILITY_FORMS}', "");
Expect(1, 65104, '\P{-IN_CJK_COMPATIBILITY_FORMS}', "");
Expect(0, 65104, '\P{^-IN_CJK_COMPATIBILITY_FORMS}', "");
Error('\p{/a/	_CJK_compat_FORMS}');
Error('\P{/a/	_CJK_compat_FORMS}');
Expect(1, 65103, '\p{cjkcompatforms}', "");
Expect(0, 65103, '\p{^cjkcompatforms}', "");
Expect(0, 65103, '\P{cjkcompatforms}', "");
Expect(1, 65103, '\P{^cjkcompatforms}', "");
Expect(0, 65104, '\p{cjkcompatforms}', "");
Expect(1, 65104, '\p{^cjkcompatforms}', "");
Expect(1, 65104, '\P{cjkcompatforms}', "");
Expect(0, 65104, '\P{^cjkcompatforms}', "");
Expect(1, 65103, '\p{__CJK_Compat_Forms}', "");
Expect(0, 65103, '\p{^__CJK_Compat_Forms}', "");
Expect(0, 65103, '\P{__CJK_Compat_Forms}', "");
Expect(1, 65103, '\P{^__CJK_Compat_Forms}', "");
Expect(0, 65104, '\p{__CJK_Compat_Forms}', "");
Expect(1, 65104, '\p{^__CJK_Compat_Forms}', "");
Expect(1, 65104, '\P{__CJK_Compat_Forms}', "");
Expect(0, 65104, '\P{^__CJK_Compat_Forms}', "");
Error('\p{:= Is_CJK_Compat_forms}');
Error('\P{:= Is_CJK_Compat_forms}');
Expect(1, 65103, '\p{iscjkcompatforms}', "");
Expect(0, 65103, '\p{^iscjkcompatforms}', "");
Expect(0, 65103, '\P{iscjkcompatforms}', "");
Expect(1, 65103, '\P{^iscjkcompatforms}', "");
Expect(0, 65104, '\p{iscjkcompatforms}', "");
Expect(1, 65104, '\p{^iscjkcompatforms}', "");
Expect(1, 65104, '\P{iscjkcompatforms}', "");
Expect(0, 65104, '\P{^iscjkcompatforms}', "");
Expect(1, 65103, '\p{		Is_cjk_COMPAT_Forms}', "");
Expect(0, 65103, '\p{^		Is_cjk_COMPAT_Forms}', "");
Expect(0, 65103, '\P{		Is_cjk_COMPAT_Forms}', "");
Expect(1, 65103, '\P{^		Is_cjk_COMPAT_Forms}', "");
Expect(0, 65104, '\p{		Is_cjk_COMPAT_Forms}', "");
Expect(1, 65104, '\p{^		Is_cjk_COMPAT_Forms}', "");
Expect(1, 65104, '\P{		Is_cjk_COMPAT_Forms}', "");
Expect(0, 65104, '\P{^		Is_cjk_COMPAT_Forms}', "");
Error('\p{/a/_IN_CJK_Compat_Forms}');
Error('\P{/a/_IN_CJK_Compat_Forms}');
Expect(1, 65103, '\p{incjkcompatforms}', "");
Expect(0, 65103, '\p{^incjkcompatforms}', "");
Expect(0, 65103, '\P{incjkcompatforms}', "");
Expect(1, 65103, '\P{^incjkcompatforms}', "");
Expect(0, 65104, '\p{incjkcompatforms}', "");
Expect(1, 65104, '\p{^incjkcompatforms}', "");
Expect(1, 65104, '\P{incjkcompatforms}', "");
Expect(0, 65104, '\P{^incjkcompatforms}', "");
Expect(1, 65103, '\p{- In_CJK_COMPAT_FORMS}', "");
Expect(0, 65103, '\p{^- In_CJK_COMPAT_FORMS}', "");
Expect(0, 65103, '\P{- In_CJK_COMPAT_FORMS}', "");
Expect(1, 65103, '\P{^- In_CJK_COMPAT_FORMS}', "");
Expect(0, 65104, '\p{- In_CJK_COMPAT_FORMS}', "");
Expect(1, 65104, '\p{^- In_CJK_COMPAT_FORMS}', "");
Expect(1, 65104, '\P{- In_CJK_COMPAT_FORMS}', "");
Expect(0, 65104, '\P{^- In_CJK_COMPAT_FORMS}', "");
Error('\p{ :=cjk_compatibility_ideographs}');
Error('\P{ :=cjk_compatibility_ideographs}');
Expect(1, 64255, '\p{cjkcompatibilityideographs}', "");
Expect(0, 64255, '\p{^cjkcompatibilityideographs}', "");
Expect(0, 64255, '\P{cjkcompatibilityideographs}', "");
Expect(1, 64255, '\P{^cjkcompatibilityideographs}', "");
Expect(0, 64256, '\p{cjkcompatibilityideographs}', "");
Expect(1, 64256, '\p{^cjkcompatibilityideographs}', "");
Expect(1, 64256, '\P{cjkcompatibilityideographs}', "");
Expect(0, 64256, '\P{^cjkcompatibilityideographs}', "");
Expect(1, 64255, '\p{ CJK_Compatibility_Ideographs}', "");
Expect(0, 64255, '\p{^ CJK_Compatibility_Ideographs}', "");
Expect(0, 64255, '\P{ CJK_Compatibility_Ideographs}', "");
Expect(1, 64255, '\P{^ CJK_Compatibility_Ideographs}', "");
Expect(0, 64256, '\p{ CJK_Compatibility_Ideographs}', "");
Expect(1, 64256, '\p{^ CJK_Compatibility_Ideographs}', "");
Expect(1, 64256, '\P{ CJK_Compatibility_Ideographs}', "");
Expect(0, 64256, '\P{^ CJK_Compatibility_Ideographs}', "");
Error('\p{-_Is_CJK_Compatibility_Ideographs/a/}');
Error('\P{-_Is_CJK_Compatibility_Ideographs/a/}');
Expect(1, 64255, '\p{iscjkcompatibilityideographs}', "");
Expect(0, 64255, '\p{^iscjkcompatibilityideographs}', "");
Expect(0, 64255, '\P{iscjkcompatibilityideographs}', "");
Expect(1, 64255, '\P{^iscjkcompatibilityideographs}', "");
Expect(0, 64256, '\p{iscjkcompatibilityideographs}', "");
Expect(1, 64256, '\p{^iscjkcompatibilityideographs}', "");
Expect(1, 64256, '\P{iscjkcompatibilityideographs}', "");
Expect(0, 64256, '\P{^iscjkcompatibilityideographs}', "");
Expect(1, 64255, '\p{_ Is_CJK_compatibility_Ideographs}', "");
Expect(0, 64255, '\p{^_ Is_CJK_compatibility_Ideographs}', "");
Expect(0, 64255, '\P{_ Is_CJK_compatibility_Ideographs}', "");
Expect(1, 64255, '\P{^_ Is_CJK_compatibility_Ideographs}', "");
Expect(0, 64256, '\p{_ Is_CJK_compatibility_Ideographs}', "");
Expect(1, 64256, '\p{^_ Is_CJK_compatibility_Ideographs}', "");
Expect(1, 64256, '\P{_ Is_CJK_compatibility_Ideographs}', "");
Expect(0, 64256, '\P{^_ Is_CJK_compatibility_Ideographs}', "");
Error('\p{ In_CJK_Compatibility_Ideographs/a/}');
Error('\P{ In_CJK_Compatibility_Ideographs/a/}');
Expect(1, 64255, '\p{incjkcompatibilityideographs}', "");
Expect(0, 64255, '\p{^incjkcompatibilityideographs}', "");
Expect(0, 64255, '\P{incjkcompatibilityideographs}', "");
Expect(1, 64255, '\P{^incjkcompatibilityideographs}', "");
Expect(0, 64256, '\p{incjkcompatibilityideographs}', "");
Expect(1, 64256, '\p{^incjkcompatibilityideographs}', "");
Expect(1, 64256, '\P{incjkcompatibilityideographs}', "");
Expect(0, 64256, '\P{^incjkcompatibilityideographs}', "");
Expect(1, 64255, '\p{		In_CJK_compatibility_ideographs}', "");
Expect(0, 64255, '\p{^		In_CJK_compatibility_ideographs}', "");
Expect(0, 64255, '\P{		In_CJK_compatibility_ideographs}', "");
Expect(1, 64255, '\P{^		In_CJK_compatibility_ideographs}', "");
Expect(0, 64256, '\p{		In_CJK_compatibility_ideographs}', "");
Expect(1, 64256, '\p{^		In_CJK_compatibility_ideographs}', "");
Expect(1, 64256, '\P{		In_CJK_compatibility_ideographs}', "");
Expect(0, 64256, '\P{^		In_CJK_compatibility_ideographs}', "");
Error('\p{:=  CJK_Compat_IDEOGRAPHS}');
Error('\P{:=  CJK_Compat_IDEOGRAPHS}');
Expect(1, 64255, '\p{cjkcompatideographs}', "");
Expect(0, 64255, '\p{^cjkcompatideographs}', "");
Expect(0, 64255, '\P{cjkcompatideographs}', "");
Expect(1, 64255, '\P{^cjkcompatideographs}', "");
Expect(0, 64256, '\p{cjkcompatideographs}', "");
Expect(1, 64256, '\p{^cjkcompatideographs}', "");
Expect(1, 64256, '\P{cjkcompatideographs}', "");
Expect(0, 64256, '\P{^cjkcompatideographs}', "");
Expect(1, 64255, '\p{-CJK_COMPAT_IDEOGRAPHS}', "");
Expect(0, 64255, '\p{^-CJK_COMPAT_IDEOGRAPHS}', "");
Expect(0, 64255, '\P{-CJK_COMPAT_IDEOGRAPHS}', "");
Expect(1, 64255, '\P{^-CJK_COMPAT_IDEOGRAPHS}', "");
Expect(0, 64256, '\p{-CJK_COMPAT_IDEOGRAPHS}', "");
Expect(1, 64256, '\p{^-CJK_COMPAT_IDEOGRAPHS}', "");
Expect(1, 64256, '\P{-CJK_COMPAT_IDEOGRAPHS}', "");
Expect(0, 64256, '\P{^-CJK_COMPAT_IDEOGRAPHS}', "");
Error('\p{_ Is_cjk_Compat_Ideographs:=}');
Error('\P{_ Is_cjk_Compat_Ideographs:=}');
Expect(1, 64255, '\p{iscjkcompatideographs}', "");
Expect(0, 64255, '\p{^iscjkcompatideographs}', "");
Expect(0, 64255, '\P{iscjkcompatideographs}', "");
Expect(1, 64255, '\P{^iscjkcompatideographs}', "");
Expect(0, 64256, '\p{iscjkcompatideographs}', "");
Expect(1, 64256, '\p{^iscjkcompatideographs}', "");
Expect(1, 64256, '\P{iscjkcompatideographs}', "");
Expect(0, 64256, '\P{^iscjkcompatideographs}', "");
Expect(1, 64255, '\p{	_IS_CJK_Compat_IDEOGRAPHS}', "");
Expect(0, 64255, '\p{^	_IS_CJK_Compat_IDEOGRAPHS}', "");
Expect(0, 64255, '\P{	_IS_CJK_Compat_IDEOGRAPHS}', "");
Expect(1, 64255, '\P{^	_IS_CJK_Compat_IDEOGRAPHS}', "");
Expect(0, 64256, '\p{	_IS_CJK_Compat_IDEOGRAPHS}', "");
Expect(1, 64256, '\p{^	_IS_CJK_Compat_IDEOGRAPHS}', "");
Expect(1, 64256, '\P{	_IS_CJK_Compat_IDEOGRAPHS}', "");
Expect(0, 64256, '\P{^	_IS_CJK_Compat_IDEOGRAPHS}', "");
Error('\p{-/a/IN_cjk_Compat_ideographs}');
Error('\P{-/a/IN_cjk_Compat_ideographs}');
Expect(1, 64255, '\p{incjkcompatideographs}', "");
Expect(0, 64255, '\p{^incjkcompatideographs}', "");
Expect(0, 64255, '\P{incjkcompatideographs}', "");
Expect(1, 64255, '\P{^incjkcompatideographs}', "");
Expect(0, 64256, '\p{incjkcompatideographs}', "");
Expect(1, 64256, '\p{^incjkcompatideographs}', "");
Expect(1, 64256, '\P{incjkcompatideographs}', "");
Expect(0, 64256, '\P{^incjkcompatideographs}', "");
Expect(1, 64255, '\p{_ In_cjk_compat_Ideographs}', "");
Expect(0, 64255, '\p{^_ In_cjk_compat_Ideographs}', "");
Expect(0, 64255, '\P{_ In_cjk_compat_Ideographs}', "");
Expect(1, 64255, '\P{^_ In_cjk_compat_Ideographs}', "");
Expect(0, 64256, '\p{_ In_cjk_compat_Ideographs}', "");
Expect(1, 64256, '\p{^_ In_cjk_compat_Ideographs}', "");
Expect(1, 64256, '\P{_ In_cjk_compat_Ideographs}', "");
Expect(0, 64256, '\P{^_ In_cjk_compat_Ideographs}', "");
Error('\p{--cjk_COMPATIBILITY_Ideographs_supplement/a/}');
Error('\P{--cjk_COMPATIBILITY_Ideographs_supplement/a/}');
Expect(1, 195103, '\p{cjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\p{^cjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\P{cjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\P{^cjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\p{cjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\p{^cjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\P{cjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\P{^cjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\p{-_CJK_Compatibility_Ideographs_Supplement}', "");
Expect(0, 195103, '\p{^-_CJK_Compatibility_Ideographs_Supplement}', "");
Expect(0, 195103, '\P{-_CJK_Compatibility_Ideographs_Supplement}', "");
Expect(1, 195103, '\P{^-_CJK_Compatibility_Ideographs_Supplement}', "");
Expect(0, 195104, '\p{-_CJK_Compatibility_Ideographs_Supplement}', "");
Expect(1, 195104, '\p{^-_CJK_Compatibility_Ideographs_Supplement}', "");
Expect(1, 195104, '\P{-_CJK_Compatibility_Ideographs_Supplement}', "");
Expect(0, 195104, '\P{^-_CJK_Compatibility_Ideographs_Supplement}', "");
Error('\p{  IS_cjk_Compatibility_ideographs_Supplement:=}');
Error('\P{  IS_cjk_Compatibility_ideographs_Supplement:=}');
Expect(1, 195103, '\p{iscjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\p{^iscjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\P{iscjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\P{^iscjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\p{iscjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\p{^iscjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\P{iscjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\P{^iscjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\p{	 IS_CJK_Compatibility_ideographs_Supplement}', "");
Expect(0, 195103, '\p{^	 IS_CJK_Compatibility_ideographs_Supplement}', "");
Expect(0, 195103, '\P{	 IS_CJK_Compatibility_ideographs_Supplement}', "");
Expect(1, 195103, '\P{^	 IS_CJK_Compatibility_ideographs_Supplement}', "");
Expect(0, 195104, '\p{	 IS_CJK_Compatibility_ideographs_Supplement}', "");
Expect(1, 195104, '\p{^	 IS_CJK_Compatibility_ideographs_Supplement}', "");
Expect(1, 195104, '\P{	 IS_CJK_Compatibility_ideographs_Supplement}', "");
Expect(0, 195104, '\P{^	 IS_CJK_Compatibility_ideographs_Supplement}', "");
Error('\p{_:=in_CJK_Compatibility_IDEOGRAPHS_Supplement}');
Error('\P{_:=in_CJK_Compatibility_IDEOGRAPHS_Supplement}');
Expect(1, 195103, '\p{incjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\p{^incjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\P{incjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\P{^incjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\p{incjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\p{^incjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\P{incjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\P{^incjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\p{ 	In_CJK_Compatibility_Ideographs_Supplement}', "");
Expect(0, 195103, '\p{^ 	In_CJK_Compatibility_Ideographs_Supplement}', "");
Expect(0, 195103, '\P{ 	In_CJK_Compatibility_Ideographs_Supplement}', "");
Expect(1, 195103, '\P{^ 	In_CJK_Compatibility_Ideographs_Supplement}', "");
Expect(0, 195104, '\p{ 	In_CJK_Compatibility_Ideographs_Supplement}', "");
Expect(1, 195104, '\p{^ 	In_CJK_Compatibility_Ideographs_Supplement}', "");
Expect(1, 195104, '\P{ 	In_CJK_Compatibility_Ideographs_Supplement}', "");
Expect(0, 195104, '\P{^ 	In_CJK_Compatibility_Ideographs_Supplement}', "");
Error('\p{/a/CJK_compat_ideographs_SUP}');
Error('\P{/a/CJK_compat_ideographs_SUP}');
Expect(1, 195103, '\p{cjkcompatideographssup}', "");
Expect(0, 195103, '\p{^cjkcompatideographssup}', "");
Expect(0, 195103, '\P{cjkcompatideographssup}', "");
Expect(1, 195103, '\P{^cjkcompatideographssup}', "");
Expect(0, 195104, '\p{cjkcompatideographssup}', "");
Expect(1, 195104, '\p{^cjkcompatideographssup}', "");
Expect(1, 195104, '\P{cjkcompatideographssup}', "");
Expect(0, 195104, '\P{^cjkcompatideographssup}', "");
Expect(1, 195103, '\p{CJK_Compat_IDEOGRAPHS_Sup}', "");
Expect(0, 195103, '\p{^CJK_Compat_IDEOGRAPHS_Sup}', "");
Expect(0, 195103, '\P{CJK_Compat_IDEOGRAPHS_Sup}', "");
Expect(1, 195103, '\P{^CJK_Compat_IDEOGRAPHS_Sup}', "");
Expect(0, 195104, '\p{CJK_Compat_IDEOGRAPHS_Sup}', "");
Expect(1, 195104, '\p{^CJK_Compat_IDEOGRAPHS_Sup}', "");
Expect(1, 195104, '\P{CJK_Compat_IDEOGRAPHS_Sup}', "");
Expect(0, 195104, '\P{^CJK_Compat_IDEOGRAPHS_Sup}', "");
Error('\p{:=	Is_CJK_Compat_Ideographs_Sup}');
Error('\P{:=	Is_CJK_Compat_Ideographs_Sup}');
Expect(1, 195103, '\p{iscjkcompatideographssup}', "");
Expect(0, 195103, '\p{^iscjkcompatideographssup}', "");
Expect(0, 195103, '\P{iscjkcompatideographssup}', "");
Expect(1, 195103, '\P{^iscjkcompatideographssup}', "");
Expect(0, 195104, '\p{iscjkcompatideographssup}', "");
Expect(1, 195104, '\p{^iscjkcompatideographssup}', "");
Expect(1, 195104, '\P{iscjkcompatideographssup}', "");
Expect(0, 195104, '\P{^iscjkcompatideographssup}', "");
Expect(1, 195103, '\p{-_Is_cjk_Compat_IDEOGRAPHS_Sup}', "");
Expect(0, 195103, '\p{^-_Is_cjk_Compat_IDEOGRAPHS_Sup}', "");
Expect(0, 195103, '\P{-_Is_cjk_Compat_IDEOGRAPHS_Sup}', "");
Expect(1, 195103, '\P{^-_Is_cjk_Compat_IDEOGRAPHS_Sup}', "");
Expect(0, 195104, '\p{-_Is_cjk_Compat_IDEOGRAPHS_Sup}', "");
Expect(1, 195104, '\p{^-_Is_cjk_Compat_IDEOGRAPHS_Sup}', "");
Expect(1, 195104, '\P{-_Is_cjk_Compat_IDEOGRAPHS_Sup}', "");
Expect(0, 195104, '\P{^-_Is_cjk_Compat_IDEOGRAPHS_Sup}', "");
Error('\p{/a/_ IN_CJK_COMPAT_Ideographs_Sup}');
Error('\P{/a/_ IN_CJK_COMPAT_Ideographs_Sup}');
Expect(1, 195103, '\p{incjkcompatideographssup}', "");
Expect(0, 195103, '\p{^incjkcompatideographssup}', "");
Expect(0, 195103, '\P{incjkcompatideographssup}', "");
Expect(1, 195103, '\P{^incjkcompatideographssup}', "");
Expect(0, 195104, '\p{incjkcompatideographssup}', "");
Expect(1, 195104, '\p{^incjkcompatideographssup}', "");
Expect(1, 195104, '\P{incjkcompatideographssup}', "");
Expect(0, 195104, '\P{^incjkcompatideographssup}', "");
Expect(1, 195103, '\p{ 	In_CJK_Compat_ideographs_sup}', "");
Expect(0, 195103, '\p{^ 	In_CJK_Compat_ideographs_sup}', "");
Expect(0, 195103, '\P{ 	In_CJK_Compat_ideographs_sup}', "");
Expect(1, 195103, '\P{^ 	In_CJK_Compat_ideographs_sup}', "");
Expect(0, 195104, '\p{ 	In_CJK_Compat_ideographs_sup}', "");
Expect(1, 195104, '\p{^ 	In_CJK_Compat_ideographs_sup}', "");
Expect(1, 195104, '\P{ 	In_CJK_Compat_ideographs_sup}', "");
Expect(0, 195104, '\P{^ 	In_CJK_Compat_ideographs_sup}', "");
Error('\p{	:=CJK_RADICALS_SUPPLEMENT}');
Error('\P{	:=CJK_RADICALS_SUPPLEMENT}');
Expect(1, 12031, '\p{cjkradicalssupplement}', "");
Expect(0, 12031, '\p{^cjkradicalssupplement}', "");
Expect(0, 12031, '\P{cjkradicalssupplement}', "");
Expect(1, 12031, '\P{^cjkradicalssupplement}', "");
Expect(0, 12032, '\p{cjkradicalssupplement}', "");
Expect(1, 12032, '\p{^cjkradicalssupplement}', "");
Expect(1, 12032, '\P{cjkradicalssupplement}', "");
Expect(0, 12032, '\P{^cjkradicalssupplement}', "");
Expect(1, 12031, '\p{_CJK_radicals_Supplement}', "");
Expect(0, 12031, '\p{^_CJK_radicals_Supplement}', "");
Expect(0, 12031, '\P{_CJK_radicals_Supplement}', "");
Expect(1, 12031, '\P{^_CJK_radicals_Supplement}', "");
Expect(0, 12032, '\p{_CJK_radicals_Supplement}', "");
Expect(1, 12032, '\p{^_CJK_radicals_Supplement}', "");
Expect(1, 12032, '\P{_CJK_radicals_Supplement}', "");
Expect(0, 12032, '\P{^_CJK_radicals_Supplement}', "");
Error('\p{/a/ _IS_CJK_Radicals_Supplement}');
Error('\P{/a/ _IS_CJK_Radicals_Supplement}');
Expect(1, 12031, '\p{iscjkradicalssupplement}', "");
Expect(0, 12031, '\p{^iscjkradicalssupplement}', "");
Expect(0, 12031, '\P{iscjkradicalssupplement}', "");
Expect(1, 12031, '\P{^iscjkradicalssupplement}', "");
Expect(0, 12032, '\p{iscjkradicalssupplement}', "");
Expect(1, 12032, '\p{^iscjkradicalssupplement}', "");
Expect(1, 12032, '\P{iscjkradicalssupplement}', "");
Expect(0, 12032, '\P{^iscjkradicalssupplement}', "");
Expect(1, 12031, '\p{_	Is_cjk_Radicals_supplement}', "");
Expect(0, 12031, '\p{^_	Is_cjk_Radicals_supplement}', "");
Expect(0, 12031, '\P{_	Is_cjk_Radicals_supplement}', "");
Expect(1, 12031, '\P{^_	Is_cjk_Radicals_supplement}', "");
Expect(0, 12032, '\p{_	Is_cjk_Radicals_supplement}', "");
Expect(1, 12032, '\p{^_	Is_cjk_Radicals_supplement}', "");
Expect(1, 12032, '\P{_	Is_cjk_Radicals_supplement}', "");
Expect(0, 12032, '\P{^_	Is_cjk_Radicals_supplement}', "");
Error('\p{		In_CJK_radicals_Supplement/a/}');
Error('\P{		In_CJK_radicals_Supplement/a/}');
Expect(1, 12031, '\p{incjkradicalssupplement}', "");
Expect(0, 12031, '\p{^incjkradicalssupplement}', "");
Expect(0, 12031, '\P{incjkradicalssupplement}', "");
Expect(1, 12031, '\P{^incjkradicalssupplement}', "");
Expect(0, 12032, '\p{incjkradicalssupplement}', "");
Expect(1, 12032, '\p{^incjkradicalssupplement}', "");
Expect(1, 12032, '\P{incjkradicalssupplement}', "");
Expect(0, 12032, '\P{^incjkradicalssupplement}', "");
Expect(1, 12031, '\p{-in_cjk_Radicals_SUPPLEMENT}', "");
Expect(0, 12031, '\p{^-in_cjk_Radicals_SUPPLEMENT}', "");
Expect(0, 12031, '\P{-in_cjk_Radicals_SUPPLEMENT}', "");
Expect(1, 12031, '\P{^-in_cjk_Radicals_SUPPLEMENT}', "");
Expect(0, 12032, '\p{-in_cjk_Radicals_SUPPLEMENT}', "");
Expect(1, 12032, '\p{^-in_cjk_Radicals_SUPPLEMENT}', "");
Expect(1, 12032, '\P{-in_cjk_Radicals_SUPPLEMENT}', "");
Expect(0, 12032, '\P{^-in_cjk_Radicals_SUPPLEMENT}', "");
Error('\p{__cjk_Radicals_Sup:=}');
Error('\P{__cjk_Radicals_Sup:=}');
Expect(1, 12031, '\p{cjkradicalssup}', "");
Expect(0, 12031, '\p{^cjkradicalssup}', "");
Expect(0, 12031, '\P{cjkradicalssup}', "");
Expect(1, 12031, '\P{^cjkradicalssup}', "");
Expect(0, 12032, '\p{cjkradicalssup}', "");
Expect(1, 12032, '\p{^cjkradicalssup}', "");
Expect(1, 12032, '\P{cjkradicalssup}', "");
Expect(0, 12032, '\P{^cjkradicalssup}', "");
Expect(1, 12031, '\p{_	CJK_Radicals_Sup}', "");
Expect(0, 12031, '\p{^_	CJK_Radicals_Sup}', "");
Expect(0, 12031, '\P{_	CJK_Radicals_Sup}', "");
Expect(1, 12031, '\P{^_	CJK_Radicals_Sup}', "");
Expect(0, 12032, '\p{_	CJK_Radicals_Sup}', "");
Expect(1, 12032, '\p{^_	CJK_Radicals_Sup}', "");
Expect(1, 12032, '\P{_	CJK_Radicals_Sup}', "");
Expect(0, 12032, '\P{^_	CJK_Radicals_Sup}', "");
Error('\p{/a/Is_CJK_Radicals_Sup}');
Error('\P{/a/Is_CJK_Radicals_Sup}');
Expect(1, 12031, '\p{iscjkradicalssup}', "");
Expect(0, 12031, '\p{^iscjkradicalssup}', "");
Expect(0, 12031, '\P{iscjkradicalssup}', "");
Expect(1, 12031, '\P{^iscjkradicalssup}', "");
Expect(0, 12032, '\p{iscjkradicalssup}', "");
Expect(1, 12032, '\p{^iscjkradicalssup}', "");
Expect(1, 12032, '\P{iscjkradicalssup}', "");
Expect(0, 12032, '\P{^iscjkradicalssup}', "");
Expect(1, 12031, '\p{- Is_cjk_radicals_SUP}', "");
Expect(0, 12031, '\p{^- Is_cjk_radicals_SUP}', "");
Expect(0, 12031, '\P{- Is_cjk_radicals_SUP}', "");
Expect(1, 12031, '\P{^- Is_cjk_radicals_SUP}', "");
Expect(0, 12032, '\p{- Is_cjk_radicals_SUP}', "");
Expect(1, 12032, '\p{^- Is_cjk_radicals_SUP}', "");
Expect(1, 12032, '\P{- Is_cjk_radicals_SUP}', "");
Expect(0, 12032, '\P{^- Is_cjk_radicals_SUP}', "");
Error('\p{:= _IN_CJK_radicals_SUP}');
Error('\P{:= _IN_CJK_radicals_SUP}');
Expect(1, 12031, '\p{incjkradicalssup}', "");
Expect(0, 12031, '\p{^incjkradicalssup}', "");
Expect(0, 12031, '\P{incjkradicalssup}', "");
Expect(1, 12031, '\P{^incjkradicalssup}', "");
Expect(0, 12032, '\p{incjkradicalssup}', "");
Expect(1, 12032, '\p{^incjkradicalssup}', "");
Expect(1, 12032, '\P{incjkradicalssup}', "");
Expect(0, 12032, '\P{^incjkradicalssup}', "");
Expect(1, 12031, '\p{ 	In_CJK_radicals_sup}', "");
Expect(0, 12031, '\p{^ 	In_CJK_radicals_sup}', "");
Expect(0, 12031, '\P{ 	In_CJK_radicals_sup}', "");
Expect(1, 12031, '\P{^ 	In_CJK_radicals_sup}', "");
Expect(0, 12032, '\p{ 	In_CJK_radicals_sup}', "");
Expect(1, 12032, '\p{^ 	In_CJK_radicals_sup}', "");
Expect(1, 12032, '\P{ 	In_CJK_radicals_sup}', "");
Expect(0, 12032, '\P{^ 	In_CJK_radicals_sup}', "");
Error('\p{_/a/CJK_STROKES}');
Error('\P{_/a/CJK_STROKES}');
Expect(1, 12783, '\p{cjkstrokes}', "");
Expect(0, 12783, '\p{^cjkstrokes}', "");
Expect(0, 12783, '\P{cjkstrokes}', "");
Expect(1, 12783, '\P{^cjkstrokes}', "");
Expect(0, 12784, '\p{cjkstrokes}', "");
Expect(1, 12784, '\p{^cjkstrokes}', "");
Expect(1, 12784, '\P{cjkstrokes}', "");
Expect(0, 12784, '\P{^cjkstrokes}', "");
Expect(1, 12783, '\p{ CJK_STROKES}', "");
Expect(0, 12783, '\p{^ CJK_STROKES}', "");
Expect(0, 12783, '\P{ CJK_STROKES}', "");
Expect(1, 12783, '\P{^ CJK_STROKES}', "");
Expect(0, 12784, '\p{ CJK_STROKES}', "");
Expect(1, 12784, '\p{^ CJK_STROKES}', "");
Expect(1, 12784, '\P{ CJK_STROKES}', "");
Expect(0, 12784, '\P{^ CJK_STROKES}', "");
Error('\p{	/a/Is_CJK_Strokes}');
Error('\P{	/a/Is_CJK_Strokes}');
Expect(1, 12783, '\p{iscjkstrokes}', "");
Expect(0, 12783, '\p{^iscjkstrokes}', "");
Expect(0, 12783, '\P{iscjkstrokes}', "");
Expect(1, 12783, '\P{^iscjkstrokes}', "");
Expect(0, 12784, '\p{iscjkstrokes}', "");
Expect(1, 12784, '\p{^iscjkstrokes}', "");
Expect(1, 12784, '\P{iscjkstrokes}', "");
Expect(0, 12784, '\P{^iscjkstrokes}', "");
Expect(1, 12783, '\p{	-Is_cjk_Strokes}', "");
Expect(0, 12783, '\p{^	-Is_cjk_Strokes}', "");
Expect(0, 12783, '\P{	-Is_cjk_Strokes}', "");
Expect(1, 12783, '\P{^	-Is_cjk_Strokes}', "");
Expect(0, 12784, '\p{	-Is_cjk_Strokes}', "");
Expect(1, 12784, '\p{^	-Is_cjk_Strokes}', "");
Expect(1, 12784, '\P{	-Is_cjk_Strokes}', "");
Expect(0, 12784, '\P{^	-Is_cjk_Strokes}', "");
Error('\p{	_In_CJK_STROKES/a/}');
Error('\P{	_In_CJK_STROKES/a/}');
Expect(1, 12783, '\p{incjkstrokes}', "");
Expect(0, 12783, '\p{^incjkstrokes}', "");
Expect(0, 12783, '\P{incjkstrokes}', "");
Expect(1, 12783, '\P{^incjkstrokes}', "");
Expect(0, 12784, '\p{incjkstrokes}', "");
Expect(1, 12784, '\p{^incjkstrokes}', "");
Expect(1, 12784, '\P{incjkstrokes}', "");
Expect(0, 12784, '\P{^incjkstrokes}', "");
Expect(1, 12783, '\p{_-IN_CJK_Strokes}', "");
Expect(0, 12783, '\p{^_-IN_CJK_Strokes}', "");
Expect(0, 12783, '\P{_-IN_CJK_Strokes}', "");
Expect(1, 12783, '\P{^_-IN_CJK_Strokes}', "");
Expect(0, 12784, '\p{_-IN_CJK_Strokes}', "");
Expect(1, 12784, '\p{^_-IN_CJK_Strokes}', "");
Expect(1, 12784, '\P{_-IN_CJK_Strokes}', "");
Expect(0, 12784, '\P{^_-IN_CJK_Strokes}', "");
Error('\p{CJK_symbols_and_punctuation:=}');
Error('\P{CJK_symbols_and_punctuation:=}');
Expect(1, 12351, '\p{cjksymbolsandpunctuation}', "");
Expect(0, 12351, '\p{^cjksymbolsandpunctuation}', "");
Expect(0, 12351, '\P{cjksymbolsandpunctuation}', "");
Expect(1, 12351, '\P{^cjksymbolsandpunctuation}', "");
Expect(0, 12352, '\p{cjksymbolsandpunctuation}', "");
Expect(1, 12352, '\p{^cjksymbolsandpunctuation}', "");
Expect(1, 12352, '\P{cjksymbolsandpunctuation}', "");
Expect(0, 12352, '\P{^cjksymbolsandpunctuation}', "");
Expect(1, 12351, '\p{ -cjk_SYMBOLS_AND_PUNCTUATION}', "");
Expect(0, 12351, '\p{^ -cjk_SYMBOLS_AND_PUNCTUATION}', "");
Expect(0, 12351, '\P{ -cjk_SYMBOLS_AND_PUNCTUATION}', "");
Expect(1, 12351, '\P{^ -cjk_SYMBOLS_AND_PUNCTUATION}', "");
Expect(0, 12352, '\p{ -cjk_SYMBOLS_AND_PUNCTUATION}', "");
Expect(1, 12352, '\p{^ -cjk_SYMBOLS_AND_PUNCTUATION}', "");
Expect(1, 12352, '\P{ -cjk_SYMBOLS_AND_PUNCTUATION}', "");
Expect(0, 12352, '\P{^ -cjk_SYMBOLS_AND_PUNCTUATION}', "");
Error('\p{-_Is_cjk_Symbols_And_punctuation:=}');
Error('\P{-_Is_cjk_Symbols_And_punctuation:=}');
Expect(1, 12351, '\p{iscjksymbolsandpunctuation}', "");
Expect(0, 12351, '\p{^iscjksymbolsandpunctuation}', "");
Expect(0, 12351, '\P{iscjksymbolsandpunctuation}', "");
Expect(1, 12351, '\P{^iscjksymbolsandpunctuation}', "");
Expect(0, 12352, '\p{iscjksymbolsandpunctuation}', "");
Expect(1, 12352, '\p{^iscjksymbolsandpunctuation}', "");
Expect(1, 12352, '\P{iscjksymbolsandpunctuation}', "");
Expect(0, 12352, '\P{^iscjksymbolsandpunctuation}', "");
Expect(1, 12351, '\p{ _Is_cjk_Symbols_And_punctuation}', "");
Expect(0, 12351, '\p{^ _Is_cjk_Symbols_And_punctuation}', "");
Expect(0, 12351, '\P{ _Is_cjk_Symbols_And_punctuation}', "");
Expect(1, 12351, '\P{^ _Is_cjk_Symbols_And_punctuation}', "");
Expect(0, 12352, '\p{ _Is_cjk_Symbols_And_punctuation}', "");
Expect(1, 12352, '\p{^ _Is_cjk_Symbols_And_punctuation}', "");
Expect(1, 12352, '\P{ _Is_cjk_Symbols_And_punctuation}', "");
Expect(0, 12352, '\P{^ _Is_cjk_Symbols_And_punctuation}', "");
Error('\p{ :=In_CJK_Symbols_And_Punctuation}');
Error('\P{ :=In_CJK_Symbols_And_Punctuation}');
Expect(1, 12351, '\p{incjksymbolsandpunctuation}', "");
Expect(0, 12351, '\p{^incjksymbolsandpunctuation}', "");
Expect(0, 12351, '\P{incjksymbolsandpunctuation}', "");
Expect(1, 12351, '\P{^incjksymbolsandpunctuation}', "");
Expect(0, 12352, '\p{incjksymbolsandpunctuation}', "");
Expect(1, 12352, '\p{^incjksymbolsandpunctuation}', "");
Expect(1, 12352, '\P{incjksymbolsandpunctuation}', "");
Expect(0, 12352, '\P{^incjksymbolsandpunctuation}', "");
Expect(1, 12351, '\p{	In_CJK_Symbols_and_Punctuation}', "");
Expect(0, 12351, '\p{^	In_CJK_Symbols_and_Punctuation}', "");
Expect(0, 12351, '\P{	In_CJK_Symbols_and_Punctuation}', "");
Expect(1, 12351, '\P{^	In_CJK_Symbols_and_Punctuation}', "");
Expect(0, 12352, '\p{	In_CJK_Symbols_and_Punctuation}', "");
Expect(1, 12352, '\p{^	In_CJK_Symbols_and_Punctuation}', "");
Expect(1, 12352, '\P{	In_CJK_Symbols_and_Punctuation}', "");
Expect(0, 12352, '\P{^	In_CJK_Symbols_and_Punctuation}', "");
Error('\p{:=  cjk_Symbols}');
Error('\P{:=  cjk_Symbols}');
Expect(1, 12351, '\p{cjksymbols}', "");
Expect(0, 12351, '\p{^cjksymbols}', "");
Expect(0, 12351, '\P{cjksymbols}', "");
Expect(1, 12351, '\P{^cjksymbols}', "");
Expect(0, 12352, '\p{cjksymbols}', "");
Expect(1, 12352, '\p{^cjksymbols}', "");
Expect(1, 12352, '\P{cjksymbols}', "");
Expect(0, 12352, '\P{^cjksymbols}', "");
Expect(1, 12351, '\p{	 CJK_SYMBOLS}', "");
Expect(0, 12351, '\p{^	 CJK_SYMBOLS}', "");
Expect(0, 12351, '\P{	 CJK_SYMBOLS}', "");
Expect(1, 12351, '\P{^	 CJK_SYMBOLS}', "");
Expect(0, 12352, '\p{	 CJK_SYMBOLS}', "");
Expect(1, 12352, '\p{^	 CJK_SYMBOLS}', "");
Expect(1, 12352, '\P{	 CJK_SYMBOLS}', "");
Expect(0, 12352, '\P{^	 CJK_SYMBOLS}', "");
Error('\p{/a/ Is_CJK_symbols}');
Error('\P{/a/ Is_CJK_symbols}');
Expect(1, 12351, '\p{iscjksymbols}', "");
Expect(0, 12351, '\p{^iscjksymbols}', "");
Expect(0, 12351, '\P{iscjksymbols}', "");
Expect(1, 12351, '\P{^iscjksymbols}', "");
Expect(0, 12352, '\p{iscjksymbols}', "");
Expect(1, 12352, '\p{^iscjksymbols}', "");
Expect(1, 12352, '\P{iscjksymbols}', "");
Expect(0, 12352, '\P{^iscjksymbols}', "");
Expect(1, 12351, '\p{	-IS_CJK_Symbols}', "");
Expect(0, 12351, '\p{^	-IS_CJK_Symbols}', "");
Expect(0, 12351, '\P{	-IS_CJK_Symbols}', "");
Expect(1, 12351, '\P{^	-IS_CJK_Symbols}', "");
Expect(0, 12352, '\p{	-IS_CJK_Symbols}', "");
Expect(1, 12352, '\p{^	-IS_CJK_Symbols}', "");
Expect(1, 12352, '\P{	-IS_CJK_Symbols}', "");
Expect(0, 12352, '\P{^	-IS_CJK_Symbols}', "");
Error('\p{_IN_CJK_Symbols/a/}');
Error('\P{_IN_CJK_Symbols/a/}');
Expect(1, 12351, '\p{incjksymbols}', "");
Expect(0, 12351, '\p{^incjksymbols}', "");
Expect(0, 12351, '\P{incjksymbols}', "");
Expect(1, 12351, '\P{^incjksymbols}', "");
Expect(0, 12352, '\p{incjksymbols}', "");
Expect(1, 12352, '\p{^incjksymbols}', "");
Expect(1, 12352, '\P{incjksymbols}', "");
Expect(0, 12352, '\P{^incjksymbols}', "");
Expect(1, 12351, '\p{_ in_CJK_symbols}', "");
Expect(0, 12351, '\p{^_ in_CJK_symbols}', "");
Expect(0, 12351, '\P{_ in_CJK_symbols}', "");
Expect(1, 12351, '\P{^_ in_CJK_symbols}', "");
Expect(0, 12352, '\p{_ in_CJK_symbols}', "");
Expect(1, 12352, '\p{^_ in_CJK_symbols}', "");
Expect(1, 12352, '\P{_ in_CJK_symbols}', "");
Expect(0, 12352, '\P{^_ in_CJK_symbols}', "");
Error('\p{ /a/CJK_UNIFIED_Ideographs}');
Error('\P{ /a/CJK_UNIFIED_Ideographs}');
Expect(1, 40959, '\p{cjkunifiedideographs}', "");
Expect(0, 40959, '\p{^cjkunifiedideographs}', "");
Expect(0, 40959, '\P{cjkunifiedideographs}', "");
Expect(1, 40959, '\P{^cjkunifiedideographs}', "");
Expect(0, 40960, '\p{cjkunifiedideographs}', "");
Expect(1, 40960, '\p{^cjkunifiedideographs}', "");
Expect(1, 40960, '\P{cjkunifiedideographs}', "");
Expect(0, 40960, '\P{^cjkunifiedideographs}', "");
Expect(1, 40959, '\p{__CJK_unified_Ideographs}', "");
Expect(0, 40959, '\p{^__CJK_unified_Ideographs}', "");
Expect(0, 40959, '\P{__CJK_unified_Ideographs}', "");
Expect(1, 40959, '\P{^__CJK_unified_Ideographs}', "");
Expect(0, 40960, '\p{__CJK_unified_Ideographs}', "");
Expect(1, 40960, '\p{^__CJK_unified_Ideographs}', "");
Expect(1, 40960, '\P{__CJK_unified_Ideographs}', "");
Expect(0, 40960, '\P{^__CJK_unified_Ideographs}', "");
Error('\p{--IS_CJK_UNIFIED_IDEOGRAPHS:=}');
Error('\P{--IS_CJK_UNIFIED_IDEOGRAPHS:=}');
Expect(1, 40959, '\p{iscjkunifiedideographs}', "");
Expect(0, 40959, '\p{^iscjkunifiedideographs}', "");
Expect(0, 40959, '\P{iscjkunifiedideographs}', "");
Expect(1, 40959, '\P{^iscjkunifiedideographs}', "");
Expect(0, 40960, '\p{iscjkunifiedideographs}', "");
Expect(1, 40960, '\p{^iscjkunifiedideographs}', "");
Expect(1, 40960, '\P{iscjkunifiedideographs}', "");
Expect(0, 40960, '\P{^iscjkunifiedideographs}', "");
Expect(1, 40959, '\p{ _is_CJK_Unified_Ideographs}', "");
Expect(0, 40959, '\p{^ _is_CJK_Unified_Ideographs}', "");
Expect(0, 40959, '\P{ _is_CJK_Unified_Ideographs}', "");
Expect(1, 40959, '\P{^ _is_CJK_Unified_Ideographs}', "");
Expect(0, 40960, '\p{ _is_CJK_Unified_Ideographs}', "");
Expect(1, 40960, '\p{^ _is_CJK_Unified_Ideographs}', "");
Expect(1, 40960, '\P{ _is_CJK_Unified_Ideographs}', "");
Expect(0, 40960, '\P{^ _is_CJK_Unified_Ideographs}', "");
Error('\p{	:=In_CJK_Unified_ideographs}');
Error('\P{	:=In_CJK_Unified_ideographs}');
Expect(1, 40959, '\p{incjkunifiedideographs}', "");
Expect(0, 40959, '\p{^incjkunifiedideographs}', "");
Expect(0, 40959, '\P{incjkunifiedideographs}', "");
Expect(1, 40959, '\P{^incjkunifiedideographs}', "");
Expect(0, 40960, '\p{incjkunifiedideographs}', "");
Expect(1, 40960, '\p{^incjkunifiedideographs}', "");
Expect(1, 40960, '\P{incjkunifiedideographs}', "");
Expect(0, 40960, '\P{^incjkunifiedideographs}', "");
Expect(1, 40959, '\p{--IN_CJK_Unified_Ideographs}', "");
Expect(0, 40959, '\p{^--IN_CJK_Unified_Ideographs}', "");
Expect(0, 40959, '\P{--IN_CJK_Unified_Ideographs}', "");
Expect(1, 40959, '\P{^--IN_CJK_Unified_Ideographs}', "");
Expect(0, 40960, '\p{--IN_CJK_Unified_Ideographs}', "");
Expect(1, 40960, '\p{^--IN_CJK_Unified_Ideographs}', "");
Expect(1, 40960, '\P{--IN_CJK_Unified_Ideographs}', "");
Expect(0, 40960, '\P{^--IN_CJK_Unified_Ideographs}', "");
Error('\p{:=_cjk}');
Error('\P{:=_cjk}');
Expect(1, 40959, '\p{cjk}', "");
Expect(0, 40959, '\p{^cjk}', "");
Expect(0, 40959, '\P{cjk}', "");
Expect(1, 40959, '\P{^cjk}', "");
Expect(0, 40960, '\p{cjk}', "");
Expect(1, 40960, '\p{^cjk}', "");
Expect(1, 40960, '\P{cjk}', "");
Expect(0, 40960, '\P{^cjk}', "");
Expect(1, 40959, '\p{	CJK}', "");
Expect(0, 40959, '\p{^	CJK}', "");
Expect(0, 40959, '\P{	CJK}', "");
Expect(1, 40959, '\P{^	CJK}', "");
Expect(0, 40960, '\p{	CJK}', "");
Expect(1, 40960, '\p{^	CJK}', "");
Expect(1, 40960, '\P{	CJK}', "");
Expect(0, 40960, '\P{^	CJK}', "");
Error('\p{:= 	IS_CJK}');
Error('\P{:= 	IS_CJK}');
Expect(1, 40959, '\p{iscjk}', "");
Expect(0, 40959, '\p{^iscjk}', "");
Expect(0, 40959, '\P{iscjk}', "");
Expect(1, 40959, '\P{^iscjk}', "");
Expect(0, 40960, '\p{iscjk}', "");
Expect(1, 40960, '\p{^iscjk}', "");
Expect(1, 40960, '\P{iscjk}', "");
Expect(0, 40960, '\P{^iscjk}', "");
Expect(1, 40959, '\p{ is_CJK}', "");
Expect(0, 40959, '\p{^ is_CJK}', "");
Expect(0, 40959, '\P{ is_CJK}', "");
Expect(1, 40959, '\P{^ is_CJK}', "");
Expect(0, 40960, '\p{ is_CJK}', "");
Expect(1, 40960, '\p{^ is_CJK}', "");
Expect(1, 40960, '\P{ is_CJK}', "");
Expect(0, 40960, '\P{^ is_CJK}', "");
Error('\p{		In_CJK/a/}');
Error('\P{		In_CJK/a/}');
Expect(1, 40959, '\p{incjk}', "");
Expect(0, 40959, '\p{^incjk}', "");
Expect(0, 40959, '\P{incjk}', "");
Expect(1, 40959, '\P{^incjk}', "");
Expect(0, 40960, '\p{incjk}', "");
Expect(1, 40960, '\p{^incjk}', "");
Expect(1, 40960, '\P{incjk}', "");
Expect(0, 40960, '\P{^incjk}', "");
Expect(1, 40959, '\p{	_IN_CJK}', "");
Expect(0, 40959, '\p{^	_IN_CJK}', "");
Expect(0, 40959, '\P{	_IN_CJK}', "");
Expect(1, 40959, '\P{^	_IN_CJK}', "");
Expect(0, 40960, '\p{	_IN_CJK}', "");
Expect(1, 40960, '\p{^	_IN_CJK}', "");
Expect(1, 40960, '\P{	_IN_CJK}', "");
Expect(0, 40960, '\P{^	_IN_CJK}', "");
Error('\p{	CJK_Unified_IDEOGRAPHS_extension_a:=}');
Error('\P{	CJK_Unified_IDEOGRAPHS_extension_a:=}');
Expect(1, 19903, '\p{cjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\p{^cjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\P{cjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\P{^cjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\p{cjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\p{^cjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\P{cjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\P{^cjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\p{_-CJK_unified_ideographs_Extension_A}', "");
Expect(0, 19903, '\p{^_-CJK_unified_ideographs_Extension_A}', "");
Expect(0, 19903, '\P{_-CJK_unified_ideographs_Extension_A}', "");
Expect(1, 19903, '\P{^_-CJK_unified_ideographs_Extension_A}', "");
Expect(0, 19904, '\p{_-CJK_unified_ideographs_Extension_A}', "");
Expect(1, 19904, '\p{^_-CJK_unified_ideographs_Extension_A}', "");
Expect(1, 19904, '\P{_-CJK_unified_ideographs_Extension_A}', "");
Expect(0, 19904, '\P{^_-CJK_unified_ideographs_Extension_A}', "");
Error('\p{:=	-Is_CJK_Unified_IDEOGRAPHS_EXTENSION_A}');
Error('\P{:=	-Is_CJK_Unified_IDEOGRAPHS_EXTENSION_A}');
Expect(1, 19903, '\p{iscjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\p{^iscjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\P{iscjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\P{^iscjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\p{iscjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\p{^iscjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\P{iscjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\P{^iscjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\p{ -Is_CJK_UNIFIED_Ideographs_EXTENSION_A}', "");
Expect(0, 19903, '\p{^ -Is_CJK_UNIFIED_Ideographs_EXTENSION_A}', "");
Expect(0, 19903, '\P{ -Is_CJK_UNIFIED_Ideographs_EXTENSION_A}', "");
Expect(1, 19903, '\P{^ -Is_CJK_UNIFIED_Ideographs_EXTENSION_A}', "");
Expect(0, 19904, '\p{ -Is_CJK_UNIFIED_Ideographs_EXTENSION_A}', "");
Expect(1, 19904, '\p{^ -Is_CJK_UNIFIED_Ideographs_EXTENSION_A}', "");
Expect(1, 19904, '\P{ -Is_CJK_UNIFIED_Ideographs_EXTENSION_A}', "");
Expect(0, 19904, '\P{^ -Is_CJK_UNIFIED_Ideographs_EXTENSION_A}', "");
Error('\p{/a/In_CJK_UNIFIED_Ideographs_EXTENSION_A}');
Error('\P{/a/In_CJK_UNIFIED_Ideographs_EXTENSION_A}');
Expect(1, 19903, '\p{incjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\p{^incjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\P{incjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\P{^incjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\p{incjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\p{^incjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\P{incjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\P{^incjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\p{- In_CJK_Unified_IDEOGRAPHS_Extension_A}', "");
Expect(0, 19903, '\p{^- In_CJK_Unified_IDEOGRAPHS_Extension_A}', "");
Expect(0, 19903, '\P{- In_CJK_Unified_IDEOGRAPHS_Extension_A}', "");
Expect(1, 19903, '\P{^- In_CJK_Unified_IDEOGRAPHS_Extension_A}', "");
Expect(0, 19904, '\p{- In_CJK_Unified_IDEOGRAPHS_Extension_A}', "");
Expect(1, 19904, '\p{^- In_CJK_Unified_IDEOGRAPHS_Extension_A}', "");
Expect(1, 19904, '\P{- In_CJK_Unified_IDEOGRAPHS_Extension_A}', "");
Expect(0, 19904, '\P{^- In_CJK_Unified_IDEOGRAPHS_Extension_A}', "");
Error('\p{/a/CJK_Ext_a}');
Error('\P{/a/CJK_Ext_a}');
Expect(1, 19903, '\p{cjkexta}', "");
Expect(0, 19903, '\p{^cjkexta}', "");
Expect(0, 19903, '\P{cjkexta}', "");
Expect(1, 19903, '\P{^cjkexta}', "");
Expect(0, 19904, '\p{cjkexta}', "");
Expect(1, 19904, '\p{^cjkexta}', "");
Expect(1, 19904, '\P{cjkexta}', "");
Expect(0, 19904, '\P{^cjkexta}', "");
Expect(1, 19903, '\p{-CJK_ext_A}', "");
Expect(0, 19903, '\p{^-CJK_ext_A}', "");
Expect(0, 19903, '\P{-CJK_ext_A}', "");
Expect(1, 19903, '\P{^-CJK_ext_A}', "");
Expect(0, 19904, '\p{-CJK_ext_A}', "");
Expect(1, 19904, '\p{^-CJK_ext_A}', "");
Expect(1, 19904, '\P{-CJK_ext_A}', "");
Expect(0, 19904, '\P{^-CJK_ext_A}', "");
Error('\p{ /a/Is_CJK_Ext_A}');
Error('\P{ /a/Is_CJK_Ext_A}');
Expect(1, 19903, '\p{iscjkexta}', "");
Expect(0, 19903, '\p{^iscjkexta}', "");
Expect(0, 19903, '\P{iscjkexta}', "");
Expect(1, 19903, '\P{^iscjkexta}', "");
Expect(0, 19904, '\p{iscjkexta}', "");
Expect(1, 19904, '\p{^iscjkexta}', "");
Expect(1, 19904, '\P{iscjkexta}', "");
Expect(0, 19904, '\P{^iscjkexta}', "");
Expect(1, 19903, '\p{	-Is_CJK_Ext_a}', "");
Expect(0, 19903, '\p{^	-Is_CJK_Ext_a}', "");
Expect(0, 19903, '\P{	-Is_CJK_Ext_a}', "");
Expect(1, 19903, '\P{^	-Is_CJK_Ext_a}', "");
Expect(0, 19904, '\p{	-Is_CJK_Ext_a}', "");
Expect(1, 19904, '\p{^	-Is_CJK_Ext_a}', "");
Expect(1, 19904, '\P{	-Is_CJK_Ext_a}', "");
Expect(0, 19904, '\P{^	-Is_CJK_Ext_a}', "");
Error('\p{-IN_CJK_Ext_A:=}');
Error('\P{-IN_CJK_Ext_A:=}');
Expect(1, 19903, '\p{incjkexta}', "");
Expect(0, 19903, '\p{^incjkexta}', "");
Expect(0, 19903, '\P{incjkexta}', "");
Expect(1, 19903, '\P{^incjkexta}', "");
Expect(0, 19904, '\p{incjkexta}', "");
Expect(1, 19904, '\p{^incjkexta}', "");
Expect(1, 19904, '\P{incjkexta}', "");
Expect(0, 19904, '\P{^incjkexta}', "");
Expect(1, 19903, '\p{_	in_cjk_Ext_A}', "");
Expect(0, 19903, '\p{^_	in_cjk_Ext_A}', "");
Expect(0, 19903, '\P{_	in_cjk_Ext_A}', "");
Expect(1, 19903, '\P{^_	in_cjk_Ext_A}', "");
Expect(0, 19904, '\p{_	in_cjk_Ext_A}', "");
Expect(1, 19904, '\p{^_	in_cjk_Ext_A}', "");
Expect(1, 19904, '\P{_	in_cjk_Ext_A}', "");
Expect(0, 19904, '\P{^_	in_cjk_Ext_A}', "");
Error('\p{ /a/cjk_UNIFIED_Ideographs_Extension_B}');
Error('\P{ /a/cjk_UNIFIED_Ideographs_Extension_B}');
Expect(1, 173791, '\p{cjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\p{^cjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\P{cjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\P{^cjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\p{cjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\p{^cjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\P{cjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\P{^cjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\p{CJK_unified_Ideographs_EXTENSION_B}', "");
Expect(0, 173791, '\p{^CJK_unified_Ideographs_EXTENSION_B}', "");
Expect(0, 173791, '\P{CJK_unified_Ideographs_EXTENSION_B}', "");
Expect(1, 173791, '\P{^CJK_unified_Ideographs_EXTENSION_B}', "");
Expect(0, 173792, '\p{CJK_unified_Ideographs_EXTENSION_B}', "");
Expect(1, 173792, '\p{^CJK_unified_Ideographs_EXTENSION_B}', "");
Expect(1, 173792, '\P{CJK_unified_Ideographs_EXTENSION_B}', "");
Expect(0, 173792, '\P{^CJK_unified_Ideographs_EXTENSION_B}', "");
Error('\p{:=-	Is_CJK_Unified_Ideographs_Extension_B}');
Error('\P{:=-	Is_CJK_Unified_Ideographs_Extension_B}');
Expect(1, 173791, '\p{iscjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\p{^iscjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\P{iscjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\P{^iscjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\p{iscjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\p{^iscjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\P{iscjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\P{^iscjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\p{	-is_CJK_Unified_ideographs_EXTENSION_B}', "");
Expect(0, 173791, '\p{^	-is_CJK_Unified_ideographs_EXTENSION_B}', "");
Expect(0, 173791, '\P{	-is_CJK_Unified_ideographs_EXTENSION_B}', "");
Expect(1, 173791, '\P{^	-is_CJK_Unified_ideographs_EXTENSION_B}', "");
Expect(0, 173792, '\p{	-is_CJK_Unified_ideographs_EXTENSION_B}', "");
Expect(1, 173792, '\p{^	-is_CJK_Unified_ideographs_EXTENSION_B}', "");
Expect(1, 173792, '\P{	-is_CJK_Unified_ideographs_EXTENSION_B}', "");
Expect(0, 173792, '\P{^	-is_CJK_Unified_ideographs_EXTENSION_B}', "");
Error('\p{/a/In_CJK_Unified_Ideographs_Extension_b}');
Error('\P{/a/In_CJK_Unified_Ideographs_Extension_b}');
Expect(1, 173791, '\p{incjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\p{^incjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\P{incjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\P{^incjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\p{incjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\p{^incjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\P{incjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\P{^incjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\p{_	In_cjk_Unified_Ideographs_Extension_b}', "");
Expect(0, 173791, '\p{^_	In_cjk_Unified_Ideographs_Extension_b}', "");
Expect(0, 173791, '\P{_	In_cjk_Unified_Ideographs_Extension_b}', "");
Expect(1, 173791, '\P{^_	In_cjk_Unified_Ideographs_Extension_b}', "");
Expect(0, 173792, '\p{_	In_cjk_Unified_Ideographs_Extension_b}', "");
Expect(1, 173792, '\p{^_	In_cjk_Unified_Ideographs_Extension_b}', "");
Expect(1, 173792, '\P{_	In_cjk_Unified_Ideographs_Extension_b}', "");
Expect(0, 173792, '\P{^_	In_cjk_Unified_Ideographs_Extension_b}', "");
Error('\p{-CJK_Ext_B:=}');
Error('\P{-CJK_Ext_B:=}');
Expect(1, 173791, '\p{cjkextb}', "");
Expect(0, 173791, '\p{^cjkextb}', "");
Expect(0, 173791, '\P{cjkextb}', "");
Expect(1, 173791, '\P{^cjkextb}', "");
Expect(0, 173792, '\p{cjkextb}', "");
Expect(1, 173792, '\p{^cjkextb}', "");
Expect(1, 173792, '\P{cjkextb}', "");
Expect(0, 173792, '\P{^cjkextb}', "");
Expect(1, 173791, '\p{		CJK_EXT_B}', "");
Expect(0, 173791, '\p{^		CJK_EXT_B}', "");
Expect(0, 173791, '\P{		CJK_EXT_B}', "");
Expect(1, 173791, '\P{^		CJK_EXT_B}', "");
Expect(0, 173792, '\p{		CJK_EXT_B}', "");
Expect(1, 173792, '\p{^		CJK_EXT_B}', "");
Expect(1, 173792, '\P{		CJK_EXT_B}', "");
Expect(0, 173792, '\P{^		CJK_EXT_B}', "");
Error('\p{:=- IS_cjk_Ext_B}');
Error('\P{:=- IS_cjk_Ext_B}');
Expect(1, 173791, '\p{iscjkextb}', "");
Expect(0, 173791, '\p{^iscjkextb}', "");
Expect(0, 173791, '\P{iscjkextb}', "");
Expect(1, 173791, '\P{^iscjkextb}', "");
Expect(0, 173792, '\p{iscjkextb}', "");
Expect(1, 173792, '\p{^iscjkextb}', "");
Expect(1, 173792, '\P{iscjkextb}', "");
Expect(0, 173792, '\P{^iscjkextb}', "");
Expect(1, 173791, '\p{_	IS_CJK_Ext_B}', "");
Expect(0, 173791, '\p{^_	IS_CJK_Ext_B}', "");
Expect(0, 173791, '\P{_	IS_CJK_Ext_B}', "");
Expect(1, 173791, '\P{^_	IS_CJK_Ext_B}', "");
Expect(0, 173792, '\p{_	IS_CJK_Ext_B}', "");
Expect(1, 173792, '\p{^_	IS_CJK_Ext_B}', "");
Expect(1, 173792, '\P{_	IS_CJK_Ext_B}', "");
Expect(0, 173792, '\P{^_	IS_CJK_Ext_B}', "");
Error('\p{-	IN_CJK_ext_B:=}');
Error('\P{-	IN_CJK_ext_B:=}');
Expect(1, 173791, '\p{incjkextb}', "");
Expect(0, 173791, '\p{^incjkextb}', "");
Expect(0, 173791, '\P{incjkextb}', "");
Expect(1, 173791, '\P{^incjkextb}', "");
Expect(0, 173792, '\p{incjkextb}', "");
Expect(1, 173792, '\p{^incjkextb}', "");
Expect(1, 173792, '\P{incjkextb}', "");
Expect(0, 173792, '\P{^incjkextb}', "");
Expect(1, 173791, '\p{_ IN_CJK_EXT_B}', "");
Expect(0, 173791, '\p{^_ IN_CJK_EXT_B}', "");
Expect(0, 173791, '\P{_ IN_CJK_EXT_B}', "");
Expect(1, 173791, '\P{^_ IN_CJK_EXT_B}', "");
Expect(0, 173792, '\p{_ IN_CJK_EXT_B}', "");
Expect(1, 173792, '\p{^_ IN_CJK_EXT_B}', "");
Expect(1, 173792, '\P{_ IN_CJK_EXT_B}', "");
Expect(0, 173792, '\P{^_ IN_CJK_EXT_B}', "");
Error('\p{  CJK_Unified_IDEOGRAPHS_Extension_C/a/}');
Error('\P{  CJK_Unified_IDEOGRAPHS_Extension_C/a/}');
Expect(1, 177983, '\p{cjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\p{^cjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\P{cjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\P{^cjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\p{cjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\p{^cjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\P{cjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\P{^cjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\p{	CJK_unified_Ideographs_EXTENSION_c}', "");
Expect(0, 177983, '\p{^	CJK_unified_Ideographs_EXTENSION_c}', "");
Expect(0, 177983, '\P{	CJK_unified_Ideographs_EXTENSION_c}', "");
Expect(1, 177983, '\P{^	CJK_unified_Ideographs_EXTENSION_c}', "");
Expect(0, 177984, '\p{	CJK_unified_Ideographs_EXTENSION_c}', "");
Expect(1, 177984, '\p{^	CJK_unified_Ideographs_EXTENSION_c}', "");
Expect(1, 177984, '\P{	CJK_unified_Ideographs_EXTENSION_c}', "");
Expect(0, 177984, '\P{^	CJK_unified_Ideographs_EXTENSION_c}', "");
Error('\p{_:=IS_CJK_unified_IDEOGRAPHS_extension_C}');
Error('\P{_:=IS_CJK_unified_IDEOGRAPHS_extension_C}');
Expect(1, 177983, '\p{iscjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\p{^iscjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\P{iscjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\P{^iscjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\p{iscjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\p{^iscjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\P{iscjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\P{^iscjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\p{_	Is_CJK_Unified_Ideographs_Extension_C}', "");
Expect(0, 177983, '\p{^_	Is_CJK_Unified_Ideographs_Extension_C}', "");
Expect(0, 177983, '\P{_	Is_CJK_Unified_Ideographs_Extension_C}', "");
Expect(1, 177983, '\P{^_	Is_CJK_Unified_Ideographs_Extension_C}', "");
Expect(0, 177984, '\p{_	Is_CJK_Unified_Ideographs_Extension_C}', "");
Expect(1, 177984, '\p{^_	Is_CJK_Unified_Ideographs_Extension_C}', "");
Expect(1, 177984, '\P{_	Is_CJK_Unified_Ideographs_Extension_C}', "");
Expect(0, 177984, '\P{^_	Is_CJK_Unified_Ideographs_Extension_C}', "");
Error('\p{__in_CJK_Unified_ideographs_Extension_c/a/}');
Error('\P{__in_CJK_Unified_ideographs_Extension_c/a/}');
Expect(1, 177983, '\p{incjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\p{^incjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\P{incjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\P{^incjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\p{incjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\p{^incjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\P{incjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\P{^incjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\p{	In_CJK_UNIFIED_Ideographs_EXTENSION_c}', "");
Expect(0, 177983, '\p{^	In_CJK_UNIFIED_Ideographs_EXTENSION_c}', "");
Expect(0, 177983, '\P{	In_CJK_UNIFIED_Ideographs_EXTENSION_c}', "");
Expect(1, 177983, '\P{^	In_CJK_UNIFIED_Ideographs_EXTENSION_c}', "");
Expect(0, 177984, '\p{	In_CJK_UNIFIED_Ideographs_EXTENSION_c}', "");
Expect(1, 177984, '\p{^	In_CJK_UNIFIED_Ideographs_EXTENSION_c}', "");
Expect(1, 177984, '\P{	In_CJK_UNIFIED_Ideographs_EXTENSION_c}', "");
Expect(0, 177984, '\P{^	In_CJK_UNIFIED_Ideographs_EXTENSION_c}', "");
Error('\p{		CJK_EXT_C:=}');
Error('\P{		CJK_EXT_C:=}');
Expect(1, 177983, '\p{cjkextc}', "");
Expect(0, 177983, '\p{^cjkextc}', "");
Expect(0, 177983, '\P{cjkextc}', "");
Expect(1, 177983, '\P{^cjkextc}', "");
Expect(0, 177984, '\p{cjkextc}', "");
Expect(1, 177984, '\p{^cjkextc}', "");
Expect(1, 177984, '\P{cjkextc}', "");
Expect(0, 177984, '\P{^cjkextc}', "");
Expect(1, 177983, '\p{ -CJK_Ext_C}', "");
Expect(0, 177983, '\p{^ -CJK_Ext_C}', "");
Expect(0, 177983, '\P{ -CJK_Ext_C}', "");
Expect(1, 177983, '\P{^ -CJK_Ext_C}', "");
Expect(0, 177984, '\p{ -CJK_Ext_C}', "");
Expect(1, 177984, '\p{^ -CJK_Ext_C}', "");
Expect(1, 177984, '\P{ -CJK_Ext_C}', "");
Expect(0, 177984, '\P{^ -CJK_Ext_C}', "");
Error('\p{/a/Is_CJK_Ext_C}');
Error('\P{/a/Is_CJK_Ext_C}');
Expect(1, 177983, '\p{iscjkextc}', "");
Expect(0, 177983, '\p{^iscjkextc}', "");
Expect(0, 177983, '\P{iscjkextc}', "");
Expect(1, 177983, '\P{^iscjkextc}', "");
Expect(0, 177984, '\p{iscjkextc}', "");
Expect(1, 177984, '\p{^iscjkextc}', "");
Expect(1, 177984, '\P{iscjkextc}', "");
Expect(0, 177984, '\P{^iscjkextc}', "");
Expect(1, 177983, '\p{	is_CJK_ext_C}', "");
Expect(0, 177983, '\p{^	is_CJK_ext_C}', "");
Expect(0, 177983, '\P{	is_CJK_ext_C}', "");
Expect(1, 177983, '\P{^	is_CJK_ext_C}', "");
Expect(0, 177984, '\p{	is_CJK_ext_C}', "");
Expect(1, 177984, '\p{^	is_CJK_ext_C}', "");
Expect(1, 177984, '\P{	is_CJK_ext_C}', "");
Expect(0, 177984, '\P{^	is_CJK_ext_C}', "");
Error('\p{_/a/In_cjk_ext_C}');
Error('\P{_/a/In_cjk_ext_C}');
Expect(1, 177983, '\p{incjkextc}', "");
Expect(0, 177983, '\p{^incjkextc}', "");
Expect(0, 177983, '\P{incjkextc}', "");
Expect(1, 177983, '\P{^incjkextc}', "");
Expect(0, 177984, '\p{incjkextc}', "");
Expect(1, 177984, '\p{^incjkextc}', "");
Expect(1, 177984, '\P{incjkextc}', "");
Expect(0, 177984, '\P{^incjkextc}', "");
Expect(1, 177983, '\p{ 	in_CJK_EXT_C}', "");
Expect(0, 177983, '\p{^ 	in_CJK_EXT_C}', "");
Expect(0, 177983, '\P{ 	in_CJK_EXT_C}', "");
Expect(1, 177983, '\P{^ 	in_CJK_EXT_C}', "");
Expect(0, 177984, '\p{ 	in_CJK_EXT_C}', "");
Expect(1, 177984, '\p{^ 	in_CJK_EXT_C}', "");
Expect(1, 177984, '\P{ 	in_CJK_EXT_C}', "");
Expect(0, 177984, '\P{^ 	in_CJK_EXT_C}', "");
Error('\p{ :=CJK_Unified_Ideographs_extension_D}');
Error('\P{ :=CJK_Unified_Ideographs_extension_D}');
Expect(1, 178207, '\p{cjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\p{^cjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\P{cjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\P{^cjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\p{cjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\p{^cjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\P{cjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\P{^cjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\p{-	cjk_unified_Ideographs_extension_D}', "");
Expect(0, 178207, '\p{^-	cjk_unified_Ideographs_extension_D}', "");
Expect(0, 178207, '\P{-	cjk_unified_Ideographs_extension_D}', "");
Expect(1, 178207, '\P{^-	cjk_unified_Ideographs_extension_D}', "");
Expect(0, 178208, '\p{-	cjk_unified_Ideographs_extension_D}', "");
Expect(1, 178208, '\p{^-	cjk_unified_Ideographs_extension_D}', "");
Expect(1, 178208, '\P{-	cjk_unified_Ideographs_extension_D}', "");
Expect(0, 178208, '\P{^-	cjk_unified_Ideographs_extension_D}', "");
Error('\p{:=- Is_CJK_UNIFIED_IDEOGRAPHS_Extension_D}');
Error('\P{:=- Is_CJK_UNIFIED_IDEOGRAPHS_Extension_D}');
Expect(1, 178207, '\p{iscjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\p{^iscjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\P{iscjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\P{^iscjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\p{iscjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\p{^iscjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\P{iscjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\P{^iscjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\p{	IS_CJK_unified_Ideographs_Extension_d}', "");
Expect(0, 178207, '\p{^	IS_CJK_unified_Ideographs_Extension_d}', "");
Expect(0, 178207, '\P{	IS_CJK_unified_Ideographs_Extension_d}', "");
Expect(1, 178207, '\P{^	IS_CJK_unified_Ideographs_Extension_d}', "");
Expect(0, 178208, '\p{	IS_CJK_unified_Ideographs_Extension_d}', "");
Expect(1, 178208, '\p{^	IS_CJK_unified_Ideographs_Extension_d}', "");
Expect(1, 178208, '\P{	IS_CJK_unified_Ideographs_Extension_d}', "");
Expect(0, 178208, '\P{^	IS_CJK_unified_Ideographs_Extension_d}', "");
Error('\p{	/a/IN_cjk_UNIFIED_ideographs_EXTENSION_D}');
Error('\P{	/a/IN_cjk_UNIFIED_ideographs_EXTENSION_D}');
Expect(1, 178207, '\p{incjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\p{^incjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\P{incjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\P{^incjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\p{incjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\p{^incjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\P{incjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\P{^incjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\p{-in_CJK_Unified_Ideographs_extension_D}', "");
Expect(0, 178207, '\p{^-in_CJK_Unified_Ideographs_extension_D}', "");
Expect(0, 178207, '\P{-in_CJK_Unified_Ideographs_extension_D}', "");
Expect(1, 178207, '\P{^-in_CJK_Unified_Ideographs_extension_D}', "");
Expect(0, 178208, '\p{-in_CJK_Unified_Ideographs_extension_D}', "");
Expect(1, 178208, '\p{^-in_CJK_Unified_Ideographs_extension_D}', "");
Expect(1, 178208, '\P{-in_CJK_Unified_Ideographs_extension_D}', "");
Expect(0, 178208, '\P{^-in_CJK_Unified_Ideographs_extension_D}', "");
Error('\p{/a/CJK_ext_D}');
Error('\P{/a/CJK_ext_D}');
Expect(1, 178207, '\p{cjkextd}', "");
Expect(0, 178207, '\p{^cjkextd}', "");
Expect(0, 178207, '\P{cjkextd}', "");
Expect(1, 178207, '\P{^cjkextd}', "");
Expect(0, 178208, '\p{cjkextd}', "");
Expect(1, 178208, '\p{^cjkextd}', "");
Expect(1, 178208, '\P{cjkextd}', "");
Expect(0, 178208, '\P{^cjkextd}', "");
Expect(1, 178207, '\p{_cjk_ext_D}', "");
Expect(0, 178207, '\p{^_cjk_ext_D}', "");
Expect(0, 178207, '\P{_cjk_ext_D}', "");
Expect(1, 178207, '\P{^_cjk_ext_D}', "");
Expect(0, 178208, '\p{_cjk_ext_D}', "");
Expect(1, 178208, '\p{^_cjk_ext_D}', "");
Expect(1, 178208, '\P{_cjk_ext_D}', "");
Expect(0, 178208, '\P{^_cjk_ext_D}', "");
Error('\p{:=__Is_CJK_Ext_D}');
Error('\P{:=__Is_CJK_Ext_D}');
Expect(1, 178207, '\p{iscjkextd}', "");
Expect(0, 178207, '\p{^iscjkextd}', "");
Expect(0, 178207, '\P{iscjkextd}', "");
Expect(1, 178207, '\P{^iscjkextd}', "");
Expect(0, 178208, '\p{iscjkextd}', "");
Expect(1, 178208, '\p{^iscjkextd}', "");
Expect(1, 178208, '\P{iscjkextd}', "");
Expect(0, 178208, '\P{^iscjkextd}', "");
Expect(1, 178207, '\p{-Is_cjk_Ext_D}', "");
Expect(0, 178207, '\p{^-Is_cjk_Ext_D}', "");
Expect(0, 178207, '\P{-Is_cjk_Ext_D}', "");
Expect(1, 178207, '\P{^-Is_cjk_Ext_D}', "");
Expect(0, 178208, '\p{-Is_cjk_Ext_D}', "");
Expect(1, 178208, '\p{^-Is_cjk_Ext_D}', "");
Expect(1, 178208, '\P{-Is_cjk_Ext_D}', "");
Expect(0, 178208, '\P{^-Is_cjk_Ext_D}', "");
Error('\p{/a/--In_CJK_Ext_D}');
Error('\P{/a/--In_CJK_Ext_D}');
Expect(1, 178207, '\p{incjkextd}', "");
Expect(0, 178207, '\p{^incjkextd}', "");
Expect(0, 178207, '\P{incjkextd}', "");
Expect(1, 178207, '\P{^incjkextd}', "");
Expect(0, 178208, '\p{incjkextd}', "");
Expect(1, 178208, '\p{^incjkextd}', "");
Expect(1, 178208, '\P{incjkextd}', "");
Expect(0, 178208, '\P{^incjkextd}', "");
Expect(1, 178207, '\p{ -In_CJK_Ext_D}', "");
Expect(0, 178207, '\p{^ -In_CJK_Ext_D}', "");
Expect(0, 178207, '\P{ -In_CJK_Ext_D}', "");
Expect(1, 178207, '\P{^ -In_CJK_Ext_D}', "");
Expect(0, 178208, '\p{ -In_CJK_Ext_D}', "");
Expect(1, 178208, '\p{^ -In_CJK_Ext_D}', "");
Expect(1, 178208, '\P{ -In_CJK_Ext_D}', "");
Expect(0, 178208, '\P{^ -In_CJK_Ext_D}', "");
Error('\p{:=-Canadian_ABORIGINAL}');
Error('\P{:=-Canadian_ABORIGINAL}');
Expect(1, 6389, '\p{canadianaboriginal}', "");
Expect(0, 6389, '\p{^canadianaboriginal}', "");
Expect(0, 6389, '\P{canadianaboriginal}', "");
Expect(1, 6389, '\P{^canadianaboriginal}', "");
Expect(0, 6390, '\p{canadianaboriginal}', "");
Expect(1, 6390, '\p{^canadianaboriginal}', "");
Expect(1, 6390, '\P{canadianaboriginal}', "");
Expect(0, 6390, '\P{^canadianaboriginal}', "");
Expect(1, 6389, '\p{--Canadian_ABORIGINAL}', "");
Expect(0, 6389, '\p{^--Canadian_ABORIGINAL}', "");
Expect(0, 6389, '\P{--Canadian_ABORIGINAL}', "");
Expect(1, 6389, '\P{^--Canadian_ABORIGINAL}', "");
Expect(0, 6390, '\p{--Canadian_ABORIGINAL}', "");
Expect(1, 6390, '\p{^--Canadian_ABORIGINAL}', "");
Expect(1, 6390, '\P{--Canadian_ABORIGINAL}', "");
Expect(0, 6390, '\P{^--Canadian_ABORIGINAL}', "");
Error('\p{/a/	-IS_Canadian_Aboriginal}');
Error('\P{/a/	-IS_Canadian_Aboriginal}');
Expect(1, 6389, '\p{iscanadianaboriginal}', "");
Expect(0, 6389, '\p{^iscanadianaboriginal}', "");
Expect(0, 6389, '\P{iscanadianaboriginal}', "");
Expect(1, 6389, '\P{^iscanadianaboriginal}', "");
Expect(0, 6390, '\p{iscanadianaboriginal}', "");
Expect(1, 6390, '\p{^iscanadianaboriginal}', "");
Expect(1, 6390, '\P{iscanadianaboriginal}', "");
Expect(0, 6390, '\P{^iscanadianaboriginal}', "");
Expect(1, 6389, '\p{__is_Canadian_Aboriginal}', "");
Expect(0, 6389, '\p{^__is_Canadian_Aboriginal}', "");
Expect(0, 6389, '\P{__is_Canadian_Aboriginal}', "");
Expect(1, 6389, '\P{^__is_Canadian_Aboriginal}', "");
Expect(0, 6390, '\p{__is_Canadian_Aboriginal}', "");
Expect(1, 6390, '\p{^__is_Canadian_Aboriginal}', "");
Expect(1, 6390, '\P{__is_Canadian_Aboriginal}', "");
Expect(0, 6390, '\P{^__is_Canadian_Aboriginal}', "");
Error('\p{		Cans:=}');
Error('\P{		Cans:=}');
Expect(1, 6389, '\p{cans}', "");
Expect(0, 6389, '\p{^cans}', "");
Expect(0, 6389, '\P{cans}', "");
Expect(1, 6389, '\P{^cans}', "");
Expect(0, 6390, '\p{cans}', "");
Expect(1, 6390, '\p{^cans}', "");
Expect(1, 6390, '\P{cans}', "");
Expect(0, 6390, '\P{^cans}', "");
Expect(1, 6389, '\p{--cans}', "");
Expect(0, 6389, '\p{^--cans}', "");
Expect(0, 6389, '\P{--cans}', "");
Expect(1, 6389, '\P{^--cans}', "");
Expect(0, 6390, '\p{--cans}', "");
Expect(1, 6390, '\p{^--cans}', "");
Expect(1, 6390, '\P{--cans}', "");
Expect(0, 6390, '\P{^--cans}', "");
Error('\p{-/a/Is_Cans}');
Error('\P{-/a/Is_Cans}');
Expect(1, 6389, '\p{iscans}', "");
Expect(0, 6389, '\p{^iscans}', "");
Expect(0, 6389, '\P{iscans}', "");
Expect(1, 6389, '\P{^iscans}', "");
Expect(0, 6390, '\p{iscans}', "");
Expect(1, 6390, '\p{^iscans}', "");
Expect(1, 6390, '\P{iscans}', "");
Expect(0, 6390, '\P{^iscans}', "");
Expect(1, 6389, '\p{	Is_CANS}', "");
Expect(0, 6389, '\p{^	Is_CANS}', "");
Expect(0, 6389, '\P{	Is_CANS}', "");
Expect(1, 6389, '\P{^	Is_CANS}', "");
Expect(0, 6390, '\p{	Is_CANS}', "");
Expect(1, 6390, '\p{^	Is_CANS}', "");
Expect(1, 6390, '\P{	Is_CANS}', "");
Expect(0, 6390, '\P{^	Is_CANS}', "");
Error('\p{:=Carian}');
Error('\P{:=Carian}');
Expect(1, 66256, '\p{carian}', "");
Expect(0, 66256, '\p{^carian}', "");
Expect(0, 66256, '\P{carian}', "");
Expect(1, 66256, '\P{^carian}', "");
Expect(0, 66257, '\p{carian}', "");
Expect(1, 66257, '\p{^carian}', "");
Expect(1, 66257, '\P{carian}', "");
Expect(0, 66257, '\P{^carian}', "");
Expect(1, 66256, '\p{		carian}', "");
Expect(0, 66256, '\p{^		carian}', "");
Expect(0, 66256, '\P{		carian}', "");
Expect(1, 66256, '\P{^		carian}', "");
Expect(0, 66257, '\p{		carian}', "");
Expect(1, 66257, '\p{^		carian}', "");
Expect(1, 66257, '\P{		carian}', "");
Expect(0, 66257, '\P{^		carian}', "");
Error('\p{_IS_carian:=}');
Error('\P{_IS_carian:=}');
Expect(1, 66256, '\p{iscarian}', "");
Expect(0, 66256, '\p{^iscarian}', "");
Expect(0, 66256, '\P{iscarian}', "");
Expect(1, 66256, '\P{^iscarian}', "");
Expect(0, 66257, '\p{iscarian}', "");
Expect(1, 66257, '\p{^iscarian}', "");
Expect(1, 66257, '\P{iscarian}', "");
Expect(0, 66257, '\P{^iscarian}', "");
Expect(1, 66256, '\p{  is_Carian}', "");
Expect(0, 66256, '\p{^  is_Carian}', "");
Expect(0, 66256, '\P{  is_Carian}', "");
Expect(1, 66256, '\P{^  is_Carian}', "");
Expect(0, 66257, '\p{  is_Carian}', "");
Expect(1, 66257, '\p{^  is_Carian}', "");
Expect(1, 66257, '\P{  is_Carian}', "");
Expect(0, 66257, '\P{^  is_Carian}', "");
Error('\p{:=cari}');
Error('\P{:=cari}');
Expect(1, 66256, '\p{cari}', "");
Expect(0, 66256, '\p{^cari}', "");
Expect(0, 66256, '\P{cari}', "");
Expect(1, 66256, '\P{^cari}', "");
Expect(0, 66257, '\p{cari}', "");
Expect(1, 66257, '\p{^cari}', "");
Expect(1, 66257, '\P{cari}', "");
Expect(0, 66257, '\P{^cari}', "");
Expect(1, 66256, '\p{--cari}', "");
Expect(0, 66256, '\p{^--cari}', "");
Expect(0, 66256, '\P{--cari}', "");
Expect(1, 66256, '\P{^--cari}', "");
Expect(0, 66257, '\p{--cari}', "");
Expect(1, 66257, '\p{^--cari}', "");
Expect(1, 66257, '\P{--cari}', "");
Expect(0, 66257, '\P{^--cari}', "");
Error('\p{	/a/Is_Cari}');
Error('\P{	/a/Is_Cari}');
Expect(1, 66256, '\p{iscari}', "");
Expect(0, 66256, '\p{^iscari}', "");
Expect(0, 66256, '\P{iscari}', "");
Expect(1, 66256, '\P{^iscari}', "");
Expect(0, 66257, '\p{iscari}', "");
Expect(1, 66257, '\p{^iscari}', "");
Expect(1, 66257, '\P{iscari}', "");
Expect(0, 66257, '\P{^iscari}', "");
Expect(1, 66256, '\p{-Is_cari}', "");
Expect(0, 66256, '\p{^-Is_cari}', "");
Expect(0, 66256, '\P{-Is_cari}', "");
Expect(1, 66256, '\P{^-Is_cari}', "");
Expect(0, 66257, '\p{-Is_cari}', "");
Expect(1, 66257, '\p{^-Is_cari}', "");
Expect(1, 66257, '\P{-Is_cari}', "");
Expect(0, 66257, '\P{^-Is_cari}', "");
Error('\p{ -cased/a/}');
Error('\P{ -cased/a/}');
Expect(1, 120779, '\p{cased}', "");
Expect(0, 120779, '\p{^cased}', "");
Expect(0, 120779, '\P{cased}', "");
Expect(1, 120779, '\P{^cased}', "");
Expect(0, 120780, '\p{cased}', "");
Expect(1, 120780, '\p{^cased}', "");
Expect(1, 120780, '\P{cased}', "");
Expect(0, 120780, '\P{^cased}', "");
Expect(1, 120779, '\p{	 Cased}', "");
Expect(0, 120779, '\p{^	 Cased}', "");
Expect(0, 120779, '\P{	 Cased}', "");
Expect(1, 120779, '\P{^	 Cased}', "");
Expect(0, 120780, '\p{	 Cased}', "");
Expect(1, 120780, '\p{^	 Cased}', "");
Expect(1, 120780, '\P{	 Cased}', "");
Expect(0, 120780, '\P{^	 Cased}', "");
Error('\p{	/a/Is_Cased}');
Error('\P{	/a/Is_Cased}');
Expect(1, 120779, '\p{iscased}', "");
Expect(0, 120779, '\p{^iscased}', "");
Expect(0, 120779, '\P{iscased}', "");
Expect(1, 120779, '\P{^iscased}', "");
Expect(0, 120780, '\p{iscased}', "");
Expect(1, 120780, '\p{^iscased}', "");
Expect(1, 120780, '\P{iscased}', "");
Expect(0, 120780, '\P{^iscased}', "");
Expect(1, 120779, '\p{__Is_Cased}', "");
Expect(0, 120779, '\p{^__Is_Cased}', "");
Expect(0, 120779, '\P{__Is_Cased}', "");
Expect(1, 120779, '\P{^__Is_Cased}', "");
Expect(0, 120780, '\p{__Is_Cased}', "");
Expect(1, 120780, '\p{^__Is_Cased}', "");
Expect(1, 120780, '\P{__Is_Cased}', "");
Expect(0, 120780, '\P{^__Is_Cased}', "");
Error('\p{	/a/Cased_Letter}');
Error('\P{	/a/Cased_Letter}');
Expect(1, 120779, '\p{casedletter}', "");
Expect(0, 120779, '\p{^casedletter}', "");
Expect(0, 120779, '\P{casedletter}', "");
Expect(1, 120779, '\P{^casedletter}', "");
Expect(0, 120780, '\p{casedletter}', "");
Expect(1, 120780, '\p{^casedletter}', "");
Expect(1, 120780, '\P{casedletter}', "");
Expect(0, 120780, '\P{^casedletter}', "");
Expect(1, 120779, '\p{  Cased_Letter}', "");
Expect(0, 120779, '\p{^  Cased_Letter}', "");
Expect(0, 120779, '\P{  Cased_Letter}', "");
Expect(1, 120779, '\P{^  Cased_Letter}', "");
Expect(0, 120780, '\p{  Cased_Letter}', "");
Expect(1, 120780, '\p{^  Cased_Letter}', "");
Expect(1, 120780, '\P{  Cased_Letter}', "");
Expect(0, 120780, '\P{^  Cased_Letter}', "");
Error('\p{/a/  Is_Cased_LETTER}');
Error('\P{/a/  Is_Cased_LETTER}');
Expect(1, 120779, '\p{iscasedletter}', "");
Expect(0, 120779, '\p{^iscasedletter}', "");
Expect(0, 120779, '\P{iscasedletter}', "");
Expect(1, 120779, '\P{^iscasedletter}', "");
Expect(0, 120780, '\p{iscasedletter}', "");
Expect(1, 120780, '\p{^iscasedletter}', "");
Expect(1, 120780, '\P{iscasedletter}', "");
Expect(0, 120780, '\P{^iscasedletter}', "");
Expect(1, 120779, '\p{	_Is_cased_letter}', "");
Expect(0, 120779, '\p{^	_Is_cased_letter}', "");
Expect(0, 120779, '\P{	_Is_cased_letter}', "");
Expect(1, 120779, '\P{^	_Is_cased_letter}', "");
Expect(0, 120780, '\p{	_Is_cased_letter}', "");
Expect(1, 120780, '\p{^	_Is_cased_letter}', "");
Expect(1, 120780, '\P{	_Is_cased_letter}', "");
Expect(0, 120780, '\P{^	_Is_cased_letter}', "");
Error('\p{ _LC/a/}');
Error('\P{ _LC/a/}');
Expect(1, 120779, '\p{lc}', "");
Expect(0, 120779, '\p{^lc}', "");
Expect(0, 120779, '\P{lc}', "");
Expect(1, 120779, '\P{^lc}', "");
Expect(0, 120780, '\p{lc}', "");
Expect(1, 120780, '\p{^lc}', "");
Expect(1, 120780, '\P{lc}', "");
Expect(0, 120780, '\P{^lc}', "");
Expect(1, 120779, '\p{_-LC}', "");
Expect(0, 120779, '\p{^_-LC}', "");
Expect(0, 120779, '\P{_-LC}', "");
Expect(1, 120779, '\P{^_-LC}', "");
Expect(0, 120780, '\p{_-LC}', "");
Expect(1, 120780, '\p{^_-LC}', "");
Expect(1, 120780, '\P{_-LC}', "");
Expect(0, 120780, '\P{^_-LC}', "");
Error('\p{-:=IS_LC}');
Error('\P{-:=IS_LC}');
Expect(1, 120779, '\p{islc}', "");
Expect(0, 120779, '\p{^islc}', "");
Expect(0, 120779, '\P{islc}', "");
Expect(1, 120779, '\P{^islc}', "");
Expect(0, 120780, '\p{islc}', "");
Expect(1, 120780, '\p{^islc}', "");
Expect(1, 120780, '\P{islc}', "");
Expect(0, 120780, '\P{^islc}', "");
Expect(1, 120779, '\p{_Is_LC}', "");
Expect(0, 120779, '\p{^_Is_LC}', "");
Expect(0, 120779, '\P{_Is_LC}', "");
Expect(1, 120779, '\P{^_Is_LC}', "");
Expect(0, 120780, '\p{_Is_LC}', "");
Expect(1, 120780, '\p{^_Is_LC}', "");
Expect(1, 120780, '\P{_Is_LC}', "");
Expect(0, 120780, '\P{^_Is_LC}', "");
Error('\p{:= _l_}');
Error('\P{:= _l_}');
Expect(1, 120779, '\p{l_}', "");
Expect(0, 120779, '\p{^l_}', "");
Expect(0, 120779, '\P{l_}', "");
Expect(1, 120779, '\P{^l_}', "");
Expect(0, 120780, '\p{l_}', "");
Expect(1, 120780, '\p{^l_}', "");
Expect(1, 120780, '\P{l_}', "");
Expect(0, 120780, '\P{^l_}', "");
Expect(1, 120779, '\p{		L_}', "");
Expect(0, 120779, '\p{^		L_}', "");
Expect(0, 120779, '\P{		L_}', "");
Expect(1, 120779, '\P{^		L_}', "");
Expect(0, 120780, '\p{		L_}', "");
Expect(1, 120780, '\p{^		L_}', "");
Expect(1, 120780, '\P{		L_}', "");
Expect(0, 120780, '\P{^		L_}', "");
Error('\p{ :=IS_L_}');
Error('\P{ :=IS_L_}');
Expect(1, 120779, '\p{isl_}', "");
Expect(0, 120779, '\p{^isl_}', "");
Expect(0, 120779, '\P{isl_}', "");
Expect(1, 120779, '\P{^isl_}', "");
Expect(0, 120780, '\p{isl_}', "");
Expect(1, 120780, '\p{^isl_}', "");
Expect(1, 120780, '\P{isl_}', "");
Expect(0, 120780, '\P{^isl_}', "");
Expect(1, 120779, '\p{ IS_L_}', "");
Expect(0, 120779, '\p{^ IS_L_}', "");
Expect(0, 120779, '\P{ IS_L_}', "");
Expect(1, 120779, '\P{^ IS_L_}', "");
Expect(0, 120780, '\p{ IS_L_}', "");
Expect(1, 120780, '\p{^ IS_L_}', "");
Expect(1, 120780, '\P{ IS_L_}', "");
Expect(0, 120780, '\P{^ IS_L_}', "");
Error('\p{ /a/l&}');
Error('\P{ /a/l&}');
Expect(1, 120779, '\p{l&}', "");
Expect(0, 120779, '\p{^l&}', "");
Expect(0, 120779, '\P{l&}', "");
Expect(1, 120779, '\P{^l&}', "");
Expect(0, 120780, '\p{l&}', "");
Expect(1, 120780, '\p{^l&}', "");
Expect(1, 120780, '\P{l&}', "");
Expect(0, 120780, '\P{^l&}', "");
Expect(1, 120779, '\p{- L&}', "");
Expect(0, 120779, '\p{^- L&}', "");
Expect(0, 120779, '\P{- L&}', "");
Expect(1, 120779, '\P{^- L&}', "");
Expect(0, 120780, '\p{- L&}', "");
Expect(1, 120780, '\p{^- L&}', "");
Expect(1, 120780, '\P{- L&}', "");
Expect(0, 120780, '\P{^- L&}', "");
Error('\p{	 Is_l&/a/}');
Error('\P{	 Is_l&/a/}');
Expect(1, 120779, '\p{isl&}', "");
Expect(0, 120779, '\p{^isl&}', "");
Expect(0, 120779, '\P{isl&}', "");
Expect(1, 120779, '\P{^isl&}', "");
Expect(0, 120780, '\p{isl&}', "");
Expect(1, 120780, '\p{^isl&}', "");
Expect(1, 120780, '\P{isl&}', "");
Expect(0, 120780, '\P{^isl&}', "");
Expect(1, 120779, '\p{_ Is_l&}', "");
Expect(0, 120779, '\p{^_ Is_l&}', "");
Expect(0, 120779, '\P{_ Is_l&}', "");
Expect(1, 120779, '\P{^_ Is_l&}', "");
Expect(0, 120780, '\p{_ Is_l&}', "");
Expect(1, 120780, '\p{^_ Is_l&}', "");
Expect(1, 120780, '\P{_ Is_l&}', "");
Expect(0, 120780, '\P{^_ Is_l&}', "");
Error('\p{:=Chakma}');
Error('\P{:=Chakma}');
Expect(1, 69955, '\p{chakma}', "");
Expect(0, 69955, '\p{^chakma}', "");
Expect(0, 69955, '\P{chakma}', "");
Expect(1, 69955, '\P{^chakma}', "");
Expect(0, 69956, '\p{chakma}', "");
Expect(1, 69956, '\p{^chakma}', "");
Expect(1, 69956, '\P{chakma}', "");
Expect(0, 69956, '\P{^chakma}', "");
Expect(1, 69955, '\p{_-Chakma}', "");
Expect(0, 69955, '\p{^_-Chakma}', "");
Expect(0, 69955, '\P{_-Chakma}', "");
Expect(1, 69955, '\P{^_-Chakma}', "");
Expect(0, 69956, '\p{_-Chakma}', "");
Expect(1, 69956, '\p{^_-Chakma}', "");
Expect(1, 69956, '\P{_-Chakma}', "");
Expect(0, 69956, '\P{^_-Chakma}', "");
Error('\p{_:=is_chakma}');
Error('\P{_:=is_chakma}');
Expect(1, 69955, '\p{ischakma}', "");
Expect(0, 69955, '\p{^ischakma}', "");
Expect(0, 69955, '\P{ischakma}', "");
Expect(1, 69955, '\P{^ischakma}', "");
Expect(0, 69956, '\p{ischakma}', "");
Expect(1, 69956, '\p{^ischakma}', "");
Expect(1, 69956, '\P{ischakma}', "");
Expect(0, 69956, '\P{^ischakma}', "");
Expect(1, 69955, '\p{_-Is_Chakma}', "");
Expect(0, 69955, '\p{^_-Is_Chakma}', "");
Expect(0, 69955, '\P{_-Is_Chakma}', "");
Expect(1, 69955, '\P{^_-Is_Chakma}', "");
Expect(0, 69956, '\p{_-Is_Chakma}', "");
Expect(1, 69956, '\p{^_-Is_Chakma}', "");
Expect(1, 69956, '\P{_-Is_Chakma}', "");
Expect(0, 69956, '\P{^_-Is_Chakma}', "");
Error('\p{	CAKM:=}');
Error('\P{	CAKM:=}');
Expect(1, 69955, '\p{cakm}', "");
Expect(0, 69955, '\p{^cakm}', "");
Expect(0, 69955, '\P{cakm}', "");
Expect(1, 69955, '\P{^cakm}', "");
Expect(0, 69956, '\p{cakm}', "");
Expect(1, 69956, '\p{^cakm}', "");
Expect(1, 69956, '\P{cakm}', "");
Expect(0, 69956, '\P{^cakm}', "");
Expect(1, 69955, '\p{_-cakm}', "");
Expect(0, 69955, '\p{^_-cakm}', "");
Expect(0, 69955, '\P{_-cakm}', "");
Expect(1, 69955, '\P{^_-cakm}', "");
Expect(0, 69956, '\p{_-cakm}', "");
Expect(1, 69956, '\p{^_-cakm}', "");
Expect(1, 69956, '\P{_-cakm}', "");
Expect(0, 69956, '\P{^_-cakm}', "");
Error('\p{_-IS_Cakm:=}');
Error('\P{_-IS_Cakm:=}');
Expect(1, 69955, '\p{iscakm}', "");
Expect(0, 69955, '\p{^iscakm}', "");
Expect(0, 69955, '\P{iscakm}', "");
Expect(1, 69955, '\P{^iscakm}', "");
Expect(0, 69956, '\p{iscakm}', "");
Expect(1, 69956, '\p{^iscakm}', "");
Expect(1, 69956, '\P{iscakm}', "");
Expect(0, 69956, '\P{^iscakm}', "");
Expect(1, 69955, '\p{ IS_Cakm}', "");
Expect(0, 69955, '\p{^ IS_Cakm}', "");
Expect(0, 69955, '\P{ IS_Cakm}', "");
Expect(1, 69955, '\P{^ IS_Cakm}', "");
Expect(0, 69956, '\p{ IS_Cakm}', "");
Expect(1, 69956, '\p{^ IS_Cakm}', "");
Expect(1, 69956, '\P{ IS_Cakm}', "");
Expect(0, 69956, '\P{^ IS_Cakm}', "");
Error('\p{/a/ cham}');
Error('\P{/a/ cham}');
Expect(1, 43615, '\p{cham}', "");
Expect(0, 43615, '\p{^cham}', "");
Expect(0, 43615, '\P{cham}', "");
Expect(1, 43615, '\P{^cham}', "");
Expect(0, 43616, '\p{cham}', "");
Expect(1, 43616, '\p{^cham}', "");
Expect(1, 43616, '\P{cham}', "");
Expect(0, 43616, '\P{^cham}', "");
Expect(1, 43615, '\p{		Cham}', "");
Expect(0, 43615, '\p{^		Cham}', "");
Expect(0, 43615, '\P{		Cham}', "");
Expect(1, 43615, '\P{^		Cham}', "");
Expect(0, 43616, '\p{		Cham}', "");
Expect(1, 43616, '\p{^		Cham}', "");
Expect(1, 43616, '\P{		Cham}', "");
Expect(0, 43616, '\P{^		Cham}', "");
Error('\p{	/a/IS_CHAM}');
Error('\P{	/a/IS_CHAM}');
Expect(1, 43615, '\p{ischam}', "");
Expect(0, 43615, '\p{^ischam}', "");
Expect(0, 43615, '\P{ischam}', "");
Expect(1, 43615, '\P{^ischam}', "");
Expect(0, 43616, '\p{ischam}', "");
Expect(1, 43616, '\p{^ischam}', "");
Expect(1, 43616, '\P{ischam}', "");
Expect(0, 43616, '\P{^ischam}', "");
Expect(1, 43615, '\p{	is_Cham}', "");
Expect(0, 43615, '\p{^	is_Cham}', "");
Expect(0, 43615, '\P{	is_Cham}', "");
Expect(1, 43615, '\P{^	is_Cham}', "");
Expect(0, 43616, '\p{	is_Cham}', "");
Expect(1, 43616, '\p{^	is_Cham}', "");
Expect(1, 43616, '\P{	is_Cham}', "");
Expect(0, 43616, '\P{^	is_Cham}', "");
Error('\p{ :=Changes_WHEN_casefolded}');
Error('\P{ :=Changes_WHEN_casefolded}');
Expect(1, 66599, '\p{changeswhencasefolded}', "");
Expect(0, 66599, '\p{^changeswhencasefolded}', "");
Expect(0, 66599, '\P{changeswhencasefolded}', "");
Expect(1, 66599, '\P{^changeswhencasefolded}', "");
Expect(0, 66600, '\p{changeswhencasefolded}', "");
Expect(1, 66600, '\p{^changeswhencasefolded}', "");
Expect(1, 66600, '\P{changeswhencasefolded}', "");
Expect(0, 66600, '\P{^changeswhencasefolded}', "");
Expect(1, 66599, '\p{_	Changes_When_Casefolded}', "");
Expect(0, 66599, '\p{^_	Changes_When_Casefolded}', "");
Expect(0, 66599, '\P{_	Changes_When_Casefolded}', "");
Expect(1, 66599, '\P{^_	Changes_When_Casefolded}', "");
Expect(0, 66600, '\p{_	Changes_When_Casefolded}', "");
Expect(1, 66600, '\p{^_	Changes_When_Casefolded}', "");
Expect(1, 66600, '\P{_	Changes_When_Casefolded}', "");
Expect(0, 66600, '\P{^_	Changes_When_Casefolded}', "");
Error('\p{:=-	Is_changes_When_Casefolded}');
Error('\P{:=-	Is_changes_When_Casefolded}');
Expect(1, 66599, '\p{ischangeswhencasefolded}', "");
Expect(0, 66599, '\p{^ischangeswhencasefolded}', "");
Expect(0, 66599, '\P{ischangeswhencasefolded}', "");
Expect(1, 66599, '\P{^ischangeswhencasefolded}', "");
Expect(0, 66600, '\p{ischangeswhencasefolded}', "");
Expect(1, 66600, '\p{^ischangeswhencasefolded}', "");
Expect(1, 66600, '\P{ischangeswhencasefolded}', "");
Expect(0, 66600, '\P{^ischangeswhencasefolded}', "");
Expect(1, 66599, '\p{_-Is_Changes_WHEN_casefolded}', "");
Expect(0, 66599, '\p{^_-Is_Changes_WHEN_casefolded}', "");
Expect(0, 66599, '\P{_-Is_Changes_WHEN_casefolded}', "");
Expect(1, 66599, '\P{^_-Is_Changes_WHEN_casefolded}', "");
Expect(0, 66600, '\p{_-Is_Changes_WHEN_casefolded}', "");
Expect(1, 66600, '\p{^_-Is_Changes_WHEN_casefolded}', "");
Expect(1, 66600, '\P{_-Is_Changes_WHEN_casefolded}', "");
Expect(0, 66600, '\P{^_-Is_Changes_WHEN_casefolded}', "");
Error('\p{ -CWCF/a/}');
Error('\P{ -CWCF/a/}');
Expect(1, 66599, '\p{cwcf}', "");
Expect(0, 66599, '\p{^cwcf}', "");
Expect(0, 66599, '\P{cwcf}', "");
Expect(1, 66599, '\P{^cwcf}', "");
Expect(0, 66600, '\p{cwcf}', "");
Expect(1, 66600, '\p{^cwcf}', "");
Expect(1, 66600, '\P{cwcf}', "");
Expect(0, 66600, '\P{^cwcf}', "");
Expect(1, 66599, '\p{_	CWCF}', "");
Expect(0, 66599, '\p{^_	CWCF}', "");
Expect(0, 66599, '\P{_	CWCF}', "");
Expect(1, 66599, '\P{^_	CWCF}', "");
Expect(0, 66600, '\p{_	CWCF}', "");
Expect(1, 66600, '\p{^_	CWCF}', "");
Expect(1, 66600, '\P{_	CWCF}', "");
Expect(0, 66600, '\P{^_	CWCF}', "");
Error('\p{/a/-Is_CWCF}');
Error('\P{/a/-Is_CWCF}');
Expect(1, 66599, '\p{iscwcf}', "");
Expect(0, 66599, '\p{^iscwcf}', "");
Expect(0, 66599, '\P{iscwcf}', "");
Expect(1, 66599, '\P{^iscwcf}', "");
Expect(0, 66600, '\p{iscwcf}', "");
Expect(1, 66600, '\p{^iscwcf}', "");
Expect(1, 66600, '\P{iscwcf}', "");
Expect(0, 66600, '\P{^iscwcf}', "");
Expect(1, 66599, '\p{- IS_cwcf}', "");
Expect(0, 66599, '\p{^- IS_cwcf}', "");
Expect(0, 66599, '\P{- IS_cwcf}', "");
Expect(1, 66599, '\P{^- IS_cwcf}', "");
Expect(0, 66600, '\p{- IS_cwcf}', "");
Expect(1, 66600, '\p{^- IS_cwcf}', "");
Expect(1, 66600, '\P{- IS_cwcf}', "");
Expect(0, 66600, '\P{^- IS_cwcf}', "");
Error('\p{- CHANGES_WHEN_Casemapped:=}');
Error('\P{- CHANGES_WHEN_Casemapped:=}');
Expect(1, 66639, '\p{changeswhencasemapped}', "");
Expect(0, 66639, '\p{^changeswhencasemapped}', "");
Expect(0, 66639, '\P{changeswhencasemapped}', "");
Expect(1, 66639, '\P{^changeswhencasemapped}', "");
Expect(0, 66640, '\p{changeswhencasemapped}', "");
Expect(1, 66640, '\p{^changeswhencasemapped}', "");
Expect(1, 66640, '\P{changeswhencasemapped}', "");
Expect(0, 66640, '\P{^changeswhencasemapped}', "");
Expect(1, 66639, '\p{CHANGES_When_Casemapped}', "");
Expect(0, 66639, '\p{^CHANGES_When_Casemapped}', "");
Expect(0, 66639, '\P{CHANGES_When_Casemapped}', "");
Expect(1, 66639, '\P{^CHANGES_When_Casemapped}', "");
Expect(0, 66640, '\p{CHANGES_When_Casemapped}', "");
Expect(1, 66640, '\p{^CHANGES_When_Casemapped}', "");
Expect(1, 66640, '\P{CHANGES_When_Casemapped}', "");
Expect(0, 66640, '\P{^CHANGES_When_Casemapped}', "");
Error('\p{_:=Is_Changes_WHEN_CASEMAPPED}');
Error('\P{_:=Is_Changes_WHEN_CASEMAPPED}');
Expect(1, 66639, '\p{ischangeswhencasemapped}', "");
Expect(0, 66639, '\p{^ischangeswhencasemapped}', "");
Expect(0, 66639, '\P{ischangeswhencasemapped}', "");
Expect(1, 66639, '\P{^ischangeswhencasemapped}', "");
Expect(0, 66640, '\p{ischangeswhencasemapped}', "");
Expect(1, 66640, '\p{^ischangeswhencasemapped}', "");
Expect(1, 66640, '\P{ischangeswhencasemapped}', "");
Expect(0, 66640, '\P{^ischangeswhencasemapped}', "");
Expect(1, 66639, '\p{-	Is_CHANGES_when_CASEMAPPED}', "");
Expect(0, 66639, '\p{^-	Is_CHANGES_when_CASEMAPPED}', "");
Expect(0, 66639, '\P{-	Is_CHANGES_when_CASEMAPPED}', "");
Expect(1, 66639, '\P{^-	Is_CHANGES_when_CASEMAPPED}', "");
Expect(0, 66640, '\p{-	Is_CHANGES_when_CASEMAPPED}', "");
Expect(1, 66640, '\p{^-	Is_CHANGES_when_CASEMAPPED}', "");
Expect(1, 66640, '\P{-	Is_CHANGES_when_CASEMAPPED}', "");
Expect(0, 66640, '\P{^-	Is_CHANGES_when_CASEMAPPED}', "");
Error('\p{/a/_CWCM}');
Error('\P{/a/_CWCM}');
Expect(1, 66639, '\p{cwcm}', "");
Expect(0, 66639, '\p{^cwcm}', "");
Expect(0, 66639, '\P{cwcm}', "");
Expect(1, 66639, '\P{^cwcm}', "");
Expect(0, 66640, '\p{cwcm}', "");
Expect(1, 66640, '\p{^cwcm}', "");
Expect(1, 66640, '\P{cwcm}', "");
Expect(0, 66640, '\P{^cwcm}', "");
Expect(1, 66639, '\p{ _cwcm}', "");
Expect(0, 66639, '\p{^ _cwcm}', "");
Expect(0, 66639, '\P{ _cwcm}', "");
Expect(1, 66639, '\P{^ _cwcm}', "");
Expect(0, 66640, '\p{ _cwcm}', "");
Expect(1, 66640, '\p{^ _cwcm}', "");
Expect(1, 66640, '\P{ _cwcm}', "");
Expect(0, 66640, '\P{^ _cwcm}', "");
Error('\p{-IS_CWCM:=}');
Error('\P{-IS_CWCM:=}');
Expect(1, 66639, '\p{iscwcm}', "");
Expect(0, 66639, '\p{^iscwcm}', "");
Expect(0, 66639, '\P{iscwcm}', "");
Expect(1, 66639, '\P{^iscwcm}', "");
Expect(0, 66640, '\p{iscwcm}', "");
Expect(1, 66640, '\p{^iscwcm}', "");
Expect(1, 66640, '\P{iscwcm}', "");
Expect(0, 66640, '\P{^iscwcm}', "");
Expect(1, 66639, '\p{ _IS_CWCM}', "");
Expect(0, 66639, '\p{^ _IS_CWCM}', "");
Expect(0, 66639, '\P{ _IS_CWCM}', "");
Expect(1, 66639, '\P{^ _IS_CWCM}', "");
Expect(0, 66640, '\p{ _IS_CWCM}', "");
Expect(1, 66640, '\p{^ _IS_CWCM}', "");
Expect(1, 66640, '\P{ _IS_CWCM}', "");
Expect(0, 66640, '\P{^ _IS_CWCM}', "");
Error('\p{/a/Changes_WHEN_LOWERCASED}');
Error('\P{/a/Changes_WHEN_LOWERCASED}');
Expect(1, 66599, '\p{changeswhenlowercased}', "");
Expect(0, 66599, '\p{^changeswhenlowercased}', "");
Expect(0, 66599, '\P{changeswhenlowercased}', "");
Expect(1, 66599, '\P{^changeswhenlowercased}', "");
Expect(0, 66600, '\p{changeswhenlowercased}', "");
Expect(1, 66600, '\p{^changeswhenlowercased}', "");
Expect(1, 66600, '\P{changeswhenlowercased}', "");
Expect(0, 66600, '\P{^changeswhenlowercased}', "");
Expect(1, 66599, '\p{__changes_When_Lowercased}', "");
Expect(0, 66599, '\p{^__changes_When_Lowercased}', "");
Expect(0, 66599, '\P{__changes_When_Lowercased}', "");
Expect(1, 66599, '\P{^__changes_When_Lowercased}', "");
Expect(0, 66600, '\p{__changes_When_Lowercased}', "");
Expect(1, 66600, '\p{^__changes_When_Lowercased}', "");
Expect(1, 66600, '\P{__changes_When_Lowercased}', "");
Expect(0, 66600, '\P{^__changes_When_Lowercased}', "");
Error('\p{:=_	IS_Changes_WHEN_Lowercased}');
Error('\P{:=_	IS_Changes_WHEN_Lowercased}');
Expect(1, 66599, '\p{ischangeswhenlowercased}', "");
Expect(0, 66599, '\p{^ischangeswhenlowercased}', "");
Expect(0, 66599, '\P{ischangeswhenlowercased}', "");
Expect(1, 66599, '\P{^ischangeswhenlowercased}', "");
Expect(0, 66600, '\p{ischangeswhenlowercased}', "");
Expect(1, 66600, '\p{^ischangeswhenlowercased}', "");
Expect(1, 66600, '\P{ischangeswhenlowercased}', "");
Expect(0, 66600, '\P{^ischangeswhenlowercased}', "");
Expect(1, 66599, '\p{ 	Is_CHANGES_when_Lowercased}', "");
Expect(0, 66599, '\p{^ 	Is_CHANGES_when_Lowercased}', "");
Expect(0, 66599, '\P{ 	Is_CHANGES_when_Lowercased}', "");
Expect(1, 66599, '\P{^ 	Is_CHANGES_when_Lowercased}', "");
Expect(0, 66600, '\p{ 	Is_CHANGES_when_Lowercased}', "");
Expect(1, 66600, '\p{^ 	Is_CHANGES_when_Lowercased}', "");
Expect(1, 66600, '\P{ 	Is_CHANGES_when_Lowercased}', "");
Expect(0, 66600, '\P{^ 	Is_CHANGES_when_Lowercased}', "");
Error('\p{:=_CWL}');
Error('\P{:=_CWL}');
Expect(1, 66599, '\p{cwl}', "");
Expect(0, 66599, '\p{^cwl}', "");
Expect(0, 66599, '\P{cwl}', "");
Expect(1, 66599, '\P{^cwl}', "");
Expect(0, 66600, '\p{cwl}', "");
Expect(1, 66600, '\p{^cwl}', "");
Expect(1, 66600, '\P{cwl}', "");
Expect(0, 66600, '\P{^cwl}', "");
Expect(1, 66599, '\p{_ CWL}', "");
Expect(0, 66599, '\p{^_ CWL}', "");
Expect(0, 66599, '\P{_ CWL}', "");
Expect(1, 66599, '\P{^_ CWL}', "");
Expect(0, 66600, '\p{_ CWL}', "");
Expect(1, 66600, '\p{^_ CWL}', "");
Expect(1, 66600, '\P{_ CWL}', "");
Expect(0, 66600, '\P{^_ CWL}', "");
Error('\p{:=is_CWL}');
Error('\P{:=is_CWL}');
Expect(1, 66599, '\p{iscwl}', "");
Expect(0, 66599, '\p{^iscwl}', "");
Expect(0, 66599, '\P{iscwl}', "");
Expect(1, 66599, '\P{^iscwl}', "");
Expect(0, 66600, '\p{iscwl}', "");
Expect(1, 66600, '\p{^iscwl}', "");
Expect(1, 66600, '\P{iscwl}', "");
Expect(0, 66600, '\P{^iscwl}', "");
Expect(1, 66599, '\p{ 	is_CWL}', "");
Expect(0, 66599, '\p{^ 	is_CWL}', "");
Expect(0, 66599, '\P{ 	is_CWL}', "");
Expect(1, 66599, '\P{^ 	is_CWL}', "");
Expect(0, 66600, '\p{ 	is_CWL}', "");
Expect(1, 66600, '\p{^ 	is_CWL}', "");
Expect(1, 66600, '\P{ 	is_CWL}', "");
Expect(0, 66600, '\P{^ 	is_CWL}', "");
Error('\p{	Changes_WHEN_NFKC_casefolded:=}');
Error('\P{	Changes_WHEN_NFKC_casefolded:=}');
Expect(1, 921599, '\p{changeswhennfkccasefolded}', "");
Expect(0, 921599, '\p{^changeswhennfkccasefolded}', "");
Expect(0, 921599, '\P{changeswhennfkccasefolded}', "");
Expect(1, 921599, '\P{^changeswhennfkccasefolded}', "");
Expect(0, 921600, '\p{changeswhennfkccasefolded}', "");
Expect(1, 921600, '\p{^changeswhennfkccasefolded}', "");
Expect(1, 921600, '\P{changeswhennfkccasefolded}', "");
Expect(0, 921600, '\P{^changeswhennfkccasefolded}', "");
Expect(1, 921599, '\p{_	changes_when_NFKC_Casefolded}', "");
Expect(0, 921599, '\p{^_	changes_when_NFKC_Casefolded}', "");
Expect(0, 921599, '\P{_	changes_when_NFKC_Casefolded}', "");
Expect(1, 921599, '\P{^_	changes_when_NFKC_Casefolded}', "");
Expect(0, 921600, '\p{_	changes_when_NFKC_Casefolded}', "");
Expect(1, 921600, '\p{^_	changes_when_NFKC_Casefolded}', "");
Expect(1, 921600, '\P{_	changes_when_NFKC_Casefolded}', "");
Expect(0, 921600, '\P{^_	changes_when_NFKC_Casefolded}', "");
Error('\p{:=_	is_changes_when_NFKC_CASEFOLDED}');
Error('\P{:=_	is_changes_when_NFKC_CASEFOLDED}');
Expect(1, 921599, '\p{ischangeswhennfkccasefolded}', "");
Expect(0, 921599, '\p{^ischangeswhennfkccasefolded}', "");
Expect(0, 921599, '\P{ischangeswhennfkccasefolded}', "");
Expect(1, 921599, '\P{^ischangeswhennfkccasefolded}', "");
Expect(0, 921600, '\p{ischangeswhennfkccasefolded}', "");
Expect(1, 921600, '\p{^ischangeswhennfkccasefolded}', "");
Expect(1, 921600, '\P{ischangeswhennfkccasefolded}', "");
Expect(0, 921600, '\P{^ischangeswhennfkccasefolded}', "");
Expect(1, 921599, '\p{	-Is_CHANGES_when_NFKC_Casefolded}', "");
Expect(0, 921599, '\p{^	-Is_CHANGES_when_NFKC_Casefolded}', "");
Expect(0, 921599, '\P{	-Is_CHANGES_when_NFKC_Casefolded}', "");
Expect(1, 921599, '\P{^	-Is_CHANGES_when_NFKC_Casefolded}', "");
Expect(0, 921600, '\p{	-Is_CHANGES_when_NFKC_Casefolded}', "");
Expect(1, 921600, '\p{^	-Is_CHANGES_when_NFKC_Casefolded}', "");
Expect(1, 921600, '\P{	-Is_CHANGES_when_NFKC_Casefolded}', "");
Expect(0, 921600, '\P{^	-Is_CHANGES_when_NFKC_Casefolded}', "");
Error('\p{/a/CWKCF}');
Error('\P{/a/CWKCF}');
Expect(1, 921599, '\p{cwkcf}', "");
Expect(0, 921599, '\p{^cwkcf}', "");
Expect(0, 921599, '\P{cwkcf}', "");
Expect(1, 921599, '\P{^cwkcf}', "");
Expect(0, 921600, '\p{cwkcf}', "");
Expect(1, 921600, '\p{^cwkcf}', "");
Expect(1, 921600, '\P{cwkcf}', "");
Expect(0, 921600, '\P{^cwkcf}', "");
Expect(1, 921599, '\p{-	CWKCF}', "");
Expect(0, 921599, '\p{^-	CWKCF}', "");
Expect(0, 921599, '\P{-	CWKCF}', "");
Expect(1, 921599, '\P{^-	CWKCF}', "");
Expect(0, 921600, '\p{-	CWKCF}', "");
Expect(1, 921600, '\p{^-	CWKCF}', "");
Expect(1, 921600, '\P{-	CWKCF}', "");
Expect(0, 921600, '\P{^-	CWKCF}', "");
Error('\p{:=	_Is_cwkcf}');
Error('\P{:=	_Is_cwkcf}');
Expect(1, 921599, '\p{iscwkcf}', "");
Expect(0, 921599, '\p{^iscwkcf}', "");
Expect(0, 921599, '\P{iscwkcf}', "");
Expect(1, 921599, '\P{^iscwkcf}', "");
Expect(0, 921600, '\p{iscwkcf}', "");
Expect(1, 921600, '\p{^iscwkcf}', "");
Expect(1, 921600, '\P{iscwkcf}', "");
Expect(0, 921600, '\P{^iscwkcf}', "");
Expect(1, 921599, '\p{ -is_CWKCF}', "");
Expect(0, 921599, '\p{^ -is_CWKCF}', "");
Expect(0, 921599, '\P{ -is_CWKCF}', "");
Expect(1, 921599, '\P{^ -is_CWKCF}', "");
Expect(0, 921600, '\p{ -is_CWKCF}', "");
Expect(1, 921600, '\p{^ -is_CWKCF}', "");
Expect(1, 921600, '\P{ -is_CWKCF}', "");
Expect(0, 921600, '\P{^ -is_CWKCF}', "");
Error('\p{_:=Changes_when_Titlecased}');
Error('\P{_:=Changes_when_Titlecased}');
Expect(1, 66639, '\p{changeswhentitlecased}', "");
Expect(0, 66639, '\p{^changeswhentitlecased}', "");
Expect(0, 66639, '\P{changeswhentitlecased}', "");
Expect(1, 66639, '\P{^changeswhentitlecased}', "");
Expect(0, 66640, '\p{changeswhentitlecased}', "");
Expect(1, 66640, '\p{^changeswhentitlecased}', "");
Expect(1, 66640, '\P{changeswhentitlecased}', "");
Expect(0, 66640, '\P{^changeswhentitlecased}', "");
Expect(1, 66639, '\p{- Changes_when_titlecased}', "");
Expect(0, 66639, '\p{^- Changes_when_titlecased}', "");
Expect(0, 66639, '\P{- Changes_when_titlecased}', "");
Expect(1, 66639, '\P{^- Changes_when_titlecased}', "");
Expect(0, 66640, '\p{- Changes_when_titlecased}', "");
Expect(1, 66640, '\p{^- Changes_when_titlecased}', "");
Expect(1, 66640, '\P{- Changes_when_titlecased}', "");
Expect(0, 66640, '\P{^- Changes_when_titlecased}', "");
Error('\p{	-IS_CHANGES_WHEN_Titlecased/a/}');
Error('\P{	-IS_CHANGES_WHEN_Titlecased/a/}');
Expect(1, 66639, '\p{ischangeswhentitlecased}', "");
Expect(0, 66639, '\p{^ischangeswhentitlecased}', "");
Expect(0, 66639, '\P{ischangeswhentitlecased}', "");
Expect(1, 66639, '\P{^ischangeswhentitlecased}', "");
Expect(0, 66640, '\p{ischangeswhentitlecased}', "");
Expect(1, 66640, '\p{^ischangeswhentitlecased}', "");
Expect(1, 66640, '\P{ischangeswhentitlecased}', "");
Expect(0, 66640, '\P{^ischangeswhentitlecased}', "");
Expect(1, 66639, '\p{	Is_CHANGES_WHEN_Titlecased}', "");
Expect(0, 66639, '\p{^	Is_CHANGES_WHEN_Titlecased}', "");
Expect(0, 66639, '\P{	Is_CHANGES_WHEN_Titlecased}', "");
Expect(1, 66639, '\P{^	Is_CHANGES_WHEN_Titlecased}', "");
Expect(0, 66640, '\p{	Is_CHANGES_WHEN_Titlecased}', "");
Expect(1, 66640, '\p{^	Is_CHANGES_WHEN_Titlecased}', "");
Expect(1, 66640, '\P{	Is_CHANGES_WHEN_Titlecased}', "");
Expect(0, 66640, '\P{^	Is_CHANGES_WHEN_Titlecased}', "");
Error('\p{	 CWT/a/}');
Error('\P{	 CWT/a/}');
Expect(1, 66639, '\p{cwt}', "");
Expect(0, 66639, '\p{^cwt}', "");
Expect(0, 66639, '\P{cwt}', "");
Expect(1, 66639, '\P{^cwt}', "");
Expect(0, 66640, '\p{cwt}', "");
Expect(1, 66640, '\p{^cwt}', "");
Expect(1, 66640, '\P{cwt}', "");
Expect(0, 66640, '\P{^cwt}', "");
Expect(1, 66639, '\p{-CWT}', "");
Expect(0, 66639, '\p{^-CWT}', "");
Expect(0, 66639, '\P{-CWT}', "");
Expect(1, 66639, '\P{^-CWT}', "");
Expect(0, 66640, '\p{-CWT}', "");
Expect(1, 66640, '\p{^-CWT}', "");
Expect(1, 66640, '\P{-CWT}', "");
Expect(0, 66640, '\P{^-CWT}', "");
Error('\p{/a/_	Is_CWT}');
Error('\P{/a/_	Is_CWT}');
Expect(1, 66639, '\p{iscwt}', "");
Expect(0, 66639, '\p{^iscwt}', "");
Expect(0, 66639, '\P{iscwt}', "");
Expect(1, 66639, '\P{^iscwt}', "");
Expect(0, 66640, '\p{iscwt}', "");
Expect(1, 66640, '\p{^iscwt}', "");
Expect(1, 66640, '\P{iscwt}', "");
Expect(0, 66640, '\P{^iscwt}', "");
Expect(1, 66639, '\p{-Is_CWT}', "");
Expect(0, 66639, '\p{^-Is_CWT}', "");
Expect(0, 66639, '\P{-Is_CWT}', "");
Expect(1, 66639, '\P{^-Is_CWT}', "");
Expect(0, 66640, '\p{-Is_CWT}', "");
Expect(1, 66640, '\p{^-Is_CWT}', "");
Expect(1, 66640, '\P{-Is_CWT}', "");
Expect(0, 66640, '\P{^-Is_CWT}', "");
Error('\p{:= -Changes_WHEN_Uppercased}');
Error('\P{:= -Changes_WHEN_Uppercased}');
Expect(1, 66639, '\p{changeswhenuppercased}', "");
Expect(0, 66639, '\p{^changeswhenuppercased}', "");
Expect(0, 66639, '\P{changeswhenuppercased}', "");
Expect(1, 66639, '\P{^changeswhenuppercased}', "");
Expect(0, 66640, '\p{changeswhenuppercased}', "");
Expect(1, 66640, '\p{^changeswhenuppercased}', "");
Expect(1, 66640, '\P{changeswhenuppercased}', "");
Expect(0, 66640, '\P{^changeswhenuppercased}', "");
Expect(1, 66639, '\p{_ changes_When_Uppercased}', "");
Expect(0, 66639, '\p{^_ changes_When_Uppercased}', "");
Expect(0, 66639, '\P{_ changes_When_Uppercased}', "");
Expect(1, 66639, '\P{^_ changes_When_Uppercased}', "");
Expect(0, 66640, '\p{_ changes_When_Uppercased}', "");
Expect(1, 66640, '\p{^_ changes_When_Uppercased}', "");
Expect(1, 66640, '\P{_ changes_When_Uppercased}', "");
Expect(0, 66640, '\P{^_ changes_When_Uppercased}', "");
Error('\p{ -IS_Changes_When_uppercased/a/}');
Error('\P{ -IS_Changes_When_uppercased/a/}');
Expect(1, 66639, '\p{ischangeswhenuppercased}', "");
Expect(0, 66639, '\p{^ischangeswhenuppercased}', "");
Expect(0, 66639, '\P{ischangeswhenuppercased}', "");
Expect(1, 66639, '\P{^ischangeswhenuppercased}', "");
Expect(0, 66640, '\p{ischangeswhenuppercased}', "");
Expect(1, 66640, '\p{^ischangeswhenuppercased}', "");
Expect(1, 66640, '\P{ischangeswhenuppercased}', "");
Expect(0, 66640, '\P{^ischangeswhenuppercased}', "");
Expect(1, 66639, '\p{ _Is_Changes_When_UPPERCASED}', "");
Expect(0, 66639, '\p{^ _Is_Changes_When_UPPERCASED}', "");
Expect(0, 66639, '\P{ _Is_Changes_When_UPPERCASED}', "");
Expect(1, 66639, '\P{^ _Is_Changes_When_UPPERCASED}', "");
Expect(0, 66640, '\p{ _Is_Changes_When_UPPERCASED}', "");
Expect(1, 66640, '\p{^ _Is_Changes_When_UPPERCASED}', "");
Expect(1, 66640, '\P{ _Is_Changes_When_UPPERCASED}', "");
Expect(0, 66640, '\P{^ _Is_Changes_When_UPPERCASED}', "");
Error('\p{	:=cwu}');
Error('\P{	:=cwu}');
Expect(1, 66639, '\p{cwu}', "");
Expect(0, 66639, '\p{^cwu}', "");
Expect(0, 66639, '\P{cwu}', "");
Expect(1, 66639, '\P{^cwu}', "");
Expect(0, 66640, '\p{cwu}', "");
Expect(1, 66640, '\p{^cwu}', "");
Expect(1, 66640, '\P{cwu}', "");
Expect(0, 66640, '\P{^cwu}', "");
Expect(1, 66639, '\p{ CWU}', "");
Expect(0, 66639, '\p{^ CWU}', "");
Expect(0, 66639, '\P{ CWU}', "");
Expect(1, 66639, '\P{^ CWU}', "");
Expect(0, 66640, '\p{ CWU}', "");
Expect(1, 66640, '\p{^ CWU}', "");
Expect(1, 66640, '\P{ CWU}', "");
Expect(0, 66640, '\P{^ CWU}', "");
Error('\p{-IS_CWU:=}');
Error('\P{-IS_CWU:=}');
Expect(1, 66639, '\p{iscwu}', "");
Expect(0, 66639, '\p{^iscwu}', "");
Expect(0, 66639, '\P{iscwu}', "");
Expect(1, 66639, '\P{^iscwu}', "");
Expect(0, 66640, '\p{iscwu}', "");
Expect(1, 66640, '\p{^iscwu}', "");
Expect(1, 66640, '\P{iscwu}', "");
Expect(0, 66640, '\P{^iscwu}', "");
Expect(1, 66639, '\p{- Is_CWU}', "");
Expect(0, 66639, '\p{^- Is_CWU}', "");
Expect(0, 66639, '\P{- Is_CWU}', "");
Expect(1, 66639, '\P{^- Is_CWU}', "");
Expect(0, 66640, '\p{- Is_CWU}', "");
Expect(1, 66640, '\p{^- Is_CWU}', "");
Expect(1, 66640, '\P{- Is_CWU}', "");
Expect(0, 66640, '\P{^- Is_CWU}', "");
Error('\p{_:=Cherokee}');
Error('\P{_:=Cherokee}');
Expect(1, 5108, '\p{cherokee}', "");
Expect(0, 5108, '\p{^cherokee}', "");
Expect(0, 5108, '\P{cherokee}', "");
Expect(1, 5108, '\P{^cherokee}', "");
Expect(0, 5109, '\p{cherokee}', "");
Expect(1, 5109, '\p{^cherokee}', "");
Expect(1, 5109, '\P{cherokee}', "");
Expect(0, 5109, '\P{^cherokee}', "");
Expect(1, 5108, '\p{_-Cherokee}', "");
Expect(0, 5108, '\p{^_-Cherokee}', "");
Expect(0, 5108, '\P{_-Cherokee}', "");
Expect(1, 5108, '\P{^_-Cherokee}', "");
Expect(0, 5109, '\p{_-Cherokee}', "");
Expect(1, 5109, '\p{^_-Cherokee}', "");
Expect(1, 5109, '\P{_-Cherokee}', "");
Expect(0, 5109, '\P{^_-Cherokee}', "");
Error('\p{	/a/is_CHEROKEE}');
Error('\P{	/a/is_CHEROKEE}');
Expect(1, 5108, '\p{ischerokee}', "");
Expect(0, 5108, '\p{^ischerokee}', "");
Expect(0, 5108, '\P{ischerokee}', "");
Expect(1, 5108, '\P{^ischerokee}', "");
Expect(0, 5109, '\p{ischerokee}', "");
Expect(1, 5109, '\p{^ischerokee}', "");
Expect(1, 5109, '\P{ischerokee}', "");
Expect(0, 5109, '\P{^ischerokee}', "");
Expect(1, 5108, '\p{  is_Cherokee}', "");
Expect(0, 5108, '\p{^  is_Cherokee}', "");
Expect(0, 5108, '\P{  is_Cherokee}', "");
Expect(1, 5108, '\P{^  is_Cherokee}', "");
Expect(0, 5109, '\p{  is_Cherokee}', "");
Expect(1, 5109, '\p{^  is_Cherokee}', "");
Expect(1, 5109, '\P{  is_Cherokee}', "");
Expect(0, 5109, '\P{^  is_Cherokee}', "");
Error('\p{-/a/cher}');
Error('\P{-/a/cher}');
Expect(1, 5108, '\p{cher}', "");
Expect(0, 5108, '\p{^cher}', "");
Expect(0, 5108, '\P{cher}', "");
Expect(1, 5108, '\P{^cher}', "");
Expect(0, 5109, '\p{cher}', "");
Expect(1, 5109, '\p{^cher}', "");
Expect(1, 5109, '\P{cher}', "");
Expect(0, 5109, '\P{^cher}', "");
Expect(1, 5108, '\p{-Cher}', "");
Expect(0, 5108, '\p{^-Cher}', "");
Expect(0, 5108, '\P{-Cher}', "");
Expect(1, 5108, '\P{^-Cher}', "");
Expect(0, 5109, '\p{-Cher}', "");
Expect(1, 5109, '\p{^-Cher}', "");
Expect(1, 5109, '\P{-Cher}', "");
Expect(0, 5109, '\P{^-Cher}', "");
Error('\p{-is_Cher/a/}');
Error('\P{-is_Cher/a/}');
Expect(1, 5108, '\p{ischer}', "");
Expect(0, 5108, '\p{^ischer}', "");
Expect(0, 5108, '\P{ischer}', "");
Expect(1, 5108, '\P{^ischer}', "");
Expect(0, 5109, '\p{ischer}', "");
Expect(1, 5109, '\p{^ischer}', "");
Expect(1, 5109, '\P{ischer}', "");
Expect(0, 5109, '\P{^ischer}', "");
Expect(1, 5108, '\p{- IS_CHER}', "");
Expect(0, 5108, '\p{^- IS_CHER}', "");
Expect(0, 5108, '\P{- IS_CHER}', "");
Expect(1, 5108, '\P{^- IS_CHER}', "");
Expect(0, 5109, '\p{- IS_CHER}', "");
Expect(1, 5109, '\p{^- IS_CHER}', "");
Expect(1, 5109, '\P{- IS_CHER}', "");
Expect(0, 5109, '\P{^- IS_CHER}', "");
Error('\p{_-Close_Punctuation/a/}');
Error('\P{_-Close_Punctuation/a/}');
Expect(1, 65379, '\p{closepunctuation}', "");
Expect(0, 65379, '\p{^closepunctuation}', "");
Expect(0, 65379, '\P{closepunctuation}', "");
Expect(1, 65379, '\P{^closepunctuation}', "");
Expect(0, 65380, '\p{closepunctuation}', "");
Expect(1, 65380, '\p{^closepunctuation}', "");
Expect(1, 65380, '\P{closepunctuation}', "");
Expect(0, 65380, '\P{^closepunctuation}', "");
Expect(1, 65379, '\p{	Close_punctuation}', "");
Expect(0, 65379, '\p{^	Close_punctuation}', "");
Expect(0, 65379, '\P{	Close_punctuation}', "");
Expect(1, 65379, '\P{^	Close_punctuation}', "");
Expect(0, 65380, '\p{	Close_punctuation}', "");
Expect(1, 65380, '\p{^	Close_punctuation}', "");
Expect(1, 65380, '\P{	Close_punctuation}', "");
Expect(0, 65380, '\P{^	Close_punctuation}', "");
Error('\p{:= is_CLOSE_punctuation}');
Error('\P{:= is_CLOSE_punctuation}');
Expect(1, 65379, '\p{isclosepunctuation}', "");
Expect(0, 65379, '\p{^isclosepunctuation}', "");
Expect(0, 65379, '\P{isclosepunctuation}', "");
Expect(1, 65379, '\P{^isclosepunctuation}', "");
Expect(0, 65380, '\p{isclosepunctuation}', "");
Expect(1, 65380, '\p{^isclosepunctuation}', "");
Expect(1, 65380, '\P{isclosepunctuation}', "");
Expect(0, 65380, '\P{^isclosepunctuation}', "");
Expect(1, 65379, '\p{	 Is_Close_Punctuation}', "");
Expect(0, 65379, '\p{^	 Is_Close_Punctuation}', "");
Expect(0, 65379, '\P{	 Is_Close_Punctuation}', "");
Expect(1, 65379, '\P{^	 Is_Close_Punctuation}', "");
Expect(0, 65380, '\p{	 Is_Close_Punctuation}', "");
Expect(1, 65380, '\p{^	 Is_Close_Punctuation}', "");
Expect(1, 65380, '\P{	 Is_Close_Punctuation}', "");
Expect(0, 65380, '\P{^	 Is_Close_Punctuation}', "");
Error('\p{_ Pe:=}');
Error('\P{_ Pe:=}');
Expect(1, 65379, '\p{pe}', "");
Expect(0, 65379, '\p{^pe}', "");
Expect(0, 65379, '\P{pe}', "");
Expect(1, 65379, '\P{^pe}', "");
Expect(0, 65380, '\p{pe}', "");
Expect(1, 65380, '\p{^pe}', "");
Expect(1, 65380, '\P{pe}', "");
Expect(0, 65380, '\P{^pe}', "");
Expect(1, 65379, '\p{Pe}', "");
Expect(0, 65379, '\p{^Pe}', "");
Expect(0, 65379, '\P{Pe}', "");
Expect(1, 65379, '\P{^Pe}', "");
Expect(0, 65380, '\p{Pe}', "");
Expect(1, 65380, '\p{^Pe}', "");
Expect(1, 65380, '\P{Pe}', "");
Expect(0, 65380, '\P{^Pe}', "");
Error('\p{-:=is_Pe}');
Error('\P{-:=is_Pe}');
Expect(1, 65379, '\p{ispe}', "");
Expect(0, 65379, '\p{^ispe}', "");
Expect(0, 65379, '\P{ispe}', "");
Expect(1, 65379, '\P{^ispe}', "");
Expect(0, 65380, '\p{ispe}', "");
Expect(1, 65380, '\p{^ispe}', "");
Expect(1, 65380, '\P{ispe}', "");
Expect(0, 65380, '\P{^ispe}', "");
Expect(1, 65379, '\p{-IS_PE}', "");
Expect(0, 65379, '\p{^-IS_PE}', "");
Expect(0, 65379, '\P{-IS_PE}', "");
Expect(1, 65379, '\P{^-IS_PE}', "");
Expect(0, 65380, '\p{-IS_PE}', "");
Expect(1, 65380, '\p{^-IS_PE}', "");
Expect(1, 65380, '\P{-IS_PE}', "");
Expect(0, 65380, '\P{^-IS_PE}', "");
Error('\p{:=_-Cntrl}');
Error('\P{:=_-Cntrl}');
Expect(1, 159, '\p{cntrl}', "");
Expect(0, 159, '\p{^cntrl}', "");
Expect(0, 159, '\P{cntrl}', "");
Expect(1, 159, '\P{^cntrl}', "");
Expect(0, 160, '\p{cntrl}', "");
Expect(1, 160, '\p{^cntrl}', "");
Expect(1, 160, '\P{cntrl}', "");
Expect(0, 160, '\P{^cntrl}', "");
Expect(1, 159, '\p{-CNTRL}', "");
Expect(0, 159, '\p{^-CNTRL}', "");
Expect(0, 159, '\P{-CNTRL}', "");
Expect(1, 159, '\P{^-CNTRL}', "");
Expect(0, 160, '\p{-CNTRL}', "");
Expect(1, 160, '\p{^-CNTRL}', "");
Expect(1, 160, '\P{-CNTRL}', "");
Expect(0, 160, '\P{^-CNTRL}', "");
Error('\p{/a/_	XPosixCntrl}');
Error('\P{/a/_	XPosixCntrl}');
Expect(1, 159, '\p{xposixcntrl}', "");
Expect(0, 159, '\p{^xposixcntrl}', "");
Expect(0, 159, '\P{xposixcntrl}', "");
Expect(1, 159, '\P{^xposixcntrl}', "");
Expect(0, 160, '\p{xposixcntrl}', "");
Expect(1, 160, '\p{^xposixcntrl}', "");
Expect(1, 160, '\P{xposixcntrl}', "");
Expect(0, 160, '\P{^xposixcntrl}', "");
Expect(1, 159, '\p{ -XPosixCntrl}', "");
Expect(0, 159, '\p{^ -XPosixCntrl}', "");
Expect(0, 159, '\P{ -XPosixCntrl}', "");
Expect(1, 159, '\P{^ -XPosixCntrl}', "");
Expect(0, 160, '\p{ -XPosixCntrl}', "");
Expect(1, 160, '\p{^ -XPosixCntrl}', "");
Expect(1, 160, '\P{ -XPosixCntrl}', "");
Expect(0, 160, '\P{^ -XPosixCntrl}', "");
Error('\p{_	is_cntrl:=}');
Error('\P{_	is_cntrl:=}');
Expect(1, 159, '\p{iscntrl}', "");
Expect(0, 159, '\p{^iscntrl}', "");
Expect(0, 159, '\P{iscntrl}', "");
Expect(1, 159, '\P{^iscntrl}', "");
Expect(0, 160, '\p{iscntrl}', "");
Expect(1, 160, '\p{^iscntrl}', "");
Expect(1, 160, '\P{iscntrl}', "");
Expect(0, 160, '\P{^iscntrl}', "");
Expect(1, 159, '\p{ 	Is_cntrl}', "");
Expect(0, 159, '\p{^ 	Is_cntrl}', "");
Expect(0, 159, '\P{ 	Is_cntrl}', "");
Expect(1, 159, '\P{^ 	Is_cntrl}', "");
Expect(0, 160, '\p{ 	Is_cntrl}', "");
Expect(1, 160, '\p{^ 	Is_cntrl}', "");
Expect(1, 160, '\P{ 	Is_cntrl}', "");
Expect(0, 160, '\P{^ 	Is_cntrl}', "");
Error('\p{	:=Is_XPOSIXCNTRL}');
Error('\P{	:=Is_XPOSIXCNTRL}');
Expect(1, 159, '\p{isxposixcntrl}', "");
Expect(0, 159, '\p{^isxposixcntrl}', "");
Expect(0, 159, '\P{isxposixcntrl}', "");
Expect(1, 159, '\P{^isxposixcntrl}', "");
Expect(0, 160, '\p{isxposixcntrl}', "");
Expect(1, 160, '\p{^isxposixcntrl}', "");
Expect(1, 160, '\P{isxposixcntrl}', "");
Expect(0, 160, '\P{^isxposixcntrl}', "");
Expect(1, 159, '\p{-_Is_xposixcntrl}', "");
Expect(0, 159, '\p{^-_Is_xposixcntrl}', "");
Expect(0, 159, '\P{-_Is_xposixcntrl}', "");
Expect(1, 159, '\P{^-_Is_xposixcntrl}', "");
Expect(0, 160, '\p{-_Is_xposixcntrl}', "");
Expect(1, 160, '\p{^-_Is_xposixcntrl}', "");
Expect(1, 160, '\P{-_Is_xposixcntrl}', "");
Expect(0, 160, '\P{^-_Is_xposixcntrl}', "");
Error('\p{	Control/a/}');
Error('\P{	Control/a/}');
Expect(1, 159, '\p{control}', "");
Expect(0, 159, '\p{^control}', "");
Expect(0, 159, '\P{control}', "");
Expect(1, 159, '\P{^control}', "");
Expect(0, 160, '\p{control}', "");
Expect(1, 160, '\p{^control}', "");
Expect(1, 160, '\P{control}', "");
Expect(0, 160, '\P{^control}', "");
Expect(1, 159, '\p{ -CONTROL}', "");
Expect(0, 159, '\p{^ -CONTROL}', "");
Expect(0, 159, '\P{ -CONTROL}', "");
Expect(1, 159, '\P{^ -CONTROL}', "");
Expect(0, 160, '\p{ -CONTROL}', "");
Expect(1, 160, '\p{^ -CONTROL}', "");
Expect(1, 160, '\P{ -CONTROL}', "");
Expect(0, 160, '\P{^ -CONTROL}', "");
Error('\p{_ Is_CONTROL:=}');
Error('\P{_ Is_CONTROL:=}');
Expect(1, 159, '\p{iscontrol}', "");
Expect(0, 159, '\p{^iscontrol}', "");
Expect(0, 159, '\P{iscontrol}', "");
Expect(1, 159, '\P{^iscontrol}', "");
Expect(0, 160, '\p{iscontrol}', "");
Expect(1, 160, '\p{^iscontrol}', "");
Expect(1, 160, '\P{iscontrol}', "");
Expect(0, 160, '\P{^iscontrol}', "");
Expect(1, 159, '\p{-_Is_CONTROL}', "");
Expect(0, 159, '\p{^-_Is_CONTROL}', "");
Expect(0, 159, '\P{-_Is_CONTROL}', "");
Expect(1, 159, '\P{^-_Is_CONTROL}', "");
Expect(0, 160, '\p{-_Is_CONTROL}', "");
Expect(1, 160, '\p{^-_Is_CONTROL}', "");
Expect(1, 160, '\P{-_Is_CONTROL}', "");
Expect(0, 160, '\P{^-_Is_CONTROL}', "");
Error('\p{ Cc:=}');
Error('\P{ Cc:=}');
Expect(1, 159, '\p{cc}', "");
Expect(0, 159, '\p{^cc}', "");
Expect(0, 159, '\P{cc}', "");
Expect(1, 159, '\P{^cc}', "");
Expect(0, 160, '\p{cc}', "");
Expect(1, 160, '\p{^cc}', "");
Expect(1, 160, '\P{cc}', "");
Expect(0, 160, '\P{^cc}', "");
Expect(1, 159, '\p{__cc}', "");
Expect(0, 159, '\p{^__cc}', "");
Expect(0, 159, '\P{__cc}', "");
Expect(1, 159, '\P{^__cc}', "");
Expect(0, 160, '\p{__cc}', "");
Expect(1, 160, '\p{^__cc}', "");
Expect(1, 160, '\P{__cc}', "");
Expect(0, 160, '\P{^__cc}', "");
Error('\p{	/a/IS_CC}');
Error('\P{	/a/IS_CC}');
Expect(1, 159, '\p{iscc}', "");
Expect(0, 159, '\p{^iscc}', "");
Expect(0, 159, '\P{iscc}', "");
Expect(1, 159, '\P{^iscc}', "");
Expect(0, 160, '\p{iscc}', "");
Expect(1, 160, '\p{^iscc}', "");
Expect(1, 160, '\P{iscc}', "");
Expect(0, 160, '\P{^iscc}', "");
Expect(1, 159, '\p{ Is_Cc}', "");
Expect(0, 159, '\p{^ Is_Cc}', "");
Expect(0, 159, '\P{ Is_Cc}', "");
Expect(1, 159, '\P{^ Is_Cc}', "");
Expect(0, 160, '\p{ Is_Cc}', "");
Expect(1, 160, '\p{^ Is_Cc}', "");
Expect(1, 160, '\P{ Is_Cc}', "");
Expect(0, 160, '\P{^ Is_Cc}', "");
Error('\p{ /a/combining_diacritical_Marks}');
Error('\P{ /a/combining_diacritical_Marks}');
Expect(1, 879, '\p{combiningdiacriticalmarks}', "");
Expect(0, 879, '\p{^combiningdiacriticalmarks}', "");
Expect(0, 879, '\P{combiningdiacriticalmarks}', "");
Expect(1, 879, '\P{^combiningdiacriticalmarks}', "");
Expect(0, 880, '\p{combiningdiacriticalmarks}', "");
Expect(1, 880, '\p{^combiningdiacriticalmarks}', "");
Expect(1, 880, '\P{combiningdiacriticalmarks}', "");
Expect(0, 880, '\P{^combiningdiacriticalmarks}', "");
Expect(1, 879, '\p{Combining_diacritical_Marks}', "");
Expect(0, 879, '\p{^Combining_diacritical_Marks}', "");
Expect(0, 879, '\P{Combining_diacritical_Marks}', "");
Expect(1, 879, '\P{^Combining_diacritical_Marks}', "");
Expect(0, 880, '\p{Combining_diacritical_Marks}', "");
Expect(1, 880, '\p{^Combining_diacritical_Marks}', "");
Expect(1, 880, '\P{Combining_diacritical_Marks}', "");
Expect(0, 880, '\P{^Combining_diacritical_Marks}', "");
Error('\p{	:=Is_combining_DIACRITICAL_marks}');
Error('\P{	:=Is_combining_DIACRITICAL_marks}');
Expect(1, 879, '\p{iscombiningdiacriticalmarks}', "");
Expect(0, 879, '\p{^iscombiningdiacriticalmarks}', "");
Expect(0, 879, '\P{iscombiningdiacriticalmarks}', "");
Expect(1, 879, '\P{^iscombiningdiacriticalmarks}', "");
Expect(0, 880, '\p{iscombiningdiacriticalmarks}', "");
Expect(1, 880, '\p{^iscombiningdiacriticalmarks}', "");
Expect(1, 880, '\P{iscombiningdiacriticalmarks}', "");
Expect(0, 880, '\P{^iscombiningdiacriticalmarks}', "");
Expect(1, 879, '\p{ _IS_combining_Diacritical_Marks}', "");
Expect(0, 879, '\p{^ _IS_combining_Diacritical_Marks}', "");
Expect(0, 879, '\P{ _IS_combining_Diacritical_Marks}', "");
Expect(1, 879, '\P{^ _IS_combining_Diacritical_Marks}', "");
Expect(0, 880, '\p{ _IS_combining_Diacritical_Marks}', "");
Expect(1, 880, '\p{^ _IS_combining_Diacritical_Marks}', "");
Expect(1, 880, '\P{ _IS_combining_Diacritical_Marks}', "");
Expect(0, 880, '\P{^ _IS_combining_Diacritical_Marks}', "");
Error('\p{/a/_-IN_Combining_Diacritical_Marks}');
Error('\P{/a/_-IN_Combining_Diacritical_Marks}');
Expect(1, 879, '\p{incombiningdiacriticalmarks}', "");
Expect(0, 879, '\p{^incombiningdiacriticalmarks}', "");
Expect(0, 879, '\P{incombiningdiacriticalmarks}', "");
Expect(1, 879, '\P{^incombiningdiacriticalmarks}', "");
Expect(0, 880, '\p{incombiningdiacriticalmarks}', "");
Expect(1, 880, '\p{^incombiningdiacriticalmarks}', "");
Expect(1, 880, '\P{incombiningdiacriticalmarks}', "");
Expect(0, 880, '\P{^incombiningdiacriticalmarks}', "");
Expect(1, 879, '\p{__In_COMBINING_Diacritical_Marks}', "");
Expect(0, 879, '\p{^__In_COMBINING_Diacritical_Marks}', "");
Expect(0, 879, '\P{__In_COMBINING_Diacritical_Marks}', "");
Expect(1, 879, '\P{^__In_COMBINING_Diacritical_Marks}', "");
Expect(0, 880, '\p{__In_COMBINING_Diacritical_Marks}', "");
Expect(1, 880, '\p{^__In_COMBINING_Diacritical_Marks}', "");
Expect(1, 880, '\P{__In_COMBINING_Diacritical_Marks}', "");
Expect(0, 880, '\P{^__In_COMBINING_Diacritical_Marks}', "");
Error('\p{:= -diacriticals}');
Error('\P{:= -diacriticals}');
Expect(1, 879, '\p{diacriticals}', "");
Expect(0, 879, '\p{^diacriticals}', "");
Expect(0, 879, '\P{diacriticals}', "");
Expect(1, 879, '\P{^diacriticals}', "");
Expect(0, 880, '\p{diacriticals}', "");
Expect(1, 880, '\p{^diacriticals}', "");
Expect(1, 880, '\P{diacriticals}', "");
Expect(0, 880, '\P{^diacriticals}', "");
Expect(1, 879, '\p{	-DIACRITICALS}', "");
Expect(0, 879, '\p{^	-DIACRITICALS}', "");
Expect(0, 879, '\P{	-DIACRITICALS}', "");
Expect(1, 879, '\P{^	-DIACRITICALS}', "");
Expect(0, 880, '\p{	-DIACRITICALS}', "");
Expect(1, 880, '\p{^	-DIACRITICALS}', "");
Expect(1, 880, '\P{	-DIACRITICALS}', "");
Expect(0, 880, '\P{^	-DIACRITICALS}', "");
Error('\p{ IS_Diacriticals/a/}');
Error('\P{ IS_Diacriticals/a/}');
Expect(1, 879, '\p{isdiacriticals}', "");
Expect(0, 879, '\p{^isdiacriticals}', "");
Expect(0, 879, '\P{isdiacriticals}', "");
Expect(1, 879, '\P{^isdiacriticals}', "");
Expect(0, 880, '\p{isdiacriticals}', "");
Expect(1, 880, '\p{^isdiacriticals}', "");
Expect(1, 880, '\P{isdiacriticals}', "");
Expect(0, 880, '\P{^isdiacriticals}', "");
Expect(1, 879, '\p{	IS_diacriticals}', "");
Expect(0, 879, '\p{^	IS_diacriticals}', "");
Expect(0, 879, '\P{	IS_diacriticals}', "");
Expect(1, 879, '\P{^	IS_diacriticals}', "");
Expect(0, 880, '\p{	IS_diacriticals}', "");
Expect(1, 880, '\p{^	IS_diacriticals}', "");
Expect(1, 880, '\P{	IS_diacriticals}', "");
Expect(0, 880, '\P{^	IS_diacriticals}', "");
Error('\p{-/a/In_Diacriticals}');
Error('\P{-/a/In_Diacriticals}');
Expect(1, 879, '\p{indiacriticals}', "");
Expect(0, 879, '\p{^indiacriticals}', "");
Expect(0, 879, '\P{indiacriticals}', "");
Expect(1, 879, '\P{^indiacriticals}', "");
Expect(0, 880, '\p{indiacriticals}', "");
Expect(1, 880, '\p{^indiacriticals}', "");
Expect(1, 880, '\P{indiacriticals}', "");
Expect(0, 880, '\P{^indiacriticals}', "");
Expect(1, 879, '\p{ 	In_Diacriticals}', "");
Expect(0, 879, '\p{^ 	In_Diacriticals}', "");
Expect(0, 879, '\P{ 	In_Diacriticals}', "");
Expect(1, 879, '\P{^ 	In_Diacriticals}', "");
Expect(0, 880, '\p{ 	In_Diacriticals}', "");
Expect(1, 880, '\p{^ 	In_Diacriticals}', "");
Expect(1, 880, '\P{ 	In_Diacriticals}', "");
Expect(0, 880, '\P{^ 	In_Diacriticals}', "");
Error('\p{:=_-combining_diacritical_MARKS_FOR_symbols}');
Error('\P{:=_-combining_diacritical_MARKS_FOR_symbols}');
Expect(1, 8447, '\p{combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\p{^combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\P{combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\P{^combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\p{combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\p{^combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\P{combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\P{^combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\p{Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(0, 8447, '\p{^Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(0, 8447, '\P{Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(1, 8447, '\P{^Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(0, 8448, '\p{Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(1, 8448, '\p{^Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(1, 8448, '\P{Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(0, 8448, '\P{^Combining_Diacritical_Marks_For_SYMBOLS}', "");
Error('\p{/a/-IS_Combining_DIACRITICAL_Marks_For_Symbols}');
Error('\P{/a/-IS_Combining_DIACRITICAL_Marks_For_Symbols}');
Expect(1, 8447, '\p{iscombiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\p{^iscombiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\P{iscombiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\P{^iscombiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\p{iscombiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\p{^iscombiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\P{iscombiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\P{^iscombiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\p{  Is_Combining_Diacritical_Marks_For_Symbols}', "");
Expect(0, 8447, '\p{^  Is_Combining_Diacritical_Marks_For_Symbols}', "");
Expect(0, 8447, '\P{  Is_Combining_Diacritical_Marks_For_Symbols}', "");
Expect(1, 8447, '\P{^  Is_Combining_Diacritical_Marks_For_Symbols}', "");
Expect(0, 8448, '\p{  Is_Combining_Diacritical_Marks_For_Symbols}', "");
Expect(1, 8448, '\p{^  Is_Combining_Diacritical_Marks_For_Symbols}', "");
Expect(1, 8448, '\P{  Is_Combining_Diacritical_Marks_For_Symbols}', "");
Expect(0, 8448, '\P{^  Is_Combining_Diacritical_Marks_For_Symbols}', "");
Error('\p{	_IN_COMBINING_Diacritical_MARKS_For_Symbols:=}');
Error('\P{	_IN_COMBINING_Diacritical_MARKS_For_Symbols:=}');
Expect(1, 8447, '\p{incombiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\p{^incombiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\P{incombiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\P{^incombiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\p{incombiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\p{^incombiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\P{incombiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\P{^incombiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\p{-_In_combining_diacritical_Marks_For_Symbols}', "");
Expect(0, 8447, '\p{^-_In_combining_diacritical_Marks_For_Symbols}', "");
Expect(0, 8447, '\P{-_In_combining_diacritical_Marks_For_Symbols}', "");
Expect(1, 8447, '\P{^-_In_combining_diacritical_Marks_For_Symbols}', "");
Expect(0, 8448, '\p{-_In_combining_diacritical_Marks_For_Symbols}', "");
Expect(1, 8448, '\p{^-_In_combining_diacritical_Marks_For_Symbols}', "");
Expect(1, 8448, '\P{-_In_combining_diacritical_Marks_For_Symbols}', "");
Expect(0, 8448, '\P{^-_In_combining_diacritical_Marks_For_Symbols}', "");
Error('\p{	/a/Diacriticals_For_Symbols}');
Error('\P{	/a/Diacriticals_For_Symbols}');
Expect(1, 8447, '\p{diacriticalsforsymbols}', "");
Expect(0, 8447, '\p{^diacriticalsforsymbols}', "");
Expect(0, 8447, '\P{diacriticalsforsymbols}', "");
Expect(1, 8447, '\P{^diacriticalsforsymbols}', "");
Expect(0, 8448, '\p{diacriticalsforsymbols}', "");
Expect(1, 8448, '\p{^diacriticalsforsymbols}', "");
Expect(1, 8448, '\P{diacriticalsforsymbols}', "");
Expect(0, 8448, '\P{^diacriticalsforsymbols}', "");
Expect(1, 8447, '\p{ _Diacriticals_FOR_Symbols}', "");
Expect(0, 8447, '\p{^ _Diacriticals_FOR_Symbols}', "");
Expect(0, 8447, '\P{ _Diacriticals_FOR_Symbols}', "");
Expect(1, 8447, '\P{^ _Diacriticals_FOR_Symbols}', "");
Expect(0, 8448, '\p{ _Diacriticals_FOR_Symbols}', "");
Expect(1, 8448, '\p{^ _Diacriticals_FOR_Symbols}', "");
Expect(1, 8448, '\P{ _Diacriticals_FOR_Symbols}', "");
Expect(0, 8448, '\P{^ _Diacriticals_FOR_Symbols}', "");
Error('\p{-_IS_Diacriticals_FOR_SYMBOLS:=}');
Error('\P{-_IS_Diacriticals_FOR_SYMBOLS:=}');
Expect(1, 8447, '\p{isdiacriticalsforsymbols}', "");
Expect(0, 8447, '\p{^isdiacriticalsforsymbols}', "");
Expect(0, 8447, '\P{isdiacriticalsforsymbols}', "");
Expect(1, 8447, '\P{^isdiacriticalsforsymbols}', "");
Expect(0, 8448, '\p{isdiacriticalsforsymbols}', "");
Expect(1, 8448, '\p{^isdiacriticalsforsymbols}', "");
Expect(1, 8448, '\P{isdiacriticalsforsymbols}', "");
Expect(0, 8448, '\P{^isdiacriticalsforsymbols}', "");
Expect(1, 8447, '\p{	-is_Diacriticals_FOR_symbols}', "");
Expect(0, 8447, '\p{^	-is_Diacriticals_FOR_symbols}', "");
Expect(0, 8447, '\P{	-is_Diacriticals_FOR_symbols}', "");
Expect(1, 8447, '\P{^	-is_Diacriticals_FOR_symbols}', "");
Expect(0, 8448, '\p{	-is_Diacriticals_FOR_symbols}', "");
Expect(1, 8448, '\p{^	-is_Diacriticals_FOR_symbols}', "");
Expect(1, 8448, '\P{	-is_Diacriticals_FOR_symbols}', "");
Expect(0, 8448, '\P{^	-is_Diacriticals_FOR_symbols}', "");
Error('\p{	in_Diacriticals_for_Symbols/a/}');
Error('\P{	in_Diacriticals_for_Symbols/a/}');
Expect(1, 8447, '\p{indiacriticalsforsymbols}', "");
Expect(0, 8447, '\p{^indiacriticalsforsymbols}', "");
Expect(0, 8447, '\P{indiacriticalsforsymbols}', "");
Expect(1, 8447, '\P{^indiacriticalsforsymbols}', "");
Expect(0, 8448, '\p{indiacriticalsforsymbols}', "");
Expect(1, 8448, '\p{^indiacriticalsforsymbols}', "");
Expect(1, 8448, '\P{indiacriticalsforsymbols}', "");
Expect(0, 8448, '\P{^indiacriticalsforsymbols}', "");
Expect(1, 8447, '\p{__In_diacriticals_For_Symbols}', "");
Expect(0, 8447, '\p{^__In_diacriticals_For_Symbols}', "");
Expect(0, 8447, '\P{__In_diacriticals_For_Symbols}', "");
Expect(1, 8447, '\P{^__In_diacriticals_For_Symbols}', "");
Expect(0, 8448, '\p{__In_diacriticals_For_Symbols}', "");
Expect(1, 8448, '\p{^__In_diacriticals_For_Symbols}', "");
Expect(1, 8448, '\P{__In_diacriticals_For_Symbols}', "");
Expect(0, 8448, '\P{^__In_diacriticals_For_Symbols}', "");
Error('\p{/a/Combining_marks_for_symbols}');
Error('\P{/a/Combining_marks_for_symbols}');
Expect(1, 8447, '\p{combiningmarksforsymbols}', "");
Expect(0, 8447, '\p{^combiningmarksforsymbols}', "");
Expect(0, 8447, '\P{combiningmarksforsymbols}', "");
Expect(1, 8447, '\P{^combiningmarksforsymbols}', "");
Expect(0, 8448, '\p{combiningmarksforsymbols}', "");
Expect(1, 8448, '\p{^combiningmarksforsymbols}', "");
Expect(1, 8448, '\P{combiningmarksforsymbols}', "");
Expect(0, 8448, '\P{^combiningmarksforsymbols}', "");
Expect(1, 8447, '\p{_Combining_Marks_For_Symbols}', "");
Expect(0, 8447, '\p{^_Combining_Marks_For_Symbols}', "");
Expect(0, 8447, '\P{_Combining_Marks_For_Symbols}', "");
Expect(1, 8447, '\P{^_Combining_Marks_For_Symbols}', "");
Expect(0, 8448, '\p{_Combining_Marks_For_Symbols}', "");
Expect(1, 8448, '\p{^_Combining_Marks_For_Symbols}', "");
Expect(1, 8448, '\P{_Combining_Marks_For_Symbols}', "");
Expect(0, 8448, '\P{^_Combining_Marks_For_Symbols}', "");
Error('\p{ IS_Combining_marks_FOR_symbols:=}');
Error('\P{ IS_Combining_marks_FOR_symbols:=}');
Expect(1, 8447, '\p{iscombiningmarksforsymbols}', "");
Expect(0, 8447, '\p{^iscombiningmarksforsymbols}', "");
Expect(0, 8447, '\P{iscombiningmarksforsymbols}', "");
Expect(1, 8447, '\P{^iscombiningmarksforsymbols}', "");
Expect(0, 8448, '\p{iscombiningmarksforsymbols}', "");
Expect(1, 8448, '\p{^iscombiningmarksforsymbols}', "");
Expect(1, 8448, '\P{iscombiningmarksforsymbols}', "");
Expect(0, 8448, '\P{^iscombiningmarksforsymbols}', "");
Expect(1, 8447, '\p{__Is_combining_marks_for_symbols}', "");
Expect(0, 8447, '\p{^__Is_combining_marks_for_symbols}', "");
Expect(0, 8447, '\P{__Is_combining_marks_for_symbols}', "");
Expect(1, 8447, '\P{^__Is_combining_marks_for_symbols}', "");
Expect(0, 8448, '\p{__Is_combining_marks_for_symbols}', "");
Expect(1, 8448, '\p{^__Is_combining_marks_for_symbols}', "");
Expect(1, 8448, '\P{__Is_combining_marks_for_symbols}', "");
Expect(0, 8448, '\P{^__Is_combining_marks_for_symbols}', "");
Error('\p{-:=In_COMBINING_Marks_For_Symbols}');
Error('\P{-:=In_COMBINING_Marks_For_Symbols}');
Expect(1, 8447, '\p{incombiningmarksforsymbols}', "");
Expect(0, 8447, '\p{^incombiningmarksforsymbols}', "");
Expect(0, 8447, '\P{incombiningmarksforsymbols}', "");
Expect(1, 8447, '\P{^incombiningmarksforsymbols}', "");
Expect(0, 8448, '\p{incombiningmarksforsymbols}', "");
Expect(1, 8448, '\p{^incombiningmarksforsymbols}', "");
Expect(1, 8448, '\P{incombiningmarksforsymbols}', "");
Expect(0, 8448, '\P{^incombiningmarksforsymbols}', "");
Expect(1, 8447, '\p{ 	In_Combining_marks_For_symbols}', "");
Expect(0, 8447, '\p{^ 	In_Combining_marks_For_symbols}', "");
Expect(0, 8447, '\P{ 	In_Combining_marks_For_symbols}', "");
Expect(1, 8447, '\P{^ 	In_Combining_marks_For_symbols}', "");
Expect(0, 8448, '\p{ 	In_Combining_marks_For_symbols}', "");
Expect(1, 8448, '\p{^ 	In_Combining_marks_For_symbols}', "");
Expect(1, 8448, '\P{ 	In_Combining_marks_For_symbols}', "");
Expect(0, 8448, '\P{^ 	In_Combining_marks_For_symbols}', "");
Error('\p{:=COMBINING_Diacritical_marks_Supplement}');
Error('\P{:=COMBINING_Diacritical_marks_Supplement}');
Expect(1, 7679, '\p{combiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\p{^combiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\P{combiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\P{^combiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\p{combiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\p{^combiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\P{combiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\P{^combiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\p{__combining_Diacritical_Marks_supplement}', "");
Expect(0, 7679, '\p{^__combining_Diacritical_Marks_supplement}', "");
Expect(0, 7679, '\P{__combining_Diacritical_Marks_supplement}', "");
Expect(1, 7679, '\P{^__combining_Diacritical_Marks_supplement}', "");
Expect(0, 7680, '\p{__combining_Diacritical_Marks_supplement}', "");
Expect(1, 7680, '\p{^__combining_Diacritical_Marks_supplement}', "");
Expect(1, 7680, '\P{__combining_Diacritical_Marks_supplement}', "");
Expect(0, 7680, '\P{^__combining_Diacritical_Marks_supplement}', "");
Error('\p{_	IS_COMBINING_DIACRITICAL_Marks_Supplement:=}');
Error('\P{_	IS_COMBINING_DIACRITICAL_Marks_Supplement:=}');
Expect(1, 7679, '\p{iscombiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\p{^iscombiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\P{iscombiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\P{^iscombiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\p{iscombiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\p{^iscombiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\P{iscombiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\P{^iscombiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\p{_Is_Combining_Diacritical_MARKS_Supplement}', "");
Expect(0, 7679, '\p{^_Is_Combining_Diacritical_MARKS_Supplement}', "");
Expect(0, 7679, '\P{_Is_Combining_Diacritical_MARKS_Supplement}', "");
Expect(1, 7679, '\P{^_Is_Combining_Diacritical_MARKS_Supplement}', "");
Expect(0, 7680, '\p{_Is_Combining_Diacritical_MARKS_Supplement}', "");
Expect(1, 7680, '\p{^_Is_Combining_Diacritical_MARKS_Supplement}', "");
Expect(1, 7680, '\P{_Is_Combining_Diacritical_MARKS_Supplement}', "");
Expect(0, 7680, '\P{^_Is_Combining_Diacritical_MARKS_Supplement}', "");
Error('\p{		In_COMBINING_DIACRITICAL_Marks_SUPPLEMENT/a/}');
Error('\P{		In_COMBINING_DIACRITICAL_Marks_SUPPLEMENT/a/}');
Expect(1, 7679, '\p{incombiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\p{^incombiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\P{incombiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\P{^incombiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\p{incombiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\p{^incombiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\P{incombiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\P{^incombiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\p{-In_combining_DIACRITICAL_marks_Supplement}', "");
Expect(0, 7679, '\p{^-In_combining_DIACRITICAL_marks_Supplement}', "");
Expect(0, 7679, '\P{-In_combining_DIACRITICAL_marks_Supplement}', "");
Expect(1, 7679, '\P{^-In_combining_DIACRITICAL_marks_Supplement}', "");
Expect(0, 7680, '\p{-In_combining_DIACRITICAL_marks_Supplement}', "");
Expect(1, 7680, '\p{^-In_combining_DIACRITICAL_marks_Supplement}', "");
Expect(1, 7680, '\P{-In_combining_DIACRITICAL_marks_Supplement}', "");
Expect(0, 7680, '\P{^-In_combining_DIACRITICAL_marks_Supplement}', "");
Error('\p{-_Diacriticals_Sup:=}');
Error('\P{-_Diacriticals_Sup:=}');
Expect(1, 7679, '\p{diacriticalssup}', "");
Expect(0, 7679, '\p{^diacriticalssup}', "");
Expect(0, 7679, '\P{diacriticalssup}', "");
Expect(1, 7679, '\P{^diacriticalssup}', "");
Expect(0, 7680, '\p{diacriticalssup}', "");
Expect(1, 7680, '\p{^diacriticalssup}', "");
Expect(1, 7680, '\P{diacriticalssup}', "");
Expect(0, 7680, '\P{^diacriticalssup}', "");
Expect(1, 7679, '\p{-Diacriticals_SUP}', "");
Expect(0, 7679, '\p{^-Diacriticals_SUP}', "");
Expect(0, 7679, '\P{-Diacriticals_SUP}', "");
Expect(1, 7679, '\P{^-Diacriticals_SUP}', "");
Expect(0, 7680, '\p{-Diacriticals_SUP}', "");
Expect(1, 7680, '\p{^-Diacriticals_SUP}', "");
Expect(1, 7680, '\P{-Diacriticals_SUP}', "");
Expect(0, 7680, '\P{^-Diacriticals_SUP}', "");
Error('\p{	_IS_Diacriticals_SUP/a/}');
Error('\P{	_IS_Diacriticals_SUP/a/}');
Expect(1, 7679, '\p{isdiacriticalssup}', "");
Expect(0, 7679, '\p{^isdiacriticalssup}', "");
Expect(0, 7679, '\P{isdiacriticalssup}', "");
Expect(1, 7679, '\P{^isdiacriticalssup}', "");
Expect(0, 7680, '\p{isdiacriticalssup}', "");
Expect(1, 7680, '\p{^isdiacriticalssup}', "");
Expect(1, 7680, '\P{isdiacriticalssup}', "");
Expect(0, 7680, '\P{^isdiacriticalssup}', "");
Expect(1, 7679, '\p{	Is_DIACRITICALS_sup}', "");
Expect(0, 7679, '\p{^	Is_DIACRITICALS_sup}', "");
Expect(0, 7679, '\P{	Is_DIACRITICALS_sup}', "");
Expect(1, 7679, '\P{^	Is_DIACRITICALS_sup}', "");
Expect(0, 7680, '\p{	Is_DIACRITICALS_sup}', "");
Expect(1, 7680, '\p{^	Is_DIACRITICALS_sup}', "");
Expect(1, 7680, '\P{	Is_DIACRITICALS_sup}', "");
Expect(0, 7680, '\P{^	Is_DIACRITICALS_sup}', "");
Error('\p{	In_DIACRITICALS_Sup/a/}');
Error('\P{	In_DIACRITICALS_Sup/a/}');
Expect(1, 7679, '\p{indiacriticalssup}', "");
Expect(0, 7679, '\p{^indiacriticalssup}', "");
Expect(0, 7679, '\P{indiacriticalssup}', "");
Expect(1, 7679, '\P{^indiacriticalssup}', "");
Expect(0, 7680, '\p{indiacriticalssup}', "");
Expect(1, 7680, '\p{^indiacriticalssup}', "");
Expect(1, 7680, '\P{indiacriticalssup}', "");
Expect(0, 7680, '\P{^indiacriticalssup}', "");
Expect(1, 7679, '\p{	_IN_Diacriticals_sup}', "");
Expect(0, 7679, '\p{^	_IN_Diacriticals_sup}', "");
Expect(0, 7679, '\P{	_IN_Diacriticals_sup}', "");
Expect(1, 7679, '\P{^	_IN_Diacriticals_sup}', "");
Expect(0, 7680, '\p{	_IN_Diacriticals_sup}', "");
Expect(1, 7680, '\p{^	_IN_Diacriticals_sup}', "");
Expect(1, 7680, '\P{	_IN_Diacriticals_sup}', "");
Expect(0, 7680, '\P{^	_IN_Diacriticals_sup}', "");
Error('\p{:= 	Combining_half_Marks}');
Error('\P{:= 	Combining_half_Marks}');
Expect(1, 65071, '\p{combininghalfmarks}', "");
Expect(0, 65071, '\p{^combininghalfmarks}', "");
Expect(0, 65071, '\P{combininghalfmarks}', "");
Expect(1, 65071, '\P{^combininghalfmarks}', "");
Expect(0, 65072, '\p{combininghalfmarks}', "");
Expect(1, 65072, '\p{^combininghalfmarks}', "");
Expect(1, 65072, '\P{combininghalfmarks}', "");
Expect(0, 65072, '\P{^combininghalfmarks}', "");
Expect(1, 65071, '\p{  Combining_Half_Marks}', "");
Expect(0, 65071, '\p{^  Combining_Half_Marks}', "");
Expect(0, 65071, '\P{  Combining_Half_Marks}', "");
Expect(1, 65071, '\P{^  Combining_Half_Marks}', "");
Expect(0, 65072, '\p{  Combining_Half_Marks}', "");
Expect(1, 65072, '\p{^  Combining_Half_Marks}', "");
Expect(1, 65072, '\P{  Combining_Half_Marks}', "");
Expect(0, 65072, '\P{^  Combining_Half_Marks}', "");
Error('\p{:=Is_combining_half_Marks}');
Error('\P{:=Is_combining_half_Marks}');
Expect(1, 65071, '\p{iscombininghalfmarks}', "");
Expect(0, 65071, '\p{^iscombininghalfmarks}', "");
Expect(0, 65071, '\P{iscombininghalfmarks}', "");
Expect(1, 65071, '\P{^iscombininghalfmarks}', "");
Expect(0, 65072, '\p{iscombininghalfmarks}', "");
Expect(1, 65072, '\p{^iscombininghalfmarks}', "");
Expect(1, 65072, '\P{iscombininghalfmarks}', "");
Expect(0, 65072, '\P{^iscombininghalfmarks}', "");
Expect(1, 65071, '\p{ Is_Combining_Half_Marks}', "");
Expect(0, 65071, '\p{^ Is_Combining_Half_Marks}', "");
Expect(0, 65071, '\P{ Is_Combining_Half_Marks}', "");
Expect(1, 65071, '\P{^ Is_Combining_Half_Marks}', "");
Expect(0, 65072, '\p{ Is_Combining_Half_Marks}', "");
Expect(1, 65072, '\p{^ Is_Combining_Half_Marks}', "");
Expect(1, 65072, '\P{ Is_Combining_Half_Marks}', "");
Expect(0, 65072, '\P{^ Is_Combining_Half_Marks}', "");
Error('\p{  In_combining_Half_marks/a/}');
Error('\P{  In_combining_Half_marks/a/}');
Expect(1, 65071, '\p{incombininghalfmarks}', "");
Expect(0, 65071, '\p{^incombininghalfmarks}', "");
Expect(0, 65071, '\P{incombininghalfmarks}', "");
Expect(1, 65071, '\P{^incombininghalfmarks}', "");
Expect(0, 65072, '\p{incombininghalfmarks}', "");
Expect(1, 65072, '\p{^incombininghalfmarks}', "");
Expect(1, 65072, '\P{incombininghalfmarks}', "");
Expect(0, 65072, '\P{^incombininghalfmarks}', "");
Expect(1, 65071, '\p{-In_combining_HALF_Marks}', "");
Expect(0, 65071, '\p{^-In_combining_HALF_Marks}', "");
Expect(0, 65071, '\P{-In_combining_HALF_Marks}', "");
Expect(1, 65071, '\P{^-In_combining_HALF_Marks}', "");
Expect(0, 65072, '\p{-In_combining_HALF_Marks}', "");
Expect(1, 65072, '\p{^-In_combining_HALF_Marks}', "");
Expect(1, 65072, '\P{-In_combining_HALF_Marks}', "");
Expect(0, 65072, '\P{^-In_combining_HALF_Marks}', "");
Error('\p{- half_Marks:=}');
Error('\P{- half_Marks:=}');
Expect(1, 65071, '\p{halfmarks}', "");
Expect(0, 65071, '\p{^halfmarks}', "");
Expect(0, 65071, '\P{halfmarks}', "");
Expect(1, 65071, '\P{^halfmarks}', "");
Expect(0, 65072, '\p{halfmarks}', "");
Expect(1, 65072, '\p{^halfmarks}', "");
Expect(1, 65072, '\P{halfmarks}', "");
Expect(0, 65072, '\P{^halfmarks}', "");
Expect(1, 65071, '\p{_	half_Marks}', "");
Expect(0, 65071, '\p{^_	half_Marks}', "");
Expect(0, 65071, '\P{_	half_Marks}', "");
Expect(1, 65071, '\P{^_	half_Marks}', "");
Expect(0, 65072, '\p{_	half_Marks}', "");
Expect(1, 65072, '\p{^_	half_Marks}', "");
Expect(1, 65072, '\P{_	half_Marks}', "");
Expect(0, 65072, '\P{^_	half_Marks}', "");
Error('\p{ :=Is_HALF_MARKS}');
Error('\P{ :=Is_HALF_MARKS}');
Expect(1, 65071, '\p{ishalfmarks}', "");
Expect(0, 65071, '\p{^ishalfmarks}', "");
Expect(0, 65071, '\P{ishalfmarks}', "");
Expect(1, 65071, '\P{^ishalfmarks}', "");
Expect(0, 65072, '\p{ishalfmarks}', "");
Expect(1, 65072, '\p{^ishalfmarks}', "");
Expect(1, 65072, '\P{ishalfmarks}', "");
Expect(0, 65072, '\P{^ishalfmarks}', "");
Expect(1, 65071, '\p{_IS_half_Marks}', "");
Expect(0, 65071, '\p{^_IS_half_Marks}', "");
Expect(0, 65071, '\P{_IS_half_Marks}', "");
Expect(1, 65071, '\P{^_IS_half_Marks}', "");
Expect(0, 65072, '\p{_IS_half_Marks}', "");
Expect(1, 65072, '\p{^_IS_half_Marks}', "");
Expect(1, 65072, '\P{_IS_half_Marks}', "");
Expect(0, 65072, '\P{^_IS_half_Marks}', "");
Error('\p{/a/ 	In_Half_marks}');
Error('\P{/a/ 	In_Half_marks}');
Expect(1, 65071, '\p{inhalfmarks}', "");
Expect(0, 65071, '\p{^inhalfmarks}', "");
Expect(0, 65071, '\P{inhalfmarks}', "");
Expect(1, 65071, '\P{^inhalfmarks}', "");
Expect(0, 65072, '\p{inhalfmarks}', "");
Expect(1, 65072, '\p{^inhalfmarks}', "");
Expect(1, 65072, '\P{inhalfmarks}', "");
Expect(0, 65072, '\P{^inhalfmarks}', "");
Expect(1, 65071, '\p{-In_Half_Marks}', "");
Expect(0, 65071, '\p{^-In_Half_Marks}', "");
Expect(0, 65071, '\P{-In_Half_Marks}', "");
Expect(1, 65071, '\P{^-In_Half_Marks}', "");
Expect(0, 65072, '\p{-In_Half_Marks}', "");
Expect(1, 65072, '\p{^-In_Half_Marks}', "");
Expect(1, 65072, '\P{-In_Half_Marks}', "");
Expect(0, 65072, '\P{^-In_Half_Marks}', "");
Error('\p{:=	COMMON}');
Error('\P{:=	COMMON}');
Expect(1, 917631, '\p{common}', "");
Expect(0, 917631, '\p{^common}', "");
Expect(0, 917631, '\P{common}', "");
Expect(1, 917631, '\P{^common}', "");
Expect(0, 917632, '\p{common}', "");
Expect(1, 917632, '\p{^common}', "");
Expect(1, 917632, '\P{common}', "");
Expect(0, 917632, '\P{^common}', "");
Expect(1, 917631, '\p{_common}', "");
Expect(0, 917631, '\p{^_common}', "");
Expect(0, 917631, '\P{_common}', "");
Expect(1, 917631, '\P{^_common}', "");
Expect(0, 917632, '\p{_common}', "");
Expect(1, 917632, '\p{^_common}', "");
Expect(1, 917632, '\P{_common}', "");
Expect(0, 917632, '\P{^_common}', "");
Error('\p{/a/is_Common}');
Error('\P{/a/is_Common}');
Expect(1, 917631, '\p{iscommon}', "");
Expect(0, 917631, '\p{^iscommon}', "");
Expect(0, 917631, '\P{iscommon}', "");
Expect(1, 917631, '\P{^iscommon}', "");
Expect(0, 917632, '\p{iscommon}', "");
Expect(1, 917632, '\p{^iscommon}', "");
Expect(1, 917632, '\P{iscommon}', "");
Expect(0, 917632, '\P{^iscommon}', "");
Expect(1, 917631, '\p{__is_COMMON}', "");
Expect(0, 917631, '\p{^__is_COMMON}', "");
Expect(0, 917631, '\P{__is_COMMON}', "");
Expect(1, 917631, '\P{^__is_COMMON}', "");
Expect(0, 917632, '\p{__is_COMMON}', "");
Expect(1, 917632, '\p{^__is_COMMON}', "");
Expect(1, 917632, '\P{__is_COMMON}', "");
Expect(0, 917632, '\P{^__is_COMMON}', "");
Error('\p{_	zyyy:=}');
Error('\P{_	zyyy:=}');
Expect(1, 917631, '\p{zyyy}', "");
Expect(0, 917631, '\p{^zyyy}', "");
Expect(0, 917631, '\P{zyyy}', "");
Expect(1, 917631, '\P{^zyyy}', "");
Expect(0, 917632, '\p{zyyy}', "");
Expect(1, 917632, '\p{^zyyy}', "");
Expect(1, 917632, '\P{zyyy}', "");
Expect(0, 917632, '\P{^zyyy}', "");
Expect(1, 917631, '\p{ ZYYY}', "");
Expect(0, 917631, '\p{^ ZYYY}', "");
Expect(0, 917631, '\P{ ZYYY}', "");
Expect(1, 917631, '\P{^ ZYYY}', "");
Expect(0, 917632, '\p{ ZYYY}', "");
Expect(1, 917632, '\p{^ ZYYY}', "");
Expect(1, 917632, '\P{ ZYYY}', "");
Expect(0, 917632, '\P{^ ZYYY}', "");
Error('\p{:=__IS_Zyyy}');
Error('\P{:=__IS_Zyyy}');
Expect(1, 917631, '\p{iszyyy}', "");
Expect(0, 917631, '\p{^iszyyy}', "");
Expect(0, 917631, '\P{iszyyy}', "");
Expect(1, 917631, '\P{^iszyyy}', "");
Expect(0, 917632, '\p{iszyyy}', "");
Expect(1, 917632, '\p{^iszyyy}', "");
Expect(1, 917632, '\P{iszyyy}', "");
Expect(0, 917632, '\P{^iszyyy}', "");
Expect(1, 917631, '\p{ -Is_zyyy}', "");
Expect(0, 917631, '\p{^ -Is_zyyy}', "");
Expect(0, 917631, '\P{ -Is_zyyy}', "");
Expect(1, 917631, '\P{^ -Is_zyyy}', "");
Expect(0, 917632, '\p{ -Is_zyyy}', "");
Expect(1, 917632, '\p{^ -Is_zyyy}', "");
Expect(1, 917632, '\P{ -Is_zyyy}', "");
Expect(0, 917632, '\P{^ -Is_zyyy}', "");
Error('\p{	_Common_Indic_Number_Forms/a/}');
Error('\P{	_Common_Indic_Number_Forms/a/}');
Expect(1, 43071, '\p{commonindicnumberforms}', "");
Expect(0, 43071, '\p{^commonindicnumberforms}', "");
Expect(0, 43071, '\P{commonindicnumberforms}', "");
Expect(1, 43071, '\P{^commonindicnumberforms}', "");
Expect(0, 43072, '\p{commonindicnumberforms}', "");
Expect(1, 43072, '\p{^commonindicnumberforms}', "");
Expect(1, 43072, '\P{commonindicnumberforms}', "");
Expect(0, 43072, '\P{^commonindicnumberforms}', "");
Expect(1, 43071, '\p{	 common_indic_Number_forms}', "");
Expect(0, 43071, '\p{^	 common_indic_Number_forms}', "");
Expect(0, 43071, '\P{	 common_indic_Number_forms}', "");
Expect(1, 43071, '\P{^	 common_indic_Number_forms}', "");
Expect(0, 43072, '\p{	 common_indic_Number_forms}', "");
Expect(1, 43072, '\p{^	 common_indic_Number_forms}', "");
Expect(1, 43072, '\P{	 common_indic_Number_forms}', "");
Expect(0, 43072, '\P{^	 common_indic_Number_forms}', "");
Error('\p{--Is_Common_Indic_Number_Forms/a/}');
Error('\P{--Is_Common_Indic_Number_Forms/a/}');
Expect(1, 43071, '\p{iscommonindicnumberforms}', "");
Expect(0, 43071, '\p{^iscommonindicnumberforms}', "");
Expect(0, 43071, '\P{iscommonindicnumberforms}', "");
Expect(1, 43071, '\P{^iscommonindicnumberforms}', "");
Expect(0, 43072, '\p{iscommonindicnumberforms}', "");
Expect(1, 43072, '\p{^iscommonindicnumberforms}', "");
Expect(1, 43072, '\P{iscommonindicnumberforms}', "");
Expect(0, 43072, '\P{^iscommonindicnumberforms}', "");
Expect(1, 43071, '\p{ _Is_Common_Indic_Number_Forms}', "");
Expect(0, 43071, '\p{^ _Is_Common_Indic_Number_Forms}', "");
Expect(0, 43071, '\P{ _Is_Common_Indic_Number_Forms}', "");
Expect(1, 43071, '\P{^ _Is_Common_Indic_Number_Forms}', "");
Expect(0, 43072, '\p{ _Is_Common_Indic_Number_Forms}', "");
Expect(1, 43072, '\p{^ _Is_Common_Indic_Number_Forms}', "");
Expect(1, 43072, '\P{ _Is_Common_Indic_Number_Forms}', "");
Expect(0, 43072, '\P{^ _Is_Common_Indic_Number_Forms}', "");
Error('\p{--in_common_INDIC_NUMBER_Forms/a/}');
Error('\P{--in_common_INDIC_NUMBER_Forms/a/}');
Expect(1, 43071, '\p{incommonindicnumberforms}', "");
Expect(0, 43071, '\p{^incommonindicnumberforms}', "");
Expect(0, 43071, '\P{incommonindicnumberforms}', "");
Expect(1, 43071, '\P{^incommonindicnumberforms}', "");
Expect(0, 43072, '\p{incommonindicnumberforms}', "");
Expect(1, 43072, '\p{^incommonindicnumberforms}', "");
Expect(1, 43072, '\P{incommonindicnumberforms}', "");
Expect(0, 43072, '\P{^incommonindicnumberforms}', "");
Expect(1, 43071, '\p{ In_COMMON_indic_number_Forms}', "");
Expect(0, 43071, '\p{^ In_COMMON_indic_number_Forms}', "");
Expect(0, 43071, '\P{ In_COMMON_indic_number_Forms}', "");
Expect(1, 43071, '\P{^ In_COMMON_indic_number_Forms}', "");
Expect(0, 43072, '\p{ In_COMMON_indic_number_Forms}', "");
Expect(1, 43072, '\p{^ In_COMMON_indic_number_Forms}', "");
Expect(1, 43072, '\P{ In_COMMON_indic_number_Forms}', "");
Expect(0, 43072, '\P{^ In_COMMON_indic_number_Forms}', "");
Error('\p{:=Indic_NUMBER_Forms}');
Error('\P{:=Indic_NUMBER_Forms}');
Expect(1, 43071, '\p{indicnumberforms}', "");
Expect(0, 43071, '\p{^indicnumberforms}', "");
Expect(0, 43071, '\P{indicnumberforms}', "");
Expect(1, 43071, '\P{^indicnumberforms}', "");
Expect(0, 43072, '\p{indicnumberforms}', "");
Expect(1, 43072, '\p{^indicnumberforms}', "");
Expect(1, 43072, '\P{indicnumberforms}', "");
Expect(0, 43072, '\P{^indicnumberforms}', "");
Expect(1, 43071, '\p{ _Indic_NUMBER_Forms}', "");
Expect(0, 43071, '\p{^ _Indic_NUMBER_Forms}', "");
Expect(0, 43071, '\P{ _Indic_NUMBER_Forms}', "");
Expect(1, 43071, '\P{^ _Indic_NUMBER_Forms}', "");
Expect(0, 43072, '\p{ _Indic_NUMBER_Forms}', "");
Expect(1, 43072, '\p{^ _Indic_NUMBER_Forms}', "");
Expect(1, 43072, '\P{ _Indic_NUMBER_Forms}', "");
Expect(0, 43072, '\P{^ _Indic_NUMBER_Forms}', "");
Error('\p{	/a/is_indic_number_Forms}');
Error('\P{	/a/is_indic_number_Forms}');
Expect(1, 43071, '\p{isindicnumberforms}', "");
Expect(0, 43071, '\p{^isindicnumberforms}', "");
Expect(0, 43071, '\P{isindicnumberforms}', "");
Expect(1, 43071, '\P{^isindicnumberforms}', "");
Expect(0, 43072, '\p{isindicnumberforms}', "");
Expect(1, 43072, '\p{^isindicnumberforms}', "");
Expect(1, 43072, '\P{isindicnumberforms}', "");
Expect(0, 43072, '\P{^isindicnumberforms}', "");
Expect(1, 43071, '\p{	_Is_Indic_Number_forms}', "");
Expect(0, 43071, '\p{^	_Is_Indic_Number_forms}', "");
Expect(0, 43071, '\P{	_Is_Indic_Number_forms}', "");
Expect(1, 43071, '\P{^	_Is_Indic_Number_forms}', "");
Expect(0, 43072, '\p{	_Is_Indic_Number_forms}', "");
Expect(1, 43072, '\p{^	_Is_Indic_Number_forms}', "");
Expect(1, 43072, '\P{	_Is_Indic_Number_forms}', "");
Expect(0, 43072, '\P{^	_Is_Indic_Number_forms}', "");
Error('\p{_IN_Indic_Number_FORMS:=}');
Error('\P{_IN_Indic_Number_FORMS:=}');
Expect(1, 43071, '\p{inindicnumberforms}', "");
Expect(0, 43071, '\p{^inindicnumberforms}', "");
Expect(0, 43071, '\P{inindicnumberforms}', "");
Expect(1, 43071, '\P{^inindicnumberforms}', "");
Expect(0, 43072, '\p{inindicnumberforms}', "");
Expect(1, 43072, '\p{^inindicnumberforms}', "");
Expect(1, 43072, '\P{inindicnumberforms}', "");
Expect(0, 43072, '\P{^inindicnumberforms}', "");
Expect(1, 43071, '\p{ -In_indic_number_FORMS}', "");
Expect(0, 43071, '\p{^ -In_indic_number_FORMS}', "");
Expect(0, 43071, '\P{ -In_indic_number_FORMS}', "");
Expect(1, 43071, '\P{^ -In_indic_number_FORMS}', "");
Expect(0, 43072, '\p{ -In_indic_number_FORMS}', "");
Expect(1, 43072, '\p{^ -In_indic_number_FORMS}', "");
Expect(1, 43072, '\P{ -In_indic_number_FORMS}', "");
Expect(0, 43072, '\P{^ -In_indic_number_FORMS}', "");
Error('\p{:=Composition_EXCLUSION}');
Error('\P{:=Composition_EXCLUSION}');
Expect(1, 119232, '\p{compositionexclusion}', "");
Expect(0, 119232, '\p{^compositionexclusion}', "");
Expect(0, 119232, '\P{compositionexclusion}', "");
Expect(1, 119232, '\P{^compositionexclusion}', "");
Expect(0, 119233, '\p{compositionexclusion}', "");
Expect(1, 119233, '\p{^compositionexclusion}', "");
Expect(1, 119233, '\P{compositionexclusion}', "");
Expect(0, 119233, '\P{^compositionexclusion}', "");
Expect(1, 119232, '\p{__Composition_Exclusion}', "");
Expect(0, 119232, '\p{^__Composition_Exclusion}', "");
Expect(0, 119232, '\P{__Composition_Exclusion}', "");
Expect(1, 119232, '\P{^__Composition_Exclusion}', "");
Expect(0, 119233, '\p{__Composition_Exclusion}', "");
Expect(1, 119233, '\p{^__Composition_Exclusion}', "");
Expect(1, 119233, '\P{__Composition_Exclusion}', "");
Expect(0, 119233, '\P{^__Composition_Exclusion}', "");
Error('\p{	:=IS_Composition_EXCLUSION}');
Error('\P{	:=IS_Composition_EXCLUSION}');
Expect(1, 119232, '\p{iscompositionexclusion}', "");
Expect(0, 119232, '\p{^iscompositionexclusion}', "");
Expect(0, 119232, '\P{iscompositionexclusion}', "");
Expect(1, 119232, '\P{^iscompositionexclusion}', "");
Expect(0, 119233, '\p{iscompositionexclusion}', "");
Expect(1, 119233, '\p{^iscompositionexclusion}', "");
Expect(1, 119233, '\P{iscompositionexclusion}', "");
Expect(0, 119233, '\P{^iscompositionexclusion}', "");
Expect(1, 119232, '\p{	_IS_composition_Exclusion}', "");
Expect(0, 119232, '\p{^	_IS_composition_Exclusion}', "");
Expect(0, 119232, '\P{	_IS_composition_Exclusion}', "");
Expect(1, 119232, '\P{^	_IS_composition_Exclusion}', "");
Expect(0, 119233, '\p{	_IS_composition_Exclusion}', "");
Expect(1, 119233, '\p{^	_IS_composition_Exclusion}', "");
Expect(1, 119233, '\P{	_IS_composition_Exclusion}', "");
Expect(0, 119233, '\P{^	_IS_composition_Exclusion}', "");
Error('\p{	/a/CE}');
Error('\P{	/a/CE}');
Expect(1, 119232, '\p{ce}', "");
Expect(0, 119232, '\p{^ce}', "");
Expect(0, 119232, '\P{ce}', "");
Expect(1, 119232, '\P{^ce}', "");
Expect(0, 119233, '\p{ce}', "");
Expect(1, 119233, '\p{^ce}', "");
Expect(1, 119233, '\P{ce}', "");
Expect(0, 119233, '\P{^ce}', "");
Expect(1, 119232, '\p{_CE}', "");
Expect(0, 119232, '\p{^_CE}', "");
Expect(0, 119232, '\P{_CE}', "");
Expect(1, 119232, '\P{^_CE}', "");
Expect(0, 119233, '\p{_CE}', "");
Expect(1, 119233, '\p{^_CE}', "");
Expect(1, 119233, '\P{_CE}', "");
Expect(0, 119233, '\P{^_CE}', "");
Error('\p{-is_CE/a/}');
Error('\P{-is_CE/a/}');
Expect(1, 119232, '\p{isce}', "");
Expect(0, 119232, '\p{^isce}', "");
Expect(0, 119232, '\P{isce}', "");
Expect(1, 119232, '\P{^isce}', "");
Expect(0, 119233, '\p{isce}', "");
Expect(1, 119233, '\p{^isce}', "");
Expect(1, 119233, '\P{isce}', "");
Expect(0, 119233, '\P{^isce}', "");
Expect(1, 119232, '\p{-_is_CE}', "");
Expect(0, 119232, '\p{^-_is_CE}', "");
Expect(0, 119232, '\P{-_is_CE}', "");
Expect(1, 119232, '\P{^-_is_CE}', "");
Expect(0, 119233, '\p{-_is_CE}', "");
Expect(1, 119233, '\p{^-_is_CE}', "");
Expect(1, 119233, '\P{-_is_CE}', "");
Expect(0, 119233, '\P{^-_is_CE}', "");
Error('\p{/a/-Connector_Punctuation}');
Error('\P{/a/-Connector_Punctuation}');
Expect(1, 65343, '\p{connectorpunctuation}', "");
Expect(0, 65343, '\p{^connectorpunctuation}', "");
Expect(0, 65343, '\P{connectorpunctuation}', "");
Expect(1, 65343, '\P{^connectorpunctuation}', "");
Expect(0, 65344, '\p{connectorpunctuation}', "");
Expect(1, 65344, '\p{^connectorpunctuation}', "");
Expect(1, 65344, '\P{connectorpunctuation}', "");
Expect(0, 65344, '\P{^connectorpunctuation}', "");
Expect(1, 65343, '\p{_ CONNECTOR_Punctuation}', "");
Expect(0, 65343, '\p{^_ CONNECTOR_Punctuation}', "");
Expect(0, 65343, '\P{_ CONNECTOR_Punctuation}', "");
Expect(1, 65343, '\P{^_ CONNECTOR_Punctuation}', "");
Expect(0, 65344, '\p{_ CONNECTOR_Punctuation}', "");
Expect(1, 65344, '\p{^_ CONNECTOR_Punctuation}', "");
Expect(1, 65344, '\P{_ CONNECTOR_Punctuation}', "");
Expect(0, 65344, '\P{^_ CONNECTOR_Punctuation}', "");
Error('\p{-:=Is_CONNECTOR_PUNCTUATION}');
Error('\P{-:=Is_CONNECTOR_PUNCTUATION}');
Expect(1, 65343, '\p{isconnectorpunctuation}', "");
Expect(0, 65343, '\p{^isconnectorpunctuation}', "");
Expect(0, 65343, '\P{isconnectorpunctuation}', "");
Expect(1, 65343, '\P{^isconnectorpunctuation}', "");
Expect(0, 65344, '\p{isconnectorpunctuation}', "");
Expect(1, 65344, '\p{^isconnectorpunctuation}', "");
Expect(1, 65344, '\P{isconnectorpunctuation}', "");
Expect(0, 65344, '\P{^isconnectorpunctuation}', "");
Expect(1, 65343, '\p{	 is_CONNECTOR_PUNCTUATION}', "");
Expect(0, 65343, '\p{^	 is_CONNECTOR_PUNCTUATION}', "");
Expect(0, 65343, '\P{	 is_CONNECTOR_PUNCTUATION}', "");
Expect(1, 65343, '\P{^	 is_CONNECTOR_PUNCTUATION}', "");
Expect(0, 65344, '\p{	 is_CONNECTOR_PUNCTUATION}', "");
Expect(1, 65344, '\p{^	 is_CONNECTOR_PUNCTUATION}', "");
Expect(1, 65344, '\P{	 is_CONNECTOR_PUNCTUATION}', "");
Expect(0, 65344, '\P{^	 is_CONNECTOR_PUNCTUATION}', "");
Error('\p{/a/  PC}');
Error('\P{/a/  PC}');
Expect(1, 65343, '\p{pc}', "");
Expect(0, 65343, '\p{^pc}', "");
Expect(0, 65343, '\P{pc}', "");
Expect(1, 65343, '\P{^pc}', "");
Expect(0, 65344, '\p{pc}', "");
Expect(1, 65344, '\p{^pc}', "");
Expect(1, 65344, '\P{pc}', "");
Expect(0, 65344, '\P{^pc}', "");
Expect(1, 65343, '\p{ 	Pc}', "");
Expect(0, 65343, '\p{^ 	Pc}', "");
Expect(0, 65343, '\P{ 	Pc}', "");
Expect(1, 65343, '\P{^ 	Pc}', "");
Expect(0, 65344, '\p{ 	Pc}', "");
Expect(1, 65344, '\p{^ 	Pc}', "");
Expect(1, 65344, '\P{ 	Pc}', "");
Expect(0, 65344, '\P{^ 	Pc}', "");
Error('\p{/a/-Is_PC}');
Error('\P{/a/-Is_PC}');
Expect(1, 65343, '\p{ispc}', "");
Expect(0, 65343, '\p{^ispc}', "");
Expect(0, 65343, '\P{ispc}', "");
Expect(1, 65343, '\P{^ispc}', "");
Expect(0, 65344, '\p{ispc}', "");
Expect(1, 65344, '\p{^ispc}', "");
Expect(1, 65344, '\P{ispc}', "");
Expect(0, 65344, '\P{^ispc}', "");
Expect(1, 65343, '\p{--IS_Pc}', "");
Expect(0, 65343, '\p{^--IS_Pc}', "");
Expect(0, 65343, '\P{--IS_Pc}', "");
Expect(1, 65343, '\P{^--IS_Pc}', "");
Expect(0, 65344, '\p{--IS_Pc}', "");
Expect(1, 65344, '\p{^--IS_Pc}', "");
Expect(1, 65344, '\P{--IS_Pc}', "");
Expect(0, 65344, '\P{^--IS_Pc}', "");
Error('\p{/a/	Control_Pictures}');
Error('\P{/a/	Control_Pictures}');
Expect(1, 9279, '\p{controlpictures}', "");
Expect(0, 9279, '\p{^controlpictures}', "");
Expect(0, 9279, '\P{controlpictures}', "");
Expect(1, 9279, '\P{^controlpictures}', "");
Expect(0, 9280, '\p{controlpictures}', "");
Expect(1, 9280, '\p{^controlpictures}', "");
Expect(1, 9280, '\P{controlpictures}', "");
Expect(0, 9280, '\P{^controlpictures}', "");
Expect(1, 9279, '\p{	-Control_PICTURES}', "");
Expect(0, 9279, '\p{^	-Control_PICTURES}', "");
Expect(0, 9279, '\P{	-Control_PICTURES}', "");
Expect(1, 9279, '\P{^	-Control_PICTURES}', "");
Expect(0, 9280, '\p{	-Control_PICTURES}', "");
Expect(1, 9280, '\p{^	-Control_PICTURES}', "");
Expect(1, 9280, '\P{	-Control_PICTURES}', "");
Expect(0, 9280, '\P{^	-Control_PICTURES}', "");
Error('\p{	:=Is_Control_PICTURES}');
Error('\P{	:=Is_Control_PICTURES}');
Expect(1, 9279, '\p{iscontrolpictures}', "");
Expect(0, 9279, '\p{^iscontrolpictures}', "");
Expect(0, 9279, '\P{iscontrolpictures}', "");
Expect(1, 9279, '\P{^iscontrolpictures}', "");
Expect(0, 9280, '\p{iscontrolpictures}', "");
Expect(1, 9280, '\p{^iscontrolpictures}', "");
Expect(1, 9280, '\P{iscontrolpictures}', "");
Expect(0, 9280, '\P{^iscontrolpictures}', "");
Expect(1, 9279, '\p{--Is_CONTROL_Pictures}', "");
Expect(0, 9279, '\p{^--Is_CONTROL_Pictures}', "");
Expect(0, 9279, '\P{--Is_CONTROL_Pictures}', "");
Expect(1, 9279, '\P{^--Is_CONTROL_Pictures}', "");
Expect(0, 9280, '\p{--Is_CONTROL_Pictures}', "");
Expect(1, 9280, '\p{^--Is_CONTROL_Pictures}', "");
Expect(1, 9280, '\P{--Is_CONTROL_Pictures}', "");
Expect(0, 9280, '\P{^--Is_CONTROL_Pictures}', "");
Error('\p{/a/	_In_CONTROL_Pictures}');
Error('\P{/a/	_In_CONTROL_Pictures}');
Expect(1, 9279, '\p{incontrolpictures}', "");
Expect(0, 9279, '\p{^incontrolpictures}', "");
Expect(0, 9279, '\P{incontrolpictures}', "");
Expect(1, 9279, '\P{^incontrolpictures}', "");
Expect(0, 9280, '\p{incontrolpictures}', "");
Expect(1, 9280, '\p{^incontrolpictures}', "");
Expect(1, 9280, '\P{incontrolpictures}', "");
Expect(0, 9280, '\P{^incontrolpictures}', "");
Expect(1, 9279, '\p{  In_control_Pictures}', "");
Expect(0, 9279, '\p{^  In_control_Pictures}', "");
Expect(0, 9279, '\P{  In_control_Pictures}', "");
Expect(1, 9279, '\P{^  In_control_Pictures}', "");
Expect(0, 9280, '\p{  In_control_Pictures}', "");
Expect(1, 9280, '\p{^  In_control_Pictures}', "");
Expect(1, 9280, '\P{  In_control_Pictures}', "");
Expect(0, 9280, '\P{^  In_control_Pictures}', "");
Error('\p{:=-Coptic}');
Error('\P{:=-Coptic}');
Expect(1, 11519, '\p{coptic}', "");
Expect(0, 11519, '\p{^coptic}', "");
Expect(0, 11519, '\P{coptic}', "");
Expect(1, 11519, '\P{^coptic}', "");
Expect(0, 11520, '\p{coptic}', "");
Expect(1, 11520, '\p{^coptic}', "");
Expect(1, 11520, '\P{coptic}', "");
Expect(0, 11520, '\P{^coptic}', "");
Expect(1, 11519, '\p{ Coptic}', "");
Expect(0, 11519, '\p{^ Coptic}', "");
Expect(0, 11519, '\P{ Coptic}', "");
Expect(1, 11519, '\P{^ Coptic}', "");
Expect(0, 11520, '\p{ Coptic}', "");
Expect(1, 11520, '\p{^ Coptic}', "");
Expect(1, 11520, '\P{ Coptic}', "");
Expect(0, 11520, '\P{^ Coptic}', "");
Error('\p{:=-_Is_coptic}');
Error('\P{:=-_Is_coptic}');
Expect(1, 11519, '\p{iscoptic}', "");
Expect(0, 11519, '\p{^iscoptic}', "");
Expect(0, 11519, '\P{iscoptic}', "");
Expect(1, 11519, '\P{^iscoptic}', "");
Expect(0, 11520, '\p{iscoptic}', "");
Expect(1, 11520, '\p{^iscoptic}', "");
Expect(1, 11520, '\P{iscoptic}', "");
Expect(0, 11520, '\P{^iscoptic}', "");
Expect(1, 11519, '\p{ IS_coptic}', "");
Expect(0, 11519, '\p{^ IS_coptic}', "");
Expect(0, 11519, '\P{ IS_coptic}', "");
Expect(1, 11519, '\P{^ IS_coptic}', "");
Expect(0, 11520, '\p{ IS_coptic}', "");
Expect(1, 11520, '\p{^ IS_coptic}', "");
Expect(1, 11520, '\P{ IS_coptic}', "");
Expect(0, 11520, '\P{^ IS_coptic}', "");
Error('\p{/a/		Copt}');
Error('\P{/a/		Copt}');
Expect(1, 11519, '\p{copt}', "");
Expect(0, 11519, '\p{^copt}', "");
Expect(0, 11519, '\P{copt}', "");
Expect(1, 11519, '\P{^copt}', "");
Expect(0, 11520, '\p{copt}', "");
Expect(1, 11520, '\p{^copt}', "");
Expect(1, 11520, '\P{copt}', "");
Expect(0, 11520, '\P{^copt}', "");
Expect(1, 11519, '\p{__copt}', "");
Expect(0, 11519, '\p{^__copt}', "");
Expect(0, 11519, '\P{__copt}', "");
Expect(1, 11519, '\P{^__copt}', "");
Expect(0, 11520, '\p{__copt}', "");
Expect(1, 11520, '\p{^__copt}', "");
Expect(1, 11520, '\P{__copt}', "");
Expect(0, 11520, '\P{^__copt}', "");
Error('\p{	_Is_Copt/a/}');
Error('\P{	_Is_Copt/a/}');
Expect(1, 11519, '\p{iscopt}', "");
Expect(0, 11519, '\p{^iscopt}', "");
Expect(0, 11519, '\P{iscopt}', "");
Expect(1, 11519, '\P{^iscopt}', "");
Expect(0, 11520, '\p{iscopt}', "");
Expect(1, 11520, '\p{^iscopt}', "");
Expect(1, 11520, '\P{iscopt}', "");
Expect(0, 11520, '\P{^iscopt}', "");
Expect(1, 11519, '\p{ Is_Copt}', "");
Expect(0, 11519, '\p{^ Is_Copt}', "");
Expect(0, 11519, '\P{ Is_Copt}', "");
Expect(1, 11519, '\P{^ Is_Copt}', "");
Expect(0, 11520, '\p{ Is_Copt}', "");
Expect(1, 11520, '\p{^ Is_Copt}', "");
Expect(1, 11520, '\P{ Is_Copt}', "");
Expect(0, 11520, '\P{^ Is_Copt}', "");
Error('\p{:=	-qaac}');
Error('\P{:=	-qaac}');
Expect(1, 11519, '\p{qaac}', "");
Expect(0, 11519, '\p{^qaac}', "");
Expect(0, 11519, '\P{qaac}', "");
Expect(1, 11519, '\P{^qaac}', "");
Expect(0, 11520, '\p{qaac}', "");
Expect(1, 11520, '\p{^qaac}', "");
Expect(1, 11520, '\P{qaac}', "");
Expect(0, 11520, '\P{^qaac}', "");
Expect(1, 11519, '\p{_ Qaac}', "");
Expect(0, 11519, '\p{^_ Qaac}', "");
Expect(0, 11519, '\P{_ Qaac}', "");
Expect(1, 11519, '\P{^_ Qaac}', "");
Expect(0, 11520, '\p{_ Qaac}', "");
Expect(1, 11520, '\p{^_ Qaac}', "");
Expect(1, 11520, '\P{_ Qaac}', "");
Expect(0, 11520, '\P{^_ Qaac}', "");
Error('\p{ 	Is_Qaac/a/}');
Error('\P{ 	Is_Qaac/a/}');
Expect(1, 11519, '\p{isqaac}', "");
Expect(0, 11519, '\p{^isqaac}', "");
Expect(0, 11519, '\P{isqaac}', "");
Expect(1, 11519, '\P{^isqaac}', "");
Expect(0, 11520, '\p{isqaac}', "");
Expect(1, 11520, '\p{^isqaac}', "");
Expect(1, 11520, '\P{isqaac}', "");
Expect(0, 11520, '\P{^isqaac}', "");
Expect(1, 11519, '\p{-	IS_Qaac}', "");
Expect(0, 11519, '\p{^-	IS_Qaac}', "");
Expect(0, 11519, '\P{-	IS_Qaac}', "");
Expect(1, 11519, '\P{^-	IS_Qaac}', "");
Expect(0, 11520, '\p{-	IS_Qaac}', "");
Expect(1, 11520, '\p{^-	IS_Qaac}', "");
Expect(1, 11520, '\P{-	IS_Qaac}', "");
Expect(0, 11520, '\P{^-	IS_Qaac}', "");
Error('\p{	:=COUNTING_Rod_Numerals}');
Error('\P{	:=COUNTING_Rod_Numerals}');
Expect(1, 119679, '\p{countingrodnumerals}', "");
Expect(0, 119679, '\p{^countingrodnumerals}', "");
Expect(0, 119679, '\P{countingrodnumerals}', "");
Expect(1, 119679, '\P{^countingrodnumerals}', "");
Expect(0, 119680, '\p{countingrodnumerals}', "");
Expect(1, 119680, '\p{^countingrodnumerals}', "");
Expect(1, 119680, '\P{countingrodnumerals}', "");
Expect(0, 119680, '\P{^countingrodnumerals}', "");
Expect(1, 119679, '\p{-	counting_rod_numerals}', "");
Expect(0, 119679, '\p{^-	counting_rod_numerals}', "");
Expect(0, 119679, '\P{-	counting_rod_numerals}', "");
Expect(1, 119679, '\P{^-	counting_rod_numerals}', "");
Expect(0, 119680, '\p{-	counting_rod_numerals}', "");
Expect(1, 119680, '\p{^-	counting_rod_numerals}', "");
Expect(1, 119680, '\P{-	counting_rod_numerals}', "");
Expect(0, 119680, '\P{^-	counting_rod_numerals}', "");
Error('\p{:=	_IS_counting_ROD_Numerals}');
Error('\P{:=	_IS_counting_ROD_Numerals}');
Expect(1, 119679, '\p{iscountingrodnumerals}', "");
Expect(0, 119679, '\p{^iscountingrodnumerals}', "");
Expect(0, 119679, '\P{iscountingrodnumerals}', "");
Expect(1, 119679, '\P{^iscountingrodnumerals}', "");
Expect(0, 119680, '\p{iscountingrodnumerals}', "");
Expect(1, 119680, '\p{^iscountingrodnumerals}', "");
Expect(1, 119680, '\P{iscountingrodnumerals}', "");
Expect(0, 119680, '\P{^iscountingrodnumerals}', "");
Expect(1, 119679, '\p{_Is_counting_ROD_NUMERALS}', "");
Expect(0, 119679, '\p{^_Is_counting_ROD_NUMERALS}', "");
Expect(0, 119679, '\P{_Is_counting_ROD_NUMERALS}', "");
Expect(1, 119679, '\P{^_Is_counting_ROD_NUMERALS}', "");
Expect(0, 119680, '\p{_Is_counting_ROD_NUMERALS}', "");
Expect(1, 119680, '\p{^_Is_counting_ROD_NUMERALS}', "");
Expect(1, 119680, '\P{_Is_counting_ROD_NUMERALS}', "");
Expect(0, 119680, '\P{^_Is_counting_ROD_NUMERALS}', "");
Error('\p{  In_counting_ROD_NUMERALS/a/}');
Error('\P{  In_counting_ROD_NUMERALS/a/}');
Expect(1, 119679, '\p{incountingrodnumerals}', "");
Expect(0, 119679, '\p{^incountingrodnumerals}', "");
Expect(0, 119679, '\P{incountingrodnumerals}', "");
Expect(1, 119679, '\P{^incountingrodnumerals}', "");
Expect(0, 119680, '\p{incountingrodnumerals}', "");
Expect(1, 119680, '\p{^incountingrodnumerals}', "");
Expect(1, 119680, '\P{incountingrodnumerals}', "");
Expect(0, 119680, '\P{^incountingrodnumerals}', "");
Expect(1, 119679, '\p{  In_COUNTING_rod_Numerals}', "");
Expect(0, 119679, '\p{^  In_COUNTING_rod_Numerals}', "");
Expect(0, 119679, '\P{  In_COUNTING_rod_Numerals}', "");
Expect(1, 119679, '\P{^  In_COUNTING_rod_Numerals}', "");
Expect(0, 119680, '\p{  In_COUNTING_rod_Numerals}', "");
Expect(1, 119680, '\p{^  In_COUNTING_rod_Numerals}', "");
Expect(1, 119680, '\P{  In_COUNTING_rod_Numerals}', "");
Expect(0, 119680, '\P{^  In_COUNTING_rod_Numerals}', "");
Error('\p{-/a/Counting_ROD}');
Error('\P{-/a/Counting_ROD}');
Expect(1, 119679, '\p{countingrod}', "");
Expect(0, 119679, '\p{^countingrod}', "");
Expect(0, 119679, '\P{countingrod}', "");
Expect(1, 119679, '\P{^countingrod}', "");
Expect(0, 119680, '\p{countingrod}', "");
Expect(1, 119680, '\p{^countingrod}', "");
Expect(1, 119680, '\P{countingrod}', "");
Expect(0, 119680, '\P{^countingrod}', "");
Expect(1, 119679, '\p{	_Counting_rod}', "");
Expect(0, 119679, '\p{^	_Counting_rod}', "");
Expect(0, 119679, '\P{	_Counting_rod}', "");
Expect(1, 119679, '\P{^	_Counting_rod}', "");
Expect(0, 119680, '\p{	_Counting_rod}', "");
Expect(1, 119680, '\p{^	_Counting_rod}', "");
Expect(1, 119680, '\P{	_Counting_rod}', "");
Expect(0, 119680, '\P{^	_Counting_rod}', "");
Error('\p{/a/	Is_counting_rod}');
Error('\P{/a/	Is_counting_rod}');
Expect(1, 119679, '\p{iscountingrod}', "");
Expect(0, 119679, '\p{^iscountingrod}', "");
Expect(0, 119679, '\P{iscountingrod}', "");
Expect(1, 119679, '\P{^iscountingrod}', "");
Expect(0, 119680, '\p{iscountingrod}', "");
Expect(1, 119680, '\p{^iscountingrod}', "");
Expect(1, 119680, '\P{iscountingrod}', "");
Expect(0, 119680, '\P{^iscountingrod}', "");
Expect(1, 119679, '\p{		is_Counting_rod}', "");
Expect(0, 119679, '\p{^		is_Counting_rod}', "");
Expect(0, 119679, '\P{		is_Counting_rod}', "");
Expect(1, 119679, '\P{^		is_Counting_rod}', "");
Expect(0, 119680, '\p{		is_Counting_rod}', "");
Expect(1, 119680, '\p{^		is_Counting_rod}', "");
Expect(1, 119680, '\P{		is_Counting_rod}', "");
Expect(0, 119680, '\P{^		is_Counting_rod}', "");
Error('\p{- IN_counting_Rod/a/}');
Error('\P{- IN_counting_Rod/a/}');
Expect(1, 119679, '\p{incountingrod}', "");
Expect(0, 119679, '\p{^incountingrod}', "");
Expect(0, 119679, '\P{incountingrod}', "");
Expect(1, 119679, '\P{^incountingrod}', "");
Expect(0, 119680, '\p{incountingrod}', "");
Expect(1, 119680, '\p{^incountingrod}', "");
Expect(1, 119680, '\P{incountingrod}', "");
Expect(0, 119680, '\P{^incountingrod}', "");
Expect(1, 119679, '\p{ IN_Counting_Rod}', "");
Expect(0, 119679, '\p{^ IN_Counting_Rod}', "");
Expect(0, 119679, '\P{ IN_Counting_Rod}', "");
Expect(1, 119679, '\P{^ IN_Counting_Rod}', "");
Expect(0, 119680, '\p{ IN_Counting_Rod}', "");
Expect(1, 119680, '\p{^ IN_Counting_Rod}', "");
Expect(1, 119680, '\P{ IN_Counting_Rod}', "");
Expect(0, 119680, '\P{^ IN_Counting_Rod}', "");
Error('\p{  CUNEIFORM:=}');
Error('\P{  CUNEIFORM:=}');
Expect(1, 74867, '\p{cuneiform}', "");
Expect(0, 74867, '\p{^cuneiform}', "");
Expect(0, 74867, '\P{cuneiform}', "");
Expect(1, 74867, '\P{^cuneiform}', "");
Expect(0, 74868, '\p{cuneiform}', "");
Expect(1, 74868, '\p{^cuneiform}', "");
Expect(1, 74868, '\P{cuneiform}', "");
Expect(0, 74868, '\P{^cuneiform}', "");
Expect(1, 74867, '\p{	 CUNEIFORM}', "");
Expect(0, 74867, '\p{^	 CUNEIFORM}', "");
Expect(0, 74867, '\P{	 CUNEIFORM}', "");
Expect(1, 74867, '\P{^	 CUNEIFORM}', "");
Expect(0, 74868, '\p{	 CUNEIFORM}', "");
Expect(1, 74868, '\p{^	 CUNEIFORM}', "");
Expect(1, 74868, '\P{	 CUNEIFORM}', "");
Expect(0, 74868, '\P{^	 CUNEIFORM}', "");
Error('\p{-IS_Cuneiform:=}');
Error('\P{-IS_Cuneiform:=}');
Expect(1, 74867, '\p{iscuneiform}', "");
Expect(0, 74867, '\p{^iscuneiform}', "");
Expect(0, 74867, '\P{iscuneiform}', "");
Expect(1, 74867, '\P{^iscuneiform}', "");
Expect(0, 74868, '\p{iscuneiform}', "");
Expect(1, 74868, '\p{^iscuneiform}', "");
Expect(1, 74868, '\P{iscuneiform}', "");
Expect(0, 74868, '\P{^iscuneiform}', "");
Expect(1, 74867, '\p{ is_Cuneiform}', "");
Expect(0, 74867, '\p{^ is_Cuneiform}', "");
Expect(0, 74867, '\P{ is_Cuneiform}', "");
Expect(1, 74867, '\P{^ is_Cuneiform}', "");
Expect(0, 74868, '\p{ is_Cuneiform}', "");
Expect(1, 74868, '\p{^ is_Cuneiform}', "");
Expect(1, 74868, '\P{ is_Cuneiform}', "");
Expect(0, 74868, '\P{^ is_Cuneiform}', "");
Error('\p{_:=XSUX}');
Error('\P{_:=XSUX}');
Expect(1, 74867, '\p{xsux}', "");
Expect(0, 74867, '\p{^xsux}', "");
Expect(0, 74867, '\P{xsux}', "");
Expect(1, 74867, '\P{^xsux}', "");
Expect(0, 74868, '\p{xsux}', "");
Expect(1, 74868, '\p{^xsux}', "");
Expect(1, 74868, '\P{xsux}', "");
Expect(0, 74868, '\P{^xsux}', "");
Expect(1, 74867, '\p{_	Xsux}', "");
Expect(0, 74867, '\p{^_	Xsux}', "");
Expect(0, 74867, '\P{_	Xsux}', "");
Expect(1, 74867, '\P{^_	Xsux}', "");
Expect(0, 74868, '\p{_	Xsux}', "");
Expect(1, 74868, '\p{^_	Xsux}', "");
Expect(1, 74868, '\P{_	Xsux}', "");
Expect(0, 74868, '\P{^_	Xsux}', "");
Error('\p{ -Is_Xsux:=}');
Error('\P{ -Is_Xsux:=}');
Expect(1, 74867, '\p{isxsux}', "");
Expect(0, 74867, '\p{^isxsux}', "");
Expect(0, 74867, '\P{isxsux}', "");
Expect(1, 74867, '\P{^isxsux}', "");
Expect(0, 74868, '\p{isxsux}', "");
Expect(1, 74868, '\p{^isxsux}', "");
Expect(1, 74868, '\P{isxsux}', "");
Expect(0, 74868, '\P{^isxsux}', "");
Expect(1, 74867, '\p{ -IS_Xsux}', "");
Expect(0, 74867, '\p{^ -IS_Xsux}', "");
Expect(0, 74867, '\P{ -IS_Xsux}', "");
Expect(1, 74867, '\P{^ -IS_Xsux}', "");
Expect(0, 74868, '\p{ -IS_Xsux}', "");
Expect(1, 74868, '\p{^ -IS_Xsux}', "");
Expect(1, 74868, '\P{ -IS_Xsux}', "");
Expect(0, 74868, '\P{^ -IS_Xsux}', "");
Error('\p{:=_	Cuneiform_Numbers_And_punctuation}');
Error('\P{:=_	Cuneiform_Numbers_And_punctuation}');
Expect(1, 74879, '\p{cuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\p{^cuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\P{cuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\P{^cuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\p{cuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\p{^cuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\P{cuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\P{^cuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\p{- cuneiform_Numbers_AND_Punctuation}', "");
Expect(0, 74879, '\p{^- cuneiform_Numbers_AND_Punctuation}', "");
Expect(0, 74879, '\P{- cuneiform_Numbers_AND_Punctuation}', "");
Expect(1, 74879, '\P{^- cuneiform_Numbers_AND_Punctuation}', "");
Expect(0, 74880, '\p{- cuneiform_Numbers_AND_Punctuation}', "");
Expect(1, 74880, '\p{^- cuneiform_Numbers_AND_Punctuation}', "");
Expect(1, 74880, '\P{- cuneiform_Numbers_AND_Punctuation}', "");
Expect(0, 74880, '\P{^- cuneiform_Numbers_AND_Punctuation}', "");
Error('\p{/a/ -Is_Cuneiform_numbers_And_Punctuation}');
Error('\P{/a/ -Is_Cuneiform_numbers_And_Punctuation}');
Expect(1, 74879, '\p{iscuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\p{^iscuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\P{iscuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\P{^iscuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\p{iscuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\p{^iscuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\P{iscuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\P{^iscuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\p{- Is_CUNEIFORM_Numbers_And_PUNCTUATION}', "");
Expect(0, 74879, '\p{^- Is_CUNEIFORM_Numbers_And_PUNCTUATION}', "");
Expect(0, 74879, '\P{- Is_CUNEIFORM_Numbers_And_PUNCTUATION}', "");
Expect(1, 74879, '\P{^- Is_CUNEIFORM_Numbers_And_PUNCTUATION}', "");
Expect(0, 74880, '\p{- Is_CUNEIFORM_Numbers_And_PUNCTUATION}', "");
Expect(1, 74880, '\p{^- Is_CUNEIFORM_Numbers_And_PUNCTUATION}', "");
Expect(1, 74880, '\P{- Is_CUNEIFORM_Numbers_And_PUNCTUATION}', "");
Expect(0, 74880, '\P{^- Is_CUNEIFORM_Numbers_And_PUNCTUATION}', "");
Error('\p{	/a/IN_Cuneiform_numbers_AND_PUNCTUATION}');
Error('\P{	/a/IN_Cuneiform_numbers_AND_PUNCTUATION}');
Expect(1, 74879, '\p{incuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\p{^incuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\P{incuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\P{^incuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\p{incuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\p{^incuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\P{incuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\P{^incuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\p{--IN_CUNEIFORM_Numbers_and_Punctuation}', "");
Expect(0, 74879, '\p{^--IN_CUNEIFORM_Numbers_and_Punctuation}', "");
Expect(0, 74879, '\P{--IN_CUNEIFORM_Numbers_and_Punctuation}', "");
Expect(1, 74879, '\P{^--IN_CUNEIFORM_Numbers_and_Punctuation}', "");
Expect(0, 74880, '\p{--IN_CUNEIFORM_Numbers_and_Punctuation}', "");
Expect(1, 74880, '\p{^--IN_CUNEIFORM_Numbers_and_Punctuation}', "");
Expect(1, 74880, '\P{--IN_CUNEIFORM_Numbers_and_Punctuation}', "");
Expect(0, 74880, '\P{^--IN_CUNEIFORM_Numbers_and_Punctuation}', "");
Error('\p{:=		CUNEIFORM_numbers}');
Error('\P{:=		CUNEIFORM_numbers}');
Expect(1, 74879, '\p{cuneiformnumbers}', "");
Expect(0, 74879, '\p{^cuneiformnumbers}', "");
Expect(0, 74879, '\P{cuneiformnumbers}', "");
Expect(1, 74879, '\P{^cuneiformnumbers}', "");
Expect(0, 74880, '\p{cuneiformnumbers}', "");
Expect(1, 74880, '\p{^cuneiformnumbers}', "");
Expect(1, 74880, '\P{cuneiformnumbers}', "");
Expect(0, 74880, '\P{^cuneiformnumbers}', "");
Expect(1, 74879, '\p{ 	Cuneiform_numbers}', "");
Expect(0, 74879, '\p{^ 	Cuneiform_numbers}', "");
Expect(0, 74879, '\P{ 	Cuneiform_numbers}', "");
Expect(1, 74879, '\P{^ 	Cuneiform_numbers}', "");
Expect(0, 74880, '\p{ 	Cuneiform_numbers}', "");
Expect(1, 74880, '\p{^ 	Cuneiform_numbers}', "");
Expect(1, 74880, '\P{ 	Cuneiform_numbers}', "");
Expect(0, 74880, '\P{^ 	Cuneiform_numbers}', "");
Error('\p{ IS_Cuneiform_numbers:=}');
Error('\P{ IS_Cuneiform_numbers:=}');
Expect(1, 74879, '\p{iscuneiformnumbers}', "");
Expect(0, 74879, '\p{^iscuneiformnumbers}', "");
Expect(0, 74879, '\P{iscuneiformnumbers}', "");
Expect(1, 74879, '\P{^iscuneiformnumbers}', "");
Expect(0, 74880, '\p{iscuneiformnumbers}', "");
Expect(1, 74880, '\p{^iscuneiformnumbers}', "");
Expect(1, 74880, '\P{iscuneiformnumbers}', "");
Expect(0, 74880, '\P{^iscuneiformnumbers}', "");
Expect(1, 74879, '\p{	-Is_Cuneiform_Numbers}', "");
Expect(0, 74879, '\p{^	-Is_Cuneiform_Numbers}', "");
Expect(0, 74879, '\P{	-Is_Cuneiform_Numbers}', "");
Expect(1, 74879, '\P{^	-Is_Cuneiform_Numbers}', "");
Expect(0, 74880, '\p{	-Is_Cuneiform_Numbers}', "");
Expect(1, 74880, '\p{^	-Is_Cuneiform_Numbers}', "");
Expect(1, 74880, '\P{	-Is_Cuneiform_Numbers}', "");
Expect(0, 74880, '\P{^	-Is_Cuneiform_Numbers}', "");
Error('\p{ /a/in_Cuneiform_Numbers}');
Error('\P{ /a/in_Cuneiform_Numbers}');
Expect(1, 74879, '\p{incuneiformnumbers}', "");
Expect(0, 74879, '\p{^incuneiformnumbers}', "");
Expect(0, 74879, '\P{incuneiformnumbers}', "");
Expect(1, 74879, '\P{^incuneiformnumbers}', "");
Expect(0, 74880, '\p{incuneiformnumbers}', "");
Expect(1, 74880, '\p{^incuneiformnumbers}', "");
Expect(1, 74880, '\P{incuneiformnumbers}', "");
Expect(0, 74880, '\P{^incuneiformnumbers}', "");
Expect(1, 74879, '\p{  In_Cuneiform_NUMBERS}', "");
Expect(0, 74879, '\p{^  In_Cuneiform_NUMBERS}', "");
Expect(0, 74879, '\P{  In_Cuneiform_NUMBERS}', "");
Expect(1, 74879, '\P{^  In_Cuneiform_NUMBERS}', "");
Expect(0, 74880, '\p{  In_Cuneiform_NUMBERS}', "");
Expect(1, 74880, '\p{^  In_Cuneiform_NUMBERS}', "");
Expect(1, 74880, '\P{  In_Cuneiform_NUMBERS}', "");
Expect(0, 74880, '\P{^  In_Cuneiform_NUMBERS}', "");
Error('\p{:=Currency_Symbol}');
Error('\P{:=Currency_Symbol}');
Expect(1, 65510, '\p{currencysymbol}', "");
Expect(0, 65510, '\p{^currencysymbol}', "");
Expect(0, 65510, '\P{currencysymbol}', "");
Expect(1, 65510, '\P{^currencysymbol}', "");
Expect(0, 65511, '\p{currencysymbol}', "");
Expect(1, 65511, '\p{^currencysymbol}', "");
Expect(1, 65511, '\P{currencysymbol}', "");
Expect(0, 65511, '\P{^currencysymbol}', "");
Expect(1, 65510, '\p{	-CURRENCY_Symbol}', "");
Expect(0, 65510, '\p{^	-CURRENCY_Symbol}', "");
Expect(0, 65510, '\P{	-CURRENCY_Symbol}', "");
Expect(1, 65510, '\P{^	-CURRENCY_Symbol}', "");
Expect(0, 65511, '\p{	-CURRENCY_Symbol}', "");
Expect(1, 65511, '\p{^	-CURRENCY_Symbol}', "");
Expect(1, 65511, '\P{	-CURRENCY_Symbol}', "");
Expect(0, 65511, '\P{^	-CURRENCY_Symbol}', "");
Error('\p{_/a/Is_CURRENCY_Symbol}');
Error('\P{_/a/Is_CURRENCY_Symbol}');
Expect(1, 65510, '\p{iscurrencysymbol}', "");
Expect(0, 65510, '\p{^iscurrencysymbol}', "");
Expect(0, 65510, '\P{iscurrencysymbol}', "");
Expect(1, 65510, '\P{^iscurrencysymbol}', "");
Expect(0, 65511, '\p{iscurrencysymbol}', "");
Expect(1, 65511, '\p{^iscurrencysymbol}', "");
Expect(1, 65511, '\P{iscurrencysymbol}', "");
Expect(0, 65511, '\P{^iscurrencysymbol}', "");
Expect(1, 65510, '\p{	IS_currency_Symbol}', "");
Expect(0, 65510, '\p{^	IS_currency_Symbol}', "");
Expect(0, 65510, '\P{	IS_currency_Symbol}', "");
Expect(1, 65510, '\P{^	IS_currency_Symbol}', "");
Expect(0, 65511, '\p{	IS_currency_Symbol}', "");
Expect(1, 65511, '\p{^	IS_currency_Symbol}', "");
Expect(1, 65511, '\P{	IS_currency_Symbol}', "");
Expect(0, 65511, '\P{^	IS_currency_Symbol}', "");
Error('\p{	-Sc/a/}');
Error('\P{	-Sc/a/}');
Expect(1, 65510, '\p{sc}', "");
Expect(0, 65510, '\p{^sc}', "");
Expect(0, 65510, '\P{sc}', "");
Expect(1, 65510, '\P{^sc}', "");
Expect(0, 65511, '\p{sc}', "");
Expect(1, 65511, '\p{^sc}', "");
Expect(1, 65511, '\P{sc}', "");
Expect(0, 65511, '\P{^sc}', "");
Expect(1, 65510, '\p{ -Sc}', "");
Expect(0, 65510, '\p{^ -Sc}', "");
Expect(0, 65510, '\P{ -Sc}', "");
Expect(1, 65510, '\P{^ -Sc}', "");
Expect(0, 65511, '\p{ -Sc}', "");
Expect(1, 65511, '\p{^ -Sc}', "");
Expect(1, 65511, '\P{ -Sc}', "");
Expect(0, 65511, '\P{^ -Sc}', "");
Error('\p{-_Is_SC:=}');
Error('\P{-_Is_SC:=}');
Expect(1, 65510, '\p{issc}', "");
Expect(0, 65510, '\p{^issc}', "");
Expect(0, 65510, '\P{issc}', "");
Expect(1, 65510, '\P{^issc}', "");
Expect(0, 65511, '\p{issc}', "");
Expect(1, 65511, '\p{^issc}', "");
Expect(1, 65511, '\P{issc}', "");
Expect(0, 65511, '\P{^issc}', "");
Expect(1, 65510, '\p{--is_Sc}', "");
Expect(0, 65510, '\p{^--is_Sc}', "");
Expect(0, 65510, '\P{--is_Sc}', "");
Expect(1, 65510, '\P{^--is_Sc}', "");
Expect(0, 65511, '\p{--is_Sc}', "");
Expect(1, 65511, '\p{^--is_Sc}', "");
Expect(1, 65511, '\P{--is_Sc}', "");
Expect(0, 65511, '\P{^--is_Sc}', "");
Error('\p{ /a/CURRENCY_Symbols}');
Error('\P{ /a/CURRENCY_Symbols}');
Expect(1, 8399, '\p{currencysymbols}', "");
Expect(0, 8399, '\p{^currencysymbols}', "");
Expect(0, 8399, '\P{currencysymbols}', "");
Expect(1, 8399, '\P{^currencysymbols}', "");
Expect(0, 8400, '\p{currencysymbols}', "");
Expect(1, 8400, '\p{^currencysymbols}', "");
Expect(1, 8400, '\P{currencysymbols}', "");
Expect(0, 8400, '\P{^currencysymbols}', "");
Expect(1, 8399, '\p{-currency_Symbols}', "");
Expect(0, 8399, '\p{^-currency_Symbols}', "");
Expect(0, 8399, '\P{-currency_Symbols}', "");
Expect(1, 8399, '\P{^-currency_Symbols}', "");
Expect(0, 8400, '\p{-currency_Symbols}', "");
Expect(1, 8400, '\p{^-currency_Symbols}', "");
Expect(1, 8400, '\P{-currency_Symbols}', "");
Expect(0, 8400, '\P{^-currency_Symbols}', "");
Error('\p{/a/ -IS_Currency_Symbols}');
Error('\P{/a/ -IS_Currency_Symbols}');
Expect(1, 8399, '\p{iscurrencysymbols}', "");
Expect(0, 8399, '\p{^iscurrencysymbols}', "");
Expect(0, 8399, '\P{iscurrencysymbols}', "");
Expect(1, 8399, '\P{^iscurrencysymbols}', "");
Expect(0, 8400, '\p{iscurrencysymbols}', "");
Expect(1, 8400, '\p{^iscurrencysymbols}', "");
Expect(1, 8400, '\P{iscurrencysymbols}', "");
Expect(0, 8400, '\P{^iscurrencysymbols}', "");
Expect(1, 8399, '\p{	_Is_CURRENCY_Symbols}', "");
Expect(0, 8399, '\p{^	_Is_CURRENCY_Symbols}', "");
Expect(0, 8399, '\P{	_Is_CURRENCY_Symbols}', "");
Expect(1, 8399, '\P{^	_Is_CURRENCY_Symbols}', "");
Expect(0, 8400, '\p{	_Is_CURRENCY_Symbols}', "");
Expect(1, 8400, '\p{^	_Is_CURRENCY_Symbols}', "");
Expect(1, 8400, '\P{	_Is_CURRENCY_Symbols}', "");
Expect(0, 8400, '\P{^	_Is_CURRENCY_Symbols}', "");
Error('\p{		in_Currency_Symbols:=}');
Error('\P{		in_Currency_Symbols:=}');
Expect(1, 8399, '\p{incurrencysymbols}', "");
Expect(0, 8399, '\p{^incurrencysymbols}', "");
Expect(0, 8399, '\P{incurrencysymbols}', "");
Expect(1, 8399, '\P{^incurrencysymbols}', "");
Expect(0, 8400, '\p{incurrencysymbols}', "");
Expect(1, 8400, '\p{^incurrencysymbols}', "");
Expect(1, 8400, '\P{incurrencysymbols}', "");
Expect(0, 8400, '\P{^incurrencysymbols}', "");
Expect(1, 8399, '\p{_In_currency_symbols}', "");
Expect(0, 8399, '\p{^_In_currency_symbols}', "");
Expect(0, 8399, '\P{_In_currency_symbols}', "");
Expect(1, 8399, '\P{^_In_currency_symbols}', "");
Expect(0, 8400, '\p{_In_currency_symbols}', "");
Expect(1, 8400, '\p{^_In_currency_symbols}', "");
Expect(1, 8400, '\P{_In_currency_symbols}', "");
Expect(0, 8400, '\P{^_In_currency_symbols}', "");
Error('\p{-:=Cypriot}');
Error('\P{-:=Cypriot}');
Expect(1, 67647, '\p{cypriot}', "");
Expect(0, 67647, '\p{^cypriot}', "");
Expect(0, 67647, '\P{cypriot}', "");
Expect(1, 67647, '\P{^cypriot}', "");
Expect(0, 67648, '\p{cypriot}', "");
Expect(1, 67648, '\p{^cypriot}', "");
Expect(1, 67648, '\P{cypriot}', "");
Expect(0, 67648, '\P{^cypriot}', "");
Expect(1, 67647, '\p{--Cypriot}', "");
Expect(0, 67647, '\p{^--Cypriot}', "");
Expect(0, 67647, '\P{--Cypriot}', "");
Expect(1, 67647, '\P{^--Cypriot}', "");
Expect(0, 67648, '\p{--Cypriot}', "");
Expect(1, 67648, '\p{^--Cypriot}', "");
Expect(1, 67648, '\P{--Cypriot}', "");
Expect(0, 67648, '\P{^--Cypriot}', "");
Error('\p{ :=IS_cypriot}');
Error('\P{ :=IS_cypriot}');
Expect(1, 67647, '\p{iscypriot}', "");
Expect(0, 67647, '\p{^iscypriot}', "");
Expect(0, 67647, '\P{iscypriot}', "");
Expect(1, 67647, '\P{^iscypriot}', "");
Expect(0, 67648, '\p{iscypriot}', "");
Expect(1, 67648, '\p{^iscypriot}', "");
Expect(1, 67648, '\P{iscypriot}', "");
Expect(0, 67648, '\P{^iscypriot}', "");
Expect(1, 67647, '\p{		Is_Cypriot}', "");
Expect(0, 67647, '\p{^		Is_Cypriot}', "");
Expect(0, 67647, '\P{		Is_Cypriot}', "");
Expect(1, 67647, '\P{^		Is_Cypriot}', "");
Expect(0, 67648, '\p{		Is_Cypriot}', "");
Expect(1, 67648, '\p{^		Is_Cypriot}', "");
Expect(1, 67648, '\P{		Is_Cypriot}', "");
Expect(0, 67648, '\P{^		Is_Cypriot}', "");
Error('\p{/a/_Cprt}');
Error('\P{/a/_Cprt}');
Expect(1, 67647, '\p{cprt}', "");
Expect(0, 67647, '\p{^cprt}', "");
Expect(0, 67647, '\P{cprt}', "");
Expect(1, 67647, '\P{^cprt}', "");
Expect(0, 67648, '\p{cprt}', "");
Expect(1, 67648, '\p{^cprt}', "");
Expect(1, 67648, '\P{cprt}', "");
Expect(0, 67648, '\P{^cprt}', "");
Expect(1, 67647, '\p{-_CPRT}', "");
Expect(0, 67647, '\p{^-_CPRT}', "");
Expect(0, 67647, '\P{-_CPRT}', "");
Expect(1, 67647, '\P{^-_CPRT}', "");
Expect(0, 67648, '\p{-_CPRT}', "");
Expect(1, 67648, '\p{^-_CPRT}', "");
Expect(1, 67648, '\P{-_CPRT}', "");
Expect(0, 67648, '\P{^-_CPRT}', "");
Error('\p{_:=Is_Cprt}');
Error('\P{_:=Is_Cprt}');
Expect(1, 67647, '\p{iscprt}', "");
Expect(0, 67647, '\p{^iscprt}', "");
Expect(0, 67647, '\P{iscprt}', "");
Expect(1, 67647, '\P{^iscprt}', "");
Expect(0, 67648, '\p{iscprt}', "");
Expect(1, 67648, '\p{^iscprt}', "");
Expect(1, 67648, '\P{iscprt}', "");
Expect(0, 67648, '\P{^iscprt}', "");
Expect(1, 67647, '\p{Is_cprt}', "");
Expect(0, 67647, '\p{^Is_cprt}', "");
Expect(0, 67647, '\P{Is_cprt}', "");
Expect(1, 67647, '\P{^Is_cprt}', "");
Expect(0, 67648, '\p{Is_cprt}', "");
Expect(1, 67648, '\p{^Is_cprt}', "");
Expect(1, 67648, '\P{Is_cprt}', "");
Expect(0, 67648, '\P{^Is_cprt}', "");
Error('\p{/a/		CYPRIOT_Syllabary}');
Error('\P{/a/		CYPRIOT_Syllabary}');
Expect(1, 67647, '\p{cypriotsyllabary}', "");
Expect(0, 67647, '\p{^cypriotsyllabary}', "");
Expect(0, 67647, '\P{cypriotsyllabary}', "");
Expect(1, 67647, '\P{^cypriotsyllabary}', "");
Expect(0, 67648, '\p{cypriotsyllabary}', "");
Expect(1, 67648, '\p{^cypriotsyllabary}', "");
Expect(1, 67648, '\P{cypriotsyllabary}', "");
Expect(0, 67648, '\P{^cypriotsyllabary}', "");
Expect(1, 67647, '\p{--Cypriot_SYLLABARY}', "");
Expect(0, 67647, '\p{^--Cypriot_SYLLABARY}', "");
Expect(0, 67647, '\P{--Cypriot_SYLLABARY}', "");
Expect(1, 67647, '\P{^--Cypriot_SYLLABARY}', "");
Expect(0, 67648, '\p{--Cypriot_SYLLABARY}', "");
Expect(1, 67648, '\p{^--Cypriot_SYLLABARY}', "");
Expect(1, 67648, '\P{--Cypriot_SYLLABARY}', "");
Expect(0, 67648, '\P{^--Cypriot_SYLLABARY}', "");
Error('\p{/a/-_is_CYPRIOT_syllabary}');
Error('\P{/a/-_is_CYPRIOT_syllabary}');
Expect(1, 67647, '\p{iscypriotsyllabary}', "");
Expect(0, 67647, '\p{^iscypriotsyllabary}', "");
Expect(0, 67647, '\P{iscypriotsyllabary}', "");
Expect(1, 67647, '\P{^iscypriotsyllabary}', "");
Expect(0, 67648, '\p{iscypriotsyllabary}', "");
Expect(1, 67648, '\p{^iscypriotsyllabary}', "");
Expect(1, 67648, '\P{iscypriotsyllabary}', "");
Expect(0, 67648, '\P{^iscypriotsyllabary}', "");
Expect(1, 67647, '\p{ IS_Cypriot_syllabary}', "");
Expect(0, 67647, '\p{^ IS_Cypriot_syllabary}', "");
Expect(0, 67647, '\P{ IS_Cypriot_syllabary}', "");
Expect(1, 67647, '\P{^ IS_Cypriot_syllabary}', "");
Expect(0, 67648, '\p{ IS_Cypriot_syllabary}', "");
Expect(1, 67648, '\p{^ IS_Cypriot_syllabary}', "");
Expect(1, 67648, '\P{ IS_Cypriot_syllabary}', "");
Expect(0, 67648, '\P{^ IS_Cypriot_syllabary}', "");
Error('\p{/a/	 IN_CYPRIOT_syllabary}');
Error('\P{/a/	 IN_CYPRIOT_syllabary}');
Expect(1, 67647, '\p{incypriotsyllabary}', "");
Expect(0, 67647, '\p{^incypriotsyllabary}', "");
Expect(0, 67647, '\P{incypriotsyllabary}', "");
Expect(1, 67647, '\P{^incypriotsyllabary}', "");
Expect(0, 67648, '\p{incypriotsyllabary}', "");
Expect(1, 67648, '\p{^incypriotsyllabary}', "");
Expect(1, 67648, '\P{incypriotsyllabary}', "");
Expect(0, 67648, '\P{^incypriotsyllabary}', "");
Expect(1, 67647, '\p{	In_Cypriot_Syllabary}', "");
Expect(0, 67647, '\p{^	In_Cypriot_Syllabary}', "");
Expect(0, 67647, '\P{	In_Cypriot_Syllabary}', "");
Expect(1, 67647, '\P{^	In_Cypriot_Syllabary}', "");
Expect(0, 67648, '\p{	In_Cypriot_Syllabary}', "");
Expect(1, 67648, '\p{^	In_Cypriot_Syllabary}', "");
Expect(1, 67648, '\P{	In_Cypriot_Syllabary}', "");
Expect(0, 67648, '\P{^	In_Cypriot_Syllabary}', "");
Error('\p{	Cyrillic/a/}');
Error('\P{	Cyrillic/a/}');
Expect(1, 42655, '\p{cyrillic}', "");
Expect(0, 42655, '\p{^cyrillic}', "");
Expect(0, 42655, '\P{cyrillic}', "");
Expect(1, 42655, '\P{^cyrillic}', "");
Expect(0, 42656, '\p{cyrillic}', "");
Expect(1, 42656, '\p{^cyrillic}', "");
Expect(1, 42656, '\P{cyrillic}', "");
Expect(0, 42656, '\P{^cyrillic}', "");
Error('\p{_/a/is_Cyrillic}');
Error('\P{_/a/is_Cyrillic}');
Expect(1, 42655, '\p{iscyrillic}', "");
Expect(0, 42655, '\p{^iscyrillic}', "");
Expect(0, 42655, '\P{iscyrillic}', "");
Expect(1, 42655, '\P{^iscyrillic}', "");
Expect(0, 42656, '\p{iscyrillic}', "");
Expect(1, 42656, '\p{^iscyrillic}', "");
Expect(1, 42656, '\P{iscyrillic}', "");
Expect(0, 42656, '\P{^iscyrillic}', "");
Expect(1, 42655, '\p{ IS_Cyrillic}', "");
Expect(0, 42655, '\p{^ IS_Cyrillic}', "");
Expect(0, 42655, '\P{ IS_Cyrillic}', "");
Expect(1, 42655, '\P{^ IS_Cyrillic}', "");
Expect(0, 42656, '\p{ IS_Cyrillic}', "");
Expect(1, 42656, '\p{^ IS_Cyrillic}', "");
Expect(1, 42656, '\P{ IS_Cyrillic}', "");
Expect(0, 42656, '\P{^ IS_Cyrillic}', "");
Error('\p{ /a/cyrl}');
Error('\P{ /a/cyrl}');
Expect(1, 42655, '\p{cyrl}', "");
Expect(0, 42655, '\p{^cyrl}', "");
Expect(0, 42655, '\P{cyrl}', "");
Expect(1, 42655, '\P{^cyrl}', "");
Expect(0, 42656, '\p{cyrl}', "");
Expect(1, 42656, '\p{^cyrl}', "");
Expect(1, 42656, '\P{cyrl}', "");
Expect(0, 42656, '\P{^cyrl}', "");
Expect(1, 42655, '\p{- Cyrl}', "");
Expect(0, 42655, '\p{^- Cyrl}', "");
Expect(0, 42655, '\P{- Cyrl}', "");
Expect(1, 42655, '\P{^- Cyrl}', "");
Expect(0, 42656, '\p{- Cyrl}', "");
Expect(1, 42656, '\p{^- Cyrl}', "");
Expect(1, 42656, '\P{- Cyrl}', "");
Expect(0, 42656, '\P{^- Cyrl}', "");
Error('\p{ 	Is_CYRL:=}');
Error('\P{ 	Is_CYRL:=}');
Expect(1, 42655, '\p{iscyrl}', "");
Expect(0, 42655, '\p{^iscyrl}', "");
Expect(0, 42655, '\P{iscyrl}', "");
Expect(1, 42655, '\P{^iscyrl}', "");
Expect(0, 42656, '\p{iscyrl}', "");
Expect(1, 42656, '\p{^iscyrl}', "");
Expect(1, 42656, '\P{iscyrl}', "");
Expect(0, 42656, '\P{^iscyrl}', "");
Expect(1, 42655, '\p{-IS_Cyrl}', "");
Expect(0, 42655, '\p{^-IS_Cyrl}', "");
Expect(0, 42655, '\P{-IS_Cyrl}', "");
Expect(1, 42655, '\P{^-IS_Cyrl}', "");
Expect(0, 42656, '\p{-IS_Cyrl}', "");
Expect(1, 42656, '\p{^-IS_Cyrl}', "");
Expect(1, 42656, '\P{-IS_Cyrl}', "");
Expect(0, 42656, '\P{^-IS_Cyrl}', "");
Error('\p{__Cyrillic_extended_A:=}');
Error('\P{__Cyrillic_extended_A:=}');
Expect(1, 11775, '\p{cyrillicextendeda}', "");
Expect(0, 11775, '\p{^cyrillicextendeda}', "");
Expect(0, 11775, '\P{cyrillicextendeda}', "");
Expect(1, 11775, '\P{^cyrillicextendeda}', "");
Expect(0, 11776, '\p{cyrillicextendeda}', "");
Expect(1, 11776, '\p{^cyrillicextendeda}', "");
Expect(1, 11776, '\P{cyrillicextendeda}', "");
Expect(0, 11776, '\P{^cyrillicextendeda}', "");
Expect(1, 11775, '\p{ Cyrillic_extended_A}', "");
Expect(0, 11775, '\p{^ Cyrillic_extended_A}', "");
Expect(0, 11775, '\P{ Cyrillic_extended_A}', "");
Expect(1, 11775, '\P{^ Cyrillic_extended_A}', "");
Expect(0, 11776, '\p{ Cyrillic_extended_A}', "");
Expect(1, 11776, '\p{^ Cyrillic_extended_A}', "");
Expect(1, 11776, '\P{ Cyrillic_extended_A}', "");
Expect(0, 11776, '\P{^ Cyrillic_extended_A}', "");
Error('\p{_:=Is_Cyrillic_Extended_A}');
Error('\P{_:=Is_Cyrillic_Extended_A}');
Expect(1, 11775, '\p{iscyrillicextendeda}', "");
Expect(0, 11775, '\p{^iscyrillicextendeda}', "");
Expect(0, 11775, '\P{iscyrillicextendeda}', "");
Expect(1, 11775, '\P{^iscyrillicextendeda}', "");
Expect(0, 11776, '\p{iscyrillicextendeda}', "");
Expect(1, 11776, '\p{^iscyrillicextendeda}', "");
Expect(1, 11776, '\P{iscyrillicextendeda}', "");
Expect(0, 11776, '\P{^iscyrillicextendeda}', "");
Expect(1, 11775, '\p{_Is_Cyrillic_Extended_a}', "");
Expect(0, 11775, '\p{^_Is_Cyrillic_Extended_a}', "");
Expect(0, 11775, '\P{_Is_Cyrillic_Extended_a}', "");
Expect(1, 11775, '\P{^_Is_Cyrillic_Extended_a}', "");
Expect(0, 11776, '\p{_Is_Cyrillic_Extended_a}', "");
Expect(1, 11776, '\p{^_Is_Cyrillic_Extended_a}', "");
Expect(1, 11776, '\P{_Is_Cyrillic_Extended_a}', "");
Expect(0, 11776, '\P{^_Is_Cyrillic_Extended_a}', "");
Error('\p{:=In_Cyrillic_EXTENDED_A}');
Error('\P{:=In_Cyrillic_EXTENDED_A}');
Expect(1, 11775, '\p{incyrillicextendeda}', "");
Expect(0, 11775, '\p{^incyrillicextendeda}', "");
Expect(0, 11775, '\P{incyrillicextendeda}', "");
Expect(1, 11775, '\P{^incyrillicextendeda}', "");
Expect(0, 11776, '\p{incyrillicextendeda}', "");
Expect(1, 11776, '\p{^incyrillicextendeda}', "");
Expect(1, 11776, '\P{incyrillicextendeda}', "");
Expect(0, 11776, '\P{^incyrillicextendeda}', "");
Expect(1, 11775, '\p{ 	in_CYRILLIC_extended_A}', "");
Expect(0, 11775, '\p{^ 	in_CYRILLIC_extended_A}', "");
Expect(0, 11775, '\P{ 	in_CYRILLIC_extended_A}', "");
Expect(1, 11775, '\P{^ 	in_CYRILLIC_extended_A}', "");
Expect(0, 11776, '\p{ 	in_CYRILLIC_extended_A}', "");
Expect(1, 11776, '\p{^ 	in_CYRILLIC_extended_A}', "");
Expect(1, 11776, '\P{ 	in_CYRILLIC_extended_A}', "");
Expect(0, 11776, '\P{^ 	in_CYRILLIC_extended_A}', "");
Error('\p{/a/	Cyrillic_Ext_A}');
Error('\P{/a/	Cyrillic_Ext_A}');
Expect(1, 11775, '\p{cyrillicexta}', "");
Expect(0, 11775, '\p{^cyrillicexta}', "");
Expect(0, 11775, '\P{cyrillicexta}', "");
Expect(1, 11775, '\P{^cyrillicexta}', "");
Expect(0, 11776, '\p{cyrillicexta}', "");
Expect(1, 11776, '\p{^cyrillicexta}', "");
Expect(1, 11776, '\P{cyrillicexta}', "");
Expect(0, 11776, '\P{^cyrillicexta}', "");
Expect(1, 11775, '\p{ _CYRILLIC_EXT_A}', "");
Expect(0, 11775, '\p{^ _CYRILLIC_EXT_A}', "");
Expect(0, 11775, '\P{ _CYRILLIC_EXT_A}', "");
Expect(1, 11775, '\P{^ _CYRILLIC_EXT_A}', "");
Expect(0, 11776, '\p{ _CYRILLIC_EXT_A}', "");
Expect(1, 11776, '\p{^ _CYRILLIC_EXT_A}', "");
Expect(1, 11776, '\P{ _CYRILLIC_EXT_A}', "");
Expect(0, 11776, '\P{^ _CYRILLIC_EXT_A}', "");
Error('\p{- Is_Cyrillic_Ext_A/a/}');
Error('\P{- Is_Cyrillic_Ext_A/a/}');
Expect(1, 11775, '\p{iscyrillicexta}', "");
Expect(0, 11775, '\p{^iscyrillicexta}', "");
Expect(0, 11775, '\P{iscyrillicexta}', "");
Expect(1, 11775, '\P{^iscyrillicexta}', "");
Expect(0, 11776, '\p{iscyrillicexta}', "");
Expect(1, 11776, '\p{^iscyrillicexta}', "");
Expect(1, 11776, '\P{iscyrillicexta}', "");
Expect(0, 11776, '\P{^iscyrillicexta}', "");
Expect(1, 11775, '\p{_Is_CYRILLIC_ext_A}', "");
Expect(0, 11775, '\p{^_Is_CYRILLIC_ext_A}', "");
Expect(0, 11775, '\P{_Is_CYRILLIC_ext_A}', "");
Expect(1, 11775, '\P{^_Is_CYRILLIC_ext_A}', "");
Expect(0, 11776, '\p{_Is_CYRILLIC_ext_A}', "");
Expect(1, 11776, '\p{^_Is_CYRILLIC_ext_A}', "");
Expect(1, 11776, '\P{_Is_CYRILLIC_ext_A}', "");
Expect(0, 11776, '\P{^_Is_CYRILLIC_ext_A}', "");
Error('\p{_in_Cyrillic_Ext_a:=}');
Error('\P{_in_Cyrillic_Ext_a:=}');
Expect(1, 11775, '\p{incyrillicexta}', "");
Expect(0, 11775, '\p{^incyrillicexta}', "");
Expect(0, 11775, '\P{incyrillicexta}', "");
Expect(1, 11775, '\P{^incyrillicexta}', "");
Expect(0, 11776, '\p{incyrillicexta}', "");
Expect(1, 11776, '\p{^incyrillicexta}', "");
Expect(1, 11776, '\P{incyrillicexta}', "");
Expect(0, 11776, '\P{^incyrillicexta}', "");
Expect(1, 11775, '\p{ 	IN_CYRILLIC_Ext_a}', "");
Expect(0, 11775, '\p{^ 	IN_CYRILLIC_Ext_a}', "");
Expect(0, 11775, '\P{ 	IN_CYRILLIC_Ext_a}', "");
Expect(1, 11775, '\P{^ 	IN_CYRILLIC_Ext_a}', "");
Expect(0, 11776, '\p{ 	IN_CYRILLIC_Ext_a}', "");
Expect(1, 11776, '\p{^ 	IN_CYRILLIC_Ext_a}', "");
Expect(1, 11776, '\P{ 	IN_CYRILLIC_Ext_a}', "");
Expect(0, 11776, '\P{^ 	IN_CYRILLIC_Ext_a}', "");
Error('\p{_-Cyrillic_Extended_B:=}');
Error('\P{_-Cyrillic_Extended_B:=}');
Expect(1, 42655, '\p{cyrillicextendedb}', "");
Expect(0, 42655, '\p{^cyrillicextendedb}', "");
Expect(0, 42655, '\P{cyrillicextendedb}', "");
Expect(1, 42655, '\P{^cyrillicextendedb}', "");
Expect(0, 42656, '\p{cyrillicextendedb}', "");
Expect(1, 42656, '\p{^cyrillicextendedb}', "");
Expect(1, 42656, '\P{cyrillicextendedb}', "");
Expect(0, 42656, '\P{^cyrillicextendedb}', "");
Expect(1, 42655, '\p{ CYRILLIC_EXTENDED_B}', "");
Expect(0, 42655, '\p{^ CYRILLIC_EXTENDED_B}', "");
Expect(0, 42655, '\P{ CYRILLIC_EXTENDED_B}', "");
Expect(1, 42655, '\P{^ CYRILLIC_EXTENDED_B}', "");
Expect(0, 42656, '\p{ CYRILLIC_EXTENDED_B}', "");
Expect(1, 42656, '\p{^ CYRILLIC_EXTENDED_B}', "");
Expect(1, 42656, '\P{ CYRILLIC_EXTENDED_B}', "");
Expect(0, 42656, '\P{^ CYRILLIC_EXTENDED_B}', "");
Error('\p{Is_Cyrillic_EXTENDED_b/a/}');
Error('\P{Is_Cyrillic_EXTENDED_b/a/}');
Expect(1, 42655, '\p{iscyrillicextendedb}', "");
Expect(0, 42655, '\p{^iscyrillicextendedb}', "");
Expect(0, 42655, '\P{iscyrillicextendedb}', "");
Expect(1, 42655, '\P{^iscyrillicextendedb}', "");
Expect(0, 42656, '\p{iscyrillicextendedb}', "");
Expect(1, 42656, '\p{^iscyrillicextendedb}', "");
Expect(1, 42656, '\P{iscyrillicextendedb}', "");
Expect(0, 42656, '\P{^iscyrillicextendedb}', "");
Expect(1, 42655, '\p{-IS_cyrillic_Extended_B}', "");
Expect(0, 42655, '\p{^-IS_cyrillic_Extended_B}', "");
Expect(0, 42655, '\P{-IS_cyrillic_Extended_B}', "");
Expect(1, 42655, '\P{^-IS_cyrillic_Extended_B}', "");
Expect(0, 42656, '\p{-IS_cyrillic_Extended_B}', "");
Expect(1, 42656, '\p{^-IS_cyrillic_Extended_B}', "");
Expect(1, 42656, '\P{-IS_cyrillic_Extended_B}', "");
Expect(0, 42656, '\P{^-IS_cyrillic_Extended_B}', "");
Error('\p{/a/-	IN_Cyrillic_extended_B}');
Error('\P{/a/-	IN_Cyrillic_extended_B}');
Expect(1, 42655, '\p{incyrillicextendedb}', "");
Expect(0, 42655, '\p{^incyrillicextendedb}', "");
Expect(0, 42655, '\P{incyrillicextendedb}', "");
Expect(1, 42655, '\P{^incyrillicextendedb}', "");
Expect(0, 42656, '\p{incyrillicextendedb}', "");
Expect(1, 42656, '\p{^incyrillicextendedb}', "");
Expect(1, 42656, '\P{incyrillicextendedb}', "");
Expect(0, 42656, '\P{^incyrillicextendedb}', "");
Expect(1, 42655, '\p{ 	in_Cyrillic_Extended_B}', "");
Expect(0, 42655, '\p{^ 	in_Cyrillic_Extended_B}', "");
Expect(0, 42655, '\P{ 	in_Cyrillic_Extended_B}', "");
Expect(1, 42655, '\P{^ 	in_Cyrillic_Extended_B}', "");
Expect(0, 42656, '\p{ 	in_Cyrillic_Extended_B}', "");
Expect(1, 42656, '\p{^ 	in_Cyrillic_Extended_B}', "");
Expect(1, 42656, '\P{ 	in_Cyrillic_Extended_B}', "");
Expect(0, 42656, '\P{^ 	in_Cyrillic_Extended_B}', "");
Error('\p{/a/-CYRILLIC_EXT_b}');
Error('\P{/a/-CYRILLIC_EXT_b}');
Expect(1, 42655, '\p{cyrillicextb}', "");
Expect(0, 42655, '\p{^cyrillicextb}', "");
Expect(0, 42655, '\P{cyrillicextb}', "");
Expect(1, 42655, '\P{^cyrillicextb}', "");
Expect(0, 42656, '\p{cyrillicextb}', "");
Expect(1, 42656, '\p{^cyrillicextb}', "");
Expect(1, 42656, '\P{cyrillicextb}', "");
Expect(0, 42656, '\P{^cyrillicextb}', "");
Expect(1, 42655, '\p{--cyrillic_Ext_b}', "");
Expect(0, 42655, '\p{^--cyrillic_Ext_b}', "");
Expect(0, 42655, '\P{--cyrillic_Ext_b}', "");
Expect(1, 42655, '\P{^--cyrillic_Ext_b}', "");
Expect(0, 42656, '\p{--cyrillic_Ext_b}', "");
Expect(1, 42656, '\p{^--cyrillic_Ext_b}', "");
Expect(1, 42656, '\P{--cyrillic_Ext_b}', "");
Expect(0, 42656, '\P{^--cyrillic_Ext_b}', "");
Error('\p{__is_Cyrillic_ext_B:=}');
Error('\P{__is_Cyrillic_ext_B:=}');
Expect(1, 42655, '\p{iscyrillicextb}', "");
Expect(0, 42655, '\p{^iscyrillicextb}', "");
Expect(0, 42655, '\P{iscyrillicextb}', "");
Expect(1, 42655, '\P{^iscyrillicextb}', "");
Expect(0, 42656, '\p{iscyrillicextb}', "");
Expect(1, 42656, '\p{^iscyrillicextb}', "");
Expect(1, 42656, '\P{iscyrillicextb}', "");
Expect(0, 42656, '\P{^iscyrillicextb}', "");
Expect(1, 42655, '\p{- is_Cyrillic_ext_B}', "");
Expect(0, 42655, '\p{^- is_Cyrillic_ext_B}', "");
Expect(0, 42655, '\P{- is_Cyrillic_ext_B}', "");
Expect(1, 42655, '\P{^- is_Cyrillic_ext_B}', "");
Expect(0, 42656, '\p{- is_Cyrillic_ext_B}', "");
Expect(1, 42656, '\p{^- is_Cyrillic_ext_B}', "");
Expect(1, 42656, '\P{- is_Cyrillic_ext_B}', "");
Expect(0, 42656, '\P{^- is_Cyrillic_ext_B}', "");
Error('\p{-/a/In_Cyrillic_Ext_B}');
Error('\P{-/a/In_Cyrillic_Ext_B}');
Expect(1, 42655, '\p{incyrillicextb}', "");
Expect(0, 42655, '\p{^incyrillicextb}', "");
Expect(0, 42655, '\P{incyrillicextb}', "");
Expect(1, 42655, '\P{^incyrillicextb}', "");
Expect(0, 42656, '\p{incyrillicextb}', "");
Expect(1, 42656, '\p{^incyrillicextb}', "");
Expect(1, 42656, '\P{incyrillicextb}', "");
Expect(0, 42656, '\P{^incyrillicextb}', "");
Expect(1, 42655, '\p{ _in_Cyrillic_EXT_B}', "");
Expect(0, 42655, '\p{^ _in_Cyrillic_EXT_B}', "");
Expect(0, 42655, '\P{ _in_Cyrillic_EXT_B}', "");
Expect(1, 42655, '\P{^ _in_Cyrillic_EXT_B}', "");
Expect(0, 42656, '\p{ _in_Cyrillic_EXT_B}', "");
Expect(1, 42656, '\p{^ _in_Cyrillic_EXT_B}', "");
Expect(1, 42656, '\P{ _in_Cyrillic_EXT_B}', "");
Expect(0, 42656, '\P{^ _in_Cyrillic_EXT_B}', "");
Error('\p{-	cyrillic_supplement:=}');
Error('\P{-	cyrillic_supplement:=}');
Expect(1, 1327, '\p{cyrillicsupplement}', "");
Expect(0, 1327, '\p{^cyrillicsupplement}', "");
Expect(0, 1327, '\P{cyrillicsupplement}', "");
Expect(1, 1327, '\P{^cyrillicsupplement}', "");
Expect(0, 1328, '\p{cyrillicsupplement}', "");
Expect(1, 1328, '\p{^cyrillicsupplement}', "");
Expect(1, 1328, '\P{cyrillicsupplement}', "");
Expect(0, 1328, '\P{^cyrillicsupplement}', "");
Expect(1, 1327, '\p{_	Cyrillic_supplement}', "");
Expect(0, 1327, '\p{^_	Cyrillic_supplement}', "");
Expect(0, 1327, '\P{_	Cyrillic_supplement}', "");
Expect(1, 1327, '\P{^_	Cyrillic_supplement}', "");
Expect(0, 1328, '\p{_	Cyrillic_supplement}', "");
Expect(1, 1328, '\p{^_	Cyrillic_supplement}', "");
Expect(1, 1328, '\P{_	Cyrillic_supplement}', "");
Expect(0, 1328, '\P{^_	Cyrillic_supplement}', "");
Error('\p{/a/-_Is_CYRILLIC_supplement}');
Error('\P{/a/-_Is_CYRILLIC_supplement}');
Expect(1, 1327, '\p{iscyrillicsupplement}', "");
Expect(0, 1327, '\p{^iscyrillicsupplement}', "");
Expect(0, 1327, '\P{iscyrillicsupplement}', "");
Expect(1, 1327, '\P{^iscyrillicsupplement}', "");
Expect(0, 1328, '\p{iscyrillicsupplement}', "");
Expect(1, 1328, '\p{^iscyrillicsupplement}', "");
Expect(1, 1328, '\P{iscyrillicsupplement}', "");
Expect(0, 1328, '\P{^iscyrillicsupplement}', "");
Expect(1, 1327, '\p{		Is_Cyrillic_SUPPLEMENT}', "");
Expect(0, 1327, '\p{^		Is_Cyrillic_SUPPLEMENT}', "");
Expect(0, 1327, '\P{		Is_Cyrillic_SUPPLEMENT}', "");
Expect(1, 1327, '\P{^		Is_Cyrillic_SUPPLEMENT}', "");
Expect(0, 1328, '\p{		Is_Cyrillic_SUPPLEMENT}', "");
Expect(1, 1328, '\p{^		Is_Cyrillic_SUPPLEMENT}', "");
Expect(1, 1328, '\P{		Is_Cyrillic_SUPPLEMENT}', "");
Expect(0, 1328, '\P{^		Is_Cyrillic_SUPPLEMENT}', "");
Error('\p{:=_	In_Cyrillic_Supplement}');
Error('\P{:=_	In_Cyrillic_Supplement}');
Expect(1, 1327, '\p{incyrillicsupplement}', "");
Expect(0, 1327, '\p{^incyrillicsupplement}', "");
Expect(0, 1327, '\P{incyrillicsupplement}', "");
Expect(1, 1327, '\P{^incyrillicsupplement}', "");
Expect(0, 1328, '\p{incyrillicsupplement}', "");
Expect(1, 1328, '\p{^incyrillicsupplement}', "");
Expect(1, 1328, '\P{incyrillicsupplement}', "");
Expect(0, 1328, '\P{^incyrillicsupplement}', "");
Expect(1, 1327, '\p{_In_cyrillic_Supplement}', "");
Expect(0, 1327, '\p{^_In_cyrillic_Supplement}', "");
Expect(0, 1327, '\P{_In_cyrillic_Supplement}', "");
Expect(1, 1327, '\P{^_In_cyrillic_Supplement}', "");
Expect(0, 1328, '\p{_In_cyrillic_Supplement}', "");
Expect(1, 1328, '\p{^_In_cyrillic_Supplement}', "");
Expect(1, 1328, '\P{_In_cyrillic_Supplement}', "");
Expect(0, 1328, '\P{^_In_cyrillic_Supplement}', "");
Error('\p{	Cyrillic_Sup/a/}');
Error('\P{	Cyrillic_Sup/a/}');
Expect(1, 1327, '\p{cyrillicsup}', "");
Expect(0, 1327, '\p{^cyrillicsup}', "");
Expect(0, 1327, '\P{cyrillicsup}', "");
Expect(1, 1327, '\P{^cyrillicsup}', "");
Expect(0, 1328, '\p{cyrillicsup}', "");
Expect(1, 1328, '\p{^cyrillicsup}', "");
Expect(1, 1328, '\P{cyrillicsup}', "");
Expect(0, 1328, '\P{^cyrillicsup}', "");
Expect(1, 1327, '\p{		Cyrillic_Sup}', "");
Expect(0, 1327, '\p{^		Cyrillic_Sup}', "");
Expect(0, 1327, '\P{		Cyrillic_Sup}', "");
Expect(1, 1327, '\P{^		Cyrillic_Sup}', "");
Expect(0, 1328, '\p{		Cyrillic_Sup}', "");
Expect(1, 1328, '\p{^		Cyrillic_Sup}', "");
Expect(1, 1328, '\P{		Cyrillic_Sup}', "");
Expect(0, 1328, '\P{^		Cyrillic_Sup}', "");
Error('\p{/a/_ is_CYRILLIC_Sup}');
Error('\P{/a/_ is_CYRILLIC_Sup}');
Expect(1, 1327, '\p{iscyrillicsup}', "");
Expect(0, 1327, '\p{^iscyrillicsup}', "");
Expect(0, 1327, '\P{iscyrillicsup}', "");
Expect(1, 1327, '\P{^iscyrillicsup}', "");
Expect(0, 1328, '\p{iscyrillicsup}', "");
Expect(1, 1328, '\p{^iscyrillicsup}', "");
Expect(1, 1328, '\P{iscyrillicsup}', "");
Expect(0, 1328, '\P{^iscyrillicsup}', "");
Expect(1, 1327, '\p{ Is_CYRILLIC_Sup}', "");
Expect(0, 1327, '\p{^ Is_CYRILLIC_Sup}', "");
Expect(0, 1327, '\P{ Is_CYRILLIC_Sup}', "");
Expect(1, 1327, '\P{^ Is_CYRILLIC_Sup}', "");
Expect(0, 1328, '\p{ Is_CYRILLIC_Sup}', "");
Expect(1, 1328, '\p{^ Is_CYRILLIC_Sup}', "");
Expect(1, 1328, '\P{ Is_CYRILLIC_Sup}', "");
Expect(0, 1328, '\P{^ Is_CYRILLIC_Sup}', "");
Error('\p{_:=IN_Cyrillic_sup}');
Error('\P{_:=IN_Cyrillic_sup}');
Expect(1, 1327, '\p{incyrillicsup}', "");
Expect(0, 1327, '\p{^incyrillicsup}', "");
Expect(0, 1327, '\P{incyrillicsup}', "");
Expect(1, 1327, '\P{^incyrillicsup}', "");
Expect(0, 1328, '\p{incyrillicsup}', "");
Expect(1, 1328, '\p{^incyrillicsup}', "");
Expect(1, 1328, '\P{incyrillicsup}', "");
Expect(0, 1328, '\P{^incyrillicsup}', "");
Expect(1, 1327, '\p{ -In_Cyrillic_sup}', "");
Expect(0, 1327, '\p{^ -In_Cyrillic_sup}', "");
Expect(0, 1327, '\P{ -In_Cyrillic_sup}', "");
Expect(1, 1327, '\P{^ -In_Cyrillic_sup}', "");
Expect(0, 1328, '\p{ -In_Cyrillic_sup}', "");
Expect(1, 1328, '\p{^ -In_Cyrillic_sup}', "");
Expect(1, 1328, '\P{ -In_Cyrillic_sup}', "");
Expect(0, 1328, '\P{^ -In_Cyrillic_sup}', "");
Error('\p{:=--Cyrillic_Supplementary}');
Error('\P{:=--Cyrillic_Supplementary}');
Expect(1, 1327, '\p{cyrillicsupplementary}', "");
Expect(0, 1327, '\p{^cyrillicsupplementary}', "");
Expect(0, 1327, '\P{cyrillicsupplementary}', "");
Expect(1, 1327, '\P{^cyrillicsupplementary}', "");
Expect(0, 1328, '\p{cyrillicsupplementary}', "");
Expect(1, 1328, '\p{^cyrillicsupplementary}', "");
Expect(1, 1328, '\P{cyrillicsupplementary}', "");
Expect(0, 1328, '\P{^cyrillicsupplementary}', "");
Expect(1, 1327, '\p{	-Cyrillic_Supplementary}', "");
Expect(0, 1327, '\p{^	-Cyrillic_Supplementary}', "");
Expect(0, 1327, '\P{	-Cyrillic_Supplementary}', "");
Expect(1, 1327, '\P{^	-Cyrillic_Supplementary}', "");
Expect(0, 1328, '\p{	-Cyrillic_Supplementary}', "");
Expect(1, 1328, '\p{^	-Cyrillic_Supplementary}', "");
Expect(1, 1328, '\P{	-Cyrillic_Supplementary}', "");
Expect(0, 1328, '\P{^	-Cyrillic_Supplementary}', "");
Error('\p{ /a/Is_CYRILLIC_supplementary}');
Error('\P{ /a/Is_CYRILLIC_supplementary}');
Expect(1, 1327, '\p{iscyrillicsupplementary}', "");
Expect(0, 1327, '\p{^iscyrillicsupplementary}', "");
Expect(0, 1327, '\P{iscyrillicsupplementary}', "");
Expect(1, 1327, '\P{^iscyrillicsupplementary}', "");
Expect(0, 1328, '\p{iscyrillicsupplementary}', "");
Expect(1, 1328, '\p{^iscyrillicsupplementary}', "");
Expect(1, 1328, '\P{iscyrillicsupplementary}', "");
Expect(0, 1328, '\P{^iscyrillicsupplementary}', "");
Expect(1, 1327, '\p{- Is_CYRILLIC_Supplementary}', "");
Expect(0, 1327, '\p{^- Is_CYRILLIC_Supplementary}', "");
Expect(0, 1327, '\P{- Is_CYRILLIC_Supplementary}', "");
Expect(1, 1327, '\P{^- Is_CYRILLIC_Supplementary}', "");
Expect(0, 1328, '\p{- Is_CYRILLIC_Supplementary}', "");
Expect(1, 1328, '\p{^- Is_CYRILLIC_Supplementary}', "");
Expect(1, 1328, '\P{- Is_CYRILLIC_Supplementary}', "");
Expect(0, 1328, '\P{^- Is_CYRILLIC_Supplementary}', "");
Error('\p{_	In_cyrillic_Supplementary/a/}');
Error('\P{_	In_cyrillic_Supplementary/a/}');
Expect(1, 1327, '\p{incyrillicsupplementary}', "");
Expect(0, 1327, '\p{^incyrillicsupplementary}', "");
Expect(0, 1327, '\P{incyrillicsupplementary}', "");
Expect(1, 1327, '\P{^incyrillicsupplementary}', "");
Expect(0, 1328, '\p{incyrillicsupplementary}', "");
Expect(1, 1328, '\p{^incyrillicsupplementary}', "");
Expect(1, 1328, '\P{incyrillicsupplementary}', "");
Expect(0, 1328, '\P{^incyrillicsupplementary}', "");
Expect(1, 1327, '\p{  IN_CYRILLIC_SUPPLEMENTARY}', "");
Expect(0, 1327, '\p{^  IN_CYRILLIC_SUPPLEMENTARY}', "");
Expect(0, 1327, '\P{  IN_CYRILLIC_SUPPLEMENTARY}', "");
Expect(1, 1327, '\P{^  IN_CYRILLIC_SUPPLEMENTARY}', "");
Expect(0, 1328, '\p{  IN_CYRILLIC_SUPPLEMENTARY}', "");
Expect(1, 1328, '\p{^  IN_CYRILLIC_SUPPLEMENTARY}', "");
Expect(1, 1328, '\P{  IN_CYRILLIC_SUPPLEMENTARY}', "");
Expect(0, 1328, '\P{^  IN_CYRILLIC_SUPPLEMENTARY}', "");
Error('\p{/a/ Dash}');
Error('\P{/a/ Dash}');
Expect(1, 65293, '\p{dash}', "");
Expect(0, 65293, '\p{^dash}', "");
Expect(0, 65293, '\P{dash}', "");
Expect(1, 65293, '\P{^dash}', "");
Expect(0, 65294, '\p{dash}', "");
Expect(1, 65294, '\p{^dash}', "");
Expect(1, 65294, '\P{dash}', "");
Expect(0, 65294, '\P{^dash}', "");
Expect(1, 65293, '\p{	DASH}', "");
Expect(0, 65293, '\p{^	DASH}', "");
Expect(0, 65293, '\P{	DASH}', "");
Expect(1, 65293, '\P{^	DASH}', "");
Expect(0, 65294, '\p{	DASH}', "");
Expect(1, 65294, '\p{^	DASH}', "");
Expect(1, 65294, '\P{	DASH}', "");
Expect(0, 65294, '\P{^	DASH}', "");
Error('\p{	_is_DASH:=}');
Error('\P{	_is_DASH:=}');
Expect(1, 65293, '\p{isdash}', "");
Expect(0, 65293, '\p{^isdash}', "");
Expect(0, 65293, '\P{isdash}', "");
Expect(1, 65293, '\P{^isdash}', "");
Expect(0, 65294, '\p{isdash}', "");
Expect(1, 65294, '\p{^isdash}', "");
Expect(1, 65294, '\P{isdash}', "");
Expect(0, 65294, '\P{^isdash}', "");
Expect(1, 65293, '\p{	_Is_Dash}', "");
Expect(0, 65293, '\p{^	_Is_Dash}', "");
Expect(0, 65293, '\P{	_Is_Dash}', "");
Expect(1, 65293, '\P{^	_Is_Dash}', "");
Expect(0, 65294, '\p{	_Is_Dash}', "");
Expect(1, 65294, '\p{^	_Is_Dash}', "");
Expect(1, 65294, '\P{	_Is_Dash}', "");
Expect(0, 65294, '\P{^	_Is_Dash}', "");
Error('\p{		DASH_Punctuation/a/}');
Error('\P{		DASH_Punctuation/a/}');
Expect(1, 65293, '\p{dashpunctuation}', "");
Expect(0, 65293, '\p{^dashpunctuation}', "");
Expect(0, 65293, '\P{dashpunctuation}', "");
Expect(1, 65293, '\P{^dashpunctuation}', "");
Expect(0, 65294, '\p{dashpunctuation}', "");
Expect(1, 65294, '\p{^dashpunctuation}', "");
Expect(1, 65294, '\P{dashpunctuation}', "");
Expect(0, 65294, '\P{^dashpunctuation}', "");
Expect(1, 65293, '\p{	Dash_PUNCTUATION}', "");
Expect(0, 65293, '\p{^	Dash_PUNCTUATION}', "");
Expect(0, 65293, '\P{	Dash_PUNCTUATION}', "");
Expect(1, 65293, '\P{^	Dash_PUNCTUATION}', "");
Expect(0, 65294, '\p{	Dash_PUNCTUATION}', "");
Expect(1, 65294, '\p{^	Dash_PUNCTUATION}', "");
Expect(1, 65294, '\P{	Dash_PUNCTUATION}', "");
Expect(0, 65294, '\P{^	Dash_PUNCTUATION}', "");
Error('\p{- Is_DASH_Punctuation/a/}');
Error('\P{- Is_DASH_Punctuation/a/}');
Expect(1, 65293, '\p{isdashpunctuation}', "");
Expect(0, 65293, '\p{^isdashpunctuation}', "");
Expect(0, 65293, '\P{isdashpunctuation}', "");
Expect(1, 65293, '\P{^isdashpunctuation}', "");
Expect(0, 65294, '\p{isdashpunctuation}', "");
Expect(1, 65294, '\p{^isdashpunctuation}', "");
Expect(1, 65294, '\P{isdashpunctuation}', "");
Expect(0, 65294, '\P{^isdashpunctuation}', "");
Expect(1, 65293, '\p{ _is_Dash_punctuation}', "");
Expect(0, 65293, '\p{^ _is_Dash_punctuation}', "");
Expect(0, 65293, '\P{ _is_Dash_punctuation}', "");
Expect(1, 65293, '\P{^ _is_Dash_punctuation}', "");
Expect(0, 65294, '\p{ _is_Dash_punctuation}', "");
Expect(1, 65294, '\p{^ _is_Dash_punctuation}', "");
Expect(1, 65294, '\P{ _is_Dash_punctuation}', "");
Expect(0, 65294, '\P{^ _is_Dash_punctuation}', "");
Error('\p{ /a/PD}');
Error('\P{ /a/PD}');
Expect(1, 65293, '\p{pd}', "");
Expect(0, 65293, '\p{^pd}', "");
Expect(0, 65293, '\P{pd}', "");
Expect(1, 65293, '\P{^pd}', "");
Expect(0, 65294, '\p{pd}', "");
Expect(1, 65294, '\p{^pd}', "");
Expect(1, 65294, '\P{pd}', "");
Expect(0, 65294, '\P{^pd}', "");
Expect(1, 65293, '\p{ 	PD}', "");
Expect(0, 65293, '\p{^ 	PD}', "");
Expect(0, 65293, '\P{ 	PD}', "");
Expect(1, 65293, '\P{^ 	PD}', "");
Expect(0, 65294, '\p{ 	PD}', "");
Expect(1, 65294, '\p{^ 	PD}', "");
Expect(1, 65294, '\P{ 	PD}', "");
Expect(0, 65294, '\P{^ 	PD}', "");
Error('\p{--Is_pd:=}');
Error('\P{--Is_pd:=}');
Expect(1, 65293, '\p{ispd}', "");
Expect(0, 65293, '\p{^ispd}', "");
Expect(0, 65293, '\P{ispd}', "");
Expect(1, 65293, '\P{^ispd}', "");
Expect(0, 65294, '\p{ispd}', "");
Expect(1, 65294, '\p{^ispd}', "");
Expect(1, 65294, '\P{ispd}', "");
Expect(0, 65294, '\P{^ispd}', "");
Expect(1, 65293, '\p{	-Is_PD}', "");
Expect(0, 65293, '\p{^	-Is_PD}', "");
Expect(0, 65293, '\P{	-Is_PD}', "");
Expect(1, 65293, '\P{^	-Is_PD}', "");
Expect(0, 65294, '\p{	-Is_PD}', "");
Expect(1, 65294, '\p{^	-Is_PD}', "");
Expect(1, 65294, '\P{	-Is_PD}', "");
Expect(0, 65294, '\P{^	-Is_PD}', "");
Error('\p{/a/	 Default_IGNORABLE_code_point}');
Error('\P{/a/	 Default_IGNORABLE_code_point}');
Expect(1, 921599, '\p{defaultignorablecodepoint}', "");
Expect(0, 921599, '\p{^defaultignorablecodepoint}', "");
Expect(0, 921599, '\P{defaultignorablecodepoint}', "");
Expect(1, 921599, '\P{^defaultignorablecodepoint}', "");
Expect(0, 921600, '\p{defaultignorablecodepoint}', "");
Expect(1, 921600, '\p{^defaultignorablecodepoint}', "");
Expect(1, 921600, '\P{defaultignorablecodepoint}', "");
Expect(0, 921600, '\P{^defaultignorablecodepoint}', "");
Expect(1, 921599, '\p{  Default_Ignorable_Code_POINT}', "");
Expect(0, 921599, '\p{^  Default_Ignorable_Code_POINT}', "");
Expect(0, 921599, '\P{  Default_Ignorable_Code_POINT}', "");
Expect(1, 921599, '\P{^  Default_Ignorable_Code_POINT}', "");
Expect(0, 921600, '\p{  Default_Ignorable_Code_POINT}', "");
Expect(1, 921600, '\p{^  Default_Ignorable_Code_POINT}', "");
Expect(1, 921600, '\P{  Default_Ignorable_Code_POINT}', "");
Expect(0, 921600, '\P{^  Default_Ignorable_Code_POINT}', "");
Error('\p{_:=IS_DEFAULT_Ignorable_code_point}');
Error('\P{_:=IS_DEFAULT_Ignorable_code_point}');
Expect(1, 921599, '\p{isdefaultignorablecodepoint}', "");
Expect(0, 921599, '\p{^isdefaultignorablecodepoint}', "");
Expect(0, 921599, '\P{isdefaultignorablecodepoint}', "");
Expect(1, 921599, '\P{^isdefaultignorablecodepoint}', "");
Expect(0, 921600, '\p{isdefaultignorablecodepoint}', "");
Expect(1, 921600, '\p{^isdefaultignorablecodepoint}', "");
Expect(1, 921600, '\P{isdefaultignorablecodepoint}', "");
Expect(0, 921600, '\P{^isdefaultignorablecodepoint}', "");
Expect(1, 921599, '\p{-	Is_Default_ignorable_CODE_POINT}', "");
Expect(0, 921599, '\p{^-	Is_Default_ignorable_CODE_POINT}', "");
Expect(0, 921599, '\P{-	Is_Default_ignorable_CODE_POINT}', "");
Expect(1, 921599, '\P{^-	Is_Default_ignorable_CODE_POINT}', "");
Expect(0, 921600, '\p{-	Is_Default_ignorable_CODE_POINT}', "");
Expect(1, 921600, '\p{^-	Is_Default_ignorable_CODE_POINT}', "");
Expect(1, 921600, '\P{-	Is_Default_ignorable_CODE_POINT}', "");
Expect(0, 921600, '\P{^-	Is_Default_ignorable_CODE_POINT}', "");
Error('\p{/a/-DI}');
Error('\P{/a/-DI}');
Expect(1, 921599, '\p{di}', "");
Expect(0, 921599, '\p{^di}', "");
Expect(0, 921599, '\P{di}', "");
Expect(1, 921599, '\P{^di}', "");
Expect(0, 921600, '\p{di}', "");
Expect(1, 921600, '\p{^di}', "");
Expect(1, 921600, '\P{di}', "");
Expect(0, 921600, '\P{^di}', "");
Expect(1, 921599, '\p{- DI}', "");
Expect(0, 921599, '\p{^- DI}', "");
Expect(0, 921599, '\P{- DI}', "");
Expect(1, 921599, '\P{^- DI}', "");
Expect(0, 921600, '\p{- DI}', "");
Expect(1, 921600, '\p{^- DI}', "");
Expect(1, 921600, '\P{- DI}', "");
Expect(0, 921600, '\P{^- DI}', "");
Error('\p{/a/	 IS_di}');
Error('\P{/a/	 IS_di}');
Expect(1, 921599, '\p{isdi}', "");
Expect(0, 921599, '\p{^isdi}', "");
Expect(0, 921599, '\P{isdi}', "");
Expect(1, 921599, '\P{^isdi}', "");
Expect(0, 921600, '\p{isdi}', "");
Expect(1, 921600, '\p{^isdi}', "");
Expect(1, 921600, '\P{isdi}', "");
Expect(0, 921600, '\P{^isdi}', "");
Expect(1, 921599, '\p{_	Is_DI}', "");
Expect(0, 921599, '\p{^_	Is_DI}', "");
Expect(0, 921599, '\P{_	Is_DI}', "");
Expect(1, 921599, '\P{^_	Is_DI}', "");
Expect(0, 921600, '\p{_	Is_DI}', "");
Expect(1, 921600, '\p{^_	Is_DI}', "");
Expect(1, 921600, '\P{_	Is_DI}', "");
Expect(0, 921600, '\P{^_	Is_DI}', "");
Error('\p{__Deprecated:=}');
Error('\P{__Deprecated:=}');
Expect(1, 917631, '\p{deprecated}', "");
Expect(0, 917631, '\p{^deprecated}', "");
Expect(0, 917631, '\P{deprecated}', "");
Expect(1, 917631, '\P{^deprecated}', "");
Expect(0, 917632, '\p{deprecated}', "");
Expect(1, 917632, '\p{^deprecated}', "");
Expect(1, 917632, '\P{deprecated}', "");
Expect(0, 917632, '\P{^deprecated}', "");
Expect(1, 917631, '\p{ DEPRECATED}', "");
Expect(0, 917631, '\p{^ DEPRECATED}', "");
Expect(0, 917631, '\P{ DEPRECATED}', "");
Expect(1, 917631, '\P{^ DEPRECATED}', "");
Expect(0, 917632, '\p{ DEPRECATED}', "");
Expect(1, 917632, '\p{^ DEPRECATED}', "");
Expect(1, 917632, '\P{ DEPRECATED}', "");
Expect(0, 917632, '\P{^ DEPRECATED}', "");
Error('\p{:=-	IS_deprecated}');
Error('\P{:=-	IS_deprecated}');
Expect(1, 917631, '\p{isdeprecated}', "");
Expect(0, 917631, '\p{^isdeprecated}', "");
Expect(0, 917631, '\P{isdeprecated}', "");
Expect(1, 917631, '\P{^isdeprecated}', "");
Expect(0, 917632, '\p{isdeprecated}', "");
Expect(1, 917632, '\p{^isdeprecated}', "");
Expect(1, 917632, '\P{isdeprecated}', "");
Expect(0, 917632, '\P{^isdeprecated}', "");
Expect(1, 917631, '\p{ -Is_DEPRECATED}', "");
Expect(0, 917631, '\p{^ -Is_DEPRECATED}', "");
Expect(0, 917631, '\P{ -Is_DEPRECATED}', "");
Expect(1, 917631, '\P{^ -Is_DEPRECATED}', "");
Expect(0, 917632, '\p{ -Is_DEPRECATED}', "");
Expect(1, 917632, '\p{^ -Is_DEPRECATED}', "");
Expect(1, 917632, '\P{ -Is_DEPRECATED}', "");
Expect(0, 917632, '\P{^ -Is_DEPRECATED}', "");
Error('\p{	Dep/a/}');
Error('\P{	Dep/a/}');
Expect(1, 917631, '\p{dep}', "");
Expect(0, 917631, '\p{^dep}', "");
Expect(0, 917631, '\P{dep}', "");
Expect(1, 917631, '\P{^dep}', "");
Expect(0, 917632, '\p{dep}', "");
Expect(1, 917632, '\p{^dep}', "");
Expect(1, 917632, '\P{dep}', "");
Expect(0, 917632, '\P{^dep}', "");
Expect(1, 917631, '\p{	-DEP}', "");
Expect(0, 917631, '\p{^	-DEP}', "");
Expect(0, 917631, '\P{	-DEP}', "");
Expect(1, 917631, '\P{^	-DEP}', "");
Expect(0, 917632, '\p{	-DEP}', "");
Expect(1, 917632, '\p{^	-DEP}', "");
Expect(1, 917632, '\P{	-DEP}', "");
Expect(0, 917632, '\P{^	-DEP}', "");
Error('\p{-/a/Is_Dep}');
Error('\P{-/a/Is_Dep}');
Expect(1, 917631, '\p{isdep}', "");
Expect(0, 917631, '\p{^isdep}', "");
Expect(0, 917631, '\P{isdep}', "");
Expect(1, 917631, '\P{^isdep}', "");
Expect(0, 917632, '\p{isdep}', "");
Expect(1, 917632, '\p{^isdep}', "");
Expect(1, 917632, '\P{isdep}', "");
Expect(0, 917632, '\P{^isdep}', "");
Expect(1, 917631, '\p{-is_dep}', "");
Expect(0, 917631, '\p{^-is_dep}', "");
Expect(0, 917631, '\P{-is_dep}', "");
Expect(1, 917631, '\P{^-is_dep}', "");
Expect(0, 917632, '\p{-is_dep}', "");
Expect(1, 917632, '\p{^-is_dep}', "");
Expect(1, 917632, '\P{-is_dep}', "");
Expect(0, 917632, '\P{^-is_dep}', "");
Error('\p{/a/  Deseret}');
Error('\P{/a/  Deseret}');
Expect(1, 66639, '\p{deseret}', "");
Expect(0, 66639, '\p{^deseret}', "");
Expect(0, 66639, '\P{deseret}', "");
Expect(1, 66639, '\P{^deseret}', "");
Expect(0, 66640, '\p{deseret}', "");
Expect(1, 66640, '\p{^deseret}', "");
Expect(1, 66640, '\P{deseret}', "");
Expect(0, 66640, '\P{^deseret}', "");
Expect(1, 66639, '\p{ deseret}', "");
Expect(0, 66639, '\p{^ deseret}', "");
Expect(0, 66639, '\P{ deseret}', "");
Expect(1, 66639, '\P{^ deseret}', "");
Expect(0, 66640, '\p{ deseret}', "");
Expect(1, 66640, '\p{^ deseret}', "");
Expect(1, 66640, '\P{ deseret}', "");
Expect(0, 66640, '\P{^ deseret}', "");
Error('\p{/a/	Is_Deseret}');
Error('\P{/a/	Is_Deseret}');
Expect(1, 66639, '\p{isdeseret}', "");
Expect(0, 66639, '\p{^isdeseret}', "");
Expect(0, 66639, '\P{isdeseret}', "");
Expect(1, 66639, '\P{^isdeseret}', "");
Expect(0, 66640, '\p{isdeseret}', "");
Expect(1, 66640, '\p{^isdeseret}', "");
Expect(1, 66640, '\P{isdeseret}', "");
Expect(0, 66640, '\P{^isdeseret}', "");
Expect(1, 66639, '\p{_ IS_Deseret}', "");
Expect(0, 66639, '\p{^_ IS_Deseret}', "");
Expect(0, 66639, '\P{_ IS_Deseret}', "");
Expect(1, 66639, '\P{^_ IS_Deseret}', "");
Expect(0, 66640, '\p{_ IS_Deseret}', "");
Expect(1, 66640, '\p{^_ IS_Deseret}', "");
Expect(1, 66640, '\P{_ IS_Deseret}', "");
Expect(0, 66640, '\P{^_ IS_Deseret}', "");
Error('\p{-_DSRT:=}');
Error('\P{-_DSRT:=}');
Expect(1, 66639, '\p{dsrt}', "");
Expect(0, 66639, '\p{^dsrt}', "");
Expect(0, 66639, '\P{dsrt}', "");
Expect(1, 66639, '\P{^dsrt}', "");
Expect(0, 66640, '\p{dsrt}', "");
Expect(1, 66640, '\p{^dsrt}', "");
Expect(1, 66640, '\P{dsrt}', "");
Expect(0, 66640, '\P{^dsrt}', "");
Expect(1, 66639, '\p{	 Dsrt}', "");
Expect(0, 66639, '\p{^	 Dsrt}', "");
Expect(0, 66639, '\P{	 Dsrt}', "");
Expect(1, 66639, '\P{^	 Dsrt}', "");
Expect(0, 66640, '\p{	 Dsrt}', "");
Expect(1, 66640, '\p{^	 Dsrt}', "");
Expect(1, 66640, '\P{	 Dsrt}', "");
Expect(0, 66640, '\P{^	 Dsrt}', "");
Error('\p{	IS_Dsrt/a/}');
Error('\P{	IS_Dsrt/a/}');
Expect(1, 66639, '\p{isdsrt}', "");
Expect(0, 66639, '\p{^isdsrt}', "");
Expect(0, 66639, '\P{isdsrt}', "");
Expect(1, 66639, '\P{^isdsrt}', "");
Expect(0, 66640, '\p{isdsrt}', "");
Expect(1, 66640, '\p{^isdsrt}', "");
Expect(1, 66640, '\P{isdsrt}', "");
Expect(0, 66640, '\P{^isdsrt}', "");
Expect(1, 66639, '\p{_IS_dsrt}', "");
Expect(0, 66639, '\p{^_IS_dsrt}', "");
Expect(0, 66639, '\P{_IS_dsrt}', "");
Expect(1, 66639, '\P{^_IS_dsrt}', "");
Expect(0, 66640, '\p{_IS_dsrt}', "");
Expect(1, 66640, '\p{^_IS_dsrt}', "");
Expect(1, 66640, '\P{_IS_dsrt}', "");
Expect(0, 66640, '\P{^_IS_dsrt}', "");
Error('\p{_:=DEVANAGARI}');
Error('\P{_:=DEVANAGARI}');
Expect(1, 43259, '\p{devanagari}', "");
Expect(0, 43259, '\p{^devanagari}', "");
Expect(0, 43259, '\P{devanagari}', "");
Expect(1, 43259, '\P{^devanagari}', "");
Expect(0, 43260, '\p{devanagari}', "");
Expect(1, 43260, '\p{^devanagari}', "");
Expect(1, 43260, '\P{devanagari}', "");
Expect(0, 43260, '\P{^devanagari}', "");
Expect(1, 43259, '\p{ 	DEVANAGARI}', "");
Expect(0, 43259, '\p{^ 	DEVANAGARI}', "");
Expect(0, 43259, '\P{ 	DEVANAGARI}', "");
Expect(1, 43259, '\P{^ 	DEVANAGARI}', "");
Expect(0, 43260, '\p{ 	DEVANAGARI}', "");
Expect(1, 43260, '\p{^ 	DEVANAGARI}', "");
Expect(1, 43260, '\P{ 	DEVANAGARI}', "");
Expect(0, 43260, '\P{^ 	DEVANAGARI}', "");
Error('\p{	:=is_Devanagari}');
Error('\P{	:=is_Devanagari}');
Expect(1, 43259, '\p{isdevanagari}', "");
Expect(0, 43259, '\p{^isdevanagari}', "");
Expect(0, 43259, '\P{isdevanagari}', "");
Expect(1, 43259, '\P{^isdevanagari}', "");
Expect(0, 43260, '\p{isdevanagari}', "");
Expect(1, 43260, '\p{^isdevanagari}', "");
Expect(1, 43260, '\P{isdevanagari}', "");
Expect(0, 43260, '\P{^isdevanagari}', "");
Expect(1, 43259, '\p{-Is_devanagari}', "");
Expect(0, 43259, '\p{^-Is_devanagari}', "");
Expect(0, 43259, '\P{-Is_devanagari}', "");
Expect(1, 43259, '\P{^-Is_devanagari}', "");
Expect(0, 43260, '\p{-Is_devanagari}', "");
Expect(1, 43260, '\p{^-Is_devanagari}', "");
Expect(1, 43260, '\P{-Is_devanagari}', "");
Expect(0, 43260, '\P{^-Is_devanagari}', "");
Error('\p{:=_Deva}');
Error('\P{:=_Deva}');
Expect(1, 43259, '\p{deva}', "");
Expect(0, 43259, '\p{^deva}', "");
Expect(0, 43259, '\P{deva}', "");
Expect(1, 43259, '\P{^deva}', "");
Expect(0, 43260, '\p{deva}', "");
Expect(1, 43260, '\p{^deva}', "");
Expect(1, 43260, '\P{deva}', "");
Expect(0, 43260, '\P{^deva}', "");
Expect(1, 43259, '\p{ _deva}', "");
Expect(0, 43259, '\p{^ _deva}', "");
Expect(0, 43259, '\P{ _deva}', "");
Expect(1, 43259, '\P{^ _deva}', "");
Expect(0, 43260, '\p{ _deva}', "");
Expect(1, 43260, '\p{^ _deva}', "");
Expect(1, 43260, '\P{ _deva}', "");
Expect(0, 43260, '\P{^ _deva}', "");
Error('\p{_/a/Is_Deva}');
Error('\P{_/a/Is_Deva}');
Expect(1, 43259, '\p{isdeva}', "");
Expect(0, 43259, '\p{^isdeva}', "");
Expect(0, 43259, '\P{isdeva}', "");
Expect(1, 43259, '\P{^isdeva}', "");
Expect(0, 43260, '\p{isdeva}', "");
Expect(1, 43260, '\p{^isdeva}', "");
Expect(1, 43260, '\P{isdeva}', "");
Expect(0, 43260, '\P{^isdeva}', "");
Expect(1, 43259, '\p{--is_Deva}', "");
Expect(0, 43259, '\p{^--is_Deva}', "");
Expect(0, 43259, '\P{--is_Deva}', "");
Expect(1, 43259, '\P{^--is_Deva}', "");
Expect(0, 43260, '\p{--is_Deva}', "");
Expect(1, 43260, '\p{^--is_Deva}', "");
Expect(1, 43260, '\P{--is_Deva}', "");
Expect(0, 43260, '\P{^--is_Deva}', "");
Error('\p{	 DEVANAGARI_Extended:=}');
Error('\P{	 DEVANAGARI_Extended:=}');
Expect(1, 43263, '\p{devanagariextended}', "");
Expect(0, 43263, '\p{^devanagariextended}', "");
Expect(0, 43263, '\P{devanagariextended}', "");
Expect(1, 43263, '\P{^devanagariextended}', "");
Expect(0, 43264, '\p{devanagariextended}', "");
Expect(1, 43264, '\p{^devanagariextended}', "");
Expect(1, 43264, '\P{devanagariextended}', "");
Expect(0, 43264, '\P{^devanagariextended}', "");
Expect(1, 43263, '\p{ -Devanagari_Extended}', "");
Expect(0, 43263, '\p{^ -Devanagari_Extended}', "");
Expect(0, 43263, '\P{ -Devanagari_Extended}', "");
Expect(1, 43263, '\P{^ -Devanagari_Extended}', "");
Expect(0, 43264, '\p{ -Devanagari_Extended}', "");
Expect(1, 43264, '\p{^ -Devanagari_Extended}', "");
Expect(1, 43264, '\P{ -Devanagari_Extended}', "");
Expect(0, 43264, '\P{^ -Devanagari_Extended}', "");
Error('\p{_is_Devanagari_EXTENDED:=}');
Error('\P{_is_Devanagari_EXTENDED:=}');
Expect(1, 43263, '\p{isdevanagariextended}', "");
Expect(0, 43263, '\p{^isdevanagariextended}', "");
Expect(0, 43263, '\P{isdevanagariextended}', "");
Expect(1, 43263, '\P{^isdevanagariextended}', "");
Expect(0, 43264, '\p{isdevanagariextended}', "");
Expect(1, 43264, '\p{^isdevanagariextended}', "");
Expect(1, 43264, '\P{isdevanagariextended}', "");
Expect(0, 43264, '\P{^isdevanagariextended}', "");
Expect(1, 43263, '\p{ _is_Devanagari_EXTENDED}', "");
Expect(0, 43263, '\p{^ _is_Devanagari_EXTENDED}', "");
Expect(0, 43263, '\P{ _is_Devanagari_EXTENDED}', "");
Expect(1, 43263, '\P{^ _is_Devanagari_EXTENDED}', "");
Expect(0, 43264, '\p{ _is_Devanagari_EXTENDED}', "");
Expect(1, 43264, '\p{^ _is_Devanagari_EXTENDED}', "");
Expect(1, 43264, '\P{ _is_Devanagari_EXTENDED}', "");
Expect(0, 43264, '\P{^ _is_Devanagari_EXTENDED}', "");
Error('\p{ :=In_devanagari_extended}');
Error('\P{ :=In_devanagari_extended}');
Expect(1, 43263, '\p{indevanagariextended}', "");
Expect(0, 43263, '\p{^indevanagariextended}', "");
Expect(0, 43263, '\P{indevanagariextended}', "");
Expect(1, 43263, '\P{^indevanagariextended}', "");
Expect(0, 43264, '\p{indevanagariextended}', "");
Expect(1, 43264, '\p{^indevanagariextended}', "");
Expect(1, 43264, '\P{indevanagariextended}', "");
Expect(0, 43264, '\P{^indevanagariextended}', "");
Expect(1, 43263, '\p{In_Devanagari_Extended}', "");
Expect(0, 43263, '\p{^In_Devanagari_Extended}', "");
Expect(0, 43263, '\P{In_Devanagari_Extended}', "");
Expect(1, 43263, '\P{^In_Devanagari_Extended}', "");
Expect(0, 43264, '\p{In_Devanagari_Extended}', "");
Expect(1, 43264, '\p{^In_Devanagari_Extended}', "");
Expect(1, 43264, '\P{In_Devanagari_Extended}', "");
Expect(0, 43264, '\P{^In_Devanagari_Extended}', "");
Error('\p{:=_devanagari_EXT}');
Error('\P{:=_devanagari_EXT}');
Expect(1, 43263, '\p{devanagariext}', "");
Expect(0, 43263, '\p{^devanagariext}', "");
Expect(0, 43263, '\P{devanagariext}', "");
Expect(1, 43263, '\P{^devanagariext}', "");
Expect(0, 43264, '\p{devanagariext}', "");
Expect(1, 43264, '\p{^devanagariext}', "");
Expect(1, 43264, '\P{devanagariext}', "");
Expect(0, 43264, '\P{^devanagariext}', "");
Expect(1, 43263, '\p{_devanagari_EXT}', "");
Expect(0, 43263, '\p{^_devanagari_EXT}', "");
Expect(0, 43263, '\P{_devanagari_EXT}', "");
Expect(1, 43263, '\P{^_devanagari_EXT}', "");
Expect(0, 43264, '\p{_devanagari_EXT}', "");
Expect(1, 43264, '\p{^_devanagari_EXT}', "");
Expect(1, 43264, '\P{_devanagari_EXT}', "");
Expect(0, 43264, '\P{^_devanagari_EXT}', "");
Error('\p{/a/--Is_DEVANAGARI_ext}');
Error('\P{/a/--Is_DEVANAGARI_ext}');
Expect(1, 43263, '\p{isdevanagariext}', "");
Expect(0, 43263, '\p{^isdevanagariext}', "");
Expect(0, 43263, '\P{isdevanagariext}', "");
Expect(1, 43263, '\P{^isdevanagariext}', "");
Expect(0, 43264, '\p{isdevanagariext}', "");
Expect(1, 43264, '\p{^isdevanagariext}', "");
Expect(1, 43264, '\P{isdevanagariext}', "");
Expect(0, 43264, '\P{^isdevanagariext}', "");
Expect(1, 43263, '\p{-Is_Devanagari_Ext}', "");
Expect(0, 43263, '\p{^-Is_Devanagari_Ext}', "");
Expect(0, 43263, '\P{-Is_Devanagari_Ext}', "");
Expect(1, 43263, '\P{^-Is_Devanagari_Ext}', "");
Expect(0, 43264, '\p{-Is_Devanagari_Ext}', "");
Expect(1, 43264, '\p{^-Is_Devanagari_Ext}', "");
Expect(1, 43264, '\P{-Is_Devanagari_Ext}', "");
Expect(0, 43264, '\P{^-Is_Devanagari_Ext}', "");
Error('\p{ :=In_DEVANAGARI_ext}');
Error('\P{ :=In_DEVANAGARI_ext}');
Expect(1, 43263, '\p{indevanagariext}', "");
Expect(0, 43263, '\p{^indevanagariext}', "");
Expect(0, 43263, '\P{indevanagariext}', "");
Expect(1, 43263, '\P{^indevanagariext}', "");
Expect(0, 43264, '\p{indevanagariext}', "");
Expect(1, 43264, '\p{^indevanagariext}', "");
Expect(1, 43264, '\P{indevanagariext}', "");
Expect(0, 43264, '\P{^indevanagariext}', "");
Expect(1, 43263, '\p{-	In_Devanagari_Ext}', "");
Expect(0, 43263, '\p{^-	In_Devanagari_Ext}', "");
Expect(0, 43263, '\P{-	In_Devanagari_Ext}', "");
Expect(1, 43263, '\P{^-	In_Devanagari_Ext}', "");
Expect(0, 43264, '\p{-	In_Devanagari_Ext}', "");
Expect(1, 43264, '\p{^-	In_Devanagari_Ext}', "");
Expect(1, 43264, '\P{-	In_Devanagari_Ext}', "");
Expect(0, 43264, '\P{^-	In_Devanagari_Ext}', "");
Error('\p{-_diacritic/a/}');
Error('\P{-_diacritic/a/}');
Expect(1, 119213, '\p{diacritic}', "");
Expect(0, 119213, '\p{^diacritic}', "");
Expect(0, 119213, '\P{diacritic}', "");
Expect(1, 119213, '\P{^diacritic}', "");
Expect(0, 119214, '\p{diacritic}', "");
Expect(1, 119214, '\p{^diacritic}', "");
Expect(1, 119214, '\P{diacritic}', "");
Expect(0, 119214, '\P{^diacritic}', "");
Error('\p{_ is_Diacritic:=}');
Error('\P{_ is_Diacritic:=}');
Expect(1, 119213, '\p{isdiacritic}', "");
Expect(0, 119213, '\p{^isdiacritic}', "");
Expect(0, 119213, '\P{isdiacritic}', "");
Expect(1, 119213, '\P{^isdiacritic}', "");
Expect(0, 119214, '\p{isdiacritic}', "");
Expect(1, 119214, '\p{^isdiacritic}', "");
Expect(1, 119214, '\P{isdiacritic}', "");
Expect(0, 119214, '\P{^isdiacritic}', "");
Expect(1, 119213, '\p{		Is_Diacritic}', "");
Expect(0, 119213, '\p{^		Is_Diacritic}', "");
Expect(0, 119213, '\P{		Is_Diacritic}', "");
Expect(1, 119213, '\P{^		Is_Diacritic}', "");
Expect(0, 119214, '\p{		Is_Diacritic}', "");
Expect(1, 119214, '\p{^		Is_Diacritic}', "");
Expect(1, 119214, '\P{		Is_Diacritic}', "");
Expect(0, 119214, '\P{^		Is_Diacritic}', "");
Error('\p{-Dia:=}');
Error('\P{-Dia:=}');
Expect(1, 119213, '\p{dia}', "");
Expect(0, 119213, '\p{^dia}', "");
Expect(0, 119213, '\P{dia}', "");
Expect(1, 119213, '\P{^dia}', "");
Expect(0, 119214, '\p{dia}', "");
Expect(1, 119214, '\p{^dia}', "");
Expect(1, 119214, '\P{dia}', "");
Expect(0, 119214, '\P{^dia}', "");
Expect(1, 119213, '\p{	 DIA}', "");
Expect(0, 119213, '\p{^	 DIA}', "");
Expect(0, 119213, '\P{	 DIA}', "");
Expect(1, 119213, '\P{^	 DIA}', "");
Expect(0, 119214, '\p{	 DIA}', "");
Expect(1, 119214, '\p{^	 DIA}', "");
Expect(1, 119214, '\P{	 DIA}', "");
Expect(0, 119214, '\P{^	 DIA}', "");
Error('\p{-Is_DIA:=}');
Error('\P{-Is_DIA:=}');
Expect(1, 119213, '\p{isdia}', "");
Expect(0, 119213, '\p{^isdia}', "");
Expect(0, 119213, '\P{isdia}', "");
Expect(1, 119213, '\P{^isdia}', "");
Expect(0, 119214, '\p{isdia}', "");
Expect(1, 119214, '\p{^isdia}', "");
Expect(1, 119214, '\P{isdia}', "");
Expect(0, 119214, '\P{^isdia}', "");
Expect(1, 119213, '\p{- Is_Dia}', "");
Expect(0, 119213, '\p{^- Is_Dia}', "");
Expect(0, 119213, '\P{- Is_Dia}', "");
Expect(1, 119213, '\P{^- Is_Dia}', "");
Expect(0, 119214, '\p{- Is_Dia}', "");
Expect(1, 119214, '\p{^- Is_Dia}', "");
Expect(1, 119214, '\P{- Is_Dia}', "");
Expect(0, 119214, '\P{^- Is_Dia}', "");
Error('\p{/a/digit}');
Error('\P{/a/digit}');
Expect(1, 120831, '\p{digit}', "");
Expect(0, 120831, '\p{^digit}', "");
Expect(0, 120831, '\P{digit}', "");
Expect(1, 120831, '\P{^digit}', "");
Expect(0, 120832, '\p{digit}', "");
Expect(1, 120832, '\p{^digit}', "");
Expect(1, 120832, '\P{digit}', "");
Expect(0, 120832, '\P{^digit}', "");
Expect(1, 120831, '\p{Digit}', "");
Expect(0, 120831, '\p{^Digit}', "");
Expect(0, 120831, '\P{Digit}', "");
Expect(1, 120831, '\P{^Digit}', "");
Expect(0, 120832, '\p{Digit}', "");
Expect(1, 120832, '\p{^Digit}', "");
Expect(1, 120832, '\P{Digit}', "");
Expect(0, 120832, '\P{^Digit}', "");
Error('\p{:= _xposixdigit}');
Error('\P{:= _xposixdigit}');
Expect(1, 120831, '\p{xposixdigit}', "");
Expect(0, 120831, '\p{^xposixdigit}', "");
Expect(0, 120831, '\P{xposixdigit}', "");
Expect(1, 120831, '\P{^xposixdigit}', "");
Expect(0, 120832, '\p{xposixdigit}', "");
Expect(1, 120832, '\p{^xposixdigit}', "");
Expect(1, 120832, '\P{xposixdigit}', "");
Expect(0, 120832, '\P{^xposixdigit}', "");
Expect(1, 120831, '\p{ -xposixdigit}', "");
Expect(0, 120831, '\p{^ -xposixdigit}', "");
Expect(0, 120831, '\P{ -xposixdigit}', "");
Expect(1, 120831, '\P{^ -xposixdigit}', "");
Expect(0, 120832, '\p{ -xposixdigit}', "");
Expect(1, 120832, '\p{^ -xposixdigit}', "");
Expect(1, 120832, '\P{ -xposixdigit}', "");
Expect(0, 120832, '\P{^ -xposixdigit}', "");
Error('\p{	:=is_Digit}');
Error('\P{	:=is_Digit}');
Expect(1, 120831, '\p{isdigit}', "");
Expect(0, 120831, '\p{^isdigit}', "");
Expect(0, 120831, '\P{isdigit}', "");
Expect(1, 120831, '\P{^isdigit}', "");
Expect(0, 120832, '\p{isdigit}', "");
Expect(1, 120832, '\p{^isdigit}', "");
Expect(1, 120832, '\P{isdigit}', "");
Expect(0, 120832, '\P{^isdigit}', "");
Expect(1, 120831, '\p{ 	IS_digit}', "");
Expect(0, 120831, '\p{^ 	IS_digit}', "");
Expect(0, 120831, '\P{ 	IS_digit}', "");
Expect(1, 120831, '\P{^ 	IS_digit}', "");
Expect(0, 120832, '\p{ 	IS_digit}', "");
Expect(1, 120832, '\p{^ 	IS_digit}', "");
Expect(1, 120832, '\P{ 	IS_digit}', "");
Expect(0, 120832, '\P{^ 	IS_digit}', "");
Error('\p{Is_XPOSIXDIGIT/a/}');
Error('\P{Is_XPOSIXDIGIT/a/}');
Expect(1, 120831, '\p{isxposixdigit}', "");
Expect(0, 120831, '\p{^isxposixdigit}', "");
Expect(0, 120831, '\P{isxposixdigit}', "");
Expect(1, 120831, '\P{^isxposixdigit}', "");
Expect(0, 120832, '\p{isxposixdigit}', "");
Expect(1, 120832, '\p{^isxposixdigit}', "");
Expect(1, 120832, '\P{isxposixdigit}', "");
Expect(0, 120832, '\P{^isxposixdigit}', "");
Expect(1, 120831, '\p{	-Is_XPOSIXDIGIT}', "");
Expect(0, 120831, '\p{^	-Is_XPOSIXDIGIT}', "");
Expect(0, 120831, '\P{	-Is_XPOSIXDIGIT}', "");
Expect(1, 120831, '\P{^	-Is_XPOSIXDIGIT}', "");
Expect(0, 120832, '\p{	-Is_XPOSIXDIGIT}', "");
Expect(1, 120832, '\p{^	-Is_XPOSIXDIGIT}', "");
Expect(1, 120832, '\P{	-Is_XPOSIXDIGIT}', "");
Expect(0, 120832, '\P{^	-Is_XPOSIXDIGIT}', "");
Error('\p{/a/decimal_number}');
Error('\P{/a/decimal_number}');
Expect(1, 120831, '\p{decimalnumber}', "");
Expect(0, 120831, '\p{^decimalnumber}', "");
Expect(0, 120831, '\P{decimalnumber}', "");
Expect(1, 120831, '\P{^decimalnumber}', "");
Expect(0, 120832, '\p{decimalnumber}', "");
Expect(1, 120832, '\p{^decimalnumber}', "");
Expect(1, 120832, '\P{decimalnumber}', "");
Expect(0, 120832, '\P{^decimalnumber}', "");
Expect(1, 120831, '\p{-_Decimal_number}', "");
Expect(0, 120831, '\p{^-_Decimal_number}', "");
Expect(0, 120831, '\P{-_Decimal_number}', "");
Expect(1, 120831, '\P{^-_Decimal_number}', "");
Expect(0, 120832, '\p{-_Decimal_number}', "");
Expect(1, 120832, '\p{^-_Decimal_number}', "");
Expect(1, 120832, '\P{-_Decimal_number}', "");
Expect(0, 120832, '\P{^-_Decimal_number}', "");
Error('\p{_-IS_Decimal_Number:=}');
Error('\P{_-IS_Decimal_Number:=}');
Expect(1, 120831, '\p{isdecimalnumber}', "");
Expect(0, 120831, '\p{^isdecimalnumber}', "");
Expect(0, 120831, '\P{isdecimalnumber}', "");
Expect(1, 120831, '\P{^isdecimalnumber}', "");
Expect(0, 120832, '\p{isdecimalnumber}', "");
Expect(1, 120832, '\p{^isdecimalnumber}', "");
Expect(1, 120832, '\P{isdecimalnumber}', "");
Expect(0, 120832, '\P{^isdecimalnumber}', "");
Expect(1, 120831, '\p{- Is_decimal_number}', "");
Expect(0, 120831, '\p{^- Is_decimal_number}', "");
Expect(0, 120831, '\P{- Is_decimal_number}', "");
Expect(1, 120831, '\P{^- Is_decimal_number}', "");
Expect(0, 120832, '\p{- Is_decimal_number}', "");
Expect(1, 120832, '\p{^- Is_decimal_number}', "");
Expect(1, 120832, '\P{- Is_decimal_number}', "");
Expect(0, 120832, '\P{^- Is_decimal_number}', "");
Error('\p{/a/_ND}');
Error('\P{/a/_ND}');
Expect(1, 120831, '\p{nd}', "");
Expect(0, 120831, '\p{^nd}', "");
Expect(0, 120831, '\P{nd}', "");
Expect(1, 120831, '\P{^nd}', "");
Expect(0, 120832, '\p{nd}', "");
Expect(1, 120832, '\p{^nd}', "");
Expect(1, 120832, '\P{nd}', "");
Expect(0, 120832, '\P{^nd}', "");
Expect(1, 120831, '\p{	 Nd}', "");
Expect(0, 120831, '\p{^	 Nd}', "");
Expect(0, 120831, '\P{	 Nd}', "");
Expect(1, 120831, '\P{^	 Nd}', "");
Expect(0, 120832, '\p{	 Nd}', "");
Expect(1, 120832, '\p{^	 Nd}', "");
Expect(1, 120832, '\P{	 Nd}', "");
Expect(0, 120832, '\P{^	 Nd}', "");
Error('\p{_Is_Nd:=}');
Error('\P{_Is_Nd:=}');
Expect(1, 120831, '\p{isnd}', "");
Expect(0, 120831, '\p{^isnd}', "");
Expect(0, 120831, '\P{isnd}', "");
Expect(1, 120831, '\P{^isnd}', "");
Expect(0, 120832, '\p{isnd}', "");
Expect(1, 120832, '\p{^isnd}', "");
Expect(1, 120832, '\P{isnd}', "");
Expect(0, 120832, '\P{^isnd}', "");
Expect(1, 120831, '\p{_-Is_Nd}', "");
Expect(0, 120831, '\p{^_-Is_Nd}', "");
Expect(0, 120831, '\P{_-Is_Nd}', "");
Expect(1, 120831, '\P{^_-Is_Nd}', "");
Expect(0, 120832, '\p{_-Is_Nd}', "");
Expect(1, 120832, '\p{^_-Is_Nd}', "");
Expect(1, 120832, '\P{_-Is_Nd}', "");
Expect(0, 120832, '\P{^_-Is_Nd}', "");
Error('\p{ 	DINGBATS/a/}');
Error('\P{ 	DINGBATS/a/}');
Expect(1, 10175, '\p{dingbats}', "");
Expect(0, 10175, '\p{^dingbats}', "");
Expect(0, 10175, '\P{dingbats}', "");
Expect(1, 10175, '\P{^dingbats}', "");
Expect(0, 10176, '\p{dingbats}', "");
Expect(1, 10176, '\p{^dingbats}', "");
Expect(1, 10176, '\P{dingbats}', "");
Expect(0, 10176, '\P{^dingbats}', "");
Expect(1, 10175, '\p{	 dingbats}', "");
Expect(0, 10175, '\p{^	 dingbats}', "");
Expect(0, 10175, '\P{	 dingbats}', "");
Expect(1, 10175, '\P{^	 dingbats}', "");
Expect(0, 10176, '\p{	 dingbats}', "");
Expect(1, 10176, '\p{^	 dingbats}', "");
Expect(1, 10176, '\P{	 dingbats}', "");
Expect(0, 10176, '\P{^	 dingbats}', "");
Error('\p{:=		Is_Dingbats}');
Error('\P{:=		Is_Dingbats}');
Expect(1, 10175, '\p{isdingbats}', "");
Expect(0, 10175, '\p{^isdingbats}', "");
Expect(0, 10175, '\P{isdingbats}', "");
Expect(1, 10175, '\P{^isdingbats}', "");
Expect(0, 10176, '\p{isdingbats}', "");
Expect(1, 10176, '\p{^isdingbats}', "");
Expect(1, 10176, '\P{isdingbats}', "");
Expect(0, 10176, '\P{^isdingbats}', "");
Expect(1, 10175, '\p{_-Is_Dingbats}', "");
Expect(0, 10175, '\p{^_-Is_Dingbats}', "");
Expect(0, 10175, '\P{_-Is_Dingbats}', "");
Expect(1, 10175, '\P{^_-Is_Dingbats}', "");
Expect(0, 10176, '\p{_-Is_Dingbats}', "");
Expect(1, 10176, '\p{^_-Is_Dingbats}', "");
Expect(1, 10176, '\P{_-Is_Dingbats}', "");
Expect(0, 10176, '\P{^_-Is_Dingbats}', "");
Error('\p{/a/in_Dingbats}');
Error('\P{/a/in_Dingbats}');
Expect(1, 10175, '\p{indingbats}', "");
Expect(0, 10175, '\p{^indingbats}', "");
Expect(0, 10175, '\P{indingbats}', "");
Expect(1, 10175, '\P{^indingbats}', "");
Expect(0, 10176, '\p{indingbats}', "");
Expect(1, 10176, '\p{^indingbats}', "");
Expect(1, 10176, '\P{indingbats}', "");
Expect(0, 10176, '\P{^indingbats}', "");
Expect(1, 10175, '\p{-	in_Dingbats}', "");
Expect(0, 10175, '\p{^-	in_Dingbats}', "");
Expect(0, 10175, '\P{-	in_Dingbats}', "");
Expect(1, 10175, '\P{^-	in_Dingbats}', "");
Expect(0, 10176, '\p{-	in_Dingbats}', "");
Expect(1, 10176, '\p{^-	in_Dingbats}', "");
Expect(1, 10176, '\P{-	in_Dingbats}', "");
Expect(0, 10176, '\P{^-	in_Dingbats}', "");
Error('\p{:=Domino_Tiles}');
Error('\P{:=Domino_Tiles}');
Expect(1, 127135, '\p{dominotiles}', "");
Expect(0, 127135, '\p{^dominotiles}', "");
Expect(0, 127135, '\P{dominotiles}', "");
Expect(1, 127135, '\P{^dominotiles}', "");
Expect(0, 127136, '\p{dominotiles}', "");
Expect(1, 127136, '\p{^dominotiles}', "");
Expect(1, 127136, '\P{dominotiles}', "");
Expect(0, 127136, '\P{^dominotiles}', "");
Expect(1, 127135, '\p{	_DOMINO_Tiles}', "");
Expect(0, 127135, '\p{^	_DOMINO_Tiles}', "");
Expect(0, 127135, '\P{	_DOMINO_Tiles}', "");
Expect(1, 127135, '\P{^	_DOMINO_Tiles}', "");
Expect(0, 127136, '\p{	_DOMINO_Tiles}', "");
Expect(1, 127136, '\p{^	_DOMINO_Tiles}', "");
Expect(1, 127136, '\P{	_DOMINO_Tiles}', "");
Expect(0, 127136, '\P{^	_DOMINO_Tiles}', "");
Error('\p{/a/Is_Domino_Tiles}');
Error('\P{/a/Is_Domino_Tiles}');
Expect(1, 127135, '\p{isdominotiles}', "");
Expect(0, 127135, '\p{^isdominotiles}', "");
Expect(0, 127135, '\P{isdominotiles}', "");
Expect(1, 127135, '\P{^isdominotiles}', "");
Expect(0, 127136, '\p{isdominotiles}', "");
Expect(1, 127136, '\p{^isdominotiles}', "");
Expect(1, 127136, '\P{isdominotiles}', "");
Expect(0, 127136, '\P{^isdominotiles}', "");
Expect(1, 127135, '\p{ Is_DOMINO_Tiles}', "");
Expect(0, 127135, '\p{^ Is_DOMINO_Tiles}', "");
Expect(0, 127135, '\P{ Is_DOMINO_Tiles}', "");
Expect(1, 127135, '\P{^ Is_DOMINO_Tiles}', "");
Expect(0, 127136, '\p{ Is_DOMINO_Tiles}', "");
Expect(1, 127136, '\p{^ Is_DOMINO_Tiles}', "");
Expect(1, 127136, '\P{ Is_DOMINO_Tiles}', "");
Expect(0, 127136, '\P{^ Is_DOMINO_Tiles}', "");
Error('\p{/a/	 In_Domino_Tiles}');
Error('\P{/a/	 In_Domino_Tiles}');
Expect(1, 127135, '\p{indominotiles}', "");
Expect(0, 127135, '\p{^indominotiles}', "");
Expect(0, 127135, '\P{indominotiles}', "");
Expect(1, 127135, '\P{^indominotiles}', "");
Expect(0, 127136, '\p{indominotiles}', "");
Expect(1, 127136, '\p{^indominotiles}', "");
Expect(1, 127136, '\P{indominotiles}', "");
Expect(0, 127136, '\P{^indominotiles}', "");
Expect(1, 127135, '\p{-In_domino_Tiles}', "");
Expect(0, 127135, '\p{^-In_domino_Tiles}', "");
Expect(0, 127135, '\P{-In_domino_Tiles}', "");
Expect(1, 127135, '\P{^-In_domino_Tiles}', "");
Expect(0, 127136, '\p{-In_domino_Tiles}', "");
Expect(1, 127136, '\p{^-In_domino_Tiles}', "");
Expect(1, 127136, '\P{-In_domino_Tiles}', "");
Expect(0, 127136, '\P{^-In_domino_Tiles}', "");
Error('\p{/a/ 	Domino}');
Error('\P{/a/ 	Domino}');
Expect(1, 127135, '\p{domino}', "");
Expect(0, 127135, '\p{^domino}', "");
Expect(0, 127135, '\P{domino}', "");
Expect(1, 127135, '\P{^domino}', "");
Expect(0, 127136, '\p{domino}', "");
Expect(1, 127136, '\p{^domino}', "");
Expect(1, 127136, '\P{domino}', "");
Expect(0, 127136, '\P{^domino}', "");
Expect(1, 127135, '\p{ -domino}', "");
Expect(0, 127135, '\p{^ -domino}', "");
Expect(0, 127135, '\P{ -domino}', "");
Expect(1, 127135, '\P{^ -domino}', "");
Expect(0, 127136, '\p{ -domino}', "");
Expect(1, 127136, '\p{^ -domino}', "");
Expect(1, 127136, '\P{ -domino}', "");
Expect(0, 127136, '\P{^ -domino}', "");
Error('\p{_/a/Is_domino}');
Error('\P{_/a/Is_domino}');
Expect(1, 127135, '\p{isdomino}', "");
Expect(0, 127135, '\p{^isdomino}', "");
Expect(0, 127135, '\P{isdomino}', "");
Expect(1, 127135, '\P{^isdomino}', "");
Expect(0, 127136, '\p{isdomino}', "");
Expect(1, 127136, '\p{^isdomino}', "");
Expect(1, 127136, '\P{isdomino}', "");
Expect(0, 127136, '\P{^isdomino}', "");
Expect(1, 127135, '\p{_ is_Domino}', "");
Expect(0, 127135, '\p{^_ is_Domino}', "");
Expect(0, 127135, '\P{_ is_Domino}', "");
Expect(1, 127135, '\P{^_ is_Domino}', "");
Expect(0, 127136, '\p{_ is_Domino}', "");
Expect(1, 127136, '\p{^_ is_Domino}', "");
Expect(1, 127136, '\P{_ is_Domino}', "");
Expect(0, 127136, '\P{^_ is_Domino}', "");
Error('\p{/a/ in_domino}');
Error('\P{/a/ in_domino}');
Expect(1, 127135, '\p{indomino}', "");
Expect(0, 127135, '\p{^indomino}', "");
Expect(0, 127135, '\P{indomino}', "");
Expect(1, 127135, '\P{^indomino}', "");
Expect(0, 127136, '\p{indomino}', "");
Expect(1, 127136, '\p{^indomino}', "");
Expect(1, 127136, '\P{indomino}', "");
Expect(0, 127136, '\P{^indomino}', "");
Expect(1, 127135, '\p{-_IN_domino}', "");
Expect(0, 127135, '\p{^-_IN_domino}', "");
Expect(0, 127135, '\P{-_IN_domino}', "");
Expect(1, 127135, '\P{^-_IN_domino}', "");
Expect(0, 127136, '\p{-_IN_domino}', "");
Expect(1, 127136, '\p{^-_IN_domino}', "");
Expect(1, 127136, '\P{-_IN_domino}', "");
Expect(0, 127136, '\P{^-_IN_domino}', "");
Error('\p{:=Egyptian_Hieroglyphs}');
Error('\P{:=Egyptian_Hieroglyphs}');
Expect(1, 78894, '\p{egyptianhieroglyphs}', "");
Expect(0, 78894, '\p{^egyptianhieroglyphs}', "");
Expect(0, 78894, '\P{egyptianhieroglyphs}', "");
Expect(1, 78894, '\P{^egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{^egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{^egyptianhieroglyphs}', "");
Expect(1, 78894, '\p{	Egyptian_hieroglyphs}', "");
Expect(0, 78894, '\p{^	Egyptian_hieroglyphs}', "");
Expect(0, 78894, '\P{	Egyptian_hieroglyphs}', "");
Expect(1, 78894, '\P{^	Egyptian_hieroglyphs}', "");
Expect(0, 78895, '\p{	Egyptian_hieroglyphs}', "");
Expect(1, 78895, '\p{^	Egyptian_hieroglyphs}', "");
Expect(1, 78895, '\P{	Egyptian_hieroglyphs}', "");
Expect(0, 78895, '\P{^	Egyptian_hieroglyphs}', "");
Error('\p{:=	 Is_EGYPTIAN_hieroglyphs}');
Error('\P{:=	 Is_EGYPTIAN_hieroglyphs}');
Expect(1, 78894, '\p{isegyptianhieroglyphs}', "");
Expect(0, 78894, '\p{^isegyptianhieroglyphs}', "");
Expect(0, 78894, '\P{isegyptianhieroglyphs}', "");
Expect(1, 78894, '\P{^isegyptianhieroglyphs}', "");
Expect(0, 78895, '\p{isegyptianhieroglyphs}', "");
Expect(1, 78895, '\p{^isegyptianhieroglyphs}', "");
Expect(1, 78895, '\P{isegyptianhieroglyphs}', "");
Expect(0, 78895, '\P{^isegyptianhieroglyphs}', "");
Expect(1, 78894, '\p{		Is_EGYPTIAN_HIEROGLYPHS}', "");
Expect(0, 78894, '\p{^		Is_EGYPTIAN_HIEROGLYPHS}', "");
Expect(0, 78894, '\P{		Is_EGYPTIAN_HIEROGLYPHS}', "");
Expect(1, 78894, '\P{^		Is_EGYPTIAN_HIEROGLYPHS}', "");
Expect(0, 78895, '\p{		Is_EGYPTIAN_HIEROGLYPHS}', "");
Expect(1, 78895, '\p{^		Is_EGYPTIAN_HIEROGLYPHS}', "");
Expect(1, 78895, '\P{		Is_EGYPTIAN_HIEROGLYPHS}', "");
Expect(0, 78895, '\P{^		Is_EGYPTIAN_HIEROGLYPHS}', "");
Error('\p{ -Egyp/a/}');
Error('\P{ -Egyp/a/}');
Expect(1, 78894, '\p{egyp}', "");
Expect(0, 78894, '\p{^egyp}', "");
Expect(0, 78894, '\P{egyp}', "");
Expect(1, 78894, '\P{^egyp}', "");
Expect(0, 78895, '\p{egyp}', "");
Expect(1, 78895, '\p{^egyp}', "");
Expect(1, 78895, '\P{egyp}', "");
Expect(0, 78895, '\P{^egyp}', "");
Expect(1, 78894, '\p{_-Egyp}', "");
Expect(0, 78894, '\p{^_-Egyp}', "");
Expect(0, 78894, '\P{_-Egyp}', "");
Expect(1, 78894, '\P{^_-Egyp}', "");
Expect(0, 78895, '\p{_-Egyp}', "");
Expect(1, 78895, '\p{^_-Egyp}', "");
Expect(1, 78895, '\P{_-Egyp}', "");
Expect(0, 78895, '\P{^_-Egyp}', "");
Error('\p{-_is_egyp/a/}');
Error('\P{-_is_egyp/a/}');
Expect(1, 78894, '\p{isegyp}', "");
Expect(0, 78894, '\p{^isegyp}', "");
Expect(0, 78894, '\P{isegyp}', "");
Expect(1, 78894, '\P{^isegyp}', "");
Expect(0, 78895, '\p{isegyp}', "");
Expect(1, 78895, '\p{^isegyp}', "");
Expect(1, 78895, '\P{isegyp}', "");
Expect(0, 78895, '\P{^isegyp}', "");
Expect(1, 78894, '\p{ 	is_EGYP}', "");
Expect(0, 78894, '\p{^ 	is_EGYP}', "");
Expect(0, 78894, '\P{ 	is_EGYP}', "");
Expect(1, 78894, '\P{^ 	is_EGYP}', "");
Expect(0, 78895, '\p{ 	is_EGYP}', "");
Expect(1, 78895, '\p{^ 	is_EGYP}', "");
Expect(1, 78895, '\P{ 	is_EGYP}', "");
Expect(0, 78895, '\P{^ 	is_EGYP}', "");
Error('\p{/a/Emoticons}');
Error('\P{/a/Emoticons}');
Expect(1, 128591, '\p{emoticons}', "");
Expect(0, 128591, '\p{^emoticons}', "");
Expect(0, 128591, '\P{emoticons}', "");
Expect(1, 128591, '\P{^emoticons}', "");
Expect(0, 128592, '\p{emoticons}', "");
Expect(1, 128592, '\p{^emoticons}', "");
Expect(1, 128592, '\P{emoticons}', "");
Expect(0, 128592, '\P{^emoticons}', "");
Expect(1, 128591, '\p{__Emoticons}', "");
Expect(0, 128591, '\p{^__Emoticons}', "");
Expect(0, 128591, '\P{__Emoticons}', "");
Expect(1, 128591, '\P{^__Emoticons}', "");
Expect(0, 128592, '\p{__Emoticons}', "");
Expect(1, 128592, '\p{^__Emoticons}', "");
Expect(1, 128592, '\P{__Emoticons}', "");
Expect(0, 128592, '\P{^__Emoticons}', "");
Error('\p{ Is_emoticons:=}');
Error('\P{ Is_emoticons:=}');
Expect(1, 128591, '\p{isemoticons}', "");
Expect(0, 128591, '\p{^isemoticons}', "");
Expect(0, 128591, '\P{isemoticons}', "");
Expect(1, 128591, '\P{^isemoticons}', "");
Expect(0, 128592, '\p{isemoticons}', "");
Expect(1, 128592, '\p{^isemoticons}', "");
Expect(1, 128592, '\P{isemoticons}', "");
Expect(0, 128592, '\P{^isemoticons}', "");
Expect(1, 128591, '\p{_	IS_Emoticons}', "");
Expect(0, 128591, '\p{^_	IS_Emoticons}', "");
Expect(0, 128591, '\P{_	IS_Emoticons}', "");
Expect(1, 128591, '\P{^_	IS_Emoticons}', "");
Expect(0, 128592, '\p{_	IS_Emoticons}', "");
Expect(1, 128592, '\p{^_	IS_Emoticons}', "");
Expect(1, 128592, '\P{_	IS_Emoticons}', "");
Expect(0, 128592, '\P{^_	IS_Emoticons}', "");
Error('\p{:=-In_Emoticons}');
Error('\P{:=-In_Emoticons}');
Expect(1, 128591, '\p{inemoticons}', "");
Expect(0, 128591, '\p{^inemoticons}', "");
Expect(0, 128591, '\P{inemoticons}', "");
Expect(1, 128591, '\P{^inemoticons}', "");
Expect(0, 128592, '\p{inemoticons}', "");
Expect(1, 128592, '\p{^inemoticons}', "");
Expect(1, 128592, '\P{inemoticons}', "");
Expect(0, 128592, '\P{^inemoticons}', "");
Expect(1, 128591, '\p{--In_Emoticons}', "");
Expect(0, 128591, '\p{^--In_Emoticons}', "");
Expect(0, 128591, '\P{--In_Emoticons}', "");
Expect(1, 128591, '\P{^--In_Emoticons}', "");
Expect(0, 128592, '\p{--In_Emoticons}', "");
Expect(1, 128592, '\p{^--In_Emoticons}', "");
Expect(1, 128592, '\P{--In_Emoticons}', "");
Expect(0, 128592, '\P{^--In_Emoticons}', "");
Error('\p{/a/ _Enclosed_Alphanumeric_Supplement}');
Error('\P{/a/ _Enclosed_Alphanumeric_Supplement}');
Expect(1, 127487, '\p{enclosedalphanumericsupplement}', "");
Expect(0, 127487, '\p{^enclosedalphanumericsupplement}', "");
Expect(0, 127487, '\P{enclosedalphanumericsupplement}', "");
Expect(1, 127487, '\P{^enclosedalphanumericsupplement}', "");
Expect(0, 127488, '\p{enclosedalphanumericsupplement}', "");
Expect(1, 127488, '\p{^enclosedalphanumericsupplement}', "");
Expect(1, 127488, '\P{enclosedalphanumericsupplement}', "");
Expect(0, 127488, '\P{^enclosedalphanumericsupplement}', "");
Expect(1, 127487, '\p{_-Enclosed_Alphanumeric_SUPPLEMENT}', "");
Expect(0, 127487, '\p{^_-Enclosed_Alphanumeric_SUPPLEMENT}', "");
Expect(0, 127487, '\P{_-Enclosed_Alphanumeric_SUPPLEMENT}', "");
Expect(1, 127487, '\P{^_-Enclosed_Alphanumeric_SUPPLEMENT}', "");
Expect(0, 127488, '\p{_-Enclosed_Alphanumeric_SUPPLEMENT}', "");
Expect(1, 127488, '\p{^_-Enclosed_Alphanumeric_SUPPLEMENT}', "");
Expect(1, 127488, '\P{_-Enclosed_Alphanumeric_SUPPLEMENT}', "");
Expect(0, 127488, '\P{^_-Enclosed_Alphanumeric_SUPPLEMENT}', "");
Error('\p{:=_	Is_enclosed_ALPHANUMERIC_Supplement}');
Error('\P{:=_	Is_enclosed_ALPHANUMERIC_Supplement}');
Expect(1, 127487, '\p{isenclosedalphanumericsupplement}', "");
Expect(0, 127487, '\p{^isenclosedalphanumericsupplement}', "");
Expect(0, 127487, '\P{isenclosedalphanumericsupplement}', "");
Expect(1, 127487, '\P{^isenclosedalphanumericsupplement}', "");
Expect(0, 127488, '\p{isenclosedalphanumericsupplement}', "");
Expect(1, 127488, '\p{^isenclosedalphanumericsupplement}', "");
Expect(1, 127488, '\P{isenclosedalphanumericsupplement}', "");
Expect(0, 127488, '\P{^isenclosedalphanumericsupplement}', "");
Expect(1, 127487, '\p{_-IS_Enclosed_Alphanumeric_supplement}', "");
Expect(0, 127487, '\p{^_-IS_Enclosed_Alphanumeric_supplement}', "");
Expect(0, 127487, '\P{_-IS_Enclosed_Alphanumeric_supplement}', "");
Expect(1, 127487, '\P{^_-IS_Enclosed_Alphanumeric_supplement}', "");
Expect(0, 127488, '\p{_-IS_Enclosed_Alphanumeric_supplement}', "");
Expect(1, 127488, '\p{^_-IS_Enclosed_Alphanumeric_supplement}', "");
Expect(1, 127488, '\P{_-IS_Enclosed_Alphanumeric_supplement}', "");
Expect(0, 127488, '\P{^_-IS_Enclosed_Alphanumeric_supplement}', "");
Error('\p{/a/ _In_Enclosed_ALPHANUMERIC_Supplement}');
Error('\P{/a/ _In_Enclosed_ALPHANUMERIC_Supplement}');
Expect(1, 127487, '\p{inenclosedalphanumericsupplement}', "");
Expect(0, 127487, '\p{^inenclosedalphanumericsupplement}', "");
Expect(0, 127487, '\P{inenclosedalphanumericsupplement}', "");
Expect(1, 127487, '\P{^inenclosedalphanumericsupplement}', "");
Expect(0, 127488, '\p{inenclosedalphanumericsupplement}', "");
Expect(1, 127488, '\p{^inenclosedalphanumericsupplement}', "");
Expect(1, 127488, '\P{inenclosedalphanumericsupplement}', "");
Expect(0, 127488, '\P{^inenclosedalphanumericsupplement}', "");
Expect(1, 127487, '\p{	IN_enclosed_Alphanumeric_Supplement}', "");
Expect(0, 127487, '\p{^	IN_enclosed_Alphanumeric_Supplement}', "");
Expect(0, 127487, '\P{	IN_enclosed_Alphanumeric_Supplement}', "");
Expect(1, 127487, '\P{^	IN_enclosed_Alphanumeric_Supplement}', "");
Expect(0, 127488, '\p{	IN_enclosed_Alphanumeric_Supplement}', "");
Expect(1, 127488, '\p{^	IN_enclosed_Alphanumeric_Supplement}', "");
Expect(1, 127488, '\P{	IN_enclosed_Alphanumeric_Supplement}', "");
Expect(0, 127488, '\P{^	IN_enclosed_Alphanumeric_Supplement}', "");
Error('\p{:=__enclosed_alphanum_Sup}');
Error('\P{:=__enclosed_alphanum_Sup}');
Expect(1, 127487, '\p{enclosedalphanumsup}', "");
Expect(0, 127487, '\p{^enclosedalphanumsup}', "");
Expect(0, 127487, '\P{enclosedalphanumsup}', "");
Expect(1, 127487, '\P{^enclosedalphanumsup}', "");
Expect(0, 127488, '\p{enclosedalphanumsup}', "");
Expect(1, 127488, '\p{^enclosedalphanumsup}', "");
Expect(1, 127488, '\P{enclosedalphanumsup}', "");
Expect(0, 127488, '\P{^enclosedalphanumsup}', "");
Expect(1, 127487, '\p{	 Enclosed_alphanum_SUP}', "");
Expect(0, 127487, '\p{^	 Enclosed_alphanum_SUP}', "");
Expect(0, 127487, '\P{	 Enclosed_alphanum_SUP}', "");
Expect(1, 127487, '\P{^	 Enclosed_alphanum_SUP}', "");
Expect(0, 127488, '\p{	 Enclosed_alphanum_SUP}', "");
Expect(1, 127488, '\p{^	 Enclosed_alphanum_SUP}', "");
Expect(1, 127488, '\P{	 Enclosed_alphanum_SUP}', "");
Expect(0, 127488, '\P{^	 Enclosed_alphanum_SUP}', "");
Error('\p{	_Is_enclosed_Alphanum_Sup/a/}');
Error('\P{	_Is_enclosed_Alphanum_Sup/a/}');
Expect(1, 127487, '\p{isenclosedalphanumsup}', "");
Expect(0, 127487, '\p{^isenclosedalphanumsup}', "");
Expect(0, 127487, '\P{isenclosedalphanumsup}', "");
Expect(1, 127487, '\P{^isenclosedalphanumsup}', "");
Expect(0, 127488, '\p{isenclosedalphanumsup}', "");
Expect(1, 127488, '\p{^isenclosedalphanumsup}', "");
Expect(1, 127488, '\P{isenclosedalphanumsup}', "");
Expect(0, 127488, '\P{^isenclosedalphanumsup}', "");
Expect(1, 127487, '\p{	-is_ENCLOSED_ALPHANUM_Sup}', "");
Expect(0, 127487, '\p{^	-is_ENCLOSED_ALPHANUM_Sup}', "");
Expect(0, 127487, '\P{	-is_ENCLOSED_ALPHANUM_Sup}', "");
Expect(1, 127487, '\P{^	-is_ENCLOSED_ALPHANUM_Sup}', "");
Expect(0, 127488, '\p{	-is_ENCLOSED_ALPHANUM_Sup}', "");
Expect(1, 127488, '\p{^	-is_ENCLOSED_ALPHANUM_Sup}', "");
Expect(1, 127488, '\P{	-is_ENCLOSED_ALPHANUM_Sup}', "");
Expect(0, 127488, '\P{^	-is_ENCLOSED_ALPHANUM_Sup}', "");
Error('\p{:=	in_ENCLOSED_ALPHANUM_Sup}');
Error('\P{:=	in_ENCLOSED_ALPHANUM_Sup}');
Expect(1, 127487, '\p{inenclosedalphanumsup}', "");
Expect(0, 127487, '\p{^inenclosedalphanumsup}', "");
Expect(0, 127487, '\P{inenclosedalphanumsup}', "");
Expect(1, 127487, '\P{^inenclosedalphanumsup}', "");
Expect(0, 127488, '\p{inenclosedalphanumsup}', "");
Expect(1, 127488, '\p{^inenclosedalphanumsup}', "");
Expect(1, 127488, '\P{inenclosedalphanumsup}', "");
Expect(0, 127488, '\P{^inenclosedalphanumsup}', "");
Expect(1, 127487, '\p{__in_enclosed_alphanum_SUP}', "");
Expect(0, 127487, '\p{^__in_enclosed_alphanum_SUP}', "");
Expect(0, 127487, '\P{__in_enclosed_alphanum_SUP}', "");
Expect(1, 127487, '\P{^__in_enclosed_alphanum_SUP}', "");
Expect(0, 127488, '\p{__in_enclosed_alphanum_SUP}', "");
Expect(1, 127488, '\p{^__in_enclosed_alphanum_SUP}', "");
Expect(1, 127488, '\P{__in_enclosed_alphanum_SUP}', "");
Expect(0, 127488, '\P{^__in_enclosed_alphanum_SUP}', "");
Error('\p{-	ENCLOSED_alphanumerics:=}');
Error('\P{-	ENCLOSED_alphanumerics:=}');
Expect(1, 9471, '\p{enclosedalphanumerics}', "");
Expect(0, 9471, '\p{^enclosedalphanumerics}', "");
Expect(0, 9471, '\P{enclosedalphanumerics}', "");
Expect(1, 9471, '\P{^enclosedalphanumerics}', "");
Expect(0, 9472, '\p{enclosedalphanumerics}', "");
Expect(1, 9472, '\p{^enclosedalphanumerics}', "");
Expect(1, 9472, '\P{enclosedalphanumerics}', "");
Expect(0, 9472, '\P{^enclosedalphanumerics}', "");
Expect(1, 9471, '\p{_Enclosed_Alphanumerics}', "");
Expect(0, 9471, '\p{^_Enclosed_Alphanumerics}', "");
Expect(0, 9471, '\P{_Enclosed_Alphanumerics}', "");
Expect(1, 9471, '\P{^_Enclosed_Alphanumerics}', "");
Expect(0, 9472, '\p{_Enclosed_Alphanumerics}', "");
Expect(1, 9472, '\p{^_Enclosed_Alphanumerics}', "");
Expect(1, 9472, '\P{_Enclosed_Alphanumerics}', "");
Expect(0, 9472, '\P{^_Enclosed_Alphanumerics}', "");
Error('\p{-/a/IS_Enclosed_Alphanumerics}');
Error('\P{-/a/IS_Enclosed_Alphanumerics}');
Expect(1, 9471, '\p{isenclosedalphanumerics}', "");
Expect(0, 9471, '\p{^isenclosedalphanumerics}', "");
Expect(0, 9471, '\P{isenclosedalphanumerics}', "");
Expect(1, 9471, '\P{^isenclosedalphanumerics}', "");
Expect(0, 9472, '\p{isenclosedalphanumerics}', "");
Expect(1, 9472, '\p{^isenclosedalphanumerics}', "");
Expect(1, 9472, '\P{isenclosedalphanumerics}', "");
Expect(0, 9472, '\P{^isenclosedalphanumerics}', "");
Expect(1, 9471, '\p{-_IS_enclosed_alphanumerics}', "");
Expect(0, 9471, '\p{^-_IS_enclosed_alphanumerics}', "");
Expect(0, 9471, '\P{-_IS_enclosed_alphanumerics}', "");
Expect(1, 9471, '\P{^-_IS_enclosed_alphanumerics}', "");
Expect(0, 9472, '\p{-_IS_enclosed_alphanumerics}', "");
Expect(1, 9472, '\p{^-_IS_enclosed_alphanumerics}', "");
Expect(1, 9472, '\P{-_IS_enclosed_alphanumerics}', "");
Expect(0, 9472, '\P{^-_IS_enclosed_alphanumerics}', "");
Error('\p{_/a/In_Enclosed_ALPHANUMERICS}');
Error('\P{_/a/In_Enclosed_ALPHANUMERICS}');
Expect(1, 9471, '\p{inenclosedalphanumerics}', "");
Expect(0, 9471, '\p{^inenclosedalphanumerics}', "");
Expect(0, 9471, '\P{inenclosedalphanumerics}', "");
Expect(1, 9471, '\P{^inenclosedalphanumerics}', "");
Expect(0, 9472, '\p{inenclosedalphanumerics}', "");
Expect(1, 9472, '\p{^inenclosedalphanumerics}', "");
Expect(1, 9472, '\P{inenclosedalphanumerics}', "");
Expect(0, 9472, '\P{^inenclosedalphanumerics}', "");
Expect(1, 9471, '\p{_	IN_ENCLOSED_Alphanumerics}', "");
Expect(0, 9471, '\p{^_	IN_ENCLOSED_Alphanumerics}', "");
Expect(0, 9471, '\P{_	IN_ENCLOSED_Alphanumerics}', "");
Expect(1, 9471, '\P{^_	IN_ENCLOSED_Alphanumerics}', "");
Expect(0, 9472, '\p{_	IN_ENCLOSED_Alphanumerics}', "");
Expect(1, 9472, '\p{^_	IN_ENCLOSED_Alphanumerics}', "");
Expect(1, 9472, '\P{_	IN_ENCLOSED_Alphanumerics}', "");
Expect(0, 9472, '\P{^_	IN_ENCLOSED_Alphanumerics}', "");
Error('\p{:=	Enclosed_ALPHANUM}');
Error('\P{:=	Enclosed_ALPHANUM}');
Expect(1, 9471, '\p{enclosedalphanum}', "");
Expect(0, 9471, '\p{^enclosedalphanum}', "");
Expect(0, 9471, '\P{enclosedalphanum}', "");
Expect(1, 9471, '\P{^enclosedalphanum}', "");
Expect(0, 9472, '\p{enclosedalphanum}', "");
Expect(1, 9472, '\p{^enclosedalphanum}', "");
Expect(1, 9472, '\P{enclosedalphanum}', "");
Expect(0, 9472, '\P{^enclosedalphanum}', "");
Expect(1, 9471, '\p{-Enclosed_ALPHANUM}', "");
Expect(0, 9471, '\p{^-Enclosed_ALPHANUM}', "");
Expect(0, 9471, '\P{-Enclosed_ALPHANUM}', "");
Expect(1, 9471, '\P{^-Enclosed_ALPHANUM}', "");
Expect(0, 9472, '\p{-Enclosed_ALPHANUM}', "");
Expect(1, 9472, '\p{^-Enclosed_ALPHANUM}', "");
Expect(1, 9472, '\P{-Enclosed_ALPHANUM}', "");
Expect(0, 9472, '\P{^-Enclosed_ALPHANUM}', "");
Error('\p{	is_Enclosed_ALPHANUM/a/}');
Error('\P{	is_Enclosed_ALPHANUM/a/}');
Expect(1, 9471, '\p{isenclosedalphanum}', "");
Expect(0, 9471, '\p{^isenclosedalphanum}', "");
Expect(0, 9471, '\P{isenclosedalphanum}', "");
Expect(1, 9471, '\P{^isenclosedalphanum}', "");
Expect(0, 9472, '\p{isenclosedalphanum}', "");
Expect(1, 9472, '\p{^isenclosedalphanum}', "");
Expect(1, 9472, '\P{isenclosedalphanum}', "");
Expect(0, 9472, '\P{^isenclosedalphanum}', "");
Expect(1, 9471, '\p{__IS_Enclosed_alphanum}', "");
Expect(0, 9471, '\p{^__IS_Enclosed_alphanum}', "");
Expect(0, 9471, '\P{__IS_Enclosed_alphanum}', "");
Expect(1, 9471, '\P{^__IS_Enclosed_alphanum}', "");
Expect(0, 9472, '\p{__IS_Enclosed_alphanum}', "");
Expect(1, 9472, '\p{^__IS_Enclosed_alphanum}', "");
Expect(1, 9472, '\P{__IS_Enclosed_alphanum}', "");
Expect(0, 9472, '\P{^__IS_Enclosed_alphanum}', "");
Error('\p{:=In_Enclosed_Alphanum}');
Error('\P{:=In_Enclosed_Alphanum}');
Expect(1, 9471, '\p{inenclosedalphanum}', "");
Expect(0, 9471, '\p{^inenclosedalphanum}', "");
Expect(0, 9471, '\P{inenclosedalphanum}', "");
Expect(1, 9471, '\P{^inenclosedalphanum}', "");
Expect(0, 9472, '\p{inenclosedalphanum}', "");
Expect(1, 9472, '\p{^inenclosedalphanum}', "");
Expect(1, 9472, '\P{inenclosedalphanum}', "");
Expect(0, 9472, '\P{^inenclosedalphanum}', "");
Expect(1, 9471, '\p{ 	IN_Enclosed_alphanum}', "");
Expect(0, 9471, '\p{^ 	IN_Enclosed_alphanum}', "");
Expect(0, 9471, '\P{ 	IN_Enclosed_alphanum}', "");
Expect(1, 9471, '\P{^ 	IN_Enclosed_alphanum}', "");
Expect(0, 9472, '\p{ 	IN_Enclosed_alphanum}', "");
Expect(1, 9472, '\p{^ 	IN_Enclosed_alphanum}', "");
Expect(1, 9472, '\P{ 	IN_Enclosed_alphanum}', "");
Expect(0, 9472, '\P{^ 	IN_Enclosed_alphanum}', "");
Error('\p{ :=enclosed_CJK_letters_And_Months}');
Error('\P{ :=enclosed_CJK_letters_And_Months}');
Expect(1, 13055, '\p{enclosedcjklettersandmonths}', "");
Expect(0, 13055, '\p{^enclosedcjklettersandmonths}', "");
Expect(0, 13055, '\P{enclosedcjklettersandmonths}', "");
Expect(1, 13055, '\P{^enclosedcjklettersandmonths}', "");
Expect(0, 13056, '\p{enclosedcjklettersandmonths}', "");
Expect(1, 13056, '\p{^enclosedcjklettersandmonths}', "");
Expect(1, 13056, '\P{enclosedcjklettersandmonths}', "");
Expect(0, 13056, '\P{^enclosedcjklettersandmonths}', "");
Expect(1, 13055, '\p{-ENCLOSED_CJK_Letters_and_Months}', "");
Expect(0, 13055, '\p{^-ENCLOSED_CJK_Letters_and_Months}', "");
Expect(0, 13055, '\P{-ENCLOSED_CJK_Letters_and_Months}', "");
Expect(1, 13055, '\P{^-ENCLOSED_CJK_Letters_and_Months}', "");
Expect(0, 13056, '\p{-ENCLOSED_CJK_Letters_and_Months}', "");
Expect(1, 13056, '\p{^-ENCLOSED_CJK_Letters_and_Months}', "");
Expect(1, 13056, '\P{-ENCLOSED_CJK_Letters_and_Months}', "");
Expect(0, 13056, '\P{^-ENCLOSED_CJK_Letters_and_Months}', "");
Error('\p{/a/	_Is_enclosed_CJK_LETTERS_And_Months}');
Error('\P{/a/	_Is_enclosed_CJK_LETTERS_And_Months}');
Expect(1, 13055, '\p{isenclosedcjklettersandmonths}', "");
Expect(0, 13055, '\p{^isenclosedcjklettersandmonths}', "");
Expect(0, 13055, '\P{isenclosedcjklettersandmonths}', "");
Expect(1, 13055, '\P{^isenclosedcjklettersandmonths}', "");
Expect(0, 13056, '\p{isenclosedcjklettersandmonths}', "");
Expect(1, 13056, '\p{^isenclosedcjklettersandmonths}', "");
Expect(1, 13056, '\P{isenclosedcjklettersandmonths}', "");
Expect(0, 13056, '\P{^isenclosedcjklettersandmonths}', "");
Expect(1, 13055, '\p{		IS_ENCLOSED_cjk_letters_And_Months}', "");
Expect(0, 13055, '\p{^		IS_ENCLOSED_cjk_letters_And_Months}', "");
Expect(0, 13055, '\P{		IS_ENCLOSED_cjk_letters_And_Months}', "");
Expect(1, 13055, '\P{^		IS_ENCLOSED_cjk_letters_And_Months}', "");
Expect(0, 13056, '\p{		IS_ENCLOSED_cjk_letters_And_Months}', "");
Expect(1, 13056, '\p{^		IS_ENCLOSED_cjk_letters_And_Months}', "");
Expect(1, 13056, '\P{		IS_ENCLOSED_cjk_letters_And_Months}', "");
Expect(0, 13056, '\P{^		IS_ENCLOSED_cjk_letters_And_Months}', "");
Error('\p{:=In_Enclosed_CJK_Letters_And_months}');
Error('\P{:=In_Enclosed_CJK_Letters_And_months}');
Expect(1, 13055, '\p{inenclosedcjklettersandmonths}', "");
Expect(0, 13055, '\p{^inenclosedcjklettersandmonths}', "");
Expect(0, 13055, '\P{inenclosedcjklettersandmonths}', "");
Expect(1, 13055, '\P{^inenclosedcjklettersandmonths}', "");
Expect(0, 13056, '\p{inenclosedcjklettersandmonths}', "");
Expect(1, 13056, '\p{^inenclosedcjklettersandmonths}', "");
Expect(1, 13056, '\P{inenclosedcjklettersandmonths}', "");
Expect(0, 13056, '\P{^inenclosedcjklettersandmonths}', "");
Expect(1, 13055, '\p{-	In_ENCLOSED_CJK_letters_AND_MONTHS}', "");
Expect(0, 13055, '\p{^-	In_ENCLOSED_CJK_letters_AND_MONTHS}', "");
Expect(0, 13055, '\P{-	In_ENCLOSED_CJK_letters_AND_MONTHS}', "");
Expect(1, 13055, '\P{^-	In_ENCLOSED_CJK_letters_AND_MONTHS}', "");
Expect(0, 13056, '\p{-	In_ENCLOSED_CJK_letters_AND_MONTHS}', "");
Expect(1, 13056, '\p{^-	In_ENCLOSED_CJK_letters_AND_MONTHS}', "");
Expect(1, 13056, '\P{-	In_ENCLOSED_CJK_letters_AND_MONTHS}', "");
Expect(0, 13056, '\P{^-	In_ENCLOSED_CJK_letters_AND_MONTHS}', "");
Error('\p{ /a/Enclosed_CJK}');
Error('\P{ /a/Enclosed_CJK}');
Expect(1, 13055, '\p{enclosedcjk}', "");
Expect(0, 13055, '\p{^enclosedcjk}', "");
Expect(0, 13055, '\P{enclosedcjk}', "");
Expect(1, 13055, '\P{^enclosedcjk}', "");
Expect(0, 13056, '\p{enclosedcjk}', "");
Expect(1, 13056, '\p{^enclosedcjk}', "");
Expect(1, 13056, '\P{enclosedcjk}', "");
Expect(0, 13056, '\P{^enclosedcjk}', "");
Expect(1, 13055, '\p{  Enclosed_cjk}', "");
Expect(0, 13055, '\p{^  Enclosed_cjk}', "");
Expect(0, 13055, '\P{  Enclosed_cjk}', "");
Expect(1, 13055, '\P{^  Enclosed_cjk}', "");
Expect(0, 13056, '\p{  Enclosed_cjk}', "");
Expect(1, 13056, '\p{^  Enclosed_cjk}', "");
Expect(1, 13056, '\P{  Enclosed_cjk}', "");
Expect(0, 13056, '\P{^  Enclosed_cjk}', "");
Error('\p{:=--is_enclosed_CJK}');
Error('\P{:=--is_enclosed_CJK}');
Expect(1, 13055, '\p{isenclosedcjk}', "");
Expect(0, 13055, '\p{^isenclosedcjk}', "");
Expect(0, 13055, '\P{isenclosedcjk}', "");
Expect(1, 13055, '\P{^isenclosedcjk}', "");
Expect(0, 13056, '\p{isenclosedcjk}', "");
Expect(1, 13056, '\p{^isenclosedcjk}', "");
Expect(1, 13056, '\P{isenclosedcjk}', "");
Expect(0, 13056, '\P{^isenclosedcjk}', "");
Expect(1, 13055, '\p{__Is_Enclosed_cjk}', "");
Expect(0, 13055, '\p{^__Is_Enclosed_cjk}', "");
Expect(0, 13055, '\P{__Is_Enclosed_cjk}', "");
Expect(1, 13055, '\P{^__Is_Enclosed_cjk}', "");
Expect(0, 13056, '\p{__Is_Enclosed_cjk}', "");
Expect(1, 13056, '\p{^__Is_Enclosed_cjk}', "");
Expect(1, 13056, '\P{__Is_Enclosed_cjk}', "");
Expect(0, 13056, '\P{^__Is_Enclosed_cjk}', "");
Error('\p{_/a/In_enclosed_CJK}');
Error('\P{_/a/In_enclosed_CJK}');
Expect(1, 13055, '\p{inenclosedcjk}', "");
Expect(0, 13055, '\p{^inenclosedcjk}', "");
Expect(0, 13055, '\P{inenclosedcjk}', "");
Expect(1, 13055, '\P{^inenclosedcjk}', "");
Expect(0, 13056, '\p{inenclosedcjk}', "");
Expect(1, 13056, '\p{^inenclosedcjk}', "");
Expect(1, 13056, '\P{inenclosedcjk}', "");
Expect(0, 13056, '\P{^inenclosedcjk}', "");
Expect(1, 13055, '\p{_in_Enclosed_cjk}', "");
Expect(0, 13055, '\p{^_in_Enclosed_cjk}', "");
Expect(0, 13055, '\P{_in_Enclosed_cjk}', "");
Expect(1, 13055, '\P{^_in_Enclosed_cjk}', "");
Expect(0, 13056, '\p{_in_Enclosed_cjk}', "");
Expect(1, 13056, '\p{^_in_Enclosed_cjk}', "");
Expect(1, 13056, '\P{_in_Enclosed_cjk}', "");
Expect(0, 13056, '\P{^_in_Enclosed_cjk}', "");
Error('\p{_/a/Enclosed_Ideographic_SUPPLEMENT}');
Error('\P{_/a/Enclosed_Ideographic_SUPPLEMENT}');
Expect(1, 127743, '\p{enclosedideographicsupplement}', "");
Expect(0, 127743, '\p{^enclosedideographicsupplement}', "");
Expect(0, 127743, '\P{enclosedideographicsupplement}', "");
Expect(1, 127743, '\P{^enclosedideographicsupplement}', "");
Expect(0, 127744, '\p{enclosedideographicsupplement}', "");
Expect(1, 127744, '\p{^enclosedideographicsupplement}', "");
Expect(1, 127744, '\P{enclosedideographicsupplement}', "");
Expect(0, 127744, '\P{^enclosedideographicsupplement}', "");
Expect(1, 127743, '\p{enclosed_Ideographic_Supplement}', "");
Expect(0, 127743, '\p{^enclosed_Ideographic_Supplement}', "");
Expect(0, 127743, '\P{enclosed_Ideographic_Supplement}', "");
Expect(1, 127743, '\P{^enclosed_Ideographic_Supplement}', "");
Expect(0, 127744, '\p{enclosed_Ideographic_Supplement}', "");
Expect(1, 127744, '\p{^enclosed_Ideographic_Supplement}', "");
Expect(1, 127744, '\P{enclosed_Ideographic_Supplement}', "");
Expect(0, 127744, '\P{^enclosed_Ideographic_Supplement}', "");
Error('\p{	 Is_enclosed_Ideographic_Supplement:=}');
Error('\P{	 Is_enclosed_Ideographic_Supplement:=}');
Expect(1, 127743, '\p{isenclosedideographicsupplement}', "");
Expect(0, 127743, '\p{^isenclosedideographicsupplement}', "");
Expect(0, 127743, '\P{isenclosedideographicsupplement}', "");
Expect(1, 127743, '\P{^isenclosedideographicsupplement}', "");
Expect(0, 127744, '\p{isenclosedideographicsupplement}', "");
Expect(1, 127744, '\p{^isenclosedideographicsupplement}', "");
Expect(1, 127744, '\P{isenclosedideographicsupplement}', "");
Expect(0, 127744, '\P{^isenclosedideographicsupplement}', "");
Expect(1, 127743, '\p{_-Is_enclosed_ideographic_supplement}', "");
Expect(0, 127743, '\p{^_-Is_enclosed_ideographic_supplement}', "");
Expect(0, 127743, '\P{_-Is_enclosed_ideographic_supplement}', "");
Expect(1, 127743, '\P{^_-Is_enclosed_ideographic_supplement}', "");
Expect(0, 127744, '\p{_-Is_enclosed_ideographic_supplement}', "");
Expect(1, 127744, '\p{^_-Is_enclosed_ideographic_supplement}', "");
Expect(1, 127744, '\P{_-Is_enclosed_ideographic_supplement}', "");
Expect(0, 127744, '\P{^_-Is_enclosed_ideographic_supplement}', "");
Error('\p{_:=In_enclosed_Ideographic_supplement}');
Error('\P{_:=In_enclosed_Ideographic_supplement}');
Expect(1, 127743, '\p{inenclosedideographicsupplement}', "");
Expect(0, 127743, '\p{^inenclosedideographicsupplement}', "");
Expect(0, 127743, '\P{inenclosedideographicsupplement}', "");
Expect(1, 127743, '\P{^inenclosedideographicsupplement}', "");
Expect(0, 127744, '\p{inenclosedideographicsupplement}', "");
Expect(1, 127744, '\p{^inenclosedideographicsupplement}', "");
Expect(1, 127744, '\P{inenclosedideographicsupplement}', "");
Expect(0, 127744, '\P{^inenclosedideographicsupplement}', "");
Expect(1, 127743, '\p{_	in_Enclosed_ideographic_Supplement}', "");
Expect(0, 127743, '\p{^_	in_Enclosed_ideographic_Supplement}', "");
Expect(0, 127743, '\P{_	in_Enclosed_ideographic_Supplement}', "");
Expect(1, 127743, '\P{^_	in_Enclosed_ideographic_Supplement}', "");
Expect(0, 127744, '\p{_	in_Enclosed_ideographic_Supplement}', "");
Expect(1, 127744, '\p{^_	in_Enclosed_ideographic_Supplement}', "");
Expect(1, 127744, '\P{_	in_Enclosed_ideographic_Supplement}', "");
Expect(0, 127744, '\P{^_	in_Enclosed_ideographic_Supplement}', "");
Error('\p{/a/--Enclosed_Ideographic_sup}');
Error('\P{/a/--Enclosed_Ideographic_sup}');
Expect(1, 127743, '\p{enclosedideographicsup}', "");
Expect(0, 127743, '\p{^enclosedideographicsup}', "");
Expect(0, 127743, '\P{enclosedideographicsup}', "");
Expect(1, 127743, '\P{^enclosedideographicsup}', "");
Expect(0, 127744, '\p{enclosedideographicsup}', "");
Expect(1, 127744, '\p{^enclosedideographicsup}', "");
Expect(1, 127744, '\P{enclosedideographicsup}', "");
Expect(0, 127744, '\P{^enclosedideographicsup}', "");
Expect(1, 127743, '\p{	-Enclosed_Ideographic_sup}', "");
Expect(0, 127743, '\p{^	-Enclosed_Ideographic_sup}', "");
Expect(0, 127743, '\P{	-Enclosed_Ideographic_sup}', "");
Expect(1, 127743, '\P{^	-Enclosed_Ideographic_sup}', "");
Expect(0, 127744, '\p{	-Enclosed_Ideographic_sup}', "");
Expect(1, 127744, '\p{^	-Enclosed_Ideographic_sup}', "");
Expect(1, 127744, '\P{	-Enclosed_Ideographic_sup}', "");
Expect(0, 127744, '\P{^	-Enclosed_Ideographic_sup}', "");
Error('\p{:=	Is_Enclosed_ideographic_Sup}');
Error('\P{:=	Is_Enclosed_ideographic_Sup}');
Expect(1, 127743, '\p{isenclosedideographicsup}', "");
Expect(0, 127743, '\p{^isenclosedideographicsup}', "");
Expect(0, 127743, '\P{isenclosedideographicsup}', "");
Expect(1, 127743, '\P{^isenclosedideographicsup}', "");
Expect(0, 127744, '\p{isenclosedideographicsup}', "");
Expect(1, 127744, '\p{^isenclosedideographicsup}', "");
Expect(1, 127744, '\P{isenclosedideographicsup}', "");
Expect(0, 127744, '\P{^isenclosedideographicsup}', "");
Expect(1, 127743, '\p{_IS_enclosed_IDEOGRAPHIC_Sup}', "");
Expect(0, 127743, '\p{^_IS_enclosed_IDEOGRAPHIC_Sup}', "");
Expect(0, 127743, '\P{_IS_enclosed_IDEOGRAPHIC_Sup}', "");
Expect(1, 127743, '\P{^_IS_enclosed_IDEOGRAPHIC_Sup}', "");
Expect(0, 127744, '\p{_IS_enclosed_IDEOGRAPHIC_Sup}', "");
Expect(1, 127744, '\p{^_IS_enclosed_IDEOGRAPHIC_Sup}', "");
Expect(1, 127744, '\P{_IS_enclosed_IDEOGRAPHIC_Sup}', "");
Expect(0, 127744, '\P{^_IS_enclosed_IDEOGRAPHIC_Sup}', "");
Error('\p{-:=In_Enclosed_ideographic_SUP}');
Error('\P{-:=In_Enclosed_ideographic_SUP}');
Expect(1, 127743, '\p{inenclosedideographicsup}', "");
Expect(0, 127743, '\p{^inenclosedideographicsup}', "");
Expect(0, 127743, '\P{inenclosedideographicsup}', "");
Expect(1, 127743, '\P{^inenclosedideographicsup}', "");
Expect(0, 127744, '\p{inenclosedideographicsup}', "");
Expect(1, 127744, '\p{^inenclosedideographicsup}', "");
Expect(1, 127744, '\P{inenclosedideographicsup}', "");
Expect(0, 127744, '\P{^inenclosedideographicsup}', "");
Expect(1, 127743, '\p{	in_enclosed_ideographic_sup}', "");
Expect(0, 127743, '\p{^	in_enclosed_ideographic_sup}', "");
Expect(0, 127743, '\P{	in_enclosed_ideographic_sup}', "");
Expect(1, 127743, '\P{^	in_enclosed_ideographic_sup}', "");
Expect(0, 127744, '\p{	in_enclosed_ideographic_sup}', "");
Expect(1, 127744, '\p{^	in_enclosed_ideographic_sup}', "");
Expect(1, 127744, '\P{	in_enclosed_ideographic_sup}', "");
Expect(0, 127744, '\P{^	in_enclosed_ideographic_sup}', "");
Error('\p{_:=ENCLOSING_mark}');
Error('\P{_:=ENCLOSING_mark}');
Expect(1, 42610, '\p{enclosingmark}', "");
Expect(0, 42610, '\p{^enclosingmark}', "");
Expect(0, 42610, '\P{enclosingmark}', "");
Expect(1, 42610, '\P{^enclosingmark}', "");
Expect(0, 42611, '\p{enclosingmark}', "");
Expect(1, 42611, '\p{^enclosingmark}', "");
Expect(1, 42611, '\P{enclosingmark}', "");
Expect(0, 42611, '\P{^enclosingmark}', "");
Expect(1, 42610, '\p{	_ENCLOSING_MARK}', "");
Expect(0, 42610, '\p{^	_ENCLOSING_MARK}', "");
Expect(0, 42610, '\P{	_ENCLOSING_MARK}', "");
Expect(1, 42610, '\P{^	_ENCLOSING_MARK}', "");
Expect(0, 42611, '\p{	_ENCLOSING_MARK}', "");
Expect(1, 42611, '\p{^	_ENCLOSING_MARK}', "");
Expect(1, 42611, '\P{	_ENCLOSING_MARK}', "");
Expect(0, 42611, '\P{^	_ENCLOSING_MARK}', "");
Error('\p{	IS_Enclosing_mark:=}');
Error('\P{	IS_Enclosing_mark:=}');
Expect(1, 42610, '\p{isenclosingmark}', "");
Expect(0, 42610, '\p{^isenclosingmark}', "");
Expect(0, 42610, '\P{isenclosingmark}', "");
Expect(1, 42610, '\P{^isenclosingmark}', "");
Expect(0, 42611, '\p{isenclosingmark}', "");
Expect(1, 42611, '\p{^isenclosingmark}', "");
Expect(1, 42611, '\P{isenclosingmark}', "");
Expect(0, 42611, '\P{^isenclosingmark}', "");
Expect(1, 42610, '\p{ _Is_Enclosing_MARK}', "");
Expect(0, 42610, '\p{^ _Is_Enclosing_MARK}', "");
Expect(0, 42610, '\P{ _Is_Enclosing_MARK}', "");
Expect(1, 42610, '\P{^ _Is_Enclosing_MARK}', "");
Expect(0, 42611, '\p{ _Is_Enclosing_MARK}', "");
Expect(1, 42611, '\p{^ _Is_Enclosing_MARK}', "");
Expect(1, 42611, '\P{ _Is_Enclosing_MARK}', "");
Expect(0, 42611, '\P{^ _Is_Enclosing_MARK}', "");
Error('\p{- ME/a/}');
Error('\P{- ME/a/}');
Expect(1, 42610, '\p{me}', "");
Expect(0, 42610, '\p{^me}', "");
Expect(0, 42610, '\P{me}', "");
Expect(1, 42610, '\P{^me}', "");
Expect(0, 42611, '\p{me}', "");
Expect(1, 42611, '\p{^me}', "");
Expect(1, 42611, '\P{me}', "");
Expect(0, 42611, '\P{^me}', "");
Expect(1, 42610, '\p{Me}', "");
Expect(0, 42610, '\p{^Me}', "");
Expect(0, 42610, '\P{Me}', "");
Expect(1, 42610, '\P{^Me}', "");
Expect(0, 42611, '\p{Me}', "");
Expect(1, 42611, '\p{^Me}', "");
Expect(1, 42611, '\P{Me}', "");
Expect(0, 42611, '\P{^Me}', "");
Error('\p{ :=Is_Me}');
Error('\P{ :=Is_Me}');
Expect(1, 42610, '\p{isme}', "");
Expect(0, 42610, '\p{^isme}', "");
Expect(0, 42610, '\P{isme}', "");
Expect(1, 42610, '\P{^isme}', "");
Expect(0, 42611, '\p{isme}', "");
Expect(1, 42611, '\p{^isme}', "");
Expect(1, 42611, '\P{isme}', "");
Expect(0, 42611, '\P{^isme}', "");
Expect(1, 42610, '\p{	_Is_Me}', "");
Expect(0, 42610, '\p{^	_Is_Me}', "");
Expect(0, 42610, '\P{	_Is_Me}', "");
Expect(1, 42610, '\P{^	_Is_Me}', "");
Expect(0, 42611, '\p{	_Is_Me}', "");
Expect(1, 42611, '\p{^	_Is_Me}', "");
Expect(1, 42611, '\P{	_Is_Me}', "");
Expect(0, 42611, '\P{^	_Is_Me}', "");
Error('\p{:=  Ethiopic}');
Error('\P{:=  Ethiopic}');
Expect(1, 43822, '\p{ethiopic}', "");
Expect(0, 43822, '\p{^ethiopic}', "");
Expect(0, 43822, '\P{ethiopic}', "");
Expect(1, 43822, '\P{^ethiopic}', "");
Expect(0, 43823, '\p{ethiopic}', "");
Expect(1, 43823, '\p{^ethiopic}', "");
Expect(1, 43823, '\P{ethiopic}', "");
Expect(0, 43823, '\P{^ethiopic}', "");
Expect(1, 43822, '\p{-ETHIOPIC}', "");
Expect(0, 43822, '\p{^-ETHIOPIC}', "");
Expect(0, 43822, '\P{-ETHIOPIC}', "");
Expect(1, 43822, '\P{^-ETHIOPIC}', "");
Expect(0, 43823, '\p{-ETHIOPIC}', "");
Expect(1, 43823, '\p{^-ETHIOPIC}', "");
Expect(1, 43823, '\P{-ETHIOPIC}', "");
Expect(0, 43823, '\P{^-ETHIOPIC}', "");
Error('\p{-:=is_Ethiopic}');
Error('\P{-:=is_Ethiopic}');
Expect(1, 43822, '\p{isethiopic}', "");
Expect(0, 43822, '\p{^isethiopic}', "");
Expect(0, 43822, '\P{isethiopic}', "");
Expect(1, 43822, '\P{^isethiopic}', "");
Expect(0, 43823, '\p{isethiopic}', "");
Expect(1, 43823, '\p{^isethiopic}', "");
Expect(1, 43823, '\P{isethiopic}', "");
Expect(0, 43823, '\P{^isethiopic}', "");
Expect(1, 43822, '\p{ 	Is_ethiopic}', "");
Expect(0, 43822, '\p{^ 	Is_ethiopic}', "");
Expect(0, 43822, '\P{ 	Is_ethiopic}', "");
Expect(1, 43822, '\P{^ 	Is_ethiopic}', "");
Expect(0, 43823, '\p{ 	Is_ethiopic}', "");
Expect(1, 43823, '\p{^ 	Is_ethiopic}', "");
Expect(1, 43823, '\P{ 	Is_ethiopic}', "");
Expect(0, 43823, '\P{^ 	Is_ethiopic}', "");
Error('\p{ /a/ethi}');
Error('\P{ /a/ethi}');
Expect(1, 43822, '\p{ethi}', "");
Expect(0, 43822, '\p{^ethi}', "");
Expect(0, 43822, '\P{ethi}', "");
Expect(1, 43822, '\P{^ethi}', "");
Expect(0, 43823, '\p{ethi}', "");
Expect(1, 43823, '\p{^ethi}', "");
Expect(1, 43823, '\P{ethi}', "");
Expect(0, 43823, '\P{^ethi}', "");
Expect(1, 43822, '\p{ _Ethi}', "");
Expect(0, 43822, '\p{^ _Ethi}', "");
Expect(0, 43822, '\P{ _Ethi}', "");
Expect(1, 43822, '\P{^ _Ethi}', "");
Expect(0, 43823, '\p{ _Ethi}', "");
Expect(1, 43823, '\p{^ _Ethi}', "");
Expect(1, 43823, '\P{ _Ethi}', "");
Expect(0, 43823, '\P{^ _Ethi}', "");
Error('\p{_	Is_ethi:=}');
Error('\P{_	Is_ethi:=}');
Expect(1, 43822, '\p{isethi}', "");
Expect(0, 43822, '\p{^isethi}', "");
Expect(0, 43822, '\P{isethi}', "");
Expect(1, 43822, '\P{^isethi}', "");
Expect(0, 43823, '\p{isethi}', "");
Expect(1, 43823, '\p{^isethi}', "");
Expect(1, 43823, '\P{isethi}', "");
Expect(0, 43823, '\P{^isethi}', "");
Expect(1, 43822, '\p{-	Is_Ethi}', "");
Expect(0, 43822, '\p{^-	Is_Ethi}', "");
Expect(0, 43822, '\P{-	Is_Ethi}', "");
Expect(1, 43822, '\P{^-	Is_Ethi}', "");
Expect(0, 43823, '\p{-	Is_Ethi}', "");
Expect(1, 43823, '\p{^-	Is_Ethi}', "");
Expect(1, 43823, '\P{-	Is_Ethi}', "");
Expect(0, 43823, '\P{^-	Is_Ethi}', "");
Error('\p{/a/ ETHIOPIC_Extended}');
Error('\P{/a/ ETHIOPIC_Extended}');
Expect(1, 11743, '\p{ethiopicextended}', "");
Expect(0, 11743, '\p{^ethiopicextended}', "");
Expect(0, 11743, '\P{ethiopicextended}', "");
Expect(1, 11743, '\P{^ethiopicextended}', "");
Expect(0, 11744, '\p{ethiopicextended}', "");
Expect(1, 11744, '\p{^ethiopicextended}', "");
Expect(1, 11744, '\P{ethiopicextended}', "");
Expect(0, 11744, '\P{^ethiopicextended}', "");
Expect(1, 11743, '\p{_Ethiopic_Extended}', "");
Expect(0, 11743, '\p{^_Ethiopic_Extended}', "");
Expect(0, 11743, '\P{_Ethiopic_Extended}', "");
Expect(1, 11743, '\P{^_Ethiopic_Extended}', "");
Expect(0, 11744, '\p{_Ethiopic_Extended}', "");
Expect(1, 11744, '\p{^_Ethiopic_Extended}', "");
Expect(1, 11744, '\P{_Ethiopic_Extended}', "");
Expect(0, 11744, '\P{^_Ethiopic_Extended}', "");
Error('\p{_is_ethiopic_Extended:=}');
Error('\P{_is_ethiopic_Extended:=}');
Expect(1, 11743, '\p{isethiopicextended}', "");
Expect(0, 11743, '\p{^isethiopicextended}', "");
Expect(0, 11743, '\P{isethiopicextended}', "");
Expect(1, 11743, '\P{^isethiopicextended}', "");
Expect(0, 11744, '\p{isethiopicextended}', "");
Expect(1, 11744, '\p{^isethiopicextended}', "");
Expect(1, 11744, '\P{isethiopicextended}', "");
Expect(0, 11744, '\P{^isethiopicextended}', "");
Expect(1, 11743, '\p{_	is_Ethiopic_EXTENDED}', "");
Expect(0, 11743, '\p{^_	is_Ethiopic_EXTENDED}', "");
Expect(0, 11743, '\P{_	is_Ethiopic_EXTENDED}', "");
Expect(1, 11743, '\P{^_	is_Ethiopic_EXTENDED}', "");
Expect(0, 11744, '\p{_	is_Ethiopic_EXTENDED}', "");
Expect(1, 11744, '\p{^_	is_Ethiopic_EXTENDED}', "");
Expect(1, 11744, '\P{_	is_Ethiopic_EXTENDED}', "");
Expect(0, 11744, '\P{^_	is_Ethiopic_EXTENDED}', "");
Error('\p{:=_In_ETHIOPIC_Extended}');
Error('\P{:=_In_ETHIOPIC_Extended}');
Expect(1, 11743, '\p{inethiopicextended}', "");
Expect(0, 11743, '\p{^inethiopicextended}', "");
Expect(0, 11743, '\P{inethiopicextended}', "");
Expect(1, 11743, '\P{^inethiopicextended}', "");
Expect(0, 11744, '\p{inethiopicextended}', "");
Expect(1, 11744, '\p{^inethiopicextended}', "");
Expect(1, 11744, '\P{inethiopicextended}', "");
Expect(0, 11744, '\P{^inethiopicextended}', "");
Expect(1, 11743, '\p{--In_Ethiopic_Extended}', "");
Expect(0, 11743, '\p{^--In_Ethiopic_Extended}', "");
Expect(0, 11743, '\P{--In_Ethiopic_Extended}', "");
Expect(1, 11743, '\P{^--In_Ethiopic_Extended}', "");
Expect(0, 11744, '\p{--In_Ethiopic_Extended}', "");
Expect(1, 11744, '\p{^--In_Ethiopic_Extended}', "");
Expect(1, 11744, '\P{--In_Ethiopic_Extended}', "");
Expect(0, 11744, '\P{^--In_Ethiopic_Extended}', "");
Error('\p{:=_Ethiopic_ext}');
Error('\P{:=_Ethiopic_ext}');
Expect(1, 11743, '\p{ethiopicext}', "");
Expect(0, 11743, '\p{^ethiopicext}', "");
Expect(0, 11743, '\P{ethiopicext}', "");
Expect(1, 11743, '\P{^ethiopicext}', "");
Expect(0, 11744, '\p{ethiopicext}', "");
Expect(1, 11744, '\p{^ethiopicext}', "");
Expect(1, 11744, '\P{ethiopicext}', "");
Expect(0, 11744, '\P{^ethiopicext}', "");
Expect(1, 11743, '\p{-Ethiopic_ext}', "");
Expect(0, 11743, '\p{^-Ethiopic_ext}', "");
Expect(0, 11743, '\P{-Ethiopic_ext}', "");
Expect(1, 11743, '\P{^-Ethiopic_ext}', "");
Expect(0, 11744, '\p{-Ethiopic_ext}', "");
Expect(1, 11744, '\p{^-Ethiopic_ext}', "");
Expect(1, 11744, '\P{-Ethiopic_ext}', "");
Expect(0, 11744, '\P{^-Ethiopic_ext}', "");
Error('\p{- IS_Ethiopic_ext:=}');
Error('\P{- IS_Ethiopic_ext:=}');
Expect(1, 11743, '\p{isethiopicext}', "");
Expect(0, 11743, '\p{^isethiopicext}', "");
Expect(0, 11743, '\P{isethiopicext}', "");
Expect(1, 11743, '\P{^isethiopicext}', "");
Expect(0, 11744, '\p{isethiopicext}', "");
Expect(1, 11744, '\p{^isethiopicext}', "");
Expect(1, 11744, '\P{isethiopicext}', "");
Expect(0, 11744, '\P{^isethiopicext}', "");
Expect(1, 11743, '\p{_ is_Ethiopic_ext}', "");
Expect(0, 11743, '\p{^_ is_Ethiopic_ext}', "");
Expect(0, 11743, '\P{_ is_Ethiopic_ext}', "");
Expect(1, 11743, '\P{^_ is_Ethiopic_ext}', "");
Expect(0, 11744, '\p{_ is_Ethiopic_ext}', "");
Expect(1, 11744, '\p{^_ is_Ethiopic_ext}', "");
Expect(1, 11744, '\P{_ is_Ethiopic_ext}', "");
Expect(0, 11744, '\P{^_ is_Ethiopic_ext}', "");
Error('\p{-_In_ethiopic_ext:=}');
Error('\P{-_In_ethiopic_ext:=}');
Expect(1, 11743, '\p{inethiopicext}', "");
Expect(0, 11743, '\p{^inethiopicext}', "");
Expect(0, 11743, '\P{inethiopicext}', "");
Expect(1, 11743, '\P{^inethiopicext}', "");
Expect(0, 11744, '\p{inethiopicext}', "");
Expect(1, 11744, '\p{^inethiopicext}', "");
Expect(1, 11744, '\P{inethiopicext}', "");
Expect(0, 11744, '\P{^inethiopicext}', "");
Expect(1, 11743, '\p{in_Ethiopic_ext}', "");
Expect(0, 11743, '\p{^in_Ethiopic_ext}', "");
Expect(0, 11743, '\P{in_Ethiopic_ext}', "");
Expect(1, 11743, '\P{^in_Ethiopic_ext}', "");
Expect(0, 11744, '\p{in_Ethiopic_ext}', "");
Expect(1, 11744, '\p{^in_Ethiopic_ext}', "");
Expect(1, 11744, '\P{in_Ethiopic_ext}', "");
Expect(0, 11744, '\P{^in_Ethiopic_ext}', "");
Error('\p{-ethiopic_extended_a:=}');
Error('\P{-ethiopic_extended_a:=}');
Expect(1, 43823, '\p{ethiopicextendeda}', "");
Expect(0, 43823, '\p{^ethiopicextendeda}', "");
Expect(0, 43823, '\P{ethiopicextendeda}', "");
Expect(1, 43823, '\P{^ethiopicextendeda}', "");
Expect(0, 43824, '\p{ethiopicextendeda}', "");
Expect(1, 43824, '\p{^ethiopicextendeda}', "");
Expect(1, 43824, '\P{ethiopicextendeda}', "");
Expect(0, 43824, '\P{^ethiopicextendeda}', "");
Expect(1, 43823, '\p{Ethiopic_Extended_A}', "");
Expect(0, 43823, '\p{^Ethiopic_Extended_A}', "");
Expect(0, 43823, '\P{Ethiopic_Extended_A}', "");
Expect(1, 43823, '\P{^Ethiopic_Extended_A}', "");
Expect(0, 43824, '\p{Ethiopic_Extended_A}', "");
Expect(1, 43824, '\p{^Ethiopic_Extended_A}', "");
Expect(1, 43824, '\P{Ethiopic_Extended_A}', "");
Expect(0, 43824, '\P{^Ethiopic_Extended_A}', "");
Error('\p{:=is_Ethiopic_Extended_A}');
Error('\P{:=is_Ethiopic_Extended_A}');
Expect(1, 43823, '\p{isethiopicextendeda}', "");
Expect(0, 43823, '\p{^isethiopicextendeda}', "");
Expect(0, 43823, '\P{isethiopicextendeda}', "");
Expect(1, 43823, '\P{^isethiopicextendeda}', "");
Expect(0, 43824, '\p{isethiopicextendeda}', "");
Expect(1, 43824, '\p{^isethiopicextendeda}', "");
Expect(1, 43824, '\P{isethiopicextendeda}', "");
Expect(0, 43824, '\P{^isethiopicextendeda}', "");
Expect(1, 43823, '\p{__Is_ETHIOPIC_extended_A}', "");
Expect(0, 43823, '\p{^__Is_ETHIOPIC_extended_A}', "");
Expect(0, 43823, '\P{__Is_ETHIOPIC_extended_A}', "");
Expect(1, 43823, '\P{^__Is_ETHIOPIC_extended_A}', "");
Expect(0, 43824, '\p{__Is_ETHIOPIC_extended_A}', "");
Expect(1, 43824, '\p{^__Is_ETHIOPIC_extended_A}', "");
Expect(1, 43824, '\P{__Is_ETHIOPIC_extended_A}', "");
Expect(0, 43824, '\P{^__Is_ETHIOPIC_extended_A}', "");
Error('\p{	:=in_Ethiopic_Extended_A}');
Error('\P{	:=in_Ethiopic_Extended_A}');
Expect(1, 43823, '\p{inethiopicextendeda}', "");
Expect(0, 43823, '\p{^inethiopicextendeda}', "");
Expect(0, 43823, '\P{inethiopicextendeda}', "");
Expect(1, 43823, '\P{^inethiopicextendeda}', "");
Expect(0, 43824, '\p{inethiopicextendeda}', "");
Expect(1, 43824, '\p{^inethiopicextendeda}', "");
Expect(1, 43824, '\P{inethiopicextendeda}', "");
Expect(0, 43824, '\P{^inethiopicextendeda}', "");
Expect(1, 43823, '\p{	_In_ethiopic_Extended_A}', "");
Expect(0, 43823, '\p{^	_In_ethiopic_Extended_A}', "");
Expect(0, 43823, '\P{	_In_ethiopic_Extended_A}', "");
Expect(1, 43823, '\P{^	_In_ethiopic_Extended_A}', "");
Expect(0, 43824, '\p{	_In_ethiopic_Extended_A}', "");
Expect(1, 43824, '\p{^	_In_ethiopic_Extended_A}', "");
Expect(1, 43824, '\P{	_In_ethiopic_Extended_A}', "");
Expect(0, 43824, '\P{^	_In_ethiopic_Extended_A}', "");
Error('\p{/a/Ethiopic_Ext_A}');
Error('\P{/a/Ethiopic_Ext_A}');
Expect(1, 43823, '\p{ethiopicexta}', "");
Expect(0, 43823, '\p{^ethiopicexta}', "");
Expect(0, 43823, '\P{ethiopicexta}', "");
Expect(1, 43823, '\P{^ethiopicexta}', "");
Expect(0, 43824, '\p{ethiopicexta}', "");
Expect(1, 43824, '\p{^ethiopicexta}', "");
Expect(1, 43824, '\P{ethiopicexta}', "");
Expect(0, 43824, '\P{^ethiopicexta}', "");
Expect(1, 43823, '\p{_	ethiopic_EXT_A}', "");
Expect(0, 43823, '\p{^_	ethiopic_EXT_A}', "");
Expect(0, 43823, '\P{_	ethiopic_EXT_A}', "");
Expect(1, 43823, '\P{^_	ethiopic_EXT_A}', "");
Expect(0, 43824, '\p{_	ethiopic_EXT_A}', "");
Expect(1, 43824, '\p{^_	ethiopic_EXT_A}', "");
Expect(1, 43824, '\P{_	ethiopic_EXT_A}', "");
Expect(0, 43824, '\P{^_	ethiopic_EXT_A}', "");
Error('\p{	Is_ETHIOPIC_Ext_A/a/}');
Error('\P{	Is_ETHIOPIC_Ext_A/a/}');
Expect(1, 43823, '\p{isethiopicexta}', "");
Expect(0, 43823, '\p{^isethiopicexta}', "");
Expect(0, 43823, '\P{isethiopicexta}', "");
Expect(1, 43823, '\P{^isethiopicexta}', "");
Expect(0, 43824, '\p{isethiopicexta}', "");
Expect(1, 43824, '\p{^isethiopicexta}', "");
Expect(1, 43824, '\P{isethiopicexta}', "");
Expect(0, 43824, '\P{^isethiopicexta}', "");
Expect(1, 43823, '\p{_is_Ethiopic_Ext_a}', "");
Expect(0, 43823, '\p{^_is_Ethiopic_Ext_a}', "");
Expect(0, 43823, '\P{_is_Ethiopic_Ext_a}', "");
Expect(1, 43823, '\P{^_is_Ethiopic_Ext_a}', "");
Expect(0, 43824, '\p{_is_Ethiopic_Ext_a}', "");
Expect(1, 43824, '\p{^_is_Ethiopic_Ext_a}', "");
Expect(1, 43824, '\P{_is_Ethiopic_Ext_a}', "");
Expect(0, 43824, '\P{^_is_Ethiopic_Ext_a}', "");
Error('\p{-IN_Ethiopic_ext_a/a/}');
Error('\P{-IN_Ethiopic_ext_a/a/}');
Expect(1, 43823, '\p{inethiopicexta}', "");
Expect(0, 43823, '\p{^inethiopicexta}', "");
Expect(0, 43823, '\P{inethiopicexta}', "");
Expect(1, 43823, '\P{^inethiopicexta}', "");
Expect(0, 43824, '\p{inethiopicexta}', "");
Expect(1, 43824, '\p{^inethiopicexta}', "");
Expect(1, 43824, '\P{inethiopicexta}', "");
Expect(0, 43824, '\P{^inethiopicexta}', "");
Expect(1, 43823, '\p{ In_Ethiopic_EXT_A}', "");
Expect(0, 43823, '\p{^ In_Ethiopic_EXT_A}', "");
Expect(0, 43823, '\P{ In_Ethiopic_EXT_A}', "");
Expect(1, 43823, '\P{^ In_Ethiopic_EXT_A}', "");
Expect(0, 43824, '\p{ In_Ethiopic_EXT_A}', "");
Expect(1, 43824, '\p{^ In_Ethiopic_EXT_A}', "");
Expect(1, 43824, '\P{ In_Ethiopic_EXT_A}', "");
Expect(0, 43824, '\P{^ In_Ethiopic_EXT_A}', "");
Error('\p{/a/	ETHIOPIC_supplement}');
Error('\P{/a/	ETHIOPIC_supplement}');
Expect(1, 5023, '\p{ethiopicsupplement}', "");
Expect(0, 5023, '\p{^ethiopicsupplement}', "");
Expect(0, 5023, '\P{ethiopicsupplement}', "");
Expect(1, 5023, '\P{^ethiopicsupplement}', "");
Expect(0, 5024, '\p{ethiopicsupplement}', "");
Expect(1, 5024, '\p{^ethiopicsupplement}', "");
Expect(1, 5024, '\P{ethiopicsupplement}', "");
Expect(0, 5024, '\P{^ethiopicsupplement}', "");
Expect(1, 5023, '\p{-Ethiopic_Supplement}', "");
Expect(0, 5023, '\p{^-Ethiopic_Supplement}', "");
Expect(0, 5023, '\P{-Ethiopic_Supplement}', "");
Expect(1, 5023, '\P{^-Ethiopic_Supplement}', "");
Expect(0, 5024, '\p{-Ethiopic_Supplement}', "");
Expect(1, 5024, '\p{^-Ethiopic_Supplement}', "");
Expect(1, 5024, '\P{-Ethiopic_Supplement}', "");
Expect(0, 5024, '\P{^-Ethiopic_Supplement}', "");
Error('\p{-/a/IS_Ethiopic_Supplement}');
Error('\P{-/a/IS_Ethiopic_Supplement}');
Expect(1, 5023, '\p{isethiopicsupplement}', "");
Expect(0, 5023, '\p{^isethiopicsupplement}', "");
Expect(0, 5023, '\P{isethiopicsupplement}', "");
Expect(1, 5023, '\P{^isethiopicsupplement}', "");
Expect(0, 5024, '\p{isethiopicsupplement}', "");
Expect(1, 5024, '\p{^isethiopicsupplement}', "");
Expect(1, 5024, '\P{isethiopicsupplement}', "");
Expect(0, 5024, '\P{^isethiopicsupplement}', "");
Expect(1, 5023, '\p{ IS_Ethiopic_supplement}', "");
Expect(0, 5023, '\p{^ IS_Ethiopic_supplement}', "");
Expect(0, 5023, '\P{ IS_Ethiopic_supplement}', "");
Expect(1, 5023, '\P{^ IS_Ethiopic_supplement}', "");
Expect(0, 5024, '\p{ IS_Ethiopic_supplement}', "");
Expect(1, 5024, '\p{^ IS_Ethiopic_supplement}', "");
Expect(1, 5024, '\P{ IS_Ethiopic_supplement}', "");
Expect(0, 5024, '\P{^ IS_Ethiopic_supplement}', "");
Error('\p{	 In_ethiopic_SUPPLEMENT:=}');
Error('\P{	 In_ethiopic_SUPPLEMENT:=}');
Expect(1, 5023, '\p{inethiopicsupplement}', "");
Expect(0, 5023, '\p{^inethiopicsupplement}', "");
Expect(0, 5023, '\P{inethiopicsupplement}', "");
Expect(1, 5023, '\P{^inethiopicsupplement}', "");
Expect(0, 5024, '\p{inethiopicsupplement}', "");
Expect(1, 5024, '\p{^inethiopicsupplement}', "");
Expect(1, 5024, '\P{inethiopicsupplement}', "");
Expect(0, 5024, '\P{^inethiopicsupplement}', "");
Expect(1, 5023, '\p{		In_ETHIOPIC_Supplement}', "");
Expect(0, 5023, '\p{^		In_ETHIOPIC_Supplement}', "");
Expect(0, 5023, '\P{		In_ETHIOPIC_Supplement}', "");
Expect(1, 5023, '\P{^		In_ETHIOPIC_Supplement}', "");
Expect(0, 5024, '\p{		In_ETHIOPIC_Supplement}', "");
Expect(1, 5024, '\p{^		In_ETHIOPIC_Supplement}', "");
Expect(1, 5024, '\P{		In_ETHIOPIC_Supplement}', "");
Expect(0, 5024, '\P{^		In_ETHIOPIC_Supplement}', "");
Error('\p{ /a/Ethiopic_sup}');
Error('\P{ /a/Ethiopic_sup}');
Expect(1, 5023, '\p{ethiopicsup}', "");
Expect(0, 5023, '\p{^ethiopicsup}', "");
Expect(0, 5023, '\P{ethiopicsup}', "");
Expect(1, 5023, '\P{^ethiopicsup}', "");
Expect(0, 5024, '\p{ethiopicsup}', "");
Expect(1, 5024, '\p{^ethiopicsup}', "");
Expect(1, 5024, '\P{ethiopicsup}', "");
Expect(0, 5024, '\P{^ethiopicsup}', "");
Expect(1, 5023, '\p{-ethiopic_Sup}', "");
Expect(0, 5023, '\p{^-ethiopic_Sup}', "");
Expect(0, 5023, '\P{-ethiopic_Sup}', "");
Expect(1, 5023, '\P{^-ethiopic_Sup}', "");
Expect(0, 5024, '\p{-ethiopic_Sup}', "");
Expect(1, 5024, '\p{^-ethiopic_Sup}', "");
Expect(1, 5024, '\P{-ethiopic_Sup}', "");
Expect(0, 5024, '\P{^-ethiopic_Sup}', "");
Error('\p{/a/-_Is_ETHIOPIC_Sup}');
Error('\P{/a/-_Is_ETHIOPIC_Sup}');
Expect(1, 5023, '\p{isethiopicsup}', "");
Expect(0, 5023, '\p{^isethiopicsup}', "");
Expect(0, 5023, '\P{isethiopicsup}', "");
Expect(1, 5023, '\P{^isethiopicsup}', "");
Expect(0, 5024, '\p{isethiopicsup}', "");
Expect(1, 5024, '\p{^isethiopicsup}', "");
Expect(1, 5024, '\P{isethiopicsup}', "");
Expect(0, 5024, '\P{^isethiopicsup}', "");
Expect(1, 5023, '\p{-Is_Ethiopic_SUP}', "");
Expect(0, 5023, '\p{^-Is_Ethiopic_SUP}', "");
Expect(0, 5023, '\P{-Is_Ethiopic_SUP}', "");
Expect(1, 5023, '\P{^-Is_Ethiopic_SUP}', "");
Expect(0, 5024, '\p{-Is_Ethiopic_SUP}', "");
Expect(1, 5024, '\p{^-Is_Ethiopic_SUP}', "");
Expect(1, 5024, '\P{-Is_Ethiopic_SUP}', "");
Expect(0, 5024, '\P{^-Is_Ethiopic_SUP}', "");
Error('\p{:=	-in_Ethiopic_SUP}');
Error('\P{:=	-in_Ethiopic_SUP}');
Expect(1, 5023, '\p{inethiopicsup}', "");
Expect(0, 5023, '\p{^inethiopicsup}', "");
Expect(0, 5023, '\P{inethiopicsup}', "");
Expect(1, 5023, '\P{^inethiopicsup}', "");
Expect(0, 5024, '\p{inethiopicsup}', "");
Expect(1, 5024, '\p{^inethiopicsup}', "");
Expect(1, 5024, '\P{inethiopicsup}', "");
Expect(0, 5024, '\P{^inethiopicsup}', "");
Expect(1, 5023, '\p{		In_Ethiopic_Sup}', "");
Expect(0, 5023, '\p{^		In_Ethiopic_Sup}', "");
Expect(0, 5023, '\P{		In_Ethiopic_Sup}', "");
Expect(1, 5023, '\P{^		In_Ethiopic_Sup}', "");
Expect(0, 5024, '\p{		In_Ethiopic_Sup}', "");
Expect(1, 5024, '\p{^		In_Ethiopic_Sup}', "");
Expect(1, 5024, '\P{		In_Ethiopic_Sup}', "");
Expect(0, 5024, '\P{^		In_Ethiopic_Sup}', "");
Error('\p{Expands_On_NFC}');
Error('\P{Expands_On_NFC}');
Error('\p{Is_Expands_On_NFC}');
Error('\P{Is_Expands_On_NFC}');
Error('\p{XO_NFC}');
Error('\P{XO_NFC}');
Error('\p{Is_XO_NFC}');
Error('\P{Is_XO_NFC}');
Error('\p{Expands_On_NFD}');
Error('\P{Expands_On_NFD}');
Error('\p{Is_Expands_On_NFD}');
Error('\P{Is_Expands_On_NFD}');
Error('\p{XO_NFD}');
Error('\P{XO_NFD}');
Error('\p{Is_XO_NFD}');
Error('\P{Is_XO_NFD}');
Error('\p{Expands_On_NFKC}');
Error('\P{Expands_On_NFKC}');
Error('\p{Is_Expands_On_NFKC}');
Error('\P{Is_Expands_On_NFKC}');
Error('\p{XO_NFKC}');
Error('\P{XO_NFKC}');
Error('\p{Is_XO_NFKC}');
Error('\P{Is_XO_NFKC}');
Error('\p{Expands_On_NFKD}');
Error('\P{Expands_On_NFKD}');
Error('\p{Is_Expands_On_NFKD}');
Error('\P{Is_Expands_On_NFKD}');
Error('\p{XO_NFKD}');
Error('\P{XO_NFKD}');
Error('\p{Is_XO_NFKD}');
Error('\P{Is_XO_NFKD}');
Error('\p{_/a/Extender}');
Error('\P{_/a/Extender}');
Expect(1, 65392, '\p{extender}', "");
Expect(0, 65392, '\p{^extender}', "");
Expect(0, 65392, '\P{extender}', "");
Expect(1, 65392, '\P{^extender}', "");
Expect(0, 65393, '\p{extender}', "");
Expect(1, 65393, '\p{^extender}', "");
Expect(1, 65393, '\P{extender}', "");
Expect(0, 65393, '\P{^extender}', "");
Expect(1, 65392, '\p{ -Extender}', "");
Expect(0, 65392, '\p{^ -Extender}', "");
Expect(0, 65392, '\P{ -Extender}', "");
Expect(1, 65392, '\P{^ -Extender}', "");
Expect(0, 65393, '\p{ -Extender}', "");
Expect(1, 65393, '\p{^ -Extender}', "");
Expect(1, 65393, '\P{ -Extender}', "");
Expect(0, 65393, '\P{^ -Extender}', "");
Error('\p{/a/	 is_Extender}');
Error('\P{/a/	 is_Extender}');
Expect(1, 65392, '\p{isextender}', "");
Expect(0, 65392, '\p{^isextender}', "");
Expect(0, 65392, '\P{isextender}', "");
Expect(1, 65392, '\P{^isextender}', "");
Expect(0, 65393, '\p{isextender}', "");
Expect(1, 65393, '\p{^isextender}', "");
Expect(1, 65393, '\P{isextender}', "");
Expect(0, 65393, '\P{^isextender}', "");
Expect(1, 65392, '\p{-	Is_Extender}', "");
Expect(0, 65392, '\p{^-	Is_Extender}', "");
Expect(0, 65392, '\P{-	Is_Extender}', "");
Expect(1, 65392, '\P{^-	Is_Extender}', "");
Expect(0, 65393, '\p{-	Is_Extender}', "");
Expect(1, 65393, '\p{^-	Is_Extender}', "");
Expect(1, 65393, '\P{-	Is_Extender}', "");
Expect(0, 65393, '\P{^-	Is_Extender}', "");
Error('\p{:=	_EXT}');
Error('\P{:=	_EXT}');
Expect(1, 65392, '\p{ext}', "");
Expect(0, 65392, '\p{^ext}', "");
Expect(0, 65392, '\P{ext}', "");
Expect(1, 65392, '\P{^ext}', "");
Expect(0, 65393, '\p{ext}', "");
Expect(1, 65393, '\p{^ext}', "");
Expect(1, 65393, '\P{ext}', "");
Expect(0, 65393, '\P{^ext}', "");
Expect(1, 65392, '\p{__EXT}', "");
Expect(0, 65392, '\p{^__EXT}', "");
Expect(0, 65392, '\P{__EXT}', "");
Expect(1, 65392, '\P{^__EXT}', "");
Expect(0, 65393, '\p{__EXT}', "");
Expect(1, 65393, '\p{^__EXT}', "");
Expect(1, 65393, '\P{__EXT}', "");
Expect(0, 65393, '\P{^__EXT}', "");
Error('\p{/a/Is_Ext}');
Error('\P{/a/Is_Ext}');
Expect(1, 65392, '\p{isext}', "");
Expect(0, 65392, '\p{^isext}', "");
Expect(0, 65392, '\P{isext}', "");
Expect(1, 65392, '\P{^isext}', "");
Expect(0, 65393, '\p{isext}', "");
Expect(1, 65393, '\p{^isext}', "");
Expect(1, 65393, '\P{isext}', "");
Expect(0, 65393, '\P{^isext}', "");
Expect(1, 65392, '\p{-	is_Ext}', "");
Expect(0, 65392, '\p{^-	is_Ext}', "");
Expect(0, 65392, '\P{-	is_Ext}', "");
Expect(1, 65392, '\P{^-	is_Ext}', "");
Expect(0, 65393, '\p{-	is_Ext}', "");
Expect(1, 65393, '\p{^-	is_Ext}', "");
Expect(1, 65393, '\P{-	is_Ext}', "");
Expect(0, 65393, '\P{^-	is_Ext}', "");
Error('\p{:=-final_Punctuation}');
Error('\P{:=-final_Punctuation}');
Expect(1, 11809, '\p{finalpunctuation}', "");
Expect(0, 11809, '\p{^finalpunctuation}', "");
Expect(0, 11809, '\P{finalpunctuation}', "");
Expect(1, 11809, '\P{^finalpunctuation}', "");
Expect(0, 11810, '\p{finalpunctuation}', "");
Expect(1, 11810, '\p{^finalpunctuation}', "");
Expect(1, 11810, '\P{finalpunctuation}', "");
Expect(0, 11810, '\P{^finalpunctuation}', "");
Expect(1, 11809, '\p{	final_PUNCTUATION}', "");
Expect(0, 11809, '\p{^	final_PUNCTUATION}', "");
Expect(0, 11809, '\P{	final_PUNCTUATION}', "");
Expect(1, 11809, '\P{^	final_PUNCTUATION}', "");
Expect(0, 11810, '\p{	final_PUNCTUATION}', "");
Expect(1, 11810, '\p{^	final_PUNCTUATION}', "");
Expect(1, 11810, '\P{	final_PUNCTUATION}', "");
Expect(0, 11810, '\P{^	final_PUNCTUATION}', "");
Error('\p{:=	Is_Final_Punctuation}');
Error('\P{:=	Is_Final_Punctuation}');
Expect(1, 11809, '\p{isfinalpunctuation}', "");
Expect(0, 11809, '\p{^isfinalpunctuation}', "");
Expect(0, 11809, '\P{isfinalpunctuation}', "");
Expect(1, 11809, '\P{^isfinalpunctuation}', "");
Expect(0, 11810, '\p{isfinalpunctuation}', "");
Expect(1, 11810, '\p{^isfinalpunctuation}', "");
Expect(1, 11810, '\P{isfinalpunctuation}', "");
Expect(0, 11810, '\P{^isfinalpunctuation}', "");
Expect(1, 11809, '\p{--is_FINAL_Punctuation}', "");
Expect(0, 11809, '\p{^--is_FINAL_Punctuation}', "");
Expect(0, 11809, '\P{--is_FINAL_Punctuation}', "");
Expect(1, 11809, '\P{^--is_FINAL_Punctuation}', "");
Expect(0, 11810, '\p{--is_FINAL_Punctuation}', "");
Expect(1, 11810, '\p{^--is_FINAL_Punctuation}', "");
Expect(1, 11810, '\P{--is_FINAL_Punctuation}', "");
Expect(0, 11810, '\P{^--is_FINAL_Punctuation}', "");
Error('\p{:=_	PF}');
Error('\P{:=_	PF}');
Expect(1, 11809, '\p{pf}', "");
Expect(0, 11809, '\p{^pf}', "");
Expect(0, 11809, '\P{pf}', "");
Expect(1, 11809, '\P{^pf}', "");
Expect(0, 11810, '\p{pf}', "");
Expect(1, 11810, '\p{^pf}', "");
Expect(1, 11810, '\P{pf}', "");
Expect(0, 11810, '\P{^pf}', "");
Expect(1, 11809, '\p{	pf}', "");
Expect(0, 11809, '\p{^	pf}', "");
Expect(0, 11809, '\P{	pf}', "");
Expect(1, 11809, '\P{^	pf}', "");
Expect(0, 11810, '\p{	pf}', "");
Expect(1, 11810, '\p{^	pf}', "");
Expect(1, 11810, '\P{	pf}', "");
Expect(0, 11810, '\P{^	pf}', "");
Error('\p{_:=Is_Pf}');
Error('\P{_:=Is_Pf}');
Expect(1, 11809, '\p{ispf}', "");
Expect(0, 11809, '\p{^ispf}', "");
Expect(0, 11809, '\P{ispf}', "");
Expect(1, 11809, '\P{^ispf}', "");
Expect(0, 11810, '\p{ispf}', "");
Expect(1, 11810, '\p{^ispf}', "");
Expect(1, 11810, '\P{ispf}', "");
Expect(0, 11810, '\P{^ispf}', "");
Expect(1, 11809, '\p{-_Is_PF}', "");
Expect(0, 11809, '\p{^-_Is_PF}', "");
Expect(0, 11809, '\P{-_Is_PF}', "");
Expect(1, 11809, '\P{^-_Is_PF}', "");
Expect(0, 11810, '\p{-_Is_PF}', "");
Expect(1, 11810, '\p{^-_Is_PF}', "");
Expect(1, 11810, '\P{-_Is_PF}', "");
Expect(0, 11810, '\P{^-_Is_PF}', "");
Error('\p{/a/_ FORMAT}');
Error('\P{/a/_ FORMAT}');
Expect(1, 917631, '\p{format}', "");
Expect(0, 917631, '\p{^format}', "");
Expect(0, 917631, '\P{format}', "");
Expect(1, 917631, '\P{^format}', "");
Expect(0, 917632, '\p{format}', "");
Expect(1, 917632, '\p{^format}', "");
Expect(1, 917632, '\P{format}', "");
Expect(0, 917632, '\P{^format}', "");
Expect(1, 917631, '\p{	-Format}', "");
Expect(0, 917631, '\p{^	-Format}', "");
Expect(0, 917631, '\P{	-Format}', "");
Expect(1, 917631, '\P{^	-Format}', "");
Expect(0, 917632, '\p{	-Format}', "");
Expect(1, 917632, '\p{^	-Format}', "");
Expect(1, 917632, '\P{	-Format}', "");
Expect(0, 917632, '\P{^	-Format}', "");
Error('\p{	IS_FORMAT/a/}');
Error('\P{	IS_FORMAT/a/}');
Expect(1, 917631, '\p{isformat}', "");
Expect(0, 917631, '\p{^isformat}', "");
Expect(0, 917631, '\P{isformat}', "");
Expect(1, 917631, '\P{^isformat}', "");
Expect(0, 917632, '\p{isformat}', "");
Expect(1, 917632, '\p{^isformat}', "");
Expect(1, 917632, '\P{isformat}', "");
Expect(0, 917632, '\P{^isformat}', "");
Expect(1, 917631, '\p{ is_FORMAT}', "");
Expect(0, 917631, '\p{^ is_FORMAT}', "");
Expect(0, 917631, '\P{ is_FORMAT}', "");
Expect(1, 917631, '\P{^ is_FORMAT}', "");
Expect(0, 917632, '\p{ is_FORMAT}', "");
Expect(1, 917632, '\p{^ is_FORMAT}', "");
Expect(1, 917632, '\P{ is_FORMAT}', "");
Expect(0, 917632, '\P{^ is_FORMAT}', "");
Error('\p{	-CF:=}');
Error('\P{	-CF:=}');
Expect(1, 917631, '\p{cf}', "");
Expect(0, 917631, '\p{^cf}', "");
Expect(0, 917631, '\P{cf}', "");
Expect(1, 917631, '\P{^cf}', "");
Expect(0, 917632, '\p{cf}', "");
Expect(1, 917632, '\p{^cf}', "");
Expect(1, 917632, '\P{cf}', "");
Expect(0, 917632, '\P{^cf}', "");
Expect(1, 917631, '\p{	-cf}', "");
Expect(0, 917631, '\p{^	-cf}', "");
Expect(0, 917631, '\P{	-cf}', "");
Expect(1, 917631, '\P{^	-cf}', "");
Expect(0, 917632, '\p{	-cf}', "");
Expect(1, 917632, '\p{^	-cf}', "");
Expect(1, 917632, '\P{	-cf}', "");
Expect(0, 917632, '\P{^	-cf}', "");
Error('\p{:=	-is_CF}');
Error('\P{:=	-is_CF}');
Expect(1, 917631, '\p{iscf}', "");
Expect(0, 917631, '\p{^iscf}', "");
Expect(0, 917631, '\P{iscf}', "");
Expect(1, 917631, '\P{^iscf}', "");
Expect(0, 917632, '\p{iscf}', "");
Expect(1, 917632, '\p{^iscf}', "");
Expect(1, 917632, '\P{iscf}', "");
Expect(0, 917632, '\P{^iscf}', "");
Expect(1, 917631, '\p{ IS_cf}', "");
Expect(0, 917631, '\p{^ IS_cf}', "");
Expect(0, 917631, '\P{ IS_cf}', "");
Expect(1, 917631, '\P{^ IS_cf}', "");
Expect(0, 917632, '\p{ IS_cf}', "");
Expect(1, 917632, '\p{^ IS_cf}', "");
Expect(1, 917632, '\P{ IS_cf}', "");
Expect(0, 917632, '\P{^ IS_cf}', "");
Error('\p{/a/ FULL_Composition_Exclusion}');
Error('\P{/a/ FULL_Composition_Exclusion}');
Expect(1, 195101, '\p{fullcompositionexclusion}', "");
Expect(0, 195101, '\p{^fullcompositionexclusion}', "");
Expect(0, 195101, '\P{fullcompositionexclusion}', "");
Expect(1, 195101, '\P{^fullcompositionexclusion}', "");
Expect(0, 195102, '\p{fullcompositionexclusion}', "");
Expect(1, 195102, '\p{^fullcompositionexclusion}', "");
Expect(1, 195102, '\P{fullcompositionexclusion}', "");
Expect(0, 195102, '\P{^fullcompositionexclusion}', "");
Expect(1, 195101, '\p{--FULL_Composition_exclusion}', "");
Expect(0, 195101, '\p{^--FULL_Composition_exclusion}', "");
Expect(0, 195101, '\P{--FULL_Composition_exclusion}', "");
Expect(1, 195101, '\P{^--FULL_Composition_exclusion}', "");
Expect(0, 195102, '\p{--FULL_Composition_exclusion}', "");
Expect(1, 195102, '\p{^--FULL_Composition_exclusion}', "");
Expect(1, 195102, '\P{--FULL_Composition_exclusion}', "");
Expect(0, 195102, '\P{^--FULL_Composition_exclusion}', "");
Error('\p{_:=IS_Full_composition_EXCLUSION}');
Error('\P{_:=IS_Full_composition_EXCLUSION}');
Expect(1, 195101, '\p{isfullcompositionexclusion}', "");
Expect(0, 195101, '\p{^isfullcompositionexclusion}', "");
Expect(0, 195101, '\P{isfullcompositionexclusion}', "");
Expect(1, 195101, '\P{^isfullcompositionexclusion}', "");
Expect(0, 195102, '\p{isfullcompositionexclusion}', "");
Expect(1, 195102, '\p{^isfullcompositionexclusion}', "");
Expect(1, 195102, '\P{isfullcompositionexclusion}', "");
Expect(0, 195102, '\P{^isfullcompositionexclusion}', "");
Expect(1, 195101, '\p{	_Is_Full_Composition_EXCLUSION}', "");
Expect(0, 195101, '\p{^	_Is_Full_Composition_EXCLUSION}', "");
Expect(0, 195101, '\P{	_Is_Full_Composition_EXCLUSION}', "");
Expect(1, 195101, '\P{^	_Is_Full_Composition_EXCLUSION}', "");
Expect(0, 195102, '\p{	_Is_Full_Composition_EXCLUSION}', "");
Expect(1, 195102, '\p{^	_Is_Full_Composition_EXCLUSION}', "");
Expect(1, 195102, '\P{	_Is_Full_Composition_EXCLUSION}', "");
Expect(0, 195102, '\P{^	_Is_Full_Composition_EXCLUSION}', "");
Error('\p{/a/-_Comp_ex}');
Error('\P{/a/-_Comp_ex}');
Expect(1, 195101, '\p{compex}', "");
Expect(0, 195101, '\p{^compex}', "");
Expect(0, 195101, '\P{compex}', "");
Expect(1, 195101, '\P{^compex}', "");
Expect(0, 195102, '\p{compex}', "");
Expect(1, 195102, '\p{^compex}', "");
Expect(1, 195102, '\P{compex}', "");
Expect(0, 195102, '\P{^compex}', "");
Expect(1, 195101, '\p{_Comp_ex}', "");
Expect(0, 195101, '\p{^_Comp_ex}', "");
Expect(0, 195101, '\P{_Comp_ex}', "");
Expect(1, 195101, '\P{^_Comp_ex}', "");
Expect(0, 195102, '\p{_Comp_ex}', "");
Expect(1, 195102, '\p{^_Comp_ex}', "");
Expect(1, 195102, '\P{_Comp_ex}', "");
Expect(0, 195102, '\P{^_Comp_ex}', "");
Error('\p{:=-IS_comp_EX}');
Error('\P{:=-IS_comp_EX}');
Expect(1, 195101, '\p{iscompex}', "");
Expect(0, 195101, '\p{^iscompex}', "");
Expect(0, 195101, '\P{iscompex}', "");
Expect(1, 195101, '\P{^iscompex}', "");
Expect(0, 195102, '\p{iscompex}', "");
Expect(1, 195102, '\p{^iscompex}', "");
Expect(1, 195102, '\P{iscompex}', "");
Expect(0, 195102, '\P{^iscompex}', "");
Expect(1, 195101, '\p{__Is_Comp_Ex}', "");
Expect(0, 195101, '\p{^__Is_Comp_Ex}', "");
Expect(0, 195101, '\P{__Is_Comp_Ex}', "");
Expect(1, 195101, '\P{^__Is_Comp_Ex}', "");
Expect(0, 195102, '\p{__Is_Comp_Ex}', "");
Expect(1, 195102, '\p{^__Is_Comp_Ex}', "");
Expect(1, 195102, '\P{__Is_Comp_Ex}', "");
Expect(0, 195102, '\P{^__Is_Comp_Ex}', "");
Error('\p{General_PUNCTUATION/a/}');
Error('\P{General_PUNCTUATION/a/}');
Expect(1, 8303, '\p{generalpunctuation}', "");
Expect(0, 8303, '\p{^generalpunctuation}', "");
Expect(0, 8303, '\P{generalpunctuation}', "");
Expect(1, 8303, '\P{^generalpunctuation}', "");
Expect(0, 8304, '\p{generalpunctuation}', "");
Expect(1, 8304, '\p{^generalpunctuation}', "");
Expect(1, 8304, '\P{generalpunctuation}', "");
Expect(0, 8304, '\P{^generalpunctuation}', "");
Expect(1, 8303, '\p{__general_PUNCTUATION}', "");
Expect(0, 8303, '\p{^__general_PUNCTUATION}', "");
Expect(0, 8303, '\P{__general_PUNCTUATION}', "");
Expect(1, 8303, '\P{^__general_PUNCTUATION}', "");
Expect(0, 8304, '\p{__general_PUNCTUATION}', "");
Expect(1, 8304, '\p{^__general_PUNCTUATION}', "");
Expect(1, 8304, '\P{__general_PUNCTUATION}', "");
Expect(0, 8304, '\P{^__general_PUNCTUATION}', "");
Error('\p{ /a/Is_General_Punctuation}');
Error('\P{ /a/Is_General_Punctuation}');
Expect(1, 8303, '\p{isgeneralpunctuation}', "");
Expect(0, 8303, '\p{^isgeneralpunctuation}', "");
Expect(0, 8303, '\P{isgeneralpunctuation}', "");
Expect(1, 8303, '\P{^isgeneralpunctuation}', "");
Expect(0, 8304, '\p{isgeneralpunctuation}', "");
Expect(1, 8304, '\p{^isgeneralpunctuation}', "");
Expect(1, 8304, '\P{isgeneralpunctuation}', "");
Expect(0, 8304, '\P{^isgeneralpunctuation}', "");
Expect(1, 8303, '\p{__IS_general_punctuation}', "");
Expect(0, 8303, '\p{^__IS_general_punctuation}', "");
Expect(0, 8303, '\P{__IS_general_punctuation}', "");
Expect(1, 8303, '\P{^__IS_general_punctuation}', "");
Expect(0, 8304, '\p{__IS_general_punctuation}', "");
Expect(1, 8304, '\p{^__IS_general_punctuation}', "");
Expect(1, 8304, '\P{__IS_general_punctuation}', "");
Expect(0, 8304, '\P{^__IS_general_punctuation}', "");
Error('\p{-/a/In_general_PUNCTUATION}');
Error('\P{-/a/In_general_PUNCTUATION}');
Expect(1, 8303, '\p{ingeneralpunctuation}', "");
Expect(0, 8303, '\p{^ingeneralpunctuation}', "");
Expect(0, 8303, '\P{ingeneralpunctuation}', "");
Expect(1, 8303, '\P{^ingeneralpunctuation}', "");
Expect(0, 8304, '\p{ingeneralpunctuation}', "");
Expect(1, 8304, '\p{^ingeneralpunctuation}', "");
Expect(1, 8304, '\P{ingeneralpunctuation}', "");
Expect(0, 8304, '\P{^ingeneralpunctuation}', "");
Expect(1, 8303, '\p{	In_General_Punctuation}', "");
Expect(0, 8303, '\p{^	In_General_Punctuation}', "");
Expect(0, 8303, '\P{	In_General_Punctuation}', "");
Expect(1, 8303, '\P{^	In_General_Punctuation}', "");
Expect(0, 8304, '\p{	In_General_Punctuation}', "");
Expect(1, 8304, '\p{^	In_General_Punctuation}', "");
Expect(1, 8304, '\P{	In_General_Punctuation}', "");
Expect(0, 8304, '\P{^	In_General_Punctuation}', "");
Error('\p{ :=In_PUNCTUATION}');
Error('\P{ :=In_PUNCTUATION}');
Expect(1, 8303, '\p{inpunctuation}', "");
Expect(0, 8303, '\p{^inpunctuation}', "");
Expect(0, 8303, '\P{inpunctuation}', "");
Expect(1, 8303, '\P{^inpunctuation}', "");
Expect(0, 8304, '\p{inpunctuation}', "");
Expect(1, 8304, '\p{^inpunctuation}', "");
Expect(1, 8304, '\P{inpunctuation}', "");
Expect(0, 8304, '\P{^inpunctuation}', "");
Expect(1, 8303, '\p{-_IN_Punctuation}', "");
Expect(0, 8303, '\p{^-_IN_Punctuation}', "");
Expect(0, 8303, '\P{-_IN_Punctuation}', "");
Expect(1, 8303, '\P{^-_IN_Punctuation}', "");
Expect(0, 8304, '\p{-_IN_Punctuation}', "");
Expect(1, 8304, '\p{^-_IN_Punctuation}', "");
Expect(1, 8304, '\P{-_IN_Punctuation}', "");
Expect(0, 8304, '\P{^-_IN_Punctuation}', "");
Error('\p{	/a/geometric_SHAPES}');
Error('\P{	/a/geometric_SHAPES}');
Expect(1, 9727, '\p{geometricshapes}', "");
Expect(0, 9727, '\p{^geometricshapes}', "");
Expect(0, 9727, '\P{geometricshapes}', "");
Expect(1, 9727, '\P{^geometricshapes}', "");
Expect(0, 9728, '\p{geometricshapes}', "");
Expect(1, 9728, '\p{^geometricshapes}', "");
Expect(1, 9728, '\P{geometricshapes}', "");
Expect(0, 9728, '\P{^geometricshapes}', "");
Expect(1, 9727, '\p{	GEOMETRIC_Shapes}', "");
Expect(0, 9727, '\p{^	GEOMETRIC_Shapes}', "");
Expect(0, 9727, '\P{	GEOMETRIC_Shapes}', "");
Expect(1, 9727, '\P{^	GEOMETRIC_Shapes}', "");
Expect(0, 9728, '\p{	GEOMETRIC_Shapes}', "");
Expect(1, 9728, '\p{^	GEOMETRIC_Shapes}', "");
Expect(1, 9728, '\P{	GEOMETRIC_Shapes}', "");
Expect(0, 9728, '\P{^	GEOMETRIC_Shapes}', "");
Error('\p{/a/is_GEOMETRIC_Shapes}');
Error('\P{/a/is_GEOMETRIC_Shapes}');
Expect(1, 9727, '\p{isgeometricshapes}', "");
Expect(0, 9727, '\p{^isgeometricshapes}', "");
Expect(0, 9727, '\P{isgeometricshapes}', "");
Expect(1, 9727, '\P{^isgeometricshapes}', "");
Expect(0, 9728, '\p{isgeometricshapes}', "");
Expect(1, 9728, '\p{^isgeometricshapes}', "");
Expect(1, 9728, '\P{isgeometricshapes}', "");
Expect(0, 9728, '\P{^isgeometricshapes}', "");
Expect(1, 9727, '\p{	_IS_GEOMETRIC_Shapes}', "");
Expect(0, 9727, '\p{^	_IS_GEOMETRIC_Shapes}', "");
Expect(0, 9727, '\P{	_IS_GEOMETRIC_Shapes}', "");
Expect(1, 9727, '\P{^	_IS_GEOMETRIC_Shapes}', "");
Expect(0, 9728, '\p{	_IS_GEOMETRIC_Shapes}', "");
Expect(1, 9728, '\p{^	_IS_GEOMETRIC_Shapes}', "");
Expect(1, 9728, '\P{	_IS_GEOMETRIC_Shapes}', "");
Expect(0, 9728, '\P{^	_IS_GEOMETRIC_Shapes}', "");
Error('\p{:=In_GEOMETRIC_Shapes}');
Error('\P{:=In_GEOMETRIC_Shapes}');
Expect(1, 9727, '\p{ingeometricshapes}', "");
Expect(0, 9727, '\p{^ingeometricshapes}', "");
Expect(0, 9727, '\P{ingeometricshapes}', "");
Expect(1, 9727, '\P{^ingeometricshapes}', "");
Expect(0, 9728, '\p{ingeometricshapes}', "");
Expect(1, 9728, '\p{^ingeometricshapes}', "");
Expect(1, 9728, '\P{ingeometricshapes}', "");
Expect(0, 9728, '\P{^ingeometricshapes}', "");
Expect(1, 9727, '\p{_ IN_GEOMETRIC_Shapes}', "");
Expect(0, 9727, '\p{^_ IN_GEOMETRIC_Shapes}', "");
Expect(0, 9727, '\P{_ IN_GEOMETRIC_Shapes}', "");
Expect(1, 9727, '\P{^_ IN_GEOMETRIC_Shapes}', "");
Expect(0, 9728, '\p{_ IN_GEOMETRIC_Shapes}', "");
Expect(1, 9728, '\p{^_ IN_GEOMETRIC_Shapes}', "");
Expect(1, 9728, '\P{_ IN_GEOMETRIC_Shapes}', "");
Expect(0, 9728, '\P{^_ IN_GEOMETRIC_Shapes}', "");
Error('\p{:= -Georgian}');
Error('\P{:= -Georgian}');
Expect(1, 11565, '\p{georgian}', "");
Expect(0, 11565, '\p{^georgian}', "");
Expect(0, 11565, '\P{georgian}', "");
Expect(1, 11565, '\P{^georgian}', "");
Expect(0, 11566, '\p{georgian}', "");
Expect(1, 11566, '\p{^georgian}', "");
Expect(1, 11566, '\P{georgian}', "");
Expect(0, 11566, '\P{^georgian}', "");
Expect(1, 11565, '\p{ 	Georgian}', "");
Expect(0, 11565, '\p{^ 	Georgian}', "");
Expect(0, 11565, '\P{ 	Georgian}', "");
Expect(1, 11565, '\P{^ 	Georgian}', "");
Expect(0, 11566, '\p{ 	Georgian}', "");
Expect(1, 11566, '\p{^ 	Georgian}', "");
Expect(1, 11566, '\P{ 	Georgian}', "");
Expect(0, 11566, '\P{^ 	Georgian}', "");
Error('\p{/a/	Is_Georgian}');
Error('\P{/a/	Is_Georgian}');
Expect(1, 11565, '\p{isgeorgian}', "");
Expect(0, 11565, '\p{^isgeorgian}', "");
Expect(0, 11565, '\P{isgeorgian}', "");
Expect(1, 11565, '\P{^isgeorgian}', "");
Expect(0, 11566, '\p{isgeorgian}', "");
Expect(1, 11566, '\p{^isgeorgian}', "");
Expect(1, 11566, '\P{isgeorgian}', "");
Expect(0, 11566, '\P{^isgeorgian}', "");
Expect(1, 11565, '\p{-Is_Georgian}', "");
Expect(0, 11565, '\p{^-Is_Georgian}', "");
Expect(0, 11565, '\P{-Is_Georgian}', "");
Expect(1, 11565, '\P{^-Is_Georgian}', "");
Expect(0, 11566, '\p{-Is_Georgian}', "");
Expect(1, 11566, '\p{^-Is_Georgian}', "");
Expect(1, 11566, '\P{-Is_Georgian}', "");
Expect(0, 11566, '\P{^-Is_Georgian}', "");
Error('\p{:= -Geor}');
Error('\P{:= -Geor}');
Expect(1, 11565, '\p{geor}', "");
Expect(0, 11565, '\p{^geor}', "");
Expect(0, 11565, '\P{geor}', "");
Expect(1, 11565, '\P{^geor}', "");
Expect(0, 11566, '\p{geor}', "");
Expect(1, 11566, '\p{^geor}', "");
Expect(1, 11566, '\P{geor}', "");
Expect(0, 11566, '\P{^geor}', "");
Expect(1, 11565, '\p{-_Geor}', "");
Expect(0, 11565, '\p{^-_Geor}', "");
Expect(0, 11565, '\P{-_Geor}', "");
Expect(1, 11565, '\P{^-_Geor}', "");
Expect(0, 11566, '\p{-_Geor}', "");
Expect(1, 11566, '\p{^-_Geor}', "");
Expect(1, 11566, '\P{-_Geor}', "");
Expect(0, 11566, '\P{^-_Geor}', "");
Error('\p{	 is_geor/a/}');
Error('\P{	 is_geor/a/}');
Expect(1, 11565, '\p{isgeor}', "");
Expect(0, 11565, '\p{^isgeor}', "");
Expect(0, 11565, '\P{isgeor}', "");
Expect(1, 11565, '\P{^isgeor}', "");
Expect(0, 11566, '\p{isgeor}', "");
Expect(1, 11566, '\p{^isgeor}', "");
Expect(1, 11566, '\P{isgeor}', "");
Expect(0, 11566, '\P{^isgeor}', "");
Expect(1, 11565, '\p{  Is_Geor}', "");
Expect(0, 11565, '\p{^  Is_Geor}', "");
Expect(0, 11565, '\P{  Is_Geor}', "");
Expect(1, 11565, '\P{^  Is_Geor}', "");
Expect(0, 11566, '\p{  Is_Geor}', "");
Expect(1, 11566, '\p{^  Is_Geor}', "");
Expect(1, 11566, '\P{  Is_Geor}', "");
Expect(0, 11566, '\P{^  Is_Geor}', "");
Error('\p{/a/-Georgian_Supplement}');
Error('\P{/a/-Georgian_Supplement}');
Expect(1, 11567, '\p{georgiansupplement}', "");
Expect(0, 11567, '\p{^georgiansupplement}', "");
Expect(0, 11567, '\P{georgiansupplement}', "");
Expect(1, 11567, '\P{^georgiansupplement}', "");
Expect(0, 11568, '\p{georgiansupplement}', "");
Expect(1, 11568, '\p{^georgiansupplement}', "");
Expect(1, 11568, '\P{georgiansupplement}', "");
Expect(0, 11568, '\P{^georgiansupplement}', "");
Expect(1, 11567, '\p{-	Georgian_supplement}', "");
Expect(0, 11567, '\p{^-	Georgian_supplement}', "");
Expect(0, 11567, '\P{-	Georgian_supplement}', "");
Expect(1, 11567, '\P{^-	Georgian_supplement}', "");
Expect(0, 11568, '\p{-	Georgian_supplement}', "");
Expect(1, 11568, '\p{^-	Georgian_supplement}', "");
Expect(1, 11568, '\P{-	Georgian_supplement}', "");
Expect(0, 11568, '\P{^-	Georgian_supplement}', "");
Error('\p{-	IS_GEORGIAN_Supplement:=}');
Error('\P{-	IS_GEORGIAN_Supplement:=}');
Expect(1, 11567, '\p{isgeorgiansupplement}', "");
Expect(0, 11567, '\p{^isgeorgiansupplement}', "");
Expect(0, 11567, '\P{isgeorgiansupplement}', "");
Expect(1, 11567, '\P{^isgeorgiansupplement}', "");
Expect(0, 11568, '\p{isgeorgiansupplement}', "");
Expect(1, 11568, '\p{^isgeorgiansupplement}', "");
Expect(1, 11568, '\P{isgeorgiansupplement}', "");
Expect(0, 11568, '\P{^isgeorgiansupplement}', "");
Expect(1, 11567, '\p{	Is_GEORGIAN_Supplement}', "");
Expect(0, 11567, '\p{^	Is_GEORGIAN_Supplement}', "");
Expect(0, 11567, '\P{	Is_GEORGIAN_Supplement}', "");
Expect(1, 11567, '\P{^	Is_GEORGIAN_Supplement}', "");
Expect(0, 11568, '\p{	Is_GEORGIAN_Supplement}', "");
Expect(1, 11568, '\p{^	Is_GEORGIAN_Supplement}', "");
Expect(1, 11568, '\P{	Is_GEORGIAN_Supplement}', "");
Expect(0, 11568, '\P{^	Is_GEORGIAN_Supplement}', "");
Error('\p{:=-In_Georgian_SUPPLEMENT}');
Error('\P{:=-In_Georgian_SUPPLEMENT}');
Expect(1, 11567, '\p{ingeorgiansupplement}', "");
Expect(0, 11567, '\p{^ingeorgiansupplement}', "");
Expect(0, 11567, '\P{ingeorgiansupplement}', "");
Expect(1, 11567, '\P{^ingeorgiansupplement}', "");
Expect(0, 11568, '\p{ingeorgiansupplement}', "");
Expect(1, 11568, '\p{^ingeorgiansupplement}', "");
Expect(1, 11568, '\P{ingeorgiansupplement}', "");
Expect(0, 11568, '\P{^ingeorgiansupplement}', "");
Expect(1, 11567, '\p{	 in_Georgian_SUPPLEMENT}', "");
Expect(0, 11567, '\p{^	 in_Georgian_SUPPLEMENT}', "");
Expect(0, 11567, '\P{	 in_Georgian_SUPPLEMENT}', "");
Expect(1, 11567, '\P{^	 in_Georgian_SUPPLEMENT}', "");
Expect(0, 11568, '\p{	 in_Georgian_SUPPLEMENT}', "");
Expect(1, 11568, '\p{^	 in_Georgian_SUPPLEMENT}', "");
Expect(1, 11568, '\P{	 in_Georgian_SUPPLEMENT}', "");
Expect(0, 11568, '\P{^	 in_Georgian_SUPPLEMENT}', "");
Error('\p{/a/__Georgian_Sup}');
Error('\P{/a/__Georgian_Sup}');
Expect(1, 11567, '\p{georgiansup}', "");
Expect(0, 11567, '\p{^georgiansup}', "");
Expect(0, 11567, '\P{georgiansup}', "");
Expect(1, 11567, '\P{^georgiansup}', "");
Expect(0, 11568, '\p{georgiansup}', "");
Expect(1, 11568, '\p{^georgiansup}', "");
Expect(1, 11568, '\P{georgiansup}', "");
Expect(0, 11568, '\P{^georgiansup}', "");
Expect(1, 11567, '\p{-georgian_sup}', "");
Expect(0, 11567, '\p{^-georgian_sup}', "");
Expect(0, 11567, '\P{-georgian_sup}', "");
Expect(1, 11567, '\P{^-georgian_sup}', "");
Expect(0, 11568, '\p{-georgian_sup}', "");
Expect(1, 11568, '\p{^-georgian_sup}', "");
Expect(1, 11568, '\P{-georgian_sup}', "");
Expect(0, 11568, '\P{^-georgian_sup}', "");
Error('\p{-:=Is_Georgian_SUP}');
Error('\P{-:=Is_Georgian_SUP}');
Expect(1, 11567, '\p{isgeorgiansup}', "");
Expect(0, 11567, '\p{^isgeorgiansup}', "");
Expect(0, 11567, '\P{isgeorgiansup}', "");
Expect(1, 11567, '\P{^isgeorgiansup}', "");
Expect(0, 11568, '\p{isgeorgiansup}', "");
Expect(1, 11568, '\p{^isgeorgiansup}', "");
Expect(1, 11568, '\P{isgeorgiansup}', "");
Expect(0, 11568, '\P{^isgeorgiansup}', "");
Expect(1, 11567, '\p{- IS_GEORGIAN_Sup}', "");
Expect(0, 11567, '\p{^- IS_GEORGIAN_Sup}', "");
Expect(0, 11567, '\P{- IS_GEORGIAN_Sup}', "");
Expect(1, 11567, '\P{^- IS_GEORGIAN_Sup}', "");
Expect(0, 11568, '\p{- IS_GEORGIAN_Sup}', "");
Expect(1, 11568, '\p{^- IS_GEORGIAN_Sup}', "");
Expect(1, 11568, '\P{- IS_GEORGIAN_Sup}', "");
Expect(0, 11568, '\P{^- IS_GEORGIAN_Sup}', "");
Error('\p{:=_In_GEORGIAN_Sup}');
Error('\P{:=_In_GEORGIAN_Sup}');
Expect(1, 11567, '\p{ingeorgiansup}', "");
Expect(0, 11567, '\p{^ingeorgiansup}', "");
Expect(0, 11567, '\P{ingeorgiansup}', "");
Expect(1, 11567, '\P{^ingeorgiansup}', "");
Expect(0, 11568, '\p{ingeorgiansup}', "");
Expect(1, 11568, '\p{^ingeorgiansup}', "");
Expect(1, 11568, '\P{ingeorgiansup}', "");
Expect(0, 11568, '\P{^ingeorgiansup}', "");
Expect(1, 11567, '\p{	IN_Georgian_SUP}', "");
Expect(0, 11567, '\p{^	IN_Georgian_SUP}', "");
Expect(0, 11567, '\P{	IN_Georgian_SUP}', "");
Expect(1, 11567, '\P{^	IN_Georgian_SUP}', "");
Expect(0, 11568, '\p{	IN_Georgian_SUP}', "");
Expect(1, 11568, '\p{^	IN_Georgian_SUP}', "");
Expect(1, 11568, '\P{	IN_Georgian_SUP}', "");
Expect(0, 11568, '\P{^	IN_Georgian_SUP}', "");
Error('\p{:=  Glagolitic}');
Error('\P{:=  Glagolitic}');
Expect(1, 11358, '\p{glagolitic}', "");
Expect(0, 11358, '\p{^glagolitic}', "");
Expect(0, 11358, '\P{glagolitic}', "");
Expect(1, 11358, '\P{^glagolitic}', "");
Expect(0, 11359, '\p{glagolitic}', "");
Expect(1, 11359, '\p{^glagolitic}', "");
Expect(1, 11359, '\P{glagolitic}', "");
Expect(0, 11359, '\P{^glagolitic}', "");
Expect(1, 11358, '\p{-Glagolitic}', "");
Expect(0, 11358, '\p{^-Glagolitic}', "");
Expect(0, 11358, '\P{-Glagolitic}', "");
Expect(1, 11358, '\P{^-Glagolitic}', "");
Expect(0, 11359, '\p{-Glagolitic}', "");
Expect(1, 11359, '\p{^-Glagolitic}', "");
Expect(1, 11359, '\P{-Glagolitic}', "");
Expect(0, 11359, '\P{^-Glagolitic}', "");
Error('\p{  is_Glagolitic/a/}');
Error('\P{  is_Glagolitic/a/}');
Expect(1, 11358, '\p{isglagolitic}', "");
Expect(0, 11358, '\p{^isglagolitic}', "");
Expect(0, 11358, '\P{isglagolitic}', "");
Expect(1, 11358, '\P{^isglagolitic}', "");
Expect(0, 11359, '\p{isglagolitic}', "");
Expect(1, 11359, '\p{^isglagolitic}', "");
Expect(1, 11359, '\P{isglagolitic}', "");
Expect(0, 11359, '\P{^isglagolitic}', "");
Expect(1, 11358, '\p{	_IS_Glagolitic}', "");
Expect(0, 11358, '\p{^	_IS_Glagolitic}', "");
Expect(0, 11358, '\P{	_IS_Glagolitic}', "");
Expect(1, 11358, '\P{^	_IS_Glagolitic}', "");
Expect(0, 11359, '\p{	_IS_Glagolitic}', "");
Expect(1, 11359, '\p{^	_IS_Glagolitic}', "");
Expect(1, 11359, '\P{	_IS_Glagolitic}', "");
Expect(0, 11359, '\P{^	_IS_Glagolitic}', "");
Error('\p{/a/_-Glag}');
Error('\P{/a/_-Glag}');
Expect(1, 11358, '\p{glag}', "");
Expect(0, 11358, '\p{^glag}', "");
Expect(0, 11358, '\P{glag}', "");
Expect(1, 11358, '\P{^glag}', "");
Expect(0, 11359, '\p{glag}', "");
Expect(1, 11359, '\p{^glag}', "");
Expect(1, 11359, '\P{glag}', "");
Expect(0, 11359, '\P{^glag}', "");
Expect(1, 11358, '\p{		Glag}', "");
Expect(0, 11358, '\p{^		Glag}', "");
Expect(0, 11358, '\P{		Glag}', "");
Expect(1, 11358, '\P{^		Glag}', "");
Expect(0, 11359, '\p{		Glag}', "");
Expect(1, 11359, '\p{^		Glag}', "");
Expect(1, 11359, '\P{		Glag}', "");
Expect(0, 11359, '\P{^		Glag}', "");
Error('\p{	/a/is_GLAG}');
Error('\P{	/a/is_GLAG}');
Expect(1, 11358, '\p{isglag}', "");
Expect(0, 11358, '\p{^isglag}', "");
Expect(0, 11358, '\P{isglag}', "");
Expect(1, 11358, '\P{^isglag}', "");
Expect(0, 11359, '\p{isglag}', "");
Expect(1, 11359, '\p{^isglag}', "");
Expect(1, 11359, '\P{isglag}', "");
Expect(0, 11359, '\P{^isglag}', "");
Expect(1, 11358, '\p{_ Is_glag}', "");
Expect(0, 11358, '\p{^_ Is_glag}', "");
Expect(0, 11358, '\P{_ Is_glag}', "");
Expect(1, 11358, '\P{^_ Is_glag}', "");
Expect(0, 11359, '\p{_ Is_glag}', "");
Expect(1, 11359, '\p{^_ Is_glag}', "");
Expect(1, 11359, '\P{_ Is_glag}', "");
Expect(0, 11359, '\P{^_ Is_glag}', "");
Error('\p{/a/_	Gothic}');
Error('\P{/a/_	Gothic}');
Expect(1, 66378, '\p{gothic}', "");
Expect(0, 66378, '\p{^gothic}', "");
Expect(0, 66378, '\P{gothic}', "");
Expect(1, 66378, '\P{^gothic}', "");
Expect(0, 66379, '\p{gothic}', "");
Expect(1, 66379, '\p{^gothic}', "");
Expect(1, 66379, '\P{gothic}', "");
Expect(0, 66379, '\P{^gothic}', "");
Expect(1, 66378, '\p{-_GOTHIC}', "");
Expect(0, 66378, '\p{^-_GOTHIC}', "");
Expect(0, 66378, '\P{-_GOTHIC}', "");
Expect(1, 66378, '\P{^-_GOTHIC}', "");
Expect(0, 66379, '\p{-_GOTHIC}', "");
Expect(1, 66379, '\p{^-_GOTHIC}', "");
Expect(1, 66379, '\P{-_GOTHIC}', "");
Expect(0, 66379, '\P{^-_GOTHIC}', "");
Error('\p{/a/_	Is_Gothic}');
Error('\P{/a/_	Is_Gothic}');
Expect(1, 66378, '\p{isgothic}', "");
Expect(0, 66378, '\p{^isgothic}', "");
Expect(0, 66378, '\P{isgothic}', "");
Expect(1, 66378, '\P{^isgothic}', "");
Expect(0, 66379, '\p{isgothic}', "");
Expect(1, 66379, '\p{^isgothic}', "");
Expect(1, 66379, '\P{isgothic}', "");
Expect(0, 66379, '\P{^isgothic}', "");
Expect(1, 66378, '\p{_	Is_GOTHIC}', "");
Expect(0, 66378, '\p{^_	Is_GOTHIC}', "");
Expect(0, 66378, '\P{_	Is_GOTHIC}', "");
Expect(1, 66378, '\P{^_	Is_GOTHIC}', "");
Expect(0, 66379, '\p{_	Is_GOTHIC}', "");
Expect(1, 66379, '\p{^_	Is_GOTHIC}', "");
Expect(1, 66379, '\P{_	Is_GOTHIC}', "");
Expect(0, 66379, '\P{^_	Is_GOTHIC}', "");
Error('\p{:=	Goth}');
Error('\P{:=	Goth}');
Expect(1, 66378, '\p{goth}', "");
Expect(0, 66378, '\p{^goth}', "");
Expect(0, 66378, '\P{goth}', "");
Expect(1, 66378, '\P{^goth}', "");
Expect(0, 66379, '\p{goth}', "");
Expect(1, 66379, '\p{^goth}', "");
Expect(1, 66379, '\P{goth}', "");
Expect(0, 66379, '\P{^goth}', "");
Expect(1, 66378, '\p{-	goth}', "");
Expect(0, 66378, '\p{^-	goth}', "");
Expect(0, 66378, '\P{-	goth}', "");
Expect(1, 66378, '\P{^-	goth}', "");
Expect(0, 66379, '\p{-	goth}', "");
Expect(1, 66379, '\p{^-	goth}', "");
Expect(1, 66379, '\P{-	goth}', "");
Expect(0, 66379, '\P{^-	goth}', "");
Error('\p{:= _Is_Goth}');
Error('\P{:= _Is_Goth}');
Expect(1, 66378, '\p{isgoth}', "");
Expect(0, 66378, '\p{^isgoth}', "");
Expect(0, 66378, '\P{isgoth}', "");
Expect(1, 66378, '\P{^isgoth}', "");
Expect(0, 66379, '\p{isgoth}', "");
Expect(1, 66379, '\p{^isgoth}', "");
Expect(1, 66379, '\P{isgoth}', "");
Expect(0, 66379, '\P{^isgoth}', "");
Expect(1, 66378, '\p{-Is_GOTH}', "");
Expect(0, 66378, '\p{^-Is_GOTH}', "");
Expect(0, 66378, '\P{-Is_GOTH}', "");
Expect(1, 66378, '\P{^-Is_GOTH}', "");
Expect(0, 66379, '\p{-Is_GOTH}', "");
Expect(1, 66379, '\p{^-Is_GOTH}', "");
Expect(1, 66379, '\P{-Is_GOTH}', "");
Expect(0, 66379, '\P{^-Is_GOTH}', "");
Error('\p{:=	-Graph}');
Error('\P{:=	-Graph}');
Expect(1, 1114109, '\p{graph}', "");
Expect(0, 1114109, '\p{^graph}', "");
Expect(0, 1114109, '\P{graph}', "");
Expect(1, 1114109, '\P{^graph}', "");
Expect(0, 918000, '\p{graph}', "");
Expect(1, 918000, '\p{^graph}', "");
Expect(1, 918000, '\P{graph}', "");
Expect(0, 918000, '\P{^graph}', "");
Expect(1, 1114109, '\p{_ GRAPH}', "");
Expect(0, 1114109, '\p{^_ GRAPH}', "");
Expect(0, 1114109, '\P{_ GRAPH}', "");
Expect(1, 1114109, '\P{^_ GRAPH}', "");
Expect(0, 918000, '\p{_ GRAPH}', "");
Expect(1, 918000, '\p{^_ GRAPH}', "");
Expect(1, 918000, '\P{_ GRAPH}', "");
Expect(0, 918000, '\P{^_ GRAPH}', "");
Error('\p{/a/XPosixGraph}');
Error('\P{/a/XPosixGraph}');
Expect(1, 1114109, '\p{xposixgraph}', "");
Expect(0, 1114109, '\p{^xposixgraph}', "");
Expect(0, 1114109, '\P{xposixgraph}', "");
Expect(1, 1114109, '\P{^xposixgraph}', "");
Expect(0, 918000, '\p{xposixgraph}', "");
Expect(1, 918000, '\p{^xposixgraph}', "");
Expect(1, 918000, '\P{xposixgraph}', "");
Expect(0, 918000, '\P{^xposixgraph}', "");
Expect(1, 1114109, '\p{_-XPosixGraph}', "");
Expect(0, 1114109, '\p{^_-XPosixGraph}', "");
Expect(0, 1114109, '\P{_-XPosixGraph}', "");
Expect(1, 1114109, '\P{^_-XPosixGraph}', "");
Expect(0, 918000, '\p{_-XPosixGraph}', "");
Expect(1, 918000, '\p{^_-XPosixGraph}', "");
Expect(1, 918000, '\P{_-XPosixGraph}', "");
Expect(0, 918000, '\P{^_-XPosixGraph}', "");
Error('\p{/a/_ Is_graph}');
Error('\P{/a/_ Is_graph}');
Expect(1, 1114109, '\p{isgraph}', "");
Expect(0, 1114109, '\p{^isgraph}', "");
Expect(0, 1114109, '\P{isgraph}', "");
Expect(1, 1114109, '\P{^isgraph}', "");
Expect(0, 918000, '\p{isgraph}', "");
Expect(1, 918000, '\p{^isgraph}', "");
Expect(1, 918000, '\P{isgraph}', "");
Expect(0, 918000, '\P{^isgraph}', "");
Expect(1, 1114109, '\p{-_Is_GRAPH}', "");
Expect(0, 1114109, '\p{^-_Is_GRAPH}', "");
Expect(0, 1114109, '\P{-_Is_GRAPH}', "");
Expect(1, 1114109, '\P{^-_Is_GRAPH}', "");
Expect(0, 918000, '\p{-_Is_GRAPH}', "");
Expect(1, 918000, '\p{^-_Is_GRAPH}', "");
Expect(1, 918000, '\P{-_Is_GRAPH}', "");
Expect(0, 918000, '\P{^-_Is_GRAPH}', "");
Error('\p{/a/_is_XPosixGraph}');
Error('\P{/a/_is_XPosixGraph}');
Expect(1, 1114109, '\p{isxposixgraph}', "");
Expect(0, 1114109, '\p{^isxposixgraph}', "");
Expect(0, 1114109, '\P{isxposixgraph}', "");
Expect(1, 1114109, '\P{^isxposixgraph}', "");
Expect(0, 918000, '\p{isxposixgraph}', "");
Expect(1, 918000, '\p{^isxposixgraph}', "");
Expect(1, 918000, '\P{isxposixgraph}', "");
Expect(0, 918000, '\P{^isxposixgraph}', "");
Expect(1, 1114109, '\p{- Is_XPosixGraph}', "");
Expect(0, 1114109, '\p{^- Is_XPosixGraph}', "");
Expect(0, 1114109, '\P{- Is_XPosixGraph}', "");
Expect(1, 1114109, '\P{^- Is_XPosixGraph}', "");
Expect(0, 918000, '\p{- Is_XPosixGraph}', "");
Expect(1, 918000, '\p{^- Is_XPosixGraph}', "");
Expect(1, 918000, '\P{- Is_XPosixGraph}', "");
Expect(0, 918000, '\P{^- Is_XPosixGraph}', "");
Error('\p{_:=grapheme_BASE}');
Error('\P{_:=grapheme_BASE}');
Expect(1, 195101, '\p{graphemebase}', "");
Expect(0, 195101, '\p{^graphemebase}', "");
Expect(0, 195101, '\P{graphemebase}', "");
Expect(1, 195101, '\P{^graphemebase}', "");
Expect(0, 195102, '\p{graphemebase}', "");
Expect(1, 195102, '\p{^graphemebase}', "");
Expect(1, 195102, '\P{graphemebase}', "");
Expect(0, 195102, '\P{^graphemebase}', "");
Expect(1, 195101, '\p{	Grapheme_BASE}', "");
Expect(0, 195101, '\p{^	Grapheme_BASE}', "");
Expect(0, 195101, '\P{	Grapheme_BASE}', "");
Expect(1, 195101, '\P{^	Grapheme_BASE}', "");
Expect(0, 195102, '\p{	Grapheme_BASE}', "");
Expect(1, 195102, '\p{^	Grapheme_BASE}', "");
Expect(1, 195102, '\P{	Grapheme_BASE}', "");
Expect(0, 195102, '\P{^	Grapheme_BASE}', "");
Error('\p{_ IS_GRAPHEME_base/a/}');
Error('\P{_ IS_GRAPHEME_base/a/}');
Expect(1, 195101, '\p{isgraphemebase}', "");
Expect(0, 195101, '\p{^isgraphemebase}', "");
Expect(0, 195101, '\P{isgraphemebase}', "");
Expect(1, 195101, '\P{^isgraphemebase}', "");
Expect(0, 195102, '\p{isgraphemebase}', "");
Expect(1, 195102, '\p{^isgraphemebase}', "");
Expect(1, 195102, '\P{isgraphemebase}', "");
Expect(0, 195102, '\P{^isgraphemebase}', "");
Expect(1, 195101, '\p{-	Is_grapheme_BASE}', "");
Expect(0, 195101, '\p{^-	Is_grapheme_BASE}', "");
Expect(0, 195101, '\P{-	Is_grapheme_BASE}', "");
Expect(1, 195101, '\P{^-	Is_grapheme_BASE}', "");
Expect(0, 195102, '\p{-	Is_grapheme_BASE}', "");
Expect(1, 195102, '\p{^-	Is_grapheme_BASE}', "");
Expect(1, 195102, '\P{-	Is_grapheme_BASE}', "");
Expect(0, 195102, '\P{^-	Is_grapheme_BASE}', "");
Error('\p{_:=Gr_Base}');
Error('\P{_:=Gr_Base}');
Expect(1, 195101, '\p{grbase}', "");
Expect(0, 195101, '\p{^grbase}', "");
Expect(0, 195101, '\P{grbase}', "");
Expect(1, 195101, '\P{^grbase}', "");
Expect(0, 195102, '\p{grbase}', "");
Expect(1, 195102, '\p{^grbase}', "");
Expect(1, 195102, '\P{grbase}', "");
Expect(0, 195102, '\P{^grbase}', "");
Expect(1, 195101, '\p{_	Gr_BASE}', "");
Expect(0, 195101, '\p{^_	Gr_BASE}', "");
Expect(0, 195101, '\P{_	Gr_BASE}', "");
Expect(1, 195101, '\P{^_	Gr_BASE}', "");
Expect(0, 195102, '\p{_	Gr_BASE}', "");
Expect(1, 195102, '\p{^_	Gr_BASE}', "");
Expect(1, 195102, '\P{_	Gr_BASE}', "");
Expect(0, 195102, '\P{^_	Gr_BASE}', "");
Error('\p{:=  Is_Gr_Base}');
Error('\P{:=  Is_Gr_Base}');
Expect(1, 195101, '\p{isgrbase}', "");
Expect(0, 195101, '\p{^isgrbase}', "");
Expect(0, 195101, '\P{isgrbase}', "");
Expect(1, 195101, '\P{^isgrbase}', "");
Expect(0, 195102, '\p{isgrbase}', "");
Expect(1, 195102, '\p{^isgrbase}', "");
Expect(1, 195102, '\P{isgrbase}', "");
Expect(0, 195102, '\P{^isgrbase}', "");
Expect(1, 195101, '\p{ Is_GR_Base}', "");
Expect(0, 195101, '\p{^ Is_GR_Base}', "");
Expect(0, 195101, '\P{ Is_GR_Base}', "");
Expect(1, 195101, '\P{^ Is_GR_Base}', "");
Expect(0, 195102, '\p{ Is_GR_Base}', "");
Expect(1, 195102, '\p{^ Is_GR_Base}', "");
Expect(1, 195102, '\P{ Is_GR_Base}', "");
Expect(0, 195102, '\P{^ Is_GR_Base}', "");
Error('\p{/a/-Grapheme_Extend}');
Error('\P{/a/-Grapheme_Extend}');
Expect(1, 917999, '\p{graphemeextend}', "");
Expect(0, 917999, '\p{^graphemeextend}', "");
Expect(0, 917999, '\P{graphemeextend}', "");
Expect(1, 917999, '\P{^graphemeextend}', "");
Expect(0, 918000, '\p{graphemeextend}', "");
Expect(1, 918000, '\p{^graphemeextend}', "");
Expect(1, 918000, '\P{graphemeextend}', "");
Expect(0, 918000, '\P{^graphemeextend}', "");
Expect(1, 917999, '\p{_GRAPHEME_Extend}', "");
Expect(0, 917999, '\p{^_GRAPHEME_Extend}', "");
Expect(0, 917999, '\P{_GRAPHEME_Extend}', "");
Expect(1, 917999, '\P{^_GRAPHEME_Extend}', "");
Expect(0, 918000, '\p{_GRAPHEME_Extend}', "");
Expect(1, 918000, '\p{^_GRAPHEME_Extend}', "");
Expect(1, 918000, '\P{_GRAPHEME_Extend}', "");
Expect(0, 918000, '\P{^_GRAPHEME_Extend}', "");
Error('\p{ :=is_grapheme_EXTEND}');
Error('\P{ :=is_grapheme_EXTEND}');
Expect(1, 917999, '\p{isgraphemeextend}', "");
Expect(0, 917999, '\p{^isgraphemeextend}', "");
Expect(0, 917999, '\P{isgraphemeextend}', "");
Expect(1, 917999, '\P{^isgraphemeextend}', "");
Expect(0, 918000, '\p{isgraphemeextend}', "");
Expect(1, 918000, '\p{^isgraphemeextend}', "");
Expect(1, 918000, '\P{isgraphemeextend}', "");
Expect(0, 918000, '\P{^isgraphemeextend}', "");
Expect(1, 917999, '\p{	Is_Grapheme_Extend}', "");
Expect(0, 917999, '\p{^	Is_Grapheme_Extend}', "");
Expect(0, 917999, '\P{	Is_Grapheme_Extend}', "");
Expect(1, 917999, '\P{^	Is_Grapheme_Extend}', "");
Expect(0, 918000, '\p{	Is_Grapheme_Extend}', "");
Expect(1, 918000, '\p{^	Is_Grapheme_Extend}', "");
Expect(1, 918000, '\P{	Is_Grapheme_Extend}', "");
Expect(0, 918000, '\P{^	Is_Grapheme_Extend}', "");
Error('\p{ :=Gr_Ext}');
Error('\P{ :=Gr_Ext}');
Expect(1, 917999, '\p{grext}', "");
Expect(0, 917999, '\p{^grext}', "");
Expect(0, 917999, '\P{grext}', "");
Expect(1, 917999, '\P{^grext}', "");
Expect(0, 918000, '\p{grext}', "");
Expect(1, 918000, '\p{^grext}', "");
Expect(1, 918000, '\P{grext}', "");
Expect(0, 918000, '\P{^grext}', "");
Expect(1, 917999, '\p{_Gr_Ext}', "");
Expect(0, 917999, '\p{^_Gr_Ext}', "");
Expect(0, 917999, '\P{_Gr_Ext}', "");
Expect(1, 917999, '\P{^_Gr_Ext}', "");
Expect(0, 918000, '\p{_Gr_Ext}', "");
Expect(1, 918000, '\p{^_Gr_Ext}', "");
Expect(1, 918000, '\P{_Gr_Ext}', "");
Expect(0, 918000, '\P{^_Gr_Ext}', "");
Error('\p{:= -Is_Gr_Ext}');
Error('\P{:= -Is_Gr_Ext}');
Expect(1, 917999, '\p{isgrext}', "");
Expect(0, 917999, '\p{^isgrext}', "");
Expect(0, 917999, '\P{isgrext}', "");
Expect(1, 917999, '\P{^isgrext}', "");
Expect(0, 918000, '\p{isgrext}', "");
Expect(1, 918000, '\p{^isgrext}', "");
Expect(1, 918000, '\P{isgrext}', "");
Expect(0, 918000, '\P{^isgrext}', "");
Expect(1, 917999, '\p{_is_gr_Ext}', "");
Expect(0, 917999, '\p{^_is_gr_Ext}', "");
Expect(0, 917999, '\P{_is_gr_Ext}', "");
Expect(1, 917999, '\P{^_is_gr_Ext}', "");
Expect(0, 918000, '\p{_is_gr_Ext}', "");
Expect(1, 918000, '\p{^_is_gr_Ext}', "");
Expect(1, 918000, '\P{_is_gr_Ext}', "");
Expect(0, 918000, '\P{^_is_gr_Ext}', "");
Error('\p{Grapheme_Link}');
Error('\P{Grapheme_Link}');
Error('\p{Is_Grapheme_Link}');
Error('\P{Is_Grapheme_Link}');
Error('\p{Gr_Link}');
Error('\P{Gr_Link}');
Error('\p{Is_Gr_Link}');
Error('\P{Is_Gr_Link}');
Error('\p{  GREEK:=}');
Error('\P{  GREEK:=}');
Expect(1, 119365, '\p{greek}', "");
Expect(0, 119365, '\p{^greek}', "");
Expect(0, 119365, '\P{greek}', "");
Expect(1, 119365, '\P{^greek}', "");
Expect(0, 119366, '\p{greek}', "");
Expect(1, 119366, '\p{^greek}', "");
Expect(1, 119366, '\P{greek}', "");
Expect(0, 119366, '\P{^greek}', "");
Expect(1, 119365, '\p{-Greek}', "");
Expect(0, 119365, '\p{^-Greek}', "");
Expect(0, 119365, '\P{-Greek}', "");
Expect(1, 119365, '\P{^-Greek}', "");
Expect(0, 119366, '\p{-Greek}', "");
Expect(1, 119366, '\p{^-Greek}', "");
Expect(1, 119366, '\P{-Greek}', "");
Expect(0, 119366, '\P{^-Greek}', "");
Error('\p{	 IS_GREEK/a/}');
Error('\P{	 IS_GREEK/a/}');
Expect(1, 119365, '\p{isgreek}', "");
Expect(0, 119365, '\p{^isgreek}', "");
Expect(0, 119365, '\P{isgreek}', "");
Expect(1, 119365, '\P{^isgreek}', "");
Expect(0, 119366, '\p{isgreek}', "");
Expect(1, 119366, '\p{^isgreek}', "");
Expect(1, 119366, '\P{isgreek}', "");
Expect(0, 119366, '\P{^isgreek}', "");
Expect(1, 119365, '\p{	Is_Greek}', "");
Expect(0, 119365, '\p{^	Is_Greek}', "");
Expect(0, 119365, '\P{	Is_Greek}', "");
Expect(1, 119365, '\P{^	Is_Greek}', "");
Expect(0, 119366, '\p{	Is_Greek}', "");
Expect(1, 119366, '\p{^	Is_Greek}', "");
Expect(1, 119366, '\P{	Is_Greek}', "");
Expect(0, 119366, '\P{^	Is_Greek}', "");
Error('\p{-/a/Grek}');
Error('\P{-/a/Grek}');
Expect(1, 119365, '\p{grek}', "");
Expect(0, 119365, '\p{^grek}', "");
Expect(0, 119365, '\P{grek}', "");
Expect(1, 119365, '\P{^grek}', "");
Expect(0, 119366, '\p{grek}', "");
Expect(1, 119366, '\p{^grek}', "");
Expect(1, 119366, '\P{grek}', "");
Expect(0, 119366, '\P{^grek}', "");
Expect(1, 119365, '\p{-grek}', "");
Expect(0, 119365, '\p{^-grek}', "");
Expect(0, 119365, '\P{-grek}', "");
Expect(1, 119365, '\P{^-grek}', "");
Expect(0, 119366, '\p{-grek}', "");
Expect(1, 119366, '\p{^-grek}', "");
Expect(1, 119366, '\P{-grek}', "");
Expect(0, 119366, '\P{^-grek}', "");
Error('\p{ _Is_Grek:=}');
Error('\P{ _Is_Grek:=}');
Expect(1, 119365, '\p{isgrek}', "");
Expect(0, 119365, '\p{^isgrek}', "");
Expect(0, 119365, '\P{isgrek}', "");
Expect(1, 119365, '\P{^isgrek}', "");
Expect(0, 119366, '\p{isgrek}', "");
Expect(1, 119366, '\p{^isgrek}', "");
Expect(1, 119366, '\P{isgrek}', "");
Expect(0, 119366, '\P{^isgrek}', "");
Expect(1, 119365, '\p{-Is_grek}', "");
Expect(0, 119365, '\p{^-Is_grek}', "");
Expect(0, 119365, '\P{-Is_grek}', "");
Expect(1, 119365, '\P{^-Is_grek}', "");
Expect(0, 119366, '\p{-Is_grek}', "");
Expect(1, 119366, '\p{^-Is_grek}', "");
Expect(1, 119366, '\P{-Is_grek}', "");
Expect(0, 119366, '\P{^-Is_grek}', "");
Error('\p{ /a/Greek_And_coptic}');
Error('\P{ /a/Greek_And_coptic}');
Expect(1, 1023, '\p{greekandcoptic}', "");
Expect(0, 1023, '\p{^greekandcoptic}', "");
Expect(0, 1023, '\P{greekandcoptic}', "");
Expect(1, 1023, '\P{^greekandcoptic}', "");
Expect(0, 1024, '\p{greekandcoptic}', "");
Expect(1, 1024, '\p{^greekandcoptic}', "");
Expect(1, 1024, '\P{greekandcoptic}', "");
Expect(0, 1024, '\P{^greekandcoptic}', "");
Expect(1, 1023, '\p{-_Greek_And_Coptic}', "");
Expect(0, 1023, '\p{^-_Greek_And_Coptic}', "");
Expect(0, 1023, '\P{-_Greek_And_Coptic}', "");
Expect(1, 1023, '\P{^-_Greek_And_Coptic}', "");
Expect(0, 1024, '\p{-_Greek_And_Coptic}', "");
Expect(1, 1024, '\p{^-_Greek_And_Coptic}', "");
Expect(1, 1024, '\P{-_Greek_And_Coptic}', "");
Expect(0, 1024, '\P{^-_Greek_And_Coptic}', "");
Error('\p{_:=is_Greek_AND_coptic}');
Error('\P{_:=is_Greek_AND_coptic}');
Expect(1, 1023, '\p{isgreekandcoptic}', "");
Expect(0, 1023, '\p{^isgreekandcoptic}', "");
Expect(0, 1023, '\P{isgreekandcoptic}', "");
Expect(1, 1023, '\P{^isgreekandcoptic}', "");
Expect(0, 1024, '\p{isgreekandcoptic}', "");
Expect(1, 1024, '\p{^isgreekandcoptic}', "");
Expect(1, 1024, '\P{isgreekandcoptic}', "");
Expect(0, 1024, '\P{^isgreekandcoptic}', "");
Expect(1, 1023, '\p{		Is_greek_and_Coptic}', "");
Expect(0, 1023, '\p{^		Is_greek_and_Coptic}', "");
Expect(0, 1023, '\P{		Is_greek_and_Coptic}', "");
Expect(1, 1023, '\P{^		Is_greek_and_Coptic}', "");
Expect(0, 1024, '\p{		Is_greek_and_Coptic}', "");
Expect(1, 1024, '\p{^		Is_greek_and_Coptic}', "");
Expect(1, 1024, '\P{		Is_greek_and_Coptic}', "");
Expect(0, 1024, '\P{^		Is_greek_and_Coptic}', "");
Error('\p{__In_GREEK_AND_Coptic:=}');
Error('\P{__In_GREEK_AND_Coptic:=}');
Expect(1, 1023, '\p{ingreekandcoptic}', "");
Expect(0, 1023, '\p{^ingreekandcoptic}', "");
Expect(0, 1023, '\P{ingreekandcoptic}', "");
Expect(1, 1023, '\P{^ingreekandcoptic}', "");
Expect(0, 1024, '\p{ingreekandcoptic}', "");
Expect(1, 1024, '\p{^ingreekandcoptic}', "");
Expect(1, 1024, '\P{ingreekandcoptic}', "");
Expect(0, 1024, '\P{^ingreekandcoptic}', "");
Expect(1, 1023, '\p{ -IN_GREEK_And_Coptic}', "");
Expect(0, 1023, '\p{^ -IN_GREEK_And_Coptic}', "");
Expect(0, 1023, '\P{ -IN_GREEK_And_Coptic}', "");
Expect(1, 1023, '\P{^ -IN_GREEK_And_Coptic}', "");
Expect(0, 1024, '\p{ -IN_GREEK_And_Coptic}', "");
Expect(1, 1024, '\p{^ -IN_GREEK_And_Coptic}', "");
Expect(1, 1024, '\P{ -IN_GREEK_And_Coptic}', "");
Expect(0, 1024, '\P{^ -IN_GREEK_And_Coptic}', "");
Error('\p{in_GREEK/a/}');
Error('\P{in_GREEK/a/}');
Expect(1, 1023, '\p{ingreek}', "");
Expect(0, 1023, '\p{^ingreek}', "");
Expect(0, 1023, '\P{ingreek}', "");
Expect(1, 1023, '\P{^ingreek}', "");
Expect(0, 1024, '\p{ingreek}', "");
Expect(1, 1024, '\p{^ingreek}', "");
Expect(1, 1024, '\P{ingreek}', "");
Expect(0, 1024, '\P{^ingreek}', "");
Expect(1, 1023, '\p{-In_GREEK}', "");
Expect(0, 1023, '\p{^-In_GREEK}', "");
Expect(0, 1023, '\P{-In_GREEK}', "");
Expect(1, 1023, '\P{^-In_GREEK}', "");
Expect(0, 1024, '\p{-In_GREEK}', "");
Expect(1, 1024, '\p{^-In_GREEK}', "");
Expect(1, 1024, '\P{-In_GREEK}', "");
Expect(0, 1024, '\P{^-In_GREEK}', "");
Error('\p{/a/_-greek_extended}');
Error('\P{/a/_-greek_extended}');
Expect(1, 8191, '\p{greekextended}', "");
Expect(0, 8191, '\p{^greekextended}', "");
Expect(0, 8191, '\P{greekextended}', "");
Expect(1, 8191, '\P{^greekextended}', "");
Expect(0, 8192, '\p{greekextended}', "");
Expect(1, 8192, '\p{^greekextended}', "");
Expect(1, 8192, '\P{greekextended}', "");
Expect(0, 8192, '\P{^greekextended}', "");
Expect(1, 8191, '\p{-Greek_Extended}', "");
Expect(0, 8191, '\p{^-Greek_Extended}', "");
Expect(0, 8191, '\P{-Greek_Extended}', "");
Expect(1, 8191, '\P{^-Greek_Extended}', "");
Expect(0, 8192, '\p{-Greek_Extended}', "");
Expect(1, 8192, '\p{^-Greek_Extended}', "");
Expect(1, 8192, '\P{-Greek_Extended}', "");
Expect(0, 8192, '\P{^-Greek_Extended}', "");
Error('\p{:=-Is_greek_Extended}');
Error('\P{:=-Is_greek_Extended}');
Expect(1, 8191, '\p{isgreekextended}', "");
Expect(0, 8191, '\p{^isgreekextended}', "");
Expect(0, 8191, '\P{isgreekextended}', "");
Expect(1, 8191, '\P{^isgreekextended}', "");
Expect(0, 8192, '\p{isgreekextended}', "");
Expect(1, 8192, '\p{^isgreekextended}', "");
Expect(1, 8192, '\P{isgreekextended}', "");
Expect(0, 8192, '\P{^isgreekextended}', "");
Expect(1, 8191, '\p{_is_GREEK_Extended}', "");
Expect(0, 8191, '\p{^_is_GREEK_Extended}', "");
Expect(0, 8191, '\P{_is_GREEK_Extended}', "");
Expect(1, 8191, '\P{^_is_GREEK_Extended}', "");
Expect(0, 8192, '\p{_is_GREEK_Extended}', "");
Expect(1, 8192, '\p{^_is_GREEK_Extended}', "");
Expect(1, 8192, '\P{_is_GREEK_Extended}', "");
Expect(0, 8192, '\P{^_is_GREEK_Extended}', "");
Error('\p{:=- in_Greek_extended}');
Error('\P{:=- in_Greek_extended}');
Expect(1, 8191, '\p{ingreekextended}', "");
Expect(0, 8191, '\p{^ingreekextended}', "");
Expect(0, 8191, '\P{ingreekextended}', "");
Expect(1, 8191, '\P{^ingreekextended}', "");
Expect(0, 8192, '\p{ingreekextended}', "");
Expect(1, 8192, '\p{^ingreekextended}', "");
Expect(1, 8192, '\P{ingreekextended}', "");
Expect(0, 8192, '\P{^ingreekextended}', "");
Expect(1, 8191, '\p{_in_greek_EXTENDED}', "");
Expect(0, 8191, '\p{^_in_greek_EXTENDED}', "");
Expect(0, 8191, '\P{_in_greek_EXTENDED}', "");
Expect(1, 8191, '\P{^_in_greek_EXTENDED}', "");
Expect(0, 8192, '\p{_in_greek_EXTENDED}', "");
Expect(1, 8192, '\p{^_in_greek_EXTENDED}', "");
Expect(1, 8192, '\P{_in_greek_EXTENDED}', "");
Expect(0, 8192, '\P{^_in_greek_EXTENDED}', "");
Error('\p{:=__Greek_Ext}');
Error('\P{:=__Greek_Ext}');
Expect(1, 8191, '\p{greekext}', "");
Expect(0, 8191, '\p{^greekext}', "");
Expect(0, 8191, '\P{greekext}', "");
Expect(1, 8191, '\P{^greekext}', "");
Expect(0, 8192, '\p{greekext}', "");
Expect(1, 8192, '\p{^greekext}', "");
Expect(1, 8192, '\P{greekext}', "");
Expect(0, 8192, '\P{^greekext}', "");
Expect(1, 8191, '\p{__Greek_Ext}', "");
Expect(0, 8191, '\p{^__Greek_Ext}', "");
Expect(0, 8191, '\P{__Greek_Ext}', "");
Expect(1, 8191, '\P{^__Greek_Ext}', "");
Expect(0, 8192, '\p{__Greek_Ext}', "");
Expect(1, 8192, '\p{^__Greek_Ext}', "");
Expect(1, 8192, '\P{__Greek_Ext}', "");
Expect(0, 8192, '\P{^__Greek_Ext}', "");
Error('\p{ :=Is_greek_ext}');
Error('\P{ :=Is_greek_ext}');
Expect(1, 8191, '\p{isgreekext}', "");
Expect(0, 8191, '\p{^isgreekext}', "");
Expect(0, 8191, '\P{isgreekext}', "");
Expect(1, 8191, '\P{^isgreekext}', "");
Expect(0, 8192, '\p{isgreekext}', "");
Expect(1, 8192, '\p{^isgreekext}', "");
Expect(1, 8192, '\P{isgreekext}', "");
Expect(0, 8192, '\P{^isgreekext}', "");
Expect(1, 8191, '\p{ -is_GREEK_Ext}', "");
Expect(0, 8191, '\p{^ -is_GREEK_Ext}', "");
Expect(0, 8191, '\P{ -is_GREEK_Ext}', "");
Expect(1, 8191, '\P{^ -is_GREEK_Ext}', "");
Expect(0, 8192, '\p{ -is_GREEK_Ext}', "");
Expect(1, 8192, '\p{^ -is_GREEK_Ext}', "");
Expect(1, 8192, '\P{ -is_GREEK_Ext}', "");
Expect(0, 8192, '\P{^ -is_GREEK_Ext}', "");
Error('\p{ :=In_Greek_ext}');
Error('\P{ :=In_Greek_ext}');
Expect(1, 8191, '\p{ingreekext}', "");
Expect(0, 8191, '\p{^ingreekext}', "");
Expect(0, 8191, '\P{ingreekext}', "");
Expect(1, 8191, '\P{^ingreekext}', "");
Expect(0, 8192, '\p{ingreekext}', "");
Expect(1, 8192, '\p{^ingreekext}', "");
Expect(1, 8192, '\P{ingreekext}', "");
Expect(0, 8192, '\P{^ingreekext}', "");
Expect(1, 8191, '\p{_-IN_Greek_Ext}', "");
Expect(0, 8191, '\p{^_-IN_Greek_Ext}', "");
Expect(0, 8191, '\P{_-IN_Greek_Ext}', "");
Expect(1, 8191, '\P{^_-IN_Greek_Ext}', "");
Expect(0, 8192, '\p{_-IN_Greek_Ext}', "");
Expect(1, 8192, '\p{^_-IN_Greek_Ext}', "");
Expect(1, 8192, '\P{_-IN_Greek_Ext}', "");
Expect(0, 8192, '\P{^_-IN_Greek_Ext}', "");
Error('\p{-:=GUJARATI}');
Error('\P{-:=GUJARATI}');
Expect(1, 2801, '\p{gujarati}', "");
Expect(0, 2801, '\p{^gujarati}', "");
Expect(0, 2801, '\P{gujarati}', "");
Expect(1, 2801, '\P{^gujarati}', "");
Expect(0, 2802, '\p{gujarati}', "");
Expect(1, 2802, '\p{^gujarati}', "");
Expect(1, 2802, '\P{gujarati}', "");
Expect(0, 2802, '\P{^gujarati}', "");
Expect(1, 2801, '\p{_ gujarati}', "");
Expect(0, 2801, '\p{^_ gujarati}', "");
Expect(0, 2801, '\P{_ gujarati}', "");
Expect(1, 2801, '\P{^_ gujarati}', "");
Expect(0, 2802, '\p{_ gujarati}', "");
Expect(1, 2802, '\p{^_ gujarati}', "");
Expect(1, 2802, '\P{_ gujarati}', "");
Expect(0, 2802, '\P{^_ gujarati}', "");
Error('\p{:=	 Is_GUJARATI}');
Error('\P{:=	 Is_GUJARATI}');
Expect(1, 2801, '\p{isgujarati}', "");
Expect(0, 2801, '\p{^isgujarati}', "");
Expect(0, 2801, '\P{isgujarati}', "");
Expect(1, 2801, '\P{^isgujarati}', "");
Expect(0, 2802, '\p{isgujarati}', "");
Expect(1, 2802, '\p{^isgujarati}', "");
Expect(1, 2802, '\P{isgujarati}', "");
Expect(0, 2802, '\P{^isgujarati}', "");
Expect(1, 2801, '\p{_-IS_GUJARATI}', "");
Expect(0, 2801, '\p{^_-IS_GUJARATI}', "");
Expect(0, 2801, '\P{_-IS_GUJARATI}', "");
Expect(1, 2801, '\P{^_-IS_GUJARATI}', "");
Expect(0, 2802, '\p{_-IS_GUJARATI}', "");
Expect(1, 2802, '\p{^_-IS_GUJARATI}', "");
Expect(1, 2802, '\P{_-IS_GUJARATI}', "");
Expect(0, 2802, '\P{^_-IS_GUJARATI}', "");
Error('\p{:=	-GUJR}');
Error('\P{:=	-GUJR}');
Expect(1, 2801, '\p{gujr}', "");
Expect(0, 2801, '\p{^gujr}', "");
Expect(0, 2801, '\P{gujr}', "");
Expect(1, 2801, '\P{^gujr}', "");
Expect(0, 2802, '\p{gujr}', "");
Expect(1, 2802, '\p{^gujr}', "");
Expect(1, 2802, '\P{gujr}', "");
Expect(0, 2802, '\P{^gujr}', "");
Expect(1, 2801, '\p{  gujr}', "");
Expect(0, 2801, '\p{^  gujr}', "");
Expect(0, 2801, '\P{  gujr}', "");
Expect(1, 2801, '\P{^  gujr}', "");
Expect(0, 2802, '\p{  gujr}', "");
Expect(1, 2802, '\p{^  gujr}', "");
Expect(1, 2802, '\P{  gujr}', "");
Expect(0, 2802, '\P{^  gujr}', "");
Error('\p{:=		IS_GUJR}');
Error('\P{:=		IS_GUJR}');
Expect(1, 2801, '\p{isgujr}', "");
Expect(0, 2801, '\p{^isgujr}', "");
Expect(0, 2801, '\P{isgujr}', "");
Expect(1, 2801, '\P{^isgujr}', "");
Expect(0, 2802, '\p{isgujr}', "");
Expect(1, 2802, '\p{^isgujr}', "");
Expect(1, 2802, '\P{isgujr}', "");
Expect(0, 2802, '\P{^isgujr}', "");
Expect(1, 2801, '\p{--Is_gujr}', "");
Expect(0, 2801, '\p{^--Is_gujr}', "");
Expect(0, 2801, '\P{--Is_gujr}', "");
Expect(1, 2801, '\P{^--Is_gujr}', "");
Expect(0, 2802, '\p{--Is_gujr}', "");
Expect(1, 2802, '\p{^--Is_gujr}', "");
Expect(1, 2802, '\P{--Is_gujr}', "");
Expect(0, 2802, '\P{^--Is_gujr}', "");
Error('\p{/a/_ Gurmukhi}');
Error('\P{/a/_ Gurmukhi}');
Expect(1, 2677, '\p{gurmukhi}', "");
Expect(0, 2677, '\p{^gurmukhi}', "");
Expect(0, 2677, '\P{gurmukhi}', "");
Expect(1, 2677, '\P{^gurmukhi}', "");
Expect(0, 2678, '\p{gurmukhi}', "");
Expect(1, 2678, '\p{^gurmukhi}', "");
Expect(1, 2678, '\P{gurmukhi}', "");
Expect(0, 2678, '\P{^gurmukhi}', "");
Expect(1, 2677, '\p{--GURMUKHI}', "");
Expect(0, 2677, '\p{^--GURMUKHI}', "");
Expect(0, 2677, '\P{--GURMUKHI}', "");
Expect(1, 2677, '\P{^--GURMUKHI}', "");
Expect(0, 2678, '\p{--GURMUKHI}', "");
Expect(1, 2678, '\p{^--GURMUKHI}', "");
Expect(1, 2678, '\P{--GURMUKHI}', "");
Expect(0, 2678, '\P{^--GURMUKHI}', "");
Error('\p{-Is_gurmukhi:=}');
Error('\P{-Is_gurmukhi:=}');
Expect(1, 2677, '\p{isgurmukhi}', "");
Expect(0, 2677, '\p{^isgurmukhi}', "");
Expect(0, 2677, '\P{isgurmukhi}', "");
Expect(1, 2677, '\P{^isgurmukhi}', "");
Expect(0, 2678, '\p{isgurmukhi}', "");
Expect(1, 2678, '\p{^isgurmukhi}', "");
Expect(1, 2678, '\P{isgurmukhi}', "");
Expect(0, 2678, '\P{^isgurmukhi}', "");
Expect(1, 2677, '\p{- is_GURMUKHI}', "");
Expect(0, 2677, '\p{^- is_GURMUKHI}', "");
Expect(0, 2677, '\P{- is_GURMUKHI}', "");
Expect(1, 2677, '\P{^- is_GURMUKHI}', "");
Expect(0, 2678, '\p{- is_GURMUKHI}', "");
Expect(1, 2678, '\p{^- is_GURMUKHI}', "");
Expect(1, 2678, '\P{- is_GURMUKHI}', "");
Expect(0, 2678, '\P{^- is_GURMUKHI}', "");
Error('\p{/a/ 	Guru}');
Error('\P{/a/ 	Guru}');
Expect(1, 2677, '\p{guru}', "");
Expect(0, 2677, '\p{^guru}', "");
Expect(0, 2677, '\P{guru}', "");
Expect(1, 2677, '\P{^guru}', "");
Expect(0, 2678, '\p{guru}', "");
Expect(1, 2678, '\p{^guru}', "");
Expect(1, 2678, '\P{guru}', "");
Expect(0, 2678, '\P{^guru}', "");
Expect(1, 2677, '\p{_ guru}', "");
Expect(0, 2677, '\p{^_ guru}', "");
Expect(0, 2677, '\P{_ guru}', "");
Expect(1, 2677, '\P{^_ guru}', "");
Expect(0, 2678, '\p{_ guru}', "");
Expect(1, 2678, '\p{^_ guru}', "");
Expect(1, 2678, '\P{_ guru}', "");
Expect(0, 2678, '\P{^_ guru}', "");
Error('\p{/a/ -Is_Guru}');
Error('\P{/a/ -Is_Guru}');
Expect(1, 2677, '\p{isguru}', "");
Expect(0, 2677, '\p{^isguru}', "");
Expect(0, 2677, '\P{isguru}', "");
Expect(1, 2677, '\P{^isguru}', "");
Expect(0, 2678, '\p{isguru}', "");
Expect(1, 2678, '\p{^isguru}', "");
Expect(1, 2678, '\P{isguru}', "");
Expect(0, 2678, '\P{^isguru}', "");
Expect(1, 2677, '\p{ Is_guru}', "");
Expect(0, 2677, '\p{^ Is_guru}', "");
Expect(0, 2677, '\P{ Is_guru}', "");
Expect(1, 2677, '\P{^ Is_guru}', "");
Expect(0, 2678, '\p{ Is_guru}', "");
Expect(1, 2678, '\p{^ Is_guru}', "");
Expect(1, 2678, '\P{ Is_guru}', "");
Expect(0, 2678, '\P{^ Is_guru}', "");
Error('\p{  HALFWIDTH_And_Fullwidth_Forms/a/}');
Error('\P{  HALFWIDTH_And_Fullwidth_Forms/a/}');
Expect(1, 65519, '\p{halfwidthandfullwidthforms}', "");
Expect(0, 65519, '\p{^halfwidthandfullwidthforms}', "");
Expect(0, 65519, '\P{halfwidthandfullwidthforms}', "");
Expect(1, 65519, '\P{^halfwidthandfullwidthforms}', "");
Expect(0, 65520, '\p{halfwidthandfullwidthforms}', "");
Expect(1, 65520, '\p{^halfwidthandfullwidthforms}', "");
Expect(1, 65520, '\P{halfwidthandfullwidthforms}', "");
Expect(0, 65520, '\P{^halfwidthandfullwidthforms}', "");
Expect(1, 65519, '\p{		HALFWIDTH_And_fullwidth_Forms}', "");
Expect(0, 65519, '\p{^		HALFWIDTH_And_fullwidth_Forms}', "");
Expect(0, 65519, '\P{		HALFWIDTH_And_fullwidth_Forms}', "");
Expect(1, 65519, '\P{^		HALFWIDTH_And_fullwidth_Forms}', "");
Expect(0, 65520, '\p{		HALFWIDTH_And_fullwidth_Forms}', "");
Expect(1, 65520, '\p{^		HALFWIDTH_And_fullwidth_Forms}', "");
Expect(1, 65520, '\P{		HALFWIDTH_And_fullwidth_Forms}', "");
Expect(0, 65520, '\P{^		HALFWIDTH_And_fullwidth_Forms}', "");
Error('\p{/a/-is_Halfwidth_And_FULLWIDTH_FORMS}');
Error('\P{/a/-is_Halfwidth_And_FULLWIDTH_FORMS}');
Expect(1, 65519, '\p{ishalfwidthandfullwidthforms}', "");
Expect(0, 65519, '\p{^ishalfwidthandfullwidthforms}', "");
Expect(0, 65519, '\P{ishalfwidthandfullwidthforms}', "");
Expect(1, 65519, '\P{^ishalfwidthandfullwidthforms}', "");
Expect(0, 65520, '\p{ishalfwidthandfullwidthforms}', "");
Expect(1, 65520, '\p{^ishalfwidthandfullwidthforms}', "");
Expect(1, 65520, '\P{ishalfwidthandfullwidthforms}', "");
Expect(0, 65520, '\P{^ishalfwidthandfullwidthforms}', "");
Expect(1, 65519, '\p{_	is_Halfwidth_AND_fullwidth_Forms}', "");
Expect(0, 65519, '\p{^_	is_Halfwidth_AND_fullwidth_Forms}', "");
Expect(0, 65519, '\P{_	is_Halfwidth_AND_fullwidth_Forms}', "");
Expect(1, 65519, '\P{^_	is_Halfwidth_AND_fullwidth_Forms}', "");
Expect(0, 65520, '\p{_	is_Halfwidth_AND_fullwidth_Forms}', "");
Expect(1, 65520, '\p{^_	is_Halfwidth_AND_fullwidth_Forms}', "");
Expect(1, 65520, '\P{_	is_Halfwidth_AND_fullwidth_Forms}', "");
Expect(0, 65520, '\P{^_	is_Halfwidth_AND_fullwidth_Forms}', "");
Error('\p{:=		In_HALFWIDTH_and_FULLWIDTH_forms}');
Error('\P{:=		In_HALFWIDTH_and_FULLWIDTH_forms}');
Expect(1, 65519, '\p{inhalfwidthandfullwidthforms}', "");
Expect(0, 65519, '\p{^inhalfwidthandfullwidthforms}', "");
Expect(0, 65519, '\P{inhalfwidthandfullwidthforms}', "");
Expect(1, 65519, '\P{^inhalfwidthandfullwidthforms}', "");
Expect(0, 65520, '\p{inhalfwidthandfullwidthforms}', "");
Expect(1, 65520, '\p{^inhalfwidthandfullwidthforms}', "");
Expect(1, 65520, '\P{inhalfwidthandfullwidthforms}', "");
Expect(0, 65520, '\P{^inhalfwidthandfullwidthforms}', "");
Expect(1, 65519, '\p{_ In_halfwidth_And_Fullwidth_FORMS}', "");
Expect(0, 65519, '\p{^_ In_halfwidth_And_Fullwidth_FORMS}', "");
Expect(0, 65519, '\P{_ In_halfwidth_And_Fullwidth_FORMS}', "");
Expect(1, 65519, '\P{^_ In_halfwidth_And_Fullwidth_FORMS}', "");
Expect(0, 65520, '\p{_ In_halfwidth_And_Fullwidth_FORMS}', "");
Expect(1, 65520, '\p{^_ In_halfwidth_And_Fullwidth_FORMS}', "");
Expect(1, 65520, '\P{_ In_halfwidth_And_Fullwidth_FORMS}', "");
Expect(0, 65520, '\P{^_ In_halfwidth_And_Fullwidth_FORMS}', "");
Error('\p{ half_AND_full_FORMS/a/}');
Error('\P{ half_AND_full_FORMS/a/}');
Expect(1, 65519, '\p{halfandfullforms}', "");
Expect(0, 65519, '\p{^halfandfullforms}', "");
Expect(0, 65519, '\P{halfandfullforms}', "");
Expect(1, 65519, '\P{^halfandfullforms}', "");
Expect(0, 65520, '\p{halfandfullforms}', "");
Expect(1, 65520, '\p{^halfandfullforms}', "");
Expect(1, 65520, '\P{halfandfullforms}', "");
Expect(0, 65520, '\P{^halfandfullforms}', "");
Expect(1, 65519, '\p{_ half_AND_full_Forms}', "");
Expect(0, 65519, '\p{^_ half_AND_full_Forms}', "");
Expect(0, 65519, '\P{_ half_AND_full_Forms}', "");
Expect(1, 65519, '\P{^_ half_AND_full_Forms}', "");
Expect(0, 65520, '\p{_ half_AND_full_Forms}', "");
Expect(1, 65520, '\p{^_ half_AND_full_Forms}', "");
Expect(1, 65520, '\P{_ half_AND_full_Forms}', "");
Expect(0, 65520, '\P{^_ half_AND_full_Forms}', "");
Error('\p{/a/-	Is_HALF_And_Full_Forms}');
Error('\P{/a/-	Is_HALF_And_Full_Forms}');
Expect(1, 65519, '\p{ishalfandfullforms}', "");
Expect(0, 65519, '\p{^ishalfandfullforms}', "");
Expect(0, 65519, '\P{ishalfandfullforms}', "");
Expect(1, 65519, '\P{^ishalfandfullforms}', "");
Expect(0, 65520, '\p{ishalfandfullforms}', "");
Expect(1, 65520, '\p{^ishalfandfullforms}', "");
Expect(1, 65520, '\P{ishalfandfullforms}', "");
Expect(0, 65520, '\P{^ishalfandfullforms}', "");
Expect(1, 65519, '\p{-	IS_Half_And_full_Forms}', "");
Expect(0, 65519, '\p{^-	IS_Half_And_full_Forms}', "");
Expect(0, 65519, '\P{-	IS_Half_And_full_Forms}', "");
Expect(1, 65519, '\P{^-	IS_Half_And_full_Forms}', "");
Expect(0, 65520, '\p{-	IS_Half_And_full_Forms}', "");
Expect(1, 65520, '\p{^-	IS_Half_And_full_Forms}', "");
Expect(1, 65520, '\P{-	IS_Half_And_full_Forms}', "");
Expect(0, 65520, '\P{^-	IS_Half_And_full_Forms}', "");
Error('\p{- In_Half_AND_Full_Forms:=}');
Error('\P{- In_Half_AND_Full_Forms:=}');
Expect(1, 65519, '\p{inhalfandfullforms}', "");
Expect(0, 65519, '\p{^inhalfandfullforms}', "");
Expect(0, 65519, '\P{inhalfandfullforms}', "");
Expect(1, 65519, '\P{^inhalfandfullforms}', "");
Expect(0, 65520, '\p{inhalfandfullforms}', "");
Expect(1, 65520, '\p{^inhalfandfullforms}', "");
Expect(1, 65520, '\P{inhalfandfullforms}', "");
Expect(0, 65520, '\P{^inhalfandfullforms}', "");
Expect(1, 65519, '\p{	-In_Half_And_Full_Forms}', "");
Expect(0, 65519, '\p{^	-In_Half_And_Full_Forms}', "");
Expect(0, 65519, '\P{	-In_Half_And_Full_Forms}', "");
Expect(1, 65519, '\P{^	-In_Half_And_Full_Forms}', "");
Expect(0, 65520, '\p{	-In_Half_And_Full_Forms}', "");
Expect(1, 65520, '\p{^	-In_Half_And_Full_Forms}', "");
Expect(1, 65520, '\P{	-In_Half_And_Full_Forms}', "");
Expect(0, 65520, '\P{^	-In_Half_And_Full_Forms}', "");
Error('\p{-	Han/a/}');
Error('\P{-	Han/a/}');
Expect(1, 195101, '\p{han}', "");
Expect(0, 195101, '\p{^han}', "");
Expect(0, 195101, '\P{han}', "");
Expect(1, 195101, '\P{^han}', "");
Expect(0, 195102, '\p{han}', "");
Expect(1, 195102, '\p{^han}', "");
Expect(1, 195102, '\P{han}', "");
Expect(0, 195102, '\P{^han}', "");
Expect(1, 195101, '\p{-han}', "");
Expect(0, 195101, '\p{^-han}', "");
Expect(0, 195101, '\P{-han}', "");
Expect(1, 195101, '\P{^-han}', "");
Expect(0, 195102, '\p{-han}', "");
Expect(1, 195102, '\p{^-han}', "");
Expect(1, 195102, '\P{-han}', "");
Expect(0, 195102, '\P{^-han}', "");
Error('\p{:=Is_han}');
Error('\P{:=Is_han}');
Expect(1, 195101, '\p{ishan}', "");
Expect(0, 195101, '\p{^ishan}', "");
Expect(0, 195101, '\P{ishan}', "");
Expect(1, 195101, '\P{^ishan}', "");
Expect(0, 195102, '\p{ishan}', "");
Expect(1, 195102, '\p{^ishan}', "");
Expect(1, 195102, '\P{ishan}', "");
Expect(0, 195102, '\P{^ishan}', "");
Expect(1, 195101, '\p{ Is_HAN}', "");
Expect(0, 195101, '\p{^ Is_HAN}', "");
Expect(0, 195101, '\P{ Is_HAN}', "");
Expect(1, 195101, '\P{^ Is_HAN}', "");
Expect(0, 195102, '\p{ Is_HAN}', "");
Expect(1, 195102, '\p{^ Is_HAN}', "");
Expect(1, 195102, '\P{ Is_HAN}', "");
Expect(0, 195102, '\P{^ Is_HAN}', "");
Error('\p{-Hani/a/}');
Error('\P{-Hani/a/}');
Expect(1, 195101, '\p{hani}', "");
Expect(0, 195101, '\p{^hani}', "");
Expect(0, 195101, '\P{hani}', "");
Expect(1, 195101, '\P{^hani}', "");
Expect(0, 195102, '\p{hani}', "");
Expect(1, 195102, '\p{^hani}', "");
Expect(1, 195102, '\P{hani}', "");
Expect(0, 195102, '\P{^hani}', "");
Expect(1, 195101, '\p{ -Hani}', "");
Expect(0, 195101, '\p{^ -Hani}', "");
Expect(0, 195101, '\P{ -Hani}', "");
Expect(1, 195101, '\P{^ -Hani}', "");
Expect(0, 195102, '\p{ -Hani}', "");
Expect(1, 195102, '\p{^ -Hani}', "");
Expect(1, 195102, '\P{ -Hani}', "");
Expect(0, 195102, '\P{^ -Hani}', "");
Error('\p{ -Is_Hani/a/}');
Error('\P{ -Is_Hani/a/}');
Expect(1, 195101, '\p{ishani}', "");
Expect(0, 195101, '\p{^ishani}', "");
Expect(0, 195101, '\P{ishani}', "");
Expect(1, 195101, '\P{^ishani}', "");
Expect(0, 195102, '\p{ishani}', "");
Expect(1, 195102, '\p{^ishani}', "");
Expect(1, 195102, '\P{ishani}', "");
Expect(0, 195102, '\P{^ishani}', "");
Expect(1, 195101, '\p{Is_Hani}', "");
Expect(0, 195101, '\p{^Is_Hani}', "");
Expect(0, 195101, '\P{Is_Hani}', "");
Expect(1, 195101, '\P{^Is_Hani}', "");
Expect(0, 195102, '\p{Is_Hani}', "");
Expect(1, 195102, '\p{^Is_Hani}', "");
Expect(1, 195102, '\P{Is_Hani}', "");
Expect(0, 195102, '\P{^Is_Hani}', "");
Error('\p{	:=HANGUL}');
Error('\P{	:=HANGUL}');
Expect(1, 65500, '\p{hangul}', "");
Expect(0, 65500, '\p{^hangul}', "");
Expect(0, 65500, '\P{hangul}', "");
Expect(1, 65500, '\P{^hangul}', "");
Expect(0, 65501, '\p{hangul}', "");
Expect(1, 65501, '\p{^hangul}', "");
Expect(1, 65501, '\P{hangul}', "");
Expect(0, 65501, '\P{^hangul}', "");
Expect(1, 65500, '\p{- Hangul}', "");
Expect(0, 65500, '\p{^- Hangul}', "");
Expect(0, 65500, '\P{- Hangul}', "");
Expect(1, 65500, '\P{^- Hangul}', "");
Expect(0, 65501, '\p{- Hangul}', "");
Expect(1, 65501, '\p{^- Hangul}', "");
Expect(1, 65501, '\P{- Hangul}', "");
Expect(0, 65501, '\P{^- Hangul}', "");
Error('\p{		IS_Hangul/a/}');
Error('\P{		IS_Hangul/a/}');
Expect(1, 65500, '\p{ishangul}', "");
Expect(0, 65500, '\p{^ishangul}', "");
Expect(0, 65500, '\P{ishangul}', "");
Expect(1, 65500, '\P{^ishangul}', "");
Expect(0, 65501, '\p{ishangul}', "");
Expect(1, 65501, '\p{^ishangul}', "");
Expect(1, 65501, '\P{ishangul}', "");
Expect(0, 65501, '\P{^ishangul}', "");
Expect(1, 65500, '\p{-	Is_Hangul}', "");
Expect(0, 65500, '\p{^-	Is_Hangul}', "");
Expect(0, 65500, '\P{-	Is_Hangul}', "");
Expect(1, 65500, '\P{^-	Is_Hangul}', "");
Expect(0, 65501, '\p{-	Is_Hangul}', "");
Expect(1, 65501, '\p{^-	Is_Hangul}', "");
Expect(1, 65501, '\P{-	Is_Hangul}', "");
Expect(0, 65501, '\P{^-	Is_Hangul}', "");
Error('\p{/a/	HANG}');
Error('\P{/a/	HANG}');
Expect(1, 65500, '\p{hang}', "");
Expect(0, 65500, '\p{^hang}', "");
Expect(0, 65500, '\P{hang}', "");
Expect(1, 65500, '\P{^hang}', "");
Expect(0, 65501, '\p{hang}', "");
Expect(1, 65501, '\p{^hang}', "");
Expect(1, 65501, '\P{hang}', "");
Expect(0, 65501, '\P{^hang}', "");
Expect(1, 65500, '\p{	Hang}', "");
Expect(0, 65500, '\p{^	Hang}', "");
Expect(0, 65500, '\P{	Hang}', "");
Expect(1, 65500, '\P{^	Hang}', "");
Expect(0, 65501, '\p{	Hang}', "");
Expect(1, 65501, '\p{^	Hang}', "");
Expect(1, 65501, '\P{	Hang}', "");
Expect(0, 65501, '\P{^	Hang}', "");
Error('\p{/a/IS_Hang}');
Error('\P{/a/IS_Hang}');
Expect(1, 65500, '\p{ishang}', "");
Expect(0, 65500, '\p{^ishang}', "");
Expect(0, 65500, '\P{ishang}', "");
Expect(1, 65500, '\P{^ishang}', "");
Expect(0, 65501, '\p{ishang}', "");
Expect(1, 65501, '\p{^ishang}', "");
Expect(1, 65501, '\P{ishang}', "");
Expect(0, 65501, '\P{^ishang}', "");
Expect(1, 65500, '\p{-_Is_Hang}', "");
Expect(0, 65500, '\p{^-_Is_Hang}', "");
Expect(0, 65500, '\P{-_Is_Hang}', "");
Expect(1, 65500, '\P{^-_Is_Hang}', "");
Expect(0, 65501, '\p{-_Is_Hang}', "");
Expect(1, 65501, '\p{^-_Is_Hang}', "");
Expect(1, 65501, '\P{-_Is_Hang}', "");
Expect(0, 65501, '\P{^-_Is_Hang}', "");
Error('\p{_HANGUL_Compatibility_Jamo/a/}');
Error('\P{_HANGUL_Compatibility_Jamo/a/}');
Expect(1, 12687, '\p{hangulcompatibilityjamo}', "");
Expect(0, 12687, '\p{^hangulcompatibilityjamo}', "");
Expect(0, 12687, '\P{hangulcompatibilityjamo}', "");
Expect(1, 12687, '\P{^hangulcompatibilityjamo}', "");
Expect(0, 12688, '\p{hangulcompatibilityjamo}', "");
Expect(1, 12688, '\p{^hangulcompatibilityjamo}', "");
Expect(1, 12688, '\P{hangulcompatibilityjamo}', "");
Expect(0, 12688, '\P{^hangulcompatibilityjamo}', "");
Expect(1, 12687, '\p{	Hangul_compatibility_JAMO}', "");
Expect(0, 12687, '\p{^	Hangul_compatibility_JAMO}', "");
Expect(0, 12687, '\P{	Hangul_compatibility_JAMO}', "");
Expect(1, 12687, '\P{^	Hangul_compatibility_JAMO}', "");
Expect(0, 12688, '\p{	Hangul_compatibility_JAMO}', "");
Expect(1, 12688, '\p{^	Hangul_compatibility_JAMO}', "");
Expect(1, 12688, '\P{	Hangul_compatibility_JAMO}', "");
Expect(0, 12688, '\P{^	Hangul_compatibility_JAMO}', "");
Error('\p{	-IS_HANGUL_COMPATIBILITY_Jamo:=}');
Error('\P{	-IS_HANGUL_COMPATIBILITY_Jamo:=}');
Expect(1, 12687, '\p{ishangulcompatibilityjamo}', "");
Expect(0, 12687, '\p{^ishangulcompatibilityjamo}', "");
Expect(0, 12687, '\P{ishangulcompatibilityjamo}', "");
Expect(1, 12687, '\P{^ishangulcompatibilityjamo}', "");
Expect(0, 12688, '\p{ishangulcompatibilityjamo}', "");
Expect(1, 12688, '\p{^ishangulcompatibilityjamo}', "");
Expect(1, 12688, '\P{ishangulcompatibilityjamo}', "");
Expect(0, 12688, '\P{^ishangulcompatibilityjamo}', "");
Expect(1, 12687, '\p{ _Is_HANGUL_COMPATIBILITY_Jamo}', "");
Expect(0, 12687, '\p{^ _Is_HANGUL_COMPATIBILITY_Jamo}', "");
Expect(0, 12687, '\P{ _Is_HANGUL_COMPATIBILITY_Jamo}', "");
Expect(1, 12687, '\P{^ _Is_HANGUL_COMPATIBILITY_Jamo}', "");
Expect(0, 12688, '\p{ _Is_HANGUL_COMPATIBILITY_Jamo}', "");
Expect(1, 12688, '\p{^ _Is_HANGUL_COMPATIBILITY_Jamo}', "");
Expect(1, 12688, '\P{ _Is_HANGUL_COMPATIBILITY_Jamo}', "");
Expect(0, 12688, '\P{^ _Is_HANGUL_COMPATIBILITY_Jamo}', "");
Error('\p{	/a/IN_hangul_Compatibility_JAMO}');
Error('\P{	/a/IN_hangul_Compatibility_JAMO}');
Expect(1, 12687, '\p{inhangulcompatibilityjamo}', "");
Expect(0, 12687, '\p{^inhangulcompatibilityjamo}', "");
Expect(0, 12687, '\P{inhangulcompatibilityjamo}', "");
Expect(1, 12687, '\P{^inhangulcompatibilityjamo}', "");
Expect(0, 12688, '\p{inhangulcompatibilityjamo}', "");
Expect(1, 12688, '\p{^inhangulcompatibilityjamo}', "");
Expect(1, 12688, '\P{inhangulcompatibilityjamo}', "");
Expect(0, 12688, '\P{^inhangulcompatibilityjamo}', "");
Expect(1, 12687, '\p{_In_hangul_Compatibility_jamo}', "");
Expect(0, 12687, '\p{^_In_hangul_Compatibility_jamo}', "");
Expect(0, 12687, '\P{_In_hangul_Compatibility_jamo}', "");
Expect(1, 12687, '\P{^_In_hangul_Compatibility_jamo}', "");
Expect(0, 12688, '\p{_In_hangul_Compatibility_jamo}', "");
Expect(1, 12688, '\p{^_In_hangul_Compatibility_jamo}', "");
Expect(1, 12688, '\P{_In_hangul_Compatibility_jamo}', "");
Expect(0, 12688, '\P{^_In_hangul_Compatibility_jamo}', "");
Error('\p{_:=Compat_jamo}');
Error('\P{_:=Compat_jamo}');
Expect(1, 12687, '\p{compatjamo}', "");
Expect(0, 12687, '\p{^compatjamo}', "");
Expect(0, 12687, '\P{compatjamo}', "");
Expect(1, 12687, '\P{^compatjamo}', "");
Expect(0, 12688, '\p{compatjamo}', "");
Expect(1, 12688, '\p{^compatjamo}', "");
Expect(1, 12688, '\P{compatjamo}', "");
Expect(0, 12688, '\P{^compatjamo}', "");
Expect(1, 12687, '\p{_-COMPAT_Jamo}', "");
Expect(0, 12687, '\p{^_-COMPAT_Jamo}', "");
Expect(0, 12687, '\P{_-COMPAT_Jamo}', "");
Expect(1, 12687, '\P{^_-COMPAT_Jamo}', "");
Expect(0, 12688, '\p{_-COMPAT_Jamo}', "");
Expect(1, 12688, '\p{^_-COMPAT_Jamo}', "");
Expect(1, 12688, '\P{_-COMPAT_Jamo}', "");
Expect(0, 12688, '\P{^_-COMPAT_Jamo}', "");
Error('\p{ /a/Is_Compat_jamo}');
Error('\P{ /a/Is_Compat_jamo}');
Expect(1, 12687, '\p{iscompatjamo}', "");
Expect(0, 12687, '\p{^iscompatjamo}', "");
Expect(0, 12687, '\P{iscompatjamo}', "");
Expect(1, 12687, '\P{^iscompatjamo}', "");
Expect(0, 12688, '\p{iscompatjamo}', "");
Expect(1, 12688, '\p{^iscompatjamo}', "");
Expect(1, 12688, '\P{iscompatjamo}', "");
Expect(0, 12688, '\P{^iscompatjamo}', "");
Expect(1, 12687, '\p{  Is_Compat_JAMO}', "");
Expect(0, 12687, '\p{^  Is_Compat_JAMO}', "");
Expect(0, 12687, '\P{  Is_Compat_JAMO}', "");
Expect(1, 12687, '\P{^  Is_Compat_JAMO}', "");
Expect(0, 12688, '\p{  Is_Compat_JAMO}', "");
Expect(1, 12688, '\p{^  Is_Compat_JAMO}', "");
Expect(1, 12688, '\P{  Is_Compat_JAMO}', "");
Expect(0, 12688, '\P{^  Is_Compat_JAMO}', "");
Error('\p{ :=In_Compat_JAMO}');
Error('\P{ :=In_Compat_JAMO}');
Expect(1, 12687, '\p{incompatjamo}', "");
Expect(0, 12687, '\p{^incompatjamo}', "");
Expect(0, 12687, '\P{incompatjamo}', "");
Expect(1, 12687, '\P{^incompatjamo}', "");
Expect(0, 12688, '\p{incompatjamo}', "");
Expect(1, 12688, '\p{^incompatjamo}', "");
Expect(1, 12688, '\P{incompatjamo}', "");
Expect(0, 12688, '\P{^incompatjamo}', "");
Expect(1, 12687, '\p{--In_compat_Jamo}', "");
Expect(0, 12687, '\p{^--In_compat_Jamo}', "");
Expect(0, 12687, '\P{--In_compat_Jamo}', "");
Expect(1, 12687, '\P{^--In_compat_Jamo}', "");
Expect(0, 12688, '\p{--In_compat_Jamo}', "");
Expect(1, 12688, '\p{^--In_compat_Jamo}', "");
Expect(1, 12688, '\P{--In_compat_Jamo}', "");
Expect(0, 12688, '\P{^--In_compat_Jamo}', "");
Error('\p{:=-hangul_Jamo}');
Error('\P{:=-hangul_Jamo}');
Expect(1, 4607, '\p{hanguljamo}', "");
Expect(0, 4607, '\p{^hanguljamo}', "");
Expect(0, 4607, '\P{hanguljamo}', "");
Expect(1, 4607, '\P{^hanguljamo}', "");
Expect(0, 4608, '\p{hanguljamo}', "");
Expect(1, 4608, '\p{^hanguljamo}', "");
Expect(1, 4608, '\P{hanguljamo}', "");
Expect(0, 4608, '\P{^hanguljamo}', "");
Expect(1, 4607, '\p{_HANGUL_Jamo}', "");
Expect(0, 4607, '\p{^_HANGUL_Jamo}', "");
Expect(0, 4607, '\P{_HANGUL_Jamo}', "");
Expect(1, 4607, '\P{^_HANGUL_Jamo}', "");
Expect(0, 4608, '\p{_HANGUL_Jamo}', "");
Expect(1, 4608, '\p{^_HANGUL_Jamo}', "");
Expect(1, 4608, '\P{_HANGUL_Jamo}', "");
Expect(0, 4608, '\P{^_HANGUL_Jamo}', "");
Error('\p{ IS_Hangul_Jamo/a/}');
Error('\P{ IS_Hangul_Jamo/a/}');
Expect(1, 4607, '\p{ishanguljamo}', "");
Expect(0, 4607, '\p{^ishanguljamo}', "");
Expect(0, 4607, '\P{ishanguljamo}', "");
Expect(1, 4607, '\P{^ishanguljamo}', "");
Expect(0, 4608, '\p{ishanguljamo}', "");
Expect(1, 4608, '\p{^ishanguljamo}', "");
Expect(1, 4608, '\P{ishanguljamo}', "");
Expect(0, 4608, '\P{^ishanguljamo}', "");
Expect(1, 4607, '\p{-Is_hangul_jamo}', "");
Expect(0, 4607, '\p{^-Is_hangul_jamo}', "");
Expect(0, 4607, '\P{-Is_hangul_jamo}', "");
Expect(1, 4607, '\P{^-Is_hangul_jamo}', "");
Expect(0, 4608, '\p{-Is_hangul_jamo}', "");
Expect(1, 4608, '\p{^-Is_hangul_jamo}', "");
Expect(1, 4608, '\P{-Is_hangul_jamo}', "");
Expect(0, 4608, '\P{^-Is_hangul_jamo}', "");
Error('\p{:= _In_hangul_Jamo}');
Error('\P{:= _In_hangul_Jamo}');
Expect(1, 4607, '\p{inhanguljamo}', "");
Expect(0, 4607, '\p{^inhanguljamo}', "");
Expect(0, 4607, '\P{inhanguljamo}', "");
Expect(1, 4607, '\P{^inhanguljamo}', "");
Expect(0, 4608, '\p{inhanguljamo}', "");
Expect(1, 4608, '\p{^inhanguljamo}', "");
Expect(1, 4608, '\P{inhanguljamo}', "");
Expect(0, 4608, '\P{^inhanguljamo}', "");
Expect(1, 4607, '\p{ In_HANGUL_JAMO}', "");
Expect(0, 4607, '\p{^ In_HANGUL_JAMO}', "");
Expect(0, 4607, '\P{ In_HANGUL_JAMO}', "");
Expect(1, 4607, '\P{^ In_HANGUL_JAMO}', "");
Expect(0, 4608, '\p{ In_HANGUL_JAMO}', "");
Expect(1, 4608, '\p{^ In_HANGUL_JAMO}', "");
Expect(1, 4608, '\P{ In_HANGUL_JAMO}', "");
Expect(0, 4608, '\P{^ In_HANGUL_JAMO}', "");
Error('\p{/a/_	Jamo}');
Error('\P{/a/_	Jamo}');
Expect(1, 4607, '\p{jamo}', "");
Expect(0, 4607, '\p{^jamo}', "");
Expect(0, 4607, '\P{jamo}', "");
Expect(1, 4607, '\P{^jamo}', "");
Expect(0, 4608, '\p{jamo}', "");
Expect(1, 4608, '\p{^jamo}', "");
Expect(1, 4608, '\P{jamo}', "");
Expect(0, 4608, '\P{^jamo}', "");
Expect(1, 4607, '\p{	 Jamo}', "");
Expect(0, 4607, '\p{^	 Jamo}', "");
Expect(0, 4607, '\P{	 Jamo}', "");
Expect(1, 4607, '\P{^	 Jamo}', "");
Expect(0, 4608, '\p{	 Jamo}', "");
Expect(1, 4608, '\p{^	 Jamo}', "");
Expect(1, 4608, '\P{	 Jamo}', "");
Expect(0, 4608, '\P{^	 Jamo}', "");
Error('\p{-is_Jamo/a/}');
Error('\P{-is_Jamo/a/}');
Expect(1, 4607, '\p{isjamo}', "");
Expect(0, 4607, '\p{^isjamo}', "");
Expect(0, 4607, '\P{isjamo}', "");
Expect(1, 4607, '\P{^isjamo}', "");
Expect(0, 4608, '\p{isjamo}', "");
Expect(1, 4608, '\p{^isjamo}', "");
Expect(1, 4608, '\P{isjamo}', "");
Expect(0, 4608, '\P{^isjamo}', "");
Expect(1, 4607, '\p{	_IS_JAMO}', "");
Expect(0, 4607, '\p{^	_IS_JAMO}', "");
Expect(0, 4607, '\P{	_IS_JAMO}', "");
Expect(1, 4607, '\P{^	_IS_JAMO}', "");
Expect(0, 4608, '\p{	_IS_JAMO}', "");
Expect(1, 4608, '\p{^	_IS_JAMO}', "");
Expect(1, 4608, '\P{	_IS_JAMO}', "");
Expect(0, 4608, '\P{^	_IS_JAMO}', "");
Error('\p{-_in_jamo:=}');
Error('\P{-_in_jamo:=}');
Expect(1, 4607, '\p{injamo}', "");
Expect(0, 4607, '\p{^injamo}', "");
Expect(0, 4607, '\P{injamo}', "");
Expect(1, 4607, '\P{^injamo}', "");
Expect(0, 4608, '\p{injamo}', "");
Expect(1, 4608, '\p{^injamo}', "");
Expect(1, 4608, '\P{injamo}', "");
Expect(0, 4608, '\P{^injamo}', "");
Expect(1, 4607, '\p{  In_Jamo}', "");
Expect(0, 4607, '\p{^  In_Jamo}', "");
Expect(0, 4607, '\P{  In_Jamo}', "");
Expect(1, 4607, '\P{^  In_Jamo}', "");
Expect(0, 4608, '\p{  In_Jamo}', "");
Expect(1, 4608, '\p{^  In_Jamo}', "");
Expect(1, 4608, '\P{  In_Jamo}', "");
Expect(0, 4608, '\P{^  In_Jamo}', "");
Error('\p{:=hangul_Jamo_Extended_A}');
Error('\P{:=hangul_Jamo_Extended_A}');
Expect(1, 43391, '\p{hanguljamoextendeda}', "");
Expect(0, 43391, '\p{^hanguljamoextendeda}', "");
Expect(0, 43391, '\P{hanguljamoextendeda}', "");
Expect(1, 43391, '\P{^hanguljamoextendeda}', "");
Expect(0, 43392, '\p{hanguljamoextendeda}', "");
Expect(1, 43392, '\p{^hanguljamoextendeda}', "");
Expect(1, 43392, '\P{hanguljamoextendeda}', "");
Expect(0, 43392, '\P{^hanguljamoextendeda}', "");
Expect(1, 43391, '\p{ hangul_Jamo_Extended_A}', "");
Expect(0, 43391, '\p{^ hangul_Jamo_Extended_A}', "");
Expect(0, 43391, '\P{ hangul_Jamo_Extended_A}', "");
Expect(1, 43391, '\P{^ hangul_Jamo_Extended_A}', "");
Expect(0, 43392, '\p{ hangul_Jamo_Extended_A}', "");
Expect(1, 43392, '\p{^ hangul_Jamo_Extended_A}', "");
Expect(1, 43392, '\P{ hangul_Jamo_Extended_A}', "");
Expect(0, 43392, '\P{^ hangul_Jamo_Extended_A}', "");
Error('\p{_/a/is_HANGUL_JAMO_extended_A}');
Error('\P{_/a/is_HANGUL_JAMO_extended_A}');
Expect(1, 43391, '\p{ishanguljamoextendeda}', "");
Expect(0, 43391, '\p{^ishanguljamoextendeda}', "");
Expect(0, 43391, '\P{ishanguljamoextendeda}', "");
Expect(1, 43391, '\P{^ishanguljamoextendeda}', "");
Expect(0, 43392, '\p{ishanguljamoextendeda}', "");
Expect(1, 43392, '\p{^ishanguljamoextendeda}', "");
Expect(1, 43392, '\P{ishanguljamoextendeda}', "");
Expect(0, 43392, '\P{^ishanguljamoextendeda}', "");
Expect(1, 43391, '\p{--Is_Hangul_JAMO_Extended_a}', "");
Expect(0, 43391, '\p{^--Is_Hangul_JAMO_Extended_a}', "");
Expect(0, 43391, '\P{--Is_Hangul_JAMO_Extended_a}', "");
Expect(1, 43391, '\P{^--Is_Hangul_JAMO_Extended_a}', "");
Expect(0, 43392, '\p{--Is_Hangul_JAMO_Extended_a}', "");
Expect(1, 43392, '\p{^--Is_Hangul_JAMO_Extended_a}', "");
Expect(1, 43392, '\P{--Is_Hangul_JAMO_Extended_a}', "");
Expect(0, 43392, '\P{^--Is_Hangul_JAMO_Extended_a}', "");
Error('\p{ In_Hangul_JAMO_Extended_A:=}');
Error('\P{ In_Hangul_JAMO_Extended_A:=}');
Expect(1, 43391, '\p{inhanguljamoextendeda}', "");
Expect(0, 43391, '\p{^inhanguljamoextendeda}', "");
Expect(0, 43391, '\P{inhanguljamoextendeda}', "");
Expect(1, 43391, '\P{^inhanguljamoextendeda}', "");
Expect(0, 43392, '\p{inhanguljamoextendeda}', "");
Expect(1, 43392, '\p{^inhanguljamoextendeda}', "");
Expect(1, 43392, '\P{inhanguljamoextendeda}', "");
Expect(0, 43392, '\P{^inhanguljamoextendeda}', "");
Expect(1, 43391, '\p{_-In_Hangul_JAMO_EXTENDED_a}', "");
Expect(0, 43391, '\p{^_-In_Hangul_JAMO_EXTENDED_a}', "");
Expect(0, 43391, '\P{_-In_Hangul_JAMO_EXTENDED_a}', "");
Expect(1, 43391, '\P{^_-In_Hangul_JAMO_EXTENDED_a}', "");
Expect(0, 43392, '\p{_-In_Hangul_JAMO_EXTENDED_a}', "");
Expect(1, 43392, '\p{^_-In_Hangul_JAMO_EXTENDED_a}', "");
Expect(1, 43392, '\P{_-In_Hangul_JAMO_EXTENDED_a}', "");
Expect(0, 43392, '\P{^_-In_Hangul_JAMO_EXTENDED_a}', "");
Error('\p{_:=jamo_Ext_A}');
Error('\P{_:=jamo_Ext_A}');
Expect(1, 43391, '\p{jamoexta}', "");
Expect(0, 43391, '\p{^jamoexta}', "");
Expect(0, 43391, '\P{jamoexta}', "");
Expect(1, 43391, '\P{^jamoexta}', "");
Expect(0, 43392, '\p{jamoexta}', "");
Expect(1, 43392, '\p{^jamoexta}', "");
Expect(1, 43392, '\P{jamoexta}', "");
Expect(0, 43392, '\P{^jamoexta}', "");
Expect(1, 43391, '\p{  Jamo_Ext_a}', "");
Expect(0, 43391, '\p{^  Jamo_Ext_a}', "");
Expect(0, 43391, '\P{  Jamo_Ext_a}', "");
Expect(1, 43391, '\P{^  Jamo_Ext_a}', "");
Expect(0, 43392, '\p{  Jamo_Ext_a}', "");
Expect(1, 43392, '\p{^  Jamo_Ext_a}', "");
Expect(1, 43392, '\P{  Jamo_Ext_a}', "");
Expect(0, 43392, '\P{^  Jamo_Ext_a}', "");
Error('\p{/a/-_Is_jamo_ext_A}');
Error('\P{/a/-_Is_jamo_ext_A}');
Expect(1, 43391, '\p{isjamoexta}', "");
Expect(0, 43391, '\p{^isjamoexta}', "");
Expect(0, 43391, '\P{isjamoexta}', "");
Expect(1, 43391, '\P{^isjamoexta}', "");
Expect(0, 43392, '\p{isjamoexta}', "");
Expect(1, 43392, '\p{^isjamoexta}', "");
Expect(1, 43392, '\P{isjamoexta}', "");
Expect(0, 43392, '\P{^isjamoexta}', "");
Expect(1, 43391, '\p{		Is_Jamo_ext_A}', "");
Expect(0, 43391, '\p{^		Is_Jamo_ext_A}', "");
Expect(0, 43391, '\P{		Is_Jamo_ext_A}', "");
Expect(1, 43391, '\P{^		Is_Jamo_ext_A}', "");
Expect(0, 43392, '\p{		Is_Jamo_ext_A}', "");
Expect(1, 43392, '\p{^		Is_Jamo_ext_A}', "");
Expect(1, 43392, '\P{		Is_Jamo_ext_A}', "");
Expect(0, 43392, '\P{^		Is_Jamo_ext_A}', "");
Error('\p{__In_jamo_EXT_A:=}');
Error('\P{__In_jamo_EXT_A:=}');
Expect(1, 43391, '\p{injamoexta}', "");
Expect(0, 43391, '\p{^injamoexta}', "");
Expect(0, 43391, '\P{injamoexta}', "");
Expect(1, 43391, '\P{^injamoexta}', "");
Expect(0, 43392, '\p{injamoexta}', "");
Expect(1, 43392, '\p{^injamoexta}', "");
Expect(1, 43392, '\P{injamoexta}', "");
Expect(0, 43392, '\P{^injamoexta}', "");
Expect(1, 43391, '\p{	 In_Jamo_ext_a}', "");
Expect(0, 43391, '\p{^	 In_Jamo_ext_a}', "");
Expect(0, 43391, '\P{	 In_Jamo_ext_a}', "");
Expect(1, 43391, '\P{^	 In_Jamo_ext_a}', "");
Expect(0, 43392, '\p{	 In_Jamo_ext_a}', "");
Expect(1, 43392, '\p{^	 In_Jamo_ext_a}', "");
Expect(1, 43392, '\P{	 In_Jamo_ext_a}', "");
Expect(0, 43392, '\P{^	 In_Jamo_ext_a}', "");
Error('\p{/a/	-HANGUL_JAMO_Extended_B}');
Error('\P{/a/	-HANGUL_JAMO_Extended_B}');
Expect(1, 55295, '\p{hanguljamoextendedb}', "");
Expect(0, 55295, '\p{^hanguljamoextendedb}', "");
Expect(0, 55295, '\P{hanguljamoextendedb}', "");
Expect(1, 55295, '\P{^hanguljamoextendedb}', "");
Expect(0, 57344, '\p{hanguljamoextendedb}', "");
Expect(1, 57344, '\p{^hanguljamoextendedb}', "");
Expect(1, 57344, '\P{hanguljamoextendedb}', "");
Expect(0, 57344, '\P{^hanguljamoextendedb}', "");
Expect(1, 55295, '\p{ Hangul_jamo_Extended_B}', "");
Expect(0, 55295, '\p{^ Hangul_jamo_Extended_B}', "");
Expect(0, 55295, '\P{ Hangul_jamo_Extended_B}', "");
Expect(1, 55295, '\P{^ Hangul_jamo_Extended_B}', "");
Expect(0, 57344, '\p{ Hangul_jamo_Extended_B}', "");
Expect(1, 57344, '\p{^ Hangul_jamo_Extended_B}', "");
Expect(1, 57344, '\P{ Hangul_jamo_Extended_B}', "");
Expect(0, 57344, '\P{^ Hangul_jamo_Extended_B}', "");
Error('\p{ 	Is_HANGUL_Jamo_EXTENDED_B:=}');
Error('\P{ 	Is_HANGUL_Jamo_EXTENDED_B:=}');
Expect(1, 55295, '\p{ishanguljamoextendedb}', "");
Expect(0, 55295, '\p{^ishanguljamoextendedb}', "");
Expect(0, 55295, '\P{ishanguljamoextendedb}', "");
Expect(1, 55295, '\P{^ishanguljamoextendedb}', "");
Expect(0, 57344, '\p{ishanguljamoextendedb}', "");
Expect(1, 57344, '\p{^ishanguljamoextendedb}', "");
Expect(1, 57344, '\P{ishanguljamoextendedb}', "");
Expect(0, 57344, '\P{^ishanguljamoextendedb}', "");
Expect(1, 55295, '\p{	Is_HANGUL_Jamo_EXTENDED_B}', "");
Expect(0, 55295, '\p{^	Is_HANGUL_Jamo_EXTENDED_B}', "");
Expect(0, 55295, '\P{	Is_HANGUL_Jamo_EXTENDED_B}', "");
Expect(1, 55295, '\P{^	Is_HANGUL_Jamo_EXTENDED_B}', "");
Expect(0, 57344, '\p{	Is_HANGUL_Jamo_EXTENDED_B}', "");
Expect(1, 57344, '\p{^	Is_HANGUL_Jamo_EXTENDED_B}', "");
Expect(1, 57344, '\P{	Is_HANGUL_Jamo_EXTENDED_B}', "");
Expect(0, 57344, '\P{^	Is_HANGUL_Jamo_EXTENDED_B}', "");
Error('\p{/a/ _In_HANGUL_Jamo_Extended_B}');
Error('\P{/a/ _In_HANGUL_Jamo_Extended_B}');
Expect(1, 55295, '\p{inhanguljamoextendedb}', "");
Expect(0, 55295, '\p{^inhanguljamoextendedb}', "");
Expect(0, 55295, '\P{inhanguljamoextendedb}', "");
Expect(1, 55295, '\P{^inhanguljamoextendedb}', "");
Expect(0, 57344, '\p{inhanguljamoextendedb}', "");
Expect(1, 57344, '\p{^inhanguljamoextendedb}', "");
Expect(1, 57344, '\P{inhanguljamoextendedb}', "");
Expect(0, 57344, '\P{^inhanguljamoextendedb}', "");
Expect(1, 55295, '\p{ 	In_Hangul_Jamo_EXTENDED_B}', "");
Expect(0, 55295, '\p{^ 	In_Hangul_Jamo_EXTENDED_B}', "");
Expect(0, 55295, '\P{ 	In_Hangul_Jamo_EXTENDED_B}', "");
Expect(1, 55295, '\P{^ 	In_Hangul_Jamo_EXTENDED_B}', "");
Expect(0, 57344, '\p{ 	In_Hangul_Jamo_EXTENDED_B}', "");
Expect(1, 57344, '\p{^ 	In_Hangul_Jamo_EXTENDED_B}', "");
Expect(1, 57344, '\P{ 	In_Hangul_Jamo_EXTENDED_B}', "");
Expect(0, 57344, '\P{^ 	In_Hangul_Jamo_EXTENDED_B}', "");
Error('\p{__JAMO_EXT_b:=}');
Error('\P{__JAMO_EXT_b:=}');
Expect(1, 55295, '\p{jamoextb}', "");
Expect(0, 55295, '\p{^jamoextb}', "");
Expect(0, 55295, '\P{jamoextb}', "");
Expect(1, 55295, '\P{^jamoextb}', "");
Expect(0, 57344, '\p{jamoextb}', "");
Expect(1, 57344, '\p{^jamoextb}', "");
Expect(1, 57344, '\P{jamoextb}', "");
Expect(0, 57344, '\P{^jamoextb}', "");
Expect(1, 55295, '\p{ -Jamo_ext_B}', "");
Expect(0, 55295, '\p{^ -Jamo_ext_B}', "");
Expect(0, 55295, '\P{ -Jamo_ext_B}', "");
Expect(1, 55295, '\P{^ -Jamo_ext_B}', "");
Expect(0, 57344, '\p{ -Jamo_ext_B}', "");
Expect(1, 57344, '\p{^ -Jamo_ext_B}', "");
Expect(1, 57344, '\P{ -Jamo_ext_B}', "");
Expect(0, 57344, '\P{^ -Jamo_ext_B}', "");
Error('\p{:=-_IS_Jamo_Ext_b}');
Error('\P{:=-_IS_Jamo_Ext_b}');
Expect(1, 55295, '\p{isjamoextb}', "");
Expect(0, 55295, '\p{^isjamoextb}', "");
Expect(0, 55295, '\P{isjamoextb}', "");
Expect(1, 55295, '\P{^isjamoextb}', "");
Expect(0, 57344, '\p{isjamoextb}', "");
Expect(1, 57344, '\p{^isjamoextb}', "");
Expect(1, 57344, '\P{isjamoextb}', "");
Expect(0, 57344, '\P{^isjamoextb}', "");
Expect(1, 55295, '\p{	is_jamo_ext_b}', "");
Expect(0, 55295, '\p{^	is_jamo_ext_b}', "");
Expect(0, 55295, '\P{	is_jamo_ext_b}', "");
Expect(1, 55295, '\P{^	is_jamo_ext_b}', "");
Expect(0, 57344, '\p{	is_jamo_ext_b}', "");
Expect(1, 57344, '\p{^	is_jamo_ext_b}', "");
Expect(1, 57344, '\P{	is_jamo_ext_b}', "");
Expect(0, 57344, '\P{^	is_jamo_ext_b}', "");
Error('\p{/a/_In_JAMO_ext_B}');
Error('\P{/a/_In_JAMO_ext_B}');
Expect(1, 55295, '\p{injamoextb}', "");
Expect(0, 55295, '\p{^injamoextb}', "");
Expect(0, 55295, '\P{injamoextb}', "");
Expect(1, 55295, '\P{^injamoextb}', "");
Expect(0, 57344, '\p{injamoextb}', "");
Expect(1, 57344, '\p{^injamoextb}', "");
Expect(1, 57344, '\P{injamoextb}', "");
Expect(0, 57344, '\P{^injamoextb}', "");
Expect(1, 55295, '\p{ 	In_JAMO_ext_B}', "");
Expect(0, 55295, '\p{^ 	In_JAMO_ext_B}', "");
Expect(0, 55295, '\P{ 	In_JAMO_ext_B}', "");
Expect(1, 55295, '\P{^ 	In_JAMO_ext_B}', "");
Expect(0, 57344, '\p{ 	In_JAMO_ext_B}', "");
Expect(1, 57344, '\p{^ 	In_JAMO_ext_B}', "");
Expect(1, 57344, '\P{ 	In_JAMO_ext_B}', "");
Expect(0, 57344, '\P{^ 	In_JAMO_ext_B}', "");
Error('\p{/a/  HANGUL_syllables}');
Error('\P{/a/  HANGUL_syllables}');
Expect(1, 55215, '\p{hangulsyllables}', "");
Expect(0, 55215, '\p{^hangulsyllables}', "");
Expect(0, 55215, '\P{hangulsyllables}', "");
Expect(1, 55215, '\P{^hangulsyllables}', "");
Expect(0, 55216, '\p{hangulsyllables}', "");
Expect(1, 55216, '\p{^hangulsyllables}', "");
Expect(1, 55216, '\P{hangulsyllables}', "");
Expect(0, 55216, '\P{^hangulsyllables}', "");
Expect(1, 55215, '\p{-_Hangul_syllables}', "");
Expect(0, 55215, '\p{^-_Hangul_syllables}', "");
Expect(0, 55215, '\P{-_Hangul_syllables}', "");
Expect(1, 55215, '\P{^-_Hangul_syllables}', "");
Expect(0, 55216, '\p{-_Hangul_syllables}', "");
Expect(1, 55216, '\p{^-_Hangul_syllables}', "");
Expect(1, 55216, '\P{-_Hangul_syllables}', "");
Expect(0, 55216, '\P{^-_Hangul_syllables}', "");
Error('\p{ IS_HANGUL_SYLLABLES/a/}');
Error('\P{ IS_HANGUL_SYLLABLES/a/}');
Expect(1, 55215, '\p{ishangulsyllables}', "");
Expect(0, 55215, '\p{^ishangulsyllables}', "");
Expect(0, 55215, '\P{ishangulsyllables}', "");
Expect(1, 55215, '\P{^ishangulsyllables}', "");
Expect(0, 55216, '\p{ishangulsyllables}', "");
Expect(1, 55216, '\p{^ishangulsyllables}', "");
Expect(1, 55216, '\P{ishangulsyllables}', "");
Expect(0, 55216, '\P{^ishangulsyllables}', "");
Expect(1, 55215, '\p{is_hangul_Syllables}', "");
Expect(0, 55215, '\p{^is_hangul_Syllables}', "");
Expect(0, 55215, '\P{is_hangul_Syllables}', "");
Expect(1, 55215, '\P{^is_hangul_Syllables}', "");
Expect(0, 55216, '\p{is_hangul_Syllables}', "");
Expect(1, 55216, '\p{^is_hangul_Syllables}', "");
Expect(1, 55216, '\P{is_hangul_Syllables}', "");
Expect(0, 55216, '\P{^is_hangul_Syllables}', "");
Error('\p{_:=In_HANGUL_Syllables}');
Error('\P{_:=In_HANGUL_Syllables}');
Expect(1, 55215, '\p{inhangulsyllables}', "");
Expect(0, 55215, '\p{^inhangulsyllables}', "");
Expect(0, 55215, '\P{inhangulsyllables}', "");
Expect(1, 55215, '\P{^inhangulsyllables}', "");
Expect(0, 55216, '\p{inhangulsyllables}', "");
Expect(1, 55216, '\p{^inhangulsyllables}', "");
Expect(1, 55216, '\P{inhangulsyllables}', "");
Expect(0, 55216, '\P{^inhangulsyllables}', "");
Expect(1, 55215, '\p{- in_Hangul_Syllables}', "");
Expect(0, 55215, '\p{^- in_Hangul_Syllables}', "");
Expect(0, 55215, '\P{- in_Hangul_Syllables}', "");
Expect(1, 55215, '\P{^- in_Hangul_Syllables}', "");
Expect(0, 55216, '\p{- in_Hangul_Syllables}', "");
Expect(1, 55216, '\p{^- in_Hangul_Syllables}', "");
Expect(1, 55216, '\P{- in_Hangul_Syllables}', "");
Expect(0, 55216, '\P{^- in_Hangul_Syllables}', "");
Error('\p{:=-In_Hangul}');
Error('\P{:=-In_Hangul}');
Expect(1, 55215, '\p{inhangul}', "");
Expect(0, 55215, '\p{^inhangul}', "");
Expect(0, 55215, '\P{inhangul}', "");
Expect(1, 55215, '\P{^inhangul}', "");
Expect(0, 55216, '\p{inhangul}', "");
Expect(1, 55216, '\p{^inhangul}', "");
Expect(1, 55216, '\P{inhangul}', "");
Expect(0, 55216, '\P{^inhangul}', "");
Expect(1, 55215, '\p{_	IN_Hangul}', "");
Expect(0, 55215, '\p{^_	IN_Hangul}', "");
Expect(0, 55215, '\P{_	IN_Hangul}', "");
Expect(1, 55215, '\P{^_	IN_Hangul}', "");
Expect(0, 55216, '\p{_	IN_Hangul}', "");
Expect(1, 55216, '\p{^_	IN_Hangul}', "");
Expect(1, 55216, '\P{_	IN_Hangul}', "");
Expect(0, 55216, '\P{^_	IN_Hangul}', "");
Error('\p{-/a/HANUNOO}');
Error('\P{-/a/HANUNOO}');
Expect(1, 5940, '\p{hanunoo}', "");
Expect(0, 5940, '\p{^hanunoo}', "");
Expect(0, 5940, '\P{hanunoo}', "");
Expect(1, 5940, '\P{^hanunoo}', "");
Expect(0, 5941, '\p{hanunoo}', "");
Expect(1, 5941, '\p{^hanunoo}', "");
Expect(1, 5941, '\P{hanunoo}', "");
Expect(0, 5941, '\P{^hanunoo}', "");
Expect(1, 5940, '\p{ Hanunoo}', "");
Expect(0, 5940, '\p{^ Hanunoo}', "");
Expect(0, 5940, '\P{ Hanunoo}', "");
Expect(1, 5940, '\P{^ Hanunoo}', "");
Expect(0, 5941, '\p{ Hanunoo}', "");
Expect(1, 5941, '\p{^ Hanunoo}', "");
Expect(1, 5941, '\P{ Hanunoo}', "");
Expect(0, 5941, '\P{^ Hanunoo}', "");
Error('\p{:=Is_hanunoo}');
Error('\P{:=Is_hanunoo}');
Expect(1, 5940, '\p{ishanunoo}', "");
Expect(0, 5940, '\p{^ishanunoo}', "");
Expect(0, 5940, '\P{ishanunoo}', "");
Expect(1, 5940, '\P{^ishanunoo}', "");
Expect(0, 5941, '\p{ishanunoo}', "");
Expect(1, 5941, '\p{^ishanunoo}', "");
Expect(1, 5941, '\P{ishanunoo}', "");
Expect(0, 5941, '\P{^ishanunoo}', "");
Expect(1, 5940, '\p{	 Is_Hanunoo}', "");
Expect(0, 5940, '\p{^	 Is_Hanunoo}', "");
Expect(0, 5940, '\P{	 Is_Hanunoo}', "");
Expect(1, 5940, '\P{^	 Is_Hanunoo}', "");
Expect(0, 5941, '\p{	 Is_Hanunoo}', "");
Expect(1, 5941, '\p{^	 Is_Hanunoo}', "");
Expect(1, 5941, '\P{	 Is_Hanunoo}', "");
Expect(0, 5941, '\P{^	 Is_Hanunoo}', "");
Error('\p{/a/	_hano}');
Error('\P{/a/	_hano}');
Expect(1, 5940, '\p{hano}', "");
Expect(0, 5940, '\p{^hano}', "");
Expect(0, 5940, '\P{hano}', "");
Expect(1, 5940, '\P{^hano}', "");
Expect(0, 5941, '\p{hano}', "");
Expect(1, 5941, '\p{^hano}', "");
Expect(1, 5941, '\P{hano}', "");
Expect(0, 5941, '\P{^hano}', "");
Expect(1, 5940, '\p{ HANO}', "");
Expect(0, 5940, '\p{^ HANO}', "");
Expect(0, 5940, '\P{ HANO}', "");
Expect(1, 5940, '\P{^ HANO}', "");
Expect(0, 5941, '\p{ HANO}', "");
Expect(1, 5941, '\p{^ HANO}', "");
Expect(1, 5941, '\P{ HANO}', "");
Expect(0, 5941, '\P{^ HANO}', "");
Error('\p{	is_HANO:=}');
Error('\P{	is_HANO:=}');
Expect(1, 5940, '\p{ishano}', "");
Expect(0, 5940, '\p{^ishano}', "");
Expect(0, 5940, '\P{ishano}', "");
Expect(1, 5940, '\P{^ishano}', "");
Expect(0, 5941, '\p{ishano}', "");
Expect(1, 5941, '\p{^ishano}', "");
Expect(1, 5941, '\P{ishano}', "");
Expect(0, 5941, '\P{^ishano}', "");
Expect(1, 5940, '\p{ _is_Hano}', "");
Expect(0, 5940, '\p{^ _is_Hano}', "");
Expect(0, 5940, '\P{ _is_Hano}', "");
Expect(1, 5940, '\P{^ _is_Hano}', "");
Expect(0, 5941, '\p{ _is_Hano}', "");
Expect(1, 5941, '\p{^ _is_Hano}', "");
Expect(1, 5941, '\P{ _is_Hano}', "");
Expect(0, 5941, '\P{^ _is_Hano}', "");
Error('\p{:=-HEBREW}');
Error('\P{:=-HEBREW}');
Expect(1, 64335, '\p{hebrew}', "");
Expect(0, 64335, '\p{^hebrew}', "");
Expect(0, 64335, '\P{hebrew}', "");
Expect(1, 64335, '\P{^hebrew}', "");
Expect(0, 64336, '\p{hebrew}', "");
Expect(1, 64336, '\p{^hebrew}', "");
Expect(1, 64336, '\P{hebrew}', "");
Expect(0, 64336, '\P{^hebrew}', "");
Expect(1, 64335, '\p{ -HEBREW}', "");
Expect(0, 64335, '\p{^ -HEBREW}', "");
Expect(0, 64335, '\P{ -HEBREW}', "");
Expect(1, 64335, '\P{^ -HEBREW}', "");
Expect(0, 64336, '\p{ -HEBREW}', "");
Expect(1, 64336, '\p{^ -HEBREW}', "");
Expect(1, 64336, '\P{ -HEBREW}', "");
Expect(0, 64336, '\P{^ -HEBREW}', "");
Error('\p{:=- Is_Hebrew}');
Error('\P{:=- Is_Hebrew}');
Expect(1, 64335, '\p{ishebrew}', "");
Expect(0, 64335, '\p{^ishebrew}', "");
Expect(0, 64335, '\P{ishebrew}', "");
Expect(1, 64335, '\P{^ishebrew}', "");
Expect(0, 64336, '\p{ishebrew}', "");
Expect(1, 64336, '\p{^ishebrew}', "");
Expect(1, 64336, '\P{ishebrew}', "");
Expect(0, 64336, '\P{^ishebrew}', "");
Expect(1, 64335, '\p{_-Is_HEBREW}', "");
Expect(0, 64335, '\p{^_-Is_HEBREW}', "");
Expect(0, 64335, '\P{_-Is_HEBREW}', "");
Expect(1, 64335, '\P{^_-Is_HEBREW}', "");
Expect(0, 64336, '\p{_-Is_HEBREW}', "");
Expect(1, 64336, '\p{^_-Is_HEBREW}', "");
Expect(1, 64336, '\P{_-Is_HEBREW}', "");
Expect(0, 64336, '\P{^_-Is_HEBREW}', "");
Error('\p{  HEBR:=}');
Error('\P{  HEBR:=}');
Expect(1, 64335, '\p{hebr}', "");
Expect(0, 64335, '\p{^hebr}', "");
Expect(0, 64335, '\P{hebr}', "");
Expect(1, 64335, '\P{^hebr}', "");
Expect(0, 64336, '\p{hebr}', "");
Expect(1, 64336, '\p{^hebr}', "");
Expect(1, 64336, '\P{hebr}', "");
Expect(0, 64336, '\P{^hebr}', "");
Expect(1, 64335, '\p{ -Hebr}', "");
Expect(0, 64335, '\p{^ -Hebr}', "");
Expect(0, 64335, '\P{ -Hebr}', "");
Expect(1, 64335, '\P{^ -Hebr}', "");
Expect(0, 64336, '\p{ -Hebr}', "");
Expect(1, 64336, '\p{^ -Hebr}', "");
Expect(1, 64336, '\P{ -Hebr}', "");
Expect(0, 64336, '\P{^ -Hebr}', "");
Error('\p{_is_hebr/a/}');
Error('\P{_is_hebr/a/}');
Expect(1, 64335, '\p{ishebr}', "");
Expect(0, 64335, '\p{^ishebr}', "");
Expect(0, 64335, '\P{ishebr}', "");
Expect(1, 64335, '\P{^ishebr}', "");
Expect(0, 64336, '\p{ishebr}', "");
Expect(1, 64336, '\p{^ishebr}', "");
Expect(1, 64336, '\P{ishebr}', "");
Expect(0, 64336, '\P{^ishebr}', "");
Expect(1, 64335, '\p{--is_HEBR}', "");
Expect(0, 64335, '\p{^--is_HEBR}', "");
Expect(0, 64335, '\P{--is_HEBR}', "");
Expect(1, 64335, '\P{^--is_HEBR}', "");
Expect(0, 64336, '\p{--is_HEBR}', "");
Expect(1, 64336, '\p{^--is_HEBR}', "");
Expect(1, 64336, '\P{--is_HEBR}', "");
Expect(0, 64336, '\P{^--is_HEBR}', "");
Error('\p{		High_Private_Use_SURROGATES:=}');
Error('\P{		High_Private_Use_SURROGATES:=}');
Expect(1, 56319, '\p{highprivateusesurrogates}', "");
Expect(0, 56319, '\p{^highprivateusesurrogates}', "");
Expect(0, 56319, '\P{highprivateusesurrogates}', "");
Expect(1, 56319, '\P{^highprivateusesurrogates}', "");
Expect(0, 57344, '\p{highprivateusesurrogates}', "");
Expect(1, 57344, '\p{^highprivateusesurrogates}', "");
Expect(1, 57344, '\P{highprivateusesurrogates}', "");
Expect(0, 57344, '\P{^highprivateusesurrogates}', "");
Expect(1, 56319, '\p{	-High_private_use_Surrogates}', "");
Expect(0, 56319, '\p{^	-High_private_use_Surrogates}', "");
Expect(0, 56319, '\P{	-High_private_use_Surrogates}', "");
Expect(1, 56319, '\P{^	-High_private_use_Surrogates}', "");
Expect(0, 57344, '\p{	-High_private_use_Surrogates}', "");
Expect(1, 57344, '\p{^	-High_private_use_Surrogates}', "");
Expect(1, 57344, '\P{	-High_private_use_Surrogates}', "");
Expect(0, 57344, '\P{^	-High_private_use_Surrogates}', "");
Error('\p{_:=Is_High_PRIVATE_use_Surrogates}');
Error('\P{_:=Is_High_PRIVATE_use_Surrogates}');
Expect(1, 56319, '\p{ishighprivateusesurrogates}', "");
Expect(0, 56319, '\p{^ishighprivateusesurrogates}', "");
Expect(0, 56319, '\P{ishighprivateusesurrogates}', "");
Expect(1, 56319, '\P{^ishighprivateusesurrogates}', "");
Expect(0, 57344, '\p{ishighprivateusesurrogates}', "");
Expect(1, 57344, '\p{^ishighprivateusesurrogates}', "");
Expect(1, 57344, '\P{ishighprivateusesurrogates}', "");
Expect(0, 57344, '\P{^ishighprivateusesurrogates}', "");
Expect(1, 56319, '\p{ _IS_HIGH_PRIVATE_Use_Surrogates}', "");
Expect(0, 56319, '\p{^ _IS_HIGH_PRIVATE_Use_Surrogates}', "");
Expect(0, 56319, '\P{ _IS_HIGH_PRIVATE_Use_Surrogates}', "");
Expect(1, 56319, '\P{^ _IS_HIGH_PRIVATE_Use_Surrogates}', "");
Expect(0, 57344, '\p{ _IS_HIGH_PRIVATE_Use_Surrogates}', "");
Expect(1, 57344, '\p{^ _IS_HIGH_PRIVATE_Use_Surrogates}', "");
Expect(1, 57344, '\P{ _IS_HIGH_PRIVATE_Use_Surrogates}', "");
Expect(0, 57344, '\P{^ _IS_HIGH_PRIVATE_Use_Surrogates}', "");
Error('\p{-In_High_PRIVATE_Use_SURROGATES/a/}');
Error('\P{-In_High_PRIVATE_Use_SURROGATES/a/}');
Expect(1, 56319, '\p{inhighprivateusesurrogates}', "");
Expect(0, 56319, '\p{^inhighprivateusesurrogates}', "");
Expect(0, 56319, '\P{inhighprivateusesurrogates}', "");
Expect(1, 56319, '\P{^inhighprivateusesurrogates}', "");
Expect(0, 57344, '\p{inhighprivateusesurrogates}', "");
Expect(1, 57344, '\p{^inhighprivateusesurrogates}', "");
Expect(1, 57344, '\P{inhighprivateusesurrogates}', "");
Expect(0, 57344, '\P{^inhighprivateusesurrogates}', "");
Expect(1, 56319, '\p{_In_High_Private_USE_SURROGATES}', "");
Expect(0, 56319, '\p{^_In_High_Private_USE_SURROGATES}', "");
Expect(0, 56319, '\P{_In_High_Private_USE_SURROGATES}', "");
Expect(1, 56319, '\P{^_In_High_Private_USE_SURROGATES}', "");
Expect(0, 57344, '\p{_In_High_Private_USE_SURROGATES}', "");
Expect(1, 57344, '\p{^_In_High_Private_USE_SURROGATES}', "");
Expect(1, 57344, '\P{_In_High_Private_USE_SURROGATES}', "");
Expect(0, 57344, '\P{^_In_High_Private_USE_SURROGATES}', "");
Error('\p{:=_ HIGH_PU_Surrogates}');
Error('\P{:=_ HIGH_PU_Surrogates}');
Expect(1, 56319, '\p{highpusurrogates}', "");
Expect(0, 56319, '\p{^highpusurrogates}', "");
Expect(0, 56319, '\P{highpusurrogates}', "");
Expect(1, 56319, '\P{^highpusurrogates}', "");
Expect(0, 57344, '\p{highpusurrogates}', "");
Expect(1, 57344, '\p{^highpusurrogates}', "");
Expect(1, 57344, '\P{highpusurrogates}', "");
Expect(0, 57344, '\P{^highpusurrogates}', "");
Expect(1, 56319, '\p{--HIGH_pu_surrogates}', "");
Expect(0, 56319, '\p{^--HIGH_pu_surrogates}', "");
Expect(0, 56319, '\P{--HIGH_pu_surrogates}', "");
Expect(1, 56319, '\P{^--HIGH_pu_surrogates}', "");
Expect(0, 57344, '\p{--HIGH_pu_surrogates}', "");
Expect(1, 57344, '\p{^--HIGH_pu_surrogates}', "");
Expect(1, 57344, '\P{--HIGH_pu_surrogates}', "");
Expect(0, 57344, '\P{^--HIGH_pu_surrogates}', "");
Error('\p{:=-Is_High_PU_SURROGATES}');
Error('\P{:=-Is_High_PU_SURROGATES}');
Expect(1, 56319, '\p{ishighpusurrogates}', "");
Expect(0, 56319, '\p{^ishighpusurrogates}', "");
Expect(0, 56319, '\P{ishighpusurrogates}', "");
Expect(1, 56319, '\P{^ishighpusurrogates}', "");
Expect(0, 57344, '\p{ishighpusurrogates}', "");
Expect(1, 57344, '\p{^ishighpusurrogates}', "");
Expect(1, 57344, '\P{ishighpusurrogates}', "");
Expect(0, 57344, '\P{^ishighpusurrogates}', "");
Expect(1, 56319, '\p{_	Is_High_PU_SURROGATES}', "");
Expect(0, 56319, '\p{^_	Is_High_PU_SURROGATES}', "");
Expect(0, 56319, '\P{_	Is_High_PU_SURROGATES}', "");
Expect(1, 56319, '\P{^_	Is_High_PU_SURROGATES}', "");
Expect(0, 57344, '\p{_	Is_High_PU_SURROGATES}', "");
Expect(1, 57344, '\p{^_	Is_High_PU_SURROGATES}', "");
Expect(1, 57344, '\P{_	Is_High_PU_SURROGATES}', "");
Expect(0, 57344, '\P{^_	Is_High_PU_SURROGATES}', "");
Error('\p{	In_High_PU_Surrogates:=}');
Error('\P{	In_High_PU_Surrogates:=}');
Expect(1, 56319, '\p{inhighpusurrogates}', "");
Expect(0, 56319, '\p{^inhighpusurrogates}', "");
Expect(0, 56319, '\P{inhighpusurrogates}', "");
Expect(1, 56319, '\P{^inhighpusurrogates}', "");
Expect(0, 57344, '\p{inhighpusurrogates}', "");
Expect(1, 57344, '\p{^inhighpusurrogates}', "");
Expect(1, 57344, '\P{inhighpusurrogates}', "");
Expect(0, 57344, '\P{^inhighpusurrogates}', "");
Expect(1, 56319, '\p{_In_HIGH_PU_Surrogates}', "");
Expect(0, 56319, '\p{^_In_HIGH_PU_Surrogates}', "");
Expect(0, 56319, '\P{_In_HIGH_PU_Surrogates}', "");
Expect(1, 56319, '\P{^_In_HIGH_PU_Surrogates}', "");
Expect(0, 57344, '\p{_In_HIGH_PU_Surrogates}', "");
Expect(1, 57344, '\p{^_In_HIGH_PU_Surrogates}', "");
Expect(1, 57344, '\P{_In_HIGH_PU_Surrogates}', "");
Expect(0, 57344, '\P{^_In_HIGH_PU_Surrogates}', "");
Error('\p{:=_High_Surrogates}');
Error('\P{:=_High_Surrogates}');
Expect(1, 56191, '\p{highsurrogates}', "");
Expect(0, 56191, '\p{^highsurrogates}', "");
Expect(0, 56191, '\P{highsurrogates}', "");
Expect(1, 56191, '\P{^highsurrogates}', "");
Expect(0, 57344, '\p{highsurrogates}', "");
Expect(1, 57344, '\p{^highsurrogates}', "");
Expect(1, 57344, '\P{highsurrogates}', "");
Expect(0, 57344, '\P{^highsurrogates}', "");
Expect(1, 56191, '\p{ high_surrogates}', "");
Expect(0, 56191, '\p{^ high_surrogates}', "");
Expect(0, 56191, '\P{ high_surrogates}', "");
Expect(1, 56191, '\P{^ high_surrogates}', "");
Expect(0, 57344, '\p{ high_surrogates}', "");
Expect(1, 57344, '\p{^ high_surrogates}', "");
Expect(1, 57344, '\P{ high_surrogates}', "");
Expect(0, 57344, '\P{^ high_surrogates}', "");
Error('\p{/a/		Is_High_SURROGATES}');
Error('\P{/a/		Is_High_SURROGATES}');
Expect(1, 56191, '\p{ishighsurrogates}', "");
Expect(0, 56191, '\p{^ishighsurrogates}', "");
Expect(0, 56191, '\P{ishighsurrogates}', "");
Expect(1, 56191, '\P{^ishighsurrogates}', "");
Expect(0, 57344, '\p{ishighsurrogates}', "");
Expect(1, 57344, '\p{^ishighsurrogates}', "");
Expect(1, 57344, '\P{ishighsurrogates}', "");
Expect(0, 57344, '\P{^ishighsurrogates}', "");
Expect(1, 56191, '\p{is_High_SURROGATES}', "");
Expect(0, 56191, '\p{^is_High_SURROGATES}', "");
Expect(0, 56191, '\P{is_High_SURROGATES}', "");
Expect(1, 56191, '\P{^is_High_SURROGATES}', "");
Expect(0, 57344, '\p{is_High_SURROGATES}', "");
Expect(1, 57344, '\p{^is_High_SURROGATES}', "");
Expect(1, 57344, '\P{is_High_SURROGATES}', "");
Expect(0, 57344, '\P{^is_High_SURROGATES}', "");
Error('\p{/a/_In_High_Surrogates}');
Error('\P{/a/_In_High_Surrogates}');
Expect(1, 56191, '\p{inhighsurrogates}', "");
Expect(0, 56191, '\p{^inhighsurrogates}', "");
Expect(0, 56191, '\P{inhighsurrogates}', "");
Expect(1, 56191, '\P{^inhighsurrogates}', "");
Expect(0, 57344, '\p{inhighsurrogates}', "");
Expect(1, 57344, '\p{^inhighsurrogates}', "");
Expect(1, 57344, '\P{inhighsurrogates}', "");
Expect(0, 57344, '\P{^inhighsurrogates}', "");
Expect(1, 56191, '\p{-In_HIGH_Surrogates}', "");
Expect(0, 56191, '\p{^-In_HIGH_Surrogates}', "");
Expect(0, 56191, '\P{-In_HIGH_Surrogates}', "");
Expect(1, 56191, '\P{^-In_HIGH_Surrogates}', "");
Expect(0, 57344, '\p{-In_HIGH_Surrogates}', "");
Expect(1, 57344, '\p{^-In_HIGH_Surrogates}', "");
Expect(1, 57344, '\P{-In_HIGH_Surrogates}', "");
Expect(0, 57344, '\P{^-In_HIGH_Surrogates}', "");
Error('\p{_:=HIRAGANA}');
Error('\P{_:=HIRAGANA}');
Expect(1, 127488, '\p{hiragana}', "");
Expect(0, 127488, '\p{^hiragana}', "");
Expect(0, 127488, '\P{hiragana}', "");
Expect(1, 127488, '\P{^hiragana}', "");
Expect(0, 127489, '\p{hiragana}', "");
Expect(1, 127489, '\p{^hiragana}', "");
Expect(1, 127489, '\P{hiragana}', "");
Expect(0, 127489, '\P{^hiragana}', "");
Expect(1, 127488, '\p{		HIRAGANA}', "");
Expect(0, 127488, '\p{^		HIRAGANA}', "");
Expect(0, 127488, '\P{		HIRAGANA}', "");
Expect(1, 127488, '\P{^		HIRAGANA}', "");
Expect(0, 127489, '\p{		HIRAGANA}', "");
Expect(1, 127489, '\p{^		HIRAGANA}', "");
Expect(1, 127489, '\P{		HIRAGANA}', "");
Expect(0, 127489, '\P{^		HIRAGANA}', "");
Error('\p{	/a/Is_Hiragana}');
Error('\P{	/a/Is_Hiragana}');
Expect(1, 127488, '\p{ishiragana}', "");
Expect(0, 127488, '\p{^ishiragana}', "");
Expect(0, 127488, '\P{ishiragana}', "");
Expect(1, 127488, '\P{^ishiragana}', "");
Expect(0, 127489, '\p{ishiragana}', "");
Expect(1, 127489, '\p{^ishiragana}', "");
Expect(1, 127489, '\P{ishiragana}', "");
Expect(0, 127489, '\P{^ishiragana}', "");
Expect(1, 127488, '\p{	is_Hiragana}', "");
Expect(0, 127488, '\p{^	is_Hiragana}', "");
Expect(0, 127488, '\P{	is_Hiragana}', "");
Expect(1, 127488, '\P{^	is_Hiragana}', "");
Expect(0, 127489, '\p{	is_Hiragana}', "");
Expect(1, 127489, '\p{^	is_Hiragana}', "");
Expect(1, 127489, '\P{	is_Hiragana}', "");
Expect(0, 127489, '\P{^	is_Hiragana}', "");
Error('\p{ -HIRA/a/}');
Error('\P{ -HIRA/a/}');
Expect(1, 127488, '\p{hira}', "");
Expect(0, 127488, '\p{^hira}', "");
Expect(0, 127488, '\P{hira}', "");
Expect(1, 127488, '\P{^hira}', "");
Expect(0, 127489, '\p{hira}', "");
Expect(1, 127489, '\p{^hira}', "");
Expect(1, 127489, '\P{hira}', "");
Expect(0, 127489, '\P{^hira}', "");
Expect(1, 127488, '\p{-Hira}', "");
Expect(0, 127488, '\p{^-Hira}', "");
Expect(0, 127488, '\P{-Hira}', "");
Expect(1, 127488, '\P{^-Hira}', "");
Expect(0, 127489, '\p{-Hira}', "");
Expect(1, 127489, '\p{^-Hira}', "");
Expect(1, 127489, '\P{-Hira}', "");
Expect(0, 127489, '\P{^-Hira}', "");
Error('\p{/a/-Is_Hira}');
Error('\P{/a/-Is_Hira}');
Expect(1, 127488, '\p{ishira}', "");
Expect(0, 127488, '\p{^ishira}', "");
Expect(0, 127488, '\P{ishira}', "");
Expect(1, 127488, '\P{^ishira}', "");
Expect(0, 127489, '\p{ishira}', "");
Expect(1, 127489, '\p{^ishira}', "");
Expect(1, 127489, '\P{ishira}', "");
Expect(0, 127489, '\P{^ishira}', "");
Expect(1, 127488, '\p{ IS_Hira}', "");
Expect(0, 127488, '\p{^ IS_Hira}', "");
Expect(0, 127488, '\P{ IS_Hira}', "");
Expect(1, 127488, '\P{^ IS_Hira}', "");
Expect(0, 127489, '\p{ IS_Hira}', "");
Expect(1, 127489, '\p{^ IS_Hira}', "");
Expect(1, 127489, '\P{ IS_Hira}', "");
Expect(0, 127489, '\P{^ IS_Hira}', "");
Error('\p{--HYPHEN/a/}');
Error('\P{--HYPHEN/a/}');
Expect(1, 65381, '\p{hyphen}', 'deprecated');
Expect(0, 65381, '\p{^hyphen}', 'deprecated');
Expect(0, 65381, '\P{hyphen}', 'deprecated');
Expect(1, 65381, '\P{^hyphen}', 'deprecated');
Expect(0, 65382, '\p{hyphen}', 'deprecated');
Expect(1, 65382, '\p{^hyphen}', 'deprecated');
Expect(1, 65382, '\P{hyphen}', 'deprecated');
Expect(0, 65382, '\P{^hyphen}', 'deprecated');
Expect(1, 65381, '\p{_ HYPHEN}', 'deprecated');
Expect(0, 65381, '\p{^_ HYPHEN}', 'deprecated');
Expect(0, 65381, '\P{_ HYPHEN}', 'deprecated');
Expect(1, 65381, '\P{^_ HYPHEN}', 'deprecated');
Expect(0, 65382, '\p{_ HYPHEN}', 'deprecated');
Expect(1, 65382, '\p{^_ HYPHEN}', 'deprecated');
Expect(1, 65382, '\P{_ HYPHEN}', 'deprecated');
Expect(0, 65382, '\P{^_ HYPHEN}', 'deprecated');
Error('\p{ -is_Hyphen/a/}');
Error('\P{ -is_Hyphen/a/}');
Expect(1, 65381, '\p{ishyphen}', 'deprecated');
Expect(0, 65381, '\p{^ishyphen}', 'deprecated');
Expect(0, 65381, '\P{ishyphen}', 'deprecated');
Expect(1, 65381, '\P{^ishyphen}', 'deprecated');
Expect(0, 65382, '\p{ishyphen}', 'deprecated');
Expect(1, 65382, '\p{^ishyphen}', 'deprecated');
Expect(1, 65382, '\P{ishyphen}', 'deprecated');
Expect(0, 65382, '\P{^ishyphen}', 'deprecated');
Expect(1, 65381, '\p{_ IS_Hyphen}', 'deprecated');
Expect(0, 65381, '\p{^_ IS_Hyphen}', 'deprecated');
Expect(0, 65381, '\P{_ IS_Hyphen}', 'deprecated');
Expect(1, 65381, '\P{^_ IS_Hyphen}', 'deprecated');
Expect(0, 65382, '\p{_ IS_Hyphen}', 'deprecated');
Expect(1, 65382, '\p{^_ IS_Hyphen}', 'deprecated');
Expect(1, 65382, '\P{_ IS_Hyphen}', 'deprecated');
Expect(0, 65382, '\P{^_ IS_Hyphen}', 'deprecated');
Error('\p{ :=IDS_binary_Operator}');
Error('\P{ :=IDS_binary_Operator}');
Expect(1, 12283, '\p{idsbinaryoperator}', "");
Expect(0, 12283, '\p{^idsbinaryoperator}', "");
Expect(0, 12283, '\P{idsbinaryoperator}', "");
Expect(1, 12283, '\P{^idsbinaryoperator}', "");
Expect(0, 12284, '\p{idsbinaryoperator}', "");
Expect(1, 12284, '\p{^idsbinaryoperator}', "");
Expect(1, 12284, '\P{idsbinaryoperator}', "");
Expect(0, 12284, '\P{^idsbinaryoperator}', "");
Expect(1, 12283, '\p{ IDS_Binary_Operator}', "");
Expect(0, 12283, '\p{^ IDS_Binary_Operator}', "");
Expect(0, 12283, '\P{ IDS_Binary_Operator}', "");
Expect(1, 12283, '\P{^ IDS_Binary_Operator}', "");
Expect(0, 12284, '\p{ IDS_Binary_Operator}', "");
Expect(1, 12284, '\p{^ IDS_Binary_Operator}', "");
Expect(1, 12284, '\P{ IDS_Binary_Operator}', "");
Expect(0, 12284, '\P{^ IDS_Binary_Operator}', "");
Error('\p{	is_IDS_binary_operator:=}');
Error('\P{	is_IDS_binary_operator:=}');
Expect(1, 12283, '\p{isidsbinaryoperator}', "");
Expect(0, 12283, '\p{^isidsbinaryoperator}', "");
Expect(0, 12283, '\P{isidsbinaryoperator}', "");
Expect(1, 12283, '\P{^isidsbinaryoperator}', "");
Expect(0, 12284, '\p{isidsbinaryoperator}', "");
Expect(1, 12284, '\p{^isidsbinaryoperator}', "");
Expect(1, 12284, '\P{isidsbinaryoperator}', "");
Expect(0, 12284, '\P{^isidsbinaryoperator}', "");
Expect(1, 12283, '\p{--IS_IDS_binary_operator}', "");
Expect(0, 12283, '\p{^--IS_IDS_binary_operator}', "");
Expect(0, 12283, '\P{--IS_IDS_binary_operator}', "");
Expect(1, 12283, '\P{^--IS_IDS_binary_operator}', "");
Expect(0, 12284, '\p{--IS_IDS_binary_operator}', "");
Expect(1, 12284, '\p{^--IS_IDS_binary_operator}', "");
Expect(1, 12284, '\P{--IS_IDS_binary_operator}', "");
Expect(0, 12284, '\P{^--IS_IDS_binary_operator}', "");
Error('\p{/a/_IDSB}');
Error('\P{/a/_IDSB}');
Expect(1, 12283, '\p{idsb}', "");
Expect(0, 12283, '\p{^idsb}', "");
Expect(0, 12283, '\P{idsb}', "");
Expect(1, 12283, '\P{^idsb}', "");
Expect(0, 12284, '\p{idsb}', "");
Expect(1, 12284, '\p{^idsb}', "");
Expect(1, 12284, '\P{idsb}', "");
Expect(0, 12284, '\P{^idsb}', "");
Expect(1, 12283, '\p{_-IDSB}', "");
Expect(0, 12283, '\p{^_-IDSB}', "");
Expect(0, 12283, '\P{_-IDSB}', "");
Expect(1, 12283, '\P{^_-IDSB}', "");
Expect(0, 12284, '\p{_-IDSB}', "");
Expect(1, 12284, '\p{^_-IDSB}', "");
Expect(1, 12284, '\P{_-IDSB}', "");
Expect(0, 12284, '\P{^_-IDSB}', "");
Error('\p{/a/ is_IDSB}');
Error('\P{/a/ is_IDSB}');
Expect(1, 12283, '\p{isidsb}', "");
Expect(0, 12283, '\p{^isidsb}', "");
Expect(0, 12283, '\P{isidsb}', "");
Expect(1, 12283, '\P{^isidsb}', "");
Expect(0, 12284, '\p{isidsb}', "");
Expect(1, 12284, '\p{^isidsb}', "");
Expect(1, 12284, '\P{isidsb}', "");
Expect(0, 12284, '\P{^isidsb}', "");
Expect(1, 12283, '\p{-_Is_IDSB}', "");
Expect(0, 12283, '\p{^-_Is_IDSB}', "");
Expect(0, 12283, '\P{-_Is_IDSB}', "");
Expect(1, 12283, '\P{^-_Is_IDSB}', "");
Expect(0, 12284, '\p{-_Is_IDSB}', "");
Expect(1, 12284, '\p{^-_Is_IDSB}', "");
Expect(1, 12284, '\P{-_Is_IDSB}', "");
Expect(0, 12284, '\P{^-_Is_IDSB}', "");
Error('\p{_IDS_TRINARY_Operator:=}');
Error('\P{_IDS_TRINARY_Operator:=}');
Expect(1, 12275, '\p{idstrinaryoperator}', "");
Expect(0, 12275, '\p{^idstrinaryoperator}', "");
Expect(0, 12275, '\P{idstrinaryoperator}', "");
Expect(1, 12275, '\P{^idstrinaryoperator}', "");
Expect(0, 12276, '\p{idstrinaryoperator}', "");
Expect(1, 12276, '\p{^idstrinaryoperator}', "");
Expect(1, 12276, '\P{idstrinaryoperator}', "");
Expect(0, 12276, '\P{^idstrinaryoperator}', "");
Expect(1, 12275, '\p{-IDS_trinary_OPERATOR}', "");
Expect(0, 12275, '\p{^-IDS_trinary_OPERATOR}', "");
Expect(0, 12275, '\P{-IDS_trinary_OPERATOR}', "");
Expect(1, 12275, '\P{^-IDS_trinary_OPERATOR}', "");
Expect(0, 12276, '\p{-IDS_trinary_OPERATOR}', "");
Expect(1, 12276, '\p{^-IDS_trinary_OPERATOR}', "");
Expect(1, 12276, '\P{-IDS_trinary_OPERATOR}', "");
Expect(0, 12276, '\P{^-IDS_trinary_OPERATOR}', "");
Error('\p{_-Is_IDS_TRINARY_Operator:=}');
Error('\P{_-Is_IDS_TRINARY_Operator:=}');
Expect(1, 12275, '\p{isidstrinaryoperator}', "");
Expect(0, 12275, '\p{^isidstrinaryoperator}', "");
Expect(0, 12275, '\P{isidstrinaryoperator}', "");
Expect(1, 12275, '\P{^isidstrinaryoperator}', "");
Expect(0, 12276, '\p{isidstrinaryoperator}', "");
Expect(1, 12276, '\p{^isidstrinaryoperator}', "");
Expect(1, 12276, '\P{isidstrinaryoperator}', "");
Expect(0, 12276, '\P{^isidstrinaryoperator}', "");
Expect(1, 12275, '\p{__IS_IDS_Trinary_OPERATOR}', "");
Expect(0, 12275, '\p{^__IS_IDS_Trinary_OPERATOR}', "");
Expect(0, 12275, '\P{__IS_IDS_Trinary_OPERATOR}', "");
Expect(1, 12275, '\P{^__IS_IDS_Trinary_OPERATOR}', "");
Expect(0, 12276, '\p{__IS_IDS_Trinary_OPERATOR}', "");
Expect(1, 12276, '\p{^__IS_IDS_Trinary_OPERATOR}', "");
Expect(1, 12276, '\P{__IS_IDS_Trinary_OPERATOR}', "");
Expect(0, 12276, '\P{^__IS_IDS_Trinary_OPERATOR}', "");
Error('\p{	:=idst}');
Error('\P{	:=idst}');
Expect(1, 12275, '\p{idst}', "");
Expect(0, 12275, '\p{^idst}', "");
Expect(0, 12275, '\P{idst}', "");
Expect(1, 12275, '\P{^idst}', "");
Expect(0, 12276, '\p{idst}', "");
Expect(1, 12276, '\p{^idst}', "");
Expect(1, 12276, '\P{idst}', "");
Expect(0, 12276, '\P{^idst}', "");
Expect(1, 12275, '\p{	idst}', "");
Expect(0, 12275, '\p{^	idst}', "");
Expect(0, 12275, '\P{	idst}', "");
Expect(1, 12275, '\P{^	idst}', "");
Expect(0, 12276, '\p{	idst}', "");
Expect(1, 12276, '\p{^	idst}', "");
Expect(1, 12276, '\P{	idst}', "");
Expect(0, 12276, '\P{^	idst}', "");
Error('\p{/a/ _Is_IDST}');
Error('\P{/a/ _Is_IDST}');
Expect(1, 12275, '\p{isidst}', "");
Expect(0, 12275, '\p{^isidst}', "");
Expect(0, 12275, '\P{isidst}', "");
Expect(1, 12275, '\P{^isidst}', "");
Expect(0, 12276, '\p{isidst}', "");
Expect(1, 12276, '\p{^isidst}', "");
Expect(1, 12276, '\P{isidst}', "");
Expect(0, 12276, '\P{^isidst}', "");
Expect(1, 12275, '\p{	is_IDST}', "");
Expect(0, 12275, '\p{^	is_IDST}', "");
Expect(0, 12275, '\P{	is_IDST}', "");
Expect(1, 12275, '\P{^	is_IDST}', "");
Expect(0, 12276, '\p{	is_IDST}', "");
Expect(1, 12276, '\p{^	is_IDST}', "");
Expect(1, 12276, '\P{	is_IDST}', "");
Expect(0, 12276, '\P{^	is_IDST}', "");
Error('\p{:=-	ID_Continue}');
Error('\P{:=-	ID_Continue}');
Expect(1, 917999, '\p{idcontinue}', "");
Expect(0, 917999, '\p{^idcontinue}', "");
Expect(0, 917999, '\P{idcontinue}', "");
Expect(1, 917999, '\P{^idcontinue}', "");
Expect(0, 918000, '\p{idcontinue}', "");
Expect(1, 918000, '\p{^idcontinue}', "");
Expect(1, 918000, '\P{idcontinue}', "");
Expect(0, 918000, '\P{^idcontinue}', "");
Expect(1, 917999, '\p{- ID_Continue}', "");
Expect(0, 917999, '\p{^- ID_Continue}', "");
Expect(0, 917999, '\P{- ID_Continue}', "");
Expect(1, 917999, '\P{^- ID_Continue}', "");
Expect(0, 918000, '\p{- ID_Continue}', "");
Expect(1, 918000, '\p{^- ID_Continue}', "");
Expect(1, 918000, '\P{- ID_Continue}', "");
Expect(0, 918000, '\P{^- ID_Continue}', "");
Error('\p{:=__IS_ID_CONTINUE}');
Error('\P{:=__IS_ID_CONTINUE}');
Expect(1, 917999, '\p{isidcontinue}', "");
Expect(0, 917999, '\p{^isidcontinue}', "");
Expect(0, 917999, '\P{isidcontinue}', "");
Expect(1, 917999, '\P{^isidcontinue}', "");
Expect(0, 918000, '\p{isidcontinue}', "");
Expect(1, 918000, '\p{^isidcontinue}', "");
Expect(1, 918000, '\P{isidcontinue}', "");
Expect(0, 918000, '\P{^isidcontinue}', "");
Expect(1, 917999, '\p{_	Is_ID_CONTINUE}', "");
Expect(0, 917999, '\p{^_	Is_ID_CONTINUE}', "");
Expect(0, 917999, '\P{_	Is_ID_CONTINUE}', "");
Expect(1, 917999, '\P{^_	Is_ID_CONTINUE}', "");
Expect(0, 918000, '\p{_	Is_ID_CONTINUE}', "");
Expect(1, 918000, '\p{^_	Is_ID_CONTINUE}', "");
Expect(1, 918000, '\P{_	Is_ID_CONTINUE}', "");
Expect(0, 918000, '\P{^_	Is_ID_CONTINUE}', "");
Error('\p{_IDC:=}');
Error('\P{_IDC:=}');
Expect(1, 917999, '\p{idc}', "");
Expect(0, 917999, '\p{^idc}', "");
Expect(0, 917999, '\P{idc}', "");
Expect(1, 917999, '\P{^idc}', "");
Expect(0, 918000, '\p{idc}', "");
Expect(1, 918000, '\p{^idc}', "");
Expect(1, 918000, '\P{idc}', "");
Expect(0, 918000, '\P{^idc}', "");
Expect(1, 917999, '\p{	-idc}', "");
Expect(0, 917999, '\p{^	-idc}', "");
Expect(0, 917999, '\P{	-idc}', "");
Expect(1, 917999, '\P{^	-idc}', "");
Expect(0, 918000, '\p{	-idc}', "");
Expect(1, 918000, '\p{^	-idc}', "");
Expect(1, 918000, '\P{	-idc}', "");
Expect(0, 918000, '\P{^	-idc}', "");
Error('\p{__is_IDC:=}');
Error('\P{__is_IDC:=}');
Expect(1, 917999, '\p{isidc}', "");
Expect(0, 917999, '\p{^isidc}', "");
Expect(0, 917999, '\P{isidc}', "");
Expect(1, 917999, '\P{^isidc}', "");
Expect(0, 918000, '\p{isidc}', "");
Expect(1, 918000, '\p{^isidc}', "");
Expect(1, 918000, '\P{isidc}', "");
Expect(0, 918000, '\P{^isidc}', "");
Expect(1, 917999, '\p{- Is_IDC}', "");
Expect(0, 917999, '\p{^- Is_IDC}', "");
Expect(0, 917999, '\P{- Is_IDC}', "");
Expect(1, 917999, '\P{^- Is_IDC}', "");
Expect(0, 918000, '\p{- Is_IDC}', "");
Expect(1, 918000, '\p{^- Is_IDC}', "");
Expect(1, 918000, '\P{- Is_IDC}', "");
Expect(0, 918000, '\P{^- Is_IDC}', "");
Error('\p{	:=id_start}');
Error('\P{	:=id_start}');
Expect(1, 195101, '\p{idstart}', "");
Expect(0, 195101, '\p{^idstart}', "");
Expect(0, 195101, '\P{idstart}', "");
Expect(1, 195101, '\P{^idstart}', "");
Expect(0, 195102, '\p{idstart}', "");
Expect(1, 195102, '\p{^idstart}', "");
Expect(1, 195102, '\P{idstart}', "");
Expect(0, 195102, '\P{^idstart}', "");
Expect(1, 195101, '\p{_ID_start}', "");
Expect(0, 195101, '\p{^_ID_start}', "");
Expect(0, 195101, '\P{_ID_start}', "");
Expect(1, 195101, '\P{^_ID_start}', "");
Expect(0, 195102, '\p{_ID_start}', "");
Expect(1, 195102, '\p{^_ID_start}', "");
Expect(1, 195102, '\P{_ID_start}', "");
Expect(0, 195102, '\P{^_ID_start}', "");
Error('\p{/a/ is_ID_START}');
Error('\P{/a/ is_ID_START}');
Expect(1, 195101, '\p{isidstart}', "");
Expect(0, 195101, '\p{^isidstart}', "");
Expect(0, 195101, '\P{isidstart}', "");
Expect(1, 195101, '\P{^isidstart}', "");
Expect(0, 195102, '\p{isidstart}', "");
Expect(1, 195102, '\p{^isidstart}', "");
Expect(1, 195102, '\P{isidstart}', "");
Expect(0, 195102, '\P{^isidstart}', "");
Expect(1, 195101, '\p{ -Is_ID_start}', "");
Expect(0, 195101, '\p{^ -Is_ID_start}', "");
Expect(0, 195101, '\P{ -Is_ID_start}', "");
Expect(1, 195101, '\P{^ -Is_ID_start}', "");
Expect(0, 195102, '\p{ -Is_ID_start}', "");
Expect(1, 195102, '\p{^ -Is_ID_start}', "");
Expect(1, 195102, '\P{ -Is_ID_start}', "");
Expect(0, 195102, '\P{^ -Is_ID_start}', "");
Error('\p{IDS:=}');
Error('\P{IDS:=}');
Expect(1, 195101, '\p{ids}', "");
Expect(0, 195101, '\p{^ids}', "");
Expect(0, 195101, '\P{ids}', "");
Expect(1, 195101, '\P{^ids}', "");
Expect(0, 195102, '\p{ids}', "");
Expect(1, 195102, '\p{^ids}', "");
Expect(1, 195102, '\P{ids}', "");
Expect(0, 195102, '\P{^ids}', "");
Expect(1, 195101, '\p{	_IDS}', "");
Expect(0, 195101, '\p{^	_IDS}', "");
Expect(0, 195101, '\P{	_IDS}', "");
Expect(1, 195101, '\P{^	_IDS}', "");
Expect(0, 195102, '\p{	_IDS}', "");
Expect(1, 195102, '\p{^	_IDS}', "");
Expect(1, 195102, '\P{	_IDS}', "");
Expect(0, 195102, '\P{^	_IDS}', "");
Error('\p{-:=Is_IDS}');
Error('\P{-:=Is_IDS}');
Expect(1, 195101, '\p{isids}', "");
Expect(0, 195101, '\p{^isids}', "");
Expect(0, 195101, '\P{isids}', "");
Expect(1, 195101, '\P{^isids}', "");
Expect(0, 195102, '\p{isids}', "");
Expect(1, 195102, '\p{^isids}', "");
Expect(1, 195102, '\P{isids}', "");
Expect(0, 195102, '\P{^isids}', "");
Expect(1, 195101, '\p{-	Is_IDS}', "");
Expect(0, 195101, '\p{^-	Is_IDS}', "");
Expect(0, 195101, '\P{-	Is_IDS}', "");
Expect(1, 195101, '\P{^-	Is_IDS}', "");
Expect(0, 195102, '\p{-	Is_IDS}', "");
Expect(1, 195102, '\p{^-	Is_IDS}', "");
Expect(1, 195102, '\P{-	Is_IDS}', "");
Expect(0, 195102, '\P{^-	Is_IDS}', "");
Error('\p{		ipa_Extensions/a/}');
Error('\P{		ipa_Extensions/a/}');
Expect(1, 687, '\p{ipaextensions}', "");
Expect(0, 687, '\p{^ipaextensions}', "");
Expect(0, 687, '\P{ipaextensions}', "");
Expect(1, 687, '\P{^ipaextensions}', "");
Expect(0, 688, '\p{ipaextensions}', "");
Expect(1, 688, '\p{^ipaextensions}', "");
Expect(1, 688, '\P{ipaextensions}', "");
Expect(0, 688, '\P{^ipaextensions}', "");
Expect(1, 687, '\p{		IPA_EXTENSIONS}', "");
Expect(0, 687, '\p{^		IPA_EXTENSIONS}', "");
Expect(0, 687, '\P{		IPA_EXTENSIONS}', "");
Expect(1, 687, '\P{^		IPA_EXTENSIONS}', "");
Expect(0, 688, '\p{		IPA_EXTENSIONS}', "");
Expect(1, 688, '\p{^		IPA_EXTENSIONS}', "");
Expect(1, 688, '\P{		IPA_EXTENSIONS}', "");
Expect(0, 688, '\P{^		IPA_EXTENSIONS}', "");
Error('\p{_is_IPA_EXTENSIONS:=}');
Error('\P{_is_IPA_EXTENSIONS:=}');
Expect(1, 687, '\p{isipaextensions}', "");
Expect(0, 687, '\p{^isipaextensions}', "");
Expect(0, 687, '\P{isipaextensions}', "");
Expect(1, 687, '\P{^isipaextensions}', "");
Expect(0, 688, '\p{isipaextensions}', "");
Expect(1, 688, '\p{^isipaextensions}', "");
Expect(1, 688, '\P{isipaextensions}', "");
Expect(0, 688, '\P{^isipaextensions}', "");
Expect(1, 687, '\p{- is_IPA_EXTENSIONS}', "");
Expect(0, 687, '\p{^- is_IPA_EXTENSIONS}', "");
Expect(0, 687, '\P{- is_IPA_EXTENSIONS}', "");
Expect(1, 687, '\P{^- is_IPA_EXTENSIONS}', "");
Expect(0, 688, '\p{- is_IPA_EXTENSIONS}', "");
Expect(1, 688, '\p{^- is_IPA_EXTENSIONS}', "");
Expect(1, 688, '\P{- is_IPA_EXTENSIONS}', "");
Expect(0, 688, '\P{^- is_IPA_EXTENSIONS}', "");
Error('\p{In_IPA_extensions:=}');
Error('\P{In_IPA_extensions:=}');
Expect(1, 687, '\p{inipaextensions}', "");
Expect(0, 687, '\p{^inipaextensions}', "");
Expect(0, 687, '\P{inipaextensions}', "");
Expect(1, 687, '\P{^inipaextensions}', "");
Expect(0, 688, '\p{inipaextensions}', "");
Expect(1, 688, '\p{^inipaextensions}', "");
Expect(1, 688, '\P{inipaextensions}', "");
Expect(0, 688, '\P{^inipaextensions}', "");
Expect(1, 687, '\p{IN_IPA_extensions}', "");
Expect(0, 687, '\p{^IN_IPA_extensions}', "");
Expect(0, 687, '\P{IN_IPA_extensions}', "");
Expect(1, 687, '\P{^IN_IPA_extensions}', "");
Expect(0, 688, '\p{IN_IPA_extensions}', "");
Expect(1, 688, '\p{^IN_IPA_extensions}', "");
Expect(1, 688, '\P{IN_IPA_extensions}', "");
Expect(0, 688, '\P{^IN_IPA_extensions}', "");
Error('\p{	-IPA_EXT/a/}');
Error('\P{	-IPA_EXT/a/}');
Expect(1, 687, '\p{ipaext}', "");
Expect(0, 687, '\p{^ipaext}', "");
Expect(0, 687, '\P{ipaext}', "");
Expect(1, 687, '\P{^ipaext}', "");
Expect(0, 688, '\p{ipaext}', "");
Expect(1, 688, '\p{^ipaext}', "");
Expect(1, 688, '\P{ipaext}', "");
Expect(0, 688, '\P{^ipaext}', "");
Expect(1, 687, '\p{ 	IPA_ext}', "");
Expect(0, 687, '\p{^ 	IPA_ext}', "");
Expect(0, 687, '\P{ 	IPA_ext}', "");
Expect(1, 687, '\P{^ 	IPA_ext}', "");
Expect(0, 688, '\p{ 	IPA_ext}', "");
Expect(1, 688, '\p{^ 	IPA_ext}', "");
Expect(1, 688, '\P{ 	IPA_ext}', "");
Expect(0, 688, '\P{^ 	IPA_ext}', "");
Error('\p{-:=is_ipa_Ext}');
Error('\P{-:=is_ipa_Ext}');
Expect(1, 687, '\p{isipaext}', "");
Expect(0, 687, '\p{^isipaext}', "");
Expect(0, 687, '\P{isipaext}', "");
Expect(1, 687, '\P{^isipaext}', "");
Expect(0, 688, '\p{isipaext}', "");
Expect(1, 688, '\p{^isipaext}', "");
Expect(1, 688, '\P{isipaext}', "");
Expect(0, 688, '\P{^isipaext}', "");
Expect(1, 687, '\p{_is_IPA_EXT}', "");
Expect(0, 687, '\p{^_is_IPA_EXT}', "");
Expect(0, 687, '\P{_is_IPA_EXT}', "");
Expect(1, 687, '\P{^_is_IPA_EXT}', "");
Expect(0, 688, '\p{_is_IPA_EXT}', "");
Expect(1, 688, '\p{^_is_IPA_EXT}', "");
Expect(1, 688, '\P{_is_IPA_EXT}', "");
Expect(0, 688, '\P{^_is_IPA_EXT}', "");
Error('\p{ :=In_ipa_ext}');
Error('\P{ :=In_ipa_ext}');
Expect(1, 687, '\p{inipaext}', "");
Expect(0, 687, '\p{^inipaext}', "");
Expect(0, 687, '\P{inipaext}', "");
Expect(1, 687, '\P{^inipaext}', "");
Expect(0, 688, '\p{inipaext}', "");
Expect(1, 688, '\p{^inipaext}', "");
Expect(1, 688, '\P{inipaext}', "");
Expect(0, 688, '\P{^inipaext}', "");
Expect(1, 687, '\p{	 In_IPA_Ext}', "");
Expect(0, 687, '\p{^	 In_IPA_Ext}', "");
Expect(0, 687, '\P{	 In_IPA_Ext}', "");
Expect(1, 687, '\P{^	 In_IPA_Ext}', "");
Expect(0, 688, '\p{	 In_IPA_Ext}', "");
Expect(1, 688, '\p{^	 In_IPA_Ext}', "");
Expect(1, 688, '\P{	 In_IPA_Ext}', "");
Expect(0, 688, '\P{^	 In_IPA_Ext}', "");
Error('\p{:=_Ideographic}');
Error('\P{:=_Ideographic}');
Expect(1, 195101, '\p{ideographic}', "");
Expect(0, 195101, '\p{^ideographic}', "");
Expect(0, 195101, '\P{ideographic}', "");
Expect(1, 195101, '\P{^ideographic}', "");
Expect(0, 195102, '\p{ideographic}', "");
Expect(1, 195102, '\p{^ideographic}', "");
Expect(1, 195102, '\P{ideographic}', "");
Expect(0, 195102, '\P{^ideographic}', "");
Expect(1, 195101, '\p{- ideographic}', "");
Expect(0, 195101, '\p{^- ideographic}', "");
Expect(0, 195101, '\P{- ideographic}', "");
Expect(1, 195101, '\P{^- ideographic}', "");
Expect(0, 195102, '\p{- ideographic}', "");
Expect(1, 195102, '\p{^- ideographic}', "");
Expect(1, 195102, '\P{- ideographic}', "");
Expect(0, 195102, '\P{^- ideographic}', "");
Error('\p{/a/is_IDEOGRAPHIC}');
Error('\P{/a/is_IDEOGRAPHIC}');
Expect(1, 195101, '\p{isideographic}', "");
Expect(0, 195101, '\p{^isideographic}', "");
Expect(0, 195101, '\P{isideographic}', "");
Expect(1, 195101, '\P{^isideographic}', "");
Expect(0, 195102, '\p{isideographic}', "");
Expect(1, 195102, '\p{^isideographic}', "");
Expect(1, 195102, '\P{isideographic}', "");
Expect(0, 195102, '\P{^isideographic}', "");
Expect(1, 195101, '\p{_	IS_IDEOGRAPHIC}', "");
Expect(0, 195101, '\p{^_	IS_IDEOGRAPHIC}', "");
Expect(0, 195101, '\P{_	IS_IDEOGRAPHIC}', "");
Expect(1, 195101, '\P{^_	IS_IDEOGRAPHIC}', "");
Expect(0, 195102, '\p{_	IS_IDEOGRAPHIC}', "");
Expect(1, 195102, '\p{^_	IS_IDEOGRAPHIC}', "");
Expect(1, 195102, '\P{_	IS_IDEOGRAPHIC}', "");
Expect(0, 195102, '\P{^_	IS_IDEOGRAPHIC}', "");
Error('\p{ ideo/a/}');
Error('\P{ ideo/a/}');
Expect(1, 195101, '\p{ideo}', "");
Expect(0, 195101, '\p{^ideo}', "");
Expect(0, 195101, '\P{ideo}', "");
Expect(1, 195101, '\P{^ideo}', "");
Expect(0, 195102, '\p{ideo}', "");
Expect(1, 195102, '\p{^ideo}', "");
Expect(1, 195102, '\P{ideo}', "");
Expect(0, 195102, '\P{^ideo}', "");
Expect(1, 195101, '\p{-	Ideo}', "");
Expect(0, 195101, '\p{^-	Ideo}', "");
Expect(0, 195101, '\P{-	Ideo}', "");
Expect(1, 195101, '\P{^-	Ideo}', "");
Expect(0, 195102, '\p{-	Ideo}', "");
Expect(1, 195102, '\p{^-	Ideo}', "");
Expect(1, 195102, '\P{-	Ideo}', "");
Expect(0, 195102, '\P{^-	Ideo}', "");
Error('\p{:=	 IS_Ideo}');
Error('\P{:=	 IS_Ideo}');
Expect(1, 195101, '\p{isideo}', "");
Expect(0, 195101, '\p{^isideo}', "");
Expect(0, 195101, '\P{isideo}', "");
Expect(1, 195101, '\P{^isideo}', "");
Expect(0, 195102, '\p{isideo}', "");
Expect(1, 195102, '\p{^isideo}', "");
Expect(1, 195102, '\P{isideo}', "");
Expect(0, 195102, '\P{^isideo}', "");
Expect(1, 195101, '\p{__is_ideo}', "");
Expect(0, 195101, '\p{^__is_ideo}', "");
Expect(0, 195101, '\P{__is_ideo}', "");
Expect(1, 195101, '\P{^__is_ideo}', "");
Expect(0, 195102, '\p{__is_ideo}', "");
Expect(1, 195102, '\p{^__is_ideo}', "");
Expect(1, 195102, '\P{__is_ideo}', "");
Expect(0, 195102, '\P{^__is_ideo}', "");
Error('\p{:=	_IDEOGRAPHIC_Description_CHARACTERS}');
Error('\P{:=	_IDEOGRAPHIC_Description_CHARACTERS}');
Expect(1, 12287, '\p{ideographicdescriptioncharacters}', "");
Expect(0, 12287, '\p{^ideographicdescriptioncharacters}', "");
Expect(0, 12287, '\P{ideographicdescriptioncharacters}', "");
Expect(1, 12287, '\P{^ideographicdescriptioncharacters}', "");
Expect(0, 12288, '\p{ideographicdescriptioncharacters}', "");
Expect(1, 12288, '\p{^ideographicdescriptioncharacters}', "");
Expect(1, 12288, '\P{ideographicdescriptioncharacters}', "");
Expect(0, 12288, '\P{^ideographicdescriptioncharacters}', "");
Expect(1, 12287, '\p{_-Ideographic_description_Characters}', "");
Expect(0, 12287, '\p{^_-Ideographic_description_Characters}', "");
Expect(0, 12287, '\P{_-Ideographic_description_Characters}', "");
Expect(1, 12287, '\P{^_-Ideographic_description_Characters}', "");
Expect(0, 12288, '\p{_-Ideographic_description_Characters}', "");
Expect(1, 12288, '\p{^_-Ideographic_description_Characters}', "");
Expect(1, 12288, '\P{_-Ideographic_description_Characters}', "");
Expect(0, 12288, '\P{^_-Ideographic_description_Characters}', "");
Error('\p{:=IS_Ideographic_DESCRIPTION_CHARACTERS}');
Error('\P{:=IS_Ideographic_DESCRIPTION_CHARACTERS}');
Expect(1, 12287, '\p{isideographicdescriptioncharacters}', "");
Expect(0, 12287, '\p{^isideographicdescriptioncharacters}', "");
Expect(0, 12287, '\P{isideographicdescriptioncharacters}', "");
Expect(1, 12287, '\P{^isideographicdescriptioncharacters}', "");
Expect(0, 12288, '\p{isideographicdescriptioncharacters}', "");
Expect(1, 12288, '\p{^isideographicdescriptioncharacters}', "");
Expect(1, 12288, '\P{isideographicdescriptioncharacters}', "");
Expect(0, 12288, '\P{^isideographicdescriptioncharacters}', "");
Expect(1, 12287, '\p{_is_Ideographic_Description_Characters}', "");
Expect(0, 12287, '\p{^_is_Ideographic_Description_Characters}', "");
Expect(0, 12287, '\P{_is_Ideographic_Description_Characters}', "");
Expect(1, 12287, '\P{^_is_Ideographic_Description_Characters}', "");
Expect(0, 12288, '\p{_is_Ideographic_Description_Characters}', "");
Expect(1, 12288, '\p{^_is_Ideographic_Description_Characters}', "");
Expect(1, 12288, '\P{_is_Ideographic_Description_Characters}', "");
Expect(0, 12288, '\P{^_is_Ideographic_Description_Characters}', "");
Error('\p{	 IN_ideographic_description_characters/a/}');
Error('\P{	 IN_ideographic_description_characters/a/}');
Expect(1, 12287, '\p{inideographicdescriptioncharacters}', "");
Expect(0, 12287, '\p{^inideographicdescriptioncharacters}', "");
Expect(0, 12287, '\P{inideographicdescriptioncharacters}', "");
Expect(1, 12287, '\P{^inideographicdescriptioncharacters}', "");
Expect(0, 12288, '\p{inideographicdescriptioncharacters}', "");
Expect(1, 12288, '\p{^inideographicdescriptioncharacters}', "");
Expect(1, 12288, '\P{inideographicdescriptioncharacters}', "");
Expect(0, 12288, '\P{^inideographicdescriptioncharacters}', "");
Expect(1, 12287, '\p{In_ideographic_Description_characters}', "");
Expect(0, 12287, '\p{^In_ideographic_Description_characters}', "");
Expect(0, 12287, '\P{In_ideographic_Description_characters}', "");
Expect(1, 12287, '\P{^In_ideographic_Description_characters}', "");
Expect(0, 12288, '\p{In_ideographic_Description_characters}', "");
Expect(1, 12288, '\p{^In_ideographic_Description_characters}', "");
Expect(1, 12288, '\P{In_ideographic_Description_characters}', "");
Expect(0, 12288, '\P{^In_ideographic_Description_characters}', "");
Error('\p{-	In_IDC/a/}');
Error('\P{-	In_IDC/a/}');
Expect(1, 12287, '\p{inidc}', "");
Expect(0, 12287, '\p{^inidc}', "");
Expect(0, 12287, '\P{inidc}', "");
Expect(1, 12287, '\P{^inidc}', "");
Expect(0, 12288, '\p{inidc}', "");
Expect(1, 12288, '\p{^inidc}', "");
Expect(1, 12288, '\P{inidc}', "");
Expect(0, 12288, '\P{^inidc}', "");
Expect(1, 12287, '\p{		In_IDC}', "");
Expect(0, 12287, '\p{^		In_IDC}', "");
Expect(0, 12287, '\P{		In_IDC}', "");
Expect(1, 12287, '\P{^		In_IDC}', "");
Expect(0, 12288, '\p{		In_IDC}', "");
Expect(1, 12288, '\p{^		In_IDC}', "");
Expect(1, 12288, '\P{		In_IDC}', "");
Expect(0, 12288, '\P{^		In_IDC}', "");
Error('\p{/a/		IMPERIAL_Aramaic}');
Error('\P{/a/		IMPERIAL_Aramaic}');
Expect(1, 67679, '\p{imperialaramaic}', "");
Expect(0, 67679, '\p{^imperialaramaic}', "");
Expect(0, 67679, '\P{imperialaramaic}', "");
Expect(1, 67679, '\P{^imperialaramaic}', "");
Expect(0, 67680, '\p{imperialaramaic}', "");
Expect(1, 67680, '\p{^imperialaramaic}', "");
Expect(1, 67680, '\P{imperialaramaic}', "");
Expect(0, 67680, '\P{^imperialaramaic}', "");
Expect(1, 67679, '\p{Imperial_Aramaic}', "");
Expect(0, 67679, '\p{^Imperial_Aramaic}', "");
Expect(0, 67679, '\P{Imperial_Aramaic}', "");
Expect(1, 67679, '\P{^Imperial_Aramaic}', "");
Expect(0, 67680, '\p{Imperial_Aramaic}', "");
Expect(1, 67680, '\p{^Imperial_Aramaic}', "");
Expect(1, 67680, '\P{Imperial_Aramaic}', "");
Expect(0, 67680, '\P{^Imperial_Aramaic}', "");
Error('\p{	:=is_Imperial_Aramaic}');
Error('\P{	:=is_Imperial_Aramaic}');
Expect(1, 67679, '\p{isimperialaramaic}', "");
Expect(0, 67679, '\p{^isimperialaramaic}', "");
Expect(0, 67679, '\P{isimperialaramaic}', "");
Expect(1, 67679, '\P{^isimperialaramaic}', "");
Expect(0, 67680, '\p{isimperialaramaic}', "");
Expect(1, 67680, '\p{^isimperialaramaic}', "");
Expect(1, 67680, '\P{isimperialaramaic}', "");
Expect(0, 67680, '\P{^isimperialaramaic}', "");
Expect(1, 67679, '\p{__IS_imperial_Aramaic}', "");
Expect(0, 67679, '\p{^__IS_imperial_Aramaic}', "");
Expect(0, 67679, '\P{__IS_imperial_Aramaic}', "");
Expect(1, 67679, '\P{^__IS_imperial_Aramaic}', "");
Expect(0, 67680, '\p{__IS_imperial_Aramaic}', "");
Expect(1, 67680, '\p{^__IS_imperial_Aramaic}', "");
Expect(1, 67680, '\P{__IS_imperial_Aramaic}', "");
Expect(0, 67680, '\P{^__IS_imperial_Aramaic}', "");
Error('\p{--armi/a/}');
Error('\P{--armi/a/}');
Expect(1, 67679, '\p{armi}', "");
Expect(0, 67679, '\p{^armi}', "");
Expect(0, 67679, '\P{armi}', "");
Expect(1, 67679, '\P{^armi}', "");
Expect(0, 67680, '\p{armi}', "");
Expect(1, 67680, '\p{^armi}', "");
Expect(1, 67680, '\P{armi}', "");
Expect(0, 67680, '\P{^armi}', "");
Expect(1, 67679, '\p{  Armi}', "");
Expect(0, 67679, '\p{^  Armi}', "");
Expect(0, 67679, '\P{  Armi}', "");
Expect(1, 67679, '\P{^  Armi}', "");
Expect(0, 67680, '\p{  Armi}', "");
Expect(1, 67680, '\p{^  Armi}', "");
Expect(1, 67680, '\P{  Armi}', "");
Expect(0, 67680, '\P{^  Armi}', "");
Error('\p{	 Is_Armi/a/}');
Error('\P{	 Is_Armi/a/}');
Expect(1, 67679, '\p{isarmi}', "");
Expect(0, 67679, '\p{^isarmi}', "");
Expect(0, 67679, '\P{isarmi}', "");
Expect(1, 67679, '\P{^isarmi}', "");
Expect(0, 67680, '\p{isarmi}', "");
Expect(1, 67680, '\p{^isarmi}', "");
Expect(1, 67680, '\P{isarmi}', "");
Expect(0, 67680, '\P{^isarmi}', "");
Expect(1, 67679, '\p{	Is_armi}', "");
Expect(0, 67679, '\p{^	Is_armi}', "");
Expect(0, 67679, '\P{	Is_armi}', "");
Expect(1, 67679, '\P{^	Is_armi}', "");
Expect(0, 67680, '\p{	Is_armi}', "");
Expect(1, 67680, '\p{^	Is_armi}', "");
Expect(1, 67680, '\P{	Is_armi}', "");
Expect(0, 67680, '\P{^	Is_armi}', "");
Error('\p{  In_arabic/a/}');
Error('\P{  In_arabic/a/}');
Expect(1, 1791, '\p{inarabic}', "");
Expect(0, 1791, '\p{^inarabic}', "");
Expect(0, 1791, '\P{inarabic}', "");
Expect(1, 1791, '\P{^inarabic}', "");
Expect(0, 1792, '\p{inarabic}', "");
Expect(1, 1792, '\p{^inarabic}', "");
Expect(1, 1792, '\P{inarabic}', "");
Expect(0, 1792, '\P{^inarabic}', "");
Expect(1, 1791, '\p{	 In_ARABIC}', "");
Expect(0, 1791, '\p{^	 In_ARABIC}', "");
Expect(0, 1791, '\P{	 In_ARABIC}', "");
Expect(1, 1791, '\P{^	 In_ARABIC}', "");
Expect(0, 1792, '\p{	 In_ARABIC}', "");
Expect(1, 1792, '\p{^	 In_ARABIC}', "");
Expect(1, 1792, '\P{	 In_ARABIC}', "");
Expect(0, 1792, '\P{^	 In_ARABIC}', "");
Error('\p{:=		In_Arabic}');
Error('\P{:=		In_Arabic}');
Expect(1, 1791, '\p{  In_Arabic}', "");
Expect(0, 1791, '\p{^  In_Arabic}', "");
Expect(0, 1791, '\P{  In_Arabic}', "");
Expect(1, 1791, '\P{^  In_Arabic}', "");
Expect(0, 1792, '\p{  In_Arabic}', "");
Expect(1, 1792, '\p{^  In_Arabic}', "");
Expect(1, 1792, '\P{  In_Arabic}', "");
Expect(0, 1792, '\P{^  In_Arabic}', "");
Error('\p{ :=In_armenian}');
Error('\P{ :=In_armenian}');
Expect(1, 1423, '\p{inarmenian}', "");
Expect(0, 1423, '\p{^inarmenian}', "");
Expect(0, 1423, '\P{inarmenian}', "");
Expect(1, 1423, '\P{^inarmenian}', "");
Expect(0, 1424, '\p{inarmenian}', "");
Expect(1, 1424, '\p{^inarmenian}', "");
Expect(1, 1424, '\P{inarmenian}', "");
Expect(0, 1424, '\P{^inarmenian}', "");
Expect(1, 1423, '\p{_-In_Armenian}', "");
Expect(0, 1423, '\p{^_-In_Armenian}', "");
Expect(0, 1423, '\P{_-In_Armenian}', "");
Expect(1, 1423, '\P{^_-In_Armenian}', "");
Expect(0, 1424, '\p{_-In_Armenian}', "");
Expect(1, 1424, '\p{^_-In_Armenian}', "");
Expect(1, 1424, '\P{_-In_Armenian}', "");
Expect(0, 1424, '\P{^_-In_Armenian}', "");
Error('\p{-IN_Armenian:=}');
Error('\P{-IN_Armenian:=}');
Expect(1, 1423, '\p{-	IN_ARMENIAN}', "");
Expect(0, 1423, '\p{^-	IN_ARMENIAN}', "");
Expect(0, 1423, '\P{-	IN_ARMENIAN}', "");
Expect(1, 1423, '\P{^-	IN_ARMENIAN}', "");
Expect(0, 1424, '\p{-	IN_ARMENIAN}', "");
Expect(1, 1424, '\p{^-	IN_ARMENIAN}', "");
Expect(1, 1424, '\P{-	IN_ARMENIAN}', "");
Expect(0, 1424, '\P{^-	IN_ARMENIAN}', "");
Error('\p{/a/	-IN_Avestan}');
Error('\P{/a/	-IN_Avestan}');
Expect(1, 68415, '\p{inavestan}', "");
Expect(0, 68415, '\p{^inavestan}', "");
Expect(0, 68415, '\P{inavestan}', "");
Expect(1, 68415, '\P{^inavestan}', "");
Expect(0, 68416, '\p{inavestan}', "");
Expect(1, 68416, '\p{^inavestan}', "");
Expect(1, 68416, '\P{inavestan}', "");
Expect(0, 68416, '\P{^inavestan}', "");
Expect(1, 68415, '\p{_ in_AVESTAN}', "");
Expect(0, 68415, '\p{^_ in_AVESTAN}', "");
Expect(0, 68415, '\P{_ in_AVESTAN}', "");
Expect(1, 68415, '\P{^_ in_AVESTAN}', "");
Expect(0, 68416, '\p{_ in_AVESTAN}', "");
Expect(1, 68416, '\p{^_ in_AVESTAN}', "");
Expect(1, 68416, '\P{_ in_AVESTAN}', "");
Expect(0, 68416, '\P{^_ in_AVESTAN}', "");
Error('\p{:=	in_avestan}');
Error('\P{:=	in_avestan}');
Expect(1, 68415, '\p{		in_Avestan}', "");
Expect(0, 68415, '\p{^		in_Avestan}', "");
Expect(0, 68415, '\P{		in_Avestan}', "");
Expect(1, 68415, '\P{^		in_Avestan}', "");
Expect(0, 68416, '\p{		in_Avestan}', "");
Expect(1, 68416, '\p{^		in_Avestan}', "");
Expect(1, 68416, '\P{		in_Avestan}', "");
Expect(0, 68416, '\P{^		in_Avestan}', "");
Error('\p{:= in_BALINESE}');
Error('\P{:= in_BALINESE}');
Expect(1, 7039, '\p{inbalinese}', "");
Expect(0, 7039, '\p{^inbalinese}', "");
Expect(0, 7039, '\P{inbalinese}', "");
Expect(1, 7039, '\P{^inbalinese}', "");
Expect(0, 7040, '\p{inbalinese}', "");
Expect(1, 7040, '\p{^inbalinese}', "");
Expect(1, 7040, '\P{inbalinese}', "");
Expect(0, 7040, '\P{^inbalinese}', "");
Expect(1, 7039, '\p{-_In_balinese}', "");
Expect(0, 7039, '\p{^-_In_balinese}', "");
Expect(0, 7039, '\P{-_In_balinese}', "");
Expect(1, 7039, '\P{^-_In_balinese}', "");
Expect(0, 7040, '\p{-_In_balinese}', "");
Expect(1, 7040, '\p{^-_In_balinese}', "");
Expect(1, 7040, '\P{-_In_balinese}', "");
Expect(0, 7040, '\P{^-_In_balinese}', "");
Error('\p{ in_Balinese/a/}');
Error('\P{ in_Balinese/a/}');
Expect(1, 7039, '\p{-In_Balinese}', "");
Expect(0, 7039, '\p{^-In_Balinese}', "");
Expect(0, 7039, '\P{-In_Balinese}', "");
Expect(1, 7039, '\P{^-In_Balinese}', "");
Expect(0, 7040, '\p{-In_Balinese}', "");
Expect(1, 7040, '\p{^-In_Balinese}', "");
Expect(1, 7040, '\P{-In_Balinese}', "");
Expect(0, 7040, '\P{^-In_Balinese}', "");
Error('\p{_:=In_BAMUM}');
Error('\P{_:=In_BAMUM}');
Expect(1, 42751, '\p{inbamum}', "");
Expect(0, 42751, '\p{^inbamum}', "");
Expect(0, 42751, '\P{inbamum}', "");
Expect(1, 42751, '\P{^inbamum}', "");
Expect(0, 42752, '\p{inbamum}', "");
Expect(1, 42752, '\p{^inbamum}', "");
Expect(1, 42752, '\P{inbamum}', "");
Expect(0, 42752, '\P{^inbamum}', "");
Expect(1, 42751, '\p{ 	In_bamum}', "");
Expect(0, 42751, '\p{^ 	In_bamum}', "");
Expect(0, 42751, '\P{ 	In_bamum}', "");
Expect(1, 42751, '\P{^ 	In_bamum}', "");
Expect(0, 42752, '\p{ 	In_bamum}', "");
Expect(1, 42752, '\p{^ 	In_bamum}', "");
Expect(1, 42752, '\P{ 	In_bamum}', "");
Expect(0, 42752, '\P{^ 	In_bamum}', "");
Error('\p{/a/	_In_Bamum}');
Error('\P{/a/	_In_Bamum}');
Expect(1, 42751, '\p{In_BAMUM}', "");
Expect(0, 42751, '\p{^In_BAMUM}', "");
Expect(0, 42751, '\P{In_BAMUM}', "");
Expect(1, 42751, '\P{^In_BAMUM}', "");
Expect(0, 42752, '\p{In_BAMUM}', "");
Expect(1, 42752, '\p{^In_BAMUM}', "");
Expect(1, 42752, '\P{In_BAMUM}', "");
Expect(0, 42752, '\P{^In_BAMUM}', "");
Error('\p{- In_batak:=}');
Error('\P{- In_batak:=}');
Expect(1, 7167, '\p{inbatak}', "");
Expect(0, 7167, '\p{^inbatak}', "");
Expect(0, 7167, '\P{inbatak}', "");
Expect(1, 7167, '\P{^inbatak}', "");
Expect(0, 7168, '\p{inbatak}', "");
Expect(1, 7168, '\p{^inbatak}', "");
Expect(1, 7168, '\P{inbatak}', "");
Expect(0, 7168, '\P{^inbatak}', "");
Expect(1, 7167, '\p{_ In_Batak}', "");
Expect(0, 7167, '\p{^_ In_Batak}', "");
Expect(0, 7167, '\P{_ In_Batak}', "");
Expect(1, 7167, '\P{^_ In_Batak}', "");
Expect(0, 7168, '\p{_ In_Batak}', "");
Expect(1, 7168, '\p{^_ In_Batak}', "");
Expect(1, 7168, '\P{_ In_Batak}', "");
Expect(0, 7168, '\P{^_ In_Batak}', "");
Error('\p{/a/-	IN_Batak}');
Error('\P{/a/-	IN_Batak}');
Expect(1, 7167, '\p{ in_batak}', "");
Expect(0, 7167, '\p{^ in_batak}', "");
Expect(0, 7167, '\P{ in_batak}', "");
Expect(1, 7167, '\P{^ in_batak}', "");
Expect(0, 7168, '\p{ in_batak}', "");
Expect(1, 7168, '\p{^ in_batak}', "");
Expect(1, 7168, '\P{ in_batak}', "");
Expect(0, 7168, '\P{^ in_batak}', "");
Error('\p{:=	-IN_BENGALI}');
Error('\P{:=	-IN_BENGALI}');
Expect(1, 2559, '\p{inbengali}', "");
Expect(0, 2559, '\p{^inbengali}', "");
Expect(0, 2559, '\P{inbengali}', "");
Expect(1, 2559, '\P{^inbengali}', "");
Expect(0, 2560, '\p{inbengali}', "");
Expect(1, 2560, '\p{^inbengali}', "");
Expect(1, 2560, '\P{inbengali}', "");
Expect(0, 2560, '\P{^inbengali}', "");
Expect(1, 2559, '\p{	_IN_bengali}', "");
Expect(0, 2559, '\p{^	_IN_bengali}', "");
Expect(0, 2559, '\P{	_IN_bengali}', "");
Expect(1, 2559, '\P{^	_IN_bengali}', "");
Expect(0, 2560, '\p{	_IN_bengali}', "");
Expect(1, 2560, '\p{^	_IN_bengali}', "");
Expect(1, 2560, '\P{	_IN_bengali}', "");
Expect(0, 2560, '\P{^	_IN_bengali}', "");
Error('\p{ IN_Bengali/a/}');
Error('\P{ IN_Bengali/a/}');
Expect(1, 2559, '\p{_-In_Bengali}', "");
Expect(0, 2559, '\p{^_-In_Bengali}', "");
Expect(0, 2559, '\P{_-In_Bengali}', "");
Expect(1, 2559, '\P{^_-In_Bengali}', "");
Expect(0, 2560, '\p{_-In_Bengali}', "");
Expect(1, 2560, '\p{^_-In_Bengali}', "");
Expect(1, 2560, '\P{_-In_Bengali}', "");
Expect(0, 2560, '\P{^_-In_Bengali}', "");
Error('\p{:=	_In_bopomofo}');
Error('\P{:=	_In_bopomofo}');
Expect(1, 12591, '\p{inbopomofo}', "");
Expect(0, 12591, '\p{^inbopomofo}', "");
Expect(0, 12591, '\P{inbopomofo}', "");
Expect(1, 12591, '\P{^inbopomofo}', "");
Expect(0, 12592, '\p{inbopomofo}', "");
Expect(1, 12592, '\p{^inbopomofo}', "");
Expect(1, 12592, '\P{inbopomofo}', "");
Expect(0, 12592, '\P{^inbopomofo}', "");
Expect(1, 12591, '\p{-IN_Bopomofo}', "");
Expect(0, 12591, '\p{^-IN_Bopomofo}', "");
Expect(0, 12591, '\P{-IN_Bopomofo}', "");
Expect(1, 12591, '\P{^-IN_Bopomofo}', "");
Expect(0, 12592, '\p{-IN_Bopomofo}', "");
Expect(1, 12592, '\p{^-IN_Bopomofo}', "");
Expect(1, 12592, '\P{-IN_Bopomofo}', "");
Expect(0, 12592, '\P{^-IN_Bopomofo}', "");
Error('\p{_:=In_Bopomofo}');
Error('\P{_:=In_Bopomofo}');
Expect(1, 12591, '\p{	_in_bopomofo}', "");
Expect(0, 12591, '\p{^	_in_bopomofo}', "");
Expect(0, 12591, '\P{	_in_bopomofo}', "");
Expect(1, 12591, '\P{^	_in_bopomofo}', "");
Expect(0, 12592, '\p{	_in_bopomofo}', "");
Expect(1, 12592, '\p{^	_in_bopomofo}', "");
Expect(1, 12592, '\P{	_in_bopomofo}', "");
Expect(0, 12592, '\P{^	_in_bopomofo}', "");
Error('\p{-/a/in_Brahmi}');
Error('\P{-/a/in_Brahmi}');
Expect(1, 69759, '\p{inbrahmi}', "");
Expect(0, 69759, '\p{^inbrahmi}', "");
Expect(0, 69759, '\P{inbrahmi}', "");
Expect(1, 69759, '\P{^inbrahmi}', "");
Expect(0, 69760, '\p{inbrahmi}', "");
Expect(1, 69760, '\p{^inbrahmi}', "");
Expect(1, 69760, '\P{inbrahmi}', "");
Expect(0, 69760, '\P{^inbrahmi}', "");
Expect(1, 69759, '\p{-	IN_Brahmi}', "");
Expect(0, 69759, '\p{^-	IN_Brahmi}', "");
Expect(0, 69759, '\P{-	IN_Brahmi}', "");
Expect(1, 69759, '\P{^-	IN_Brahmi}', "");
Expect(0, 69760, '\p{-	IN_Brahmi}', "");
Expect(1, 69760, '\p{^-	IN_Brahmi}', "");
Expect(1, 69760, '\P{-	IN_Brahmi}', "");
Expect(0, 69760, '\P{^-	IN_Brahmi}', "");
Error('\p{_	IN_brahmi/a/}');
Error('\P{_	IN_brahmi/a/}');
Expect(1, 69759, '\p{-	IN_brahmi}', "");
Expect(0, 69759, '\p{^-	IN_brahmi}', "");
Expect(0, 69759, '\P{-	IN_brahmi}', "");
Expect(1, 69759, '\P{^-	IN_brahmi}', "");
Expect(0, 69760, '\p{-	IN_brahmi}', "");
Expect(1, 69760, '\p{^-	IN_brahmi}', "");
Expect(1, 69760, '\P{-	IN_brahmi}', "");
Expect(0, 69760, '\P{^-	IN_brahmi}', "");
Error('\p{	-In_Buginese:=}');
Error('\P{	-In_Buginese:=}');
Expect(1, 6687, '\p{inbuginese}', "");
Expect(0, 6687, '\p{^inbuginese}', "");
Expect(0, 6687, '\P{inbuginese}', "");
Expect(1, 6687, '\P{^inbuginese}', "");
Expect(0, 6688, '\p{inbuginese}', "");
Expect(1, 6688, '\p{^inbuginese}', "");
Expect(1, 6688, '\P{inbuginese}', "");
Expect(0, 6688, '\P{^inbuginese}', "");
Expect(1, 6687, '\p{  in_Buginese}', "");
Expect(0, 6687, '\p{^  in_Buginese}', "");
Expect(0, 6687, '\P{  in_Buginese}', "");
Expect(1, 6687, '\P{^  in_Buginese}', "");
Expect(0, 6688, '\p{  in_Buginese}', "");
Expect(1, 6688, '\p{^  in_Buginese}', "");
Expect(1, 6688, '\P{  in_Buginese}', "");
Expect(0, 6688, '\P{^  in_Buginese}', "");
Error('\p{-:=In_buginese}');
Error('\P{-:=In_buginese}');
Expect(1, 6687, '\p{	in_BUGINESE}', "");
Expect(0, 6687, '\p{^	in_BUGINESE}', "");
Expect(0, 6687, '\P{	in_BUGINESE}', "");
Expect(1, 6687, '\P{^	in_BUGINESE}', "");
Expect(0, 6688, '\p{	in_BUGINESE}', "");
Expect(1, 6688, '\p{^	in_BUGINESE}', "");
Expect(1, 6688, '\P{	in_BUGINESE}', "");
Expect(0, 6688, '\P{^	in_BUGINESE}', "");
Error('\p{-/a/In_buhid}');
Error('\P{-/a/In_buhid}');
Expect(1, 5983, '\p{inbuhid}', "");
Expect(0, 5983, '\p{^inbuhid}', "");
Expect(0, 5983, '\P{inbuhid}', "");
Expect(1, 5983, '\P{^inbuhid}', "");
Expect(0, 5984, '\p{inbuhid}', "");
Expect(1, 5984, '\p{^inbuhid}', "");
Expect(1, 5984, '\P{inbuhid}', "");
Expect(0, 5984, '\P{^inbuhid}', "");
Expect(1, 5983, '\p{_In_Buhid}', "");
Expect(0, 5983, '\p{^_In_Buhid}', "");
Expect(0, 5983, '\P{_In_Buhid}', "");
Expect(1, 5983, '\P{^_In_Buhid}', "");
Expect(0, 5984, '\p{_In_Buhid}', "");
Expect(1, 5984, '\p{^_In_Buhid}', "");
Expect(1, 5984, '\P{_In_Buhid}', "");
Expect(0, 5984, '\P{^_In_Buhid}', "");
Error('\p{		In_buhid:=}');
Error('\P{		In_buhid:=}');
Expect(1, 5983, '\p{-	in_BUHID}', "");
Expect(0, 5983, '\p{^-	in_BUHID}', "");
Expect(0, 5983, '\P{-	in_BUHID}', "");
Expect(1, 5983, '\P{^-	in_BUHID}', "");
Expect(0, 5984, '\p{-	in_BUHID}', "");
Expect(1, 5984, '\p{^-	in_BUHID}', "");
Expect(1, 5984, '\P{-	in_BUHID}', "");
Expect(0, 5984, '\P{^-	in_BUHID}', "");
Error('\p{:=		In_CARIAN}');
Error('\P{:=		In_CARIAN}');
Expect(1, 66271, '\p{incarian}', "");
Expect(0, 66271, '\p{^incarian}', "");
Expect(0, 66271, '\P{incarian}', "");
Expect(1, 66271, '\P{^incarian}', "");
Expect(0, 66272, '\p{incarian}', "");
Expect(1, 66272, '\p{^incarian}', "");
Expect(1, 66272, '\P{incarian}', "");
Expect(0, 66272, '\P{^incarian}', "");
Expect(1, 66271, '\p{--in_Carian}', "");
Expect(0, 66271, '\p{^--in_Carian}', "");
Expect(0, 66271, '\P{--in_Carian}', "");
Expect(1, 66271, '\P{^--in_Carian}', "");
Expect(0, 66272, '\p{--in_Carian}', "");
Expect(1, 66272, '\p{^--in_Carian}', "");
Expect(1, 66272, '\P{--in_Carian}', "");
Expect(0, 66272, '\P{^--in_Carian}', "");
Error('\p{_:=IN_Carian}');
Error('\P{_:=IN_Carian}');
Expect(1, 66271, '\p{		in_Carian}', "");
Expect(0, 66271, '\p{^		in_Carian}', "");
Expect(0, 66271, '\P{		in_Carian}', "");
Expect(1, 66271, '\P{^		in_Carian}', "");
Expect(0, 66272, '\p{		in_Carian}', "");
Expect(1, 66272, '\p{^		in_Carian}', "");
Expect(1, 66272, '\P{		in_Carian}', "");
Expect(0, 66272, '\P{^		in_Carian}', "");
Error('\p{:= _IN_Chakma}');
Error('\P{:= _IN_Chakma}');
Expect(1, 69967, '\p{inchakma}', "");
Expect(0, 69967, '\p{^inchakma}', "");
Expect(0, 69967, '\P{inchakma}', "");
Expect(1, 69967, '\P{^inchakma}', "");
Expect(0, 69968, '\p{inchakma}', "");
Expect(1, 69968, '\p{^inchakma}', "");
Expect(1, 69968, '\P{inchakma}', "");
Expect(0, 69968, '\P{^inchakma}', "");
Expect(1, 69967, '\p{-IN_chakma}', "");
Expect(0, 69967, '\p{^-IN_chakma}', "");
Expect(0, 69967, '\P{-IN_chakma}', "");
Expect(1, 69967, '\P{^-IN_chakma}', "");
Expect(0, 69968, '\p{-IN_chakma}', "");
Expect(1, 69968, '\p{^-IN_chakma}', "");
Expect(1, 69968, '\P{-IN_chakma}', "");
Expect(0, 69968, '\P{^-IN_chakma}', "");
Error('\p{ /a/in_Chakma}');
Error('\P{ /a/in_Chakma}');
Expect(1, 69967, '\p{-in_CHAKMA}', "");
Expect(0, 69967, '\p{^-in_CHAKMA}', "");
Expect(0, 69967, '\P{-in_CHAKMA}', "");
Expect(1, 69967, '\P{^-in_CHAKMA}', "");
Expect(0, 69968, '\p{-in_CHAKMA}', "");
Expect(1, 69968, '\p{^-in_CHAKMA}', "");
Expect(1, 69968, '\P{-in_CHAKMA}', "");
Expect(0, 69968, '\P{^-in_CHAKMA}', "");
Error('\p{--In_cham/a/}');
Error('\P{--In_cham/a/}');
Expect(1, 43615, '\p{incham}', "");
Expect(0, 43615, '\p{^incham}', "");
Expect(0, 43615, '\P{incham}', "");
Expect(1, 43615, '\P{^incham}', "");
Expect(0, 43616, '\p{incham}', "");
Expect(1, 43616, '\p{^incham}', "");
Expect(1, 43616, '\P{incham}', "");
Expect(0, 43616, '\P{^incham}', "");
Expect(1, 43615, '\p{-_In_cham}', "");
Expect(0, 43615, '\p{^-_In_cham}', "");
Expect(0, 43615, '\P{-_In_cham}', "");
Expect(1, 43615, '\P{^-_In_cham}', "");
Expect(0, 43616, '\p{-_In_cham}', "");
Expect(1, 43616, '\p{^-_In_cham}', "");
Expect(1, 43616, '\P{-_In_cham}', "");
Expect(0, 43616, '\P{^-_In_cham}', "");
Error('\p{/a/-_in_Cham}');
Error('\P{/a/-_in_Cham}');
Expect(1, 43615, '\p{  in_Cham}', "");
Expect(0, 43615, '\p{^  in_Cham}', "");
Expect(0, 43615, '\P{  in_Cham}', "");
Expect(1, 43615, '\P{^  in_Cham}', "");
Expect(0, 43616, '\p{  in_Cham}', "");
Expect(1, 43616, '\p{^  in_Cham}', "");
Expect(1, 43616, '\P{  in_Cham}', "");
Expect(0, 43616, '\P{^  in_Cham}', "");
Error('\p{/a/ In_CHEROKEE}');
Error('\P{/a/ In_CHEROKEE}');
Expect(1, 5119, '\p{incherokee}', "");
Expect(0, 5119, '\p{^incherokee}', "");
Expect(0, 5119, '\P{incherokee}', "");
Expect(1, 5119, '\P{^incherokee}', "");
Expect(0, 5120, '\p{incherokee}', "");
Expect(1, 5120, '\p{^incherokee}', "");
Expect(1, 5120, '\P{incherokee}', "");
Expect(0, 5120, '\P{^incherokee}', "");
Expect(1, 5119, '\p{-_In_Cherokee}', "");
Expect(0, 5119, '\p{^-_In_Cherokee}', "");
Expect(0, 5119, '\P{-_In_Cherokee}', "");
Expect(1, 5119, '\P{^-_In_Cherokee}', "");
Expect(0, 5120, '\p{-_In_Cherokee}', "");
Expect(1, 5120, '\p{^-_In_Cherokee}', "");
Expect(1, 5120, '\P{-_In_Cherokee}', "");
Expect(0, 5120, '\P{^-_In_Cherokee}', "");
Error('\p{_:=in_Cherokee}');
Error('\P{_:=in_Cherokee}');
Expect(1, 5119, '\p{-	in_Cherokee}', "");
Expect(0, 5119, '\p{^-	in_Cherokee}', "");
Expect(0, 5119, '\P{-	in_Cherokee}', "");
Expect(1, 5119, '\P{^-	in_Cherokee}', "");
Expect(0, 5120, '\p{-	in_Cherokee}', "");
Expect(1, 5120, '\p{^-	in_Cherokee}', "");
Expect(1, 5120, '\P{-	in_Cherokee}', "");
Expect(0, 5120, '\P{^-	in_Cherokee}', "");
Error('\p{ _IN_coptic/a/}');
Error('\P{ _IN_coptic/a/}');
Expect(1, 11519, '\p{incoptic}', "");
Expect(0, 11519, '\p{^incoptic}', "");
Expect(0, 11519, '\P{incoptic}', "");
Expect(1, 11519, '\P{^incoptic}', "");
Expect(0, 11520, '\p{incoptic}', "");
Expect(1, 11520, '\p{^incoptic}', "");
Expect(1, 11520, '\P{incoptic}', "");
Expect(0, 11520, '\P{^incoptic}', "");
Expect(1, 11519, '\p{-In_COPTIC}', "");
Expect(0, 11519, '\p{^-In_COPTIC}', "");
Expect(0, 11519, '\P{-In_COPTIC}', "");
Expect(1, 11519, '\P{^-In_COPTIC}', "");
Expect(0, 11520, '\p{-In_COPTIC}', "");
Expect(1, 11520, '\p{^-In_COPTIC}', "");
Expect(1, 11520, '\P{-In_COPTIC}', "");
Expect(0, 11520, '\P{^-In_COPTIC}', "");
Error('\p{- In_coptic:=}');
Error('\P{- In_coptic:=}');
Expect(1, 11519, '\p{ 	In_COPTIC}', "");
Expect(0, 11519, '\p{^ 	In_COPTIC}', "");
Expect(0, 11519, '\P{ 	In_COPTIC}', "");
Expect(1, 11519, '\P{^ 	In_COPTIC}', "");
Expect(0, 11520, '\p{ 	In_COPTIC}', "");
Expect(1, 11520, '\p{^ 	In_COPTIC}', "");
Expect(1, 11520, '\P{ 	In_COPTIC}', "");
Expect(0, 11520, '\P{^ 	In_COPTIC}', "");
Error('\p{-IN_CUNEIFORM/a/}');
Error('\P{-IN_CUNEIFORM/a/}');
Expect(1, 74751, '\p{incuneiform}', "");
Expect(0, 74751, '\p{^incuneiform}', "");
Expect(0, 74751, '\P{incuneiform}', "");
Expect(1, 74751, '\P{^incuneiform}', "");
Expect(0, 74752, '\p{incuneiform}', "");
Expect(1, 74752, '\p{^incuneiform}', "");
Expect(1, 74752, '\P{incuneiform}', "");
Expect(0, 74752, '\P{^incuneiform}', "");
Expect(1, 74751, '\p{_In_Cuneiform}', "");
Expect(0, 74751, '\p{^_In_Cuneiform}', "");
Expect(0, 74751, '\P{_In_Cuneiform}', "");
Expect(1, 74751, '\P{^_In_Cuneiform}', "");
Expect(0, 74752, '\p{_In_Cuneiform}', "");
Expect(1, 74752, '\p{^_In_Cuneiform}', "");
Expect(1, 74752, '\P{_In_Cuneiform}', "");
Expect(0, 74752, '\P{^_In_Cuneiform}', "");
Error('\p{	:=In_cuneiform}');
Error('\P{	:=In_cuneiform}');
Expect(1, 74751, '\p{--In_Cuneiform}', "");
Expect(0, 74751, '\p{^--In_Cuneiform}', "");
Expect(0, 74751, '\P{--In_Cuneiform}', "");
Expect(1, 74751, '\P{^--In_Cuneiform}', "");
Expect(0, 74752, '\p{--In_Cuneiform}', "");
Expect(1, 74752, '\p{^--In_Cuneiform}', "");
Expect(1, 74752, '\P{--In_Cuneiform}', "");
Expect(0, 74752, '\P{^--In_Cuneiform}', "");
Error('\p{In_CYRILLIC:=}');
Error('\P{In_CYRILLIC:=}');
Expect(1, 1279, '\p{incyrillic}', "");
Expect(0, 1279, '\p{^incyrillic}', "");
Expect(0, 1279, '\P{incyrillic}', "");
Expect(1, 1279, '\P{^incyrillic}', "");
Expect(0, 1280, '\p{incyrillic}', "");
Expect(1, 1280, '\p{^incyrillic}', "");
Expect(1, 1280, '\P{incyrillic}', "");
Expect(0, 1280, '\P{^incyrillic}', "");
Expect(1, 1279, '\p{in_Cyrillic}', "");
Expect(0, 1279, '\p{^in_Cyrillic}', "");
Expect(0, 1279, '\P{in_Cyrillic}', "");
Expect(1, 1279, '\P{^in_Cyrillic}', "");
Expect(0, 1280, '\p{in_Cyrillic}', "");
Expect(1, 1280, '\p{^in_Cyrillic}', "");
Expect(1, 1280, '\P{in_Cyrillic}', "");
Expect(0, 1280, '\P{^in_Cyrillic}', "");
Error('\p{  in_CYRILLIC:=}');
Error('\P{  in_CYRILLIC:=}');
Expect(1, 1279, '\p{__In_CYRILLIC}', "");
Expect(0, 1279, '\p{^__In_CYRILLIC}', "");
Expect(0, 1279, '\P{__In_CYRILLIC}', "");
Expect(1, 1279, '\P{^__In_CYRILLIC}', "");
Expect(0, 1280, '\p{__In_CYRILLIC}', "");
Expect(1, 1280, '\p{^__In_CYRILLIC}', "");
Expect(1, 1280, '\P{__In_CYRILLIC}', "");
Expect(0, 1280, '\P{^__In_CYRILLIC}', "");
Error('\p{/a/__In_Deseret}');
Error('\P{/a/__In_Deseret}');
Expect(1, 66639, '\p{indeseret}', "");
Expect(0, 66639, '\p{^indeseret}', "");
Expect(0, 66639, '\P{indeseret}', "");
Expect(1, 66639, '\P{^indeseret}', "");
Expect(0, 66640, '\p{indeseret}', "");
Expect(1, 66640, '\p{^indeseret}', "");
Expect(1, 66640, '\P{indeseret}', "");
Expect(0, 66640, '\P{^indeseret}', "");
Expect(1, 66639, '\p{-In_Deseret}', "");
Expect(0, 66639, '\p{^-In_Deseret}', "");
Expect(0, 66639, '\P{-In_Deseret}', "");
Expect(1, 66639, '\P{^-In_Deseret}', "");
Expect(0, 66640, '\p{-In_Deseret}', "");
Expect(1, 66640, '\p{^-In_Deseret}', "");
Expect(1, 66640, '\P{-In_Deseret}', "");
Expect(0, 66640, '\P{^-In_Deseret}', "");
Error('\p{__In_DESERET/a/}');
Error('\P{__In_DESERET/a/}');
Expect(1, 66639, '\p{	-IN_deseret}', "");
Expect(0, 66639, '\p{^	-IN_deseret}', "");
Expect(0, 66639, '\P{	-IN_deseret}', "");
Expect(1, 66639, '\P{^	-IN_deseret}', "");
Expect(0, 66640, '\p{	-IN_deseret}', "");
Expect(1, 66640, '\p{^	-IN_deseret}', "");
Expect(1, 66640, '\P{	-IN_deseret}', "");
Expect(0, 66640, '\P{^	-IN_deseret}', "");
Error('\p{_:=IN_devanagari}');
Error('\P{_:=IN_devanagari}');
Expect(1, 2431, '\p{indevanagari}', "");
Expect(0, 2431, '\p{^indevanagari}', "");
Expect(0, 2431, '\P{indevanagari}', "");
Expect(1, 2431, '\P{^indevanagari}', "");
Expect(0, 2432, '\p{indevanagari}', "");
Expect(1, 2432, '\p{^indevanagari}', "");
Expect(1, 2432, '\P{indevanagari}', "");
Expect(0, 2432, '\P{^indevanagari}', "");
Expect(1, 2431, '\p{in_devanagari}', "");
Expect(0, 2431, '\p{^in_devanagari}', "");
Expect(0, 2431, '\P{in_devanagari}', "");
Expect(1, 2431, '\P{^in_devanagari}', "");
Expect(0, 2432, '\p{in_devanagari}', "");
Expect(1, 2432, '\p{^in_devanagari}', "");
Expect(1, 2432, '\P{in_devanagari}', "");
Expect(0, 2432, '\P{^in_devanagari}', "");
Error('\p{_:=in_Devanagari}');
Error('\P{_:=in_Devanagari}');
Expect(1, 2431, '\p{	_In_DEVANAGARI}', "");
Expect(0, 2431, '\p{^	_In_DEVANAGARI}', "");
Expect(0, 2431, '\P{	_In_DEVANAGARI}', "");
Expect(1, 2431, '\P{^	_In_DEVANAGARI}', "");
Expect(0, 2432, '\p{	_In_DEVANAGARI}', "");
Expect(1, 2432, '\p{^	_In_DEVANAGARI}', "");
Expect(1, 2432, '\P{	_In_DEVANAGARI}', "");
Expect(0, 2432, '\P{^	_In_DEVANAGARI}', "");
Error('\p{:=__IN_egyptian_Hieroglyphs}');
Error('\P{:=__IN_egyptian_Hieroglyphs}');
Expect(1, 78895, '\p{inegyptianhieroglyphs}', "");
Expect(0, 78895, '\p{^inegyptianhieroglyphs}', "");
Expect(0, 78895, '\P{inegyptianhieroglyphs}', "");
Expect(1, 78895, '\P{^inegyptianhieroglyphs}', "");
Expect(0, 78896, '\p{inegyptianhieroglyphs}', "");
Expect(1, 78896, '\p{^inegyptianhieroglyphs}', "");
Expect(1, 78896, '\P{inegyptianhieroglyphs}', "");
Expect(0, 78896, '\P{^inegyptianhieroglyphs}', "");
Expect(1, 78895, '\p{	in_egyptian_HIEROGLYPHS}', "");
Expect(0, 78895, '\p{^	in_egyptian_HIEROGLYPHS}', "");
Expect(0, 78895, '\P{	in_egyptian_HIEROGLYPHS}', "");
Expect(1, 78895, '\P{^	in_egyptian_HIEROGLYPHS}', "");
Expect(0, 78896, '\p{	in_egyptian_HIEROGLYPHS}', "");
Expect(1, 78896, '\p{^	in_egyptian_HIEROGLYPHS}', "");
Expect(1, 78896, '\P{	in_egyptian_HIEROGLYPHS}', "");
Expect(0, 78896, '\P{^	in_egyptian_HIEROGLYPHS}', "");
Error('\p{	/a/In_EGYPTIAN_hieroglyphs}');
Error('\P{	/a/In_EGYPTIAN_hieroglyphs}');
Expect(1, 78895, '\p{_IN_egyptian_hieroglyphs}', "");
Expect(0, 78895, '\p{^_IN_egyptian_hieroglyphs}', "");
Expect(0, 78895, '\P{_IN_egyptian_hieroglyphs}', "");
Expect(1, 78895, '\P{^_IN_egyptian_hieroglyphs}', "");
Expect(0, 78896, '\p{_IN_egyptian_hieroglyphs}', "");
Expect(1, 78896, '\p{^_IN_egyptian_hieroglyphs}', "");
Expect(1, 78896, '\P{_IN_egyptian_hieroglyphs}', "");
Expect(0, 78896, '\P{^_IN_egyptian_hieroglyphs}', "");
Error('\p{/a/_In_ethiopic}');
Error('\P{/a/_In_ethiopic}');
Expect(1, 4991, '\p{inethiopic}', "");
Expect(0, 4991, '\p{^inethiopic}', "");
Expect(0, 4991, '\P{inethiopic}', "");
Expect(1, 4991, '\P{^inethiopic}', "");
Expect(0, 4992, '\p{inethiopic}', "");
Expect(1, 4992, '\p{^inethiopic}', "");
Expect(1, 4992, '\P{inethiopic}', "");
Expect(0, 4992, '\P{^inethiopic}', "");
Expect(1, 4991, '\p{_IN_Ethiopic}', "");
Expect(0, 4991, '\p{^_IN_Ethiopic}', "");
Expect(0, 4991, '\P{_IN_Ethiopic}', "");
Expect(1, 4991, '\P{^_IN_Ethiopic}', "");
Expect(0, 4992, '\p{_IN_Ethiopic}', "");
Expect(1, 4992, '\p{^_IN_Ethiopic}', "");
Expect(1, 4992, '\P{_IN_Ethiopic}', "");
Expect(0, 4992, '\P{^_IN_Ethiopic}', "");
Error('\p{/a/in_ETHIOPIC}');
Error('\P{/a/in_ETHIOPIC}');
Expect(1, 4991, '\p{ 	In_ethiopic}', "");
Expect(0, 4991, '\p{^ 	In_ethiopic}', "");
Expect(0, 4991, '\P{ 	In_ethiopic}', "");
Expect(1, 4991, '\P{^ 	In_ethiopic}', "");
Expect(0, 4992, '\p{ 	In_ethiopic}', "");
Expect(1, 4992, '\p{^ 	In_ethiopic}', "");
Expect(1, 4992, '\P{ 	In_ethiopic}', "");
Expect(0, 4992, '\P{^ 	In_ethiopic}', "");
Error('\p{ In_georgian/a/}');
Error('\P{ In_georgian/a/}');
Expect(1, 4351, '\p{ingeorgian}', "");
Expect(0, 4351, '\p{^ingeorgian}', "");
Expect(0, 4351, '\P{ingeorgian}', "");
Expect(1, 4351, '\P{^ingeorgian}', "");
Expect(0, 4352, '\p{ingeorgian}', "");
Expect(1, 4352, '\p{^ingeorgian}', "");
Expect(1, 4352, '\P{ingeorgian}', "");
Expect(0, 4352, '\P{^ingeorgian}', "");
Expect(1, 4351, '\p{ 	In_Georgian}', "");
Expect(0, 4351, '\p{^ 	In_Georgian}', "");
Expect(0, 4351, '\P{ 	In_Georgian}', "");
Expect(1, 4351, '\P{^ 	In_Georgian}', "");
Expect(0, 4352, '\p{ 	In_Georgian}', "");
Expect(1, 4352, '\p{^ 	In_Georgian}', "");
Expect(1, 4352, '\P{ 	In_Georgian}', "");
Expect(0, 4352, '\P{^ 	In_Georgian}', "");
Error('\p{/a/- in_GEORGIAN}');
Error('\P{/a/- in_GEORGIAN}');
Expect(1, 4351, '\p{ 	IN_Georgian}', "");
Expect(0, 4351, '\p{^ 	IN_Georgian}', "");
Expect(0, 4351, '\P{ 	IN_Georgian}', "");
Expect(1, 4351, '\P{^ 	IN_Georgian}', "");
Expect(0, 4352, '\p{ 	IN_Georgian}', "");
Expect(1, 4352, '\p{^ 	IN_Georgian}', "");
Expect(1, 4352, '\P{ 	IN_Georgian}', "");
Expect(0, 4352, '\P{^ 	IN_Georgian}', "");
Error('\p{:=_In_Glagolitic}');
Error('\P{:=_In_Glagolitic}');
Expect(1, 11359, '\p{inglagolitic}', "");
Expect(0, 11359, '\p{^inglagolitic}', "");
Expect(0, 11359, '\P{inglagolitic}', "");
Expect(1, 11359, '\P{^inglagolitic}', "");
Expect(0, 11360, '\p{inglagolitic}', "");
Expect(1, 11360, '\p{^inglagolitic}', "");
Expect(1, 11360, '\P{inglagolitic}', "");
Expect(0, 11360, '\P{^inglagolitic}', "");
Expect(1, 11359, '\p{	In_Glagolitic}', "");
Expect(0, 11359, '\p{^	In_Glagolitic}', "");
Expect(0, 11359, '\P{	In_Glagolitic}', "");
Expect(1, 11359, '\P{^	In_Glagolitic}', "");
Expect(0, 11360, '\p{	In_Glagolitic}', "");
Expect(1, 11360, '\p{^	In_Glagolitic}', "");
Expect(1, 11360, '\P{	In_Glagolitic}', "");
Expect(0, 11360, '\P{^	In_Glagolitic}', "");
Error('\p{	:=in_glagolitic}');
Error('\P{	:=in_glagolitic}');
Expect(1, 11359, '\p{_In_glagolitic}', "");
Expect(0, 11359, '\p{^_In_glagolitic}', "");
Expect(0, 11359, '\P{_In_glagolitic}', "");
Expect(1, 11359, '\P{^_In_glagolitic}', "");
Expect(0, 11360, '\p{_In_glagolitic}', "");
Expect(1, 11360, '\p{^_In_glagolitic}', "");
Expect(1, 11360, '\P{_In_glagolitic}', "");
Expect(0, 11360, '\P{^_In_glagolitic}', "");
Error('\p{:=_ in_GOTHIC}');
Error('\P{:=_ in_GOTHIC}');
Expect(1, 66383, '\p{ingothic}', "");
Expect(0, 66383, '\p{^ingothic}', "");
Expect(0, 66383, '\P{ingothic}', "");
Expect(1, 66383, '\P{^ingothic}', "");
Expect(0, 66384, '\p{ingothic}', "");
Expect(1, 66384, '\p{^ingothic}', "");
Expect(1, 66384, '\P{ingothic}', "");
Expect(0, 66384, '\P{^ingothic}', "");
Expect(1, 66383, '\p{	-in_GOTHIC}', "");
Expect(0, 66383, '\p{^	-in_GOTHIC}', "");
Expect(0, 66383, '\P{	-in_GOTHIC}', "");
Expect(1, 66383, '\P{^	-in_GOTHIC}', "");
Expect(0, 66384, '\p{	-in_GOTHIC}', "");
Expect(1, 66384, '\p{^	-in_GOTHIC}', "");
Expect(1, 66384, '\P{	-in_GOTHIC}', "");
Expect(0, 66384, '\P{^	-in_GOTHIC}', "");
Error('\p{:=	 IN_Gothic}');
Error('\P{:=	 IN_Gothic}');
Expect(1, 66383, '\p{In_gothic}', "");
Expect(0, 66383, '\p{^In_gothic}', "");
Expect(0, 66383, '\P{In_gothic}', "");
Expect(1, 66383, '\P{^In_gothic}', "");
Expect(0, 66384, '\p{In_gothic}', "");
Expect(1, 66384, '\p{^In_gothic}', "");
Expect(1, 66384, '\P{In_gothic}', "");
Expect(0, 66384, '\P{^In_gothic}', "");
Error('\p{:=-In_gujarati}');
Error('\P{:=-In_gujarati}');
Expect(1, 2815, '\p{ingujarati}', "");
Expect(0, 2815, '\p{^ingujarati}', "");
Expect(0, 2815, '\P{ingujarati}', "");
Expect(1, 2815, '\P{^ingujarati}', "");
Expect(0, 2816, '\p{ingujarati}', "");
Expect(1, 2816, '\p{^ingujarati}', "");
Expect(1, 2816, '\P{ingujarati}', "");
Expect(0, 2816, '\P{^ingujarati}', "");
Expect(1, 2815, '\p{ _In_Gujarati}', "");
Expect(0, 2815, '\p{^ _In_Gujarati}', "");
Expect(0, 2815, '\P{ _In_Gujarati}', "");
Expect(1, 2815, '\P{^ _In_Gujarati}', "");
Expect(0, 2816, '\p{ _In_Gujarati}', "");
Expect(1, 2816, '\p{^ _In_Gujarati}', "");
Expect(1, 2816, '\P{ _In_Gujarati}', "");
Expect(0, 2816, '\P{^ _In_Gujarati}', "");
Error('\p{:=-In_Gujarati}');
Error('\P{:=-In_Gujarati}');
Expect(1, 2815, '\p{	_in_Gujarati}', "");
Expect(0, 2815, '\p{^	_in_Gujarati}', "");
Expect(0, 2815, '\P{	_in_Gujarati}', "");
Expect(1, 2815, '\P{^	_in_Gujarati}', "");
Expect(0, 2816, '\p{	_in_Gujarati}', "");
Expect(1, 2816, '\p{^	_in_Gujarati}', "");
Expect(1, 2816, '\P{	_in_Gujarati}', "");
Expect(0, 2816, '\P{^	_in_Gujarati}', "");
Error('\p{:=	-in_Gurmukhi}');
Error('\P{:=	-in_Gurmukhi}');
Expect(1, 2687, '\p{ingurmukhi}', "");
Expect(0, 2687, '\p{^ingurmukhi}', "");
Expect(0, 2687, '\P{ingurmukhi}', "");
Expect(1, 2687, '\P{^ingurmukhi}', "");
Expect(0, 2688, '\p{ingurmukhi}', "");
Expect(1, 2688, '\p{^ingurmukhi}', "");
Expect(1, 2688, '\P{ingurmukhi}', "");
Expect(0, 2688, '\P{^ingurmukhi}', "");
Expect(1, 2687, '\p{		In_gurmukhi}', "");
Expect(0, 2687, '\p{^		In_gurmukhi}', "");
Expect(0, 2687, '\P{		In_gurmukhi}', "");
Expect(1, 2687, '\P{^		In_gurmukhi}', "");
Expect(0, 2688, '\p{		In_gurmukhi}', "");
Expect(1, 2688, '\p{^		In_gurmukhi}', "");
Expect(1, 2688, '\P{		In_gurmukhi}', "");
Expect(0, 2688, '\P{^		In_gurmukhi}', "");
Error('\p{ -IN_GURMUKHI:=}');
Error('\P{ -IN_GURMUKHI:=}');
Expect(1, 2687, '\p{  in_Gurmukhi}', "");
Expect(0, 2687, '\p{^  in_Gurmukhi}', "");
Expect(0, 2687, '\P{  in_Gurmukhi}', "");
Expect(1, 2687, '\P{^  in_Gurmukhi}', "");
Expect(0, 2688, '\p{  in_Gurmukhi}', "");
Expect(1, 2688, '\p{^  in_Gurmukhi}', "");
Expect(1, 2688, '\P{  in_Gurmukhi}', "");
Expect(0, 2688, '\P{^  in_Gurmukhi}', "");
Error('\p{/a/_In_hanunoo}');
Error('\P{/a/_In_hanunoo}');
Expect(1, 5951, '\p{inhanunoo}', "");
Expect(0, 5951, '\p{^inhanunoo}', "");
Expect(0, 5951, '\P{inhanunoo}', "");
Expect(1, 5951, '\P{^inhanunoo}', "");
Expect(0, 5952, '\p{inhanunoo}', "");
Expect(1, 5952, '\p{^inhanunoo}', "");
Expect(1, 5952, '\P{inhanunoo}', "");
Expect(0, 5952, '\P{^inhanunoo}', "");
Expect(1, 5951, '\p{-in_hanunoo}', "");
Expect(0, 5951, '\p{^-in_hanunoo}', "");
Expect(0, 5951, '\P{-in_hanunoo}', "");
Expect(1, 5951, '\P{^-in_hanunoo}', "");
Expect(0, 5952, '\p{-in_hanunoo}', "");
Expect(1, 5952, '\p{^-in_hanunoo}', "");
Expect(1, 5952, '\P{-in_hanunoo}', "");
Expect(0, 5952, '\P{^-in_hanunoo}', "");
Error('\p{ /a/In_Hanunoo}');
Error('\P{ /a/In_Hanunoo}');
Expect(1, 5951, '\p{_ in_hanunoo}', "");
Expect(0, 5951, '\p{^_ in_hanunoo}', "");
Expect(0, 5951, '\P{_ in_hanunoo}', "");
Expect(1, 5951, '\P{^_ in_hanunoo}', "");
Expect(0, 5952, '\p{_ in_hanunoo}', "");
Expect(1, 5952, '\p{^_ in_hanunoo}', "");
Expect(1, 5952, '\P{_ in_hanunoo}', "");
Expect(0, 5952, '\P{^_ in_hanunoo}', "");
Error('\p{/a/In_HEBREW}');
Error('\P{/a/In_HEBREW}');
Expect(1, 1535, '\p{inhebrew}', "");
Expect(0, 1535, '\p{^inhebrew}', "");
Expect(0, 1535, '\P{inhebrew}', "");
Expect(1, 1535, '\P{^inhebrew}', "");
Expect(0, 1536, '\p{inhebrew}', "");
Expect(1, 1536, '\p{^inhebrew}', "");
Expect(1, 1536, '\P{inhebrew}', "");
Expect(0, 1536, '\P{^inhebrew}', "");
Expect(1, 1535, '\p{ 	In_hebrew}', "");
Expect(0, 1535, '\p{^ 	In_hebrew}', "");
Expect(0, 1535, '\P{ 	In_hebrew}', "");
Expect(1, 1535, '\P{^ 	In_hebrew}', "");
Expect(0, 1536, '\p{ 	In_hebrew}', "");
Expect(1, 1536, '\p{^ 	In_hebrew}', "");
Expect(1, 1536, '\P{ 	In_hebrew}', "");
Expect(0, 1536, '\P{^ 	In_hebrew}', "");
Error('\p{--In_HEBREW/a/}');
Error('\P{--In_HEBREW/a/}');
Expect(1, 1535, '\p{_-In_Hebrew}', "");
Expect(0, 1535, '\p{^_-In_Hebrew}', "");
Expect(0, 1535, '\P{_-In_Hebrew}', "");
Expect(1, 1535, '\P{^_-In_Hebrew}', "");
Expect(0, 1536, '\p{_-In_Hebrew}', "");
Expect(1, 1536, '\p{^_-In_Hebrew}', "");
Expect(1, 1536, '\P{_-In_Hebrew}', "");
Expect(0, 1536, '\P{^_-In_Hebrew}', "");
Error('\p{__in_HIRAGANA/a/}');
Error('\P{__in_HIRAGANA/a/}');
Expect(1, 12447, '\p{inhiragana}', "");
Expect(0, 12447, '\p{^inhiragana}', "");
Expect(0, 12447, '\P{inhiragana}', "");
Expect(1, 12447, '\P{^inhiragana}', "");
Expect(0, 12448, '\p{inhiragana}', "");
Expect(1, 12448, '\p{^inhiragana}', "");
Expect(1, 12448, '\P{inhiragana}', "");
Expect(0, 12448, '\P{^inhiragana}', "");
Expect(1, 12447, '\p{ -in_Hiragana}', "");
Expect(0, 12447, '\p{^ -in_Hiragana}', "");
Expect(0, 12447, '\P{ -in_Hiragana}', "");
Expect(1, 12447, '\P{^ -in_Hiragana}', "");
Expect(0, 12448, '\p{ -in_Hiragana}', "");
Expect(1, 12448, '\p{^ -in_Hiragana}', "");
Expect(1, 12448, '\P{ -in_Hiragana}', "");
Expect(0, 12448, '\P{^ -in_Hiragana}', "");
Error('\p{__IN_Hiragana/a/}');
Error('\P{__IN_Hiragana/a/}');
Expect(1, 12447, '\p{ 	In_Hiragana}', "");
Expect(0, 12447, '\p{^ 	In_Hiragana}', "");
Expect(0, 12447, '\P{ 	In_Hiragana}', "");
Expect(1, 12447, '\P{^ 	In_Hiragana}', "");
Expect(0, 12448, '\p{ 	In_Hiragana}', "");
Expect(1, 12448, '\p{^ 	In_Hiragana}', "");
Expect(1, 12448, '\P{ 	In_Hiragana}', "");
Expect(0, 12448, '\P{^ 	In_Hiragana}', "");
Error('\p{/a/In_imperial_Aramaic}');
Error('\P{/a/In_imperial_Aramaic}');
Expect(1, 67679, '\p{inimperialaramaic}', "");
Expect(0, 67679, '\p{^inimperialaramaic}', "");
Expect(0, 67679, '\P{inimperialaramaic}', "");
Expect(1, 67679, '\P{^inimperialaramaic}', "");
Expect(0, 67680, '\p{inimperialaramaic}', "");
Expect(1, 67680, '\p{^inimperialaramaic}', "");
Expect(1, 67680, '\P{inimperialaramaic}', "");
Expect(0, 67680, '\P{^inimperialaramaic}', "");
Expect(1, 67679, '\p{ In_Imperial_ARAMAIC}', "");
Expect(0, 67679, '\p{^ In_Imperial_ARAMAIC}', "");
Expect(0, 67679, '\P{ In_Imperial_ARAMAIC}', "");
Expect(1, 67679, '\P{^ In_Imperial_ARAMAIC}', "");
Expect(0, 67680, '\p{ In_Imperial_ARAMAIC}', "");
Expect(1, 67680, '\p{^ In_Imperial_ARAMAIC}', "");
Expect(1, 67680, '\P{ In_Imperial_ARAMAIC}', "");
Expect(0, 67680, '\P{^ In_Imperial_ARAMAIC}', "");
Error('\p{-:=In_imperial_aramaic}');
Error('\P{-:=In_imperial_aramaic}');
Expect(1, 67679, '\p{-_IN_Imperial_ARAMAIC}', "");
Expect(0, 67679, '\p{^-_IN_Imperial_ARAMAIC}', "");
Expect(0, 67679, '\P{-_IN_Imperial_ARAMAIC}', "");
Expect(1, 67679, '\P{^-_IN_Imperial_ARAMAIC}', "");
Expect(0, 67680, '\p{-_IN_Imperial_ARAMAIC}', "");
Expect(1, 67680, '\p{^-_IN_Imperial_ARAMAIC}', "");
Expect(1, 67680, '\P{-_IN_Imperial_ARAMAIC}', "");
Expect(0, 67680, '\P{^-_IN_Imperial_ARAMAIC}', "");
Error('\p{/a/IN_INSCRIPTIONAL_Pahlavi}');
Error('\P{/a/IN_INSCRIPTIONAL_Pahlavi}');
Expect(1, 68479, '\p{ininscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^ininscriptionalpahlavi}', "");
Expect(0, 68479, '\P{ininscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^ininscriptionalpahlavi}', "");
Expect(0, 68480, '\p{ininscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^ininscriptionalpahlavi}', "");
Expect(1, 68480, '\P{ininscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^ininscriptionalpahlavi}', "");
Expect(1, 68479, '\p{__in_INSCRIPTIONAL_Pahlavi}', "");
Expect(0, 68479, '\p{^__in_INSCRIPTIONAL_Pahlavi}', "");
Expect(0, 68479, '\P{__in_INSCRIPTIONAL_Pahlavi}', "");
Expect(1, 68479, '\P{^__in_INSCRIPTIONAL_Pahlavi}', "");
Expect(0, 68480, '\p{__in_INSCRIPTIONAL_Pahlavi}', "");
Expect(1, 68480, '\p{^__in_INSCRIPTIONAL_Pahlavi}', "");
Expect(1, 68480, '\P{__in_INSCRIPTIONAL_Pahlavi}', "");
Expect(0, 68480, '\P{^__in_INSCRIPTIONAL_Pahlavi}', "");
Error('\p{	:=IN_Inscriptional_pahlavi}');
Error('\P{	:=IN_Inscriptional_pahlavi}');
Expect(1, 68479, '\p{-In_Inscriptional_Pahlavi}', "");
Expect(0, 68479, '\p{^-In_Inscriptional_Pahlavi}', "");
Expect(0, 68479, '\P{-In_Inscriptional_Pahlavi}', "");
Expect(1, 68479, '\P{^-In_Inscriptional_Pahlavi}', "");
Expect(0, 68480, '\p{-In_Inscriptional_Pahlavi}', "");
Expect(1, 68480, '\p{^-In_Inscriptional_Pahlavi}', "");
Expect(1, 68480, '\P{-In_Inscriptional_Pahlavi}', "");
Expect(0, 68480, '\P{^-In_Inscriptional_Pahlavi}', "");
Error('\p{:=in_Inscriptional_PARTHIAN}');
Error('\P{:=in_Inscriptional_PARTHIAN}');
Expect(1, 68447, '\p{ininscriptionalparthian}', "");
Expect(0, 68447, '\p{^ininscriptionalparthian}', "");
Expect(0, 68447, '\P{ininscriptionalparthian}', "");
Expect(1, 68447, '\P{^ininscriptionalparthian}', "");
Expect(0, 68448, '\p{ininscriptionalparthian}', "");
Expect(1, 68448, '\p{^ininscriptionalparthian}', "");
Expect(1, 68448, '\P{ininscriptionalparthian}', "");
Expect(0, 68448, '\P{^ininscriptionalparthian}', "");
Expect(1, 68447, '\p{-In_inscriptional_Parthian}', "");
Expect(0, 68447, '\p{^-In_inscriptional_Parthian}', "");
Expect(0, 68447, '\P{-In_inscriptional_Parthian}', "");
Expect(1, 68447, '\P{^-In_inscriptional_Parthian}', "");
Expect(0, 68448, '\p{-In_inscriptional_Parthian}', "");
Expect(1, 68448, '\p{^-In_inscriptional_Parthian}', "");
Expect(1, 68448, '\P{-In_inscriptional_Parthian}', "");
Expect(0, 68448, '\P{^-In_inscriptional_Parthian}', "");
Error('\p{ 	IN_Inscriptional_PARTHIAN/a/}');
Error('\P{ 	IN_Inscriptional_PARTHIAN/a/}');
Expect(1, 68447, '\p{ -in_Inscriptional_PARTHIAN}', "");
Expect(0, 68447, '\p{^ -in_Inscriptional_PARTHIAN}', "");
Expect(0, 68447, '\P{ -in_Inscriptional_PARTHIAN}', "");
Expect(1, 68447, '\P{^ -in_Inscriptional_PARTHIAN}', "");
Expect(0, 68448, '\p{ -in_Inscriptional_PARTHIAN}', "");
Expect(1, 68448, '\p{^ -in_Inscriptional_PARTHIAN}', "");
Expect(1, 68448, '\P{ -in_Inscriptional_PARTHIAN}', "");
Expect(0, 68448, '\P{^ -in_Inscriptional_PARTHIAN}', "");
Error('\p{  in_Javanese/a/}');
Error('\P{  in_Javanese/a/}');
Expect(1, 43487, '\p{injavanese}', "");
Expect(0, 43487, '\p{^injavanese}', "");
Expect(0, 43487, '\P{injavanese}', "");
Expect(1, 43487, '\P{^injavanese}', "");
Expect(0, 43488, '\p{injavanese}', "");
Expect(1, 43488, '\p{^injavanese}', "");
Expect(1, 43488, '\P{injavanese}', "");
Expect(0, 43488, '\P{^injavanese}', "");
Expect(1, 43487, '\p{-In_javanese}', "");
Expect(0, 43487, '\p{^-In_javanese}', "");
Expect(0, 43487, '\P{-In_javanese}', "");
Expect(1, 43487, '\P{^-In_javanese}', "");
Expect(0, 43488, '\p{-In_javanese}', "");
Expect(1, 43488, '\p{^-In_javanese}', "");
Expect(1, 43488, '\P{-In_javanese}', "");
Expect(0, 43488, '\P{^-In_javanese}', "");
Error('\p{-	In_Javanese:=}');
Error('\P{-	In_Javanese:=}');
Expect(1, 43487, '\p{	-In_javanese}', "");
Expect(0, 43487, '\p{^	-In_javanese}', "");
Expect(0, 43487, '\P{	-In_javanese}', "");
Expect(1, 43487, '\P{^	-In_javanese}', "");
Expect(0, 43488, '\p{	-In_javanese}', "");
Expect(1, 43488, '\p{^	-In_javanese}', "");
Expect(1, 43488, '\P{	-In_javanese}', "");
Expect(0, 43488, '\P{^	-In_javanese}', "");
Error('\p{ In_kaithi:=}');
Error('\P{ In_kaithi:=}');
Expect(1, 69839, '\p{inkaithi}', "");
Expect(0, 69839, '\p{^inkaithi}', "");
Expect(0, 69839, '\P{inkaithi}', "");
Expect(1, 69839, '\P{^inkaithi}', "");
Expect(0, 69840, '\p{inkaithi}', "");
Expect(1, 69840, '\p{^inkaithi}', "");
Expect(1, 69840, '\P{inkaithi}', "");
Expect(0, 69840, '\P{^inkaithi}', "");
Expect(1, 69839, '\p{ IN_KAITHI}', "");
Expect(0, 69839, '\p{^ IN_KAITHI}', "");
Expect(0, 69839, '\P{ IN_KAITHI}', "");
Expect(1, 69839, '\P{^ IN_KAITHI}', "");
Expect(0, 69840, '\p{ IN_KAITHI}', "");
Expect(1, 69840, '\p{^ IN_KAITHI}', "");
Expect(1, 69840, '\P{ IN_KAITHI}', "");
Expect(0, 69840, '\P{^ IN_KAITHI}', "");
Error('\p{-In_KAITHI/a/}');
Error('\P{-In_KAITHI/a/}');
Expect(1, 69839, '\p{	_in_Kaithi}', "");
Expect(0, 69839, '\p{^	_in_Kaithi}', "");
Expect(0, 69839, '\P{	_in_Kaithi}', "");
Expect(1, 69839, '\P{^	_in_Kaithi}', "");
Expect(0, 69840, '\p{	_in_Kaithi}', "");
Expect(1, 69840, '\p{^	_in_Kaithi}', "");
Expect(1, 69840, '\P{	_in_Kaithi}', "");
Expect(0, 69840, '\P{^	_in_Kaithi}', "");
Error('\p{_In_kannada:=}');
Error('\P{_In_kannada:=}');
Expect(1, 3327, '\p{inkannada}', "");
Expect(0, 3327, '\p{^inkannada}', "");
Expect(0, 3327, '\P{inkannada}', "");
Expect(1, 3327, '\P{^inkannada}', "");
Expect(0, 3328, '\p{inkannada}', "");
Expect(1, 3328, '\p{^inkannada}', "");
Expect(1, 3328, '\P{inkannada}', "");
Expect(0, 3328, '\P{^inkannada}', "");
Expect(1, 3327, '\p{ 	In_KANNADA}', "");
Expect(0, 3327, '\p{^ 	In_KANNADA}', "");
Expect(0, 3327, '\P{ 	In_KANNADA}', "");
Expect(1, 3327, '\P{^ 	In_KANNADA}', "");
Expect(0, 3328, '\p{ 	In_KANNADA}', "");
Expect(1, 3328, '\p{^ 	In_KANNADA}', "");
Expect(1, 3328, '\P{ 	In_KANNADA}', "");
Expect(0, 3328, '\P{^ 	In_KANNADA}', "");
Error('\p{:=IN_Kannada}');
Error('\P{:=IN_Kannada}');
Expect(1, 3327, '\p{ 	In_Kannada}', "");
Expect(0, 3327, '\p{^ 	In_Kannada}', "");
Expect(0, 3327, '\P{ 	In_Kannada}', "");
Expect(1, 3327, '\P{^ 	In_Kannada}', "");
Expect(0, 3328, '\p{ 	In_Kannada}', "");
Expect(1, 3328, '\p{^ 	In_Kannada}', "");
Expect(1, 3328, '\P{ 	In_Kannada}', "");
Expect(0, 3328, '\P{^ 	In_Kannada}', "");
Error('\p{/a/IN_katakana}');
Error('\P{/a/IN_katakana}');
Expect(1, 12543, '\p{inkatakana}', "");
Expect(0, 12543, '\p{^inkatakana}', "");
Expect(0, 12543, '\P{inkatakana}', "");
Expect(1, 12543, '\P{^inkatakana}', "");
Expect(0, 12544, '\p{inkatakana}', "");
Expect(1, 12544, '\p{^inkatakana}', "");
Expect(1, 12544, '\P{inkatakana}', "");
Expect(0, 12544, '\P{^inkatakana}', "");
Expect(1, 12543, '\p{	In_KATAKANA}', "");
Expect(0, 12543, '\p{^	In_KATAKANA}', "");
Expect(0, 12543, '\P{	In_KATAKANA}', "");
Expect(1, 12543, '\P{^	In_KATAKANA}', "");
Expect(0, 12544, '\p{	In_KATAKANA}', "");
Expect(1, 12544, '\p{^	In_KATAKANA}', "");
Expect(1, 12544, '\P{	In_KATAKANA}', "");
Expect(0, 12544, '\P{^	In_KATAKANA}', "");
Error('\p{:=	IN_Katakana}');
Error('\P{:=	IN_Katakana}');
Expect(1, 12543, '\p{_	In_KATAKANA}', "");
Expect(0, 12543, '\p{^_	In_KATAKANA}', "");
Expect(0, 12543, '\P{_	In_KATAKANA}', "");
Expect(1, 12543, '\P{^_	In_KATAKANA}', "");
Expect(0, 12544, '\p{_	In_KATAKANA}', "");
Expect(1, 12544, '\p{^_	In_KATAKANA}', "");
Expect(1, 12544, '\P{_	In_KATAKANA}', "");
Expect(0, 12544, '\P{^_	In_KATAKANA}', "");
Error('\p{ /a/IN_KAYAH_Li}');
Error('\P{ /a/IN_KAYAH_Li}');
Expect(1, 43311, '\p{inkayahli}', "");
Expect(0, 43311, '\p{^inkayahli}', "");
Expect(0, 43311, '\P{inkayahli}', "");
Expect(1, 43311, '\P{^inkayahli}', "");
Expect(0, 43312, '\p{inkayahli}', "");
Expect(1, 43312, '\p{^inkayahli}', "");
Expect(1, 43312, '\P{inkayahli}', "");
Expect(0, 43312, '\P{^inkayahli}', "");
Expect(1, 43311, '\p{	-In_KAYAH_li}', "");
Expect(0, 43311, '\p{^	-In_KAYAH_li}', "");
Expect(0, 43311, '\P{	-In_KAYAH_li}', "");
Expect(1, 43311, '\P{^	-In_KAYAH_li}', "");
Expect(0, 43312, '\p{	-In_KAYAH_li}', "");
Expect(1, 43312, '\p{^	-In_KAYAH_li}', "");
Expect(1, 43312, '\P{	-In_KAYAH_li}', "");
Expect(0, 43312, '\P{^	-In_KAYAH_li}', "");
Error('\p{:=	 IN_Kayah_Li}');
Error('\P{:=	 IN_Kayah_Li}');
Expect(1, 43311, '\p{-	In_kayah_Li}', "");
Expect(0, 43311, '\p{^-	In_kayah_Li}', "");
Expect(0, 43311, '\P{-	In_kayah_Li}', "");
Expect(1, 43311, '\P{^-	In_kayah_Li}', "");
Expect(0, 43312, '\p{-	In_kayah_Li}', "");
Expect(1, 43312, '\p{^-	In_kayah_Li}', "");
Expect(1, 43312, '\P{-	In_kayah_Li}', "");
Expect(0, 43312, '\P{^-	In_kayah_Li}', "");
Error('\p{		In_KHAROSHTHI/a/}');
Error('\P{		In_KHAROSHTHI/a/}');
Expect(1, 68191, '\p{inkharoshthi}', "");
Expect(0, 68191, '\p{^inkharoshthi}', "");
Expect(0, 68191, '\P{inkharoshthi}', "");
Expect(1, 68191, '\P{^inkharoshthi}', "");
Expect(0, 68192, '\p{inkharoshthi}', "");
Expect(1, 68192, '\p{^inkharoshthi}', "");
Expect(1, 68192, '\P{inkharoshthi}', "");
Expect(0, 68192, '\P{^inkharoshthi}', "");
Expect(1, 68191, '\p{_in_Kharoshthi}', "");
Expect(0, 68191, '\p{^_in_Kharoshthi}', "");
Expect(0, 68191, '\P{_in_Kharoshthi}', "");
Expect(1, 68191, '\P{^_in_Kharoshthi}', "");
Expect(0, 68192, '\p{_in_Kharoshthi}', "");
Expect(1, 68192, '\p{^_in_Kharoshthi}', "");
Expect(1, 68192, '\P{_in_Kharoshthi}', "");
Expect(0, 68192, '\P{^_in_Kharoshthi}', "");
Error('\p{/a/ IN_KHAROSHTHI}');
Error('\P{/a/ IN_KHAROSHTHI}');
Expect(1, 68191, '\p{ 	in_Kharoshthi}', "");
Expect(0, 68191, '\p{^ 	in_Kharoshthi}', "");
Expect(0, 68191, '\P{ 	in_Kharoshthi}', "");
Expect(1, 68191, '\P{^ 	in_Kharoshthi}', "");
Expect(0, 68192, '\p{ 	in_Kharoshthi}', "");
Expect(1, 68192, '\p{^ 	in_Kharoshthi}', "");
Expect(1, 68192, '\P{ 	in_Kharoshthi}', "");
Expect(0, 68192, '\P{^ 	in_Kharoshthi}', "");
Error('\p{_-In_Khmer/a/}');
Error('\P{_-In_Khmer/a/}');
Expect(1, 6143, '\p{inkhmer}', "");
Expect(0, 6143, '\p{^inkhmer}', "");
Expect(0, 6143, '\P{inkhmer}', "");
Expect(1, 6143, '\P{^inkhmer}', "");
Expect(0, 6144, '\p{inkhmer}', "");
Expect(1, 6144, '\p{^inkhmer}', "");
Expect(1, 6144, '\P{inkhmer}', "");
Expect(0, 6144, '\P{^inkhmer}', "");
Expect(1, 6143, '\p{	 In_khmer}', "");
Expect(0, 6143, '\p{^	 In_khmer}', "");
Expect(0, 6143, '\P{	 In_khmer}', "");
Expect(1, 6143, '\P{^	 In_khmer}', "");
Expect(0, 6144, '\p{	 In_khmer}', "");
Expect(1, 6144, '\p{^	 In_khmer}', "");
Expect(1, 6144, '\P{	 In_khmer}', "");
Expect(0, 6144, '\P{^	 In_khmer}', "");
Error('\p{-:=In_KHMER}');
Error('\P{-:=In_KHMER}');
Expect(1, 6143, '\p{ 	In_khmer}', "");
Expect(0, 6143, '\p{^ 	In_khmer}', "");
Expect(0, 6143, '\P{ 	In_khmer}', "");
Expect(1, 6143, '\P{^ 	In_khmer}', "");
Expect(0, 6144, '\p{ 	In_khmer}', "");
Expect(1, 6144, '\p{^ 	In_khmer}', "");
Expect(1, 6144, '\P{ 	In_khmer}', "");
Expect(0, 6144, '\P{^ 	In_khmer}', "");
Error('\p{:=In_LAO}');
Error('\P{:=In_LAO}');
Expect(1, 3839, '\p{inlao}', "");
Expect(0, 3839, '\p{^inlao}', "");
Expect(0, 3839, '\P{inlao}', "");
Expect(1, 3839, '\P{^inlao}', "");
Expect(0, 3840, '\p{inlao}', "");
Expect(1, 3840, '\p{^inlao}', "");
Expect(1, 3840, '\P{inlao}', "");
Expect(0, 3840, '\P{^inlao}', "");
Expect(1, 3839, '\p{In_lao}', "");
Expect(0, 3839, '\p{^In_lao}', "");
Expect(0, 3839, '\P{In_lao}', "");
Expect(1, 3839, '\P{^In_lao}', "");
Expect(0, 3840, '\p{In_lao}', "");
Expect(1, 3840, '\p{^In_lao}', "");
Expect(1, 3840, '\P{In_lao}', "");
Expect(0, 3840, '\P{^In_lao}', "");
Error('\p{-:=IN_Lao}');
Error('\P{-:=IN_Lao}');
Expect(1, 3839, '\p{ In_LAO}', "");
Expect(0, 3839, '\p{^ In_LAO}', "");
Expect(0, 3839, '\P{ In_LAO}', "");
Expect(1, 3839, '\P{^ In_LAO}', "");
Expect(0, 3840, '\p{ In_LAO}', "");
Expect(1, 3840, '\p{^ In_LAO}', "");
Expect(1, 3840, '\P{ In_LAO}', "");
Expect(0, 3840, '\P{^ In_LAO}', "");
Error('\p{:= 	In_lepcha}');
Error('\P{:= 	In_lepcha}');
Expect(1, 7247, '\p{inlepcha}', "");
Expect(0, 7247, '\p{^inlepcha}', "");
Expect(0, 7247, '\P{inlepcha}', "");
Expect(1, 7247, '\P{^inlepcha}', "");
Expect(0, 7248, '\p{inlepcha}', "");
Expect(1, 7248, '\p{^inlepcha}', "");
Expect(1, 7248, '\P{inlepcha}', "");
Expect(0, 7248, '\P{^inlepcha}', "");
Expect(1, 7247, '\p{ _in_lepcha}', "");
Expect(0, 7247, '\p{^ _in_lepcha}', "");
Expect(0, 7247, '\P{ _in_lepcha}', "");
Expect(1, 7247, '\P{^ _in_lepcha}', "");
Expect(0, 7248, '\p{ _in_lepcha}', "");
Expect(1, 7248, '\p{^ _in_lepcha}', "");
Expect(1, 7248, '\P{ _in_lepcha}', "");
Expect(0, 7248, '\P{^ _in_lepcha}', "");
Error('\p{/a/ IN_Lepcha}');
Error('\P{/a/ IN_Lepcha}');
Expect(1, 7247, '\p{-In_LEPCHA}', "");
Expect(0, 7247, '\p{^-In_LEPCHA}', "");
Expect(0, 7247, '\P{-In_LEPCHA}', "");
Expect(1, 7247, '\P{^-In_LEPCHA}', "");
Expect(0, 7248, '\p{-In_LEPCHA}', "");
Expect(1, 7248, '\p{^-In_LEPCHA}', "");
Expect(1, 7248, '\P{-In_LEPCHA}', "");
Expect(0, 7248, '\P{^-In_LEPCHA}', "");
Error('\p{_/a/in_limbu}');
Error('\P{_/a/in_limbu}');
Expect(1, 6479, '\p{inlimbu}', "");
Expect(0, 6479, '\p{^inlimbu}', "");
Expect(0, 6479, '\P{inlimbu}', "");
Expect(1, 6479, '\P{^inlimbu}', "");
Expect(0, 6480, '\p{inlimbu}', "");
Expect(1, 6480, '\p{^inlimbu}', "");
Expect(1, 6480, '\P{inlimbu}', "");
Expect(0, 6480, '\P{^inlimbu}', "");
Expect(1, 6479, '\p{In_LIMBU}', "");
Expect(0, 6479, '\p{^In_LIMBU}', "");
Expect(0, 6479, '\P{In_LIMBU}', "");
Expect(1, 6479, '\P{^In_LIMBU}', "");
Expect(0, 6480, '\p{In_LIMBU}', "");
Expect(1, 6480, '\p{^In_LIMBU}', "");
Expect(1, 6480, '\P{In_LIMBU}', "");
Expect(0, 6480, '\P{^In_LIMBU}', "");
Error('\p{_	in_Limbu/a/}');
Error('\P{_	in_Limbu/a/}');
Expect(1, 6479, '\p{	-In_Limbu}', "");
Expect(0, 6479, '\p{^	-In_Limbu}', "");
Expect(0, 6479, '\P{	-In_Limbu}', "");
Expect(1, 6479, '\P{^	-In_Limbu}', "");
Expect(0, 6480, '\p{	-In_Limbu}', "");
Expect(1, 6480, '\p{^	-In_Limbu}', "");
Expect(1, 6480, '\P{	-In_Limbu}', "");
Expect(0, 6480, '\P{^	-In_Limbu}', "");
Error('\p{/a/_ IN_lisu}');
Error('\P{/a/_ IN_lisu}');
Expect(1, 42239, '\p{inlisu}', "");
Expect(0, 42239, '\p{^inlisu}', "");
Expect(0, 42239, '\P{inlisu}', "");
Expect(1, 42239, '\P{^inlisu}', "");
Expect(0, 42240, '\p{inlisu}', "");
Expect(1, 42240, '\p{^inlisu}', "");
Expect(1, 42240, '\P{inlisu}', "");
Expect(0, 42240, '\P{^inlisu}', "");
Expect(1, 42239, '\p{-	In_lisu}', "");
Expect(0, 42239, '\p{^-	In_lisu}', "");
Expect(0, 42239, '\P{-	In_lisu}', "");
Expect(1, 42239, '\P{^-	In_lisu}', "");
Expect(0, 42240, '\p{-	In_lisu}', "");
Expect(1, 42240, '\p{^-	In_lisu}', "");
Expect(1, 42240, '\P{-	In_lisu}', "");
Expect(0, 42240, '\P{^-	In_lisu}', "");
Error('\p{-:=In_LISU}');
Error('\P{-:=In_LISU}');
Expect(1, 42239, '\p{  in_Lisu}', "");
Expect(0, 42239, '\p{^  in_Lisu}', "");
Expect(0, 42239, '\P{  in_Lisu}', "");
Expect(1, 42239, '\P{^  in_Lisu}', "");
Expect(0, 42240, '\p{  in_Lisu}', "");
Expect(1, 42240, '\p{^  in_Lisu}', "");
Expect(1, 42240, '\P{  in_Lisu}', "");
Expect(0, 42240, '\P{^  in_Lisu}', "");
Error('\p{_/a/In_lycian}');
Error('\P{_/a/In_lycian}');
Expect(1, 66207, '\p{inlycian}', "");
Expect(0, 66207, '\p{^inlycian}', "");
Expect(0, 66207, '\P{inlycian}', "");
Expect(1, 66207, '\P{^inlycian}', "");
Expect(0, 66208, '\p{inlycian}', "");
Expect(1, 66208, '\p{^inlycian}', "");
Expect(1, 66208, '\P{inlycian}', "");
Expect(0, 66208, '\P{^inlycian}', "");
Expect(1, 66207, '\p{	-In_Lycian}', "");
Expect(0, 66207, '\p{^	-In_Lycian}', "");
Expect(0, 66207, '\P{	-In_Lycian}', "");
Expect(1, 66207, '\P{^	-In_Lycian}', "");
Expect(0, 66208, '\p{	-In_Lycian}', "");
Expect(1, 66208, '\p{^	-In_Lycian}', "");
Expect(1, 66208, '\P{	-In_Lycian}', "");
Expect(0, 66208, '\P{^	-In_Lycian}', "");
Error('\p{_-in_Lycian:=}');
Error('\P{_-in_Lycian:=}');
Expect(1, 66207, '\p{-_In_LYCIAN}', "");
Expect(0, 66207, '\p{^-_In_LYCIAN}', "");
Expect(0, 66207, '\P{-_In_LYCIAN}', "");
Expect(1, 66207, '\P{^-_In_LYCIAN}', "");
Expect(0, 66208, '\p{-_In_LYCIAN}', "");
Expect(1, 66208, '\p{^-_In_LYCIAN}', "");
Expect(1, 66208, '\P{-_In_LYCIAN}', "");
Expect(0, 66208, '\P{^-_In_LYCIAN}', "");
Error('\p{/a/_-In_LYDIAN}');
Error('\P{/a/_-In_LYDIAN}');
Expect(1, 67903, '\p{inlydian}', "");
Expect(0, 67903, '\p{^inlydian}', "");
Expect(0, 67903, '\P{inlydian}', "");
Expect(1, 67903, '\P{^inlydian}', "");
Expect(0, 67904, '\p{inlydian}', "");
Expect(1, 67904, '\p{^inlydian}', "");
Expect(1, 67904, '\P{inlydian}', "");
Expect(0, 67904, '\P{^inlydian}', "");
Expect(1, 67903, '\p{	_IN_lydian}', "");
Expect(0, 67903, '\p{^	_IN_lydian}', "");
Expect(0, 67903, '\P{	_IN_lydian}', "");
Expect(1, 67903, '\P{^	_IN_lydian}', "");
Expect(0, 67904, '\p{	_IN_lydian}', "");
Expect(1, 67904, '\p{^	_IN_lydian}', "");
Expect(1, 67904, '\P{	_IN_lydian}', "");
Expect(0, 67904, '\P{^	_IN_lydian}', "");
Error('\p{/a/_In_LYDIAN}');
Error('\P{/a/_In_LYDIAN}');
Expect(1, 67903, '\p{-_In_Lydian}', "");
Expect(0, 67903, '\p{^-_In_Lydian}', "");
Expect(0, 67903, '\P{-_In_Lydian}', "");
Expect(1, 67903, '\P{^-_In_Lydian}', "");
Expect(0, 67904, '\p{-_In_Lydian}', "");
Expect(1, 67904, '\p{^-_In_Lydian}', "");
Expect(1, 67904, '\P{-_In_Lydian}', "");
Expect(0, 67904, '\P{^-_In_Lydian}', "");
Error('\p{-in_malayalam/a/}');
Error('\P{-in_malayalam/a/}');
Expect(1, 3455, '\p{inmalayalam}', "");
Expect(0, 3455, '\p{^inmalayalam}', "");
Expect(0, 3455, '\P{inmalayalam}', "");
Expect(1, 3455, '\P{^inmalayalam}', "");
Expect(0, 3456, '\p{inmalayalam}', "");
Expect(1, 3456, '\p{^inmalayalam}', "");
Expect(1, 3456, '\P{inmalayalam}', "");
Expect(0, 3456, '\P{^inmalayalam}', "");
Expect(1, 3455, '\p{_In_Malayalam}', "");
Expect(0, 3455, '\p{^_In_Malayalam}', "");
Expect(0, 3455, '\P{_In_Malayalam}', "");
Expect(1, 3455, '\P{^_In_Malayalam}', "");
Expect(0, 3456, '\p{_In_Malayalam}', "");
Expect(1, 3456, '\p{^_In_Malayalam}', "");
Expect(1, 3456, '\P{_In_Malayalam}', "");
Expect(0, 3456, '\P{^_In_Malayalam}', "");
Error('\p{-/a/IN_MALAYALAM}');
Error('\P{-/a/IN_MALAYALAM}');
Expect(1, 3455, '\p{_-In_MALAYALAM}', "");
Expect(0, 3455, '\p{^_-In_MALAYALAM}', "");
Expect(0, 3455, '\P{_-In_MALAYALAM}', "");
Expect(1, 3455, '\P{^_-In_MALAYALAM}', "");
Expect(0, 3456, '\p{_-In_MALAYALAM}', "");
Expect(1, 3456, '\p{^_-In_MALAYALAM}', "");
Expect(1, 3456, '\P{_-In_MALAYALAM}', "");
Expect(0, 3456, '\P{^_-In_MALAYALAM}', "");
Error('\p{ -IN_mandaic/a/}');
Error('\P{ -IN_mandaic/a/}');
Expect(1, 2143, '\p{inmandaic}', "");
Expect(0, 2143, '\p{^inmandaic}', "");
Expect(0, 2143, '\P{inmandaic}', "");
Expect(1, 2143, '\P{^inmandaic}', "");
Expect(0, 2144, '\p{inmandaic}', "");
Expect(1, 2144, '\p{^inmandaic}', "");
Expect(1, 2144, '\P{inmandaic}', "");
Expect(0, 2144, '\P{^inmandaic}', "");
Expect(1, 2143, '\p{ -IN_MANDAIC}', "");
Expect(0, 2143, '\p{^ -IN_MANDAIC}', "");
Expect(0, 2143, '\P{ -IN_MANDAIC}', "");
Expect(1, 2143, '\P{^ -IN_MANDAIC}', "");
Expect(0, 2144, '\p{ -IN_MANDAIC}', "");
Expect(1, 2144, '\p{^ -IN_MANDAIC}', "");
Expect(1, 2144, '\P{ -IN_MANDAIC}', "");
Expect(0, 2144, '\P{^ -IN_MANDAIC}', "");
Error('\p{:=	In_Mandaic}');
Error('\P{:=	In_Mandaic}');
Expect(1, 2143, '\p{  IN_Mandaic}', "");
Expect(0, 2143, '\p{^  IN_Mandaic}', "");
Expect(0, 2143, '\P{  IN_Mandaic}', "");
Expect(1, 2143, '\P{^  IN_Mandaic}', "");
Expect(0, 2144, '\p{  IN_Mandaic}', "");
Expect(1, 2144, '\p{^  IN_Mandaic}', "");
Expect(1, 2144, '\P{  IN_Mandaic}', "");
Expect(0, 2144, '\P{^  IN_Mandaic}', "");
Error('\p{		In_meetei_Mayek/a/}');
Error('\P{		In_meetei_Mayek/a/}');
Expect(1, 44031, '\p{inmeeteimayek}', "");
Expect(0, 44031, '\p{^inmeeteimayek}', "");
Expect(0, 44031, '\P{inmeeteimayek}', "");
Expect(1, 44031, '\P{^inmeeteimayek}', "");
Expect(0, 44032, '\p{inmeeteimayek}', "");
Expect(1, 44032, '\p{^inmeeteimayek}', "");
Expect(1, 44032, '\P{inmeeteimayek}', "");
Expect(0, 44032, '\P{^inmeeteimayek}', "");
Expect(1, 44031, '\p{_In_Meetei_mayek}', "");
Expect(0, 44031, '\p{^_In_Meetei_mayek}', "");
Expect(0, 44031, '\P{_In_Meetei_mayek}', "");
Expect(1, 44031, '\P{^_In_Meetei_mayek}', "");
Expect(0, 44032, '\p{_In_Meetei_mayek}', "");
Expect(1, 44032, '\p{^_In_Meetei_mayek}', "");
Expect(1, 44032, '\P{_In_Meetei_mayek}', "");
Expect(0, 44032, '\P{^_In_Meetei_mayek}', "");
Error('\p{/a/In_Meetei_Mayek}');
Error('\P{/a/In_Meetei_Mayek}');
Expect(1, 44031, '\p{_in_MEETEI_mayek}', "");
Expect(0, 44031, '\p{^_in_MEETEI_mayek}', "");
Expect(0, 44031, '\P{_in_MEETEI_mayek}', "");
Expect(1, 44031, '\P{^_in_MEETEI_mayek}', "");
Expect(0, 44032, '\p{_in_MEETEI_mayek}', "");
Expect(1, 44032, '\p{^_in_MEETEI_mayek}', "");
Expect(1, 44032, '\P{_in_MEETEI_mayek}', "");
Expect(0, 44032, '\P{^_in_MEETEI_mayek}', "");
Error('\p{ :=In_Meroitic_cursive}');
Error('\P{ :=In_Meroitic_cursive}');
Expect(1, 68095, '\p{inmeroiticcursive}', "");
Expect(0, 68095, '\p{^inmeroiticcursive}', "");
Expect(0, 68095, '\P{inmeroiticcursive}', "");
Expect(1, 68095, '\P{^inmeroiticcursive}', "");
Expect(0, 68096, '\p{inmeroiticcursive}', "");
Expect(1, 68096, '\p{^inmeroiticcursive}', "");
Expect(1, 68096, '\P{inmeroiticcursive}', "");
Expect(0, 68096, '\P{^inmeroiticcursive}', "");
Expect(1, 68095, '\p{-In_Meroitic_CURSIVE}', "");
Expect(0, 68095, '\p{^-In_Meroitic_CURSIVE}', "");
Expect(0, 68095, '\P{-In_Meroitic_CURSIVE}', "");
Expect(1, 68095, '\P{^-In_Meroitic_CURSIVE}', "");
Expect(0, 68096, '\p{-In_Meroitic_CURSIVE}', "");
Expect(1, 68096, '\p{^-In_Meroitic_CURSIVE}', "");
Expect(1, 68096, '\P{-In_Meroitic_CURSIVE}', "");
Expect(0, 68096, '\P{^-In_Meroitic_CURSIVE}', "");
Error('\p{  In_meroitic_CURSIVE:=}');
Error('\P{  In_meroitic_CURSIVE:=}');
Expect(1, 68095, '\p{_ IN_meroitic_cursive}', "");
Expect(0, 68095, '\p{^_ IN_meroitic_cursive}', "");
Expect(0, 68095, '\P{_ IN_meroitic_cursive}', "");
Expect(1, 68095, '\P{^_ IN_meroitic_cursive}', "");
Expect(0, 68096, '\p{_ IN_meroitic_cursive}', "");
Expect(1, 68096, '\p{^_ IN_meroitic_cursive}', "");
Expect(1, 68096, '\P{_ IN_meroitic_cursive}', "");
Expect(0, 68096, '\P{^_ IN_meroitic_cursive}', "");
Error('\p{ /a/In_MEROITIC_hieroglyphs}');
Error('\P{ /a/In_MEROITIC_hieroglyphs}');
Expect(1, 67999, '\p{inmeroitichieroglyphs}', "");
Expect(0, 67999, '\p{^inmeroitichieroglyphs}', "");
Expect(0, 67999, '\P{inmeroitichieroglyphs}', "");
Expect(1, 67999, '\P{^inmeroitichieroglyphs}', "");
Expect(0, 68000, '\p{inmeroitichieroglyphs}', "");
Expect(1, 68000, '\p{^inmeroitichieroglyphs}', "");
Expect(1, 68000, '\P{inmeroitichieroglyphs}', "");
Expect(0, 68000, '\P{^inmeroitichieroglyphs}', "");
Expect(1, 67999, '\p{	_In_MEROITIC_HIEROGLYPHS}', "");
Expect(0, 67999, '\p{^	_In_MEROITIC_HIEROGLYPHS}', "");
Expect(0, 67999, '\P{	_In_MEROITIC_HIEROGLYPHS}', "");
Expect(1, 67999, '\P{^	_In_MEROITIC_HIEROGLYPHS}', "");
Expect(0, 68000, '\p{	_In_MEROITIC_HIEROGLYPHS}', "");
Expect(1, 68000, '\p{^	_In_MEROITIC_HIEROGLYPHS}', "");
Expect(1, 68000, '\P{	_In_MEROITIC_HIEROGLYPHS}', "");
Expect(0, 68000, '\P{^	_In_MEROITIC_HIEROGLYPHS}', "");
Error('\p{:=In_Meroitic_HIEROGLYPHS}');
Error('\P{:=In_Meroitic_HIEROGLYPHS}');
Expect(1, 67999, '\p{_-In_MEROITIC_HIEROGLYPHS}', "");
Expect(0, 67999, '\p{^_-In_MEROITIC_HIEROGLYPHS}', "");
Expect(0, 67999, '\P{_-In_MEROITIC_HIEROGLYPHS}', "");
Expect(1, 67999, '\P{^_-In_MEROITIC_HIEROGLYPHS}', "");
Expect(0, 68000, '\p{_-In_MEROITIC_HIEROGLYPHS}', "");
Expect(1, 68000, '\p{^_-In_MEROITIC_HIEROGLYPHS}', "");
Expect(1, 68000, '\P{_-In_MEROITIC_HIEROGLYPHS}', "");
Expect(0, 68000, '\P{^_-In_MEROITIC_HIEROGLYPHS}', "");
Error('\p{/a/ _In_Miao}');
Error('\P{/a/ _In_Miao}');
Expect(1, 94111, '\p{inmiao}', "");
Expect(0, 94111, '\p{^inmiao}', "");
Expect(0, 94111, '\P{inmiao}', "");
Expect(1, 94111, '\P{^inmiao}', "");
Expect(0, 94112, '\p{inmiao}', "");
Expect(1, 94112, '\p{^inmiao}', "");
Expect(1, 94112, '\P{inmiao}', "");
Expect(0, 94112, '\P{^inmiao}', "");
Expect(1, 94111, '\p{ -IN_miao}', "");
Expect(0, 94111, '\p{^ -IN_miao}', "");
Expect(0, 94111, '\P{ -IN_miao}', "");
Expect(1, 94111, '\P{^ -IN_miao}', "");
Expect(0, 94112, '\p{ -IN_miao}', "");
Expect(1, 94112, '\p{^ -IN_miao}', "");
Expect(1, 94112, '\P{ -IN_miao}', "");
Expect(0, 94112, '\P{^ -IN_miao}', "");
Error('\p{/a/ _in_Miao}');
Error('\P{/a/ _in_Miao}');
Expect(1, 94111, '\p{		In_MIAO}', "");
Expect(0, 94111, '\p{^		In_MIAO}', "");
Expect(0, 94111, '\P{		In_MIAO}', "");
Expect(1, 94111, '\P{^		In_MIAO}', "");
Expect(0, 94112, '\p{		In_MIAO}', "");
Expect(1, 94112, '\p{^		In_MIAO}', "");
Expect(1, 94112, '\P{		In_MIAO}', "");
Expect(0, 94112, '\P{^		In_MIAO}', "");
Error('\p{-:=IN_MONGOLIAN}');
Error('\P{-:=IN_MONGOLIAN}');
Expect(1, 6319, '\p{inmongolian}', "");
Expect(0, 6319, '\p{^inmongolian}', "");
Expect(0, 6319, '\P{inmongolian}', "");
Expect(1, 6319, '\P{^inmongolian}', "");
Expect(0, 6320, '\p{inmongolian}', "");
Expect(1, 6320, '\p{^inmongolian}', "");
Expect(1, 6320, '\P{inmongolian}', "");
Expect(0, 6320, '\P{^inmongolian}', "");
Expect(1, 6319, '\p{--In_Mongolian}', "");
Expect(0, 6319, '\p{^--In_Mongolian}', "");
Expect(0, 6319, '\P{--In_Mongolian}', "");
Expect(1, 6319, '\P{^--In_Mongolian}', "");
Expect(0, 6320, '\p{--In_Mongolian}', "");
Expect(1, 6320, '\p{^--In_Mongolian}', "");
Expect(1, 6320, '\P{--In_Mongolian}', "");
Expect(0, 6320, '\P{^--In_Mongolian}', "");
Error('\p{/a/-_IN_mongolian}');
Error('\P{/a/-_IN_mongolian}');
Expect(1, 6319, '\p{	-In_Mongolian}', "");
Expect(0, 6319, '\p{^	-In_Mongolian}', "");
Expect(0, 6319, '\P{	-In_Mongolian}', "");
Expect(1, 6319, '\P{^	-In_Mongolian}', "");
Expect(0, 6320, '\p{	-In_Mongolian}', "");
Expect(1, 6320, '\p{^	-In_Mongolian}', "");
Expect(1, 6320, '\P{	-In_Mongolian}', "");
Expect(0, 6320, '\P{^	-In_Mongolian}', "");
Error('\p{_IN_MYANMAR/a/}');
Error('\P{_IN_MYANMAR/a/}');
Expect(1, 4255, '\p{inmyanmar}', "");
Expect(0, 4255, '\p{^inmyanmar}', "");
Expect(0, 4255, '\P{inmyanmar}', "");
Expect(1, 4255, '\P{^inmyanmar}', "");
Expect(0, 4256, '\p{inmyanmar}', "");
Expect(1, 4256, '\p{^inmyanmar}', "");
Expect(1, 4256, '\P{inmyanmar}', "");
Expect(0, 4256, '\P{^inmyanmar}', "");
Expect(1, 4255, '\p{	_in_myanmar}', "");
Expect(0, 4255, '\p{^	_in_myanmar}', "");
Expect(0, 4255, '\P{	_in_myanmar}', "");
Expect(1, 4255, '\P{^	_in_myanmar}', "");
Expect(0, 4256, '\p{	_in_myanmar}', "");
Expect(1, 4256, '\p{^	_in_myanmar}', "");
Expect(1, 4256, '\P{	_in_myanmar}', "");
Expect(0, 4256, '\P{^	_in_myanmar}', "");
Error('\p{_-In_myanmar:=}');
Error('\P{_-In_myanmar:=}');
Expect(1, 4255, '\p{--In_Myanmar}', "");
Expect(0, 4255, '\p{^--In_Myanmar}', "");
Expect(0, 4255, '\P{--In_Myanmar}', "");
Expect(1, 4255, '\P{^--In_Myanmar}', "");
Expect(0, 4256, '\p{--In_Myanmar}', "");
Expect(1, 4256, '\p{^--In_Myanmar}', "");
Expect(1, 4256, '\P{--In_Myanmar}', "");
Expect(0, 4256, '\P{^--In_Myanmar}', "");
Error('\p{/a/__In_NKo}');
Error('\P{/a/__In_NKo}');
Expect(1, 2047, '\p{innko}', "");
Expect(0, 2047, '\p{^innko}', "");
Expect(0, 2047, '\P{innko}', "");
Expect(1, 2047, '\P{^innko}', "");
Expect(0, 2048, '\p{innko}', "");
Expect(1, 2048, '\p{^innko}', "");
Expect(1, 2048, '\P{innko}', "");
Expect(0, 2048, '\P{^innko}', "");
Expect(1, 2047, '\p{__in_NKO}', "");
Expect(0, 2047, '\p{^__in_NKO}', "");
Expect(0, 2047, '\P{__in_NKO}', "");
Expect(1, 2047, '\P{^__in_NKO}', "");
Expect(0, 2048, '\p{__in_NKO}', "");
Expect(1, 2048, '\p{^__in_NKO}', "");
Expect(1, 2048, '\P{__in_NKO}', "");
Expect(0, 2048, '\P{^__in_NKO}', "");
Error('\p{ /a/IN_NKo}');
Error('\P{ /a/IN_NKo}');
Expect(1, 2047, '\p{-_in_nko}', "");
Expect(0, 2047, '\p{^-_in_nko}', "");
Expect(0, 2047, '\P{-_in_nko}', "");
Expect(1, 2047, '\P{^-_in_nko}', "");
Expect(0, 2048, '\p{-_in_nko}', "");
Expect(1, 2048, '\p{^-_in_nko}', "");
Expect(1, 2048, '\P{-_in_nko}', "");
Expect(0, 2048, '\P{^-_in_nko}', "");
Error('\p{ /a/in_New_tai_lue}');
Error('\P{ /a/in_New_tai_lue}');
Expect(1, 6623, '\p{innewtailue}', "");
Expect(0, 6623, '\p{^innewtailue}', "");
Expect(0, 6623, '\P{innewtailue}', "");
Expect(1, 6623, '\P{^innewtailue}', "");
Expect(0, 6624, '\p{innewtailue}', "");
Expect(1, 6624, '\p{^innewtailue}', "");
Expect(1, 6624, '\P{innewtailue}', "");
Expect(0, 6624, '\P{^innewtailue}', "");
Expect(1, 6623, '\p{ 	In_New_tai_lue}', "");
Expect(0, 6623, '\p{^ 	In_New_tai_lue}', "");
Expect(0, 6623, '\P{ 	In_New_tai_lue}', "");
Expect(1, 6623, '\P{^ 	In_New_tai_lue}', "");
Expect(0, 6624, '\p{ 	In_New_tai_lue}', "");
Expect(1, 6624, '\p{^ 	In_New_tai_lue}', "");
Expect(1, 6624, '\P{ 	In_New_tai_lue}', "");
Expect(0, 6624, '\P{^ 	In_New_tai_lue}', "");
Error('\p{-_in_NEW_TAI_Lue:=}');
Error('\P{-_in_NEW_TAI_Lue:=}');
Expect(1, 6623, '\p{		In_New_tai_Lue}', "");
Expect(0, 6623, '\p{^		In_New_tai_Lue}', "");
Expect(0, 6623, '\P{		In_New_tai_Lue}', "");
Expect(1, 6623, '\P{^		In_New_tai_Lue}', "");
Expect(0, 6624, '\p{		In_New_tai_Lue}', "");
Expect(1, 6624, '\p{^		In_New_tai_Lue}', "");
Expect(1, 6624, '\P{		In_New_tai_Lue}', "");
Expect(0, 6624, '\P{^		In_New_tai_Lue}', "");
Error('\p{ _In_OGHAM:=}');
Error('\P{ _In_OGHAM:=}');
Expect(1, 5791, '\p{inogham}', "");
Expect(0, 5791, '\p{^inogham}', "");
Expect(0, 5791, '\P{inogham}', "");
Expect(1, 5791, '\P{^inogham}', "");
Expect(0, 5792, '\p{inogham}', "");
Expect(1, 5792, '\p{^inogham}', "");
Expect(1, 5792, '\P{inogham}', "");
Expect(0, 5792, '\P{^inogham}', "");
Expect(1, 5791, '\p{_ In_ogham}', "");
Expect(0, 5791, '\p{^_ In_ogham}', "");
Expect(0, 5791, '\P{_ In_ogham}', "");
Expect(1, 5791, '\P{^_ In_ogham}', "");
Expect(0, 5792, '\p{_ In_ogham}', "");
Expect(1, 5792, '\p{^_ In_ogham}', "");
Expect(1, 5792, '\P{_ In_ogham}', "");
Expect(0, 5792, '\P{^_ In_ogham}', "");
Error('\p{ -In_Ogham:=}');
Error('\P{ -In_Ogham:=}');
Expect(1, 5791, '\p{	 IN_ogham}', "");
Expect(0, 5791, '\p{^	 IN_ogham}', "");
Expect(0, 5791, '\P{	 IN_ogham}', "");
Expect(1, 5791, '\P{^	 IN_ogham}', "");
Expect(0, 5792, '\p{	 IN_ogham}', "");
Expect(1, 5792, '\p{^	 IN_ogham}', "");
Expect(1, 5792, '\P{	 IN_ogham}', "");
Expect(0, 5792, '\P{^	 IN_ogham}', "");
Error('\p{-:=IN_Ol_chiki}');
Error('\P{-:=IN_Ol_chiki}');
Expect(1, 7295, '\p{inolchiki}', "");
Expect(0, 7295, '\p{^inolchiki}', "");
Expect(0, 7295, '\P{inolchiki}', "");
Expect(1, 7295, '\P{^inolchiki}', "");
Expect(0, 7296, '\p{inolchiki}', "");
Expect(1, 7296, '\p{^inolchiki}', "");
Expect(1, 7296, '\P{inolchiki}', "");
Expect(0, 7296, '\P{^inolchiki}', "");
Expect(1, 7295, '\p{ 	IN_Ol_chiki}', "");
Expect(0, 7295, '\p{^ 	IN_Ol_chiki}', "");
Expect(0, 7295, '\P{ 	IN_Ol_chiki}', "");
Expect(1, 7295, '\P{^ 	IN_Ol_chiki}', "");
Expect(0, 7296, '\p{ 	IN_Ol_chiki}', "");
Expect(1, 7296, '\p{^ 	IN_Ol_chiki}', "");
Expect(1, 7296, '\P{ 	IN_Ol_chiki}', "");
Expect(0, 7296, '\P{^ 	IN_Ol_chiki}', "");
Error('\p{_-In_Ol_chiki:=}');
Error('\P{_-In_Ol_chiki:=}');
Expect(1, 7295, '\p{-	In_Ol_CHIKI}', "");
Expect(0, 7295, '\p{^-	In_Ol_CHIKI}', "");
Expect(0, 7295, '\P{-	In_Ol_CHIKI}', "");
Expect(1, 7295, '\P{^-	In_Ol_CHIKI}', "");
Expect(0, 7296, '\p{-	In_Ol_CHIKI}', "");
Expect(1, 7296, '\p{^-	In_Ol_CHIKI}', "");
Expect(1, 7296, '\P{-	In_Ol_CHIKI}', "");
Expect(0, 7296, '\P{^-	In_Ol_CHIKI}', "");
Error('\p{--IN_Old_Italic:=}');
Error('\P{--IN_Old_Italic:=}');
Expect(1, 66351, '\p{inolditalic}', "");
Expect(0, 66351, '\p{^inolditalic}', "");
Expect(0, 66351, '\P{inolditalic}', "");
Expect(1, 66351, '\P{^inolditalic}', "");
Expect(0, 66352, '\p{inolditalic}', "");
Expect(1, 66352, '\p{^inolditalic}', "");
Expect(1, 66352, '\P{inolditalic}', "");
Expect(0, 66352, '\P{^inolditalic}', "");
Expect(1, 66351, '\p{	 In_OLD_Italic}', "");
Expect(0, 66351, '\p{^	 In_OLD_Italic}', "");
Expect(0, 66351, '\P{	 In_OLD_Italic}', "");
Expect(1, 66351, '\P{^	 In_OLD_Italic}', "");
Expect(0, 66352, '\p{	 In_OLD_Italic}', "");
Expect(1, 66352, '\p{^	 In_OLD_Italic}', "");
Expect(1, 66352, '\P{	 In_OLD_Italic}', "");
Expect(0, 66352, '\P{^	 In_OLD_Italic}', "");
Error('\p{	In_Old_ITALIC/a/}');
Error('\P{	In_Old_ITALIC/a/}');
Expect(1, 66351, '\p{_IN_Old_Italic}', "");
Expect(0, 66351, '\p{^_IN_Old_Italic}', "");
Expect(0, 66351, '\P{_IN_Old_Italic}', "");
Expect(1, 66351, '\P{^_IN_Old_Italic}', "");
Expect(0, 66352, '\p{_IN_Old_Italic}', "");
Expect(1, 66352, '\p{^_IN_Old_Italic}', "");
Expect(1, 66352, '\P{_IN_Old_Italic}', "");
Expect(0, 66352, '\P{^_IN_Old_Italic}', "");
Error('\p{_-IN_Old_PERSIAN/a/}');
Error('\P{_-IN_Old_PERSIAN/a/}');
Expect(1, 66527, '\p{inoldpersian}', "");
Expect(0, 66527, '\p{^inoldpersian}', "");
Expect(0, 66527, '\P{inoldpersian}', "");
Expect(1, 66527, '\P{^inoldpersian}', "");
Expect(0, 66528, '\p{inoldpersian}', "");
Expect(1, 66528, '\p{^inoldpersian}', "");
Expect(1, 66528, '\P{inoldpersian}', "");
Expect(0, 66528, '\P{^inoldpersian}', "");
Expect(1, 66527, '\p{ in_old_persian}', "");
Expect(0, 66527, '\p{^ in_old_persian}', "");
Expect(0, 66527, '\P{ in_old_persian}', "");
Expect(1, 66527, '\P{^ in_old_persian}', "");
Expect(0, 66528, '\p{ in_old_persian}', "");
Expect(1, 66528, '\p{^ in_old_persian}', "");
Expect(1, 66528, '\P{ in_old_persian}', "");
Expect(0, 66528, '\P{^ in_old_persian}', "");
Error('\p{:=-IN_Old_PERSIAN}');
Error('\P{:=-IN_Old_PERSIAN}');
Expect(1, 66527, '\p{ 	In_Old_PERSIAN}', "");
Expect(0, 66527, '\p{^ 	In_Old_PERSIAN}', "");
Expect(0, 66527, '\P{ 	In_Old_PERSIAN}', "");
Expect(1, 66527, '\P{^ 	In_Old_PERSIAN}', "");
Expect(0, 66528, '\p{ 	In_Old_PERSIAN}', "");
Expect(1, 66528, '\p{^ 	In_Old_PERSIAN}', "");
Expect(1, 66528, '\P{ 	In_Old_PERSIAN}', "");
Expect(0, 66528, '\P{^ 	In_Old_PERSIAN}', "");
Error('\p{/a/ _IN_old_South_Arabian}');
Error('\P{/a/ _IN_old_South_Arabian}');
Expect(1, 68223, '\p{inoldsoutharabian}', "");
Expect(0, 68223, '\p{^inoldsoutharabian}', "");
Expect(0, 68223, '\P{inoldsoutharabian}', "");
Expect(1, 68223, '\P{^inoldsoutharabian}', "");
Expect(0, 68224, '\p{inoldsoutharabian}', "");
Expect(1, 68224, '\p{^inoldsoutharabian}', "");
Expect(1, 68224, '\P{inoldsoutharabian}', "");
Expect(0, 68224, '\P{^inoldsoutharabian}', "");
Expect(1, 68223, '\p{ -In_Old_south_arabian}', "");
Expect(0, 68223, '\p{^ -In_Old_south_arabian}', "");
Expect(0, 68223, '\P{ -In_Old_south_arabian}', "");
Expect(1, 68223, '\P{^ -In_Old_south_arabian}', "");
Expect(0, 68224, '\p{ -In_Old_south_arabian}', "");
Expect(1, 68224, '\p{^ -In_Old_south_arabian}', "");
Expect(1, 68224, '\P{ -In_Old_south_arabian}', "");
Expect(0, 68224, '\P{^ -In_Old_south_arabian}', "");
Error('\p{/a/ _In_OLD_SOUTH_Arabian}');
Error('\P{/a/ _In_OLD_SOUTH_Arabian}');
Expect(1, 68223, '\p{_in_Old_South_Arabian}', "");
Expect(0, 68223, '\p{^_in_Old_South_Arabian}', "");
Expect(0, 68223, '\P{_in_Old_South_Arabian}', "");
Expect(1, 68223, '\P{^_in_Old_South_Arabian}', "");
Expect(0, 68224, '\p{_in_Old_South_Arabian}', "");
Expect(1, 68224, '\p{^_in_Old_South_Arabian}', "");
Expect(1, 68224, '\P{_in_Old_South_Arabian}', "");
Expect(0, 68224, '\P{^_in_Old_South_Arabian}', "");
Error('\p{_/a/IN_Old_turkic}');
Error('\P{_/a/IN_Old_turkic}');
Expect(1, 68687, '\p{inoldturkic}', "");
Expect(0, 68687, '\p{^inoldturkic}', "");
Expect(0, 68687, '\P{inoldturkic}', "");
Expect(1, 68687, '\P{^inoldturkic}', "");
Expect(0, 68688, '\p{inoldturkic}', "");
Expect(1, 68688, '\p{^inoldturkic}', "");
Expect(1, 68688, '\P{inoldturkic}', "");
Expect(0, 68688, '\P{^inoldturkic}', "");
Expect(1, 68687, '\p{	 IN_Old_turkic}', "");
Expect(0, 68687, '\p{^	 IN_Old_turkic}', "");
Expect(0, 68687, '\P{	 IN_Old_turkic}', "");
Expect(1, 68687, '\P{^	 IN_Old_turkic}', "");
Expect(0, 68688, '\p{	 IN_Old_turkic}', "");
Expect(1, 68688, '\p{^	 IN_Old_turkic}', "");
Expect(1, 68688, '\P{	 IN_Old_turkic}', "");
Expect(0, 68688, '\P{^	 IN_Old_turkic}', "");
Error('\p{_/a/IN_OLD_Turkic}');
Error('\P{_/a/IN_OLD_Turkic}');
Expect(1, 68687, '\p{__In_OLD_TURKIC}', "");
Expect(0, 68687, '\p{^__In_OLD_TURKIC}', "");
Expect(0, 68687, '\P{__In_OLD_TURKIC}', "");
Expect(1, 68687, '\P{^__In_OLD_TURKIC}', "");
Expect(0, 68688, '\p{__In_OLD_TURKIC}', "");
Expect(1, 68688, '\p{^__In_OLD_TURKIC}', "");
Expect(1, 68688, '\P{__In_OLD_TURKIC}', "");
Expect(0, 68688, '\P{^__In_OLD_TURKIC}', "");
Error('\p{-/a/In_Oriya}');
Error('\P{-/a/In_Oriya}');
Expect(1, 2943, '\p{inoriya}', "");
Expect(0, 2943, '\p{^inoriya}', "");
Expect(0, 2943, '\P{inoriya}', "");
Expect(1, 2943, '\P{^inoriya}', "");
Expect(0, 2944, '\p{inoriya}', "");
Expect(1, 2944, '\p{^inoriya}', "");
Expect(1, 2944, '\P{inoriya}', "");
Expect(0, 2944, '\P{^inoriya}', "");
Expect(1, 2943, '\p{	_In_Oriya}', "");
Expect(0, 2943, '\p{^	_In_Oriya}', "");
Expect(0, 2943, '\P{	_In_Oriya}', "");
Expect(1, 2943, '\P{^	_In_Oriya}', "");
Expect(0, 2944, '\p{	_In_Oriya}', "");
Expect(1, 2944, '\p{^	_In_Oriya}', "");
Expect(1, 2944, '\P{	_In_Oriya}', "");
Expect(0, 2944, '\P{^	_In_Oriya}', "");
Error('\p{:= -in_Oriya}');
Error('\P{:= -in_Oriya}');
Expect(1, 2943, '\p{_in_Oriya}', "");
Expect(0, 2943, '\p{^_in_Oriya}', "");
Expect(0, 2943, '\P{_in_Oriya}', "");
Expect(1, 2943, '\P{^_in_Oriya}', "");
Expect(0, 2944, '\p{_in_Oriya}', "");
Expect(1, 2944, '\p{^_in_Oriya}', "");
Expect(1, 2944, '\P{_in_Oriya}', "");
Expect(0, 2944, '\P{^_in_Oriya}', "");
Error('\p{/a/-_In_Osmanya}');
Error('\P{/a/-_In_Osmanya}');
Expect(1, 66735, '\p{inosmanya}', "");
Expect(0, 66735, '\p{^inosmanya}', "");
Expect(0, 66735, '\P{inosmanya}', "");
Expect(1, 66735, '\P{^inosmanya}', "");
Expect(0, 66736, '\p{inosmanya}', "");
Expect(1, 66736, '\p{^inosmanya}', "");
Expect(1, 66736, '\P{inosmanya}', "");
Expect(0, 66736, '\P{^inosmanya}', "");
Expect(1, 66735, '\p{	-In_osmanya}', "");
Expect(0, 66735, '\p{^	-In_osmanya}', "");
Expect(0, 66735, '\P{	-In_osmanya}', "");
Expect(1, 66735, '\P{^	-In_osmanya}', "");
Expect(0, 66736, '\p{	-In_osmanya}', "");
Expect(1, 66736, '\p{^	-In_osmanya}', "");
Expect(1, 66736, '\P{	-In_osmanya}', "");
Expect(0, 66736, '\P{^	-In_osmanya}', "");
Error('\p{/a/_	in_osmanya}');
Error('\P{/a/_	in_osmanya}');
Expect(1, 66735, '\p{	_IN_Osmanya}', "");
Expect(0, 66735, '\p{^	_IN_Osmanya}', "");
Expect(0, 66735, '\P{	_IN_Osmanya}', "");
Expect(1, 66735, '\P{^	_IN_Osmanya}', "");
Expect(0, 66736, '\p{	_IN_Osmanya}', "");
Expect(1, 66736, '\p{^	_IN_Osmanya}', "");
Expect(1, 66736, '\P{	_IN_Osmanya}', "");
Expect(0, 66736, '\P{^	_IN_Osmanya}', "");
Error('\p{-/a/In_Phags_pa}');
Error('\P{-/a/In_Phags_pa}');
Expect(1, 43135, '\p{inphagspa}', "");
Expect(0, 43135, '\p{^inphagspa}', "");
Expect(0, 43135, '\P{inphagspa}', "");
Expect(1, 43135, '\P{^inphagspa}', "");
Expect(0, 43136, '\p{inphagspa}', "");
Expect(1, 43136, '\p{^inphagspa}', "");
Expect(1, 43136, '\P{inphagspa}', "");
Expect(0, 43136, '\P{^inphagspa}', "");
Expect(1, 43135, '\p{_-in_phags_Pa}', "");
Expect(0, 43135, '\p{^_-in_phags_Pa}', "");
Expect(0, 43135, '\P{_-in_phags_Pa}', "");
Expect(1, 43135, '\P{^_-in_phags_Pa}', "");
Expect(0, 43136, '\p{_-in_phags_Pa}', "");
Expect(1, 43136, '\p{^_-in_phags_Pa}', "");
Expect(1, 43136, '\P{_-in_phags_Pa}', "");
Expect(0, 43136, '\P{^_-in_phags_Pa}', "");
Error('\p{:= in_PHAGS_Pa}');
Error('\P{:= in_PHAGS_Pa}');
Expect(1, 43135, '\p{	IN_Phags_pa}', "");
Expect(0, 43135, '\p{^	IN_Phags_pa}', "");
Expect(0, 43135, '\P{	IN_Phags_pa}', "");
Expect(1, 43135, '\P{^	IN_Phags_pa}', "");
Expect(0, 43136, '\p{	IN_Phags_pa}', "");
Expect(1, 43136, '\p{^	IN_Phags_pa}', "");
Expect(1, 43136, '\P{	IN_Phags_pa}', "");
Expect(0, 43136, '\P{^	IN_Phags_pa}', "");
Error('\p{_/a/In_PHOENICIAN}');
Error('\P{_/a/In_PHOENICIAN}');
Expect(1, 67871, '\p{inphoenician}', "");
Expect(0, 67871, '\p{^inphoenician}', "");
Expect(0, 67871, '\P{inphoenician}', "");
Expect(1, 67871, '\P{^inphoenician}', "");
Expect(0, 67872, '\p{inphoenician}', "");
Expect(1, 67872, '\p{^inphoenician}', "");
Expect(1, 67872, '\P{inphoenician}', "");
Expect(0, 67872, '\P{^inphoenician}', "");
Expect(1, 67871, '\p{_IN_Phoenician}', "");
Expect(0, 67871, '\p{^_IN_Phoenician}', "");
Expect(0, 67871, '\P{_IN_Phoenician}', "");
Expect(1, 67871, '\P{^_IN_Phoenician}', "");
Expect(0, 67872, '\p{_IN_Phoenician}', "");
Expect(1, 67872, '\p{^_IN_Phoenician}', "");
Expect(1, 67872, '\P{_IN_Phoenician}', "");
Expect(0, 67872, '\P{^_IN_Phoenician}', "");
Error('\p{:=  In_Phoenician}');
Error('\P{:=  In_Phoenician}');
Expect(1, 67871, '\p{	in_PHOENICIAN}', "");
Expect(0, 67871, '\p{^	in_PHOENICIAN}', "");
Expect(0, 67871, '\P{	in_PHOENICIAN}', "");
Expect(1, 67871, '\P{^	in_PHOENICIAN}', "");
Expect(0, 67872, '\p{	in_PHOENICIAN}', "");
Expect(1, 67872, '\p{^	in_PHOENICIAN}', "");
Expect(1, 67872, '\P{	in_PHOENICIAN}', "");
Expect(0, 67872, '\P{^	in_PHOENICIAN}', "");
Error('\p{/a/IN_Rejang}');
Error('\P{/a/IN_Rejang}');
Expect(1, 43359, '\p{inrejang}', "");
Expect(0, 43359, '\p{^inrejang}', "");
Expect(0, 43359, '\P{inrejang}', "");
Expect(1, 43359, '\P{^inrejang}', "");
Expect(0, 43360, '\p{inrejang}', "");
Expect(1, 43360, '\p{^inrejang}', "");
Expect(1, 43360, '\P{inrejang}', "");
Expect(0, 43360, '\P{^inrejang}', "");
Expect(1, 43359, '\p{ -IN_rejang}', "");
Expect(0, 43359, '\p{^ -IN_rejang}', "");
Expect(0, 43359, '\P{ -IN_rejang}', "");
Expect(1, 43359, '\P{^ -IN_rejang}', "");
Expect(0, 43360, '\p{ -IN_rejang}', "");
Expect(1, 43360, '\p{^ -IN_rejang}', "");
Expect(1, 43360, '\P{ -IN_rejang}', "");
Expect(0, 43360, '\P{^ -IN_rejang}', "");
Error('\p{/a/in_REJANG}');
Error('\P{/a/in_REJANG}');
Expect(1, 43359, '\p{	In_Rejang}', "");
Expect(0, 43359, '\p{^	In_Rejang}', "");
Expect(0, 43359, '\P{	In_Rejang}', "");
Expect(1, 43359, '\P{^	In_Rejang}', "");
Expect(0, 43360, '\p{	In_Rejang}', "");
Expect(1, 43360, '\p{^	In_Rejang}', "");
Expect(1, 43360, '\P{	In_Rejang}', "");
Expect(0, 43360, '\P{^	In_Rejang}', "");
Error('\p{:=_In_Runic}');
Error('\P{:=_In_Runic}');
Expect(1, 5887, '\p{inrunic}', "");
Expect(0, 5887, '\p{^inrunic}', "");
Expect(0, 5887, '\P{inrunic}', "");
Expect(1, 5887, '\P{^inrunic}', "");
Expect(0, 5888, '\p{inrunic}', "");
Expect(1, 5888, '\p{^inrunic}', "");
Expect(1, 5888, '\P{inrunic}', "");
Expect(0, 5888, '\P{^inrunic}', "");
Expect(1, 5887, '\p{-IN_RUNIC}', "");
Expect(0, 5887, '\p{^-IN_RUNIC}', "");
Expect(0, 5887, '\P{-IN_RUNIC}', "");
Expect(1, 5887, '\P{^-IN_RUNIC}', "");
Expect(0, 5888, '\p{-IN_RUNIC}', "");
Expect(1, 5888, '\p{^-IN_RUNIC}', "");
Expect(1, 5888, '\P{-IN_RUNIC}', "");
Expect(0, 5888, '\P{^-IN_RUNIC}', "");
Error('\p{_/a/in_runic}');
Error('\P{_/a/in_runic}');
Expect(1, 5887, '\p{--in_Runic}', "");
Expect(0, 5887, '\p{^--in_Runic}', "");
Expect(0, 5887, '\P{--in_Runic}', "");
Expect(1, 5887, '\P{^--in_Runic}', "");
Expect(0, 5888, '\p{--in_Runic}', "");
Expect(1, 5888, '\p{^--in_Runic}', "");
Expect(1, 5888, '\P{--in_Runic}', "");
Expect(0, 5888, '\P{^--in_Runic}', "");
Error('\p{IN_samaritan:=}');
Error('\P{IN_samaritan:=}');
Expect(1, 2111, '\p{insamaritan}', "");
Expect(0, 2111, '\p{^insamaritan}', "");
Expect(0, 2111, '\P{insamaritan}', "");
Expect(1, 2111, '\P{^insamaritan}', "");
Expect(0, 2112, '\p{insamaritan}', "");
Expect(1, 2112, '\p{^insamaritan}', "");
Expect(1, 2112, '\P{insamaritan}', "");
Expect(0, 2112, '\P{^insamaritan}', "");
Expect(1, 2111, '\p{ -In_SAMARITAN}', "");
Expect(0, 2111, '\p{^ -In_SAMARITAN}', "");
Expect(0, 2111, '\P{ -In_SAMARITAN}', "");
Expect(1, 2111, '\P{^ -In_SAMARITAN}', "");
Expect(0, 2112, '\p{ -In_SAMARITAN}', "");
Expect(1, 2112, '\p{^ -In_SAMARITAN}', "");
Expect(1, 2112, '\P{ -In_SAMARITAN}', "");
Expect(0, 2112, '\P{^ -In_SAMARITAN}', "");
Error('\p{:=- IN_Samaritan}');
Error('\P{:=- IN_Samaritan}');
Expect(1, 2111, '\p{ -In_Samaritan}', "");
Expect(0, 2111, '\p{^ -In_Samaritan}', "");
Expect(0, 2111, '\P{ -In_Samaritan}', "");
Expect(1, 2111, '\P{^ -In_Samaritan}', "");
Expect(0, 2112, '\p{ -In_Samaritan}', "");
Expect(1, 2112, '\p{^ -In_Samaritan}', "");
Expect(1, 2112, '\P{ -In_Samaritan}', "");
Expect(0, 2112, '\P{^ -In_Samaritan}', "");
Error('\p{ /a/IN_saurashtra}');
Error('\P{ /a/IN_saurashtra}');
Expect(1, 43231, '\p{insaurashtra}', "");
Expect(0, 43231, '\p{^insaurashtra}', "");
Expect(0, 43231, '\P{insaurashtra}', "");
Expect(1, 43231, '\P{^insaurashtra}', "");
Expect(0, 43232, '\p{insaurashtra}', "");
Expect(1, 43232, '\p{^insaurashtra}', "");
Expect(1, 43232, '\P{insaurashtra}', "");
Expect(0, 43232, '\P{^insaurashtra}', "");
Expect(1, 43231, '\p{_-IN_saurashtra}', "");
Expect(0, 43231, '\p{^_-IN_saurashtra}', "");
Expect(0, 43231, '\P{_-IN_saurashtra}', "");
Expect(1, 43231, '\P{^_-IN_saurashtra}', "");
Expect(0, 43232, '\p{_-IN_saurashtra}', "");
Expect(1, 43232, '\p{^_-IN_saurashtra}', "");
Expect(1, 43232, '\P{_-IN_saurashtra}', "");
Expect(0, 43232, '\P{^_-IN_saurashtra}', "");
Error('\p{/a/_-In_saurashtra}');
Error('\P{/a/_-In_saurashtra}');
Expect(1, 43231, '\p{		In_SAURASHTRA}', "");
Expect(0, 43231, '\p{^		In_SAURASHTRA}', "");
Expect(0, 43231, '\P{		In_SAURASHTRA}', "");
Expect(1, 43231, '\P{^		In_SAURASHTRA}', "");
Expect(0, 43232, '\p{		In_SAURASHTRA}', "");
Expect(1, 43232, '\p{^		In_SAURASHTRA}', "");
Expect(1, 43232, '\P{		In_SAURASHTRA}', "");
Expect(0, 43232, '\P{^		In_SAURASHTRA}', "");
Error('\p{:= In_Sharada}');
Error('\P{:= In_Sharada}');
Expect(1, 70111, '\p{insharada}', "");
Expect(0, 70111, '\p{^insharada}', "");
Expect(0, 70111, '\P{insharada}', "");
Expect(1, 70111, '\P{^insharada}', "");
Expect(0, 70112, '\p{insharada}', "");
Expect(1, 70112, '\p{^insharada}', "");
Expect(1, 70112, '\P{insharada}', "");
Expect(0, 70112, '\P{^insharada}', "");
Expect(1, 70111, '\p{	IN_Sharada}', "");
Expect(0, 70111, '\p{^	IN_Sharada}', "");
Expect(0, 70111, '\P{	IN_Sharada}', "");
Expect(1, 70111, '\P{^	IN_Sharada}', "");
Expect(0, 70112, '\p{	IN_Sharada}', "");
Expect(1, 70112, '\p{^	IN_Sharada}', "");
Expect(1, 70112, '\P{	IN_Sharada}', "");
Expect(0, 70112, '\P{^	IN_Sharada}', "");
Error('\p{:=_	In_Sharada}');
Error('\P{:=_	In_Sharada}');
Expect(1, 70111, '\p{_ In_Sharada}', "");
Expect(0, 70111, '\p{^_ In_Sharada}', "");
Expect(0, 70111, '\P{_ In_Sharada}', "");
Expect(1, 70111, '\P{^_ In_Sharada}', "");
Expect(0, 70112, '\p{_ In_Sharada}', "");
Expect(1, 70112, '\p{^_ In_Sharada}', "");
Expect(1, 70112, '\P{_ In_Sharada}', "");
Expect(0, 70112, '\P{^_ In_Sharada}', "");
Error('\p{-/a/in_Shavian}');
Error('\P{-/a/in_Shavian}');
Expect(1, 66687, '\p{inshavian}', "");
Expect(0, 66687, '\p{^inshavian}', "");
Expect(0, 66687, '\P{inshavian}', "");
Expect(1, 66687, '\P{^inshavian}', "");
Expect(0, 66688, '\p{inshavian}', "");
Expect(1, 66688, '\p{^inshavian}', "");
Expect(1, 66688, '\P{inshavian}', "");
Expect(0, 66688, '\P{^inshavian}', "");
Expect(1, 66687, '\p{-	IN_SHAVIAN}', "");
Expect(0, 66687, '\p{^-	IN_SHAVIAN}', "");
Expect(0, 66687, '\P{-	IN_SHAVIAN}', "");
Expect(1, 66687, '\P{^-	IN_SHAVIAN}', "");
Expect(0, 66688, '\p{-	IN_SHAVIAN}', "");
Expect(1, 66688, '\p{^-	IN_SHAVIAN}', "");
Expect(1, 66688, '\P{-	IN_SHAVIAN}', "");
Expect(0, 66688, '\P{^-	IN_SHAVIAN}', "");
Error('\p{_/a/In_Shavian}');
Error('\P{_/a/In_Shavian}');
Expect(1, 66687, '\p{_	IN_Shavian}', "");
Expect(0, 66687, '\p{^_	IN_Shavian}', "");
Expect(0, 66687, '\P{_	IN_Shavian}', "");
Expect(1, 66687, '\P{^_	IN_Shavian}', "");
Expect(0, 66688, '\p{_	IN_Shavian}', "");
Expect(1, 66688, '\p{^_	IN_Shavian}', "");
Expect(1, 66688, '\P{_	IN_Shavian}', "");
Expect(0, 66688, '\P{^_	IN_Shavian}', "");
Error('\p{/a/_In_SINHALA}');
Error('\P{/a/_In_SINHALA}');
Expect(1, 3583, '\p{insinhala}', "");
Expect(0, 3583, '\p{^insinhala}', "");
Expect(0, 3583, '\P{insinhala}', "");
Expect(1, 3583, '\P{^insinhala}', "");
Expect(0, 3584, '\p{insinhala}', "");
Expect(1, 3584, '\p{^insinhala}', "");
Expect(1, 3584, '\P{insinhala}', "");
Expect(0, 3584, '\P{^insinhala}', "");
Expect(1, 3583, '\p{ -IN_SINHALA}', "");
Expect(0, 3583, '\p{^ -IN_SINHALA}', "");
Expect(0, 3583, '\P{ -IN_SINHALA}', "");
Expect(1, 3583, '\P{^ -IN_SINHALA}', "");
Expect(0, 3584, '\p{ -IN_SINHALA}', "");
Expect(1, 3584, '\p{^ -IN_SINHALA}', "");
Expect(1, 3584, '\P{ -IN_SINHALA}', "");
Expect(0, 3584, '\P{^ -IN_SINHALA}', "");
Error('\p{_In_sinhala/a/}');
Error('\P{_In_sinhala/a/}');
Expect(1, 3583, '\p{	 In_Sinhala}', "");
Expect(0, 3583, '\p{^	 In_Sinhala}', "");
Expect(0, 3583, '\P{	 In_Sinhala}', "");
Expect(1, 3583, '\P{^	 In_Sinhala}', "");
Expect(0, 3584, '\p{	 In_Sinhala}', "");
Expect(1, 3584, '\p{^	 In_Sinhala}', "");
Expect(1, 3584, '\P{	 In_Sinhala}', "");
Expect(0, 3584, '\P{^	 In_Sinhala}', "");
Error('\p{/a/-_In_sora_Sompeng}');
Error('\P{/a/-_In_sora_Sompeng}');
Expect(1, 69887, '\p{insorasompeng}', "");
Expect(0, 69887, '\p{^insorasompeng}', "");
Expect(0, 69887, '\P{insorasompeng}', "");
Expect(1, 69887, '\P{^insorasompeng}', "");
Expect(0, 69888, '\p{insorasompeng}', "");
Expect(1, 69888, '\p{^insorasompeng}', "");
Expect(1, 69888, '\P{insorasompeng}', "");
Expect(0, 69888, '\P{^insorasompeng}', "");
Expect(1, 69887, '\p{_ In_Sora_sompeng}', "");
Expect(0, 69887, '\p{^_ In_Sora_sompeng}', "");
Expect(0, 69887, '\P{_ In_Sora_sompeng}', "");
Expect(1, 69887, '\P{^_ In_Sora_sompeng}', "");
Expect(0, 69888, '\p{_ In_Sora_sompeng}', "");
Expect(1, 69888, '\p{^_ In_Sora_sompeng}', "");
Expect(1, 69888, '\P{_ In_Sora_sompeng}', "");
Expect(0, 69888, '\P{^_ In_Sora_sompeng}', "");
Error('\p{:=_In_Sora_Sompeng}');
Error('\P{:=_In_Sora_Sompeng}');
Expect(1, 69887, '\p{_ IN_Sora_SOMPENG}', "");
Expect(0, 69887, '\p{^_ IN_Sora_SOMPENG}', "");
Expect(0, 69887, '\P{_ IN_Sora_SOMPENG}', "");
Expect(1, 69887, '\P{^_ IN_Sora_SOMPENG}', "");
Expect(0, 69888, '\p{_ IN_Sora_SOMPENG}', "");
Expect(1, 69888, '\p{^_ IN_Sora_SOMPENG}', "");
Expect(1, 69888, '\P{_ IN_Sora_SOMPENG}', "");
Expect(0, 69888, '\P{^_ IN_Sora_SOMPENG}', "");
Error('\p{:= IN_Sundanese}');
Error('\P{:= IN_Sundanese}');
Expect(1, 7103, '\p{insundanese}', "");
Expect(0, 7103, '\p{^insundanese}', "");
Expect(0, 7103, '\P{insundanese}', "");
Expect(1, 7103, '\P{^insundanese}', "");
Expect(0, 7104, '\p{insundanese}', "");
Expect(1, 7104, '\p{^insundanese}', "");
Expect(1, 7104, '\P{insundanese}', "");
Expect(0, 7104, '\P{^insundanese}', "");
Expect(1, 7103, '\p{ In_Sundanese}', "");
Expect(0, 7103, '\p{^ In_Sundanese}', "");
Expect(0, 7103, '\P{ In_Sundanese}', "");
Expect(1, 7103, '\P{^ In_Sundanese}', "");
Expect(0, 7104, '\p{ In_Sundanese}', "");
Expect(1, 7104, '\p{^ In_Sundanese}', "");
Expect(1, 7104, '\P{ In_Sundanese}', "");
Expect(0, 7104, '\P{^ In_Sundanese}', "");
Error('\p{/a/ _In_Sundanese}');
Error('\P{/a/ _In_Sundanese}');
Expect(1, 7103, '\p{-_In_Sundanese}', "");
Expect(0, 7103, '\p{^-_In_Sundanese}', "");
Expect(0, 7103, '\P{-_In_Sundanese}', "");
Expect(1, 7103, '\P{^-_In_Sundanese}', "");
Expect(0, 7104, '\p{-_In_Sundanese}', "");
Expect(1, 7104, '\p{^-_In_Sundanese}', "");
Expect(1, 7104, '\P{-_In_Sundanese}', "");
Expect(0, 7104, '\P{^-_In_Sundanese}', "");
Error('\p{	IN_Syloti_Nagri:=}');
Error('\P{	IN_Syloti_Nagri:=}');
Expect(1, 43055, '\p{insylotinagri}', "");
Expect(0, 43055, '\p{^insylotinagri}', "");
Expect(0, 43055, '\P{insylotinagri}', "");
Expect(1, 43055, '\P{^insylotinagri}', "");
Expect(0, 43056, '\p{insylotinagri}', "");
Expect(1, 43056, '\p{^insylotinagri}', "");
Expect(1, 43056, '\P{insylotinagri}', "");
Expect(0, 43056, '\P{^insylotinagri}', "");
Expect(1, 43055, '\p{--IN_Syloti_Nagri}', "");
Expect(0, 43055, '\p{^--IN_Syloti_Nagri}', "");
Expect(0, 43055, '\P{--IN_Syloti_Nagri}', "");
Expect(1, 43055, '\P{^--IN_Syloti_Nagri}', "");
Expect(0, 43056, '\p{--IN_Syloti_Nagri}', "");
Expect(1, 43056, '\p{^--IN_Syloti_Nagri}', "");
Expect(1, 43056, '\P{--IN_Syloti_Nagri}', "");
Expect(0, 43056, '\P{^--IN_Syloti_Nagri}', "");
Error('\p{-_In_syloti_Nagri/a/}');
Error('\P{-_In_syloti_Nagri/a/}');
Expect(1, 43055, '\p{	_In_Syloti_Nagri}', "");
Expect(0, 43055, '\p{^	_In_Syloti_Nagri}', "");
Expect(0, 43055, '\P{	_In_Syloti_Nagri}', "");
Expect(1, 43055, '\P{^	_In_Syloti_Nagri}', "");
Expect(0, 43056, '\p{	_In_Syloti_Nagri}', "");
Expect(1, 43056, '\p{^	_In_Syloti_Nagri}', "");
Expect(1, 43056, '\P{	_In_Syloti_Nagri}', "");
Expect(0, 43056, '\P{^	_In_Syloti_Nagri}', "");
Error('\p{:=	_In_SYRIAC}');
Error('\P{:=	_In_SYRIAC}');
Expect(1, 1871, '\p{insyriac}', "");
Expect(0, 1871, '\p{^insyriac}', "");
Expect(0, 1871, '\P{insyriac}', "");
Expect(1, 1871, '\P{^insyriac}', "");
Expect(0, 1872, '\p{insyriac}', "");
Expect(1, 1872, '\p{^insyriac}', "");
Expect(1, 1872, '\P{insyriac}', "");
Expect(0, 1872, '\P{^insyriac}', "");
Expect(1, 1871, '\p{_	in_Syriac}', "");
Expect(0, 1871, '\p{^_	in_Syriac}', "");
Expect(0, 1871, '\P{_	in_Syriac}', "");
Expect(1, 1871, '\P{^_	in_Syriac}', "");
Expect(0, 1872, '\p{_	in_Syriac}', "");
Expect(1, 1872, '\p{^_	in_Syriac}', "");
Expect(1, 1872, '\P{_	in_Syriac}', "");
Expect(0, 1872, '\P{^_	in_Syriac}', "");
Error('\p{__In_Syriac:=}');
Error('\P{__In_Syriac:=}');
Expect(1, 1871, '\p{_	In_Syriac}', "");
Expect(0, 1871, '\p{^_	In_Syriac}', "");
Expect(0, 1871, '\P{_	In_Syriac}', "");
Expect(1, 1871, '\P{^_	In_Syriac}', "");
Expect(0, 1872, '\p{_	In_Syriac}', "");
Expect(1, 1872, '\p{^_	In_Syriac}', "");
Expect(1, 1872, '\P{_	In_Syriac}', "");
Expect(0, 1872, '\P{^_	In_Syriac}', "");
Error('\p{ In_TAGALOG:=}');
Error('\P{ In_TAGALOG:=}');
Expect(1, 5919, '\p{intagalog}', "");
Expect(0, 5919, '\p{^intagalog}', "");
Expect(0, 5919, '\P{intagalog}', "");
Expect(1, 5919, '\P{^intagalog}', "");
Expect(0, 5920, '\p{intagalog}', "");
Expect(1, 5920, '\p{^intagalog}', "");
Expect(1, 5920, '\P{intagalog}', "");
Expect(0, 5920, '\P{^intagalog}', "");
Expect(1, 5919, '\p{- In_Tagalog}', "");
Expect(0, 5919, '\p{^- In_Tagalog}', "");
Expect(0, 5919, '\P{- In_Tagalog}', "");
Expect(1, 5919, '\P{^- In_Tagalog}', "");
Expect(0, 5920, '\p{- In_Tagalog}', "");
Expect(1, 5920, '\p{^- In_Tagalog}', "");
Expect(1, 5920, '\P{- In_Tagalog}', "");
Expect(0, 5920, '\P{^- In_Tagalog}', "");
Error('\p{:=	IN_TAGALOG}');
Error('\P{:=	IN_TAGALOG}');
Expect(1, 5919, '\p{_	In_TAGALOG}', "");
Expect(0, 5919, '\p{^_	In_TAGALOG}', "");
Expect(0, 5919, '\P{_	In_TAGALOG}', "");
Expect(1, 5919, '\P{^_	In_TAGALOG}', "");
Expect(0, 5920, '\p{_	In_TAGALOG}', "");
Expect(1, 5920, '\p{^_	In_TAGALOG}', "");
Expect(1, 5920, '\P{_	In_TAGALOG}', "");
Expect(0, 5920, '\P{^_	In_TAGALOG}', "");
Error('\p{ :=IN_TAGBANWA}');
Error('\P{ :=IN_TAGBANWA}');
Expect(1, 6015, '\p{intagbanwa}', "");
Expect(0, 6015, '\p{^intagbanwa}', "");
Expect(0, 6015, '\P{intagbanwa}', "");
Expect(1, 6015, '\P{^intagbanwa}', "");
Expect(0, 6016, '\p{intagbanwa}', "");
Expect(1, 6016, '\p{^intagbanwa}', "");
Expect(1, 6016, '\P{intagbanwa}', "");
Expect(0, 6016, '\P{^intagbanwa}', "");
Expect(1, 6015, '\p{- In_Tagbanwa}', "");
Expect(0, 6015, '\p{^- In_Tagbanwa}', "");
Expect(0, 6015, '\P{- In_Tagbanwa}', "");
Expect(1, 6015, '\P{^- In_Tagbanwa}', "");
Expect(0, 6016, '\p{- In_Tagbanwa}', "");
Expect(1, 6016, '\p{^- In_Tagbanwa}', "");
Expect(1, 6016, '\P{- In_Tagbanwa}', "");
Expect(0, 6016, '\P{^- In_Tagbanwa}', "");
Error('\p{_/a/In_Tagbanwa}');
Error('\P{_/a/In_Tagbanwa}');
Expect(1, 6015, '\p{	_IN_tagbanwa}', "");
Expect(0, 6015, '\p{^	_IN_tagbanwa}', "");
Expect(0, 6015, '\P{	_IN_tagbanwa}', "");
Expect(1, 6015, '\P{^	_IN_tagbanwa}', "");
Expect(0, 6016, '\p{	_IN_tagbanwa}', "");
Expect(1, 6016, '\p{^	_IN_tagbanwa}', "");
Expect(1, 6016, '\P{	_IN_tagbanwa}', "");
Expect(0, 6016, '\P{^	_IN_tagbanwa}', "");
Error('\p{:=-_In_TAI_LE}');
Error('\P{:=-_In_TAI_LE}');
Expect(1, 6527, '\p{intaile}', "");
Expect(0, 6527, '\p{^intaile}', "");
Expect(0, 6527, '\P{intaile}', "");
Expect(1, 6527, '\P{^intaile}', "");
Expect(0, 6528, '\p{intaile}', "");
Expect(1, 6528, '\p{^intaile}', "");
Expect(1, 6528, '\P{intaile}', "");
Expect(0, 6528, '\P{^intaile}', "");
Expect(1, 6527, '\p{	IN_Tai_Le}', "");
Expect(0, 6527, '\p{^	IN_Tai_Le}', "");
Expect(0, 6527, '\P{	IN_Tai_Le}', "");
Expect(1, 6527, '\P{^	IN_Tai_Le}', "");
Expect(0, 6528, '\p{	IN_Tai_Le}', "");
Expect(1, 6528, '\p{^	IN_Tai_Le}', "");
Expect(1, 6528, '\P{	IN_Tai_Le}', "");
Expect(0, 6528, '\P{^	IN_Tai_Le}', "");
Error('\p{ In_Tai_le:=}');
Error('\P{ In_Tai_le:=}');
Expect(1, 6527, '\p{	 In_Tai_Le}', "");
Expect(0, 6527, '\p{^	 In_Tai_Le}', "");
Expect(0, 6527, '\P{	 In_Tai_Le}', "");
Expect(1, 6527, '\P{^	 In_Tai_Le}', "");
Expect(0, 6528, '\p{	 In_Tai_Le}', "");
Expect(1, 6528, '\p{^	 In_Tai_Le}', "");
Expect(1, 6528, '\P{	 In_Tai_Le}', "");
Expect(0, 6528, '\P{^	 In_Tai_Le}', "");
Error('\p{/a/ In_Tai_THAM}');
Error('\P{/a/ In_Tai_THAM}');
Expect(1, 6831, '\p{intaitham}', "");
Expect(0, 6831, '\p{^intaitham}', "");
Expect(0, 6831, '\P{intaitham}', "");
Expect(1, 6831, '\P{^intaitham}', "");
Expect(0, 6832, '\p{intaitham}', "");
Expect(1, 6832, '\p{^intaitham}', "");
Expect(1, 6832, '\P{intaitham}', "");
Expect(0, 6832, '\P{^intaitham}', "");
Expect(1, 6831, '\p{  IN_tai_tham}', "");
Expect(0, 6831, '\p{^  IN_tai_tham}', "");
Expect(0, 6831, '\P{  IN_tai_tham}', "");
Expect(1, 6831, '\P{^  IN_tai_tham}', "");
Expect(0, 6832, '\p{  IN_tai_tham}', "");
Expect(1, 6832, '\p{^  IN_tai_tham}', "");
Expect(1, 6832, '\P{  IN_tai_tham}', "");
Expect(0, 6832, '\P{^  IN_tai_tham}', "");
Error('\p{:=in_Tai_Tham}');
Error('\P{:=in_Tai_Tham}');
Expect(1, 6831, '\p{	IN_TAI_Tham}', "");
Expect(0, 6831, '\p{^	IN_TAI_Tham}', "");
Expect(0, 6831, '\P{	IN_TAI_Tham}', "");
Expect(1, 6831, '\P{^	IN_TAI_Tham}', "");
Expect(0, 6832, '\p{	IN_TAI_Tham}', "");
Expect(1, 6832, '\p{^	IN_TAI_Tham}', "");
Expect(1, 6832, '\P{	IN_TAI_Tham}', "");
Expect(0, 6832, '\P{^	IN_TAI_Tham}', "");
Error('\p{:=	In_TAI_VIET}');
Error('\P{:=	In_TAI_VIET}');
Expect(1, 43743, '\p{intaiviet}', "");
Expect(0, 43743, '\p{^intaiviet}', "");
Expect(0, 43743, '\P{intaiviet}', "");
Expect(1, 43743, '\P{^intaiviet}', "");
Expect(0, 43744, '\p{intaiviet}', "");
Expect(1, 43744, '\p{^intaiviet}', "");
Expect(1, 43744, '\P{intaiviet}', "");
Expect(0, 43744, '\P{^intaiviet}', "");
Expect(1, 43743, '\p{_-in_TAI_Viet}', "");
Expect(0, 43743, '\p{^_-in_TAI_Viet}', "");
Expect(0, 43743, '\P{_-in_TAI_Viet}', "");
Expect(1, 43743, '\P{^_-in_TAI_Viet}', "");
Expect(0, 43744, '\p{_-in_TAI_Viet}', "");
Expect(1, 43744, '\p{^_-in_TAI_Viet}', "");
Expect(1, 43744, '\P{_-in_TAI_Viet}', "");
Expect(0, 43744, '\P{^_-in_TAI_Viet}', "");
Error('\p{-in_tai_Viet:=}');
Error('\P{-in_tai_Viet:=}');
Expect(1, 43743, '\p{in_Tai_Viet}', "");
Expect(0, 43743, '\p{^in_Tai_Viet}', "");
Expect(0, 43743, '\P{in_Tai_Viet}', "");
Expect(1, 43743, '\P{^in_Tai_Viet}', "");
Expect(0, 43744, '\p{in_Tai_Viet}', "");
Expect(1, 43744, '\p{^in_Tai_Viet}', "");
Expect(1, 43744, '\P{in_Tai_Viet}', "");
Expect(0, 43744, '\P{^in_Tai_Viet}', "");
Error('\p{/a/ In_TAKRI}');
Error('\P{/a/ In_TAKRI}');
Expect(1, 71375, '\p{intakri}', "");
Expect(0, 71375, '\p{^intakri}', "");
Expect(0, 71375, '\P{intakri}', "");
Expect(1, 71375, '\P{^intakri}', "");
Expect(0, 71376, '\p{intakri}', "");
Expect(1, 71376, '\p{^intakri}', "");
Expect(1, 71376, '\P{intakri}', "");
Expect(0, 71376, '\P{^intakri}', "");
Expect(1, 71375, '\p{-IN_Takri}', "");
Expect(0, 71375, '\p{^-IN_Takri}', "");
Expect(0, 71375, '\P{-IN_Takri}', "");
Expect(1, 71375, '\P{^-IN_Takri}', "");
Expect(0, 71376, '\p{-IN_Takri}', "");
Expect(1, 71376, '\p{^-IN_Takri}', "");
Expect(1, 71376, '\P{-IN_Takri}', "");
Expect(0, 71376, '\P{^-IN_Takri}', "");
Error('\p{_IN_Takri:=}');
Error('\P{_IN_Takri:=}');
Expect(1, 71375, '\p{	 IN_TAKRI}', "");
Expect(0, 71375, '\p{^	 IN_TAKRI}', "");
Expect(0, 71375, '\P{	 IN_TAKRI}', "");
Expect(1, 71375, '\P{^	 IN_TAKRI}', "");
Expect(0, 71376, '\p{	 IN_TAKRI}', "");
Expect(1, 71376, '\p{^	 IN_TAKRI}', "");
Expect(1, 71376, '\P{	 IN_TAKRI}', "");
Expect(0, 71376, '\P{^	 IN_TAKRI}', "");
Error('\p{_/a/In_Tamil}');
Error('\P{_/a/In_Tamil}');
Expect(1, 3071, '\p{intamil}', "");
Expect(0, 3071, '\p{^intamil}', "");
Expect(0, 3071, '\P{intamil}', "");
Expect(1, 3071, '\P{^intamil}', "");
Expect(0, 3072, '\p{intamil}', "");
Expect(1, 3072, '\p{^intamil}', "");
Expect(1, 3072, '\P{intamil}', "");
Expect(0, 3072, '\P{^intamil}', "");
Expect(1, 3071, '\p{-	in_tamil}', "");
Expect(0, 3071, '\p{^-	in_tamil}', "");
Expect(0, 3071, '\P{-	in_tamil}', "");
Expect(1, 3071, '\P{^-	in_tamil}', "");
Expect(0, 3072, '\p{-	in_tamil}', "");
Expect(1, 3072, '\p{^-	in_tamil}', "");
Expect(1, 3072, '\P{-	in_tamil}', "");
Expect(0, 3072, '\P{^-	in_tamil}', "");
Error('\p{-_In_Tamil:=}');
Error('\P{-_In_Tamil:=}');
Expect(1, 3071, '\p{In_TAMIL}', "");
Expect(0, 3071, '\p{^In_TAMIL}', "");
Expect(0, 3071, '\P{In_TAMIL}', "");
Expect(1, 3071, '\P{^In_TAMIL}', "");
Expect(0, 3072, '\p{In_TAMIL}', "");
Expect(1, 3072, '\p{^In_TAMIL}', "");
Expect(1, 3072, '\P{In_TAMIL}', "");
Expect(0, 3072, '\P{^In_TAMIL}', "");
Error('\p{	:=in_TELUGU}');
Error('\P{	:=in_TELUGU}');
Expect(1, 3199, '\p{intelugu}', "");
Expect(0, 3199, '\p{^intelugu}', "");
Expect(0, 3199, '\P{intelugu}', "");
Expect(1, 3199, '\P{^intelugu}', "");
Expect(0, 3200, '\p{intelugu}', "");
Expect(1, 3200, '\p{^intelugu}', "");
Expect(1, 3200, '\P{intelugu}', "");
Expect(0, 3200, '\P{^intelugu}', "");
Expect(1, 3199, '\p{IN_TELUGU}', "");
Expect(0, 3199, '\p{^IN_TELUGU}', "");
Expect(0, 3199, '\P{IN_TELUGU}', "");
Expect(1, 3199, '\P{^IN_TELUGU}', "");
Expect(0, 3200, '\p{IN_TELUGU}', "");
Expect(1, 3200, '\p{^IN_TELUGU}', "");
Expect(1, 3200, '\P{IN_TELUGU}', "");
Expect(0, 3200, '\P{^IN_TELUGU}', "");
Error('\p{ :=In_telugu}');
Error('\P{ :=In_telugu}');
Expect(1, 3199, '\p{	 in_Telugu}', "");
Expect(0, 3199, '\p{^	 in_Telugu}', "");
Expect(0, 3199, '\P{	 in_Telugu}', "");
Expect(1, 3199, '\P{^	 in_Telugu}', "");
Expect(0, 3200, '\p{	 in_Telugu}', "");
Expect(1, 3200, '\p{^	 in_Telugu}', "");
Expect(1, 3200, '\P{	 in_Telugu}', "");
Expect(0, 3200, '\P{^	 in_Telugu}', "");
Error('\p{-_In_thaana/a/}');
Error('\P{-_In_thaana/a/}');
Expect(1, 1983, '\p{inthaana}', "");
Expect(0, 1983, '\p{^inthaana}', "");
Expect(0, 1983, '\P{inthaana}', "");
Expect(1, 1983, '\P{^inthaana}', "");
Expect(0, 1984, '\p{inthaana}', "");
Expect(1, 1984, '\p{^inthaana}', "");
Expect(1, 1984, '\P{inthaana}', "");
Expect(0, 1984, '\P{^inthaana}', "");
Expect(1, 1983, '\p{-in_thaana}', "");
Expect(0, 1983, '\p{^-in_thaana}', "");
Expect(0, 1983, '\P{-in_thaana}', "");
Expect(1, 1983, '\P{^-in_thaana}', "");
Expect(0, 1984, '\p{-in_thaana}', "");
Expect(1, 1984, '\p{^-in_thaana}', "");
Expect(1, 1984, '\P{-in_thaana}', "");
Expect(0, 1984, '\P{^-in_thaana}', "");
Error('\p{  IN_THAANA:=}');
Error('\P{  IN_THAANA:=}');
Expect(1, 1983, '\p{_ In_thaana}', "");
Expect(0, 1983, '\p{^_ In_thaana}', "");
Expect(0, 1983, '\P{_ In_thaana}', "");
Expect(1, 1983, '\P{^_ In_thaana}', "");
Expect(0, 1984, '\p{_ In_thaana}', "");
Expect(1, 1984, '\p{^_ In_thaana}', "");
Expect(1, 1984, '\P{_ In_thaana}', "");
Expect(0, 1984, '\P{^_ In_thaana}', "");
Error('\p{-_In_THAI:=}');
Error('\P{-_In_THAI:=}');
Expect(1, 3711, '\p{inthai}', "");
Expect(0, 3711, '\p{^inthai}', "");
Expect(0, 3711, '\P{inthai}', "");
Expect(1, 3711, '\P{^inthai}', "");
Expect(0, 3712, '\p{inthai}', "");
Expect(1, 3712, '\p{^inthai}', "");
Expect(1, 3712, '\P{inthai}', "");
Expect(0, 3712, '\P{^inthai}', "");
Expect(1, 3711, '\p{ In_Thai}', "");
Expect(0, 3711, '\p{^ In_Thai}', "");
Expect(0, 3711, '\P{ In_Thai}', "");
Expect(1, 3711, '\P{^ In_Thai}', "");
Expect(0, 3712, '\p{ In_Thai}', "");
Expect(1, 3712, '\p{^ In_Thai}', "");
Expect(1, 3712, '\P{ In_Thai}', "");
Expect(0, 3712, '\P{^ In_Thai}', "");
Error('\p{--In_THAI/a/}');
Error('\P{--In_THAI/a/}');
Expect(1, 3711, '\p{ -In_thai}', "");
Expect(0, 3711, '\p{^ -In_thai}', "");
Expect(0, 3711, '\P{ -In_thai}', "");
Expect(1, 3711, '\P{^ -In_thai}', "");
Expect(0, 3712, '\p{ -In_thai}', "");
Expect(1, 3712, '\p{^ -In_thai}', "");
Expect(1, 3712, '\P{ -In_thai}', "");
Expect(0, 3712, '\P{^ -In_thai}', "");
Error('\p{/a/-In_Tibetan}');
Error('\P{/a/-In_Tibetan}');
Expect(1, 4095, '\p{intibetan}', "");
Expect(0, 4095, '\p{^intibetan}', "");
Expect(0, 4095, '\P{intibetan}', "");
Expect(1, 4095, '\P{^intibetan}', "");
Expect(0, 4096, '\p{intibetan}', "");
Expect(1, 4096, '\p{^intibetan}', "");
Expect(1, 4096, '\P{intibetan}', "");
Expect(0, 4096, '\P{^intibetan}', "");
Expect(1, 4095, '\p{--in_Tibetan}', "");
Expect(0, 4095, '\p{^--in_Tibetan}', "");
Expect(0, 4095, '\P{--in_Tibetan}', "");
Expect(1, 4095, '\P{^--in_Tibetan}', "");
Expect(0, 4096, '\p{--in_Tibetan}', "");
Expect(1, 4096, '\p{^--in_Tibetan}', "");
Expect(1, 4096, '\P{--in_Tibetan}', "");
Expect(0, 4096, '\P{^--in_Tibetan}', "");
Error('\p{ 	In_Tibetan/a/}');
Error('\P{ 	In_Tibetan/a/}');
Expect(1, 4095, '\p{__In_Tibetan}', "");
Expect(0, 4095, '\p{^__In_Tibetan}', "");
Expect(0, 4095, '\P{__In_Tibetan}', "");
Expect(1, 4095, '\P{^__In_Tibetan}', "");
Expect(0, 4096, '\p{__In_Tibetan}', "");
Expect(1, 4096, '\p{^__In_Tibetan}', "");
Expect(1, 4096, '\P{__In_Tibetan}', "");
Expect(0, 4096, '\P{^__In_Tibetan}', "");
Error('\p{	In_TIFINAGH:=}');
Error('\P{	In_TIFINAGH:=}');
Expect(1, 11647, '\p{intifinagh}', "");
Expect(0, 11647, '\p{^intifinagh}', "");
Expect(0, 11647, '\P{intifinagh}', "");
Expect(1, 11647, '\P{^intifinagh}', "");
Expect(0, 11648, '\p{intifinagh}', "");
Expect(1, 11648, '\p{^intifinagh}', "");
Expect(1, 11648, '\P{intifinagh}', "");
Expect(0, 11648, '\P{^intifinagh}', "");
Expect(1, 11647, '\p{-	IN_TIFINAGH}', "");
Expect(0, 11647, '\p{^-	IN_TIFINAGH}', "");
Expect(0, 11647, '\P{-	IN_TIFINAGH}', "");
Expect(1, 11647, '\P{^-	IN_TIFINAGH}', "");
Expect(0, 11648, '\p{-	IN_TIFINAGH}', "");
Expect(1, 11648, '\p{^-	IN_TIFINAGH}', "");
Expect(1, 11648, '\P{-	IN_TIFINAGH}', "");
Expect(0, 11648, '\P{^-	IN_TIFINAGH}', "");
Error('\p{ _IN_Tifinagh:=}');
Error('\P{ _IN_Tifinagh:=}');
Expect(1, 11647, '\p{-In_Tifinagh}', "");
Expect(0, 11647, '\p{^-In_Tifinagh}', "");
Expect(0, 11647, '\P{-In_Tifinagh}', "");
Expect(1, 11647, '\P{^-In_Tifinagh}', "");
Expect(0, 11648, '\p{-In_Tifinagh}', "");
Expect(1, 11648, '\p{^-In_Tifinagh}', "");
Expect(1, 11648, '\P{-In_Tifinagh}', "");
Expect(0, 11648, '\P{^-In_Tifinagh}', "");
Error('\p{  In_Ugaritic/a/}');
Error('\P{  In_Ugaritic/a/}');
Expect(1, 66463, '\p{inugaritic}', "");
Expect(0, 66463, '\p{^inugaritic}', "");
Expect(0, 66463, '\P{inugaritic}', "");
Expect(1, 66463, '\P{^inugaritic}', "");
Expect(0, 66464, '\p{inugaritic}', "");
Expect(1, 66464, '\p{^inugaritic}', "");
Expect(1, 66464, '\P{inugaritic}', "");
Expect(0, 66464, '\P{^inugaritic}', "");
Expect(1, 66463, '\p{	-in_ugaritic}', "");
Expect(0, 66463, '\p{^	-in_ugaritic}', "");
Expect(0, 66463, '\P{	-in_ugaritic}', "");
Expect(1, 66463, '\P{^	-in_ugaritic}', "");
Expect(0, 66464, '\p{	-in_ugaritic}', "");
Expect(1, 66464, '\p{^	-in_ugaritic}', "");
Expect(1, 66464, '\P{	-in_ugaritic}', "");
Expect(0, 66464, '\P{^	-in_ugaritic}', "");
Error('\p{	_IN_ugaritic/a/}');
Error('\P{	_IN_ugaritic/a/}');
Expect(1, 66463, '\p{-In_UGARITIC}', "");
Expect(0, 66463, '\p{^-In_UGARITIC}', "");
Expect(0, 66463, '\P{-In_UGARITIC}', "");
Expect(1, 66463, '\P{^-In_UGARITIC}', "");
Expect(0, 66464, '\p{-In_UGARITIC}', "");
Expect(1, 66464, '\p{^-In_UGARITIC}', "");
Expect(1, 66464, '\P{-In_UGARITIC}', "");
Expect(0, 66464, '\P{^-In_UGARITIC}', "");
Error('\p{_/a/IN_VAI}');
Error('\P{_/a/IN_VAI}');
Expect(1, 42559, '\p{invai}', "");
Expect(0, 42559, '\p{^invai}', "");
Expect(0, 42559, '\P{invai}', "");
Expect(1, 42559, '\P{^invai}', "");
Expect(0, 42560, '\p{invai}', "");
Expect(1, 42560, '\p{^invai}', "");
Expect(1, 42560, '\P{invai}', "");
Expect(0, 42560, '\P{^invai}', "");
Expect(1, 42559, '\p{_	In_Vai}', "");
Expect(0, 42559, '\p{^_	In_Vai}', "");
Expect(0, 42559, '\P{_	In_Vai}', "");
Expect(1, 42559, '\P{^_	In_Vai}', "");
Expect(0, 42560, '\p{_	In_Vai}', "");
Expect(1, 42560, '\p{^_	In_Vai}', "");
Expect(1, 42560, '\P{_	In_Vai}', "");
Expect(0, 42560, '\P{^_	In_Vai}', "");
Error('\p{_/a/In_Vai}');
Error('\P{_/a/In_Vai}');
Expect(1, 42559, '\p{	In_VAI}', "");
Expect(0, 42559, '\p{^	In_VAI}', "");
Expect(0, 42559, '\P{	In_VAI}', "");
Expect(1, 42559, '\P{^	In_VAI}', "");
Expect(0, 42560, '\p{	In_VAI}', "");
Expect(1, 42560, '\p{^	In_VAI}', "");
Expect(1, 42560, '\P{	In_VAI}', "");
Expect(0, 42560, '\P{^	In_VAI}', "");
Error('\p{Inherited:=}');
Error('\P{Inherited:=}');
Expect(1, 917999, '\p{inherited}', "");
Expect(0, 917999, '\p{^inherited}', "");
Expect(0, 917999, '\P{inherited}', "");
Expect(1, 917999, '\P{^inherited}', "");
Expect(0, 918000, '\p{inherited}', "");
Expect(1, 918000, '\p{^inherited}', "");
Expect(1, 918000, '\P{inherited}', "");
Expect(0, 918000, '\P{^inherited}', "");
Expect(1, 917999, '\p{ inherited}', "");
Expect(0, 917999, '\p{^ inherited}', "");
Expect(0, 917999, '\P{ inherited}', "");
Expect(1, 917999, '\P{^ inherited}', "");
Expect(0, 918000, '\p{ inherited}', "");
Expect(1, 918000, '\p{^ inherited}', "");
Expect(1, 918000, '\P{ inherited}', "");
Expect(0, 918000, '\P{^ inherited}', "");
Error('\p{:=		is_Inherited}');
Error('\P{:=		is_Inherited}');
Expect(1, 917999, '\p{isinherited}', "");
Expect(0, 917999, '\p{^isinherited}', "");
Expect(0, 917999, '\P{isinherited}', "");
Expect(1, 917999, '\P{^isinherited}', "");
Expect(0, 918000, '\p{isinherited}', "");
Expect(1, 918000, '\p{^isinherited}', "");
Expect(1, 918000, '\P{isinherited}', "");
Expect(0, 918000, '\P{^isinherited}', "");
Expect(1, 917999, '\p{-is_Inherited}', "");
Expect(0, 917999, '\p{^-is_Inherited}', "");
Expect(0, 917999, '\P{-is_Inherited}', "");
Expect(1, 917999, '\P{^-is_Inherited}', "");
Expect(0, 918000, '\p{-is_Inherited}', "");
Expect(1, 918000, '\p{^-is_Inherited}', "");
Expect(1, 918000, '\P{-is_Inherited}', "");
Expect(0, 918000, '\P{^-is_Inherited}', "");
Error('\p{_	Zinh/a/}');
Error('\P{_	Zinh/a/}');
Expect(1, 917999, '\p{zinh}', "");
Expect(0, 917999, '\p{^zinh}', "");
Expect(0, 917999, '\P{zinh}', "");
Expect(1, 917999, '\P{^zinh}', "");
Expect(0, 918000, '\p{zinh}', "");
Expect(1, 918000, '\p{^zinh}', "");
Expect(1, 918000, '\P{zinh}', "");
Expect(0, 918000, '\P{^zinh}', "");
Expect(1, 917999, '\p{-_ZINH}', "");
Expect(0, 917999, '\p{^-_ZINH}', "");
Expect(0, 917999, '\P{-_ZINH}', "");
Expect(1, 917999, '\P{^-_ZINH}', "");
Expect(0, 918000, '\p{-_ZINH}', "");
Expect(1, 918000, '\p{^-_ZINH}', "");
Expect(1, 918000, '\P{-_ZINH}', "");
Expect(0, 918000, '\P{^-_ZINH}', "");
Error('\p{/a/	is_Zinh}');
Error('\P{/a/	is_Zinh}');
Expect(1, 917999, '\p{iszinh}', "");
Expect(0, 917999, '\p{^iszinh}', "");
Expect(0, 917999, '\P{iszinh}', "");
Expect(1, 917999, '\P{^iszinh}', "");
Expect(0, 918000, '\p{iszinh}', "");
Expect(1, 918000, '\p{^iszinh}', "");
Expect(1, 918000, '\P{iszinh}', "");
Expect(0, 918000, '\P{^iszinh}', "");
Expect(1, 917999, '\p{-Is_Zinh}', "");
Expect(0, 917999, '\p{^-Is_Zinh}', "");
Expect(0, 917999, '\P{-Is_Zinh}', "");
Expect(1, 917999, '\P{^-Is_Zinh}', "");
Expect(0, 918000, '\p{-Is_Zinh}', "");
Expect(1, 918000, '\p{^-Is_Zinh}', "");
Expect(1, 918000, '\P{-Is_Zinh}', "");
Expect(0, 918000, '\P{^-Is_Zinh}', "");
Error('\p{_	QAAI:=}');
Error('\P{_	QAAI:=}');
Expect(1, 917999, '\p{qaai}', "");
Expect(0, 917999, '\p{^qaai}', "");
Expect(0, 917999, '\P{qaai}', "");
Expect(1, 917999, '\P{^qaai}', "");
Expect(0, 918000, '\p{qaai}', "");
Expect(1, 918000, '\p{^qaai}', "");
Expect(1, 918000, '\P{qaai}', "");
Expect(0, 918000, '\P{^qaai}', "");
Expect(1, 917999, '\p{		QAAI}', "");
Expect(0, 917999, '\p{^		QAAI}', "");
Expect(0, 917999, '\P{		QAAI}', "");
Expect(1, 917999, '\P{^		QAAI}', "");
Expect(0, 918000, '\p{		QAAI}', "");
Expect(1, 918000, '\p{^		QAAI}', "");
Expect(1, 918000, '\P{		QAAI}', "");
Expect(0, 918000, '\P{^		QAAI}', "");
Error('\p{ 	Is_Qaai/a/}');
Error('\P{ 	Is_Qaai/a/}');
Expect(1, 917999, '\p{isqaai}', "");
Expect(0, 917999, '\p{^isqaai}', "");
Expect(0, 917999, '\P{isqaai}', "");
Expect(1, 917999, '\P{^isqaai}', "");
Expect(0, 918000, '\p{isqaai}', "");
Expect(1, 918000, '\p{^isqaai}', "");
Expect(1, 918000, '\P{isqaai}', "");
Expect(0, 918000, '\P{^isqaai}', "");
Expect(1, 917999, '\p{ Is_Qaai}', "");
Expect(0, 917999, '\p{^ Is_Qaai}', "");
Expect(0, 917999, '\P{ Is_Qaai}', "");
Expect(1, 917999, '\P{^ Is_Qaai}', "");
Expect(0, 918000, '\p{ Is_Qaai}', "");
Expect(1, 918000, '\p{^ Is_Qaai}', "");
Expect(1, 918000, '\P{ Is_Qaai}', "");
Expect(0, 918000, '\P{^ Is_Qaai}', "");
Error('\p{	:=Initial_punctuation}');
Error('\P{	:=Initial_punctuation}');
Expect(1, 11808, '\p{initialpunctuation}', "");
Expect(0, 11808, '\p{^initialpunctuation}', "");
Expect(0, 11808, '\P{initialpunctuation}', "");
Expect(1, 11808, '\P{^initialpunctuation}', "");
Expect(0, 11809, '\p{initialpunctuation}', "");
Expect(1, 11809, '\p{^initialpunctuation}', "");
Expect(1, 11809, '\P{initialpunctuation}', "");
Expect(0, 11809, '\P{^initialpunctuation}', "");
Expect(1, 11808, '\p{-initial_punctuation}', "");
Expect(0, 11808, '\p{^-initial_punctuation}', "");
Expect(0, 11808, '\P{-initial_punctuation}', "");
Expect(1, 11808, '\P{^-initial_punctuation}', "");
Expect(0, 11809, '\p{-initial_punctuation}', "");
Expect(1, 11809, '\p{^-initial_punctuation}', "");
Expect(1, 11809, '\P{-initial_punctuation}', "");
Expect(0, 11809, '\P{^-initial_punctuation}', "");
Error('\p{:=-is_initial_Punctuation}');
Error('\P{:=-is_initial_Punctuation}');
Expect(1, 11808, '\p{isinitialpunctuation}', "");
Expect(0, 11808, '\p{^isinitialpunctuation}', "");
Expect(0, 11808, '\P{isinitialpunctuation}', "");
Expect(1, 11808, '\P{^isinitialpunctuation}', "");
Expect(0, 11809, '\p{isinitialpunctuation}', "");
Expect(1, 11809, '\p{^isinitialpunctuation}', "");
Expect(1, 11809, '\P{isinitialpunctuation}', "");
Expect(0, 11809, '\P{^isinitialpunctuation}', "");
Expect(1, 11808, '\p{ -Is_Initial_Punctuation}', "");
Expect(0, 11808, '\p{^ -Is_Initial_Punctuation}', "");
Expect(0, 11808, '\P{ -Is_Initial_Punctuation}', "");
Expect(1, 11808, '\P{^ -Is_Initial_Punctuation}', "");
Expect(0, 11809, '\p{ -Is_Initial_Punctuation}', "");
Expect(1, 11809, '\p{^ -Is_Initial_Punctuation}', "");
Expect(1, 11809, '\P{ -Is_Initial_Punctuation}', "");
Expect(0, 11809, '\P{^ -Is_Initial_Punctuation}', "");
Error('\p{__Pi:=}');
Error('\P{__Pi:=}');
Expect(1, 11808, '\p{pi}', "");
Expect(0, 11808, '\p{^pi}', "");
Expect(0, 11808, '\P{pi}', "");
Expect(1, 11808, '\P{^pi}', "");
Expect(0, 11809, '\p{pi}', "");
Expect(1, 11809, '\p{^pi}', "");
Expect(1, 11809, '\P{pi}', "");
Expect(0, 11809, '\P{^pi}', "");
Expect(1, 11808, '\p{-Pi}', "");
Expect(0, 11808, '\p{^-Pi}', "");
Expect(0, 11808, '\P{-Pi}', "");
Expect(1, 11808, '\P{^-Pi}', "");
Expect(0, 11809, '\p{-Pi}', "");
Expect(1, 11809, '\p{^-Pi}', "");
Expect(1, 11809, '\P{-Pi}', "");
Expect(0, 11809, '\P{^-Pi}', "");
Error('\p{	/a/is_Pi}');
Error('\P{	/a/is_Pi}');
Expect(1, 11808, '\p{ispi}', "");
Expect(0, 11808, '\p{^ispi}', "");
Expect(0, 11808, '\P{ispi}', "");
Expect(1, 11808, '\P{^ispi}', "");
Expect(0, 11809, '\p{ispi}', "");
Expect(1, 11809, '\p{^ispi}', "");
Expect(1, 11809, '\P{ispi}', "");
Expect(0, 11809, '\P{^ispi}', "");
Expect(1, 11808, '\p{	 Is_pi}', "");
Expect(0, 11808, '\p{^	 Is_pi}', "");
Expect(0, 11808, '\P{	 Is_pi}', "");
Expect(1, 11808, '\P{^	 Is_pi}', "");
Expect(0, 11809, '\p{	 Is_pi}', "");
Expect(1, 11809, '\p{^	 Is_pi}', "");
Expect(1, 11809, '\P{	 Is_pi}', "");
Expect(0, 11809, '\P{^	 Is_pi}', "");
Error('\p{:=__INSCRIPTIONAL_Pahlavi}');
Error('\P{:=__INSCRIPTIONAL_Pahlavi}');
Expect(1, 68479, '\p{inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{--inscriptional_pahlavi}', "");
Expect(0, 68479, '\p{^--inscriptional_pahlavi}', "");
Expect(0, 68479, '\P{--inscriptional_pahlavi}', "");
Expect(1, 68479, '\P{^--inscriptional_pahlavi}', "");
Expect(0, 68480, '\p{--inscriptional_pahlavi}', "");
Expect(1, 68480, '\p{^--inscriptional_pahlavi}', "");
Expect(1, 68480, '\P{--inscriptional_pahlavi}', "");
Expect(0, 68480, '\P{^--inscriptional_pahlavi}', "");
Error('\p{ _IS_inscriptional_pahlavi/a/}');
Error('\P{ _IS_inscriptional_pahlavi/a/}');
Expect(1, 68479, '\p{isinscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^isinscriptionalpahlavi}', "");
Expect(0, 68479, '\P{isinscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^isinscriptionalpahlavi}', "");
Expect(0, 68480, '\p{isinscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^isinscriptionalpahlavi}', "");
Expect(1, 68480, '\P{isinscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^isinscriptionalpahlavi}', "");
Expect(1, 68479, '\p{_ Is_inscriptional_PAHLAVI}', "");
Expect(0, 68479, '\p{^_ Is_inscriptional_PAHLAVI}', "");
Expect(0, 68479, '\P{_ Is_inscriptional_PAHLAVI}', "");
Expect(1, 68479, '\P{^_ Is_inscriptional_PAHLAVI}', "");
Expect(0, 68480, '\p{_ Is_inscriptional_PAHLAVI}', "");
Expect(1, 68480, '\p{^_ Is_inscriptional_PAHLAVI}', "");
Expect(1, 68480, '\P{_ Is_inscriptional_PAHLAVI}', "");
Expect(0, 68480, '\P{^_ Is_inscriptional_PAHLAVI}', "");
Error('\p{ Phli/a/}');
Error('\P{ Phli/a/}');
Expect(1, 68479, '\p{phli}', "");
Expect(0, 68479, '\p{^phli}', "");
Expect(0, 68479, '\P{phli}', "");
Expect(1, 68479, '\P{^phli}', "");
Expect(0, 68480, '\p{phli}', "");
Expect(1, 68480, '\p{^phli}', "");
Expect(1, 68480, '\P{phli}', "");
Expect(0, 68480, '\P{^phli}', "");
Expect(1, 68479, '\p{	_Phli}', "");
Expect(0, 68479, '\p{^	_Phli}', "");
Expect(0, 68479, '\P{	_Phli}', "");
Expect(1, 68479, '\P{^	_Phli}', "");
Expect(0, 68480, '\p{	_Phli}', "");
Expect(1, 68480, '\p{^	_Phli}', "");
Expect(1, 68480, '\P{	_Phli}', "");
Expect(0, 68480, '\P{^	_Phli}', "");
Error('\p{-:=IS_Phli}');
Error('\P{-:=IS_Phli}');
Expect(1, 68479, '\p{isphli}', "");
Expect(0, 68479, '\p{^isphli}', "");
Expect(0, 68479, '\P{isphli}', "");
Expect(1, 68479, '\P{^isphli}', "");
Expect(0, 68480, '\p{isphli}', "");
Expect(1, 68480, '\p{^isphli}', "");
Expect(1, 68480, '\P{isphli}', "");
Expect(0, 68480, '\P{^isphli}', "");
Expect(1, 68479, '\p{-Is_phli}', "");
Expect(0, 68479, '\p{^-Is_phli}', "");
Expect(0, 68479, '\P{-Is_phli}', "");
Expect(1, 68479, '\P{^-Is_phli}', "");
Expect(0, 68480, '\p{-Is_phli}', "");
Expect(1, 68480, '\p{^-Is_phli}', "");
Expect(1, 68480, '\P{-Is_phli}', "");
Expect(0, 68480, '\P{^-Is_phli}', "");
Error('\p{__Inscriptional_PARTHIAN/a/}');
Error('\P{__Inscriptional_PARTHIAN/a/}');
Expect(1, 68447, '\p{inscriptionalparthian}', "");
Expect(0, 68447, '\p{^inscriptionalparthian}', "");
Expect(0, 68447, '\P{inscriptionalparthian}', "");
Expect(1, 68447, '\P{^inscriptionalparthian}', "");
Expect(0, 68448, '\p{inscriptionalparthian}', "");
Expect(1, 68448, '\p{^inscriptionalparthian}', "");
Expect(1, 68448, '\P{inscriptionalparthian}', "");
Expect(0, 68448, '\P{^inscriptionalparthian}', "");
Expect(1, 68447, '\p{ INSCRIPTIONAL_Parthian}', "");
Expect(0, 68447, '\p{^ INSCRIPTIONAL_Parthian}', "");
Expect(0, 68447, '\P{ INSCRIPTIONAL_Parthian}', "");
Expect(1, 68447, '\P{^ INSCRIPTIONAL_Parthian}', "");
Expect(0, 68448, '\p{ INSCRIPTIONAL_Parthian}', "");
Expect(1, 68448, '\p{^ INSCRIPTIONAL_Parthian}', "");
Expect(1, 68448, '\P{ INSCRIPTIONAL_Parthian}', "");
Expect(0, 68448, '\P{^ INSCRIPTIONAL_Parthian}', "");
Error('\p{/a/	 is_INSCRIPTIONAL_parthian}');
Error('\P{/a/	 is_INSCRIPTIONAL_parthian}');
Expect(1, 68447, '\p{isinscriptionalparthian}', "");
Expect(0, 68447, '\p{^isinscriptionalparthian}', "");
Expect(0, 68447, '\P{isinscriptionalparthian}', "");
Expect(1, 68447, '\P{^isinscriptionalparthian}', "");
Expect(0, 68448, '\p{isinscriptionalparthian}', "");
Expect(1, 68448, '\p{^isinscriptionalparthian}', "");
Expect(1, 68448, '\P{isinscriptionalparthian}', "");
Expect(0, 68448, '\P{^isinscriptionalparthian}', "");
Expect(1, 68447, '\p{-	is_INSCRIPTIONAL_Parthian}', "");
Expect(0, 68447, '\p{^-	is_INSCRIPTIONAL_Parthian}', "");
Expect(0, 68447, '\P{-	is_INSCRIPTIONAL_Parthian}', "");
Expect(1, 68447, '\P{^-	is_INSCRIPTIONAL_Parthian}', "");
Expect(0, 68448, '\p{-	is_INSCRIPTIONAL_Parthian}', "");
Expect(1, 68448, '\p{^-	is_INSCRIPTIONAL_Parthian}', "");
Expect(1, 68448, '\P{-	is_INSCRIPTIONAL_Parthian}', "");
Expect(0, 68448, '\P{^-	is_INSCRIPTIONAL_Parthian}', "");
Error('\p{/a/-	Prti}');
Error('\P{/a/-	Prti}');
Expect(1, 68447, '\p{prti}', "");
Expect(0, 68447, '\p{^prti}', "");
Expect(0, 68447, '\P{prti}', "");
Expect(1, 68447, '\P{^prti}', "");
Expect(0, 68448, '\p{prti}', "");
Expect(1, 68448, '\p{^prti}', "");
Expect(1, 68448, '\P{prti}', "");
Expect(0, 68448, '\P{^prti}', "");
Expect(1, 68447, '\p{ Prti}', "");
Expect(0, 68447, '\p{^ Prti}', "");
Expect(0, 68447, '\P{ Prti}', "");
Expect(1, 68447, '\P{^ Prti}', "");
Expect(0, 68448, '\p{ Prti}', "");
Expect(1, 68448, '\p{^ Prti}', "");
Expect(1, 68448, '\P{ Prti}', "");
Expect(0, 68448, '\P{^ Prti}', "");
Error('\p{_IS_Prti:=}');
Error('\P{_IS_Prti:=}');
Expect(1, 68447, '\p{isprti}', "");
Expect(0, 68447, '\p{^isprti}', "");
Expect(0, 68447, '\P{isprti}', "");
Expect(1, 68447, '\P{^isprti}', "");
Expect(0, 68448, '\p{isprti}', "");
Expect(1, 68448, '\p{^isprti}', "");
Expect(1, 68448, '\P{isprti}', "");
Expect(0, 68448, '\P{^isprti}', "");
Expect(1, 68447, '\p{		Is_PRTI}', "");
Expect(0, 68447, '\p{^		Is_PRTI}', "");
Expect(0, 68447, '\P{		Is_PRTI}', "");
Expect(1, 68447, '\P{^		Is_PRTI}', "");
Expect(0, 68448, '\p{		Is_PRTI}', "");
Expect(1, 68448, '\p{^		Is_PRTI}', "");
Expect(1, 68448, '\P{		Is_PRTI}', "");
Expect(0, 68448, '\P{^		Is_PRTI}', "");
Error('\p{- JAVANESE/a/}');
Error('\P{- JAVANESE/a/}');
Expect(1, 43487, '\p{javanese}', "");
Expect(0, 43487, '\p{^javanese}', "");
Expect(0, 43487, '\P{javanese}', "");
Expect(1, 43487, '\P{^javanese}', "");
Expect(0, 43488, '\p{javanese}', "");
Expect(1, 43488, '\p{^javanese}', "");
Expect(1, 43488, '\P{javanese}', "");
Expect(0, 43488, '\P{^javanese}', "");
Expect(1, 43487, '\p{ 	JAVANESE}', "");
Expect(0, 43487, '\p{^ 	JAVANESE}', "");
Expect(0, 43487, '\P{ 	JAVANESE}', "");
Expect(1, 43487, '\P{^ 	JAVANESE}', "");
Expect(0, 43488, '\p{ 	JAVANESE}', "");
Expect(1, 43488, '\p{^ 	JAVANESE}', "");
Expect(1, 43488, '\P{ 	JAVANESE}', "");
Expect(0, 43488, '\P{^ 	JAVANESE}', "");
Error('\p{-	Is_Javanese/a/}');
Error('\P{-	Is_Javanese/a/}');
Expect(1, 43487, '\p{isjavanese}', "");
Expect(0, 43487, '\p{^isjavanese}', "");
Expect(0, 43487, '\P{isjavanese}', "");
Expect(1, 43487, '\P{^isjavanese}', "");
Expect(0, 43488, '\p{isjavanese}', "");
Expect(1, 43488, '\p{^isjavanese}', "");
Expect(1, 43488, '\P{isjavanese}', "");
Expect(0, 43488, '\P{^isjavanese}', "");
Expect(1, 43487, '\p{_ Is_Javanese}', "");
Expect(0, 43487, '\p{^_ Is_Javanese}', "");
Expect(0, 43487, '\P{_ Is_Javanese}', "");
Expect(1, 43487, '\P{^_ Is_Javanese}', "");
Expect(0, 43488, '\p{_ Is_Javanese}', "");
Expect(1, 43488, '\p{^_ Is_Javanese}', "");
Expect(1, 43488, '\P{_ Is_Javanese}', "");
Expect(0, 43488, '\P{^_ Is_Javanese}', "");
Error('\p{_Java:=}');
Error('\P{_Java:=}');
Expect(1, 43487, '\p{java}', "");
Expect(0, 43487, '\p{^java}', "");
Expect(0, 43487, '\P{java}', "");
Expect(1, 43487, '\P{^java}', "");
Expect(0, 43488, '\p{java}', "");
Expect(1, 43488, '\p{^java}', "");
Expect(1, 43488, '\P{java}', "");
Expect(0, 43488, '\P{^java}', "");
Expect(1, 43487, '\p{_ JAVA}', "");
Expect(0, 43487, '\p{^_ JAVA}', "");
Expect(0, 43487, '\P{_ JAVA}', "");
Expect(1, 43487, '\P{^_ JAVA}', "");
Expect(0, 43488, '\p{_ JAVA}', "");
Expect(1, 43488, '\p{^_ JAVA}', "");
Expect(1, 43488, '\P{_ JAVA}', "");
Expect(0, 43488, '\P{^_ JAVA}', "");
Error('\p{_Is_Java/a/}');
Error('\P{_Is_Java/a/}');
Expect(1, 43487, '\p{isjava}', "");
Expect(0, 43487, '\p{^isjava}', "");
Expect(0, 43487, '\P{isjava}', "");
Expect(1, 43487, '\P{^isjava}', "");
Expect(0, 43488, '\p{isjava}', "");
Expect(1, 43488, '\p{^isjava}', "");
Expect(1, 43488, '\P{isjava}', "");
Expect(0, 43488, '\P{^isjava}', "");
Expect(1, 43487, '\p{_	is_java}', "");
Expect(0, 43487, '\p{^_	is_java}', "");
Expect(0, 43487, '\P{_	is_java}', "");
Expect(1, 43487, '\P{^_	is_java}', "");
Expect(0, 43488, '\p{_	is_java}', "");
Expect(1, 43488, '\p{^_	is_java}', "");
Expect(1, 43488, '\P{_	is_java}', "");
Expect(0, 43488, '\P{^_	is_java}', "");
Error('\p{:=-	join_Control}');
Error('\P{:=-	join_Control}');
Expect(1, 8205, '\p{joincontrol}', "");
Expect(0, 8205, '\p{^joincontrol}', "");
Expect(0, 8205, '\P{joincontrol}', "");
Expect(1, 8205, '\P{^joincontrol}', "");
Expect(0, 8206, '\p{joincontrol}', "");
Expect(1, 8206, '\p{^joincontrol}', "");
Expect(1, 8206, '\P{joincontrol}', "");
Expect(0, 8206, '\P{^joincontrol}', "");
Expect(1, 8205, '\p{-	join_Control}', "");
Expect(0, 8205, '\p{^-	join_Control}', "");
Expect(0, 8205, '\P{-	join_Control}', "");
Expect(1, 8205, '\P{^-	join_Control}', "");
Expect(0, 8206, '\p{-	join_Control}', "");
Expect(1, 8206, '\p{^-	join_Control}', "");
Expect(1, 8206, '\P{-	join_Control}', "");
Expect(0, 8206, '\P{^-	join_Control}', "");
Error('\p{		Is_Join_control:=}');
Error('\P{		Is_Join_control:=}');
Expect(1, 8205, '\p{isjoincontrol}', "");
Expect(0, 8205, '\p{^isjoincontrol}', "");
Expect(0, 8205, '\P{isjoincontrol}', "");
Expect(1, 8205, '\P{^isjoincontrol}', "");
Expect(0, 8206, '\p{isjoincontrol}', "");
Expect(1, 8206, '\p{^isjoincontrol}', "");
Expect(1, 8206, '\P{isjoincontrol}', "");
Expect(0, 8206, '\P{^isjoincontrol}', "");
Expect(1, 8205, '\p{  Is_join_Control}', "");
Expect(0, 8205, '\p{^  Is_join_Control}', "");
Expect(0, 8205, '\P{  Is_join_Control}', "");
Expect(1, 8205, '\P{^  Is_join_Control}', "");
Expect(0, 8206, '\p{  Is_join_Control}', "");
Expect(1, 8206, '\p{^  Is_join_Control}', "");
Expect(1, 8206, '\P{  Is_join_Control}', "");
Expect(0, 8206, '\P{^  Is_join_Control}', "");
Error('\p{Join_C:=}');
Error('\P{Join_C:=}');
Expect(1, 8205, '\p{joinc}', "");
Expect(0, 8205, '\p{^joinc}', "");
Expect(0, 8205, '\P{joinc}', "");
Expect(1, 8205, '\P{^joinc}', "");
Expect(0, 8206, '\p{joinc}', "");
Expect(1, 8206, '\p{^joinc}', "");
Expect(1, 8206, '\P{joinc}', "");
Expect(0, 8206, '\P{^joinc}', "");
Expect(1, 8205, '\p{  Join_c}', "");
Expect(0, 8205, '\p{^  Join_c}', "");
Expect(0, 8205, '\P{  Join_c}', "");
Expect(1, 8205, '\P{^  Join_c}', "");
Expect(0, 8206, '\p{  Join_c}', "");
Expect(1, 8206, '\p{^  Join_c}', "");
Expect(1, 8206, '\P{  Join_c}', "");
Expect(0, 8206, '\P{^  Join_c}', "");
Error('\p{:= Is_Join_C}');
Error('\P{:= Is_Join_C}');
Expect(1, 8205, '\p{isjoinc}', "");
Expect(0, 8205, '\p{^isjoinc}', "");
Expect(0, 8205, '\P{isjoinc}', "");
Expect(1, 8205, '\P{^isjoinc}', "");
Expect(0, 8206, '\p{isjoinc}', "");
Expect(1, 8206, '\p{^isjoinc}', "");
Expect(1, 8206, '\P{isjoinc}', "");
Expect(0, 8206, '\P{^isjoinc}', "");
Expect(1, 8205, '\p{ Is_JOIN_c}', "");
Expect(0, 8205, '\p{^ Is_JOIN_c}', "");
Expect(0, 8205, '\P{ Is_JOIN_c}', "");
Expect(1, 8205, '\P{^ Is_JOIN_c}', "");
Expect(0, 8206, '\p{ Is_JOIN_c}', "");
Expect(1, 8206, '\p{^ Is_JOIN_c}', "");
Expect(1, 8206, '\P{ Is_JOIN_c}', "");
Expect(0, 8206, '\P{^ Is_JOIN_c}', "");
Error('\p{-KAITHI:=}');
Error('\P{-KAITHI:=}');
Expect(1, 69825, '\p{kaithi}', "");
Expect(0, 69825, '\p{^kaithi}', "");
Expect(0, 69825, '\P{kaithi}', "");
Expect(1, 69825, '\P{^kaithi}', "");
Expect(0, 69826, '\p{kaithi}', "");
Expect(1, 69826, '\p{^kaithi}', "");
Expect(1, 69826, '\P{kaithi}', "");
Expect(0, 69826, '\P{^kaithi}', "");
Expect(1, 69825, '\p{Kaithi}', "");
Expect(0, 69825, '\p{^Kaithi}', "");
Expect(0, 69825, '\P{Kaithi}', "");
Expect(1, 69825, '\P{^Kaithi}', "");
Expect(0, 69826, '\p{Kaithi}', "");
Expect(1, 69826, '\p{^Kaithi}', "");
Expect(1, 69826, '\P{Kaithi}', "");
Expect(0, 69826, '\P{^Kaithi}', "");
Error('\p{ /a/is_Kaithi}');
Error('\P{ /a/is_Kaithi}');
Expect(1, 69825, '\p{iskaithi}', "");
Expect(0, 69825, '\p{^iskaithi}', "");
Expect(0, 69825, '\P{iskaithi}', "");
Expect(1, 69825, '\P{^iskaithi}', "");
Expect(0, 69826, '\p{iskaithi}', "");
Expect(1, 69826, '\p{^iskaithi}', "");
Expect(1, 69826, '\P{iskaithi}', "");
Expect(0, 69826, '\P{^iskaithi}', "");
Expect(1, 69825, '\p{__IS_Kaithi}', "");
Expect(0, 69825, '\p{^__IS_Kaithi}', "");
Expect(0, 69825, '\P{__IS_Kaithi}', "");
Expect(1, 69825, '\P{^__IS_Kaithi}', "");
Expect(0, 69826, '\p{__IS_Kaithi}', "");
Expect(1, 69826, '\p{^__IS_Kaithi}', "");
Expect(1, 69826, '\P{__IS_Kaithi}', "");
Expect(0, 69826, '\P{^__IS_Kaithi}', "");
Error('\p{ 	KTHI:=}');
Error('\P{ 	KTHI:=}');
Expect(1, 69825, '\p{kthi}', "");
Expect(0, 69825, '\p{^kthi}', "");
Expect(0, 69825, '\P{kthi}', "");
Expect(1, 69825, '\P{^kthi}', "");
Expect(0, 69826, '\p{kthi}', "");
Expect(1, 69826, '\p{^kthi}', "");
Expect(1, 69826, '\P{kthi}', "");
Expect(0, 69826, '\P{^kthi}', "");
Expect(1, 69825, '\p{-kthi}', "");
Expect(0, 69825, '\p{^-kthi}', "");
Expect(0, 69825, '\P{-kthi}', "");
Expect(1, 69825, '\P{^-kthi}', "");
Expect(0, 69826, '\p{-kthi}', "");
Expect(1, 69826, '\p{^-kthi}', "");
Expect(1, 69826, '\P{-kthi}', "");
Expect(0, 69826, '\P{^-kthi}', "");
Error('\p{/a/-is_KTHI}');
Error('\P{/a/-is_KTHI}');
Expect(1, 69825, '\p{iskthi}', "");
Expect(0, 69825, '\p{^iskthi}', "");
Expect(0, 69825, '\P{iskthi}', "");
Expect(1, 69825, '\P{^iskthi}', "");
Expect(0, 69826, '\p{iskthi}', "");
Expect(1, 69826, '\p{^iskthi}', "");
Expect(1, 69826, '\P{iskthi}', "");
Expect(0, 69826, '\P{^iskthi}', "");
Expect(1, 69825, '\p{		Is_KTHI}', "");
Expect(0, 69825, '\p{^		Is_KTHI}', "");
Expect(0, 69825, '\P{		Is_KTHI}', "");
Expect(1, 69825, '\P{^		Is_KTHI}', "");
Expect(0, 69826, '\p{		Is_KTHI}', "");
Expect(1, 69826, '\p{^		Is_KTHI}', "");
Expect(1, 69826, '\P{		Is_KTHI}', "");
Expect(0, 69826, '\P{^		Is_KTHI}', "");
Error('\p{-:=Kana_supplement}');
Error('\P{-:=Kana_supplement}');
Expect(1, 110847, '\p{kanasupplement}', "");
Expect(0, 110847, '\p{^kanasupplement}', "");
Expect(0, 110847, '\P{kanasupplement}', "");
Expect(1, 110847, '\P{^kanasupplement}', "");
Expect(0, 110848, '\p{kanasupplement}', "");
Expect(1, 110848, '\p{^kanasupplement}', "");
Expect(1, 110848, '\P{kanasupplement}', "");
Expect(0, 110848, '\P{^kanasupplement}', "");
Expect(1, 110847, '\p{-	Kana_Supplement}', "");
Expect(0, 110847, '\p{^-	Kana_Supplement}', "");
Expect(0, 110847, '\P{-	Kana_Supplement}', "");
Expect(1, 110847, '\P{^-	Kana_Supplement}', "");
Expect(0, 110848, '\p{-	Kana_Supplement}', "");
Expect(1, 110848, '\p{^-	Kana_Supplement}', "");
Expect(1, 110848, '\P{-	Kana_Supplement}', "");
Expect(0, 110848, '\P{^-	Kana_Supplement}', "");
Error('\p{-is_KANA_SUPPLEMENT/a/}');
Error('\P{-is_KANA_SUPPLEMENT/a/}');
Expect(1, 110847, '\p{iskanasupplement}', "");
Expect(0, 110847, '\p{^iskanasupplement}', "");
Expect(0, 110847, '\P{iskanasupplement}', "");
Expect(1, 110847, '\P{^iskanasupplement}', "");
Expect(0, 110848, '\p{iskanasupplement}', "");
Expect(1, 110848, '\p{^iskanasupplement}', "");
Expect(1, 110848, '\P{iskanasupplement}', "");
Expect(0, 110848, '\P{^iskanasupplement}', "");
Expect(1, 110847, '\p{_IS_Kana_SUPPLEMENT}', "");
Expect(0, 110847, '\p{^_IS_Kana_SUPPLEMENT}', "");
Expect(0, 110847, '\P{_IS_Kana_SUPPLEMENT}', "");
Expect(1, 110847, '\P{^_IS_Kana_SUPPLEMENT}', "");
Expect(0, 110848, '\p{_IS_Kana_SUPPLEMENT}', "");
Expect(1, 110848, '\p{^_IS_Kana_SUPPLEMENT}', "");
Expect(1, 110848, '\P{_IS_Kana_SUPPLEMENT}', "");
Expect(0, 110848, '\P{^_IS_Kana_SUPPLEMENT}', "");
Error('\p{:=-_in_Kana_SUPPLEMENT}');
Error('\P{:=-_in_Kana_SUPPLEMENT}');
Expect(1, 110847, '\p{inkanasupplement}', "");
Expect(0, 110847, '\p{^inkanasupplement}', "");
Expect(0, 110847, '\P{inkanasupplement}', "");
Expect(1, 110847, '\P{^inkanasupplement}', "");
Expect(0, 110848, '\p{inkanasupplement}', "");
Expect(1, 110848, '\p{^inkanasupplement}', "");
Expect(1, 110848, '\P{inkanasupplement}', "");
Expect(0, 110848, '\P{^inkanasupplement}', "");
Expect(1, 110847, '\p{  in_Kana_SUPPLEMENT}', "");
Expect(0, 110847, '\p{^  in_Kana_SUPPLEMENT}', "");
Expect(0, 110847, '\P{  in_Kana_SUPPLEMENT}', "");
Expect(1, 110847, '\P{^  in_Kana_SUPPLEMENT}', "");
Expect(0, 110848, '\p{  in_Kana_SUPPLEMENT}', "");
Expect(1, 110848, '\p{^  in_Kana_SUPPLEMENT}', "");
Expect(1, 110848, '\P{  in_Kana_SUPPLEMENT}', "");
Expect(0, 110848, '\P{^  in_Kana_SUPPLEMENT}', "");
Error('\p{/a/ 	kana_Sup}');
Error('\P{/a/ 	kana_Sup}');
Expect(1, 110847, '\p{kanasup}', "");
Expect(0, 110847, '\p{^kanasup}', "");
Expect(0, 110847, '\P{kanasup}', "");
Expect(1, 110847, '\P{^kanasup}', "");
Expect(0, 110848, '\p{kanasup}', "");
Expect(1, 110848, '\p{^kanasup}', "");
Expect(1, 110848, '\P{kanasup}', "");
Expect(0, 110848, '\P{^kanasup}', "");
Expect(1, 110847, '\p{	-KANA_Sup}', "");
Expect(0, 110847, '\p{^	-KANA_Sup}', "");
Expect(0, 110847, '\P{	-KANA_Sup}', "");
Expect(1, 110847, '\P{^	-KANA_Sup}', "");
Expect(0, 110848, '\p{	-KANA_Sup}', "");
Expect(1, 110848, '\p{^	-KANA_Sup}', "");
Expect(1, 110848, '\P{	-KANA_Sup}', "");
Expect(0, 110848, '\P{^	-KANA_Sup}', "");
Error('\p{ /a/Is_kana_Sup}');
Error('\P{ /a/Is_kana_Sup}');
Expect(1, 110847, '\p{iskanasup}', "");
Expect(0, 110847, '\p{^iskanasup}', "");
Expect(0, 110847, '\P{iskanasup}', "");
Expect(1, 110847, '\P{^iskanasup}', "");
Expect(0, 110848, '\p{iskanasup}', "");
Expect(1, 110848, '\p{^iskanasup}', "");
Expect(1, 110848, '\P{iskanasup}', "");
Expect(0, 110848, '\P{^iskanasup}', "");
Expect(1, 110847, '\p{ IS_KANA_SUP}', "");
Expect(0, 110847, '\p{^ IS_KANA_SUP}', "");
Expect(0, 110847, '\P{ IS_KANA_SUP}', "");
Expect(1, 110847, '\P{^ IS_KANA_SUP}', "");
Expect(0, 110848, '\p{ IS_KANA_SUP}', "");
Expect(1, 110848, '\p{^ IS_KANA_SUP}', "");
Expect(1, 110848, '\P{ IS_KANA_SUP}', "");
Expect(0, 110848, '\P{^ IS_KANA_SUP}', "");
Error('\p{:=	in_kana_Sup}');
Error('\P{:=	in_kana_Sup}');
Expect(1, 110847, '\p{inkanasup}', "");
Expect(0, 110847, '\p{^inkanasup}', "");
Expect(0, 110847, '\P{inkanasup}', "");
Expect(1, 110847, '\P{^inkanasup}', "");
Expect(0, 110848, '\p{inkanasup}', "");
Expect(1, 110848, '\p{^inkanasup}', "");
Expect(1, 110848, '\P{inkanasup}', "");
Expect(0, 110848, '\P{^inkanasup}', "");
Expect(1, 110847, '\p{ -in_Kana_SUP}', "");
Expect(0, 110847, '\p{^ -in_Kana_SUP}', "");
Expect(0, 110847, '\P{ -in_Kana_SUP}', "");
Expect(1, 110847, '\P{^ -in_Kana_SUP}', "");
Expect(0, 110848, '\p{ -in_Kana_SUP}', "");
Expect(1, 110848, '\p{^ -in_Kana_SUP}', "");
Expect(1, 110848, '\P{ -in_Kana_SUP}', "");
Expect(0, 110848, '\P{^ -in_Kana_SUP}', "");
Error('\p{/a/	kanbun}');
Error('\P{/a/	kanbun}');
Expect(1, 12703, '\p{kanbun}', "");
Expect(0, 12703, '\p{^kanbun}', "");
Expect(0, 12703, '\P{kanbun}', "");
Expect(1, 12703, '\P{^kanbun}', "");
Expect(0, 12704, '\p{kanbun}', "");
Expect(1, 12704, '\p{^kanbun}', "");
Expect(1, 12704, '\P{kanbun}', "");
Expect(0, 12704, '\P{^kanbun}', "");
Expect(1, 12703, '\p{	kanbun}', "");
Expect(0, 12703, '\p{^	kanbun}', "");
Expect(0, 12703, '\P{	kanbun}', "");
Expect(1, 12703, '\P{^	kanbun}', "");
Expect(0, 12704, '\p{	kanbun}', "");
Expect(1, 12704, '\p{^	kanbun}', "");
Expect(1, 12704, '\P{	kanbun}', "");
Expect(0, 12704, '\P{^	kanbun}', "");
Error('\p{_-is_Kanbun/a/}');
Error('\P{_-is_Kanbun/a/}');
Expect(1, 12703, '\p{iskanbun}', "");
Expect(0, 12703, '\p{^iskanbun}', "");
Expect(0, 12703, '\P{iskanbun}', "");
Expect(1, 12703, '\P{^iskanbun}', "");
Expect(0, 12704, '\p{iskanbun}', "");
Expect(1, 12704, '\p{^iskanbun}', "");
Expect(1, 12704, '\P{iskanbun}', "");
Expect(0, 12704, '\P{^iskanbun}', "");
Expect(1, 12703, '\p{_Is_kanbun}', "");
Expect(0, 12703, '\p{^_Is_kanbun}', "");
Expect(0, 12703, '\P{_Is_kanbun}', "");
Expect(1, 12703, '\P{^_Is_kanbun}', "");
Expect(0, 12704, '\p{_Is_kanbun}', "");
Expect(1, 12704, '\p{^_Is_kanbun}', "");
Expect(1, 12704, '\P{_Is_kanbun}', "");
Expect(0, 12704, '\P{^_Is_kanbun}', "");
Error('\p{_/a/In_kanbun}');
Error('\P{_/a/In_kanbun}');
Expect(1, 12703, '\p{inkanbun}', "");
Expect(0, 12703, '\p{^inkanbun}', "");
Expect(0, 12703, '\P{inkanbun}', "");
Expect(1, 12703, '\P{^inkanbun}', "");
Expect(0, 12704, '\p{inkanbun}', "");
Expect(1, 12704, '\p{^inkanbun}', "");
Expect(1, 12704, '\P{inkanbun}', "");
Expect(0, 12704, '\P{^inkanbun}', "");
Expect(1, 12703, '\p{_-In_kanbun}', "");
Expect(0, 12703, '\p{^_-In_kanbun}', "");
Expect(0, 12703, '\P{_-In_kanbun}', "");
Expect(1, 12703, '\P{^_-In_kanbun}', "");
Expect(0, 12704, '\p{_-In_kanbun}', "");
Expect(1, 12704, '\p{^_-In_kanbun}', "");
Expect(1, 12704, '\P{_-In_kanbun}', "");
Expect(0, 12704, '\P{^_-In_kanbun}', "");
Error('\p{ Kangxi_Radicals:=}');
Error('\P{ Kangxi_Radicals:=}');
Expect(1, 12255, '\p{kangxiradicals}', "");
Expect(0, 12255, '\p{^kangxiradicals}', "");
Expect(0, 12255, '\P{kangxiradicals}', "");
Expect(1, 12255, '\P{^kangxiradicals}', "");
Expect(0, 12256, '\p{kangxiradicals}', "");
Expect(1, 12256, '\p{^kangxiradicals}', "");
Expect(1, 12256, '\P{kangxiradicals}', "");
Expect(0, 12256, '\P{^kangxiradicals}', "");
Expect(1, 12255, '\p{- Kangxi_radicals}', "");
Expect(0, 12255, '\p{^- Kangxi_radicals}', "");
Expect(0, 12255, '\P{- Kangxi_radicals}', "");
Expect(1, 12255, '\P{^- Kangxi_radicals}', "");
Expect(0, 12256, '\p{- Kangxi_radicals}', "");
Expect(1, 12256, '\p{^- Kangxi_radicals}', "");
Expect(1, 12256, '\P{- Kangxi_radicals}', "");
Expect(0, 12256, '\P{^- Kangxi_radicals}', "");
Error('\p{ /a/IS_Kangxi_radicals}');
Error('\P{ /a/IS_Kangxi_radicals}');
Expect(1, 12255, '\p{iskangxiradicals}', "");
Expect(0, 12255, '\p{^iskangxiradicals}', "");
Expect(0, 12255, '\P{iskangxiradicals}', "");
Expect(1, 12255, '\P{^iskangxiradicals}', "");
Expect(0, 12256, '\p{iskangxiradicals}', "");
Expect(1, 12256, '\p{^iskangxiradicals}', "");
Expect(1, 12256, '\P{iskangxiradicals}', "");
Expect(0, 12256, '\P{^iskangxiradicals}', "");
Expect(1, 12255, '\p{	 is_kangxi_Radicals}', "");
Expect(0, 12255, '\p{^	 is_kangxi_Radicals}', "");
Expect(0, 12255, '\P{	 is_kangxi_Radicals}', "");
Expect(1, 12255, '\P{^	 is_kangxi_Radicals}', "");
Expect(0, 12256, '\p{	 is_kangxi_Radicals}', "");
Expect(1, 12256, '\p{^	 is_kangxi_Radicals}', "");
Expect(1, 12256, '\P{	 is_kangxi_Radicals}', "");
Expect(0, 12256, '\P{^	 is_kangxi_Radicals}', "");
Error('\p{:= IN_Kangxi_RADICALS}');
Error('\P{:= IN_Kangxi_RADICALS}');
Expect(1, 12255, '\p{inkangxiradicals}', "");
Expect(0, 12255, '\p{^inkangxiradicals}', "");
Expect(0, 12255, '\P{inkangxiradicals}', "");
Expect(1, 12255, '\P{^inkangxiradicals}', "");
Expect(0, 12256, '\p{inkangxiradicals}', "");
Expect(1, 12256, '\p{^inkangxiradicals}', "");
Expect(1, 12256, '\P{inkangxiradicals}', "");
Expect(0, 12256, '\P{^inkangxiradicals}', "");
Expect(1, 12255, '\p{_IN_Kangxi_Radicals}', "");
Expect(0, 12255, '\p{^_IN_Kangxi_Radicals}', "");
Expect(0, 12255, '\P{_IN_Kangxi_Radicals}', "");
Expect(1, 12255, '\P{^_IN_Kangxi_Radicals}', "");
Expect(0, 12256, '\p{_IN_Kangxi_Radicals}', "");
Expect(1, 12256, '\p{^_IN_Kangxi_Radicals}', "");
Expect(1, 12256, '\P{_IN_Kangxi_Radicals}', "");
Expect(0, 12256, '\P{^_IN_Kangxi_Radicals}', "");
Error('\p{ :=KANGXI}');
Error('\P{ :=KANGXI}');
Expect(1, 12255, '\p{kangxi}', "");
Expect(0, 12255, '\p{^kangxi}', "");
Expect(0, 12255, '\P{kangxi}', "");
Expect(1, 12255, '\P{^kangxi}', "");
Expect(0, 12256, '\p{kangxi}', "");
Expect(1, 12256, '\p{^kangxi}', "");
Expect(1, 12256, '\P{kangxi}', "");
Expect(0, 12256, '\P{^kangxi}', "");
Expect(1, 12255, '\p{_Kangxi}', "");
Expect(0, 12255, '\p{^_Kangxi}', "");
Expect(0, 12255, '\P{_Kangxi}', "");
Expect(1, 12255, '\P{^_Kangxi}', "");
Expect(0, 12256, '\p{_Kangxi}', "");
Expect(1, 12256, '\p{^_Kangxi}', "");
Expect(1, 12256, '\P{_Kangxi}', "");
Expect(0, 12256, '\P{^_Kangxi}', "");
Error('\p{ Is_kangxi:=}');
Error('\P{ Is_kangxi:=}');
Expect(1, 12255, '\p{iskangxi}', "");
Expect(0, 12255, '\p{^iskangxi}', "");
Expect(0, 12255, '\P{iskangxi}', "");
Expect(1, 12255, '\P{^iskangxi}', "");
Expect(0, 12256, '\p{iskangxi}', "");
Expect(1, 12256, '\p{^iskangxi}', "");
Expect(1, 12256, '\P{iskangxi}', "");
Expect(0, 12256, '\P{^iskangxi}', "");
Expect(1, 12255, '\p{_ is_kangxi}', "");
Expect(0, 12255, '\p{^_ is_kangxi}', "");
Expect(0, 12255, '\P{_ is_kangxi}', "");
Expect(1, 12255, '\P{^_ is_kangxi}', "");
Expect(0, 12256, '\p{_ is_kangxi}', "");
Expect(1, 12256, '\p{^_ is_kangxi}', "");
Expect(1, 12256, '\P{_ is_kangxi}', "");
Expect(0, 12256, '\P{^_ is_kangxi}', "");
Error('\p{-/a/In_Kangxi}');
Error('\P{-/a/In_Kangxi}');
Expect(1, 12255, '\p{inkangxi}', "");
Expect(0, 12255, '\p{^inkangxi}', "");
Expect(0, 12255, '\P{inkangxi}', "");
Expect(1, 12255, '\P{^inkangxi}', "");
Expect(0, 12256, '\p{inkangxi}', "");
Expect(1, 12256, '\p{^inkangxi}', "");
Expect(1, 12256, '\P{inkangxi}', "");
Expect(0, 12256, '\P{^inkangxi}', "");
Expect(1, 12255, '\p{	-IN_kangxi}', "");
Expect(0, 12255, '\p{^	-IN_kangxi}', "");
Expect(0, 12255, '\P{	-IN_kangxi}', "");
Expect(1, 12255, '\P{^	-IN_kangxi}', "");
Expect(0, 12256, '\p{	-IN_kangxi}', "");
Expect(1, 12256, '\p{^	-IN_kangxi}', "");
Expect(1, 12256, '\P{	-IN_kangxi}', "");
Expect(0, 12256, '\P{^	-IN_kangxi}', "");
Error('\p{-/a/Kannada}');
Error('\P{-/a/Kannada}');
Expect(1, 3314, '\p{kannada}', "");
Expect(0, 3314, '\p{^kannada}', "");
Expect(0, 3314, '\P{kannada}', "");
Expect(1, 3314, '\P{^kannada}', "");
Expect(0, 3315, '\p{kannada}', "");
Expect(1, 3315, '\p{^kannada}', "");
Expect(1, 3315, '\P{kannada}', "");
Expect(0, 3315, '\P{^kannada}', "");
Expect(1, 3314, '\p{ kannada}', "");
Expect(0, 3314, '\p{^ kannada}', "");
Expect(0, 3314, '\P{ kannada}', "");
Expect(1, 3314, '\P{^ kannada}', "");
Expect(0, 3315, '\p{ kannada}', "");
Expect(1, 3315, '\p{^ kannada}', "");
Expect(1, 3315, '\P{ kannada}', "");
Expect(0, 3315, '\P{^ kannada}', "");
Error('\p{/a/-Is_KANNADA}');
Error('\P{/a/-Is_KANNADA}');
Expect(1, 3314, '\p{iskannada}', "");
Expect(0, 3314, '\p{^iskannada}', "");
Expect(0, 3314, '\P{iskannada}', "");
Expect(1, 3314, '\P{^iskannada}', "");
Expect(0, 3315, '\p{iskannada}', "");
Expect(1, 3315, '\p{^iskannada}', "");
Expect(1, 3315, '\P{iskannada}', "");
Expect(0, 3315, '\P{^iskannada}', "");
Expect(1, 3314, '\p{ IS_KANNADA}', "");
Expect(0, 3314, '\p{^ IS_KANNADA}', "");
Expect(0, 3314, '\P{ IS_KANNADA}', "");
Expect(1, 3314, '\P{^ IS_KANNADA}', "");
Expect(0, 3315, '\p{ IS_KANNADA}', "");
Expect(1, 3315, '\p{^ IS_KANNADA}', "");
Expect(1, 3315, '\P{ IS_KANNADA}', "");
Expect(0, 3315, '\P{^ IS_KANNADA}', "");
Error('\p{-Knda/a/}');
Error('\P{-Knda/a/}');
Expect(1, 3314, '\p{knda}', "");
Expect(0, 3314, '\p{^knda}', "");
Expect(0, 3314, '\P{knda}', "");
Expect(1, 3314, '\P{^knda}', "");
Expect(0, 3315, '\p{knda}', "");
Expect(1, 3315, '\p{^knda}', "");
Expect(1, 3315, '\P{knda}', "");
Expect(0, 3315, '\P{^knda}', "");
Expect(1, 3314, '\p{_Knda}', "");
Expect(0, 3314, '\p{^_Knda}', "");
Expect(0, 3314, '\P{_Knda}', "");
Expect(1, 3314, '\P{^_Knda}', "");
Expect(0, 3315, '\p{_Knda}', "");
Expect(1, 3315, '\p{^_Knda}', "");
Expect(1, 3315, '\P{_Knda}', "");
Expect(0, 3315, '\P{^_Knda}', "");
Error('\p{_IS_Knda:=}');
Error('\P{_IS_Knda:=}');
Expect(1, 3314, '\p{isknda}', "");
Expect(0, 3314, '\p{^isknda}', "");
Expect(0, 3314, '\P{isknda}', "");
Expect(1, 3314, '\P{^isknda}', "");
Expect(0, 3315, '\p{isknda}', "");
Expect(1, 3315, '\p{^isknda}', "");
Expect(1, 3315, '\P{isknda}', "");
Expect(0, 3315, '\P{^isknda}', "");
Expect(1, 3314, '\p{_-IS_knda}', "");
Expect(0, 3314, '\p{^_-IS_knda}', "");
Expect(0, 3314, '\P{_-IS_knda}', "");
Expect(1, 3314, '\P{^_-IS_knda}', "");
Expect(0, 3315, '\p{_-IS_knda}', "");
Expect(1, 3315, '\p{^_-IS_knda}', "");
Expect(1, 3315, '\P{_-IS_knda}', "");
Expect(0, 3315, '\P{^_-IS_knda}', "");
Error('\p{:= katakana}');
Error('\P{:= katakana}');
Expect(1, 110592, '\p{katakana}', "");
Expect(0, 110592, '\p{^katakana}', "");
Expect(0, 110592, '\P{katakana}', "");
Expect(1, 110592, '\P{^katakana}', "");
Expect(0, 110593, '\p{katakana}', "");
Expect(1, 110593, '\p{^katakana}', "");
Expect(1, 110593, '\P{katakana}', "");
Expect(0, 110593, '\P{^katakana}', "");
Expect(1, 110592, '\p{-_KATAKANA}', "");
Expect(0, 110592, '\p{^-_KATAKANA}', "");
Expect(0, 110592, '\P{-_KATAKANA}', "");
Expect(1, 110592, '\P{^-_KATAKANA}', "");
Expect(0, 110593, '\p{-_KATAKANA}', "");
Expect(1, 110593, '\p{^-_KATAKANA}', "");
Expect(1, 110593, '\P{-_KATAKANA}', "");
Expect(0, 110593, '\P{^-_KATAKANA}', "");
Error('\p{/a/IS_katakana}');
Error('\P{/a/IS_katakana}');
Expect(1, 110592, '\p{iskatakana}', "");
Expect(0, 110592, '\p{^iskatakana}', "");
Expect(0, 110592, '\P{iskatakana}', "");
Expect(1, 110592, '\P{^iskatakana}', "");
Expect(0, 110593, '\p{iskatakana}', "");
Expect(1, 110593, '\p{^iskatakana}', "");
Expect(1, 110593, '\P{iskatakana}', "");
Expect(0, 110593, '\P{^iskatakana}', "");
Expect(1, 110592, '\p{-IS_Katakana}', "");
Expect(0, 110592, '\p{^-IS_Katakana}', "");
Expect(0, 110592, '\P{-IS_Katakana}', "");
Expect(1, 110592, '\P{^-IS_Katakana}', "");
Expect(0, 110593, '\p{-IS_Katakana}', "");
Expect(1, 110593, '\p{^-IS_Katakana}', "");
Expect(1, 110593, '\P{-IS_Katakana}', "");
Expect(0, 110593, '\P{^-IS_Katakana}', "");
Error('\p{-Kana:=}');
Error('\P{-Kana:=}');
Expect(1, 110592, '\p{kana}', "");
Expect(0, 110592, '\p{^kana}', "");
Expect(0, 110592, '\P{kana}', "");
Expect(1, 110592, '\P{^kana}', "");
Expect(0, 110593, '\p{kana}', "");
Expect(1, 110593, '\p{^kana}', "");
Expect(1, 110593, '\P{kana}', "");
Expect(0, 110593, '\P{^kana}', "");
Expect(1, 110592, '\p{ 	Kana}', "");
Expect(0, 110592, '\p{^ 	Kana}', "");
Expect(0, 110592, '\P{ 	Kana}', "");
Expect(1, 110592, '\P{^ 	Kana}', "");
Expect(0, 110593, '\p{ 	Kana}', "");
Expect(1, 110593, '\p{^ 	Kana}', "");
Expect(1, 110593, '\P{ 	Kana}', "");
Expect(0, 110593, '\P{^ 	Kana}', "");
Error('\p{-:=Is_Kana}');
Error('\P{-:=Is_Kana}');
Expect(1, 110592, '\p{iskana}', "");
Expect(0, 110592, '\p{^iskana}', "");
Expect(0, 110592, '\P{iskana}', "");
Expect(1, 110592, '\P{^iskana}', "");
Expect(0, 110593, '\p{iskana}', "");
Expect(1, 110593, '\p{^iskana}', "");
Expect(1, 110593, '\P{iskana}', "");
Expect(0, 110593, '\P{^iskana}', "");
Expect(1, 110592, '\p{_Is_kana}', "");
Expect(0, 110592, '\p{^_Is_kana}', "");
Expect(0, 110592, '\P{_Is_kana}', "");
Expect(1, 110592, '\P{^_Is_kana}', "");
Expect(0, 110593, '\p{_Is_kana}', "");
Expect(1, 110593, '\p{^_Is_kana}', "");
Expect(1, 110593, '\P{_Is_kana}', "");
Expect(0, 110593, '\P{^_Is_kana}', "");
Error('\p{Katakana_Or_Hiragana}');
Error('\P{Katakana_Or_Hiragana}');
Error('\p{Is_Katakana_Or_Hiragana}');
Error('\P{Is_Katakana_Or_Hiragana}');
Error('\p{Hrkt}');
Error('\P{Hrkt}');
Error('\p{Is_Hrkt}');
Error('\P{Is_Hrkt}');
Error('\p{_/a/Katakana_Phonetic_extensions}');
Error('\P{_/a/Katakana_Phonetic_extensions}');
Expect(1, 12799, '\p{katakanaphoneticextensions}', "");
Expect(0, 12799, '\p{^katakanaphoneticextensions}', "");
Expect(0, 12799, '\P{katakanaphoneticextensions}', "");
Expect(1, 12799, '\P{^katakanaphoneticextensions}', "");
Expect(0, 12800, '\p{katakanaphoneticextensions}', "");
Expect(1, 12800, '\p{^katakanaphoneticextensions}', "");
Expect(1, 12800, '\P{katakanaphoneticextensions}', "");
Expect(0, 12800, '\P{^katakanaphoneticextensions}', "");
Expect(1, 12799, '\p{_-katakana_PHONETIC_Extensions}', "");
Expect(0, 12799, '\p{^_-katakana_PHONETIC_Extensions}', "");
Expect(0, 12799, '\P{_-katakana_PHONETIC_Extensions}', "");
Expect(1, 12799, '\P{^_-katakana_PHONETIC_Extensions}', "");
Expect(0, 12800, '\p{_-katakana_PHONETIC_Extensions}', "");
Expect(1, 12800, '\p{^_-katakana_PHONETIC_Extensions}', "");
Expect(1, 12800, '\P{_-katakana_PHONETIC_Extensions}', "");
Expect(0, 12800, '\P{^_-katakana_PHONETIC_Extensions}', "");
Error('\p{-_Is_KATAKANA_phonetic_Extensions:=}');
Error('\P{-_Is_KATAKANA_phonetic_Extensions:=}');
Expect(1, 12799, '\p{iskatakanaphoneticextensions}', "");
Expect(0, 12799, '\p{^iskatakanaphoneticextensions}', "");
Expect(0, 12799, '\P{iskatakanaphoneticextensions}', "");
Expect(1, 12799, '\P{^iskatakanaphoneticextensions}', "");
Expect(0, 12800, '\p{iskatakanaphoneticextensions}', "");
Expect(1, 12800, '\p{^iskatakanaphoneticextensions}', "");
Expect(1, 12800, '\P{iskatakanaphoneticextensions}', "");
Expect(0, 12800, '\P{^iskatakanaphoneticextensions}', "");
Expect(1, 12799, '\p{_	Is_katakana_PHONETIC_Extensions}', "");
Expect(0, 12799, '\p{^_	Is_katakana_PHONETIC_Extensions}', "");
Expect(0, 12799, '\P{_	Is_katakana_PHONETIC_Extensions}', "");
Expect(1, 12799, '\P{^_	Is_katakana_PHONETIC_Extensions}', "");
Expect(0, 12800, '\p{_	Is_katakana_PHONETIC_Extensions}', "");
Expect(1, 12800, '\p{^_	Is_katakana_PHONETIC_Extensions}', "");
Expect(1, 12800, '\P{_	Is_katakana_PHONETIC_Extensions}', "");
Expect(0, 12800, '\P{^_	Is_katakana_PHONETIC_Extensions}', "");
Error('\p{		In_Katakana_phonetic_EXTENSIONS:=}');
Error('\P{		In_Katakana_phonetic_EXTENSIONS:=}');
Expect(1, 12799, '\p{inkatakanaphoneticextensions}', "");
Expect(0, 12799, '\p{^inkatakanaphoneticextensions}', "");
Expect(0, 12799, '\P{inkatakanaphoneticextensions}', "");
Expect(1, 12799, '\P{^inkatakanaphoneticextensions}', "");
Expect(0, 12800, '\p{inkatakanaphoneticextensions}', "");
Expect(1, 12800, '\p{^inkatakanaphoneticextensions}', "");
Expect(1, 12800, '\P{inkatakanaphoneticextensions}', "");
Expect(0, 12800, '\P{^inkatakanaphoneticextensions}', "");
Expect(1, 12799, '\p{IN_Katakana_PHONETIC_extensions}', "");
Expect(0, 12799, '\p{^IN_Katakana_PHONETIC_extensions}', "");
Expect(0, 12799, '\P{IN_Katakana_PHONETIC_extensions}', "");
Expect(1, 12799, '\P{^IN_Katakana_PHONETIC_extensions}', "");
Expect(0, 12800, '\p{IN_Katakana_PHONETIC_extensions}', "");
Expect(1, 12800, '\p{^IN_Katakana_PHONETIC_extensions}', "");
Expect(1, 12800, '\P{IN_Katakana_PHONETIC_extensions}', "");
Expect(0, 12800, '\P{^IN_Katakana_PHONETIC_extensions}', "");
Error('\p{:=KATAKANA_ext}');
Error('\P{:=KATAKANA_ext}');
Expect(1, 12799, '\p{katakanaext}', "");
Expect(0, 12799, '\p{^katakanaext}', "");
Expect(0, 12799, '\P{katakanaext}', "");
Expect(1, 12799, '\P{^katakanaext}', "");
Expect(0, 12800, '\p{katakanaext}', "");
Expect(1, 12800, '\p{^katakanaext}', "");
Expect(1, 12800, '\P{katakanaext}', "");
Expect(0, 12800, '\P{^katakanaext}', "");
Expect(1, 12799, '\p{  Katakana_EXT}', "");
Expect(0, 12799, '\p{^  Katakana_EXT}', "");
Expect(0, 12799, '\P{  Katakana_EXT}', "");
Expect(1, 12799, '\P{^  Katakana_EXT}', "");
Expect(0, 12800, '\p{  Katakana_EXT}', "");
Expect(1, 12800, '\p{^  Katakana_EXT}', "");
Expect(1, 12800, '\P{  Katakana_EXT}', "");
Expect(0, 12800, '\P{^  Katakana_EXT}', "");
Error('\p{ Is_Katakana_ext:=}');
Error('\P{ Is_Katakana_ext:=}');
Expect(1, 12799, '\p{iskatakanaext}', "");
Expect(0, 12799, '\p{^iskatakanaext}', "");
Expect(0, 12799, '\P{iskatakanaext}', "");
Expect(1, 12799, '\P{^iskatakanaext}', "");
Expect(0, 12800, '\p{iskatakanaext}', "");
Expect(1, 12800, '\p{^iskatakanaext}', "");
Expect(1, 12800, '\P{iskatakanaext}', "");
Expect(0, 12800, '\P{^iskatakanaext}', "");
Expect(1, 12799, '\p{ 	Is_Katakana_ext}', "");
Expect(0, 12799, '\p{^ 	Is_Katakana_ext}', "");
Expect(0, 12799, '\P{ 	Is_Katakana_ext}', "");
Expect(1, 12799, '\P{^ 	Is_Katakana_ext}', "");
Expect(0, 12800, '\p{ 	Is_Katakana_ext}', "");
Expect(1, 12800, '\p{^ 	Is_Katakana_ext}', "");
Expect(1, 12800, '\P{ 	Is_Katakana_ext}', "");
Expect(0, 12800, '\P{^ 	Is_Katakana_ext}', "");
Error('\p{In_katakana_EXT:=}');
Error('\P{In_katakana_EXT:=}');
Expect(1, 12799, '\p{inkatakanaext}', "");
Expect(0, 12799, '\p{^inkatakanaext}', "");
Expect(0, 12799, '\P{inkatakanaext}', "");
Expect(1, 12799, '\P{^inkatakanaext}', "");
Expect(0, 12800, '\p{inkatakanaext}', "");
Expect(1, 12800, '\p{^inkatakanaext}', "");
Expect(1, 12800, '\P{inkatakanaext}', "");
Expect(0, 12800, '\P{^inkatakanaext}', "");
Expect(1, 12799, '\p{-In_KATAKANA_Ext}', "");
Expect(0, 12799, '\p{^-In_KATAKANA_Ext}', "");
Expect(0, 12799, '\P{-In_KATAKANA_Ext}', "");
Expect(1, 12799, '\P{^-In_KATAKANA_Ext}', "");
Expect(0, 12800, '\p{-In_KATAKANA_Ext}', "");
Expect(1, 12800, '\p{^-In_KATAKANA_Ext}', "");
Expect(1, 12800, '\P{-In_KATAKANA_Ext}', "");
Expect(0, 12800, '\P{^-In_KATAKANA_Ext}', "");
Error('\p{-kayah_li/a/}');
Error('\P{-kayah_li/a/}');
Expect(1, 43311, '\p{kayahli}', "");
Expect(0, 43311, '\p{^kayahli}', "");
Expect(0, 43311, '\P{kayahli}', "");
Expect(1, 43311, '\P{^kayahli}', "");
Expect(0, 43312, '\p{kayahli}', "");
Expect(1, 43312, '\p{^kayahli}', "");
Expect(1, 43312, '\P{kayahli}', "");
Expect(0, 43312, '\P{^kayahli}', "");
Expect(1, 43311, '\p{  Kayah_LI}', "");
Expect(0, 43311, '\p{^  Kayah_LI}', "");
Expect(0, 43311, '\P{  Kayah_LI}', "");
Expect(1, 43311, '\P{^  Kayah_LI}', "");
Expect(0, 43312, '\p{  Kayah_LI}', "");
Expect(1, 43312, '\p{^  Kayah_LI}', "");
Expect(1, 43312, '\P{  Kayah_LI}', "");
Expect(0, 43312, '\P{^  Kayah_LI}', "");
Error('\p{:=  Is_Kayah_Li}');
Error('\P{:=  Is_Kayah_Li}');
Expect(1, 43311, '\p{iskayahli}', "");
Expect(0, 43311, '\p{^iskayahli}', "");
Expect(0, 43311, '\P{iskayahli}', "");
Expect(1, 43311, '\P{^iskayahli}', "");
Expect(0, 43312, '\p{iskayahli}', "");
Expect(1, 43312, '\p{^iskayahli}', "");
Expect(1, 43312, '\P{iskayahli}', "");
Expect(0, 43312, '\P{^iskayahli}', "");
Expect(1, 43311, '\p{	_IS_kayah_Li}', "");
Expect(0, 43311, '\p{^	_IS_kayah_Li}', "");
Expect(0, 43311, '\P{	_IS_kayah_Li}', "");
Expect(1, 43311, '\P{^	_IS_kayah_Li}', "");
Expect(0, 43312, '\p{	_IS_kayah_Li}', "");
Expect(1, 43312, '\p{^	_IS_kayah_Li}', "");
Expect(1, 43312, '\P{	_IS_kayah_Li}', "");
Expect(0, 43312, '\P{^	_IS_kayah_Li}', "");
Error('\p{:=	_Kali}');
Error('\P{:=	_Kali}');
Expect(1, 43311, '\p{kali}', "");
Expect(0, 43311, '\p{^kali}', "");
Expect(0, 43311, '\P{kali}', "");
Expect(1, 43311, '\P{^kali}', "");
Expect(0, 43312, '\p{kali}', "");
Expect(1, 43312, '\p{^kali}', "");
Expect(1, 43312, '\P{kali}', "");
Expect(0, 43312, '\P{^kali}', "");
Expect(1, 43311, '\p{KALI}', "");
Expect(0, 43311, '\p{^KALI}', "");
Expect(0, 43311, '\P{KALI}', "");
Expect(1, 43311, '\P{^KALI}', "");
Expect(0, 43312, '\p{KALI}', "");
Expect(1, 43312, '\p{^KALI}', "");
Expect(1, 43312, '\P{KALI}', "");
Expect(0, 43312, '\P{^KALI}', "");
Error('\p{:=-	IS_KALI}');
Error('\P{:=-	IS_KALI}');
Expect(1, 43311, '\p{iskali}', "");
Expect(0, 43311, '\p{^iskali}', "");
Expect(0, 43311, '\P{iskali}', "");
Expect(1, 43311, '\P{^iskali}', "");
Expect(0, 43312, '\p{iskali}', "");
Expect(1, 43312, '\p{^iskali}', "");
Expect(1, 43312, '\P{iskali}', "");
Expect(0, 43312, '\P{^iskali}', "");
Expect(1, 43311, '\p{ IS_kali}', "");
Expect(0, 43311, '\p{^ IS_kali}', "");
Expect(0, 43311, '\P{ IS_kali}', "");
Expect(1, 43311, '\P{^ IS_kali}', "");
Expect(0, 43312, '\p{ IS_kali}', "");
Expect(1, 43312, '\p{^ IS_kali}', "");
Expect(1, 43312, '\P{ IS_kali}', "");
Expect(0, 43312, '\P{^ IS_kali}', "");
Error('\p{ -Kharoshthi/a/}');
Error('\P{ -Kharoshthi/a/}');
Expect(1, 68184, '\p{kharoshthi}', "");
Expect(0, 68184, '\p{^kharoshthi}', "");
Expect(0, 68184, '\P{kharoshthi}', "");
Expect(1, 68184, '\P{^kharoshthi}', "");
Expect(0, 68185, '\p{kharoshthi}', "");
Expect(1, 68185, '\p{^kharoshthi}', "");
Expect(1, 68185, '\P{kharoshthi}', "");
Expect(0, 68185, '\P{^kharoshthi}', "");
Expect(1, 68184, '\p{ kharoshthi}', "");
Expect(0, 68184, '\p{^ kharoshthi}', "");
Expect(0, 68184, '\P{ kharoshthi}', "");
Expect(1, 68184, '\P{^ kharoshthi}', "");
Expect(0, 68185, '\p{ kharoshthi}', "");
Expect(1, 68185, '\p{^ kharoshthi}', "");
Expect(1, 68185, '\P{ kharoshthi}', "");
Expect(0, 68185, '\P{^ kharoshthi}', "");
Error('\p{ -Is_kharoshthi:=}');
Error('\P{ -Is_kharoshthi:=}');
Expect(1, 68184, '\p{iskharoshthi}', "");
Expect(0, 68184, '\p{^iskharoshthi}', "");
Expect(0, 68184, '\P{iskharoshthi}', "");
Expect(1, 68184, '\P{^iskharoshthi}', "");
Expect(0, 68185, '\p{iskharoshthi}', "");
Expect(1, 68185, '\p{^iskharoshthi}', "");
Expect(1, 68185, '\P{iskharoshthi}', "");
Expect(0, 68185, '\P{^iskharoshthi}', "");
Expect(1, 68184, '\p{_-IS_KHAROSHTHI}', "");
Expect(0, 68184, '\p{^_-IS_KHAROSHTHI}', "");
Expect(0, 68184, '\P{_-IS_KHAROSHTHI}', "");
Expect(1, 68184, '\P{^_-IS_KHAROSHTHI}', "");
Expect(0, 68185, '\p{_-IS_KHAROSHTHI}', "");
Expect(1, 68185, '\p{^_-IS_KHAROSHTHI}', "");
Expect(1, 68185, '\P{_-IS_KHAROSHTHI}', "");
Expect(0, 68185, '\P{^_-IS_KHAROSHTHI}', "");
Error('\p{ KHAR/a/}');
Error('\P{ KHAR/a/}');
Expect(1, 68184, '\p{khar}', "");
Expect(0, 68184, '\p{^khar}', "");
Expect(0, 68184, '\P{khar}', "");
Expect(1, 68184, '\P{^khar}', "");
Expect(0, 68185, '\p{khar}', "");
Expect(1, 68185, '\p{^khar}', "");
Expect(1, 68185, '\P{khar}', "");
Expect(0, 68185, '\P{^khar}', "");
Expect(1, 68184, '\p{-_Khar}', "");
Expect(0, 68184, '\p{^-_Khar}', "");
Expect(0, 68184, '\P{-_Khar}', "");
Expect(1, 68184, '\P{^-_Khar}', "");
Expect(0, 68185, '\p{-_Khar}', "");
Expect(1, 68185, '\p{^-_Khar}', "");
Expect(1, 68185, '\P{-_Khar}', "");
Expect(0, 68185, '\P{^-_Khar}', "");
Error('\p{__Is_Khar:=}');
Error('\P{__Is_Khar:=}');
Expect(1, 68184, '\p{iskhar}', "");
Expect(0, 68184, '\p{^iskhar}', "");
Expect(0, 68184, '\P{iskhar}', "");
Expect(1, 68184, '\P{^iskhar}', "");
Expect(0, 68185, '\p{iskhar}', "");
Expect(1, 68185, '\p{^iskhar}', "");
Expect(1, 68185, '\P{iskhar}', "");
Expect(0, 68185, '\P{^iskhar}', "");
Expect(1, 68184, '\p{_IS_Khar}', "");
Expect(0, 68184, '\p{^_IS_Khar}', "");
Expect(0, 68184, '\P{_IS_Khar}', "");
Expect(1, 68184, '\P{^_IS_Khar}', "");
Expect(0, 68185, '\p{_IS_Khar}', "");
Expect(1, 68185, '\p{^_IS_Khar}', "");
Expect(1, 68185, '\P{_IS_Khar}', "");
Expect(0, 68185, '\P{^_IS_Khar}', "");
Error('\p{/a/ Khmer}');
Error('\P{/a/ Khmer}');
Expect(1, 6655, '\p{khmer}', "");
Expect(0, 6655, '\p{^khmer}', "");
Expect(0, 6655, '\P{khmer}', "");
Expect(1, 6655, '\P{^khmer}', "");
Expect(0, 6656, '\p{khmer}', "");
Expect(1, 6656, '\p{^khmer}', "");
Expect(1, 6656, '\P{khmer}', "");
Expect(0, 6656, '\P{^khmer}', "");
Expect(1, 6655, '\p{_-KHMER}', "");
Expect(0, 6655, '\p{^_-KHMER}', "");
Expect(0, 6655, '\P{_-KHMER}', "");
Expect(1, 6655, '\P{^_-KHMER}', "");
Expect(0, 6656, '\p{_-KHMER}', "");
Expect(1, 6656, '\p{^_-KHMER}', "");
Expect(1, 6656, '\P{_-KHMER}', "");
Expect(0, 6656, '\P{^_-KHMER}', "");
Error('\p{_-Is_khmer:=}');
Error('\P{_-Is_khmer:=}');
Expect(1, 6655, '\p{iskhmer}', "");
Expect(0, 6655, '\p{^iskhmer}', "");
Expect(0, 6655, '\P{iskhmer}', "");
Expect(1, 6655, '\P{^iskhmer}', "");
Expect(0, 6656, '\p{iskhmer}', "");
Expect(1, 6656, '\p{^iskhmer}', "");
Expect(1, 6656, '\P{iskhmer}', "");
Expect(0, 6656, '\P{^iskhmer}', "");
Expect(1, 6655, '\p{- is_khmer}', "");
Expect(0, 6655, '\p{^- is_khmer}', "");
Expect(0, 6655, '\P{- is_khmer}', "");
Expect(1, 6655, '\P{^- is_khmer}', "");
Expect(0, 6656, '\p{- is_khmer}', "");
Expect(1, 6656, '\p{^- is_khmer}', "");
Expect(1, 6656, '\P{- is_khmer}', "");
Expect(0, 6656, '\P{^- is_khmer}', "");
Error('\p{	 KHMR:=}');
Error('\P{	 KHMR:=}');
Expect(1, 6655, '\p{khmr}', "");
Expect(0, 6655, '\p{^khmr}', "");
Expect(0, 6655, '\P{khmr}', "");
Expect(1, 6655, '\P{^khmr}', "");
Expect(0, 6656, '\p{khmr}', "");
Expect(1, 6656, '\p{^khmr}', "");
Expect(1, 6656, '\P{khmr}', "");
Expect(0, 6656, '\P{^khmr}', "");
Expect(1, 6655, '\p{ -Khmr}', "");
Expect(0, 6655, '\p{^ -Khmr}', "");
Expect(0, 6655, '\P{ -Khmr}', "");
Expect(1, 6655, '\P{^ -Khmr}', "");
Expect(0, 6656, '\p{ -Khmr}', "");
Expect(1, 6656, '\p{^ -Khmr}', "");
Expect(1, 6656, '\P{ -Khmr}', "");
Expect(0, 6656, '\P{^ -Khmr}', "");
Error('\p{  IS_Khmr:=}');
Error('\P{  IS_Khmr:=}');
Expect(1, 6655, '\p{iskhmr}', "");
Expect(0, 6655, '\p{^iskhmr}', "");
Expect(0, 6655, '\P{iskhmr}', "");
Expect(1, 6655, '\P{^iskhmr}', "");
Expect(0, 6656, '\p{iskhmr}', "");
Expect(1, 6656, '\p{^iskhmr}', "");
Expect(1, 6656, '\P{iskhmr}', "");
Expect(0, 6656, '\P{^iskhmr}', "");
Expect(1, 6655, '\p{  Is_KHMR}', "");
Expect(0, 6655, '\p{^  Is_KHMR}', "");
Expect(0, 6655, '\P{  Is_KHMR}', "");
Expect(1, 6655, '\P{^  Is_KHMR}', "");
Expect(0, 6656, '\p{  Is_KHMR}', "");
Expect(1, 6656, '\p{^  Is_KHMR}', "");
Expect(1, 6656, '\P{  Is_KHMR}', "");
Expect(0, 6656, '\P{^  Is_KHMR}', "");
Error('\p{_-KHMER_SYMBOLS:=}');
Error('\P{_-KHMER_SYMBOLS:=}');
Expect(1, 6655, '\p{khmersymbols}', "");
Expect(0, 6655, '\p{^khmersymbols}', "");
Expect(0, 6655, '\P{khmersymbols}', "");
Expect(1, 6655, '\P{^khmersymbols}', "");
Expect(0, 6656, '\p{khmersymbols}', "");
Expect(1, 6656, '\p{^khmersymbols}', "");
Expect(1, 6656, '\P{khmersymbols}', "");
Expect(0, 6656, '\P{^khmersymbols}', "");
Expect(1, 6655, '\p{_-Khmer_SYMBOLS}', "");
Expect(0, 6655, '\p{^_-Khmer_SYMBOLS}', "");
Expect(0, 6655, '\P{_-Khmer_SYMBOLS}', "");
Expect(1, 6655, '\P{^_-Khmer_SYMBOLS}', "");
Expect(0, 6656, '\p{_-Khmer_SYMBOLS}', "");
Expect(1, 6656, '\p{^_-Khmer_SYMBOLS}', "");
Expect(1, 6656, '\P{_-Khmer_SYMBOLS}', "");
Expect(0, 6656, '\P{^_-Khmer_SYMBOLS}', "");
Error('\p{:=- is_khmer_symbols}');
Error('\P{:=- is_khmer_symbols}');
Expect(1, 6655, '\p{iskhmersymbols}', "");
Expect(0, 6655, '\p{^iskhmersymbols}', "");
Expect(0, 6655, '\P{iskhmersymbols}', "");
Expect(1, 6655, '\P{^iskhmersymbols}', "");
Expect(0, 6656, '\p{iskhmersymbols}', "");
Expect(1, 6656, '\p{^iskhmersymbols}', "");
Expect(1, 6656, '\P{iskhmersymbols}', "");
Expect(0, 6656, '\P{^iskhmersymbols}', "");
Expect(1, 6655, '\p{ Is_Khmer_Symbols}', "");
Expect(0, 6655, '\p{^ Is_Khmer_Symbols}', "");
Expect(0, 6655, '\P{ Is_Khmer_Symbols}', "");
Expect(1, 6655, '\P{^ Is_Khmer_Symbols}', "");
Expect(0, 6656, '\p{ Is_Khmer_Symbols}', "");
Expect(1, 6656, '\p{^ Is_Khmer_Symbols}', "");
Expect(1, 6656, '\P{ Is_Khmer_Symbols}', "");
Expect(0, 6656, '\P{^ Is_Khmer_Symbols}', "");
Error('\p{/a/	 in_khmer_Symbols}');
Error('\P{/a/	 in_khmer_Symbols}');
Expect(1, 6655, '\p{inkhmersymbols}', "");
Expect(0, 6655, '\p{^inkhmersymbols}', "");
Expect(0, 6655, '\P{inkhmersymbols}', "");
Expect(1, 6655, '\P{^inkhmersymbols}', "");
Expect(0, 6656, '\p{inkhmersymbols}', "");
Expect(1, 6656, '\p{^inkhmersymbols}', "");
Expect(1, 6656, '\P{inkhmersymbols}', "");
Expect(0, 6656, '\P{^inkhmersymbols}', "");
Expect(1, 6655, '\p{ -IN_khmer_symbols}', "");
Expect(0, 6655, '\p{^ -IN_khmer_symbols}', "");
Expect(0, 6655, '\P{ -IN_khmer_symbols}', "");
Expect(1, 6655, '\P{^ -IN_khmer_symbols}', "");
Expect(0, 6656, '\p{ -IN_khmer_symbols}', "");
Expect(1, 6656, '\p{^ -IN_khmer_symbols}', "");
Expect(1, 6656, '\P{ -IN_khmer_symbols}', "");
Expect(0, 6656, '\P{^ -IN_khmer_symbols}', "");
Error('\p{/a/	 Lao}');
Error('\P{/a/	 Lao}');
Expect(1, 3807, '\p{lao}', "");
Expect(0, 3807, '\p{^lao}', "");
Expect(0, 3807, '\P{lao}', "");
Expect(1, 3807, '\P{^lao}', "");
Expect(0, 3808, '\p{lao}', "");
Expect(1, 3808, '\p{^lao}', "");
Expect(1, 3808, '\P{lao}', "");
Expect(0, 3808, '\P{^lao}', "");
Expect(1, 3807, '\p{_lao}', "");
Expect(0, 3807, '\p{^_lao}', "");
Expect(0, 3807, '\P{_lao}', "");
Expect(1, 3807, '\P{^_lao}', "");
Expect(0, 3808, '\p{_lao}', "");
Expect(1, 3808, '\p{^_lao}', "");
Expect(1, 3808, '\P{_lao}', "");
Expect(0, 3808, '\P{^_lao}', "");
Error('\p{:=_ IS_Lao}');
Error('\P{:=_ IS_Lao}');
Expect(1, 3807, '\p{islao}', "");
Expect(0, 3807, '\p{^islao}', "");
Expect(0, 3807, '\P{islao}', "");
Expect(1, 3807, '\P{^islao}', "");
Expect(0, 3808, '\p{islao}', "");
Expect(1, 3808, '\p{^islao}', "");
Expect(1, 3808, '\P{islao}', "");
Expect(0, 3808, '\P{^islao}', "");
Expect(1, 3807, '\p{ -IS_lao}', "");
Expect(0, 3807, '\p{^ -IS_lao}', "");
Expect(0, 3807, '\P{ -IS_lao}', "");
Expect(1, 3807, '\P{^ -IS_lao}', "");
Expect(0, 3808, '\p{ -IS_lao}', "");
Expect(1, 3808, '\p{^ -IS_lao}', "");
Expect(1, 3808, '\P{ -IS_lao}', "");
Expect(0, 3808, '\P{^ -IS_lao}', "");
Error('\p{_/a/laoo}');
Error('\P{_/a/laoo}');
Expect(1, 3807, '\p{laoo}', "");
Expect(0, 3807, '\p{^laoo}', "");
Expect(0, 3807, '\P{laoo}', "");
Expect(1, 3807, '\P{^laoo}', "");
Expect(0, 3808, '\p{laoo}', "");
Expect(1, 3808, '\p{^laoo}', "");
Expect(1, 3808, '\P{laoo}', "");
Expect(0, 3808, '\P{^laoo}', "");
Expect(1, 3807, '\p{ Laoo}', "");
Expect(0, 3807, '\p{^ Laoo}', "");
Expect(0, 3807, '\P{ Laoo}', "");
Expect(1, 3807, '\P{^ Laoo}', "");
Expect(0, 3808, '\p{ Laoo}', "");
Expect(1, 3808, '\p{^ Laoo}', "");
Expect(1, 3808, '\P{ Laoo}', "");
Expect(0, 3808, '\P{^ Laoo}', "");
Error('\p{:=_	Is_Laoo}');
Error('\P{:=_	Is_Laoo}');
Expect(1, 3807, '\p{islaoo}', "");
Expect(0, 3807, '\p{^islaoo}', "");
Expect(0, 3807, '\P{islaoo}', "");
Expect(1, 3807, '\P{^islaoo}', "");
Expect(0, 3808, '\p{islaoo}', "");
Expect(1, 3808, '\p{^islaoo}', "");
Expect(1, 3808, '\P{islaoo}', "");
Expect(0, 3808, '\P{^islaoo}', "");
Expect(1, 3807, '\p{	 Is_LAOO}', "");
Expect(0, 3807, '\p{^	 Is_LAOO}', "");
Expect(0, 3807, '\P{	 Is_LAOO}', "");
Expect(1, 3807, '\P{^	 Is_LAOO}', "");
Expect(0, 3808, '\p{	 Is_LAOO}', "");
Expect(1, 3808, '\p{^	 Is_LAOO}', "");
Expect(1, 3808, '\P{	 Is_LAOO}', "");
Expect(0, 3808, '\P{^	 Is_LAOO}', "");
Error('\p{__Latin:=}');
Error('\P{__Latin:=}');
Expect(1, 65370, '\p{latin}', "");
Expect(0, 65370, '\p{^latin}', "");
Expect(0, 65370, '\P{latin}', "");
Expect(1, 65370, '\P{^latin}', "");
Expect(0, 65371, '\p{latin}', "");
Expect(1, 65371, '\p{^latin}', "");
Expect(1, 65371, '\P{latin}', "");
Expect(0, 65371, '\P{^latin}', "");
Expect(1, 65370, '\p{ Latin}', "");
Expect(0, 65370, '\p{^ Latin}', "");
Expect(0, 65370, '\P{ Latin}', "");
Expect(1, 65370, '\P{^ Latin}', "");
Expect(0, 65371, '\p{ Latin}', "");
Expect(1, 65371, '\p{^ Latin}', "");
Expect(1, 65371, '\P{ Latin}', "");
Expect(0, 65371, '\P{^ Latin}', "");
Error('\p{ is_Latin/a/}');
Error('\P{ is_Latin/a/}');
Expect(1, 65370, '\p{islatin}', "");
Expect(0, 65370, '\p{^islatin}', "");
Expect(0, 65370, '\P{islatin}', "");
Expect(1, 65370, '\P{^islatin}', "");
Expect(0, 65371, '\p{islatin}', "");
Expect(1, 65371, '\p{^islatin}', "");
Expect(1, 65371, '\P{islatin}', "");
Expect(0, 65371, '\P{^islatin}', "");
Expect(1, 65370, '\p{	_Is_latin}', "");
Expect(0, 65370, '\p{^	_Is_latin}', "");
Expect(0, 65370, '\P{	_Is_latin}', "");
Expect(1, 65370, '\P{^	_Is_latin}', "");
Expect(0, 65371, '\p{	_Is_latin}', "");
Expect(1, 65371, '\p{^	_Is_latin}', "");
Expect(1, 65371, '\P{	_Is_latin}', "");
Expect(0, 65371, '\P{^	_Is_latin}', "");
Error('\p{-:=latn}');
Error('\P{-:=latn}');
Expect(1, 65370, '\p{latn}', "");
Expect(0, 65370, '\p{^latn}', "");
Expect(0, 65370, '\P{latn}', "");
Expect(1, 65370, '\P{^latn}', "");
Expect(0, 65371, '\p{latn}', "");
Expect(1, 65371, '\p{^latn}', "");
Expect(1, 65371, '\P{latn}', "");
Expect(0, 65371, '\P{^latn}', "");
Expect(1, 65370, '\p{_latn}', "");
Expect(0, 65370, '\p{^_latn}', "");
Expect(0, 65370, '\P{_latn}', "");
Expect(1, 65370, '\P{^_latn}', "");
Expect(0, 65371, '\p{_latn}', "");
Expect(1, 65371, '\p{^_latn}', "");
Expect(1, 65371, '\P{_latn}', "");
Expect(0, 65371, '\P{^_latn}', "");
Error('\p{:=IS_latn}');
Error('\P{:=IS_latn}');
Expect(1, 65370, '\p{islatn}', "");
Expect(0, 65370, '\p{^islatn}', "");
Expect(0, 65370, '\P{islatn}', "");
Expect(1, 65370, '\P{^islatn}', "");
Expect(0, 65371, '\p{islatn}', "");
Expect(1, 65371, '\p{^islatn}', "");
Expect(1, 65371, '\P{islatn}', "");
Expect(0, 65371, '\P{^islatn}', "");
Expect(1, 65370, '\p{	-IS_latn}', "");
Expect(0, 65370, '\p{^	-IS_latn}', "");
Expect(0, 65370, '\P{	-IS_latn}', "");
Expect(1, 65370, '\P{^	-IS_latn}', "");
Expect(0, 65371, '\p{	-IS_latn}', "");
Expect(1, 65371, '\p{^	-IS_latn}', "");
Expect(1, 65371, '\P{	-IS_latn}', "");
Expect(0, 65371, '\P{^	-IS_latn}', "");
Error('\p{ :=Latin_1_Supplement}');
Error('\P{ :=Latin_1_Supplement}');
Expect(1, 255, '\p{latin1supplement}', "");
Expect(0, 255, '\p{^latin1supplement}', "");
Expect(0, 255, '\P{latin1supplement}', "");
Expect(1, 255, '\P{^latin1supplement}', "");
Expect(0, 256, '\p{latin1supplement}', "");
Expect(1, 256, '\p{^latin1supplement}', "");
Expect(1, 256, '\P{latin1supplement}', "");
Expect(0, 256, '\P{^latin1supplement}', "");
Expect(1, 255, '\p{_Latin_1_Supplement}', "");
Expect(0, 255, '\p{^_Latin_1_Supplement}', "");
Expect(0, 255, '\P{_Latin_1_Supplement}', "");
Expect(1, 255, '\P{^_Latin_1_Supplement}', "");
Expect(0, 256, '\p{_Latin_1_Supplement}', "");
Expect(1, 256, '\p{^_Latin_1_Supplement}', "");
Expect(1, 256, '\P{_Latin_1_Supplement}', "");
Expect(0, 256, '\P{^_Latin_1_Supplement}', "");
Error('\p{/a/is_Latin_1_Supplement}');
Error('\P{/a/is_Latin_1_Supplement}');
Expect(1, 255, '\p{islatin1supplement}', "");
Expect(0, 255, '\p{^islatin1supplement}', "");
Expect(0, 255, '\P{islatin1supplement}', "");
Expect(1, 255, '\P{^islatin1supplement}', "");
Expect(0, 256, '\p{islatin1supplement}', "");
Expect(1, 256, '\p{^islatin1supplement}', "");
Expect(1, 256, '\P{islatin1supplement}', "");
Expect(0, 256, '\P{^islatin1supplement}', "");
Expect(1, 255, '\p{_	IS_LATIN_1_SUPPLEMENT}', "");
Expect(0, 255, '\p{^_	IS_LATIN_1_SUPPLEMENT}', "");
Expect(0, 255, '\P{_	IS_LATIN_1_SUPPLEMENT}', "");
Expect(1, 255, '\P{^_	IS_LATIN_1_SUPPLEMENT}', "");
Expect(0, 256, '\p{_	IS_LATIN_1_SUPPLEMENT}', "");
Expect(1, 256, '\p{^_	IS_LATIN_1_SUPPLEMENT}', "");
Expect(1, 256, '\P{_	IS_LATIN_1_SUPPLEMENT}', "");
Expect(0, 256, '\P{^_	IS_LATIN_1_SUPPLEMENT}', "");
Error('\p{:=_in_LATIN_1_Supplement}');
Error('\P{:=_in_LATIN_1_Supplement}');
Expect(1, 255, '\p{inlatin1supplement}', "");
Expect(0, 255, '\p{^inlatin1supplement}', "");
Expect(0, 255, '\P{inlatin1supplement}', "");
Expect(1, 255, '\P{^inlatin1supplement}', "");
Expect(0, 256, '\p{inlatin1supplement}', "");
Expect(1, 256, '\p{^inlatin1supplement}', "");
Expect(1, 256, '\P{inlatin1supplement}', "");
Expect(0, 256, '\P{^inlatin1supplement}', "");
Expect(1, 255, '\p{IN_latin_1_Supplement}', "");
Expect(0, 255, '\p{^IN_latin_1_Supplement}', "");
Expect(0, 255, '\P{IN_latin_1_Supplement}', "");
Expect(1, 255, '\P{^IN_latin_1_Supplement}', "");
Expect(0, 256, '\p{IN_latin_1_Supplement}', "");
Expect(1, 256, '\p{^IN_latin_1_Supplement}', "");
Expect(1, 256, '\P{IN_latin_1_Supplement}', "");
Expect(0, 256, '\P{^IN_latin_1_Supplement}', "");
Error('\p{:=--Latin_1_Sup}');
Error('\P{:=--Latin_1_Sup}');
Expect(1, 255, '\p{latin1sup}', "");
Expect(0, 255, '\p{^latin1sup}', "");
Expect(0, 255, '\P{latin1sup}', "");
Expect(1, 255, '\P{^latin1sup}', "");
Expect(0, 256, '\p{latin1sup}', "");
Expect(1, 256, '\p{^latin1sup}', "");
Expect(1, 256, '\P{latin1sup}', "");
Expect(0, 256, '\P{^latin1sup}', "");
Expect(1, 255, '\p{- latin_1_Sup}', "");
Expect(0, 255, '\p{^- latin_1_Sup}', "");
Expect(0, 255, '\P{- latin_1_Sup}', "");
Expect(1, 255, '\P{^- latin_1_Sup}', "");
Expect(0, 256, '\p{- latin_1_Sup}', "");
Expect(1, 256, '\p{^- latin_1_Sup}', "");
Expect(1, 256, '\P{- latin_1_Sup}', "");
Expect(0, 256, '\P{^- latin_1_Sup}', "");
Error('\p{ /a/is_LATIN_1_SUP}');
Error('\P{ /a/is_LATIN_1_SUP}');
Expect(1, 255, '\p{islatin1sup}', "");
Expect(0, 255, '\p{^islatin1sup}', "");
Expect(0, 255, '\P{islatin1sup}', "");
Expect(1, 255, '\P{^islatin1sup}', "");
Expect(0, 256, '\p{islatin1sup}', "");
Expect(1, 256, '\p{^islatin1sup}', "");
Expect(1, 256, '\P{islatin1sup}', "");
Expect(0, 256, '\P{^islatin1sup}', "");
Expect(1, 255, '\p{ IS_Latin_1_SUP}', "");
Expect(0, 255, '\p{^ IS_Latin_1_SUP}', "");
Expect(0, 255, '\P{ IS_Latin_1_SUP}', "");
Expect(1, 255, '\P{^ IS_Latin_1_SUP}', "");
Expect(0, 256, '\p{ IS_Latin_1_SUP}', "");
Expect(1, 256, '\p{^ IS_Latin_1_SUP}', "");
Expect(1, 256, '\P{ IS_Latin_1_SUP}', "");
Expect(0, 256, '\P{^ IS_Latin_1_SUP}', "");
Error('\p{In_Latin_1_Sup/a/}');
Error('\P{In_Latin_1_Sup/a/}');
Expect(1, 255, '\p{inlatin1sup}', "");
Expect(0, 255, '\p{^inlatin1sup}', "");
Expect(0, 255, '\P{inlatin1sup}', "");
Expect(1, 255, '\P{^inlatin1sup}', "");
Expect(0, 256, '\p{inlatin1sup}', "");
Expect(1, 256, '\p{^inlatin1sup}', "");
Expect(1, 256, '\P{inlatin1sup}', "");
Expect(0, 256, '\P{^inlatin1sup}', "");
Expect(1, 255, '\p{-IN_Latin_1_sup}', "");
Expect(0, 255, '\p{^-IN_Latin_1_sup}', "");
Expect(0, 255, '\P{-IN_Latin_1_sup}', "");
Expect(1, 255, '\P{^-IN_Latin_1_sup}', "");
Expect(0, 256, '\p{-IN_Latin_1_sup}', "");
Expect(1, 256, '\p{^-IN_Latin_1_sup}', "");
Expect(1, 256, '\P{-IN_Latin_1_sup}', "");
Expect(0, 256, '\P{^-IN_Latin_1_sup}', "");
Error('\p{:=Latin_1}');
Error('\P{:=Latin_1}');
Expect(1, 255, '\p{latin1}', "");
Expect(0, 255, '\p{^latin1}', "");
Expect(0, 255, '\P{latin1}', "");
Expect(1, 255, '\P{^latin1}', "");
Expect(0, 256, '\p{latin1}', "");
Expect(1, 256, '\p{^latin1}', "");
Expect(1, 256, '\P{latin1}', "");
Expect(0, 256, '\P{^latin1}', "");
Expect(1, 255, '\p{ -Latin_1}', "");
Expect(0, 255, '\p{^ -Latin_1}', "");
Expect(0, 255, '\P{ -Latin_1}', "");
Expect(1, 255, '\P{^ -Latin_1}', "");
Expect(0, 256, '\p{ -Latin_1}', "");
Expect(1, 256, '\p{^ -Latin_1}', "");
Expect(1, 256, '\P{ -Latin_1}', "");
Expect(0, 256, '\P{^ -Latin_1}', "");
Error('\p{:=	_Is_latin_1}');
Error('\P{:=	_Is_latin_1}');
Expect(1, 255, '\p{islatin1}', "");
Expect(0, 255, '\p{^islatin1}', "");
Expect(0, 255, '\P{islatin1}', "");
Expect(1, 255, '\P{^islatin1}', "");
Expect(0, 256, '\p{islatin1}', "");
Expect(1, 256, '\p{^islatin1}', "");
Expect(1, 256, '\P{islatin1}', "");
Expect(0, 256, '\P{^islatin1}', "");
Expect(1, 255, '\p{-	Is_LATIN_1}', "");
Expect(0, 255, '\p{^-	Is_LATIN_1}', "");
Expect(0, 255, '\P{-	Is_LATIN_1}', "");
Expect(1, 255, '\P{^-	Is_LATIN_1}', "");
Expect(0, 256, '\p{-	Is_LATIN_1}', "");
Expect(1, 256, '\p{^-	Is_LATIN_1}', "");
Expect(1, 256, '\P{-	Is_LATIN_1}', "");
Expect(0, 256, '\P{^-	Is_LATIN_1}', "");
Error('\p{ -in_Latin_1:=}');
Error('\P{ -in_Latin_1:=}');
Expect(1, 255, '\p{inlatin1}', "");
Expect(0, 255, '\p{^inlatin1}', "");
Expect(0, 255, '\P{inlatin1}', "");
Expect(1, 255, '\P{^inlatin1}', "");
Expect(0, 256, '\p{inlatin1}', "");
Expect(1, 256, '\p{^inlatin1}', "");
Expect(1, 256, '\P{inlatin1}', "");
Expect(0, 256, '\P{^inlatin1}', "");
Expect(1, 255, '\p{_ In_LATIN_1}', "");
Expect(0, 255, '\p{^_ In_LATIN_1}', "");
Expect(0, 255, '\P{_ In_LATIN_1}', "");
Expect(1, 255, '\P{^_ In_LATIN_1}', "");
Expect(0, 256, '\p{_ In_LATIN_1}', "");
Expect(1, 256, '\p{^_ In_LATIN_1}', "");
Expect(1, 256, '\P{_ In_LATIN_1}', "");
Expect(0, 256, '\P{^_ In_LATIN_1}', "");
Error('\p{/a/-Latin_extended_a}');
Error('\P{/a/-Latin_extended_a}');
Expect(1, 383, '\p{latinextendeda}', "");
Expect(0, 383, '\p{^latinextendeda}', "");
Expect(0, 383, '\P{latinextendeda}', "");
Expect(1, 383, '\P{^latinextendeda}', "");
Expect(0, 384, '\p{latinextendeda}', "");
Expect(1, 384, '\p{^latinextendeda}', "");
Expect(1, 384, '\P{latinextendeda}', "");
Expect(0, 384, '\P{^latinextendeda}', "");
Expect(1, 383, '\p{	-Latin_EXTENDED_A}', "");
Expect(0, 383, '\p{^	-Latin_EXTENDED_A}', "");
Expect(0, 383, '\P{	-Latin_EXTENDED_A}', "");
Expect(1, 383, '\P{^	-Latin_EXTENDED_A}', "");
Expect(0, 384, '\p{	-Latin_EXTENDED_A}', "");
Expect(1, 384, '\p{^	-Latin_EXTENDED_A}', "");
Expect(1, 384, '\P{	-Latin_EXTENDED_A}', "");
Expect(0, 384, '\P{^	-Latin_EXTENDED_A}', "");
Error('\p{  Is_LATIN_Extended_A/a/}');
Error('\P{  Is_LATIN_Extended_A/a/}');
Expect(1, 383, '\p{islatinextendeda}', "");
Expect(0, 383, '\p{^islatinextendeda}', "");
Expect(0, 383, '\P{islatinextendeda}', "");
Expect(1, 383, '\P{^islatinextendeda}', "");
Expect(0, 384, '\p{islatinextendeda}', "");
Expect(1, 384, '\p{^islatinextendeda}', "");
Expect(1, 384, '\P{islatinextendeda}', "");
Expect(0, 384, '\P{^islatinextendeda}', "");
Expect(1, 383, '\p{_is_Latin_EXTENDED_A}', "");
Expect(0, 383, '\p{^_is_Latin_EXTENDED_A}', "");
Expect(0, 383, '\P{_is_Latin_EXTENDED_A}', "");
Expect(1, 383, '\P{^_is_Latin_EXTENDED_A}', "");
Expect(0, 384, '\p{_is_Latin_EXTENDED_A}', "");
Expect(1, 384, '\p{^_is_Latin_EXTENDED_A}', "");
Expect(1, 384, '\P{_is_Latin_EXTENDED_A}', "");
Expect(0, 384, '\P{^_is_Latin_EXTENDED_A}', "");
Error('\p{	-in_Latin_Extended_a:=}');
Error('\P{	-in_Latin_Extended_a:=}');
Expect(1, 383, '\p{inlatinextendeda}', "");
Expect(0, 383, '\p{^inlatinextendeda}', "");
Expect(0, 383, '\P{inlatinextendeda}', "");
Expect(1, 383, '\P{^inlatinextendeda}', "");
Expect(0, 384, '\p{inlatinextendeda}', "");
Expect(1, 384, '\p{^inlatinextendeda}', "");
Expect(1, 384, '\P{inlatinextendeda}', "");
Expect(0, 384, '\P{^inlatinextendeda}', "");
Expect(1, 383, '\p{ In_latin_Extended_A}', "");
Expect(0, 383, '\p{^ In_latin_Extended_A}', "");
Expect(0, 383, '\P{ In_latin_Extended_A}', "");
Expect(1, 383, '\P{^ In_latin_Extended_A}', "");
Expect(0, 384, '\p{ In_latin_Extended_A}', "");
Expect(1, 384, '\p{^ In_latin_Extended_A}', "");
Expect(1, 384, '\P{ In_latin_Extended_A}', "");
Expect(0, 384, '\P{^ In_latin_Extended_A}', "");
Error('\p{/a/ 	Latin_ext_A}');
Error('\P{/a/ 	Latin_ext_A}');
Expect(1, 383, '\p{latinexta}', "");
Expect(0, 383, '\p{^latinexta}', "");
Expect(0, 383, '\P{latinexta}', "");
Expect(1, 383, '\P{^latinexta}', "");
Expect(0, 384, '\p{latinexta}', "");
Expect(1, 384, '\p{^latinexta}', "");
Expect(1, 384, '\P{latinexta}', "");
Expect(0, 384, '\P{^latinexta}', "");
Expect(1, 383, '\p{-_Latin_Ext_A}', "");
Expect(0, 383, '\p{^-_Latin_Ext_A}', "");
Expect(0, 383, '\P{-_Latin_Ext_A}', "");
Expect(1, 383, '\P{^-_Latin_Ext_A}', "");
Expect(0, 384, '\p{-_Latin_Ext_A}', "");
Expect(1, 384, '\p{^-_Latin_Ext_A}', "");
Expect(1, 384, '\P{-_Latin_Ext_A}', "");
Expect(0, 384, '\P{^-_Latin_Ext_A}', "");
Error('\p{:=is_Latin_Ext_a}');
Error('\P{:=is_Latin_Ext_a}');
Expect(1, 383, '\p{islatinexta}', "");
Expect(0, 383, '\p{^islatinexta}', "");
Expect(0, 383, '\P{islatinexta}', "");
Expect(1, 383, '\P{^islatinexta}', "");
Expect(0, 384, '\p{islatinexta}', "");
Expect(1, 384, '\p{^islatinexta}', "");
Expect(1, 384, '\P{islatinexta}', "");
Expect(0, 384, '\P{^islatinexta}', "");
Expect(1, 383, '\p{__Is_Latin_Ext_A}', "");
Expect(0, 383, '\p{^__Is_Latin_Ext_A}', "");
Expect(0, 383, '\P{__Is_Latin_Ext_A}', "");
Expect(1, 383, '\P{^__Is_Latin_Ext_A}', "");
Expect(0, 384, '\p{__Is_Latin_Ext_A}', "");
Expect(1, 384, '\p{^__Is_Latin_Ext_A}', "");
Expect(1, 384, '\P{__Is_Latin_Ext_A}', "");
Expect(0, 384, '\P{^__Is_Latin_Ext_A}', "");
Error('\p{-:=IN_latin_Ext_a}');
Error('\P{-:=IN_latin_Ext_a}');
Expect(1, 383, '\p{inlatinexta}', "");
Expect(0, 383, '\p{^inlatinexta}', "");
Expect(0, 383, '\P{inlatinexta}', "");
Expect(1, 383, '\P{^inlatinexta}', "");
Expect(0, 384, '\p{inlatinexta}', "");
Expect(1, 384, '\p{^inlatinexta}', "");
Expect(1, 384, '\P{inlatinexta}', "");
Expect(0, 384, '\P{^inlatinexta}', "");
Expect(1, 383, '\p{_in_Latin_ext_A}', "");
Expect(0, 383, '\p{^_in_Latin_ext_A}', "");
Expect(0, 383, '\P{_in_Latin_ext_A}', "");
Expect(1, 383, '\P{^_in_Latin_ext_A}', "");
Expect(0, 384, '\p{_in_Latin_ext_A}', "");
Expect(1, 384, '\p{^_in_Latin_ext_A}', "");
Expect(1, 384, '\P{_in_Latin_ext_A}', "");
Expect(0, 384, '\P{^_in_Latin_ext_A}', "");
Error('\p{	-LATIN_EXTENDED_additional/a/}');
Error('\P{	-LATIN_EXTENDED_additional/a/}');
Expect(1, 7935, '\p{latinextendedadditional}', "");
Expect(0, 7935, '\p{^latinextendedadditional}', "");
Expect(0, 7935, '\P{latinextendedadditional}', "");
Expect(1, 7935, '\P{^latinextendedadditional}', "");
Expect(0, 7936, '\p{latinextendedadditional}', "");
Expect(1, 7936, '\p{^latinextendedadditional}', "");
Expect(1, 7936, '\P{latinextendedadditional}', "");
Expect(0, 7936, '\P{^latinextendedadditional}', "");
Expect(1, 7935, '\p{	-Latin_Extended_ADDITIONAL}', "");
Expect(0, 7935, '\p{^	-Latin_Extended_ADDITIONAL}', "");
Expect(0, 7935, '\P{	-Latin_Extended_ADDITIONAL}', "");
Expect(1, 7935, '\P{^	-Latin_Extended_ADDITIONAL}', "");
Expect(0, 7936, '\p{	-Latin_Extended_ADDITIONAL}', "");
Expect(1, 7936, '\p{^	-Latin_Extended_ADDITIONAL}', "");
Expect(1, 7936, '\P{	-Latin_Extended_ADDITIONAL}', "");
Expect(0, 7936, '\P{^	-Latin_Extended_ADDITIONAL}', "");
Error('\p{_/a/Is_Latin_extended_Additional}');
Error('\P{_/a/Is_Latin_extended_Additional}');
Expect(1, 7935, '\p{islatinextendedadditional}', "");
Expect(0, 7935, '\p{^islatinextendedadditional}', "");
Expect(0, 7935, '\P{islatinextendedadditional}', "");
Expect(1, 7935, '\P{^islatinextendedadditional}', "");
Expect(0, 7936, '\p{islatinextendedadditional}', "");
Expect(1, 7936, '\p{^islatinextendedadditional}', "");
Expect(1, 7936, '\P{islatinextendedadditional}', "");
Expect(0, 7936, '\P{^islatinextendedadditional}', "");
Expect(1, 7935, '\p{	 IS_Latin_EXTENDED_additional}', "");
Expect(0, 7935, '\p{^	 IS_Latin_EXTENDED_additional}', "");
Expect(0, 7935, '\P{	 IS_Latin_EXTENDED_additional}', "");
Expect(1, 7935, '\P{^	 IS_Latin_EXTENDED_additional}', "");
Expect(0, 7936, '\p{	 IS_Latin_EXTENDED_additional}', "");
Expect(1, 7936, '\p{^	 IS_Latin_EXTENDED_additional}', "");
Expect(1, 7936, '\P{	 IS_Latin_EXTENDED_additional}', "");
Expect(0, 7936, '\P{^	 IS_Latin_EXTENDED_additional}', "");
Error('\p{ -IN_latin_Extended_ADDITIONAL:=}');
Error('\P{ -IN_latin_Extended_ADDITIONAL:=}');
Expect(1, 7935, '\p{inlatinextendedadditional}', "");
Expect(0, 7935, '\p{^inlatinextendedadditional}', "");
Expect(0, 7935, '\P{inlatinextendedadditional}', "");
Expect(1, 7935, '\P{^inlatinextendedadditional}', "");
Expect(0, 7936, '\p{inlatinextendedadditional}', "");
Expect(1, 7936, '\p{^inlatinextendedadditional}', "");
Expect(1, 7936, '\P{inlatinextendedadditional}', "");
Expect(0, 7936, '\P{^inlatinextendedadditional}', "");
Expect(1, 7935, '\p{--IN_Latin_Extended_Additional}', "");
Expect(0, 7935, '\p{^--IN_Latin_Extended_Additional}', "");
Expect(0, 7935, '\P{--IN_Latin_Extended_Additional}', "");
Expect(1, 7935, '\P{^--IN_Latin_Extended_Additional}', "");
Expect(0, 7936, '\p{--IN_Latin_Extended_Additional}', "");
Expect(1, 7936, '\p{^--IN_Latin_Extended_Additional}', "");
Expect(1, 7936, '\P{--IN_Latin_Extended_Additional}', "");
Expect(0, 7936, '\P{^--IN_Latin_Extended_Additional}', "");
Error('\p{-/a/LATIN_EXT_Additional}');
Error('\P{-/a/LATIN_EXT_Additional}');
Expect(1, 7935, '\p{latinextadditional}', "");
Expect(0, 7935, '\p{^latinextadditional}', "");
Expect(0, 7935, '\P{latinextadditional}', "");
Expect(1, 7935, '\P{^latinextadditional}', "");
Expect(0, 7936, '\p{latinextadditional}', "");
Expect(1, 7936, '\p{^latinextadditional}', "");
Expect(1, 7936, '\P{latinextadditional}', "");
Expect(0, 7936, '\P{^latinextadditional}', "");
Expect(1, 7935, '\p{	-Latin_ext_Additional}', "");
Expect(0, 7935, '\p{^	-Latin_ext_Additional}', "");
Expect(0, 7935, '\P{	-Latin_ext_Additional}', "");
Expect(1, 7935, '\P{^	-Latin_ext_Additional}', "");
Expect(0, 7936, '\p{	-Latin_ext_Additional}', "");
Expect(1, 7936, '\p{^	-Latin_ext_Additional}', "");
Expect(1, 7936, '\P{	-Latin_ext_Additional}', "");
Expect(0, 7936, '\P{^	-Latin_ext_Additional}', "");
Error('\p{/a/-is_latin_Ext_additional}');
Error('\P{/a/-is_latin_Ext_additional}');
Expect(1, 7935, '\p{islatinextadditional}', "");
Expect(0, 7935, '\p{^islatinextadditional}', "");
Expect(0, 7935, '\P{islatinextadditional}', "");
Expect(1, 7935, '\P{^islatinextadditional}', "");
Expect(0, 7936, '\p{islatinextadditional}', "");
Expect(1, 7936, '\p{^islatinextadditional}', "");
Expect(1, 7936, '\P{islatinextadditional}', "");
Expect(0, 7936, '\P{^islatinextadditional}', "");
Expect(1, 7935, '\p{	_Is_Latin_Ext_ADDITIONAL}', "");
Expect(0, 7935, '\p{^	_Is_Latin_Ext_ADDITIONAL}', "");
Expect(0, 7935, '\P{	_Is_Latin_Ext_ADDITIONAL}', "");
Expect(1, 7935, '\P{^	_Is_Latin_Ext_ADDITIONAL}', "");
Expect(0, 7936, '\p{	_Is_Latin_Ext_ADDITIONAL}', "");
Expect(1, 7936, '\p{^	_Is_Latin_Ext_ADDITIONAL}', "");
Expect(1, 7936, '\P{	_Is_Latin_Ext_ADDITIONAL}', "");
Expect(0, 7936, '\P{^	_Is_Latin_Ext_ADDITIONAL}', "");
Error('\p{ /a/In_LATIN_ext_ADDITIONAL}');
Error('\P{ /a/In_LATIN_ext_ADDITIONAL}');
Expect(1, 7935, '\p{inlatinextadditional}', "");
Expect(0, 7935, '\p{^inlatinextadditional}', "");
Expect(0, 7935, '\P{inlatinextadditional}', "");
Expect(1, 7935, '\P{^inlatinextadditional}', "");
Expect(0, 7936, '\p{inlatinextadditional}', "");
Expect(1, 7936, '\p{^inlatinextadditional}', "");
Expect(1, 7936, '\P{inlatinextadditional}', "");
Expect(0, 7936, '\P{^inlatinextadditional}', "");
Expect(1, 7935, '\p{		in_LATIN_Ext_Additional}', "");
Expect(0, 7935, '\p{^		in_LATIN_Ext_Additional}', "");
Expect(0, 7935, '\P{		in_LATIN_Ext_Additional}', "");
Expect(1, 7935, '\P{^		in_LATIN_Ext_Additional}', "");
Expect(0, 7936, '\p{		in_LATIN_Ext_Additional}', "");
Expect(1, 7936, '\p{^		in_LATIN_Ext_Additional}', "");
Expect(1, 7936, '\P{		in_LATIN_Ext_Additional}', "");
Expect(0, 7936, '\P{^		in_LATIN_Ext_Additional}', "");
Error('\p{:=-_Latin_Extended_B}');
Error('\P{:=-_Latin_Extended_B}');
Expect(1, 591, '\p{latinextendedb}', "");
Expect(0, 591, '\p{^latinextendedb}', "");
Expect(0, 591, '\P{latinextendedb}', "");
Expect(1, 591, '\P{^latinextendedb}', "");
Expect(0, 592, '\p{latinextendedb}', "");
Expect(1, 592, '\p{^latinextendedb}', "");
Expect(1, 592, '\P{latinextendedb}', "");
Expect(0, 592, '\P{^latinextendedb}', "");
Expect(1, 591, '\p{ -latin_EXTENDED_B}', "");
Expect(0, 591, '\p{^ -latin_EXTENDED_B}', "");
Expect(0, 591, '\P{ -latin_EXTENDED_B}', "");
Expect(1, 591, '\P{^ -latin_EXTENDED_B}', "");
Expect(0, 592, '\p{ -latin_EXTENDED_B}', "");
Expect(1, 592, '\p{^ -latin_EXTENDED_B}', "");
Expect(1, 592, '\P{ -latin_EXTENDED_B}', "");
Expect(0, 592, '\P{^ -latin_EXTENDED_B}', "");
Error('\p{:=  Is_LATIN_Extended_B}');
Error('\P{:=  Is_LATIN_Extended_B}');
Expect(1, 591, '\p{islatinextendedb}', "");
Expect(0, 591, '\p{^islatinextendedb}', "");
Expect(0, 591, '\P{islatinextendedb}', "");
Expect(1, 591, '\P{^islatinextendedb}', "");
Expect(0, 592, '\p{islatinextendedb}', "");
Expect(1, 592, '\p{^islatinextendedb}', "");
Expect(1, 592, '\P{islatinextendedb}', "");
Expect(0, 592, '\P{^islatinextendedb}', "");
Expect(1, 591, '\p{	_Is_Latin_EXTENDED_B}', "");
Expect(0, 591, '\p{^	_Is_Latin_EXTENDED_B}', "");
Expect(0, 591, '\P{	_Is_Latin_EXTENDED_B}', "");
Expect(1, 591, '\P{^	_Is_Latin_EXTENDED_B}', "");
Expect(0, 592, '\p{	_Is_Latin_EXTENDED_B}', "");
Expect(1, 592, '\p{^	_Is_Latin_EXTENDED_B}', "");
Expect(1, 592, '\P{	_Is_Latin_EXTENDED_B}', "");
Expect(0, 592, '\P{^	_Is_Latin_EXTENDED_B}', "");
Error('\p{/a/	-In_Latin_EXTENDED_B}');
Error('\P{/a/	-In_Latin_EXTENDED_B}');
Expect(1, 591, '\p{inlatinextendedb}', "");
Expect(0, 591, '\p{^inlatinextendedb}', "");
Expect(0, 591, '\P{inlatinextendedb}', "");
Expect(1, 591, '\P{^inlatinextendedb}', "");
Expect(0, 592, '\p{inlatinextendedb}', "");
Expect(1, 592, '\p{^inlatinextendedb}', "");
Expect(1, 592, '\P{inlatinextendedb}', "");
Expect(0, 592, '\P{^inlatinextendedb}', "");
Expect(1, 591, '\p{ -in_latin_extended_b}', "");
Expect(0, 591, '\p{^ -in_latin_extended_b}', "");
Expect(0, 591, '\P{ -in_latin_extended_b}', "");
Expect(1, 591, '\P{^ -in_latin_extended_b}', "");
Expect(0, 592, '\p{ -in_latin_extended_b}', "");
Expect(1, 592, '\p{^ -in_latin_extended_b}', "");
Expect(1, 592, '\P{ -in_latin_extended_b}', "");
Expect(0, 592, '\P{^ -in_latin_extended_b}', "");
Error('\p{_/a/Latin_Ext_b}');
Error('\P{_/a/Latin_Ext_b}');
Expect(1, 591, '\p{latinextb}', "");
Expect(0, 591, '\p{^latinextb}', "");
Expect(0, 591, '\P{latinextb}', "");
Expect(1, 591, '\P{^latinextb}', "");
Expect(0, 592, '\p{latinextb}', "");
Expect(1, 592, '\p{^latinextb}', "");
Expect(1, 592, '\P{latinextb}', "");
Expect(0, 592, '\P{^latinextb}', "");
Expect(1, 591, '\p{	_Latin_Ext_b}', "");
Expect(0, 591, '\p{^	_Latin_Ext_b}', "");
Expect(0, 591, '\P{	_Latin_Ext_b}', "");
Expect(1, 591, '\P{^	_Latin_Ext_b}', "");
Expect(0, 592, '\p{	_Latin_Ext_b}', "");
Expect(1, 592, '\p{^	_Latin_Ext_b}', "");
Expect(1, 592, '\P{	_Latin_Ext_b}', "");
Expect(0, 592, '\P{^	_Latin_Ext_b}', "");
Error('\p{:=- Is_Latin_Ext_b}');
Error('\P{:=- Is_Latin_Ext_b}');
Expect(1, 591, '\p{islatinextb}', "");
Expect(0, 591, '\p{^islatinextb}', "");
Expect(0, 591, '\P{islatinextb}', "");
Expect(1, 591, '\P{^islatinextb}', "");
Expect(0, 592, '\p{islatinextb}', "");
Expect(1, 592, '\p{^islatinextb}', "");
Expect(1, 592, '\P{islatinextb}', "");
Expect(0, 592, '\P{^islatinextb}', "");
Expect(1, 591, '\p{ -is_LATIN_Ext_b}', "");
Expect(0, 591, '\p{^ -is_LATIN_Ext_b}', "");
Expect(0, 591, '\P{ -is_LATIN_Ext_b}', "");
Expect(1, 591, '\P{^ -is_LATIN_Ext_b}', "");
Expect(0, 592, '\p{ -is_LATIN_Ext_b}', "");
Expect(1, 592, '\p{^ -is_LATIN_Ext_b}', "");
Expect(1, 592, '\P{ -is_LATIN_Ext_b}', "");
Expect(0, 592, '\P{^ -is_LATIN_Ext_b}', "");
Error('\p{/a/		in_latin_Ext_B}');
Error('\P{/a/		in_latin_Ext_B}');
Expect(1, 591, '\p{inlatinextb}', "");
Expect(0, 591, '\p{^inlatinextb}', "");
Expect(0, 591, '\P{inlatinextb}', "");
Expect(1, 591, '\P{^inlatinextb}', "");
Expect(0, 592, '\p{inlatinextb}', "");
Expect(1, 592, '\p{^inlatinextb}', "");
Expect(1, 592, '\P{inlatinextb}', "");
Expect(0, 592, '\P{^inlatinextb}', "");
Expect(1, 591, '\p{ -in_Latin_Ext_B}', "");
Expect(0, 591, '\p{^ -in_Latin_Ext_B}', "");
Expect(0, 591, '\P{ -in_Latin_Ext_B}', "");
Expect(1, 591, '\P{^ -in_Latin_Ext_B}', "");
Expect(0, 592, '\p{ -in_Latin_Ext_B}', "");
Expect(1, 592, '\p{^ -in_Latin_Ext_B}', "");
Expect(1, 592, '\P{ -in_Latin_Ext_B}', "");
Expect(0, 592, '\P{^ -in_Latin_Ext_B}', "");
Error('\p{-:=Latin_Extended_c}');
Error('\P{-:=Latin_Extended_c}');
Expect(1, 11391, '\p{latinextendedc}', "");
Expect(0, 11391, '\p{^latinextendedc}', "");
Expect(0, 11391, '\P{latinextendedc}', "");
Expect(1, 11391, '\P{^latinextendedc}', "");
Expect(0, 11392, '\p{latinextendedc}', "");
Expect(1, 11392, '\p{^latinextendedc}', "");
Expect(1, 11392, '\P{latinextendedc}', "");
Expect(0, 11392, '\P{^latinextendedc}', "");
Expect(1, 11391, '\p{	 LATIN_Extended_C}', "");
Expect(0, 11391, '\p{^	 LATIN_Extended_C}', "");
Expect(0, 11391, '\P{	 LATIN_Extended_C}', "");
Expect(1, 11391, '\P{^	 LATIN_Extended_C}', "");
Expect(0, 11392, '\p{	 LATIN_Extended_C}', "");
Expect(1, 11392, '\p{^	 LATIN_Extended_C}', "");
Expect(1, 11392, '\P{	 LATIN_Extended_C}', "");
Expect(0, 11392, '\P{^	 LATIN_Extended_C}', "");
Error('\p{/a/_ IS_Latin_Extended_C}');
Error('\P{/a/_ IS_Latin_Extended_C}');
Expect(1, 11391, '\p{islatinextendedc}', "");
Expect(0, 11391, '\p{^islatinextendedc}', "");
Expect(0, 11391, '\P{islatinextendedc}', "");
Expect(1, 11391, '\P{^islatinextendedc}', "");
Expect(0, 11392, '\p{islatinextendedc}', "");
Expect(1, 11392, '\p{^islatinextendedc}', "");
Expect(1, 11392, '\P{islatinextendedc}', "");
Expect(0, 11392, '\P{^islatinextendedc}', "");
Expect(1, 11391, '\p{ _Is_Latin_Extended_C}', "");
Expect(0, 11391, '\p{^ _Is_Latin_Extended_C}', "");
Expect(0, 11391, '\P{ _Is_Latin_Extended_C}', "");
Expect(1, 11391, '\P{^ _Is_Latin_Extended_C}', "");
Expect(0, 11392, '\p{ _Is_Latin_Extended_C}', "");
Expect(1, 11392, '\p{^ _Is_Latin_Extended_C}', "");
Expect(1, 11392, '\P{ _Is_Latin_Extended_C}', "");
Expect(0, 11392, '\P{^ _Is_Latin_Extended_C}', "");
Error('\p{_In_Latin_extended_C:=}');
Error('\P{_In_Latin_extended_C:=}');
Expect(1, 11391, '\p{inlatinextendedc}', "");
Expect(0, 11391, '\p{^inlatinextendedc}', "");
Expect(0, 11391, '\P{inlatinextendedc}', "");
Expect(1, 11391, '\P{^inlatinextendedc}', "");
Expect(0, 11392, '\p{inlatinextendedc}', "");
Expect(1, 11392, '\p{^inlatinextendedc}', "");
Expect(1, 11392, '\P{inlatinextendedc}', "");
Expect(0, 11392, '\P{^inlatinextendedc}', "");
Expect(1, 11391, '\p{__IN_latin_EXTENDED_C}', "");
Expect(0, 11391, '\p{^__IN_latin_EXTENDED_C}', "");
Expect(0, 11391, '\P{__IN_latin_EXTENDED_C}', "");
Expect(1, 11391, '\P{^__IN_latin_EXTENDED_C}', "");
Expect(0, 11392, '\p{__IN_latin_EXTENDED_C}', "");
Expect(1, 11392, '\p{^__IN_latin_EXTENDED_C}', "");
Expect(1, 11392, '\P{__IN_latin_EXTENDED_C}', "");
Expect(0, 11392, '\P{^__IN_latin_EXTENDED_C}', "");
Error('\p{-/a/Latin_EXT_C}');
Error('\P{-/a/Latin_EXT_C}');
Expect(1, 11391, '\p{latinextc}', "");
Expect(0, 11391, '\p{^latinextc}', "");
Expect(0, 11391, '\P{latinextc}', "");
Expect(1, 11391, '\P{^latinextc}', "");
Expect(0, 11392, '\p{latinextc}', "");
Expect(1, 11392, '\p{^latinextc}', "");
Expect(1, 11392, '\P{latinextc}', "");
Expect(0, 11392, '\P{^latinextc}', "");
Expect(1, 11391, '\p{_Latin_EXT_c}', "");
Expect(0, 11391, '\p{^_Latin_EXT_c}', "");
Expect(0, 11391, '\P{_Latin_EXT_c}', "");
Expect(1, 11391, '\P{^_Latin_EXT_c}', "");
Expect(0, 11392, '\p{_Latin_EXT_c}', "");
Expect(1, 11392, '\p{^_Latin_EXT_c}', "");
Expect(1, 11392, '\P{_Latin_EXT_c}', "");
Expect(0, 11392, '\P{^_Latin_EXT_c}', "");
Error('\p{/a/ _Is_Latin_Ext_c}');
Error('\P{/a/ _Is_Latin_Ext_c}');
Expect(1, 11391, '\p{islatinextc}', "");
Expect(0, 11391, '\p{^islatinextc}', "");
Expect(0, 11391, '\P{islatinextc}', "");
Expect(1, 11391, '\P{^islatinextc}', "");
Expect(0, 11392, '\p{islatinextc}', "");
Expect(1, 11392, '\p{^islatinextc}', "");
Expect(1, 11392, '\P{islatinextc}', "");
Expect(0, 11392, '\P{^islatinextc}', "");
Expect(1, 11391, '\p{-_Is_Latin_Ext_C}', "");
Expect(0, 11391, '\p{^-_Is_Latin_Ext_C}', "");
Expect(0, 11391, '\P{-_Is_Latin_Ext_C}', "");
Expect(1, 11391, '\P{^-_Is_Latin_Ext_C}', "");
Expect(0, 11392, '\p{-_Is_Latin_Ext_C}', "");
Expect(1, 11392, '\p{^-_Is_Latin_Ext_C}', "");
Expect(1, 11392, '\P{-_Is_Latin_Ext_C}', "");
Expect(0, 11392, '\P{^-_Is_Latin_Ext_C}', "");
Error('\p{ :=In_Latin_EXT_C}');
Error('\P{ :=In_Latin_EXT_C}');
Expect(1, 11391, '\p{inlatinextc}', "");
Expect(0, 11391, '\p{^inlatinextc}', "");
Expect(0, 11391, '\P{inlatinextc}', "");
Expect(1, 11391, '\P{^inlatinextc}', "");
Expect(0, 11392, '\p{inlatinextc}', "");
Expect(1, 11392, '\p{^inlatinextc}', "");
Expect(1, 11392, '\P{inlatinextc}', "");
Expect(0, 11392, '\P{^inlatinextc}', "");
Expect(1, 11391, '\p{	in_Latin_EXT_C}', "");
Expect(0, 11391, '\p{^	in_Latin_EXT_C}', "");
Expect(0, 11391, '\P{	in_Latin_EXT_C}', "");
Expect(1, 11391, '\P{^	in_Latin_EXT_C}', "");
Expect(0, 11392, '\p{	in_Latin_EXT_C}', "");
Expect(1, 11392, '\p{^	in_Latin_EXT_C}', "");
Expect(1, 11392, '\P{	in_Latin_EXT_C}', "");
Expect(0, 11392, '\P{^	in_Latin_EXT_C}', "");
Error('\p{-:=LATIN_Extended_D}');
Error('\P{-:=LATIN_Extended_D}');
Expect(1, 43007, '\p{latinextendedd}', "");
Expect(0, 43007, '\p{^latinextendedd}', "");
Expect(0, 43007, '\P{latinextendedd}', "");
Expect(1, 43007, '\P{^latinextendedd}', "");
Expect(0, 43008, '\p{latinextendedd}', "");
Expect(1, 43008, '\p{^latinextendedd}', "");
Expect(1, 43008, '\P{latinextendedd}', "");
Expect(0, 43008, '\P{^latinextendedd}', "");
Expect(1, 43007, '\p{-_latin_Extended_D}', "");
Expect(0, 43007, '\p{^-_latin_Extended_D}', "");
Expect(0, 43007, '\P{-_latin_Extended_D}', "");
Expect(1, 43007, '\P{^-_latin_Extended_D}', "");
Expect(0, 43008, '\p{-_latin_Extended_D}', "");
Expect(1, 43008, '\p{^-_latin_Extended_D}', "");
Expect(1, 43008, '\P{-_latin_Extended_D}', "");
Expect(0, 43008, '\P{^-_latin_Extended_D}', "");
Error('\p{-:=is_latin_extended_D}');
Error('\P{-:=is_latin_extended_D}');
Expect(1, 43007, '\p{islatinextendedd}', "");
Expect(0, 43007, '\p{^islatinextendedd}', "");
Expect(0, 43007, '\P{islatinextendedd}', "");
Expect(1, 43007, '\P{^islatinextendedd}', "");
Expect(0, 43008, '\p{islatinextendedd}', "");
Expect(1, 43008, '\p{^islatinextendedd}', "");
Expect(1, 43008, '\P{islatinextendedd}', "");
Expect(0, 43008, '\P{^islatinextendedd}', "");
Expect(1, 43007, '\p{-IS_Latin_Extended_D}', "");
Expect(0, 43007, '\p{^-IS_Latin_Extended_D}', "");
Expect(0, 43007, '\P{-IS_Latin_Extended_D}', "");
Expect(1, 43007, '\P{^-IS_Latin_Extended_D}', "");
Expect(0, 43008, '\p{-IS_Latin_Extended_D}', "");
Expect(1, 43008, '\p{^-IS_Latin_Extended_D}', "");
Expect(1, 43008, '\P{-IS_Latin_Extended_D}', "");
Expect(0, 43008, '\P{^-IS_Latin_Extended_D}', "");
Error('\p{ :=IN_LATIN_Extended_D}');
Error('\P{ :=IN_LATIN_Extended_D}');
Expect(1, 43007, '\p{inlatinextendedd}', "");
Expect(0, 43007, '\p{^inlatinextendedd}', "");
Expect(0, 43007, '\P{inlatinextendedd}', "");
Expect(1, 43007, '\P{^inlatinextendedd}', "");
Expect(0, 43008, '\p{inlatinextendedd}', "");
Expect(1, 43008, '\p{^inlatinextendedd}', "");
Expect(1, 43008, '\P{inlatinextendedd}', "");
Expect(0, 43008, '\P{^inlatinextendedd}', "");
Expect(1, 43007, '\p{-In_Latin_extended_D}', "");
Expect(0, 43007, '\p{^-In_Latin_extended_D}', "");
Expect(0, 43007, '\P{-In_Latin_extended_D}', "");
Expect(1, 43007, '\P{^-In_Latin_extended_D}', "");
Expect(0, 43008, '\p{-In_Latin_extended_D}', "");
Expect(1, 43008, '\p{^-In_Latin_extended_D}', "");
Expect(1, 43008, '\P{-In_Latin_extended_D}', "");
Expect(0, 43008, '\P{^-In_Latin_extended_D}', "");
Error('\p{/a/ Latin_ext_d}');
Error('\P{/a/ Latin_ext_d}');
Expect(1, 43007, '\p{latinextd}', "");
Expect(0, 43007, '\p{^latinextd}', "");
Expect(0, 43007, '\P{latinextd}', "");
Expect(1, 43007, '\P{^latinextd}', "");
Expect(0, 43008, '\p{latinextd}', "");
Expect(1, 43008, '\p{^latinextd}', "");
Expect(1, 43008, '\P{latinextd}', "");
Expect(0, 43008, '\P{^latinextd}', "");
Expect(1, 43007, '\p{_ Latin_ext_D}', "");
Expect(0, 43007, '\p{^_ Latin_ext_D}', "");
Expect(0, 43007, '\P{_ Latin_ext_D}', "");
Expect(1, 43007, '\P{^_ Latin_ext_D}', "");
Expect(0, 43008, '\p{_ Latin_ext_D}', "");
Expect(1, 43008, '\p{^_ Latin_ext_D}', "");
Expect(1, 43008, '\P{_ Latin_ext_D}', "");
Expect(0, 43008, '\P{^_ Latin_ext_D}', "");
Error('\p{/a/	 Is_Latin_EXT_D}');
Error('\P{/a/	 Is_Latin_EXT_D}');
Expect(1, 43007, '\p{islatinextd}', "");
Expect(0, 43007, '\p{^islatinextd}', "");
Expect(0, 43007, '\P{islatinextd}', "");
Expect(1, 43007, '\P{^islatinextd}', "");
Expect(0, 43008, '\p{islatinextd}', "");
Expect(1, 43008, '\p{^islatinextd}', "");
Expect(1, 43008, '\P{islatinextd}', "");
Expect(0, 43008, '\P{^islatinextd}', "");
Expect(1, 43007, '\p{_IS_LATIN_Ext_D}', "");
Expect(0, 43007, '\p{^_IS_LATIN_Ext_D}', "");
Expect(0, 43007, '\P{_IS_LATIN_Ext_D}', "");
Expect(1, 43007, '\P{^_IS_LATIN_Ext_D}', "");
Expect(0, 43008, '\p{_IS_LATIN_Ext_D}', "");
Expect(1, 43008, '\p{^_IS_LATIN_Ext_D}', "");
Expect(1, 43008, '\P{_IS_LATIN_Ext_D}', "");
Expect(0, 43008, '\P{^_IS_LATIN_Ext_D}', "");
Error('\p{:=-In_latin_ext_D}');
Error('\P{:=-In_latin_ext_D}');
Expect(1, 43007, '\p{inlatinextd}', "");
Expect(0, 43007, '\p{^inlatinextd}', "");
Expect(0, 43007, '\P{inlatinextd}', "");
Expect(1, 43007, '\P{^inlatinextd}', "");
Expect(0, 43008, '\p{inlatinextd}', "");
Expect(1, 43008, '\p{^inlatinextd}', "");
Expect(1, 43008, '\P{inlatinextd}', "");
Expect(0, 43008, '\P{^inlatinextd}', "");
Expect(1, 43007, '\p{	-in_Latin_EXT_D}', "");
Expect(0, 43007, '\p{^	-in_Latin_EXT_D}', "");
Expect(0, 43007, '\P{	-in_Latin_EXT_D}', "");
Expect(1, 43007, '\P{^	-in_Latin_EXT_D}', "");
Expect(0, 43008, '\p{	-in_Latin_EXT_D}', "");
Expect(1, 43008, '\p{^	-in_Latin_EXT_D}', "");
Expect(1, 43008, '\P{	-in_Latin_EXT_D}', "");
Expect(0, 43008, '\P{^	-in_Latin_EXT_D}', "");
Error('\p{	lepcha/a/}');
Error('\P{	lepcha/a/}');
Expect(1, 7247, '\p{lepcha}', "");
Expect(0, 7247, '\p{^lepcha}', "");
Expect(0, 7247, '\P{lepcha}', "");
Expect(1, 7247, '\P{^lepcha}', "");
Expect(0, 7248, '\p{lepcha}', "");
Expect(1, 7248, '\p{^lepcha}', "");
Expect(1, 7248, '\P{lepcha}', "");
Expect(0, 7248, '\P{^lepcha}', "");
Expect(1, 7247, '\p{_Lepcha}', "");
Expect(0, 7247, '\p{^_Lepcha}', "");
Expect(0, 7247, '\P{_Lepcha}', "");
Expect(1, 7247, '\P{^_Lepcha}', "");
Expect(0, 7248, '\p{_Lepcha}', "");
Expect(1, 7248, '\p{^_Lepcha}', "");
Expect(1, 7248, '\P{_Lepcha}', "");
Expect(0, 7248, '\P{^_Lepcha}', "");
Error('\p{	_Is_lepcha:=}');
Error('\P{	_Is_lepcha:=}');
Expect(1, 7247, '\p{islepcha}', "");
Expect(0, 7247, '\p{^islepcha}', "");
Expect(0, 7247, '\P{islepcha}', "");
Expect(1, 7247, '\P{^islepcha}', "");
Expect(0, 7248, '\p{islepcha}', "");
Expect(1, 7248, '\p{^islepcha}', "");
Expect(1, 7248, '\P{islepcha}', "");
Expect(0, 7248, '\P{^islepcha}', "");
Expect(1, 7247, '\p{-IS_LEPCHA}', "");
Expect(0, 7247, '\p{^-IS_LEPCHA}', "");
Expect(0, 7247, '\P{-IS_LEPCHA}', "");
Expect(1, 7247, '\P{^-IS_LEPCHA}', "");
Expect(0, 7248, '\p{-IS_LEPCHA}', "");
Expect(1, 7248, '\p{^-IS_LEPCHA}', "");
Expect(1, 7248, '\P{-IS_LEPCHA}', "");
Expect(0, 7248, '\P{^-IS_LEPCHA}', "");
Error('\p{/a/_	Lepc}');
Error('\P{/a/_	Lepc}');
Expect(1, 7247, '\p{lepc}', "");
Expect(0, 7247, '\p{^lepc}', "");
Expect(0, 7247, '\P{lepc}', "");
Expect(1, 7247, '\P{^lepc}', "");
Expect(0, 7248, '\p{lepc}', "");
Expect(1, 7248, '\p{^lepc}', "");
Expect(1, 7248, '\P{lepc}', "");
Expect(0, 7248, '\P{^lepc}', "");
Expect(1, 7247, '\p{  Lepc}', "");
Expect(0, 7247, '\p{^  Lepc}', "");
Expect(0, 7247, '\P{  Lepc}', "");
Expect(1, 7247, '\P{^  Lepc}', "");
Expect(0, 7248, '\p{  Lepc}', "");
Expect(1, 7248, '\p{^  Lepc}', "");
Expect(1, 7248, '\P{  Lepc}', "");
Expect(0, 7248, '\P{^  Lepc}', "");
Error('\p{_-IS_Lepc:=}');
Error('\P{_-IS_Lepc:=}');
Expect(1, 7247, '\p{islepc}', "");
Expect(0, 7247, '\p{^islepc}', "");
Expect(0, 7247, '\P{islepc}', "");
Expect(1, 7247, '\P{^islepc}', "");
Expect(0, 7248, '\p{islepc}', "");
Expect(1, 7248, '\p{^islepc}', "");
Expect(1, 7248, '\P{islepc}', "");
Expect(0, 7248, '\P{^islepc}', "");
Expect(1, 7247, '\p{ IS_lepc}', "");
Expect(0, 7247, '\p{^ IS_lepc}', "");
Expect(0, 7247, '\P{ IS_lepc}', "");
Expect(1, 7247, '\P{^ IS_lepc}', "");
Expect(0, 7248, '\p{ IS_lepc}', "");
Expect(1, 7248, '\p{^ IS_lepc}', "");
Expect(1, 7248, '\P{ IS_lepc}', "");
Expect(0, 7248, '\P{^ IS_lepc}', "");
Error('\p{- Letter/a/}');
Error('\P{- Letter/a/}');
Expect(1, 195101, '\p{letter}', "");
Expect(0, 195101, '\p{^letter}', "");
Expect(0, 195101, '\P{letter}', "");
Expect(1, 195101, '\P{^letter}', "");
Expect(0, 195102, '\p{letter}', "");
Expect(1, 195102, '\p{^letter}', "");
Expect(1, 195102, '\P{letter}', "");
Expect(0, 195102, '\P{^letter}', "");
Expect(1, 195101, '\p{_LETTER}', "");
Expect(0, 195101, '\p{^_LETTER}', "");
Expect(0, 195101, '\P{_LETTER}', "");
Expect(1, 195101, '\P{^_LETTER}', "");
Expect(0, 195102, '\p{_LETTER}', "");
Expect(1, 195102, '\p{^_LETTER}', "");
Expect(1, 195102, '\P{_LETTER}', "");
Expect(0, 195102, '\P{^_LETTER}', "");
Error('\p{ Is_letter/a/}');
Error('\P{ Is_letter/a/}');
Expect(1, 195101, '\p{isletter}', "");
Expect(0, 195101, '\p{^isletter}', "");
Expect(0, 195101, '\P{isletter}', "");
Expect(1, 195101, '\P{^isletter}', "");
Expect(0, 195102, '\p{isletter}', "");
Expect(1, 195102, '\p{^isletter}', "");
Expect(1, 195102, '\P{isletter}', "");
Expect(0, 195102, '\P{^isletter}', "");
Expect(1, 195101, '\p{_ Is_Letter}', "");
Expect(0, 195101, '\p{^_ Is_Letter}', "");
Expect(0, 195101, '\P{_ Is_Letter}', "");
Expect(1, 195101, '\P{^_ Is_Letter}', "");
Expect(0, 195102, '\p{_ Is_Letter}', "");
Expect(1, 195102, '\p{^_ Is_Letter}', "");
Expect(1, 195102, '\P{_ Is_Letter}', "");
Expect(0, 195102, '\P{^_ Is_Letter}', "");
Error('\p{ 	L:=}');
Error('\P{ 	L:=}');
Expect(1, 195101, '\p{l}', "");
Expect(0, 195101, '\p{^l}', "");
Expect(0, 195101, '\P{l}', "");
Expect(1, 195101, '\P{^l}', "");
Expect(0, 195102, '\p{l}', "");
Expect(1, 195102, '\p{^l}', "");
Expect(1, 195102, '\P{l}', "");
Expect(0, 195102, '\P{^l}', "");
Expect(1, 195101, '\p{_l}', "");
Expect(0, 195101, '\p{^_l}', "");
Expect(0, 195101, '\P{_l}', "");
Expect(1, 195101, '\P{^_l}', "");
Expect(0, 195102, '\p{_l}', "");
Expect(1, 195102, '\p{^_l}', "");
Expect(1, 195102, '\P{_l}', "");
Expect(0, 195102, '\P{^_l}', "");
Error('\p{ Is_l:=}');
Error('\P{ Is_l:=}');
Expect(1, 195101, '\p{isl}', "");
Expect(0, 195101, '\p{^isl}', "");
Expect(0, 195101, '\P{isl}', "");
Expect(1, 195101, '\P{^isl}', "");
Expect(0, 195102, '\p{isl}', "");
Expect(1, 195102, '\p{^isl}', "");
Expect(1, 195102, '\P{isl}', "");
Expect(0, 195102, '\P{^isl}', "");
Expect(1, 195101, '\p{ _IS_l}', "");
Expect(0, 195101, '\p{^ _IS_l}', "");
Expect(0, 195101, '\P{ _IS_l}', "");
Expect(1, 195101, '\P{^ _IS_l}', "");
Expect(0, 195102, '\p{ _IS_l}', "");
Expect(1, 195102, '\p{^ _IS_l}', "");
Expect(1, 195102, '\P{ _IS_l}', "");
Expect(0, 195102, '\P{^ _IS_l}', "");
Error('\p{	-letter_number:=}');
Error('\P{	-letter_number:=}');
Expect(1, 74850, '\p{letternumber}', "");
Expect(0, 74850, '\p{^letternumber}', "");
Expect(0, 74850, '\P{letternumber}', "");
Expect(1, 74850, '\P{^letternumber}', "");
Expect(0, 74851, '\p{letternumber}', "");
Expect(1, 74851, '\p{^letternumber}', "");
Expect(1, 74851, '\P{letternumber}', "");
Expect(0, 74851, '\P{^letternumber}', "");
Expect(1, 74850, '\p{ _Letter_Number}', "");
Expect(0, 74850, '\p{^ _Letter_Number}', "");
Expect(0, 74850, '\P{ _Letter_Number}', "");
Expect(1, 74850, '\P{^ _Letter_Number}', "");
Expect(0, 74851, '\p{ _Letter_Number}', "");
Expect(1, 74851, '\p{^ _Letter_Number}', "");
Expect(1, 74851, '\P{ _Letter_Number}', "");
Expect(0, 74851, '\P{^ _Letter_Number}', "");
Error('\p{_/a/Is_letter_NUMBER}');
Error('\P{_/a/Is_letter_NUMBER}');
Expect(1, 74850, '\p{isletternumber}', "");
Expect(0, 74850, '\p{^isletternumber}', "");
Expect(0, 74850, '\P{isletternumber}', "");
Expect(1, 74850, '\P{^isletternumber}', "");
Expect(0, 74851, '\p{isletternumber}', "");
Expect(1, 74851, '\p{^isletternumber}', "");
Expect(1, 74851, '\P{isletternumber}', "");
Expect(0, 74851, '\P{^isletternumber}', "");
Expect(1, 74850, '\p{-Is_letter_NUMBER}', "");
Expect(0, 74850, '\p{^-Is_letter_NUMBER}', "");
Expect(0, 74850, '\P{-Is_letter_NUMBER}', "");
Expect(1, 74850, '\P{^-Is_letter_NUMBER}', "");
Expect(0, 74851, '\p{-Is_letter_NUMBER}', "");
Expect(1, 74851, '\p{^-Is_letter_NUMBER}', "");
Expect(1, 74851, '\P{-Is_letter_NUMBER}', "");
Expect(0, 74851, '\P{^-Is_letter_NUMBER}', "");
Error('\p{:=		nl}');
Error('\P{:=		nl}');
Expect(1, 74850, '\p{nl}', "");
Expect(0, 74850, '\p{^nl}', "");
Expect(0, 74850, '\P{nl}', "");
Expect(1, 74850, '\P{^nl}', "");
Expect(0, 74851, '\p{nl}', "");
Expect(1, 74851, '\p{^nl}', "");
Expect(1, 74851, '\P{nl}', "");
Expect(0, 74851, '\P{^nl}', "");
Expect(1, 74850, '\p{  Nl}', "");
Expect(0, 74850, '\p{^  Nl}', "");
Expect(0, 74850, '\P{  Nl}', "");
Expect(1, 74850, '\P{^  Nl}', "");
Expect(0, 74851, '\p{  Nl}', "");
Expect(1, 74851, '\p{^  Nl}', "");
Expect(1, 74851, '\P{  Nl}', "");
Expect(0, 74851, '\P{^  Nl}', "");
Error('\p{/a/IS_nl}');
Error('\P{/a/IS_nl}');
Expect(1, 74850, '\p{isnl}', "");
Expect(0, 74850, '\p{^isnl}', "");
Expect(0, 74850, '\P{isnl}', "");
Expect(1, 74850, '\P{^isnl}', "");
Expect(0, 74851, '\p{isnl}', "");
Expect(1, 74851, '\p{^isnl}', "");
Expect(1, 74851, '\P{isnl}', "");
Expect(0, 74851, '\P{^isnl}', "");
Expect(1, 74850, '\p{-Is_Nl}', "");
Expect(0, 74850, '\p{^-Is_Nl}', "");
Expect(0, 74850, '\P{-Is_Nl}', "");
Expect(1, 74850, '\P{^-Is_Nl}', "");
Expect(0, 74851, '\p{-Is_Nl}', "");
Expect(1, 74851, '\p{^-Is_Nl}', "");
Expect(1, 74851, '\P{-Is_Nl}', "");
Expect(0, 74851, '\P{^-Is_Nl}', "");
Error('\p{:=	 Letterlike_Symbols}');
Error('\P{:=	 Letterlike_Symbols}');
Expect(1, 8527, '\p{letterlikesymbols}', "");
Expect(0, 8527, '\p{^letterlikesymbols}', "");
Expect(0, 8527, '\P{letterlikesymbols}', "");
Expect(1, 8527, '\P{^letterlikesymbols}', "");
Expect(0, 8528, '\p{letterlikesymbols}', "");
Expect(1, 8528, '\p{^letterlikesymbols}', "");
Expect(1, 8528, '\P{letterlikesymbols}', "");
Expect(0, 8528, '\P{^letterlikesymbols}', "");
Expect(1, 8527, '\p{  LETTERLIKE_Symbols}', "");
Expect(0, 8527, '\p{^  LETTERLIKE_Symbols}', "");
Expect(0, 8527, '\P{  LETTERLIKE_Symbols}', "");
Expect(1, 8527, '\P{^  LETTERLIKE_Symbols}', "");
Expect(0, 8528, '\p{  LETTERLIKE_Symbols}', "");
Expect(1, 8528, '\p{^  LETTERLIKE_Symbols}', "");
Expect(1, 8528, '\P{  LETTERLIKE_Symbols}', "");
Expect(0, 8528, '\P{^  LETTERLIKE_Symbols}', "");
Error('\p{:=  is_Letterlike_Symbols}');
Error('\P{:=  is_Letterlike_Symbols}');
Expect(1, 8527, '\p{isletterlikesymbols}', "");
Expect(0, 8527, '\p{^isletterlikesymbols}', "");
Expect(0, 8527, '\P{isletterlikesymbols}', "");
Expect(1, 8527, '\P{^isletterlikesymbols}', "");
Expect(0, 8528, '\p{isletterlikesymbols}', "");
Expect(1, 8528, '\p{^isletterlikesymbols}', "");
Expect(1, 8528, '\P{isletterlikesymbols}', "");
Expect(0, 8528, '\P{^isletterlikesymbols}', "");
Expect(1, 8527, '\p{_Is_Letterlike_Symbols}', "");
Expect(0, 8527, '\p{^_Is_Letterlike_Symbols}', "");
Expect(0, 8527, '\P{_Is_Letterlike_Symbols}', "");
Expect(1, 8527, '\P{^_Is_Letterlike_Symbols}', "");
Expect(0, 8528, '\p{_Is_Letterlike_Symbols}', "");
Expect(1, 8528, '\p{^_Is_Letterlike_Symbols}', "");
Expect(1, 8528, '\P{_Is_Letterlike_Symbols}', "");
Expect(0, 8528, '\P{^_Is_Letterlike_Symbols}', "");
Error('\p{	in_Letterlike_Symbols:=}');
Error('\P{	in_Letterlike_Symbols:=}');
Expect(1, 8527, '\p{inletterlikesymbols}', "");
Expect(0, 8527, '\p{^inletterlikesymbols}', "");
Expect(0, 8527, '\P{inletterlikesymbols}', "");
Expect(1, 8527, '\P{^inletterlikesymbols}', "");
Expect(0, 8528, '\p{inletterlikesymbols}', "");
Expect(1, 8528, '\p{^inletterlikesymbols}', "");
Expect(1, 8528, '\P{inletterlikesymbols}', "");
Expect(0, 8528, '\P{^inletterlikesymbols}', "");
Expect(1, 8527, '\p{_IN_Letterlike_Symbols}', "");
Expect(0, 8527, '\p{^_IN_Letterlike_Symbols}', "");
Expect(0, 8527, '\P{_IN_Letterlike_Symbols}', "");
Expect(1, 8527, '\P{^_IN_Letterlike_Symbols}', "");
Expect(0, 8528, '\p{_IN_Letterlike_Symbols}', "");
Expect(1, 8528, '\p{^_IN_Letterlike_Symbols}', "");
Expect(1, 8528, '\P{_IN_Letterlike_Symbols}', "");
Expect(0, 8528, '\P{^_IN_Letterlike_Symbols}', "");
Error('\p{--Limbu:=}');
Error('\P{--Limbu:=}');
Expect(1, 6479, '\p{limbu}', "");
Expect(0, 6479, '\p{^limbu}', "");
Expect(0, 6479, '\P{limbu}', "");
Expect(1, 6479, '\P{^limbu}', "");
Expect(0, 6480, '\p{limbu}', "");
Expect(1, 6480, '\p{^limbu}', "");
Expect(1, 6480, '\P{limbu}', "");
Expect(0, 6480, '\P{^limbu}', "");
Expect(1, 6479, '\p{	 LIMBU}', "");
Expect(0, 6479, '\p{^	 LIMBU}', "");
Expect(0, 6479, '\P{	 LIMBU}', "");
Expect(1, 6479, '\P{^	 LIMBU}', "");
Expect(0, 6480, '\p{	 LIMBU}', "");
Expect(1, 6480, '\p{^	 LIMBU}', "");
Expect(1, 6480, '\P{	 LIMBU}', "");
Expect(0, 6480, '\P{^	 LIMBU}', "");
Error('\p{/a/_ Is_LIMBU}');
Error('\P{/a/_ Is_LIMBU}');
Expect(1, 6479, '\p{islimbu}', "");
Expect(0, 6479, '\p{^islimbu}', "");
Expect(0, 6479, '\P{islimbu}', "");
Expect(1, 6479, '\P{^islimbu}', "");
Expect(0, 6480, '\p{islimbu}', "");
Expect(1, 6480, '\p{^islimbu}', "");
Expect(1, 6480, '\P{islimbu}', "");
Expect(0, 6480, '\P{^islimbu}', "");
Expect(1, 6479, '\p{-	Is_Limbu}', "");
Expect(0, 6479, '\p{^-	Is_Limbu}', "");
Expect(0, 6479, '\P{-	Is_Limbu}', "");
Expect(1, 6479, '\P{^-	Is_Limbu}', "");
Expect(0, 6480, '\p{-	Is_Limbu}', "");
Expect(1, 6480, '\p{^-	Is_Limbu}', "");
Expect(1, 6480, '\P{-	Is_Limbu}', "");
Expect(0, 6480, '\P{^-	Is_Limbu}', "");
Error('\p{:= -limb}');
Error('\P{:= -limb}');
Expect(1, 6479, '\p{limb}', "");
Expect(0, 6479, '\p{^limb}', "");
Expect(0, 6479, '\P{limb}', "");
Expect(1, 6479, '\P{^limb}', "");
Expect(0, 6480, '\p{limb}', "");
Expect(1, 6480, '\p{^limb}', "");
Expect(1, 6480, '\P{limb}', "");
Expect(0, 6480, '\P{^limb}', "");
Expect(1, 6479, '\p{_-Limb}', "");
Expect(0, 6479, '\p{^_-Limb}', "");
Expect(0, 6479, '\P{_-Limb}', "");
Expect(1, 6479, '\P{^_-Limb}', "");
Expect(0, 6480, '\p{_-Limb}', "");
Expect(1, 6480, '\p{^_-Limb}', "");
Expect(1, 6480, '\P{_-Limb}', "");
Expect(0, 6480, '\P{^_-Limb}', "");
Error('\p{:=_	is_LIMB}');
Error('\P{:=_	is_LIMB}');
Expect(1, 6479, '\p{islimb}', "");
Expect(0, 6479, '\p{^islimb}', "");
Expect(0, 6479, '\P{islimb}', "");
Expect(1, 6479, '\P{^islimb}', "");
Expect(0, 6480, '\p{islimb}', "");
Expect(1, 6480, '\p{^islimb}', "");
Expect(1, 6480, '\P{islimb}', "");
Expect(0, 6480, '\P{^islimb}', "");
Expect(1, 6479, '\p{	Is_Limb}', "");
Expect(0, 6479, '\p{^	Is_Limb}', "");
Expect(0, 6479, '\P{	Is_Limb}', "");
Expect(1, 6479, '\P{^	Is_Limb}', "");
Expect(0, 6480, '\p{	Is_Limb}', "");
Expect(1, 6480, '\p{^	Is_Limb}', "");
Expect(1, 6480, '\P{	Is_Limb}', "");
Expect(0, 6480, '\P{^	Is_Limb}', "");
Error('\p{:= Line_SEPARATOR}');
Error('\P{:= Line_SEPARATOR}');
Expect(1, 8232, '\p{lineseparator}', "");
Expect(0, 8232, '\p{^lineseparator}', "");
Expect(0, 8232, '\P{lineseparator}', "");
Expect(1, 8232, '\P{^lineseparator}', "");
Expect(0, 8233, '\p{lineseparator}', "");
Expect(1, 8233, '\p{^lineseparator}', "");
Expect(1, 8233, '\P{lineseparator}', "");
Expect(0, 8233, '\P{^lineseparator}', "");
Expect(1, 8232, '\p{	Line_Separator}', "");
Expect(0, 8232, '\p{^	Line_Separator}', "");
Expect(0, 8232, '\P{	Line_Separator}', "");
Expect(1, 8232, '\P{^	Line_Separator}', "");
Expect(0, 8233, '\p{	Line_Separator}', "");
Expect(1, 8233, '\p{^	Line_Separator}', "");
Expect(1, 8233, '\P{	Line_Separator}', "");
Expect(0, 8233, '\P{^	Line_Separator}', "");
Error('\p{/a/-is_Line_Separator}');
Error('\P{/a/-is_Line_Separator}');
Expect(1, 8232, '\p{islineseparator}', "");
Expect(0, 8232, '\p{^islineseparator}', "");
Expect(0, 8232, '\P{islineseparator}', "");
Expect(1, 8232, '\P{^islineseparator}', "");
Expect(0, 8233, '\p{islineseparator}', "");
Expect(1, 8233, '\p{^islineseparator}', "");
Expect(1, 8233, '\P{islineseparator}', "");
Expect(0, 8233, '\P{^islineseparator}', "");
Expect(1, 8232, '\p{ -Is_Line_Separator}', "");
Expect(0, 8232, '\p{^ -Is_Line_Separator}', "");
Expect(0, 8232, '\P{ -Is_Line_Separator}', "");
Expect(1, 8232, '\P{^ -Is_Line_Separator}', "");
Expect(0, 8233, '\p{ -Is_Line_Separator}', "");
Expect(1, 8233, '\p{^ -Is_Line_Separator}', "");
Expect(1, 8233, '\P{ -Is_Line_Separator}', "");
Expect(0, 8233, '\P{^ -Is_Line_Separator}', "");
Error('\p{/a/ _Zl}');
Error('\P{/a/ _Zl}');
Expect(1, 8232, '\p{zl}', "");
Expect(0, 8232, '\p{^zl}', "");
Expect(0, 8232, '\P{zl}', "");
Expect(1, 8232, '\P{^zl}', "");
Expect(0, 8233, '\p{zl}', "");
Expect(1, 8233, '\p{^zl}', "");
Expect(1, 8233, '\P{zl}', "");
Expect(0, 8233, '\P{^zl}', "");
Expect(1, 8232, '\p{_	zl}', "");
Expect(0, 8232, '\p{^_	zl}', "");
Expect(0, 8232, '\P{_	zl}', "");
Expect(1, 8232, '\P{^_	zl}', "");
Expect(0, 8233, '\p{_	zl}', "");
Expect(1, 8233, '\p{^_	zl}', "");
Expect(1, 8233, '\P{_	zl}', "");
Expect(0, 8233, '\P{^_	zl}', "");
Error('\p{/a/	Is_Zl}');
Error('\P{/a/	Is_Zl}');
Expect(1, 8232, '\p{iszl}', "");
Expect(0, 8232, '\p{^iszl}', "");
Expect(0, 8232, '\P{iszl}', "");
Expect(1, 8232, '\P{^iszl}', "");
Expect(0, 8233, '\p{iszl}', "");
Expect(1, 8233, '\p{^iszl}', "");
Expect(1, 8233, '\P{iszl}', "");
Expect(0, 8233, '\P{^iszl}', "");
Expect(1, 8232, '\p{-Is_zl}', "");
Expect(0, 8232, '\p{^-Is_zl}', "");
Expect(0, 8232, '\P{-Is_zl}', "");
Expect(1, 8232, '\P{^-Is_zl}', "");
Expect(0, 8233, '\p{-Is_zl}', "");
Expect(1, 8233, '\p{^-Is_zl}', "");
Expect(1, 8233, '\P{-Is_zl}', "");
Expect(0, 8233, '\P{^-Is_zl}', "");
Error('\p{  Linear_b/a/}');
Error('\P{  Linear_b/a/}');
Expect(1, 65786, '\p{linearb}', "");
Expect(0, 65786, '\p{^linearb}', "");
Expect(0, 65786, '\P{linearb}', "");
Expect(1, 65786, '\P{^linearb}', "");
Expect(0, 65787, '\p{linearb}', "");
Expect(1, 65787, '\p{^linearb}', "");
Expect(1, 65787, '\P{linearb}', "");
Expect(0, 65787, '\P{^linearb}', "");
Expect(1, 65786, '\p{_Linear_B}', "");
Expect(0, 65786, '\p{^_Linear_B}', "");
Expect(0, 65786, '\P{_Linear_B}', "");
Expect(1, 65786, '\P{^_Linear_B}', "");
Expect(0, 65787, '\p{_Linear_B}', "");
Expect(1, 65787, '\p{^_Linear_B}', "");
Expect(1, 65787, '\P{_Linear_B}', "");
Expect(0, 65787, '\P{^_Linear_B}', "");
Error('\p{ Is_linear_B:=}');
Error('\P{ Is_linear_B:=}');
Expect(1, 65786, '\p{islinearb}', "");
Expect(0, 65786, '\p{^islinearb}', "");
Expect(0, 65786, '\P{islinearb}', "");
Expect(1, 65786, '\P{^islinearb}', "");
Expect(0, 65787, '\p{islinearb}', "");
Expect(1, 65787, '\p{^islinearb}', "");
Expect(1, 65787, '\P{islinearb}', "");
Expect(0, 65787, '\P{^islinearb}', "");
Expect(1, 65786, '\p{-	Is_LINEAR_b}', "");
Expect(0, 65786, '\p{^-	Is_LINEAR_b}', "");
Expect(0, 65786, '\P{-	Is_LINEAR_b}', "");
Expect(1, 65786, '\P{^-	Is_LINEAR_b}', "");
Expect(0, 65787, '\p{-	Is_LINEAR_b}', "");
Expect(1, 65787, '\p{^-	Is_LINEAR_b}', "");
Expect(1, 65787, '\P{-	Is_LINEAR_b}', "");
Expect(0, 65787, '\P{^-	Is_LINEAR_b}', "");
Error('\p{	LINB/a/}');
Error('\P{	LINB/a/}');
Expect(1, 65786, '\p{linb}', "");
Expect(0, 65786, '\p{^linb}', "");
Expect(0, 65786, '\P{linb}', "");
Expect(1, 65786, '\P{^linb}', "");
Expect(0, 65787, '\p{linb}', "");
Expect(1, 65787, '\p{^linb}', "");
Expect(1, 65787, '\P{linb}', "");
Expect(0, 65787, '\P{^linb}', "");
Expect(1, 65786, '\p{--Linb}', "");
Expect(0, 65786, '\p{^--Linb}', "");
Expect(0, 65786, '\P{--Linb}', "");
Expect(1, 65786, '\P{^--Linb}', "");
Expect(0, 65787, '\p{--Linb}', "");
Expect(1, 65787, '\p{^--Linb}', "");
Expect(1, 65787, '\P{--Linb}', "");
Expect(0, 65787, '\P{^--Linb}', "");
Error('\p{	is_Linb:=}');
Error('\P{	is_Linb:=}');
Expect(1, 65786, '\p{islinb}', "");
Expect(0, 65786, '\p{^islinb}', "");
Expect(0, 65786, '\P{islinb}', "");
Expect(1, 65786, '\P{^islinb}', "");
Expect(0, 65787, '\p{islinb}', "");
Expect(1, 65787, '\p{^islinb}', "");
Expect(1, 65787, '\P{islinb}', "");
Expect(0, 65787, '\P{^islinb}', "");
Expect(1, 65786, '\p{_	Is_linb}', "");
Expect(0, 65786, '\p{^_	Is_linb}', "");
Expect(0, 65786, '\P{_	Is_linb}', "");
Expect(1, 65786, '\P{^_	Is_linb}', "");
Expect(0, 65787, '\p{_	Is_linb}', "");
Expect(1, 65787, '\p{^_	Is_linb}', "");
Expect(1, 65787, '\P{_	Is_linb}', "");
Expect(0, 65787, '\P{^_	Is_linb}', "");
Error('\p{ Linear_B_Ideograms:=}');
Error('\P{ Linear_B_Ideograms:=}');
Expect(1, 65791, '\p{linearbideograms}', "");
Expect(0, 65791, '\p{^linearbideograms}', "");
Expect(0, 65791, '\P{linearbideograms}', "");
Expect(1, 65791, '\P{^linearbideograms}', "");
Expect(0, 65792, '\p{linearbideograms}', "");
Expect(1, 65792, '\p{^linearbideograms}', "");
Expect(1, 65792, '\P{linearbideograms}', "");
Expect(0, 65792, '\P{^linearbideograms}', "");
Expect(1, 65791, '\p{	-Linear_b_ideograms}', "");
Expect(0, 65791, '\p{^	-Linear_b_ideograms}', "");
Expect(0, 65791, '\P{	-Linear_b_ideograms}', "");
Expect(1, 65791, '\P{^	-Linear_b_ideograms}', "");
Expect(0, 65792, '\p{	-Linear_b_ideograms}', "");
Expect(1, 65792, '\p{^	-Linear_b_ideograms}', "");
Expect(1, 65792, '\P{	-Linear_b_ideograms}', "");
Expect(0, 65792, '\P{^	-Linear_b_ideograms}', "");
Error('\p{ -IS_linear_B_Ideograms/a/}');
Error('\P{ -IS_linear_B_Ideograms/a/}');
Expect(1, 65791, '\p{islinearbideograms}', "");
Expect(0, 65791, '\p{^islinearbideograms}', "");
Expect(0, 65791, '\P{islinearbideograms}', "");
Expect(1, 65791, '\P{^islinearbideograms}', "");
Expect(0, 65792, '\p{islinearbideograms}', "");
Expect(1, 65792, '\p{^islinearbideograms}', "");
Expect(1, 65792, '\P{islinearbideograms}', "");
Expect(0, 65792, '\P{^islinearbideograms}', "");
Expect(1, 65791, '\p{	 Is_LINEAR_B_Ideograms}', "");
Expect(0, 65791, '\p{^	 Is_LINEAR_B_Ideograms}', "");
Expect(0, 65791, '\P{	 Is_LINEAR_B_Ideograms}', "");
Expect(1, 65791, '\P{^	 Is_LINEAR_B_Ideograms}', "");
Expect(0, 65792, '\p{	 Is_LINEAR_B_Ideograms}', "");
Expect(1, 65792, '\p{^	 Is_LINEAR_B_Ideograms}', "");
Expect(1, 65792, '\P{	 Is_LINEAR_B_Ideograms}', "");
Expect(0, 65792, '\P{^	 Is_LINEAR_B_Ideograms}', "");
Error('\p{/a/-In_Linear_B_Ideograms}');
Error('\P{/a/-In_Linear_B_Ideograms}');
Expect(1, 65791, '\p{inlinearbideograms}', "");
Expect(0, 65791, '\p{^inlinearbideograms}', "");
Expect(0, 65791, '\P{inlinearbideograms}', "");
Expect(1, 65791, '\P{^inlinearbideograms}', "");
Expect(0, 65792, '\p{inlinearbideograms}', "");
Expect(1, 65792, '\p{^inlinearbideograms}', "");
Expect(1, 65792, '\P{inlinearbideograms}', "");
Expect(0, 65792, '\P{^inlinearbideograms}', "");
Expect(1, 65791, '\p{_IN_LINEAR_B_Ideograms}', "");
Expect(0, 65791, '\p{^_IN_LINEAR_B_Ideograms}', "");
Expect(0, 65791, '\P{_IN_LINEAR_B_Ideograms}', "");
Expect(1, 65791, '\P{^_IN_LINEAR_B_Ideograms}', "");
Expect(0, 65792, '\p{_IN_LINEAR_B_Ideograms}', "");
Expect(1, 65792, '\p{^_IN_LINEAR_B_Ideograms}', "");
Expect(1, 65792, '\P{_IN_LINEAR_B_Ideograms}', "");
Expect(0, 65792, '\P{^_IN_LINEAR_B_Ideograms}', "");
Error('\p{:=_-Linear_b_SYLLABARY}');
Error('\P{:=_-Linear_b_SYLLABARY}');
Expect(1, 65663, '\p{linearbsyllabary}', "");
Expect(0, 65663, '\p{^linearbsyllabary}', "");
Expect(0, 65663, '\P{linearbsyllabary}', "");
Expect(1, 65663, '\P{^linearbsyllabary}', "");
Expect(0, 65664, '\p{linearbsyllabary}', "");
Expect(1, 65664, '\p{^linearbsyllabary}', "");
Expect(1, 65664, '\P{linearbsyllabary}', "");
Expect(0, 65664, '\P{^linearbsyllabary}', "");
Expect(1, 65663, '\p{ Linear_B_SYLLABARY}', "");
Expect(0, 65663, '\p{^ Linear_B_SYLLABARY}', "");
Expect(0, 65663, '\P{ Linear_B_SYLLABARY}', "");
Expect(1, 65663, '\P{^ Linear_B_SYLLABARY}', "");
Expect(0, 65664, '\p{ Linear_B_SYLLABARY}', "");
Expect(1, 65664, '\p{^ Linear_B_SYLLABARY}', "");
Expect(1, 65664, '\P{ Linear_B_SYLLABARY}', "");
Expect(0, 65664, '\P{^ Linear_B_SYLLABARY}', "");
Error('\p{-:=IS_Linear_B_Syllabary}');
Error('\P{-:=IS_Linear_B_Syllabary}');
Expect(1, 65663, '\p{islinearbsyllabary}', "");
Expect(0, 65663, '\p{^islinearbsyllabary}', "");
Expect(0, 65663, '\P{islinearbsyllabary}', "");
Expect(1, 65663, '\P{^islinearbsyllabary}', "");
Expect(0, 65664, '\p{islinearbsyllabary}', "");
Expect(1, 65664, '\p{^islinearbsyllabary}', "");
Expect(1, 65664, '\P{islinearbsyllabary}', "");
Expect(0, 65664, '\P{^islinearbsyllabary}', "");
Expect(1, 65663, '\p{-_is_Linear_b_SYLLABARY}', "");
Expect(0, 65663, '\p{^-_is_Linear_b_SYLLABARY}', "");
Expect(0, 65663, '\P{-_is_Linear_b_SYLLABARY}', "");
Expect(1, 65663, '\P{^-_is_Linear_b_SYLLABARY}', "");
Expect(0, 65664, '\p{-_is_Linear_b_SYLLABARY}', "");
Expect(1, 65664, '\p{^-_is_Linear_b_SYLLABARY}', "");
Expect(1, 65664, '\P{-_is_Linear_b_SYLLABARY}', "");
Expect(0, 65664, '\P{^-_is_Linear_b_SYLLABARY}', "");
Error('\p{:=-	In_Linear_B_Syllabary}');
Error('\P{:=-	In_Linear_B_Syllabary}');
Expect(1, 65663, '\p{inlinearbsyllabary}', "");
Expect(0, 65663, '\p{^inlinearbsyllabary}', "");
Expect(0, 65663, '\P{inlinearbsyllabary}', "");
Expect(1, 65663, '\P{^inlinearbsyllabary}', "");
Expect(0, 65664, '\p{inlinearbsyllabary}', "");
Expect(1, 65664, '\p{^inlinearbsyllabary}', "");
Expect(1, 65664, '\P{inlinearbsyllabary}', "");
Expect(0, 65664, '\P{^inlinearbsyllabary}', "");
Expect(1, 65663, '\p{__In_LINEAR_B_syllabary}', "");
Expect(0, 65663, '\p{^__In_LINEAR_B_syllabary}', "");
Expect(0, 65663, '\P{__In_LINEAR_B_syllabary}', "");
Expect(1, 65663, '\P{^__In_LINEAR_B_syllabary}', "");
Expect(0, 65664, '\p{__In_LINEAR_B_syllabary}', "");
Expect(1, 65664, '\p{^__In_LINEAR_B_syllabary}', "");
Expect(1, 65664, '\P{__In_LINEAR_B_syllabary}', "");
Expect(0, 65664, '\P{^__In_LINEAR_B_syllabary}', "");
Error('\p{	LISU:=}');
Error('\P{	LISU:=}');
Expect(1, 42239, '\p{lisu}', "");
Expect(0, 42239, '\p{^lisu}', "");
Expect(0, 42239, '\P{lisu}', "");
Expect(1, 42239, '\P{^lisu}', "");
Expect(0, 42240, '\p{lisu}', "");
Expect(1, 42240, '\p{^lisu}', "");
Expect(1, 42240, '\P{lisu}', "");
Expect(0, 42240, '\P{^lisu}', "");
Expect(1, 42239, '\p{-	lisu}', "");
Expect(0, 42239, '\p{^-	lisu}', "");
Expect(0, 42239, '\P{-	lisu}', "");
Expect(1, 42239, '\P{^-	lisu}', "");
Expect(0, 42240, '\p{-	lisu}', "");
Expect(1, 42240, '\p{^-	lisu}', "");
Expect(1, 42240, '\P{-	lisu}', "");
Expect(0, 42240, '\P{^-	lisu}', "");
Error('\p{:=		IS_Lisu}');
Error('\P{:=		IS_Lisu}');
Expect(1, 42239, '\p{islisu}', "");
Expect(0, 42239, '\p{^islisu}', "");
Expect(0, 42239, '\P{islisu}', "");
Expect(1, 42239, '\P{^islisu}', "");
Expect(0, 42240, '\p{islisu}', "");
Expect(1, 42240, '\p{^islisu}', "");
Expect(1, 42240, '\P{islisu}', "");
Expect(0, 42240, '\P{^islisu}', "");
Expect(1, 42239, '\p{ is_Lisu}', "");
Expect(0, 42239, '\p{^ is_Lisu}', "");
Expect(0, 42239, '\P{ is_Lisu}', "");
Expect(1, 42239, '\P{^ is_Lisu}', "");
Expect(0, 42240, '\p{ is_Lisu}', "");
Expect(1, 42240, '\p{^ is_Lisu}', "");
Expect(1, 42240, '\P{ is_Lisu}', "");
Expect(0, 42240, '\P{^ is_Lisu}', "");
Error('\p{/a/logical_Order_exception}');
Error('\P{/a/logical_Order_exception}');
Expect(1, 43708, '\p{logicalorderexception}', "");
Expect(0, 43708, '\p{^logicalorderexception}', "");
Expect(0, 43708, '\P{logicalorderexception}', "");
Expect(1, 43708, '\P{^logicalorderexception}', "");
Expect(0, 43709, '\p{logicalorderexception}', "");
Expect(1, 43709, '\p{^logicalorderexception}', "");
Expect(1, 43709, '\P{logicalorderexception}', "");
Expect(0, 43709, '\P{^logicalorderexception}', "");
Expect(1, 43708, '\p{_ logical_Order_Exception}', "");
Expect(0, 43708, '\p{^_ logical_Order_Exception}', "");
Expect(0, 43708, '\P{_ logical_Order_Exception}', "");
Expect(1, 43708, '\P{^_ logical_Order_Exception}', "");
Expect(0, 43709, '\p{_ logical_Order_Exception}', "");
Expect(1, 43709, '\p{^_ logical_Order_Exception}', "");
Expect(1, 43709, '\P{_ logical_Order_Exception}', "");
Expect(0, 43709, '\P{^_ logical_Order_Exception}', "");
Error('\p{/a/IS_Logical_Order_EXCEPTION}');
Error('\P{/a/IS_Logical_Order_EXCEPTION}');
Expect(1, 43708, '\p{islogicalorderexception}', "");
Expect(0, 43708, '\p{^islogicalorderexception}', "");
Expect(0, 43708, '\P{islogicalorderexception}', "");
Expect(1, 43708, '\P{^islogicalorderexception}', "");
Expect(0, 43709, '\p{islogicalorderexception}', "");
Expect(1, 43709, '\p{^islogicalorderexception}', "");
Expect(1, 43709, '\P{islogicalorderexception}', "");
Expect(0, 43709, '\P{^islogicalorderexception}', "");
Expect(1, 43708, '\p{_-Is_logical_Order_Exception}', "");
Expect(0, 43708, '\p{^_-Is_logical_Order_Exception}', "");
Expect(0, 43708, '\P{_-Is_logical_Order_Exception}', "");
Expect(1, 43708, '\P{^_-Is_logical_Order_Exception}', "");
Expect(0, 43709, '\p{_-Is_logical_Order_Exception}', "");
Expect(1, 43709, '\p{^_-Is_logical_Order_Exception}', "");
Expect(1, 43709, '\P{_-Is_logical_Order_Exception}', "");
Expect(0, 43709, '\P{^_-Is_logical_Order_Exception}', "");
Error('\p{ loe:=}');
Error('\P{ loe:=}');
Expect(1, 43708, '\p{loe}', "");
Expect(0, 43708, '\p{^loe}', "");
Expect(0, 43708, '\P{loe}', "");
Expect(1, 43708, '\P{^loe}', "");
Expect(0, 43709, '\p{loe}', "");
Expect(1, 43709, '\p{^loe}', "");
Expect(1, 43709, '\P{loe}', "");
Expect(0, 43709, '\P{^loe}', "");
Expect(1, 43708, '\p{		LOE}', "");
Expect(0, 43708, '\p{^		LOE}', "");
Expect(0, 43708, '\P{		LOE}', "");
Expect(1, 43708, '\P{^		LOE}', "");
Expect(0, 43709, '\p{		LOE}', "");
Expect(1, 43709, '\p{^		LOE}', "");
Expect(1, 43709, '\P{		LOE}', "");
Expect(0, 43709, '\P{^		LOE}', "");
Error('\p{:=_IS_LOE}');
Error('\P{:=_IS_LOE}');
Expect(1, 43708, '\p{isloe}', "");
Expect(0, 43708, '\p{^isloe}', "");
Expect(0, 43708, '\P{isloe}', "");
Expect(1, 43708, '\P{^isloe}', "");
Expect(0, 43709, '\p{isloe}', "");
Expect(1, 43709, '\p{^isloe}', "");
Expect(1, 43709, '\P{isloe}', "");
Expect(0, 43709, '\P{^isloe}', "");
Expect(1, 43708, '\p{__Is_LOE}', "");
Expect(0, 43708, '\p{^__Is_LOE}', "");
Expect(0, 43708, '\P{__Is_LOE}', "");
Expect(1, 43708, '\P{^__Is_LOE}', "");
Expect(0, 43709, '\p{__Is_LOE}', "");
Expect(1, 43709, '\p{^__Is_LOE}', "");
Expect(1, 43709, '\P{__Is_LOE}', "");
Expect(0, 43709, '\P{^__Is_LOE}', "");
Error('\p{:=	Low_surrogates}');
Error('\P{:=	Low_surrogates}');
Expect(1, 57343, '\p{lowsurrogates}', "");
Expect(0, 57343, '\p{^lowsurrogates}', "");
Expect(0, 57343, '\P{lowsurrogates}', "");
Expect(1, 57343, '\P{^lowsurrogates}', "");
Expect(0, 57344, '\p{lowsurrogates}', "");
Expect(1, 57344, '\p{^lowsurrogates}', "");
Expect(1, 57344, '\P{lowsurrogates}', "");
Expect(0, 57344, '\P{^lowsurrogates}', "");
Expect(1, 57343, '\p{_-Low_Surrogates}', "");
Expect(0, 57343, '\p{^_-Low_Surrogates}', "");
Expect(0, 57343, '\P{_-Low_Surrogates}', "");
Expect(1, 57343, '\P{^_-Low_Surrogates}', "");
Expect(0, 57344, '\p{_-Low_Surrogates}', "");
Expect(1, 57344, '\p{^_-Low_Surrogates}', "");
Expect(1, 57344, '\P{_-Low_Surrogates}', "");
Expect(0, 57344, '\P{^_-Low_Surrogates}', "");
Error('\p{ is_LOW_Surrogates/a/}');
Error('\P{ is_LOW_Surrogates/a/}');
Expect(1, 57343, '\p{islowsurrogates}', "");
Expect(0, 57343, '\p{^islowsurrogates}', "");
Expect(0, 57343, '\P{islowsurrogates}', "");
Expect(1, 57343, '\P{^islowsurrogates}', "");
Expect(0, 57344, '\p{islowsurrogates}', "");
Expect(1, 57344, '\p{^islowsurrogates}', "");
Expect(1, 57344, '\P{islowsurrogates}', "");
Expect(0, 57344, '\P{^islowsurrogates}', "");
Expect(1, 57343, '\p{	-Is_Low_Surrogates}', "");
Expect(0, 57343, '\p{^	-Is_Low_Surrogates}', "");
Expect(0, 57343, '\P{	-Is_Low_Surrogates}', "");
Expect(1, 57343, '\P{^	-Is_Low_Surrogates}', "");
Expect(0, 57344, '\p{	-Is_Low_Surrogates}', "");
Expect(1, 57344, '\p{^	-Is_Low_Surrogates}', "");
Expect(1, 57344, '\P{	-Is_Low_Surrogates}', "");
Expect(0, 57344, '\P{^	-Is_Low_Surrogates}', "");
Error('\p{/a/--in_low_surrogates}');
Error('\P{/a/--in_low_surrogates}');
Expect(1, 57343, '\p{inlowsurrogates}', "");
Expect(0, 57343, '\p{^inlowsurrogates}', "");
Expect(0, 57343, '\P{inlowsurrogates}', "");
Expect(1, 57343, '\P{^inlowsurrogates}', "");
Expect(0, 57344, '\p{inlowsurrogates}', "");
Expect(1, 57344, '\p{^inlowsurrogates}', "");
Expect(1, 57344, '\P{inlowsurrogates}', "");
Expect(0, 57344, '\P{^inlowsurrogates}', "");
Expect(1, 57343, '\p{ IN_low_Surrogates}', "");
Expect(0, 57343, '\p{^ IN_low_Surrogates}', "");
Expect(0, 57343, '\P{ IN_low_Surrogates}', "");
Expect(1, 57343, '\P{^ IN_low_Surrogates}', "");
Expect(0, 57344, '\p{ IN_low_Surrogates}', "");
Expect(1, 57344, '\p{^ IN_low_Surrogates}', "");
Expect(1, 57344, '\P{ IN_low_Surrogates}', "");
Expect(0, 57344, '\P{^ IN_low_Surrogates}', "");
Error('\p{-	LOWER:=}');
Error('\P{-	LOWER:=}');
Expect(1, 120779, '\p{lower}', "");
Expect(0, 120779, '\p{^lower}', "");
Expect(0, 120779, '\P{lower}', "");
Expect(1, 120779, '\P{^lower}', "");
Expect(0, 120780, '\p{lower}', "");
Expect(1, 120780, '\p{^lower}', "");
Expect(1, 120780, '\P{lower}', "");
Expect(0, 120780, '\P{^lower}', "");
Expect(1, 120779, '\p{-	lower}', "");
Expect(0, 120779, '\p{^-	lower}', "");
Expect(0, 120779, '\P{-	lower}', "");
Expect(1, 120779, '\P{^-	lower}', "");
Expect(0, 120780, '\p{-	lower}', "");
Expect(1, 120780, '\p{^-	lower}', "");
Expect(1, 120780, '\P{-	lower}', "");
Expect(0, 120780, '\P{^-	lower}', "");
Error('\p{:=	XPOSIXLOWER}');
Error('\P{:=	XPOSIXLOWER}');
Expect(1, 120779, '\p{xposixlower}', "");
Expect(0, 120779, '\p{^xposixlower}', "");
Expect(0, 120779, '\P{xposixlower}', "");
Expect(1, 120779, '\P{^xposixlower}', "");
Expect(0, 120780, '\p{xposixlower}', "");
Expect(1, 120780, '\p{^xposixlower}', "");
Expect(1, 120780, '\P{xposixlower}', "");
Expect(0, 120780, '\P{^xposixlower}', "");
Expect(1, 120779, '\p{	 XPosixLower}', "");
Expect(0, 120779, '\p{^	 XPosixLower}', "");
Expect(0, 120779, '\P{	 XPosixLower}', "");
Expect(1, 120779, '\P{^	 XPosixLower}', "");
Expect(0, 120780, '\p{	 XPosixLower}', "");
Expect(1, 120780, '\p{^	 XPosixLower}', "");
Expect(1, 120780, '\P{	 XPosixLower}', "");
Expect(0, 120780, '\P{^	 XPosixLower}', "");
Error('\p{-is_Lower/a/}');
Error('\P{-is_Lower/a/}');
Expect(1, 120779, '\p{islower}', "");
Expect(0, 120779, '\p{^islower}', "");
Expect(0, 120779, '\P{islower}', "");
Expect(1, 120779, '\P{^islower}', "");
Expect(0, 120780, '\p{islower}', "");
Expect(1, 120780, '\p{^islower}', "");
Expect(1, 120780, '\P{islower}', "");
Expect(0, 120780, '\P{^islower}', "");
Expect(1, 120779, '\p{ 	IS_Lower}', "");
Expect(0, 120779, '\p{^ 	IS_Lower}', "");
Expect(0, 120779, '\P{ 	IS_Lower}', "");
Expect(1, 120779, '\P{^ 	IS_Lower}', "");
Expect(0, 120780, '\p{ 	IS_Lower}', "");
Expect(1, 120780, '\p{^ 	IS_Lower}', "");
Expect(1, 120780, '\P{ 	IS_Lower}', "");
Expect(0, 120780, '\P{^ 	IS_Lower}', "");
Error('\p{:=_-Is_XPosixLower}');
Error('\P{:=_-Is_XPosixLower}');
Expect(1, 120779, '\p{isxposixlower}', "");
Expect(0, 120779, '\p{^isxposixlower}', "");
Expect(0, 120779, '\P{isxposixlower}', "");
Expect(1, 120779, '\P{^isxposixlower}', "");
Expect(0, 120780, '\p{isxposixlower}', "");
Expect(1, 120780, '\p{^isxposixlower}', "");
Expect(1, 120780, '\P{isxposixlower}', "");
Expect(0, 120780, '\P{^isxposixlower}', "");
Expect(1, 120779, '\p{  IS_XPosixLower}', "");
Expect(0, 120779, '\p{^  IS_XPosixLower}', "");
Expect(0, 120779, '\P{  IS_XPosixLower}', "");
Expect(1, 120779, '\P{^  IS_XPosixLower}', "");
Expect(0, 120780, '\p{  IS_XPosixLower}', "");
Expect(1, 120780, '\p{^  IS_XPosixLower}', "");
Expect(1, 120780, '\P{  IS_XPosixLower}', "");
Expect(0, 120780, '\P{^  IS_XPosixLower}', "");
Error('\p{:= _LOWERCASE}');
Error('\P{:= _LOWERCASE}');
Expect(1, 120779, '\p{lowercase}', "");
Expect(0, 120779, '\p{^lowercase}', "");
Expect(0, 120779, '\P{lowercase}', "");
Expect(1, 120779, '\P{^lowercase}', "");
Expect(0, 120780, '\p{lowercase}', "");
Expect(1, 120780, '\p{^lowercase}', "");
Expect(1, 120780, '\P{lowercase}', "");
Expect(0, 120780, '\P{^lowercase}', "");
Expect(1, 120779, '\p{_ Lowercase}', "");
Expect(0, 120779, '\p{^_ Lowercase}', "");
Expect(0, 120779, '\P{_ Lowercase}', "");
Expect(1, 120779, '\P{^_ Lowercase}', "");
Expect(0, 120780, '\p{_ Lowercase}', "");
Expect(1, 120780, '\p{^_ Lowercase}', "");
Expect(1, 120780, '\P{_ Lowercase}', "");
Expect(0, 120780, '\P{^_ Lowercase}', "");
Error('\p{ _Is_LOWERCASE:=}');
Error('\P{ _Is_LOWERCASE:=}');
Expect(1, 120779, '\p{islowercase}', "");
Expect(0, 120779, '\p{^islowercase}', "");
Expect(0, 120779, '\P{islowercase}', "");
Expect(1, 120779, '\P{^islowercase}', "");
Expect(0, 120780, '\p{islowercase}', "");
Expect(1, 120780, '\p{^islowercase}', "");
Expect(1, 120780, '\P{islowercase}', "");
Expect(0, 120780, '\P{^islowercase}', "");
Expect(1, 120779, '\p{--Is_Lowercase}', "");
Expect(0, 120779, '\p{^--Is_Lowercase}', "");
Expect(0, 120779, '\P{--Is_Lowercase}', "");
Expect(1, 120779, '\P{^--Is_Lowercase}', "");
Expect(0, 120780, '\p{--Is_Lowercase}', "");
Expect(1, 120780, '\p{^--Is_Lowercase}', "");
Expect(1, 120780, '\P{--Is_Lowercase}', "");
Expect(0, 120780, '\P{^--Is_Lowercase}', "");
Error('\p{_lowercase_LETTER:=}');
Error('\P{_lowercase_LETTER:=}');
Expect(1, 120779, '\p{lowercaseletter}', "");
Expect(0, 120779, '\p{^lowercaseletter}', "");
Expect(0, 120779, '\P{lowercaseletter}', "");
Expect(1, 120779, '\P{^lowercaseletter}', "");
Expect(0, 120780, '\p{lowercaseletter}', "");
Expect(1, 120780, '\p{^lowercaseletter}', "");
Expect(1, 120780, '\P{lowercaseletter}', "");
Expect(0, 120780, '\P{^lowercaseletter}', "");
Expect(1, 120779, '\p{-_lowercase_Letter}', "");
Expect(0, 120779, '\p{^-_lowercase_Letter}', "");
Expect(0, 120779, '\P{-_lowercase_Letter}', "");
Expect(1, 120779, '\P{^-_lowercase_Letter}', "");
Expect(0, 120780, '\p{-_lowercase_Letter}', "");
Expect(1, 120780, '\p{^-_lowercase_Letter}', "");
Expect(1, 120780, '\P{-_lowercase_Letter}', "");
Expect(0, 120780, '\P{^-_lowercase_Letter}', "");
Error('\p{/a/	Is_LOWERCASE_letter}');
Error('\P{/a/	Is_LOWERCASE_letter}');
Expect(1, 120779, '\p{islowercaseletter}', "");
Expect(0, 120779, '\p{^islowercaseletter}', "");
Expect(0, 120779, '\P{islowercaseletter}', "");
Expect(1, 120779, '\P{^islowercaseletter}', "");
Expect(0, 120780, '\p{islowercaseletter}', "");
Expect(1, 120780, '\p{^islowercaseletter}', "");
Expect(1, 120780, '\P{islowercaseletter}', "");
Expect(0, 120780, '\P{^islowercaseletter}', "");
Expect(1, 120779, '\p{_	IS_LOWERCASE_Letter}', "");
Expect(0, 120779, '\p{^_	IS_LOWERCASE_Letter}', "");
Expect(0, 120779, '\P{_	IS_LOWERCASE_Letter}', "");
Expect(1, 120779, '\P{^_	IS_LOWERCASE_Letter}', "");
Expect(0, 120780, '\p{_	IS_LOWERCASE_Letter}', "");
Expect(1, 120780, '\p{^_	IS_LOWERCASE_Letter}', "");
Expect(1, 120780, '\P{_	IS_LOWERCASE_Letter}', "");
Expect(0, 120780, '\P{^_	IS_LOWERCASE_Letter}', "");
Error('\p{_/a/ll}');
Error('\P{_/a/ll}');
Expect(1, 120779, '\p{ll}', "");
Expect(0, 120779, '\p{^ll}', "");
Expect(0, 120779, '\P{ll}', "");
Expect(1, 120779, '\P{^ll}', "");
Expect(0, 120780, '\p{ll}', "");
Expect(1, 120780, '\p{^ll}', "");
Expect(1, 120780, '\P{ll}', "");
Expect(0, 120780, '\P{^ll}', "");
Expect(1, 120779, '\p{_ll}', "");
Expect(0, 120779, '\p{^_ll}', "");
Expect(0, 120779, '\P{_ll}', "");
Expect(1, 120779, '\P{^_ll}', "");
Expect(0, 120780, '\p{_ll}', "");
Expect(1, 120780, '\p{^_ll}', "");
Expect(1, 120780, '\P{_ll}', "");
Expect(0, 120780, '\P{^_ll}', "");
Error('\p{_:=Is_Ll}');
Error('\P{_:=Is_Ll}');
Expect(1, 120779, '\p{isll}', "");
Expect(0, 120779, '\p{^isll}', "");
Expect(0, 120779, '\P{isll}', "");
Expect(1, 120779, '\P{^isll}', "");
Expect(0, 120780, '\p{isll}', "");
Expect(1, 120780, '\p{^isll}', "");
Expect(1, 120780, '\P{isll}', "");
Expect(0, 120780, '\P{^isll}', "");
Expect(1, 120779, '\p{--Is_Ll}', "");
Expect(0, 120779, '\p{^--Is_Ll}', "");
Expect(0, 120779, '\P{--Is_Ll}', "");
Expect(1, 120779, '\P{^--Is_Ll}', "");
Expect(0, 120780, '\p{--Is_Ll}', "");
Expect(1, 120780, '\p{^--Is_Ll}', "");
Expect(1, 120780, '\P{--Is_Ll}', "");
Expect(0, 120780, '\P{^--Is_Ll}', "");
Error('\p{/a/_Lycian}');
Error('\P{/a/_Lycian}');
Expect(1, 66204, '\p{lycian}', "");
Expect(0, 66204, '\p{^lycian}', "");
Expect(0, 66204, '\P{lycian}', "");
Expect(1, 66204, '\P{^lycian}', "");
Expect(0, 66205, '\p{lycian}', "");
Expect(1, 66205, '\p{^lycian}', "");
Expect(1, 66205, '\P{lycian}', "");
Expect(0, 66205, '\P{^lycian}', "");
Expect(1, 66204, '\p{- LYCIAN}', "");
Expect(0, 66204, '\p{^- LYCIAN}', "");
Expect(0, 66204, '\P{- LYCIAN}', "");
Expect(1, 66204, '\P{^- LYCIAN}', "");
Expect(0, 66205, '\p{- LYCIAN}', "");
Expect(1, 66205, '\p{^- LYCIAN}', "");
Expect(1, 66205, '\P{- LYCIAN}', "");
Expect(0, 66205, '\P{^- LYCIAN}', "");
Error('\p{ /a/Is_Lycian}');
Error('\P{ /a/Is_Lycian}');
Expect(1, 66204, '\p{islycian}', "");
Expect(0, 66204, '\p{^islycian}', "");
Expect(0, 66204, '\P{islycian}', "");
Expect(1, 66204, '\P{^islycian}', "");
Expect(0, 66205, '\p{islycian}', "");
Expect(1, 66205, '\p{^islycian}', "");
Expect(1, 66205, '\P{islycian}', "");
Expect(0, 66205, '\P{^islycian}', "");
Expect(1, 66204, '\p{  is_Lycian}', "");
Expect(0, 66204, '\p{^  is_Lycian}', "");
Expect(0, 66204, '\P{  is_Lycian}', "");
Expect(1, 66204, '\P{^  is_Lycian}', "");
Expect(0, 66205, '\p{  is_Lycian}', "");
Expect(1, 66205, '\p{^  is_Lycian}', "");
Expect(1, 66205, '\P{  is_Lycian}', "");
Expect(0, 66205, '\P{^  is_Lycian}', "");
Error('\p{	LYCI:=}');
Error('\P{	LYCI:=}');
Expect(1, 66204, '\p{lyci}', "");
Expect(0, 66204, '\p{^lyci}', "");
Expect(0, 66204, '\P{lyci}', "");
Expect(1, 66204, '\P{^lyci}', "");
Expect(0, 66205, '\p{lyci}', "");
Expect(1, 66205, '\p{^lyci}', "");
Expect(1, 66205, '\P{lyci}', "");
Expect(0, 66205, '\P{^lyci}', "");
Expect(1, 66204, '\p{-	lyci}', "");
Expect(0, 66204, '\p{^-	lyci}', "");
Expect(0, 66204, '\P{-	lyci}', "");
Expect(1, 66204, '\P{^-	lyci}', "");
Expect(0, 66205, '\p{-	lyci}', "");
Expect(1, 66205, '\p{^-	lyci}', "");
Expect(1, 66205, '\P{-	lyci}', "");
Expect(0, 66205, '\P{^-	lyci}', "");
Error('\p{ /a/IS_lyci}');
Error('\P{ /a/IS_lyci}');
Expect(1, 66204, '\p{islyci}', "");
Expect(0, 66204, '\p{^islyci}', "");
Expect(0, 66204, '\P{islyci}', "");
Expect(1, 66204, '\P{^islyci}', "");
Expect(0, 66205, '\p{islyci}', "");
Expect(1, 66205, '\p{^islyci}', "");
Expect(1, 66205, '\P{islyci}', "");
Expect(0, 66205, '\P{^islyci}', "");
Expect(1, 66204, '\p{	is_LYCI}', "");
Expect(0, 66204, '\p{^	is_LYCI}', "");
Expect(0, 66204, '\P{	is_LYCI}', "");
Expect(1, 66204, '\P{^	is_LYCI}', "");
Expect(0, 66205, '\p{	is_LYCI}', "");
Expect(1, 66205, '\p{^	is_LYCI}', "");
Expect(1, 66205, '\P{	is_LYCI}', "");
Expect(0, 66205, '\P{^	is_LYCI}', "");
Error('\p{-/a/LYDIAN}');
Error('\P{-/a/LYDIAN}');
Expect(1, 67903, '\p{lydian}', "");
Expect(0, 67903, '\p{^lydian}', "");
Expect(0, 67903, '\P{lydian}', "");
Expect(1, 67903, '\P{^lydian}', "");
Expect(0, 67904, '\p{lydian}', "");
Expect(1, 67904, '\p{^lydian}', "");
Expect(1, 67904, '\P{lydian}', "");
Expect(0, 67904, '\P{^lydian}', "");
Expect(1, 67903, '\p{_	Lydian}', "");
Expect(0, 67903, '\p{^_	Lydian}', "");
Expect(0, 67903, '\P{_	Lydian}', "");
Expect(1, 67903, '\P{^_	Lydian}', "");
Expect(0, 67904, '\p{_	Lydian}', "");
Expect(1, 67904, '\p{^_	Lydian}', "");
Expect(1, 67904, '\P{_	Lydian}', "");
Expect(0, 67904, '\P{^_	Lydian}', "");
Error('\p{Is_LYDIAN:=}');
Error('\P{Is_LYDIAN:=}');
Expect(1, 67903, '\p{islydian}', "");
Expect(0, 67903, '\p{^islydian}', "");
Expect(0, 67903, '\P{islydian}', "");
Expect(1, 67903, '\P{^islydian}', "");
Expect(0, 67904, '\p{islydian}', "");
Expect(1, 67904, '\p{^islydian}', "");
Expect(1, 67904, '\P{islydian}', "");
Expect(0, 67904, '\P{^islydian}', "");
Expect(1, 67903, '\p{		Is_Lydian}', "");
Expect(0, 67903, '\p{^		Is_Lydian}', "");
Expect(0, 67903, '\P{		Is_Lydian}', "");
Expect(1, 67903, '\P{^		Is_Lydian}', "");
Expect(0, 67904, '\p{		Is_Lydian}', "");
Expect(1, 67904, '\p{^		Is_Lydian}', "");
Expect(1, 67904, '\P{		Is_Lydian}', "");
Expect(0, 67904, '\P{^		Is_Lydian}', "");
Error('\p{- LYDI:=}');
Error('\P{- LYDI:=}');
Expect(1, 67903, '\p{lydi}', "");
Expect(0, 67903, '\p{^lydi}', "");
Expect(0, 67903, '\P{lydi}', "");
Expect(1, 67903, '\P{^lydi}', "");
Expect(0, 67904, '\p{lydi}', "");
Expect(1, 67904, '\p{^lydi}', "");
Expect(1, 67904, '\P{lydi}', "");
Expect(0, 67904, '\P{^lydi}', "");
Expect(1, 67903, '\p{  lydi}', "");
Expect(0, 67903, '\p{^  lydi}', "");
Expect(0, 67903, '\P{  lydi}', "");
Expect(1, 67903, '\P{^  lydi}', "");
Expect(0, 67904, '\p{  lydi}', "");
Expect(1, 67904, '\p{^  lydi}', "");
Expect(1, 67904, '\P{  lydi}', "");
Expect(0, 67904, '\P{^  lydi}', "");
Error('\p{ /a/Is_Lydi}');
Error('\P{ /a/Is_Lydi}');
Expect(1, 67903, '\p{islydi}', "");
Expect(0, 67903, '\p{^islydi}', "");
Expect(0, 67903, '\P{islydi}', "");
Expect(1, 67903, '\P{^islydi}', "");
Expect(0, 67904, '\p{islydi}', "");
Expect(1, 67904, '\p{^islydi}', "");
Expect(1, 67904, '\P{islydi}', "");
Expect(0, 67904, '\P{^islydi}', "");
Expect(1, 67903, '\p{	_is_lydi}', "");
Expect(0, 67903, '\p{^	_is_lydi}', "");
Expect(0, 67903, '\P{	_is_lydi}', "");
Expect(1, 67903, '\P{^	_is_lydi}', "");
Expect(0, 67904, '\p{	_is_lydi}', "");
Expect(1, 67904, '\p{^	_is_lydi}', "");
Expect(1, 67904, '\P{	_is_lydi}', "");
Expect(0, 67904, '\P{^	_is_lydi}', "");
Error('\p{_/a/Mahjong_Tiles}');
Error('\P{_/a/Mahjong_Tiles}');
Expect(1, 127023, '\p{mahjongtiles}', "");
Expect(0, 127023, '\p{^mahjongtiles}', "");
Expect(0, 127023, '\P{mahjongtiles}', "");
Expect(1, 127023, '\P{^mahjongtiles}', "");
Expect(0, 127024, '\p{mahjongtiles}', "");
Expect(1, 127024, '\p{^mahjongtiles}', "");
Expect(1, 127024, '\P{mahjongtiles}', "");
Expect(0, 127024, '\P{^mahjongtiles}', "");
Expect(1, 127023, '\p{_ mahjong_TILES}', "");
Expect(0, 127023, '\p{^_ mahjong_TILES}', "");
Expect(0, 127023, '\P{_ mahjong_TILES}', "");
Expect(1, 127023, '\P{^_ mahjong_TILES}', "");
Expect(0, 127024, '\p{_ mahjong_TILES}', "");
Expect(1, 127024, '\p{^_ mahjong_TILES}', "");
Expect(1, 127024, '\P{_ mahjong_TILES}', "");
Expect(0, 127024, '\P{^_ mahjong_TILES}', "");
Error('\p{:=-_Is_Mahjong_Tiles}');
Error('\P{:=-_Is_Mahjong_Tiles}');
Expect(1, 127023, '\p{ismahjongtiles}', "");
Expect(0, 127023, '\p{^ismahjongtiles}', "");
Expect(0, 127023, '\P{ismahjongtiles}', "");
Expect(1, 127023, '\P{^ismahjongtiles}', "");
Expect(0, 127024, '\p{ismahjongtiles}', "");
Expect(1, 127024, '\p{^ismahjongtiles}', "");
Expect(1, 127024, '\P{ismahjongtiles}', "");
Expect(0, 127024, '\P{^ismahjongtiles}', "");
Expect(1, 127023, '\p{_Is_mahjong_Tiles}', "");
Expect(0, 127023, '\p{^_Is_mahjong_Tiles}', "");
Expect(0, 127023, '\P{_Is_mahjong_Tiles}', "");
Expect(1, 127023, '\P{^_Is_mahjong_Tiles}', "");
Expect(0, 127024, '\p{_Is_mahjong_Tiles}', "");
Expect(1, 127024, '\p{^_Is_mahjong_Tiles}', "");
Expect(1, 127024, '\P{_Is_mahjong_Tiles}', "");
Expect(0, 127024, '\P{^_Is_mahjong_Tiles}', "");
Error('\p{	 In_mahjong_TILES/a/}');
Error('\P{	 In_mahjong_TILES/a/}');
Expect(1, 127023, '\p{inmahjongtiles}', "");
Expect(0, 127023, '\p{^inmahjongtiles}', "");
Expect(0, 127023, '\P{inmahjongtiles}', "");
Expect(1, 127023, '\P{^inmahjongtiles}', "");
Expect(0, 127024, '\p{inmahjongtiles}', "");
Expect(1, 127024, '\p{^inmahjongtiles}', "");
Expect(1, 127024, '\P{inmahjongtiles}', "");
Expect(0, 127024, '\P{^inmahjongtiles}', "");
Expect(1, 127023, '\p{_ in_Mahjong_tiles}', "");
Expect(0, 127023, '\p{^_ in_Mahjong_tiles}', "");
Expect(0, 127023, '\P{_ in_Mahjong_tiles}', "");
Expect(1, 127023, '\P{^_ in_Mahjong_tiles}', "");
Expect(0, 127024, '\p{_ in_Mahjong_tiles}', "");
Expect(1, 127024, '\p{^_ in_Mahjong_tiles}', "");
Expect(1, 127024, '\P{_ in_Mahjong_tiles}', "");
Expect(0, 127024, '\P{^_ in_Mahjong_tiles}', "");
Error('\p{/a/_MAHJONG}');
Error('\P{/a/_MAHJONG}');
Expect(1, 127023, '\p{mahjong}', "");
Expect(0, 127023, '\p{^mahjong}', "");
Expect(0, 127023, '\P{mahjong}', "");
Expect(1, 127023, '\P{^mahjong}', "");
Expect(0, 127024, '\p{mahjong}', "");
Expect(1, 127024, '\p{^mahjong}', "");
Expect(1, 127024, '\P{mahjong}', "");
Expect(0, 127024, '\P{^mahjong}', "");
Expect(1, 127023, '\p{-Mahjong}', "");
Expect(0, 127023, '\p{^-Mahjong}', "");
Expect(0, 127023, '\P{-Mahjong}', "");
Expect(1, 127023, '\P{^-Mahjong}', "");
Expect(0, 127024, '\p{-Mahjong}', "");
Expect(1, 127024, '\p{^-Mahjong}', "");
Expect(1, 127024, '\P{-Mahjong}', "");
Expect(0, 127024, '\P{^-Mahjong}', "");
Error('\p{:=  Is_Mahjong}');
Error('\P{:=  Is_Mahjong}');
Expect(1, 127023, '\p{ismahjong}', "");
Expect(0, 127023, '\p{^ismahjong}', "");
Expect(0, 127023, '\P{ismahjong}', "");
Expect(1, 127023, '\P{^ismahjong}', "");
Expect(0, 127024, '\p{ismahjong}', "");
Expect(1, 127024, '\p{^ismahjong}', "");
Expect(1, 127024, '\P{ismahjong}', "");
Expect(0, 127024, '\P{^ismahjong}', "");
Expect(1, 127023, '\p{ 	Is_mahjong}', "");
Expect(0, 127023, '\p{^ 	Is_mahjong}', "");
Expect(0, 127023, '\P{ 	Is_mahjong}', "");
Expect(1, 127023, '\P{^ 	Is_mahjong}', "");
Expect(0, 127024, '\p{ 	Is_mahjong}', "");
Expect(1, 127024, '\p{^ 	Is_mahjong}', "");
Expect(1, 127024, '\P{ 	Is_mahjong}', "");
Expect(0, 127024, '\P{^ 	Is_mahjong}', "");
Error('\p{:=_In_mahjong}');
Error('\P{:=_In_mahjong}');
Expect(1, 127023, '\p{inmahjong}', "");
Expect(0, 127023, '\p{^inmahjong}', "");
Expect(0, 127023, '\P{inmahjong}', "");
Expect(1, 127023, '\P{^inmahjong}', "");
Expect(0, 127024, '\p{inmahjong}', "");
Expect(1, 127024, '\p{^inmahjong}', "");
Expect(1, 127024, '\P{inmahjong}', "");
Expect(0, 127024, '\P{^inmahjong}', "");
Expect(1, 127023, '\p{__In_mahjong}', "");
Expect(0, 127023, '\p{^__In_mahjong}', "");
Expect(0, 127023, '\P{__In_mahjong}', "");
Expect(1, 127023, '\P{^__In_mahjong}', "");
Expect(0, 127024, '\p{__In_mahjong}', "");
Expect(1, 127024, '\p{^__In_mahjong}', "");
Expect(1, 127024, '\P{__In_mahjong}', "");
Expect(0, 127024, '\P{^__In_mahjong}', "");
Error('\p{_:=Malayalam}');
Error('\P{_:=Malayalam}');
Expect(1, 3455, '\p{malayalam}', "");
Expect(0, 3455, '\p{^malayalam}', "");
Expect(0, 3455, '\P{malayalam}', "");
Expect(1, 3455, '\P{^malayalam}', "");
Expect(0, 3456, '\p{malayalam}', "");
Expect(1, 3456, '\p{^malayalam}', "");
Expect(1, 3456, '\P{malayalam}', "");
Expect(0, 3456, '\P{^malayalam}', "");
Expect(1, 3455, '\p{-MALAYALAM}', "");
Expect(0, 3455, '\p{^-MALAYALAM}', "");
Expect(0, 3455, '\P{-MALAYALAM}', "");
Expect(1, 3455, '\P{^-MALAYALAM}', "");
Expect(0, 3456, '\p{-MALAYALAM}', "");
Expect(1, 3456, '\p{^-MALAYALAM}', "");
Expect(1, 3456, '\P{-MALAYALAM}', "");
Expect(0, 3456, '\P{^-MALAYALAM}', "");
Error('\p{-:=IS_malayalam}');
Error('\P{-:=IS_malayalam}');
Expect(1, 3455, '\p{ismalayalam}', "");
Expect(0, 3455, '\p{^ismalayalam}', "");
Expect(0, 3455, '\P{ismalayalam}', "");
Expect(1, 3455, '\P{^ismalayalam}', "");
Expect(0, 3456, '\p{ismalayalam}', "");
Expect(1, 3456, '\p{^ismalayalam}', "");
Expect(1, 3456, '\P{ismalayalam}', "");
Expect(0, 3456, '\P{^ismalayalam}', "");
Expect(1, 3455, '\p{  Is_malayalam}', "");
Expect(0, 3455, '\p{^  Is_malayalam}', "");
Expect(0, 3455, '\P{  Is_malayalam}', "");
Expect(1, 3455, '\P{^  Is_malayalam}', "");
Expect(0, 3456, '\p{  Is_malayalam}', "");
Expect(1, 3456, '\p{^  Is_malayalam}', "");
Expect(1, 3456, '\P{  Is_malayalam}', "");
Expect(0, 3456, '\P{^  Is_malayalam}', "");
Error('\p{:=_ Mlym}');
Error('\P{:=_ Mlym}');
Expect(1, 3455, '\p{mlym}', "");
Expect(0, 3455, '\p{^mlym}', "");
Expect(0, 3455, '\P{mlym}', "");
Expect(1, 3455, '\P{^mlym}', "");
Expect(0, 3456, '\p{mlym}', "");
Expect(1, 3456, '\p{^mlym}', "");
Expect(1, 3456, '\P{mlym}', "");
Expect(0, 3456, '\P{^mlym}', "");
Expect(1, 3455, '\p{-	Mlym}', "");
Expect(0, 3455, '\p{^-	Mlym}', "");
Expect(0, 3455, '\P{-	Mlym}', "");
Expect(1, 3455, '\P{^-	Mlym}', "");
Expect(0, 3456, '\p{-	Mlym}', "");
Expect(1, 3456, '\p{^-	Mlym}', "");
Expect(1, 3456, '\P{-	Mlym}', "");
Expect(0, 3456, '\P{^-	Mlym}', "");
Error('\p{/a/ Is_mlym}');
Error('\P{/a/ Is_mlym}');
Expect(1, 3455, '\p{ismlym}', "");
Expect(0, 3455, '\p{^ismlym}', "");
Expect(0, 3455, '\P{ismlym}', "");
Expect(1, 3455, '\P{^ismlym}', "");
Expect(0, 3456, '\p{ismlym}', "");
Expect(1, 3456, '\p{^ismlym}', "");
Expect(1, 3456, '\P{ismlym}', "");
Expect(0, 3456, '\P{^ismlym}', "");
Expect(1, 3455, '\p{_Is_Mlym}', "");
Expect(0, 3455, '\p{^_Is_Mlym}', "");
Expect(0, 3455, '\P{_Is_Mlym}', "");
Expect(1, 3455, '\P{^_Is_Mlym}', "");
Expect(0, 3456, '\p{_Is_Mlym}', "");
Expect(1, 3456, '\p{^_Is_Mlym}', "");
Expect(1, 3456, '\P{_Is_Mlym}', "");
Expect(0, 3456, '\P{^_Is_Mlym}', "");
Error('\p{-mandaic:=}');
Error('\P{-mandaic:=}');
Expect(1, 2142, '\p{mandaic}', "");
Expect(0, 2142, '\p{^mandaic}', "");
Expect(0, 2142, '\P{mandaic}', "");
Expect(1, 2142, '\P{^mandaic}', "");
Expect(0, 2143, '\p{mandaic}', "");
Expect(1, 2143, '\p{^mandaic}', "");
Expect(1, 2143, '\P{mandaic}', "");
Expect(0, 2143, '\P{^mandaic}', "");
Expect(1, 2142, '\p{ _Mandaic}', "");
Expect(0, 2142, '\p{^ _Mandaic}', "");
Expect(0, 2142, '\P{ _Mandaic}', "");
Expect(1, 2142, '\P{^ _Mandaic}', "");
Expect(0, 2143, '\p{ _Mandaic}', "");
Expect(1, 2143, '\p{^ _Mandaic}', "");
Expect(1, 2143, '\P{ _Mandaic}', "");
Expect(0, 2143, '\P{^ _Mandaic}', "");
Error('\p{:=	-is_MANDAIC}');
Error('\P{:=	-is_MANDAIC}');
Expect(1, 2142, '\p{ismandaic}', "");
Expect(0, 2142, '\p{^ismandaic}', "");
Expect(0, 2142, '\P{ismandaic}', "");
Expect(1, 2142, '\P{^ismandaic}', "");
Expect(0, 2143, '\p{ismandaic}', "");
Expect(1, 2143, '\p{^ismandaic}', "");
Expect(1, 2143, '\P{ismandaic}', "");
Expect(0, 2143, '\P{^ismandaic}', "");
Expect(1, 2142, '\p{	 is_Mandaic}', "");
Expect(0, 2142, '\p{^	 is_Mandaic}', "");
Expect(0, 2142, '\P{	 is_Mandaic}', "");
Expect(1, 2142, '\P{^	 is_Mandaic}', "");
Expect(0, 2143, '\p{	 is_Mandaic}', "");
Expect(1, 2143, '\p{^	 is_Mandaic}', "");
Expect(1, 2143, '\P{	 is_Mandaic}', "");
Expect(0, 2143, '\P{^	 is_Mandaic}', "");
Error('\p{	/a/MAND}');
Error('\P{	/a/MAND}');
Expect(1, 2142, '\p{mand}', "");
Expect(0, 2142, '\p{^mand}', "");
Expect(0, 2142, '\P{mand}', "");
Expect(1, 2142, '\P{^mand}', "");
Expect(0, 2143, '\p{mand}', "");
Expect(1, 2143, '\p{^mand}', "");
Expect(1, 2143, '\P{mand}', "");
Expect(0, 2143, '\P{^mand}', "");
Expect(1, 2142, '\p{  Mand}', "");
Expect(0, 2142, '\p{^  Mand}', "");
Expect(0, 2142, '\P{  Mand}', "");
Expect(1, 2142, '\P{^  Mand}', "");
Expect(0, 2143, '\p{  Mand}', "");
Expect(1, 2143, '\p{^  Mand}', "");
Expect(1, 2143, '\P{  Mand}', "");
Expect(0, 2143, '\P{^  Mand}', "");
Error('\p{	 Is_MAND/a/}');
Error('\P{	 Is_MAND/a/}');
Expect(1, 2142, '\p{ismand}', "");
Expect(0, 2142, '\p{^ismand}', "");
Expect(0, 2142, '\P{ismand}', "");
Expect(1, 2142, '\P{^ismand}', "");
Expect(0, 2143, '\p{ismand}', "");
Expect(1, 2143, '\p{^ismand}', "");
Expect(1, 2143, '\P{ismand}', "");
Expect(0, 2143, '\P{^ismand}', "");
Expect(1, 2142, '\p{_IS_MAND}', "");
Expect(0, 2142, '\p{^_IS_MAND}', "");
Expect(0, 2142, '\P{_IS_MAND}', "");
Expect(1, 2142, '\P{^_IS_MAND}', "");
Expect(0, 2143, '\p{_IS_MAND}', "");
Expect(1, 2143, '\p{^_IS_MAND}', "");
Expect(1, 2143, '\P{_IS_MAND}', "");
Expect(0, 2143, '\P{^_IS_MAND}', "");
Error('\p{:=_ MARK}');
Error('\P{:=_ MARK}');
Expect(1, 917999, '\p{mark}', "");
Expect(0, 917999, '\p{^mark}', "");
Expect(0, 917999, '\P{mark}', "");
Expect(1, 917999, '\P{^mark}', "");
Expect(0, 918000, '\p{mark}', "");
Expect(1, 918000, '\p{^mark}', "");
Expect(1, 918000, '\P{mark}', "");
Expect(0, 918000, '\P{^mark}', "");
Expect(1, 917999, '\p{_	Mark}', "");
Expect(0, 917999, '\p{^_	Mark}', "");
Expect(0, 917999, '\P{_	Mark}', "");
Expect(1, 917999, '\P{^_	Mark}', "");
Expect(0, 918000, '\p{_	Mark}', "");
Expect(1, 918000, '\p{^_	Mark}', "");
Expect(1, 918000, '\P{_	Mark}', "");
Expect(0, 918000, '\P{^_	Mark}', "");
Error('\p{/a/	-is_MARK}');
Error('\P{/a/	-is_MARK}');
Expect(1, 917999, '\p{ismark}', "");
Expect(0, 917999, '\p{^ismark}', "");
Expect(0, 917999, '\P{ismark}', "");
Expect(1, 917999, '\P{^ismark}', "");
Expect(0, 918000, '\p{ismark}', "");
Expect(1, 918000, '\p{^ismark}', "");
Expect(1, 918000, '\P{ismark}', "");
Expect(0, 918000, '\P{^ismark}', "");
Expect(1, 917999, '\p{_is_mark}', "");
Expect(0, 917999, '\p{^_is_mark}', "");
Expect(0, 917999, '\P{_is_mark}', "");
Expect(1, 917999, '\P{^_is_mark}', "");
Expect(0, 918000, '\p{_is_mark}', "");
Expect(1, 918000, '\p{^_is_mark}', "");
Expect(1, 918000, '\P{_is_mark}', "");
Expect(0, 918000, '\P{^_is_mark}', "");
Error('\p{-:=M}');
Error('\P{-:=M}');
Expect(1, 917999, '\p{m}', "");
Expect(0, 917999, '\p{^m}', "");
Expect(0, 917999, '\P{m}', "");
Expect(1, 917999, '\P{^m}', "");
Expect(0, 918000, '\p{m}', "");
Expect(1, 918000, '\p{^m}', "");
Expect(1, 918000, '\P{m}', "");
Expect(0, 918000, '\P{^m}', "");
Expect(1, 917999, '\p{	M}', "");
Expect(0, 917999, '\p{^	M}', "");
Expect(0, 917999, '\P{	M}', "");
Expect(1, 917999, '\P{^	M}', "");
Expect(0, 918000, '\p{	M}', "");
Expect(1, 918000, '\p{^	M}', "");
Expect(1, 918000, '\P{	M}', "");
Expect(0, 918000, '\P{^	M}', "");
Error('\p{-/a/is_m}');
Error('\P{-/a/is_m}');
Expect(1, 917999, '\p{ism}', "");
Expect(0, 917999, '\p{^ism}', "");
Expect(0, 917999, '\P{ism}', "");
Expect(1, 917999, '\P{^ism}', "");
Expect(0, 918000, '\p{ism}', "");
Expect(1, 918000, '\p{^ism}', "");
Expect(1, 918000, '\P{ism}', "");
Expect(0, 918000, '\P{^ism}', "");
Expect(1, 917999, '\p{_is_M}', "");
Expect(0, 917999, '\p{^_is_M}', "");
Expect(0, 917999, '\P{_is_M}', "");
Expect(1, 917999, '\P{^_is_M}', "");
Expect(0, 918000, '\p{_is_M}', "");
Expect(1, 918000, '\p{^_is_M}', "");
Expect(1, 918000, '\P{_is_M}', "");
Expect(0, 918000, '\P{^_is_M}', "");
Error('\p{	/a/COMBINING_mark}');
Error('\P{	/a/COMBINING_mark}');
Expect(1, 917999, '\p{combiningmark}', "");
Expect(0, 917999, '\p{^combiningmark}', "");
Expect(0, 917999, '\P{combiningmark}', "");
Expect(1, 917999, '\P{^combiningmark}', "");
Expect(0, 918000, '\p{combiningmark}', "");
Expect(1, 918000, '\p{^combiningmark}', "");
Expect(1, 918000, '\P{combiningmark}', "");
Expect(0, 918000, '\P{^combiningmark}', "");
Expect(1, 917999, '\p{-	Combining_mark}', "");
Expect(0, 917999, '\p{^-	Combining_mark}', "");
Expect(0, 917999, '\P{-	Combining_mark}', "");
Expect(1, 917999, '\P{^-	Combining_mark}', "");
Expect(0, 918000, '\p{-	Combining_mark}', "");
Expect(1, 918000, '\p{^-	Combining_mark}', "");
Expect(1, 918000, '\P{-	Combining_mark}', "");
Expect(0, 918000, '\P{^-	Combining_mark}', "");
Error('\p{/a/_	Is_Combining_MARK}');
Error('\P{/a/_	Is_Combining_MARK}');
Expect(1, 917999, '\p{iscombiningmark}', "");
Expect(0, 917999, '\p{^iscombiningmark}', "");
Expect(0, 917999, '\P{iscombiningmark}', "");
Expect(1, 917999, '\P{^iscombiningmark}', "");
Expect(0, 918000, '\p{iscombiningmark}', "");
Expect(1, 918000, '\p{^iscombiningmark}', "");
Expect(1, 918000, '\P{iscombiningmark}', "");
Expect(0, 918000, '\P{^iscombiningmark}', "");
Expect(1, 917999, '\p{--Is_COMBINING_Mark}', "");
Expect(0, 917999, '\p{^--Is_COMBINING_Mark}', "");
Expect(0, 917999, '\P{--Is_COMBINING_Mark}', "");
Expect(1, 917999, '\P{^--Is_COMBINING_Mark}', "");
Expect(0, 918000, '\p{--Is_COMBINING_Mark}', "");
Expect(1, 918000, '\p{^--Is_COMBINING_Mark}', "");
Expect(1, 918000, '\P{--Is_COMBINING_Mark}', "");
Expect(0, 918000, '\P{^--Is_COMBINING_Mark}', "");
Error('\p{:=	-math}');
Error('\P{:=	-math}');
Expect(1, 126705, '\p{math}', "");
Expect(0, 126705, '\p{^math}', "");
Expect(0, 126705, '\P{math}', "");
Expect(1, 126705, '\P{^math}', "");
Expect(0, 126706, '\p{math}', "");
Expect(1, 126706, '\p{^math}', "");
Expect(1, 126706, '\P{math}', "");
Expect(0, 126706, '\P{^math}', "");
Expect(1, 126705, '\p{Math}', "");
Expect(0, 126705, '\p{^Math}', "");
Expect(0, 126705, '\P{Math}', "");
Expect(1, 126705, '\P{^Math}', "");
Expect(0, 126706, '\p{Math}', "");
Expect(1, 126706, '\p{^Math}', "");
Expect(1, 126706, '\P{Math}', "");
Expect(0, 126706, '\P{^Math}', "");
Error('\p{/a/ IS_Math}');
Error('\P{/a/ IS_Math}');
Expect(1, 126705, '\p{ismath}', "");
Expect(0, 126705, '\p{^ismath}', "");
Expect(0, 126705, '\P{ismath}', "");
Expect(1, 126705, '\P{^ismath}', "");
Expect(0, 126706, '\p{ismath}', "");
Expect(1, 126706, '\p{^ismath}', "");
Expect(1, 126706, '\P{ismath}', "");
Expect(0, 126706, '\P{^ismath}', "");
Expect(1, 126705, '\p{--Is_Math}', "");
Expect(0, 126705, '\p{^--Is_Math}', "");
Expect(0, 126705, '\P{--Is_Math}', "");
Expect(1, 126705, '\P{^--Is_Math}', "");
Expect(0, 126706, '\p{--Is_Math}', "");
Expect(1, 126706, '\p{^--Is_Math}', "");
Expect(1, 126706, '\P{--Is_Math}', "");
Expect(0, 126706, '\P{^--Is_Math}', "");
Error('\p{_ MATH_Symbol:=}');
Error('\P{_ MATH_Symbol:=}');
Expect(1, 126705, '\p{mathsymbol}', "");
Expect(0, 126705, '\p{^mathsymbol}', "");
Expect(0, 126705, '\P{mathsymbol}', "");
Expect(1, 126705, '\P{^mathsymbol}', "");
Expect(0, 126706, '\p{mathsymbol}', "");
Expect(1, 126706, '\p{^mathsymbol}', "");
Expect(1, 126706, '\P{mathsymbol}', "");
Expect(0, 126706, '\P{^mathsymbol}', "");
Expect(1, 126705, '\p{  Math_Symbol}', "");
Expect(0, 126705, '\p{^  Math_Symbol}', "");
Expect(0, 126705, '\P{  Math_Symbol}', "");
Expect(1, 126705, '\P{^  Math_Symbol}', "");
Expect(0, 126706, '\p{  Math_Symbol}', "");
Expect(1, 126706, '\p{^  Math_Symbol}', "");
Expect(1, 126706, '\P{  Math_Symbol}', "");
Expect(0, 126706, '\P{^  Math_Symbol}', "");
Error('\p{:=Is_Math_Symbol}');
Error('\P{:=Is_Math_Symbol}');
Expect(1, 126705, '\p{ismathsymbol}', "");
Expect(0, 126705, '\p{^ismathsymbol}', "");
Expect(0, 126705, '\P{ismathsymbol}', "");
Expect(1, 126705, '\P{^ismathsymbol}', "");
Expect(0, 126706, '\p{ismathsymbol}', "");
Expect(1, 126706, '\p{^ismathsymbol}', "");
Expect(1, 126706, '\P{ismathsymbol}', "");
Expect(0, 126706, '\P{^ismathsymbol}', "");
Expect(1, 126705, '\p{-Is_MATH_Symbol}', "");
Expect(0, 126705, '\p{^-Is_MATH_Symbol}', "");
Expect(0, 126705, '\P{-Is_MATH_Symbol}', "");
Expect(1, 126705, '\P{^-Is_MATH_Symbol}', "");
Expect(0, 126706, '\p{-Is_MATH_Symbol}', "");
Expect(1, 126706, '\p{^-Is_MATH_Symbol}', "");
Expect(1, 126706, '\P{-Is_MATH_Symbol}', "");
Expect(0, 126706, '\P{^-Is_MATH_Symbol}', "");
Error('\p{	/a/SM}');
Error('\P{	/a/SM}');
Expect(1, 126705, '\p{sm}', "");
Expect(0, 126705, '\p{^sm}', "");
Expect(0, 126705, '\P{sm}', "");
Expect(1, 126705, '\P{^sm}', "");
Expect(0, 126706, '\p{sm}', "");
Expect(1, 126706, '\p{^sm}', "");
Expect(1, 126706, '\P{sm}', "");
Expect(0, 126706, '\P{^sm}', "");
Expect(1, 126705, '\p{_-sm}', "");
Expect(0, 126705, '\p{^_-sm}', "");
Expect(0, 126705, '\P{_-sm}', "");
Expect(1, 126705, '\P{^_-sm}', "");
Expect(0, 126706, '\p{_-sm}', "");
Expect(1, 126706, '\p{^_-sm}', "");
Expect(1, 126706, '\P{_-sm}', "");
Expect(0, 126706, '\P{^_-sm}', "");
Error('\p{/a/_Is_sm}');
Error('\P{/a/_Is_sm}');
Expect(1, 126705, '\p{issm}', "");
Expect(0, 126705, '\p{^issm}', "");
Expect(0, 126705, '\P{issm}', "");
Expect(1, 126705, '\P{^issm}', "");
Expect(0, 126706, '\p{issm}', "");
Expect(1, 126706, '\p{^issm}', "");
Expect(1, 126706, '\P{issm}', "");
Expect(0, 126706, '\P{^issm}', "");
Expect(1, 126705, '\p{-Is_Sm}', "");
Expect(0, 126705, '\p{^-Is_Sm}', "");
Expect(0, 126705, '\P{-Is_Sm}', "");
Expect(1, 126705, '\P{^-Is_Sm}', "");
Expect(0, 126706, '\p{-Is_Sm}', "");
Expect(1, 126706, '\p{^-Is_Sm}', "");
Expect(1, 126706, '\P{-Is_Sm}', "");
Expect(0, 126706, '\P{^-Is_Sm}', "");
Error('\p{:=Mathematical_Alphanumeric_SYMBOLS}');
Error('\P{:=Mathematical_Alphanumeric_SYMBOLS}');
Expect(1, 120831, '\p{mathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\p{^mathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\P{mathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\P{^mathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\p{mathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\p{^mathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\P{mathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\P{^mathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\p{-_Mathematical_Alphanumeric_Symbols}', "");
Expect(0, 120831, '\p{^-_Mathematical_Alphanumeric_Symbols}', "");
Expect(0, 120831, '\P{-_Mathematical_Alphanumeric_Symbols}', "");
Expect(1, 120831, '\P{^-_Mathematical_Alphanumeric_Symbols}', "");
Expect(0, 120832, '\p{-_Mathematical_Alphanumeric_Symbols}', "");
Expect(1, 120832, '\p{^-_Mathematical_Alphanumeric_Symbols}', "");
Expect(1, 120832, '\P{-_Mathematical_Alphanumeric_Symbols}', "");
Expect(0, 120832, '\P{^-_Mathematical_Alphanumeric_Symbols}', "");
Error('\p{/a/	is_Mathematical_Alphanumeric_Symbols}');
Error('\P{/a/	is_Mathematical_Alphanumeric_Symbols}');
Expect(1, 120831, '\p{ismathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\p{^ismathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\P{ismathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\P{^ismathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\p{ismathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\p{^ismathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\P{ismathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\P{^ismathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\p{__is_Mathematical_alphanumeric_Symbols}', "");
Expect(0, 120831, '\p{^__is_Mathematical_alphanumeric_Symbols}', "");
Expect(0, 120831, '\P{__is_Mathematical_alphanumeric_Symbols}', "");
Expect(1, 120831, '\P{^__is_Mathematical_alphanumeric_Symbols}', "");
Expect(0, 120832, '\p{__is_Mathematical_alphanumeric_Symbols}', "");
Expect(1, 120832, '\p{^__is_Mathematical_alphanumeric_Symbols}', "");
Expect(1, 120832, '\P{__is_Mathematical_alphanumeric_Symbols}', "");
Expect(0, 120832, '\P{^__is_Mathematical_alphanumeric_Symbols}', "");
Error('\p{:=-IN_Mathematical_ALPHANUMERIC_Symbols}');
Error('\P{:=-IN_Mathematical_ALPHANUMERIC_Symbols}');
Expect(1, 120831, '\p{inmathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\p{^inmathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\P{inmathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\P{^inmathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\p{inmathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\p{^inmathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\P{inmathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\P{^inmathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\p{- In_mathematical_Alphanumeric_Symbols}', "");
Expect(0, 120831, '\p{^- In_mathematical_Alphanumeric_Symbols}', "");
Expect(0, 120831, '\P{- In_mathematical_Alphanumeric_Symbols}', "");
Expect(1, 120831, '\P{^- In_mathematical_Alphanumeric_Symbols}', "");
Expect(0, 120832, '\p{- In_mathematical_Alphanumeric_Symbols}', "");
Expect(1, 120832, '\p{^- In_mathematical_Alphanumeric_Symbols}', "");
Expect(1, 120832, '\P{- In_mathematical_Alphanumeric_Symbols}', "");
Expect(0, 120832, '\P{^- In_mathematical_Alphanumeric_Symbols}', "");
Error('\p{:= -MATH_Alphanum}');
Error('\P{:= -MATH_Alphanum}');
Expect(1, 120831, '\p{mathalphanum}', "");
Expect(0, 120831, '\p{^mathalphanum}', "");
Expect(0, 120831, '\P{mathalphanum}', "");
Expect(1, 120831, '\P{^mathalphanum}', "");
Expect(0, 120832, '\p{mathalphanum}', "");
Expect(1, 120832, '\p{^mathalphanum}', "");
Expect(1, 120832, '\P{mathalphanum}', "");
Expect(0, 120832, '\P{^mathalphanum}', "");
Expect(1, 120831, '\p{MATH_Alphanum}', "");
Expect(0, 120831, '\p{^MATH_Alphanum}', "");
Expect(0, 120831, '\P{MATH_Alphanum}', "");
Expect(1, 120831, '\P{^MATH_Alphanum}', "");
Expect(0, 120832, '\p{MATH_Alphanum}', "");
Expect(1, 120832, '\p{^MATH_Alphanum}', "");
Expect(1, 120832, '\P{MATH_Alphanum}', "");
Expect(0, 120832, '\P{^MATH_Alphanum}', "");
Error('\p{/a/_Is_MATH_Alphanum}');
Error('\P{/a/_Is_MATH_Alphanum}');
Expect(1, 120831, '\p{ismathalphanum}', "");
Expect(0, 120831, '\p{^ismathalphanum}', "");
Expect(0, 120831, '\P{ismathalphanum}', "");
Expect(1, 120831, '\P{^ismathalphanum}', "");
Expect(0, 120832, '\p{ismathalphanum}', "");
Expect(1, 120832, '\p{^ismathalphanum}', "");
Expect(1, 120832, '\P{ismathalphanum}', "");
Expect(0, 120832, '\P{^ismathalphanum}', "");
Expect(1, 120831, '\p{	Is_math_alphanum}', "");
Expect(0, 120831, '\p{^	Is_math_alphanum}', "");
Expect(0, 120831, '\P{	Is_math_alphanum}', "");
Expect(1, 120831, '\P{^	Is_math_alphanum}', "");
Expect(0, 120832, '\p{	Is_math_alphanum}', "");
Expect(1, 120832, '\p{^	Is_math_alphanum}', "");
Expect(1, 120832, '\P{	Is_math_alphanum}', "");
Expect(0, 120832, '\P{^	Is_math_alphanum}', "");
Error('\p{-/a/IN_math_Alphanum}');
Error('\P{-/a/IN_math_Alphanum}');
Expect(1, 120831, '\p{inmathalphanum}', "");
Expect(0, 120831, '\p{^inmathalphanum}', "");
Expect(0, 120831, '\P{inmathalphanum}', "");
Expect(1, 120831, '\P{^inmathalphanum}', "");
Expect(0, 120832, '\p{inmathalphanum}', "");
Expect(1, 120832, '\p{^inmathalphanum}', "");
Expect(1, 120832, '\P{inmathalphanum}', "");
Expect(0, 120832, '\P{^inmathalphanum}', "");
Expect(1, 120831, '\p{ In_MATH_ALPHANUM}', "");
Expect(0, 120831, '\p{^ In_MATH_ALPHANUM}', "");
Expect(0, 120831, '\P{ In_MATH_ALPHANUM}', "");
Expect(1, 120831, '\P{^ In_MATH_ALPHANUM}', "");
Expect(0, 120832, '\p{ In_MATH_ALPHANUM}', "");
Expect(1, 120832, '\p{^ In_MATH_ALPHANUM}', "");
Expect(1, 120832, '\P{ In_MATH_ALPHANUM}', "");
Expect(0, 120832, '\P{^ In_MATH_ALPHANUM}', "");
Error('\p{/a/__mathematical_Operators}');
Error('\P{/a/__mathematical_Operators}');
Expect(1, 8959, '\p{mathematicaloperators}', "");
Expect(0, 8959, '\p{^mathematicaloperators}', "");
Expect(0, 8959, '\P{mathematicaloperators}', "");
Expect(1, 8959, '\P{^mathematicaloperators}', "");
Expect(0, 8960, '\p{mathematicaloperators}', "");
Expect(1, 8960, '\p{^mathematicaloperators}', "");
Expect(1, 8960, '\P{mathematicaloperators}', "");
Expect(0, 8960, '\P{^mathematicaloperators}', "");
Expect(1, 8959, '\p{ Mathematical_Operators}', "");
Expect(0, 8959, '\p{^ Mathematical_Operators}', "");
Expect(0, 8959, '\P{ Mathematical_Operators}', "");
Expect(1, 8959, '\P{^ Mathematical_Operators}', "");
Expect(0, 8960, '\p{ Mathematical_Operators}', "");
Expect(1, 8960, '\p{^ Mathematical_Operators}', "");
Expect(1, 8960, '\P{ Mathematical_Operators}', "");
Expect(0, 8960, '\P{^ Mathematical_Operators}', "");
Error('\p{:=-is_MATHEMATICAL_operators}');
Error('\P{:=-is_MATHEMATICAL_operators}');
Expect(1, 8959, '\p{ismathematicaloperators}', "");
Expect(0, 8959, '\p{^ismathematicaloperators}', "");
Expect(0, 8959, '\P{ismathematicaloperators}', "");
Expect(1, 8959, '\P{^ismathematicaloperators}', "");
Expect(0, 8960, '\p{ismathematicaloperators}', "");
Expect(1, 8960, '\p{^ismathematicaloperators}', "");
Expect(1, 8960, '\P{ismathematicaloperators}', "");
Expect(0, 8960, '\P{^ismathematicaloperators}', "");
Expect(1, 8959, '\p{ Is_MATHEMATICAL_operators}', "");
Expect(0, 8959, '\p{^ Is_MATHEMATICAL_operators}', "");
Expect(0, 8959, '\P{ Is_MATHEMATICAL_operators}', "");
Expect(1, 8959, '\P{^ Is_MATHEMATICAL_operators}', "");
Expect(0, 8960, '\p{ Is_MATHEMATICAL_operators}', "");
Expect(1, 8960, '\p{^ Is_MATHEMATICAL_operators}', "");
Expect(1, 8960, '\P{ Is_MATHEMATICAL_operators}', "");
Expect(0, 8960, '\P{^ Is_MATHEMATICAL_operators}', "");
Error('\p{_:=in_MATHEMATICAL_OPERATORS}');
Error('\P{_:=in_MATHEMATICAL_OPERATORS}');
Expect(1, 8959, '\p{inmathematicaloperators}', "");
Expect(0, 8959, '\p{^inmathematicaloperators}', "");
Expect(0, 8959, '\P{inmathematicaloperators}', "");
Expect(1, 8959, '\P{^inmathematicaloperators}', "");
Expect(0, 8960, '\p{inmathematicaloperators}', "");
Expect(1, 8960, '\p{^inmathematicaloperators}', "");
Expect(1, 8960, '\P{inmathematicaloperators}', "");
Expect(0, 8960, '\P{^inmathematicaloperators}', "");
Expect(1, 8959, '\p{	 IN_Mathematical_Operators}', "");
Expect(0, 8959, '\p{^	 IN_Mathematical_Operators}', "");
Expect(0, 8959, '\P{	 IN_Mathematical_Operators}', "");
Expect(1, 8959, '\P{^	 IN_Mathematical_Operators}', "");
Expect(0, 8960, '\p{	 IN_Mathematical_Operators}', "");
Expect(1, 8960, '\p{^	 IN_Mathematical_Operators}', "");
Expect(1, 8960, '\P{	 IN_Mathematical_Operators}', "");
Expect(0, 8960, '\P{^	 IN_Mathematical_Operators}', "");
Error('\p{-/a/math_operators}');
Error('\P{-/a/math_operators}');
Expect(1, 8959, '\p{mathoperators}', "");
Expect(0, 8959, '\p{^mathoperators}', "");
Expect(0, 8959, '\P{mathoperators}', "");
Expect(1, 8959, '\P{^mathoperators}', "");
Expect(0, 8960, '\p{mathoperators}', "");
Expect(1, 8960, '\p{^mathoperators}', "");
Expect(1, 8960, '\P{mathoperators}', "");
Expect(0, 8960, '\P{^mathoperators}', "");
Expect(1, 8959, '\p{	 MATH_OPERATORS}', "");
Expect(0, 8959, '\p{^	 MATH_OPERATORS}', "");
Expect(0, 8959, '\P{	 MATH_OPERATORS}', "");
Expect(1, 8959, '\P{^	 MATH_OPERATORS}', "");
Expect(0, 8960, '\p{	 MATH_OPERATORS}', "");
Expect(1, 8960, '\p{^	 MATH_OPERATORS}', "");
Expect(1, 8960, '\P{	 MATH_OPERATORS}', "");
Expect(0, 8960, '\P{^	 MATH_OPERATORS}', "");
Error('\p{:=_	Is_MATH_Operators}');
Error('\P{:=_	Is_MATH_Operators}');
Expect(1, 8959, '\p{ismathoperators}', "");
Expect(0, 8959, '\p{^ismathoperators}', "");
Expect(0, 8959, '\P{ismathoperators}', "");
Expect(1, 8959, '\P{^ismathoperators}', "");
Expect(0, 8960, '\p{ismathoperators}', "");
Expect(1, 8960, '\p{^ismathoperators}', "");
Expect(1, 8960, '\P{ismathoperators}', "");
Expect(0, 8960, '\P{^ismathoperators}', "");
Expect(1, 8959, '\p{	is_Math_Operators}', "");
Expect(0, 8959, '\p{^	is_Math_Operators}', "");
Expect(0, 8959, '\P{	is_Math_Operators}', "");
Expect(1, 8959, '\P{^	is_Math_Operators}', "");
Expect(0, 8960, '\p{	is_Math_Operators}', "");
Expect(1, 8960, '\p{^	is_Math_Operators}', "");
Expect(1, 8960, '\P{	is_Math_Operators}', "");
Expect(0, 8960, '\P{^	is_Math_Operators}', "");
Error('\p{__In_math_Operators:=}');
Error('\P{__In_math_Operators:=}');
Expect(1, 8959, '\p{inmathoperators}', "");
Expect(0, 8959, '\p{^inmathoperators}', "");
Expect(0, 8959, '\P{inmathoperators}', "");
Expect(1, 8959, '\P{^inmathoperators}', "");
Expect(0, 8960, '\p{inmathoperators}', "");
Expect(1, 8960, '\p{^inmathoperators}', "");
Expect(1, 8960, '\P{inmathoperators}', "");
Expect(0, 8960, '\P{^inmathoperators}', "");
Expect(1, 8959, '\p{	_in_Math_operators}', "");
Expect(0, 8959, '\p{^	_in_Math_operators}', "");
Expect(0, 8959, '\P{	_in_Math_operators}', "");
Expect(1, 8959, '\P{^	_in_Math_operators}', "");
Expect(0, 8960, '\p{	_in_Math_operators}', "");
Expect(1, 8960, '\p{^	_in_Math_operators}', "");
Expect(1, 8960, '\P{	_in_Math_operators}', "");
Expect(0, 8960, '\P{^	_in_Math_operators}', "");
Error('\p{ :=Meetei_MAYEK}');
Error('\P{ :=Meetei_MAYEK}');
Expect(1, 44025, '\p{meeteimayek}', "");
Expect(0, 44025, '\p{^meeteimayek}', "");
Expect(0, 44025, '\P{meeteimayek}', "");
Expect(1, 44025, '\P{^meeteimayek}', "");
Expect(0, 44026, '\p{meeteimayek}', "");
Expect(1, 44026, '\p{^meeteimayek}', "");
Expect(1, 44026, '\P{meeteimayek}', "");
Expect(0, 44026, '\P{^meeteimayek}', "");
Expect(1, 44025, '\p{_	Meetei_Mayek}', "");
Expect(0, 44025, '\p{^_	Meetei_Mayek}', "");
Expect(0, 44025, '\P{_	Meetei_Mayek}', "");
Expect(1, 44025, '\P{^_	Meetei_Mayek}', "");
Expect(0, 44026, '\p{_	Meetei_Mayek}', "");
Expect(1, 44026, '\p{^_	Meetei_Mayek}', "");
Expect(1, 44026, '\P{_	Meetei_Mayek}', "");
Expect(0, 44026, '\P{^_	Meetei_Mayek}', "");
Error('\p{/a/	Is_meetei_mayek}');
Error('\P{/a/	Is_meetei_mayek}');
Expect(1, 44025, '\p{ismeeteimayek}', "");
Expect(0, 44025, '\p{^ismeeteimayek}', "");
Expect(0, 44025, '\P{ismeeteimayek}', "");
Expect(1, 44025, '\P{^ismeeteimayek}', "");
Expect(0, 44026, '\p{ismeeteimayek}', "");
Expect(1, 44026, '\p{^ismeeteimayek}', "");
Expect(1, 44026, '\P{ismeeteimayek}', "");
Expect(0, 44026, '\P{^ismeeteimayek}', "");
Expect(1, 44025, '\p{  is_meetei_Mayek}', "");
Expect(0, 44025, '\p{^  is_meetei_Mayek}', "");
Expect(0, 44025, '\P{  is_meetei_Mayek}', "");
Expect(1, 44025, '\P{^  is_meetei_Mayek}', "");
Expect(0, 44026, '\p{  is_meetei_Mayek}', "");
Expect(1, 44026, '\p{^  is_meetei_Mayek}', "");
Expect(1, 44026, '\P{  is_meetei_Mayek}', "");
Expect(0, 44026, '\P{^  is_meetei_Mayek}', "");
Error('\p{  MTEI:=}');
Error('\P{  MTEI:=}');
Expect(1, 44025, '\p{mtei}', "");
Expect(0, 44025, '\p{^mtei}', "");
Expect(0, 44025, '\P{mtei}', "");
Expect(1, 44025, '\P{^mtei}', "");
Expect(0, 44026, '\p{mtei}', "");
Expect(1, 44026, '\p{^mtei}', "");
Expect(1, 44026, '\P{mtei}', "");
Expect(0, 44026, '\P{^mtei}', "");
Expect(1, 44025, '\p{	_mtei}', "");
Expect(0, 44025, '\p{^	_mtei}', "");
Expect(0, 44025, '\P{	_mtei}', "");
Expect(1, 44025, '\P{^	_mtei}', "");
Expect(0, 44026, '\p{	_mtei}', "");
Expect(1, 44026, '\p{^	_mtei}', "");
Expect(1, 44026, '\P{	_mtei}', "");
Expect(0, 44026, '\P{^	_mtei}', "");
Error('\p{/a/_-IS_Mtei}');
Error('\P{/a/_-IS_Mtei}');
Expect(1, 44025, '\p{ismtei}', "");
Expect(0, 44025, '\p{^ismtei}', "");
Expect(0, 44025, '\P{ismtei}', "");
Expect(1, 44025, '\P{^ismtei}', "");
Expect(0, 44026, '\p{ismtei}', "");
Expect(1, 44026, '\p{^ismtei}', "");
Expect(1, 44026, '\P{ismtei}', "");
Expect(0, 44026, '\P{^ismtei}', "");
Expect(1, 44025, '\p{ -is_Mtei}', "");
Expect(0, 44025, '\p{^ -is_Mtei}', "");
Expect(0, 44025, '\P{ -is_Mtei}', "");
Expect(1, 44025, '\P{^ -is_Mtei}', "");
Expect(0, 44026, '\p{ -is_Mtei}', "");
Expect(1, 44026, '\p{^ -is_Mtei}', "");
Expect(1, 44026, '\P{ -is_Mtei}', "");
Expect(0, 44026, '\P{^ -is_Mtei}', "");
Error('\p{_:=MEETEI_Mayek_Extensions}');
Error('\P{_:=MEETEI_Mayek_Extensions}');
Expect(1, 43775, '\p{meeteimayekextensions}', "");
Expect(0, 43775, '\p{^meeteimayekextensions}', "");
Expect(0, 43775, '\P{meeteimayekextensions}', "");
Expect(1, 43775, '\P{^meeteimayekextensions}', "");
Expect(0, 43776, '\p{meeteimayekextensions}', "");
Expect(1, 43776, '\p{^meeteimayekextensions}', "");
Expect(1, 43776, '\P{meeteimayekextensions}', "");
Expect(0, 43776, '\P{^meeteimayekextensions}', "");
Expect(1, 43775, '\p{_	Meetei_Mayek_Extensions}', "");
Expect(0, 43775, '\p{^_	Meetei_Mayek_Extensions}', "");
Expect(0, 43775, '\P{_	Meetei_Mayek_Extensions}', "");
Expect(1, 43775, '\P{^_	Meetei_Mayek_Extensions}', "");
Expect(0, 43776, '\p{_	Meetei_Mayek_Extensions}', "");
Expect(1, 43776, '\p{^_	Meetei_Mayek_Extensions}', "");
Expect(1, 43776, '\P{_	Meetei_Mayek_Extensions}', "");
Expect(0, 43776, '\P{^_	Meetei_Mayek_Extensions}', "");
Error('\p{	/a/Is_MEETEI_Mayek_EXTENSIONS}');
Error('\P{	/a/Is_MEETEI_Mayek_EXTENSIONS}');
Expect(1, 43775, '\p{ismeeteimayekextensions}', "");
Expect(0, 43775, '\p{^ismeeteimayekextensions}', "");
Expect(0, 43775, '\P{ismeeteimayekextensions}', "");
Expect(1, 43775, '\P{^ismeeteimayekextensions}', "");
Expect(0, 43776, '\p{ismeeteimayekextensions}', "");
Expect(1, 43776, '\p{^ismeeteimayekextensions}', "");
Expect(1, 43776, '\P{ismeeteimayekextensions}', "");
Expect(0, 43776, '\P{^ismeeteimayekextensions}', "");
Expect(1, 43775, '\p{ 	Is_Meetei_Mayek_Extensions}', "");
Expect(0, 43775, '\p{^ 	Is_Meetei_Mayek_Extensions}', "");
Expect(0, 43775, '\P{ 	Is_Meetei_Mayek_Extensions}', "");
Expect(1, 43775, '\P{^ 	Is_Meetei_Mayek_Extensions}', "");
Expect(0, 43776, '\p{ 	Is_Meetei_Mayek_Extensions}', "");
Expect(1, 43776, '\p{^ 	Is_Meetei_Mayek_Extensions}', "");
Expect(1, 43776, '\P{ 	Is_Meetei_Mayek_Extensions}', "");
Expect(0, 43776, '\P{^ 	Is_Meetei_Mayek_Extensions}', "");
Error('\p{  In_Meetei_Mayek_extensions/a/}');
Error('\P{  In_Meetei_Mayek_extensions/a/}');
Expect(1, 43775, '\p{inmeeteimayekextensions}', "");
Expect(0, 43775, '\p{^inmeeteimayekextensions}', "");
Expect(0, 43775, '\P{inmeeteimayekextensions}', "");
Expect(1, 43775, '\P{^inmeeteimayekextensions}', "");
Expect(0, 43776, '\p{inmeeteimayekextensions}', "");
Expect(1, 43776, '\p{^inmeeteimayekextensions}', "");
Expect(1, 43776, '\P{inmeeteimayekextensions}', "");
Expect(0, 43776, '\P{^inmeeteimayekextensions}', "");
Expect(1, 43775, '\p{-IN_MEETEI_MAYEK_extensions}', "");
Expect(0, 43775, '\p{^-IN_MEETEI_MAYEK_extensions}', "");
Expect(0, 43775, '\P{-IN_MEETEI_MAYEK_extensions}', "");
Expect(1, 43775, '\P{^-IN_MEETEI_MAYEK_extensions}', "");
Expect(0, 43776, '\p{-IN_MEETEI_MAYEK_extensions}', "");
Expect(1, 43776, '\p{^-IN_MEETEI_MAYEK_extensions}', "");
Expect(1, 43776, '\P{-IN_MEETEI_MAYEK_extensions}', "");
Expect(0, 43776, '\P{^-IN_MEETEI_MAYEK_extensions}', "");
Error('\p{/a/_-MEETEI_Mayek_EXT}');
Error('\P{/a/_-MEETEI_Mayek_EXT}');
Expect(1, 43775, '\p{meeteimayekext}', "");
Expect(0, 43775, '\p{^meeteimayekext}', "");
Expect(0, 43775, '\P{meeteimayekext}', "");
Expect(1, 43775, '\P{^meeteimayekext}', "");
Expect(0, 43776, '\p{meeteimayekext}', "");
Expect(1, 43776, '\p{^meeteimayekext}', "");
Expect(1, 43776, '\P{meeteimayekext}', "");
Expect(0, 43776, '\P{^meeteimayekext}', "");
Expect(1, 43775, '\p{	_MEETEI_mayek_Ext}', "");
Expect(0, 43775, '\p{^	_MEETEI_mayek_Ext}', "");
Expect(0, 43775, '\P{	_MEETEI_mayek_Ext}', "");
Expect(1, 43775, '\P{^	_MEETEI_mayek_Ext}', "");
Expect(0, 43776, '\p{	_MEETEI_mayek_Ext}', "");
Expect(1, 43776, '\p{^	_MEETEI_mayek_Ext}', "");
Expect(1, 43776, '\P{	_MEETEI_mayek_Ext}', "");
Expect(0, 43776, '\P{^	_MEETEI_mayek_Ext}', "");
Error('\p{:= Is_Meetei_mayek_Ext}');
Error('\P{:= Is_Meetei_mayek_Ext}');
Expect(1, 43775, '\p{ismeeteimayekext}', "");
Expect(0, 43775, '\p{^ismeeteimayekext}', "");
Expect(0, 43775, '\P{ismeeteimayekext}', "");
Expect(1, 43775, '\P{^ismeeteimayekext}', "");
Expect(0, 43776, '\p{ismeeteimayekext}', "");
Expect(1, 43776, '\p{^ismeeteimayekext}', "");
Expect(1, 43776, '\P{ismeeteimayekext}', "");
Expect(0, 43776, '\P{^ismeeteimayekext}', "");
Expect(1, 43775, '\p{	Is_Meetei_mayek_EXT}', "");
Expect(0, 43775, '\p{^	Is_Meetei_mayek_EXT}', "");
Expect(0, 43775, '\P{	Is_Meetei_mayek_EXT}', "");
Expect(1, 43775, '\P{^	Is_Meetei_mayek_EXT}', "");
Expect(0, 43776, '\p{	Is_Meetei_mayek_EXT}', "");
Expect(1, 43776, '\p{^	Is_Meetei_mayek_EXT}', "");
Expect(1, 43776, '\P{	Is_Meetei_mayek_EXT}', "");
Expect(0, 43776, '\P{^	Is_Meetei_mayek_EXT}', "");
Error('\p{-/a/IN_Meetei_mayek_Ext}');
Error('\P{-/a/IN_Meetei_mayek_Ext}');
Expect(1, 43775, '\p{inmeeteimayekext}', "");
Expect(0, 43775, '\p{^inmeeteimayekext}', "");
Expect(0, 43775, '\P{inmeeteimayekext}', "");
Expect(1, 43775, '\P{^inmeeteimayekext}', "");
Expect(0, 43776, '\p{inmeeteimayekext}', "");
Expect(1, 43776, '\p{^inmeeteimayekext}', "");
Expect(1, 43776, '\P{inmeeteimayekext}', "");
Expect(0, 43776, '\P{^inmeeteimayekext}', "");
Expect(1, 43775, '\p{_In_Meetei_MAYEK_Ext}', "");
Expect(0, 43775, '\p{^_In_Meetei_MAYEK_Ext}', "");
Expect(0, 43775, '\P{_In_Meetei_MAYEK_Ext}', "");
Expect(1, 43775, '\P{^_In_Meetei_MAYEK_Ext}', "");
Expect(0, 43776, '\p{_In_Meetei_MAYEK_Ext}', "");
Expect(1, 43776, '\p{^_In_Meetei_MAYEK_Ext}', "");
Expect(1, 43776, '\P{_In_Meetei_MAYEK_Ext}', "");
Expect(0, 43776, '\P{^_In_Meetei_MAYEK_Ext}', "");
Error('\p{ Meroitic_Cursive/a/}');
Error('\P{ Meroitic_Cursive/a/}');
Expect(1, 68031, '\p{meroiticcursive}', "");
Expect(0, 68031, '\p{^meroiticcursive}', "");
Expect(0, 68031, '\P{meroiticcursive}', "");
Expect(1, 68031, '\P{^meroiticcursive}', "");
Expect(0, 68032, '\p{meroiticcursive}', "");
Expect(1, 68032, '\p{^meroiticcursive}', "");
Expect(1, 68032, '\P{meroiticcursive}', "");
Expect(0, 68032, '\P{^meroiticcursive}', "");
Expect(1, 68031, '\p{_ Meroitic_Cursive}', "");
Expect(0, 68031, '\p{^_ Meroitic_Cursive}', "");
Expect(0, 68031, '\P{_ Meroitic_Cursive}', "");
Expect(1, 68031, '\P{^_ Meroitic_Cursive}', "");
Expect(0, 68032, '\p{_ Meroitic_Cursive}', "");
Expect(1, 68032, '\p{^_ Meroitic_Cursive}', "");
Expect(1, 68032, '\P{_ Meroitic_Cursive}', "");
Expect(0, 68032, '\P{^_ Meroitic_Cursive}', "");
Error('\p{	Is_MEROITIC_cursive/a/}');
Error('\P{	Is_MEROITIC_cursive/a/}');
Expect(1, 68031, '\p{ismeroiticcursive}', "");
Expect(0, 68031, '\p{^ismeroiticcursive}', "");
Expect(0, 68031, '\P{ismeroiticcursive}', "");
Expect(1, 68031, '\P{^ismeroiticcursive}', "");
Expect(0, 68032, '\p{ismeroiticcursive}', "");
Expect(1, 68032, '\p{^ismeroiticcursive}', "");
Expect(1, 68032, '\P{ismeroiticcursive}', "");
Expect(0, 68032, '\P{^ismeroiticcursive}', "");
Expect(1, 68031, '\p{--Is_MEROITIC_CURSIVE}', "");
Expect(0, 68031, '\p{^--Is_MEROITIC_CURSIVE}', "");
Expect(0, 68031, '\P{--Is_MEROITIC_CURSIVE}', "");
Expect(1, 68031, '\P{^--Is_MEROITIC_CURSIVE}', "");
Expect(0, 68032, '\p{--Is_MEROITIC_CURSIVE}', "");
Expect(1, 68032, '\p{^--Is_MEROITIC_CURSIVE}', "");
Expect(1, 68032, '\P{--Is_MEROITIC_CURSIVE}', "");
Expect(0, 68032, '\P{^--Is_MEROITIC_CURSIVE}', "");
Error('\p{_-MERC:=}');
Error('\P{_-MERC:=}');
Expect(1, 68031, '\p{merc}', "");
Expect(0, 68031, '\p{^merc}', "");
Expect(0, 68031, '\P{merc}', "");
Expect(1, 68031, '\P{^merc}', "");
Expect(0, 68032, '\p{merc}', "");
Expect(1, 68032, '\p{^merc}', "");
Expect(1, 68032, '\P{merc}', "");
Expect(0, 68032, '\P{^merc}', "");
Expect(1, 68031, '\p{-	Merc}', "");
Expect(0, 68031, '\p{^-	Merc}', "");
Expect(0, 68031, '\P{-	Merc}', "");
Expect(1, 68031, '\P{^-	Merc}', "");
Expect(0, 68032, '\p{-	Merc}', "");
Expect(1, 68032, '\p{^-	Merc}', "");
Expect(1, 68032, '\P{-	Merc}', "");
Expect(0, 68032, '\P{^-	Merc}', "");
Error('\p{:=_is_Merc}');
Error('\P{:=_is_Merc}');
Expect(1, 68031, '\p{ismerc}', "");
Expect(0, 68031, '\p{^ismerc}', "");
Expect(0, 68031, '\P{ismerc}', "");
Expect(1, 68031, '\P{^ismerc}', "");
Expect(0, 68032, '\p{ismerc}', "");
Expect(1, 68032, '\p{^ismerc}', "");
Expect(1, 68032, '\P{ismerc}', "");
Expect(0, 68032, '\P{^ismerc}', "");
Expect(1, 68031, '\p{_ is_Merc}', "");
Expect(0, 68031, '\p{^_ is_Merc}', "");
Expect(0, 68031, '\P{_ is_Merc}', "");
Expect(1, 68031, '\P{^_ is_Merc}', "");
Expect(0, 68032, '\p{_ is_Merc}', "");
Expect(1, 68032, '\p{^_ is_Merc}', "");
Expect(1, 68032, '\P{_ is_Merc}', "");
Expect(0, 68032, '\P{^_ is_Merc}', "");
Error('\p{_:=MEROITIC_Hieroglyphs}');
Error('\P{_:=MEROITIC_Hieroglyphs}');
Expect(1, 67999, '\p{meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^meroitichieroglyphs}', "");
Expect(0, 67999, '\P{meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^meroitichieroglyphs}', "");
Expect(0, 68000, '\p{meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^meroitichieroglyphs}', "");
Expect(1, 68000, '\P{meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^meroitichieroglyphs}', "");
Expect(1, 67999, '\p{_Meroitic_HIEROGLYPHS}', "");
Expect(0, 67999, '\p{^_Meroitic_HIEROGLYPHS}', "");
Expect(0, 67999, '\P{_Meroitic_HIEROGLYPHS}', "");
Expect(1, 67999, '\P{^_Meroitic_HIEROGLYPHS}', "");
Expect(0, 68000, '\p{_Meroitic_HIEROGLYPHS}', "");
Expect(1, 68000, '\p{^_Meroitic_HIEROGLYPHS}', "");
Expect(1, 68000, '\P{_Meroitic_HIEROGLYPHS}', "");
Expect(0, 68000, '\P{^_Meroitic_HIEROGLYPHS}', "");
Error('\p{:=- Is_Meroitic_hieroglyphs}');
Error('\P{:=- Is_Meroitic_hieroglyphs}');
Expect(1, 67999, '\p{ismeroitichieroglyphs}', "");
Expect(0, 67999, '\p{^ismeroitichieroglyphs}', "");
Expect(0, 67999, '\P{ismeroitichieroglyphs}', "");
Expect(1, 67999, '\P{^ismeroitichieroglyphs}', "");
Expect(0, 68000, '\p{ismeroitichieroglyphs}', "");
Expect(1, 68000, '\p{^ismeroitichieroglyphs}', "");
Expect(1, 68000, '\P{ismeroitichieroglyphs}', "");
Expect(0, 68000, '\P{^ismeroitichieroglyphs}', "");
Expect(1, 67999, '\p{_	Is_Meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\p{^_	Is_Meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\P{_	Is_Meroitic_Hieroglyphs}', "");
Expect(1, 67999, '\P{^_	Is_Meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\p{_	Is_Meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\p{^_	Is_Meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\P{_	Is_Meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\P{^_	Is_Meroitic_Hieroglyphs}', "");
Error('\p{:=-mero}');
Error('\P{:=-mero}');
Expect(1, 67999, '\p{mero}', "");
Expect(0, 67999, '\p{^mero}', "");
Expect(0, 67999, '\P{mero}', "");
Expect(1, 67999, '\P{^mero}', "");
Expect(0, 68000, '\p{mero}', "");
Expect(1, 68000, '\p{^mero}', "");
Expect(1, 68000, '\P{mero}', "");
Expect(0, 68000, '\P{^mero}', "");
Expect(1, 67999, '\p{		mero}', "");
Expect(0, 67999, '\p{^		mero}', "");
Expect(0, 67999, '\P{		mero}', "");
Expect(1, 67999, '\P{^		mero}', "");
Expect(0, 68000, '\p{		mero}', "");
Expect(1, 68000, '\p{^		mero}', "");
Expect(1, 68000, '\P{		mero}', "");
Expect(0, 68000, '\P{^		mero}', "");
Error('\p{-:=is_mero}');
Error('\P{-:=is_mero}');
Expect(1, 67999, '\p{ismero}', "");
Expect(0, 67999, '\p{^ismero}', "");
Expect(0, 67999, '\P{ismero}', "");
Expect(1, 67999, '\P{^ismero}', "");
Expect(0, 68000, '\p{ismero}', "");
Expect(1, 68000, '\p{^ismero}', "");
Expect(1, 68000, '\P{ismero}', "");
Expect(0, 68000, '\P{^ismero}', "");
Expect(1, 67999, '\p{-_IS_MERO}', "");
Expect(0, 67999, '\p{^-_IS_MERO}', "");
Expect(0, 67999, '\P{-_IS_MERO}', "");
Expect(1, 67999, '\P{^-_IS_MERO}', "");
Expect(0, 68000, '\p{-_IS_MERO}', "");
Expect(1, 68000, '\p{^-_IS_MERO}', "");
Expect(1, 68000, '\P{-_IS_MERO}', "");
Expect(0, 68000, '\P{^-_IS_MERO}', "");
Error('\p{/a/	 Miao}');
Error('\P{/a/	 Miao}');
Expect(1, 94111, '\p{miao}', "");
Expect(0, 94111, '\p{^miao}', "");
Expect(0, 94111, '\P{miao}', "");
Expect(1, 94111, '\P{^miao}', "");
Expect(0, 94112, '\p{miao}', "");
Expect(1, 94112, '\p{^miao}', "");
Expect(1, 94112, '\P{miao}', "");
Expect(0, 94112, '\P{^miao}', "");
Expect(1, 94111, '\p{Miao}', "");
Expect(0, 94111, '\p{^Miao}', "");
Expect(0, 94111, '\P{Miao}', "");
Expect(1, 94111, '\P{^Miao}', "");
Expect(0, 94112, '\p{Miao}', "");
Expect(1, 94112, '\p{^Miao}', "");
Expect(1, 94112, '\P{Miao}', "");
Expect(0, 94112, '\P{^Miao}', "");
Error('\p{:=	 Is_miao}');
Error('\P{:=	 Is_miao}');
Expect(1, 94111, '\p{ismiao}', "");
Expect(0, 94111, '\p{^ismiao}', "");
Expect(0, 94111, '\P{ismiao}', "");
Expect(1, 94111, '\P{^ismiao}', "");
Expect(0, 94112, '\p{ismiao}', "");
Expect(1, 94112, '\p{^ismiao}', "");
Expect(1, 94112, '\P{ismiao}', "");
Expect(0, 94112, '\P{^ismiao}', "");
Expect(1, 94111, '\p{_Is_Miao}', "");
Expect(0, 94111, '\p{^_Is_Miao}', "");
Expect(0, 94111, '\P{_Is_Miao}', "");
Expect(1, 94111, '\P{^_Is_Miao}', "");
Expect(0, 94112, '\p{_Is_Miao}', "");
Expect(1, 94112, '\p{^_Is_Miao}', "");
Expect(1, 94112, '\P{_Is_Miao}', "");
Expect(0, 94112, '\P{^_Is_Miao}', "");
Error('\p{/a/PLRD}');
Error('\P{/a/PLRD}');
Expect(1, 94111, '\p{plrd}', "");
Expect(0, 94111, '\p{^plrd}', "");
Expect(0, 94111, '\P{plrd}', "");
Expect(1, 94111, '\P{^plrd}', "");
Expect(0, 94112, '\p{plrd}', "");
Expect(1, 94112, '\p{^plrd}', "");
Expect(1, 94112, '\P{plrd}', "");
Expect(0, 94112, '\P{^plrd}', "");
Expect(1, 94111, '\p{	Plrd}', "");
Expect(0, 94111, '\p{^	Plrd}', "");
Expect(0, 94111, '\P{	Plrd}', "");
Expect(1, 94111, '\P{^	Plrd}', "");
Expect(0, 94112, '\p{	Plrd}', "");
Expect(1, 94112, '\p{^	Plrd}', "");
Expect(1, 94112, '\P{	Plrd}', "");
Expect(0, 94112, '\P{^	Plrd}', "");
Error('\p{/a/	IS_plrd}');
Error('\P{/a/	IS_plrd}');
Expect(1, 94111, '\p{isplrd}', "");
Expect(0, 94111, '\p{^isplrd}', "");
Expect(0, 94111, '\P{isplrd}', "");
Expect(1, 94111, '\P{^isplrd}', "");
Expect(0, 94112, '\p{isplrd}', "");
Expect(1, 94112, '\p{^isplrd}', "");
Expect(1, 94112, '\P{isplrd}', "");
Expect(0, 94112, '\P{^isplrd}', "");
Expect(1, 94111, '\p{ IS_PLRD}', "");
Expect(0, 94111, '\p{^ IS_PLRD}', "");
Expect(0, 94111, '\P{ IS_PLRD}', "");
Expect(1, 94111, '\P{^ IS_PLRD}', "");
Expect(0, 94112, '\p{ IS_PLRD}', "");
Expect(1, 94112, '\p{^ IS_PLRD}', "");
Expect(1, 94112, '\P{ IS_PLRD}', "");
Expect(0, 94112, '\P{^ IS_PLRD}', "");
Error('\p{ -Miscellaneous_Mathematical_Symbols_a/a/}');
Error('\P{ -Miscellaneous_Mathematical_Symbols_a/a/}');
Expect(1, 10223, '\p{miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\p{^miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\P{miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\P{^miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\p{miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\p{^miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\P{miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\P{^miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\p{_miscellaneous_Mathematical_Symbols_a}', "");
Expect(0, 10223, '\p{^_miscellaneous_Mathematical_Symbols_a}', "");
Expect(0, 10223, '\P{_miscellaneous_Mathematical_Symbols_a}', "");
Expect(1, 10223, '\P{^_miscellaneous_Mathematical_Symbols_a}', "");
Expect(0, 10224, '\p{_miscellaneous_Mathematical_Symbols_a}', "");
Expect(1, 10224, '\p{^_miscellaneous_Mathematical_Symbols_a}', "");
Expect(1, 10224, '\P{_miscellaneous_Mathematical_Symbols_a}', "");
Expect(0, 10224, '\P{^_miscellaneous_Mathematical_Symbols_a}', "");
Error('\p{ _IS_Miscellaneous_Mathematical_symbols_A:=}');
Error('\P{ _IS_Miscellaneous_Mathematical_symbols_A:=}');
Expect(1, 10223, '\p{ismiscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\p{^ismiscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\P{ismiscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\P{^ismiscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\p{ismiscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\p{^ismiscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\P{ismiscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\P{^ismiscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\p{	_Is_MISCELLANEOUS_MATHEMATICAL_Symbols_A}', "");
Expect(0, 10223, '\p{^	_Is_MISCELLANEOUS_MATHEMATICAL_Symbols_A}', "");
Expect(0, 10223, '\P{	_Is_MISCELLANEOUS_MATHEMATICAL_Symbols_A}', "");
Expect(1, 10223, '\P{^	_Is_MISCELLANEOUS_MATHEMATICAL_Symbols_A}', "");
Expect(0, 10224, '\p{	_Is_MISCELLANEOUS_MATHEMATICAL_Symbols_A}', "");
Expect(1, 10224, '\p{^	_Is_MISCELLANEOUS_MATHEMATICAL_Symbols_A}', "");
Expect(1, 10224, '\P{	_Is_MISCELLANEOUS_MATHEMATICAL_Symbols_A}', "");
Expect(0, 10224, '\P{^	_Is_MISCELLANEOUS_MATHEMATICAL_Symbols_A}', "");
Error('\p{	IN_MISCELLANEOUS_Mathematical_Symbols_A:=}');
Error('\P{	IN_MISCELLANEOUS_Mathematical_Symbols_A:=}');
Expect(1, 10223, '\p{inmiscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\p{^inmiscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\P{inmiscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\P{^inmiscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\p{inmiscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\p{^inmiscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\P{inmiscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\P{^inmiscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\p{_in_miscellaneous_Mathematical_SYMBOLS_a}', "");
Expect(0, 10223, '\p{^_in_miscellaneous_Mathematical_SYMBOLS_a}', "");
Expect(0, 10223, '\P{_in_miscellaneous_Mathematical_SYMBOLS_a}', "");
Expect(1, 10223, '\P{^_in_miscellaneous_Mathematical_SYMBOLS_a}', "");
Expect(0, 10224, '\p{_in_miscellaneous_Mathematical_SYMBOLS_a}', "");
Expect(1, 10224, '\p{^_in_miscellaneous_Mathematical_SYMBOLS_a}', "");
Expect(1, 10224, '\P{_in_miscellaneous_Mathematical_SYMBOLS_a}', "");
Expect(0, 10224, '\P{^_in_miscellaneous_Mathematical_SYMBOLS_a}', "");
Error('\p{_/a/misc_Math_Symbols_A}');
Error('\P{_/a/misc_Math_Symbols_A}');
Expect(1, 10223, '\p{miscmathsymbolsa}', "");
Expect(0, 10223, '\p{^miscmathsymbolsa}', "");
Expect(0, 10223, '\P{miscmathsymbolsa}', "");
Expect(1, 10223, '\P{^miscmathsymbolsa}', "");
Expect(0, 10224, '\p{miscmathsymbolsa}', "");
Expect(1, 10224, '\p{^miscmathsymbolsa}', "");
Expect(1, 10224, '\P{miscmathsymbolsa}', "");
Expect(0, 10224, '\P{^miscmathsymbolsa}', "");
Expect(1, 10223, '\p{-	Misc_math_SYMBOLS_A}', "");
Expect(0, 10223, '\p{^-	Misc_math_SYMBOLS_A}', "");
Expect(0, 10223, '\P{-	Misc_math_SYMBOLS_A}', "");
Expect(1, 10223, '\P{^-	Misc_math_SYMBOLS_A}', "");
Expect(0, 10224, '\p{-	Misc_math_SYMBOLS_A}', "");
Expect(1, 10224, '\p{^-	Misc_math_SYMBOLS_A}', "");
Expect(1, 10224, '\P{-	Misc_math_SYMBOLS_A}', "");
Expect(0, 10224, '\P{^-	Misc_math_SYMBOLS_A}', "");
Error('\p{_	Is_Misc_Math_Symbols_A:=}');
Error('\P{_	Is_Misc_Math_Symbols_A:=}');
Expect(1, 10223, '\p{ismiscmathsymbolsa}', "");
Expect(0, 10223, '\p{^ismiscmathsymbolsa}', "");
Expect(0, 10223, '\P{ismiscmathsymbolsa}', "");
Expect(1, 10223, '\P{^ismiscmathsymbolsa}', "");
Expect(0, 10224, '\p{ismiscmathsymbolsa}', "");
Expect(1, 10224, '\p{^ismiscmathsymbolsa}', "");
Expect(1, 10224, '\P{ismiscmathsymbolsa}', "");
Expect(0, 10224, '\P{^ismiscmathsymbolsa}', "");
Expect(1, 10223, '\p{_	Is_MISC_math_Symbols_a}', "");
Expect(0, 10223, '\p{^_	Is_MISC_math_Symbols_a}', "");
Expect(0, 10223, '\P{_	Is_MISC_math_Symbols_a}', "");
Expect(1, 10223, '\P{^_	Is_MISC_math_Symbols_a}', "");
Expect(0, 10224, '\p{_	Is_MISC_math_Symbols_a}', "");
Expect(1, 10224, '\p{^_	Is_MISC_math_Symbols_a}', "");
Expect(1, 10224, '\P{_	Is_MISC_math_Symbols_a}', "");
Expect(0, 10224, '\P{^_	Is_MISC_math_Symbols_a}', "");
Error('\p{_-In_MISC_Math_Symbols_A/a/}');
Error('\P{_-In_MISC_Math_Symbols_A/a/}');
Expect(1, 10223, '\p{inmiscmathsymbolsa}', "");
Expect(0, 10223, '\p{^inmiscmathsymbolsa}', "");
Expect(0, 10223, '\P{inmiscmathsymbolsa}', "");
Expect(1, 10223, '\P{^inmiscmathsymbolsa}', "");
Expect(0, 10224, '\p{inmiscmathsymbolsa}', "");
Expect(1, 10224, '\p{^inmiscmathsymbolsa}', "");
Expect(1, 10224, '\P{inmiscmathsymbolsa}', "");
Expect(0, 10224, '\P{^inmiscmathsymbolsa}', "");
Expect(1, 10223, '\p{	In_Misc_math_Symbols_A}', "");
Expect(0, 10223, '\p{^	In_Misc_math_Symbols_A}', "");
Expect(0, 10223, '\P{	In_Misc_math_Symbols_A}', "");
Expect(1, 10223, '\P{^	In_Misc_math_Symbols_A}', "");
Expect(0, 10224, '\p{	In_Misc_math_Symbols_A}', "");
Expect(1, 10224, '\p{^	In_Misc_math_Symbols_A}', "");
Expect(1, 10224, '\P{	In_Misc_math_Symbols_A}', "");
Expect(0, 10224, '\P{^	In_Misc_math_Symbols_A}', "");
Error('\p{/a/  Miscellaneous_mathematical_SYMBOLS_B}');
Error('\P{/a/  Miscellaneous_mathematical_SYMBOLS_B}');
Expect(1, 10751, '\p{miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\p{^miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\P{miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\P{^miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\p{miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\p{^miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\P{miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\P{^miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\p{_	Miscellaneous_MATHEMATICAL_Symbols_b}', "");
Expect(0, 10751, '\p{^_	Miscellaneous_MATHEMATICAL_Symbols_b}', "");
Expect(0, 10751, '\P{_	Miscellaneous_MATHEMATICAL_Symbols_b}', "");
Expect(1, 10751, '\P{^_	Miscellaneous_MATHEMATICAL_Symbols_b}', "");
Expect(0, 10752, '\p{_	Miscellaneous_MATHEMATICAL_Symbols_b}', "");
Expect(1, 10752, '\p{^_	Miscellaneous_MATHEMATICAL_Symbols_b}', "");
Expect(1, 10752, '\P{_	Miscellaneous_MATHEMATICAL_Symbols_b}', "");
Expect(0, 10752, '\P{^_	Miscellaneous_MATHEMATICAL_Symbols_b}', "");
Error('\p{/a/_-IS_Miscellaneous_Mathematical_SYMBOLS_B}');
Error('\P{/a/_-IS_Miscellaneous_Mathematical_SYMBOLS_B}');
Expect(1, 10751, '\p{ismiscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\p{^ismiscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\P{ismiscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\P{^ismiscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\p{ismiscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\p{^ismiscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\P{ismiscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\P{^ismiscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\p{-Is_Miscellaneous_Mathematical_Symbols_b}', "");
Expect(0, 10751, '\p{^-Is_Miscellaneous_Mathematical_Symbols_b}', "");
Expect(0, 10751, '\P{-Is_Miscellaneous_Mathematical_Symbols_b}', "");
Expect(1, 10751, '\P{^-Is_Miscellaneous_Mathematical_Symbols_b}', "");
Expect(0, 10752, '\p{-Is_Miscellaneous_Mathematical_Symbols_b}', "");
Expect(1, 10752, '\p{^-Is_Miscellaneous_Mathematical_Symbols_b}', "");
Expect(1, 10752, '\P{-Is_Miscellaneous_Mathematical_Symbols_b}', "");
Expect(0, 10752, '\P{^-Is_Miscellaneous_Mathematical_Symbols_b}', "");
Error('\p{/a/-IN_Miscellaneous_Mathematical_Symbols_B}');
Error('\P{/a/-IN_Miscellaneous_Mathematical_Symbols_B}');
Expect(1, 10751, '\p{inmiscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\p{^inmiscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\P{inmiscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\P{^inmiscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\p{inmiscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\p{^inmiscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\P{inmiscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\P{^inmiscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\p{_ IN_Miscellaneous_mathematical_Symbols_B}', "");
Expect(0, 10751, '\p{^_ IN_Miscellaneous_mathematical_Symbols_B}', "");
Expect(0, 10751, '\P{_ IN_Miscellaneous_mathematical_Symbols_B}', "");
Expect(1, 10751, '\P{^_ IN_Miscellaneous_mathematical_Symbols_B}', "");
Expect(0, 10752, '\p{_ IN_Miscellaneous_mathematical_Symbols_B}', "");
Expect(1, 10752, '\p{^_ IN_Miscellaneous_mathematical_Symbols_B}', "");
Expect(1, 10752, '\P{_ IN_Miscellaneous_mathematical_Symbols_B}', "");
Expect(0, 10752, '\P{^_ IN_Miscellaneous_mathematical_Symbols_B}', "");
Error('\p{:=_Misc_Math_Symbols_B}');
Error('\P{:=_Misc_Math_Symbols_B}');
Expect(1, 10751, '\p{miscmathsymbolsb}', "");
Expect(0, 10751, '\p{^miscmathsymbolsb}', "");
Expect(0, 10751, '\P{miscmathsymbolsb}', "");
Expect(1, 10751, '\P{^miscmathsymbolsb}', "");
Expect(0, 10752, '\p{miscmathsymbolsb}', "");
Expect(1, 10752, '\p{^miscmathsymbolsb}', "");
Expect(1, 10752, '\P{miscmathsymbolsb}', "");
Expect(0, 10752, '\P{^miscmathsymbolsb}', "");
Expect(1, 10751, '\p{-_Misc_math_Symbols_b}', "");
Expect(0, 10751, '\p{^-_Misc_math_Symbols_b}', "");
Expect(0, 10751, '\P{-_Misc_math_Symbols_b}', "");
Expect(1, 10751, '\P{^-_Misc_math_Symbols_b}', "");
Expect(0, 10752, '\p{-_Misc_math_Symbols_b}', "");
Expect(1, 10752, '\p{^-_Misc_math_Symbols_b}', "");
Expect(1, 10752, '\P{-_Misc_math_Symbols_b}', "");
Expect(0, 10752, '\P{^-_Misc_math_Symbols_b}', "");
Error('\p{- Is_Misc_Math_Symbols_B/a/}');
Error('\P{- Is_Misc_Math_Symbols_B/a/}');
Expect(1, 10751, '\p{ismiscmathsymbolsb}', "");
Expect(0, 10751, '\p{^ismiscmathsymbolsb}', "");
Expect(0, 10751, '\P{ismiscmathsymbolsb}', "");
Expect(1, 10751, '\P{^ismiscmathsymbolsb}', "");
Expect(0, 10752, '\p{ismiscmathsymbolsb}', "");
Expect(1, 10752, '\p{^ismiscmathsymbolsb}', "");
Expect(1, 10752, '\P{ismiscmathsymbolsb}', "");
Expect(0, 10752, '\P{^ismiscmathsymbolsb}', "");
Expect(1, 10751, '\p{ 	IS_MISC_MATH_SYMBOLS_B}', "");
Expect(0, 10751, '\p{^ 	IS_MISC_MATH_SYMBOLS_B}', "");
Expect(0, 10751, '\P{ 	IS_MISC_MATH_SYMBOLS_B}', "");
Expect(1, 10751, '\P{^ 	IS_MISC_MATH_SYMBOLS_B}', "");
Expect(0, 10752, '\p{ 	IS_MISC_MATH_SYMBOLS_B}', "");
Expect(1, 10752, '\p{^ 	IS_MISC_MATH_SYMBOLS_B}', "");
Expect(1, 10752, '\P{ 	IS_MISC_MATH_SYMBOLS_B}', "");
Expect(0, 10752, '\P{^ 	IS_MISC_MATH_SYMBOLS_B}', "");
Error('\p{:=_ In_Misc_Math_Symbols_B}');
Error('\P{:=_ In_Misc_Math_Symbols_B}');
Expect(1, 10751, '\p{inmiscmathsymbolsb}', "");
Expect(0, 10751, '\p{^inmiscmathsymbolsb}', "");
Expect(0, 10751, '\P{inmiscmathsymbolsb}', "");
Expect(1, 10751, '\P{^inmiscmathsymbolsb}', "");
Expect(0, 10752, '\p{inmiscmathsymbolsb}', "");
Expect(1, 10752, '\p{^inmiscmathsymbolsb}', "");
Expect(1, 10752, '\P{inmiscmathsymbolsb}', "");
Expect(0, 10752, '\P{^inmiscmathsymbolsb}', "");
Expect(1, 10751, '\p{-In_misc_Math_Symbols_B}', "");
Expect(0, 10751, '\p{^-In_misc_Math_Symbols_B}', "");
Expect(0, 10751, '\P{-In_misc_Math_Symbols_B}', "");
Expect(1, 10751, '\P{^-In_misc_Math_Symbols_B}', "");
Expect(0, 10752, '\p{-In_misc_Math_Symbols_B}', "");
Expect(1, 10752, '\p{^-In_misc_Math_Symbols_B}', "");
Expect(1, 10752, '\P{-In_misc_Math_Symbols_B}', "");
Expect(0, 10752, '\P{^-In_misc_Math_Symbols_B}', "");
Error('\p{:=_	miscellaneous_Symbols}');
Error('\P{:=_	miscellaneous_Symbols}');
Expect(1, 9983, '\p{miscellaneoussymbols}', "");
Expect(0, 9983, '\p{^miscellaneoussymbols}', "");
Expect(0, 9983, '\P{miscellaneoussymbols}', "");
Expect(1, 9983, '\P{^miscellaneoussymbols}', "");
Expect(0, 9984, '\p{miscellaneoussymbols}', "");
Expect(1, 9984, '\p{^miscellaneoussymbols}', "");
Expect(1, 9984, '\P{miscellaneoussymbols}', "");
Expect(0, 9984, '\P{^miscellaneoussymbols}', "");
Expect(1, 9983, '\p{_ miscellaneous_Symbols}', "");
Expect(0, 9983, '\p{^_ miscellaneous_Symbols}', "");
Expect(0, 9983, '\P{_ miscellaneous_Symbols}', "");
Expect(1, 9983, '\P{^_ miscellaneous_Symbols}', "");
Expect(0, 9984, '\p{_ miscellaneous_Symbols}', "");
Expect(1, 9984, '\p{^_ miscellaneous_Symbols}', "");
Expect(1, 9984, '\P{_ miscellaneous_Symbols}', "");
Expect(0, 9984, '\P{^_ miscellaneous_Symbols}', "");
Error('\p{ :=IS_Miscellaneous_Symbols}');
Error('\P{ :=IS_Miscellaneous_Symbols}');
Expect(1, 9983, '\p{ismiscellaneoussymbols}', "");
Expect(0, 9983, '\p{^ismiscellaneoussymbols}', "");
Expect(0, 9983, '\P{ismiscellaneoussymbols}', "");
Expect(1, 9983, '\P{^ismiscellaneoussymbols}', "");
Expect(0, 9984, '\p{ismiscellaneoussymbols}', "");
Expect(1, 9984, '\p{^ismiscellaneoussymbols}', "");
Expect(1, 9984, '\P{ismiscellaneoussymbols}', "");
Expect(0, 9984, '\P{^ismiscellaneoussymbols}', "");
Expect(1, 9983, '\p{ -IS_MISCELLANEOUS_Symbols}', "");
Expect(0, 9983, '\p{^ -IS_MISCELLANEOUS_Symbols}', "");
Expect(0, 9983, '\P{ -IS_MISCELLANEOUS_Symbols}', "");
Expect(1, 9983, '\P{^ -IS_MISCELLANEOUS_Symbols}', "");
Expect(0, 9984, '\p{ -IS_MISCELLANEOUS_Symbols}', "");
Expect(1, 9984, '\p{^ -IS_MISCELLANEOUS_Symbols}', "");
Expect(1, 9984, '\P{ -IS_MISCELLANEOUS_Symbols}', "");
Expect(0, 9984, '\P{^ -IS_MISCELLANEOUS_Symbols}', "");
Error('\p{- In_Miscellaneous_symbols:=}');
Error('\P{- In_Miscellaneous_symbols:=}');
Expect(1, 9983, '\p{inmiscellaneoussymbols}', "");
Expect(0, 9983, '\p{^inmiscellaneoussymbols}', "");
Expect(0, 9983, '\P{inmiscellaneoussymbols}', "");
Expect(1, 9983, '\P{^inmiscellaneoussymbols}', "");
Expect(0, 9984, '\p{inmiscellaneoussymbols}', "");
Expect(1, 9984, '\p{^inmiscellaneoussymbols}', "");
Expect(1, 9984, '\P{inmiscellaneoussymbols}', "");
Expect(0, 9984, '\P{^inmiscellaneoussymbols}', "");
Expect(1, 9983, '\p{-IN_miscellaneous_Symbols}', "");
Expect(0, 9983, '\p{^-IN_miscellaneous_Symbols}', "");
Expect(0, 9983, '\P{-IN_miscellaneous_Symbols}', "");
Expect(1, 9983, '\P{^-IN_miscellaneous_Symbols}', "");
Expect(0, 9984, '\p{-IN_miscellaneous_Symbols}', "");
Expect(1, 9984, '\p{^-IN_miscellaneous_Symbols}', "");
Expect(1, 9984, '\P{-IN_miscellaneous_Symbols}', "");
Expect(0, 9984, '\P{^-IN_miscellaneous_Symbols}', "");
Error('\p{_-Misc_SYMBOLS:=}');
Error('\P{_-Misc_SYMBOLS:=}');
Expect(1, 9983, '\p{miscsymbols}', "");
Expect(0, 9983, '\p{^miscsymbols}', "");
Expect(0, 9983, '\P{miscsymbols}', "");
Expect(1, 9983, '\P{^miscsymbols}', "");
Expect(0, 9984, '\p{miscsymbols}', "");
Expect(1, 9984, '\p{^miscsymbols}', "");
Expect(1, 9984, '\P{miscsymbols}', "");
Expect(0, 9984, '\P{^miscsymbols}', "");
Expect(1, 9983, '\p{Misc_Symbols}', "");
Expect(0, 9983, '\p{^Misc_Symbols}', "");
Expect(0, 9983, '\P{Misc_Symbols}', "");
Expect(1, 9983, '\P{^Misc_Symbols}', "");
Expect(0, 9984, '\p{Misc_Symbols}', "");
Expect(1, 9984, '\p{^Misc_Symbols}', "");
Expect(1, 9984, '\P{Misc_Symbols}', "");
Expect(0, 9984, '\P{^Misc_Symbols}', "");
Error('\p{--IS_Misc_Symbols:=}');
Error('\P{--IS_Misc_Symbols:=}');
Expect(1, 9983, '\p{ismiscsymbols}', "");
Expect(0, 9983, '\p{^ismiscsymbols}', "");
Expect(0, 9983, '\P{ismiscsymbols}', "");
Expect(1, 9983, '\P{^ismiscsymbols}', "");
Expect(0, 9984, '\p{ismiscsymbols}', "");
Expect(1, 9984, '\p{^ismiscsymbols}', "");
Expect(1, 9984, '\P{ismiscsymbols}', "");
Expect(0, 9984, '\P{^ismiscsymbols}', "");
Expect(1, 9983, '\p{-IS_Misc_SYMBOLS}', "");
Expect(0, 9983, '\p{^-IS_Misc_SYMBOLS}', "");
Expect(0, 9983, '\P{-IS_Misc_SYMBOLS}', "");
Expect(1, 9983, '\P{^-IS_Misc_SYMBOLS}', "");
Expect(0, 9984, '\p{-IS_Misc_SYMBOLS}', "");
Expect(1, 9984, '\p{^-IS_Misc_SYMBOLS}', "");
Expect(1, 9984, '\P{-IS_Misc_SYMBOLS}', "");
Expect(0, 9984, '\P{^-IS_Misc_SYMBOLS}', "");
Error('\p{_/a/in_misc_Symbols}');
Error('\P{_/a/in_misc_Symbols}');
Expect(1, 9983, '\p{inmiscsymbols}', "");
Expect(0, 9983, '\p{^inmiscsymbols}', "");
Expect(0, 9983, '\P{inmiscsymbols}', "");
Expect(1, 9983, '\P{^inmiscsymbols}', "");
Expect(0, 9984, '\p{inmiscsymbols}', "");
Expect(1, 9984, '\p{^inmiscsymbols}', "");
Expect(1, 9984, '\P{inmiscsymbols}', "");
Expect(0, 9984, '\P{^inmiscsymbols}', "");
Expect(1, 9983, '\p{--In_Misc_symbols}', "");
Expect(0, 9983, '\p{^--In_Misc_symbols}', "");
Expect(0, 9983, '\P{--In_Misc_symbols}', "");
Expect(1, 9983, '\P{^--In_Misc_symbols}', "");
Expect(0, 9984, '\p{--In_Misc_symbols}', "");
Expect(1, 9984, '\p{^--In_Misc_symbols}', "");
Expect(1, 9984, '\P{--In_Misc_symbols}', "");
Expect(0, 9984, '\P{^--In_Misc_symbols}', "");
Error('\p{:=Miscellaneous_symbols_And_Arrows}');
Error('\P{:=Miscellaneous_symbols_And_Arrows}');
Expect(1, 11263, '\p{miscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\p{^miscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\P{miscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\P{^miscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\p{miscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\p{^miscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\P{miscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\P{^miscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\p{-	MISCELLANEOUS_SYMBOLS_And_ARROWS}', "");
Expect(0, 11263, '\p{^-	MISCELLANEOUS_SYMBOLS_And_ARROWS}', "");
Expect(0, 11263, '\P{-	MISCELLANEOUS_SYMBOLS_And_ARROWS}', "");
Expect(1, 11263, '\P{^-	MISCELLANEOUS_SYMBOLS_And_ARROWS}', "");
Expect(0, 11264, '\p{-	MISCELLANEOUS_SYMBOLS_And_ARROWS}', "");
Expect(1, 11264, '\p{^-	MISCELLANEOUS_SYMBOLS_And_ARROWS}', "");
Expect(1, 11264, '\P{-	MISCELLANEOUS_SYMBOLS_And_ARROWS}', "");
Expect(0, 11264, '\P{^-	MISCELLANEOUS_SYMBOLS_And_ARROWS}', "");
Error('\p{  Is_Miscellaneous_symbols_And_ARROWS/a/}');
Error('\P{  Is_Miscellaneous_symbols_And_ARROWS/a/}');
Expect(1, 11263, '\p{ismiscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\p{^ismiscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\P{ismiscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\P{^ismiscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\p{ismiscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\p{^ismiscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\P{ismiscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\P{^ismiscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\p{ Is_Miscellaneous_Symbols_And_Arrows}', "");
Expect(0, 11263, '\p{^ Is_Miscellaneous_Symbols_And_Arrows}', "");
Expect(0, 11263, '\P{ Is_Miscellaneous_Symbols_And_Arrows}', "");
Expect(1, 11263, '\P{^ Is_Miscellaneous_Symbols_And_Arrows}', "");
Expect(0, 11264, '\p{ Is_Miscellaneous_Symbols_And_Arrows}', "");
Expect(1, 11264, '\p{^ Is_Miscellaneous_Symbols_And_Arrows}', "");
Expect(1, 11264, '\P{ Is_Miscellaneous_Symbols_And_Arrows}', "");
Expect(0, 11264, '\P{^ Is_Miscellaneous_Symbols_And_Arrows}', "");
Error('\p{:=  In_miscellaneous_Symbols_And_arrows}');
Error('\P{:=  In_miscellaneous_Symbols_And_arrows}');
Expect(1, 11263, '\p{inmiscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\p{^inmiscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\P{inmiscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\P{^inmiscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\p{inmiscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\p{^inmiscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\P{inmiscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\P{^inmiscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\p{__In_MISCELLANEOUS_Symbols_And_arrows}', "");
Expect(0, 11263, '\p{^__In_MISCELLANEOUS_Symbols_And_arrows}', "");
Expect(0, 11263, '\P{__In_MISCELLANEOUS_Symbols_And_arrows}', "");
Expect(1, 11263, '\P{^__In_MISCELLANEOUS_Symbols_And_arrows}', "");
Expect(0, 11264, '\p{__In_MISCELLANEOUS_Symbols_And_arrows}', "");
Expect(1, 11264, '\p{^__In_MISCELLANEOUS_Symbols_And_arrows}', "");
Expect(1, 11264, '\P{__In_MISCELLANEOUS_Symbols_And_arrows}', "");
Expect(0, 11264, '\P{^__In_MISCELLANEOUS_Symbols_And_arrows}', "");
Error('\p{--MISC_ARROWS:=}');
Error('\P{--MISC_ARROWS:=}');
Expect(1, 11263, '\p{miscarrows}', "");
Expect(0, 11263, '\p{^miscarrows}', "");
Expect(0, 11263, '\P{miscarrows}', "");
Expect(1, 11263, '\P{^miscarrows}', "");
Expect(0, 11264, '\p{miscarrows}', "");
Expect(1, 11264, '\p{^miscarrows}', "");
Expect(1, 11264, '\P{miscarrows}', "");
Expect(0, 11264, '\P{^miscarrows}', "");
Expect(1, 11263, '\p{_Misc_arrows}', "");
Expect(0, 11263, '\p{^_Misc_arrows}', "");
Expect(0, 11263, '\P{_Misc_arrows}', "");
Expect(1, 11263, '\P{^_Misc_arrows}', "");
Expect(0, 11264, '\p{_Misc_arrows}', "");
Expect(1, 11264, '\p{^_Misc_arrows}', "");
Expect(1, 11264, '\P{_Misc_arrows}', "");
Expect(0, 11264, '\P{^_Misc_arrows}', "");
Error('\p{_:=is_Misc_Arrows}');
Error('\P{_:=is_Misc_Arrows}');
Expect(1, 11263, '\p{ismiscarrows}', "");
Expect(0, 11263, '\p{^ismiscarrows}', "");
Expect(0, 11263, '\P{ismiscarrows}', "");
Expect(1, 11263, '\P{^ismiscarrows}', "");
Expect(0, 11264, '\p{ismiscarrows}', "");
Expect(1, 11264, '\p{^ismiscarrows}', "");
Expect(1, 11264, '\P{ismiscarrows}', "");
Expect(0, 11264, '\P{^ismiscarrows}', "");
Expect(1, 11263, '\p{	-IS_misc_ARROWS}', "");
Expect(0, 11263, '\p{^	-IS_misc_ARROWS}', "");
Expect(0, 11263, '\P{	-IS_misc_ARROWS}', "");
Expect(1, 11263, '\P{^	-IS_misc_ARROWS}', "");
Expect(0, 11264, '\p{	-IS_misc_ARROWS}', "");
Expect(1, 11264, '\p{^	-IS_misc_ARROWS}', "");
Expect(1, 11264, '\P{	-IS_misc_ARROWS}', "");
Expect(0, 11264, '\P{^	-IS_misc_ARROWS}', "");
Error('\p{:=-_in_misc_arrows}');
Error('\P{:=-_in_misc_arrows}');
Expect(1, 11263, '\p{inmiscarrows}', "");
Expect(0, 11263, '\p{^inmiscarrows}', "");
Expect(0, 11263, '\P{inmiscarrows}', "");
Expect(1, 11263, '\P{^inmiscarrows}', "");
Expect(0, 11264, '\p{inmiscarrows}', "");
Expect(1, 11264, '\p{^inmiscarrows}', "");
Expect(1, 11264, '\P{inmiscarrows}', "");
Expect(0, 11264, '\P{^inmiscarrows}', "");
Expect(1, 11263, '\p{	In_misc_Arrows}', "");
Expect(0, 11263, '\p{^	In_misc_Arrows}', "");
Expect(0, 11263, '\P{	In_misc_Arrows}', "");
Expect(1, 11263, '\P{^	In_misc_Arrows}', "");
Expect(0, 11264, '\p{	In_misc_Arrows}', "");
Expect(1, 11264, '\p{^	In_misc_Arrows}', "");
Expect(1, 11264, '\P{	In_misc_Arrows}', "");
Expect(0, 11264, '\P{^	In_misc_Arrows}', "");
Error('\p{ -MISCELLANEOUS_symbols_And_PICTOGRAPHS:=}');
Error('\P{ -MISCELLANEOUS_symbols_And_PICTOGRAPHS:=}');
Expect(1, 128511, '\p{miscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\p{^miscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\P{miscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\P{^miscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\p{miscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\p{^miscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\P{miscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\P{^miscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\p{-miscellaneous_Symbols_AND_Pictographs}', "");
Expect(0, 128511, '\p{^-miscellaneous_Symbols_AND_Pictographs}', "");
Expect(0, 128511, '\P{-miscellaneous_Symbols_AND_Pictographs}', "");
Expect(1, 128511, '\P{^-miscellaneous_Symbols_AND_Pictographs}', "");
Expect(0, 128512, '\p{-miscellaneous_Symbols_AND_Pictographs}', "");
Expect(1, 128512, '\p{^-miscellaneous_Symbols_AND_Pictographs}', "");
Expect(1, 128512, '\P{-miscellaneous_Symbols_AND_Pictographs}', "");
Expect(0, 128512, '\P{^-miscellaneous_Symbols_AND_Pictographs}', "");
Error('\p{/a/--is_MISCELLANEOUS_SYMBOLS_And_PICTOGRAPHS}');
Error('\P{/a/--is_MISCELLANEOUS_SYMBOLS_And_PICTOGRAPHS}');
Expect(1, 128511, '\p{ismiscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\p{^ismiscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\P{ismiscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\P{^ismiscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\p{ismiscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\p{^ismiscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\P{ismiscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\P{^ismiscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\p{-Is_Miscellaneous_symbols_And_Pictographs}', "");
Expect(0, 128511, '\p{^-Is_Miscellaneous_symbols_And_Pictographs}', "");
Expect(0, 128511, '\P{-Is_Miscellaneous_symbols_And_Pictographs}', "");
Expect(1, 128511, '\P{^-Is_Miscellaneous_symbols_And_Pictographs}', "");
Expect(0, 128512, '\p{-Is_Miscellaneous_symbols_And_Pictographs}', "");
Expect(1, 128512, '\p{^-Is_Miscellaneous_symbols_And_Pictographs}', "");
Expect(1, 128512, '\P{-Is_Miscellaneous_symbols_And_Pictographs}', "");
Expect(0, 128512, '\P{^-Is_Miscellaneous_symbols_And_Pictographs}', "");
Error('\p{	/a/In_Miscellaneous_symbols_AND_pictographs}');
Error('\P{	/a/In_Miscellaneous_symbols_AND_pictographs}');
Expect(1, 128511, '\p{inmiscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\p{^inmiscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\P{inmiscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\P{^inmiscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\p{inmiscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\p{^inmiscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\P{inmiscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\P{^inmiscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\p{--In_miscellaneous_symbols_AND_Pictographs}', "");
Expect(0, 128511, '\p{^--In_miscellaneous_symbols_AND_Pictographs}', "");
Expect(0, 128511, '\P{--In_miscellaneous_symbols_AND_Pictographs}', "");
Expect(1, 128511, '\P{^--In_miscellaneous_symbols_AND_Pictographs}', "");
Expect(0, 128512, '\p{--In_miscellaneous_symbols_AND_Pictographs}', "");
Expect(1, 128512, '\p{^--In_miscellaneous_symbols_AND_Pictographs}', "");
Expect(1, 128512, '\P{--In_miscellaneous_symbols_AND_Pictographs}', "");
Expect(0, 128512, '\P{^--In_miscellaneous_symbols_AND_Pictographs}', "");
Error('\p{:=	 Misc_PICTOGRAPHS}');
Error('\P{:=	 Misc_PICTOGRAPHS}');
Expect(1, 128511, '\p{miscpictographs}', "");
Expect(0, 128511, '\p{^miscpictographs}', "");
Expect(0, 128511, '\P{miscpictographs}', "");
Expect(1, 128511, '\P{^miscpictographs}', "");
Expect(0, 128512, '\p{miscpictographs}', "");
Expect(1, 128512, '\p{^miscpictographs}', "");
Expect(1, 128512, '\P{miscpictographs}', "");
Expect(0, 128512, '\P{^miscpictographs}', "");
Expect(1, 128511, '\p{	-Misc_Pictographs}', "");
Expect(0, 128511, '\p{^	-Misc_Pictographs}', "");
Expect(0, 128511, '\P{	-Misc_Pictographs}', "");
Expect(1, 128511, '\P{^	-Misc_Pictographs}', "");
Expect(0, 128512, '\p{	-Misc_Pictographs}', "");
Expect(1, 128512, '\p{^	-Misc_Pictographs}', "");
Expect(1, 128512, '\P{	-Misc_Pictographs}', "");
Expect(0, 128512, '\P{^	-Misc_Pictographs}', "");
Error('\p{/a/_-is_Misc_PICTOGRAPHS}');
Error('\P{/a/_-is_Misc_PICTOGRAPHS}');
Expect(1, 128511, '\p{ismiscpictographs}', "");
Expect(0, 128511, '\p{^ismiscpictographs}', "");
Expect(0, 128511, '\P{ismiscpictographs}', "");
Expect(1, 128511, '\P{^ismiscpictographs}', "");
Expect(0, 128512, '\p{ismiscpictographs}', "");
Expect(1, 128512, '\p{^ismiscpictographs}', "");
Expect(1, 128512, '\P{ismiscpictographs}', "");
Expect(0, 128512, '\P{^ismiscpictographs}', "");
Expect(1, 128511, '\p{ -Is_Misc_Pictographs}', "");
Expect(0, 128511, '\p{^ -Is_Misc_Pictographs}', "");
Expect(0, 128511, '\P{ -Is_Misc_Pictographs}', "");
Expect(1, 128511, '\P{^ -Is_Misc_Pictographs}', "");
Expect(0, 128512, '\p{ -Is_Misc_Pictographs}', "");
Expect(1, 128512, '\p{^ -Is_Misc_Pictographs}', "");
Expect(1, 128512, '\P{ -Is_Misc_Pictographs}', "");
Expect(0, 128512, '\P{^ -Is_Misc_Pictographs}', "");
Error('\p{/a/  IN_misc_Pictographs}');
Error('\P{/a/  IN_misc_Pictographs}');
Expect(1, 128511, '\p{inmiscpictographs}', "");
Expect(0, 128511, '\p{^inmiscpictographs}', "");
Expect(0, 128511, '\P{inmiscpictographs}', "");
Expect(1, 128511, '\P{^inmiscpictographs}', "");
Expect(0, 128512, '\p{inmiscpictographs}', "");
Expect(1, 128512, '\p{^inmiscpictographs}', "");
Expect(1, 128512, '\P{inmiscpictographs}', "");
Expect(0, 128512, '\P{^inmiscpictographs}', "");
Expect(1, 128511, '\p{	 In_misc_PICTOGRAPHS}', "");
Expect(0, 128511, '\p{^	 In_misc_PICTOGRAPHS}', "");
Expect(0, 128511, '\P{	 In_misc_PICTOGRAPHS}', "");
Expect(1, 128511, '\P{^	 In_misc_PICTOGRAPHS}', "");
Expect(0, 128512, '\p{	 In_misc_PICTOGRAPHS}', "");
Expect(1, 128512, '\p{^	 In_misc_PICTOGRAPHS}', "");
Expect(1, 128512, '\P{	 In_misc_PICTOGRAPHS}', "");
Expect(0, 128512, '\P{^	 In_misc_PICTOGRAPHS}', "");
Error('\p{:=	-miscellaneous_TECHNICAL}');
Error('\P{:=	-miscellaneous_TECHNICAL}');
Expect(1, 9215, '\p{miscellaneoustechnical}', "");
Expect(0, 9215, '\p{^miscellaneoustechnical}', "");
Expect(0, 9215, '\P{miscellaneoustechnical}', "");
Expect(1, 9215, '\P{^miscellaneoustechnical}', "");
Expect(0, 9216, '\p{miscellaneoustechnical}', "");
Expect(1, 9216, '\p{^miscellaneoustechnical}', "");
Expect(1, 9216, '\P{miscellaneoustechnical}', "");
Expect(0, 9216, '\P{^miscellaneoustechnical}', "");
Expect(1, 9215, '\p{- Miscellaneous_technical}', "");
Expect(0, 9215, '\p{^- Miscellaneous_technical}', "");
Expect(0, 9215, '\P{- Miscellaneous_technical}', "");
Expect(1, 9215, '\P{^- Miscellaneous_technical}', "");
Expect(0, 9216, '\p{- Miscellaneous_technical}', "");
Expect(1, 9216, '\p{^- Miscellaneous_technical}', "");
Expect(1, 9216, '\P{- Miscellaneous_technical}', "");
Expect(0, 9216, '\P{^- Miscellaneous_technical}', "");
Error('\p{_:=IS_miscellaneous_technical}');
Error('\P{_:=IS_miscellaneous_technical}');
Expect(1, 9215, '\p{ismiscellaneoustechnical}', "");
Expect(0, 9215, '\p{^ismiscellaneoustechnical}', "");
Expect(0, 9215, '\P{ismiscellaneoustechnical}', "");
Expect(1, 9215, '\P{^ismiscellaneoustechnical}', "");
Expect(0, 9216, '\p{ismiscellaneoustechnical}', "");
Expect(1, 9216, '\p{^ismiscellaneoustechnical}', "");
Expect(1, 9216, '\P{ismiscellaneoustechnical}', "");
Expect(0, 9216, '\P{^ismiscellaneoustechnical}', "");
Expect(1, 9215, '\p{  is_MISCELLANEOUS_TECHNICAL}', "");
Expect(0, 9215, '\p{^  is_MISCELLANEOUS_TECHNICAL}', "");
Expect(0, 9215, '\P{  is_MISCELLANEOUS_TECHNICAL}', "");
Expect(1, 9215, '\P{^  is_MISCELLANEOUS_TECHNICAL}', "");
Expect(0, 9216, '\p{  is_MISCELLANEOUS_TECHNICAL}', "");
Expect(1, 9216, '\p{^  is_MISCELLANEOUS_TECHNICAL}', "");
Expect(1, 9216, '\P{  is_MISCELLANEOUS_TECHNICAL}', "");
Expect(0, 9216, '\P{^  is_MISCELLANEOUS_TECHNICAL}', "");
Error('\p{:=In_miscellaneous_TECHNICAL}');
Error('\P{:=In_miscellaneous_TECHNICAL}');
Expect(1, 9215, '\p{inmiscellaneoustechnical}', "");
Expect(0, 9215, '\p{^inmiscellaneoustechnical}', "");
Expect(0, 9215, '\P{inmiscellaneoustechnical}', "");
Expect(1, 9215, '\P{^inmiscellaneoustechnical}', "");
Expect(0, 9216, '\p{inmiscellaneoustechnical}', "");
Expect(1, 9216, '\p{^inmiscellaneoustechnical}', "");
Expect(1, 9216, '\P{inmiscellaneoustechnical}', "");
Expect(0, 9216, '\P{^inmiscellaneoustechnical}', "");
Expect(1, 9215, '\p{-In_Miscellaneous_TECHNICAL}', "");
Expect(0, 9215, '\p{^-In_Miscellaneous_TECHNICAL}', "");
Expect(0, 9215, '\P{-In_Miscellaneous_TECHNICAL}', "");
Expect(1, 9215, '\P{^-In_Miscellaneous_TECHNICAL}', "");
Expect(0, 9216, '\p{-In_Miscellaneous_TECHNICAL}', "");
Expect(1, 9216, '\p{^-In_Miscellaneous_TECHNICAL}', "");
Expect(1, 9216, '\P{-In_Miscellaneous_TECHNICAL}', "");
Expect(0, 9216, '\P{^-In_Miscellaneous_TECHNICAL}', "");
Error('\p{	misc_technical:=}');
Error('\P{	misc_technical:=}');
Expect(1, 9215, '\p{misctechnical}', "");
Expect(0, 9215, '\p{^misctechnical}', "");
Expect(0, 9215, '\P{misctechnical}', "");
Expect(1, 9215, '\P{^misctechnical}', "");
Expect(0, 9216, '\p{misctechnical}', "");
Expect(1, 9216, '\p{^misctechnical}', "");
Expect(1, 9216, '\P{misctechnical}', "");
Expect(0, 9216, '\P{^misctechnical}', "");
Expect(1, 9215, '\p{		MISC_Technical}', "");
Expect(0, 9215, '\p{^		MISC_Technical}', "");
Expect(0, 9215, '\P{		MISC_Technical}', "");
Expect(1, 9215, '\P{^		MISC_Technical}', "");
Expect(0, 9216, '\p{		MISC_Technical}', "");
Expect(1, 9216, '\p{^		MISC_Technical}', "");
Expect(1, 9216, '\P{		MISC_Technical}', "");
Expect(0, 9216, '\P{^		MISC_Technical}', "");
Error('\p{:=IS_misc_Technical}');
Error('\P{:=IS_misc_Technical}');
Expect(1, 9215, '\p{ismisctechnical}', "");
Expect(0, 9215, '\p{^ismisctechnical}', "");
Expect(0, 9215, '\P{ismisctechnical}', "");
Expect(1, 9215, '\P{^ismisctechnical}', "");
Expect(0, 9216, '\p{ismisctechnical}', "");
Expect(1, 9216, '\p{^ismisctechnical}', "");
Expect(1, 9216, '\P{ismisctechnical}', "");
Expect(0, 9216, '\P{^ismisctechnical}', "");
Expect(1, 9215, '\p{  Is_Misc_Technical}', "");
Expect(0, 9215, '\p{^  Is_Misc_Technical}', "");
Expect(0, 9215, '\P{  Is_Misc_Technical}', "");
Expect(1, 9215, '\P{^  Is_Misc_Technical}', "");
Expect(0, 9216, '\p{  Is_Misc_Technical}', "");
Expect(1, 9216, '\p{^  Is_Misc_Technical}', "");
Expect(1, 9216, '\P{  Is_Misc_Technical}', "");
Expect(0, 9216, '\P{^  Is_Misc_Technical}', "");
Error('\p{:=  IN_Misc_TECHNICAL}');
Error('\P{:=  IN_Misc_TECHNICAL}');
Expect(1, 9215, '\p{inmisctechnical}', "");
Expect(0, 9215, '\p{^inmisctechnical}', "");
Expect(0, 9215, '\P{inmisctechnical}', "");
Expect(1, 9215, '\P{^inmisctechnical}', "");
Expect(0, 9216, '\p{inmisctechnical}', "");
Expect(1, 9216, '\p{^inmisctechnical}', "");
Expect(1, 9216, '\P{inmisctechnical}', "");
Expect(0, 9216, '\P{^inmisctechnical}', "");
Expect(1, 9215, '\p{	_in_misc_Technical}', "");
Expect(0, 9215, '\p{^	_in_misc_Technical}', "");
Expect(0, 9215, '\P{	_in_misc_Technical}', "");
Expect(1, 9215, '\P{^	_in_misc_Technical}', "");
Expect(0, 9216, '\p{	_in_misc_Technical}', "");
Expect(1, 9216, '\p{^	_in_misc_Technical}', "");
Expect(1, 9216, '\P{	_in_misc_Technical}', "");
Expect(0, 9216, '\P{^	_in_misc_Technical}', "");
Error('\p{:=-Modifier_Letter}');
Error('\P{:=-Modifier_Letter}');
Expect(1, 94111, '\p{modifierletter}', "");
Expect(0, 94111, '\p{^modifierletter}', "");
Expect(0, 94111, '\P{modifierletter}', "");
Expect(1, 94111, '\P{^modifierletter}', "");
Expect(0, 94112, '\p{modifierletter}', "");
Expect(1, 94112, '\p{^modifierletter}', "");
Expect(1, 94112, '\P{modifierletter}', "");
Expect(0, 94112, '\P{^modifierletter}', "");
Expect(1, 94111, '\p{-	Modifier_letter}', "");
Expect(0, 94111, '\p{^-	Modifier_letter}', "");
Expect(0, 94111, '\P{-	Modifier_letter}', "");
Expect(1, 94111, '\P{^-	Modifier_letter}', "");
Expect(0, 94112, '\p{-	Modifier_letter}', "");
Expect(1, 94112, '\p{^-	Modifier_letter}', "");
Expect(1, 94112, '\P{-	Modifier_letter}', "");
Expect(0, 94112, '\P{^-	Modifier_letter}', "");
Error('\p{-is_modifier_letter:=}');
Error('\P{-is_modifier_letter:=}');
Expect(1, 94111, '\p{ismodifierletter}', "");
Expect(0, 94111, '\p{^ismodifierletter}', "");
Expect(0, 94111, '\P{ismodifierletter}', "");
Expect(1, 94111, '\P{^ismodifierletter}', "");
Expect(0, 94112, '\p{ismodifierletter}', "");
Expect(1, 94112, '\p{^ismodifierletter}', "");
Expect(1, 94112, '\P{ismodifierletter}', "");
Expect(0, 94112, '\P{^ismodifierletter}', "");
Expect(1, 94111, '\p{-IS_modifier_Letter}', "");
Expect(0, 94111, '\p{^-IS_modifier_Letter}', "");
Expect(0, 94111, '\P{-IS_modifier_Letter}', "");
Expect(1, 94111, '\P{^-IS_modifier_Letter}', "");
Expect(0, 94112, '\p{-IS_modifier_Letter}', "");
Expect(1, 94112, '\p{^-IS_modifier_Letter}', "");
Expect(1, 94112, '\P{-IS_modifier_Letter}', "");
Expect(0, 94112, '\P{^-IS_modifier_Letter}', "");
Error('\p{ _LM:=}');
Error('\P{ _LM:=}');
Expect(1, 94111, '\p{lm}', "");
Expect(0, 94111, '\p{^lm}', "");
Expect(0, 94111, '\P{lm}', "");
Expect(1, 94111, '\P{^lm}', "");
Expect(0, 94112, '\p{lm}', "");
Expect(1, 94112, '\p{^lm}', "");
Expect(1, 94112, '\P{lm}', "");
Expect(0, 94112, '\P{^lm}', "");
Expect(1, 94111, '\p{_lm}', "");
Expect(0, 94111, '\p{^_lm}', "");
Expect(0, 94111, '\P{_lm}', "");
Expect(1, 94111, '\P{^_lm}', "");
Expect(0, 94112, '\p{_lm}', "");
Expect(1, 94112, '\p{^_lm}', "");
Expect(1, 94112, '\P{_lm}', "");
Expect(0, 94112, '\P{^_lm}', "");
Error('\p{:=	 Is_Lm}');
Error('\P{:=	 Is_Lm}');
Expect(1, 94111, '\p{islm}', "");
Expect(0, 94111, '\p{^islm}', "");
Expect(0, 94111, '\P{islm}', "");
Expect(1, 94111, '\P{^islm}', "");
Expect(0, 94112, '\p{islm}', "");
Expect(1, 94112, '\p{^islm}', "");
Expect(1, 94112, '\P{islm}', "");
Expect(0, 94112, '\P{^islm}', "");
Expect(1, 94111, '\p{	Is_lm}', "");
Expect(0, 94111, '\p{^	Is_lm}', "");
Expect(0, 94111, '\P{	Is_lm}', "");
Expect(1, 94111, '\P{^	Is_lm}', "");
Expect(0, 94112, '\p{	Is_lm}', "");
Expect(1, 94112, '\p{^	Is_lm}', "");
Expect(1, 94112, '\P{	Is_lm}', "");
Expect(0, 94112, '\P{^	Is_lm}', "");
Error('\p{/a/	-Modifier_Symbol}');
Error('\P{/a/	-Modifier_Symbol}');
Expect(1, 65507, '\p{modifiersymbol}', "");
Expect(0, 65507, '\p{^modifiersymbol}', "");
Expect(0, 65507, '\P{modifiersymbol}', "");
Expect(1, 65507, '\P{^modifiersymbol}', "");
Expect(0, 65508, '\p{modifiersymbol}', "");
Expect(1, 65508, '\p{^modifiersymbol}', "");
Expect(1, 65508, '\P{modifiersymbol}', "");
Expect(0, 65508, '\P{^modifiersymbol}', "");
Expect(1, 65507, '\p{_Modifier_Symbol}', "");
Expect(0, 65507, '\p{^_Modifier_Symbol}', "");
Expect(0, 65507, '\P{_Modifier_Symbol}', "");
Expect(1, 65507, '\P{^_Modifier_Symbol}', "");
Expect(0, 65508, '\p{_Modifier_Symbol}', "");
Expect(1, 65508, '\p{^_Modifier_Symbol}', "");
Expect(1, 65508, '\P{_Modifier_Symbol}', "");
Expect(0, 65508, '\P{^_Modifier_Symbol}', "");
Error('\p{/a/	Is_Modifier_Symbol}');
Error('\P{/a/	Is_Modifier_Symbol}');
Expect(1, 65507, '\p{ismodifiersymbol}', "");
Expect(0, 65507, '\p{^ismodifiersymbol}', "");
Expect(0, 65507, '\P{ismodifiersymbol}', "");
Expect(1, 65507, '\P{^ismodifiersymbol}', "");
Expect(0, 65508, '\p{ismodifiersymbol}', "");
Expect(1, 65508, '\p{^ismodifiersymbol}', "");
Expect(1, 65508, '\P{ismodifiersymbol}', "");
Expect(0, 65508, '\P{^ismodifiersymbol}', "");
Expect(1, 65507, '\p{	_Is_Modifier_Symbol}', "");
Expect(0, 65507, '\p{^	_Is_Modifier_Symbol}', "");
Expect(0, 65507, '\P{	_Is_Modifier_Symbol}', "");
Expect(1, 65507, '\P{^	_Is_Modifier_Symbol}', "");
Expect(0, 65508, '\p{	_Is_Modifier_Symbol}', "");
Expect(1, 65508, '\p{^	_Is_Modifier_Symbol}', "");
Expect(1, 65508, '\P{	_Is_Modifier_Symbol}', "");
Expect(0, 65508, '\P{^	_Is_Modifier_Symbol}', "");
Error('\p{_/a/sk}');
Error('\P{_/a/sk}');
Expect(1, 65507, '\p{sk}', "");
Expect(0, 65507, '\p{^sk}', "");
Expect(0, 65507, '\P{sk}', "");
Expect(1, 65507, '\P{^sk}', "");
Expect(0, 65508, '\p{sk}', "");
Expect(1, 65508, '\p{^sk}', "");
Expect(1, 65508, '\P{sk}', "");
Expect(0, 65508, '\P{^sk}', "");
Expect(1, 65507, '\p{	Sk}', "");
Expect(0, 65507, '\p{^	Sk}', "");
Expect(0, 65507, '\P{	Sk}', "");
Expect(1, 65507, '\P{^	Sk}', "");
Expect(0, 65508, '\p{	Sk}', "");
Expect(1, 65508, '\p{^	Sk}', "");
Expect(1, 65508, '\P{	Sk}', "");
Expect(0, 65508, '\P{^	Sk}', "");
Error('\p{:= -Is_Sk}');
Error('\P{:= -Is_Sk}');
Expect(1, 65507, '\p{issk}', "");
Expect(0, 65507, '\p{^issk}', "");
Expect(0, 65507, '\P{issk}', "");
Expect(1, 65507, '\P{^issk}', "");
Expect(0, 65508, '\p{issk}', "");
Expect(1, 65508, '\p{^issk}', "");
Expect(1, 65508, '\P{issk}', "");
Expect(0, 65508, '\P{^issk}', "");
Expect(1, 65507, '\p{ 	IS_sk}', "");
Expect(0, 65507, '\p{^ 	IS_sk}', "");
Expect(0, 65507, '\P{ 	IS_sk}', "");
Expect(1, 65507, '\P{^ 	IS_sk}', "");
Expect(0, 65508, '\p{ 	IS_sk}', "");
Expect(1, 65508, '\p{^ 	IS_sk}', "");
Expect(1, 65508, '\P{ 	IS_sk}', "");
Expect(0, 65508, '\P{^ 	IS_sk}', "");
Error('\p{Modifier_tone_letters/a/}');
Error('\P{Modifier_tone_letters/a/}');
Expect(1, 42783, '\p{modifiertoneletters}', "");
Expect(0, 42783, '\p{^modifiertoneletters}', "");
Expect(0, 42783, '\P{modifiertoneletters}', "");
Expect(1, 42783, '\P{^modifiertoneletters}', "");
Expect(0, 42784, '\p{modifiertoneletters}', "");
Expect(1, 42784, '\p{^modifiertoneletters}', "");
Expect(1, 42784, '\P{modifiertoneletters}', "");
Expect(0, 42784, '\P{^modifiertoneletters}', "");
Expect(1, 42783, '\p{ -Modifier_TONE_letters}', "");
Expect(0, 42783, '\p{^ -Modifier_TONE_letters}', "");
Expect(0, 42783, '\P{ -Modifier_TONE_letters}', "");
Expect(1, 42783, '\P{^ -Modifier_TONE_letters}', "");
Expect(0, 42784, '\p{ -Modifier_TONE_letters}', "");
Expect(1, 42784, '\p{^ -Modifier_TONE_letters}', "");
Expect(1, 42784, '\P{ -Modifier_TONE_letters}', "");
Expect(0, 42784, '\P{^ -Modifier_TONE_letters}', "");
Error('\p{_	is_MODIFIER_TONE_Letters:=}');
Error('\P{_	is_MODIFIER_TONE_Letters:=}');
Expect(1, 42783, '\p{ismodifiertoneletters}', "");
Expect(0, 42783, '\p{^ismodifiertoneletters}', "");
Expect(0, 42783, '\P{ismodifiertoneletters}', "");
Expect(1, 42783, '\P{^ismodifiertoneletters}', "");
Expect(0, 42784, '\p{ismodifiertoneletters}', "");
Expect(1, 42784, '\p{^ismodifiertoneletters}', "");
Expect(1, 42784, '\P{ismodifiertoneletters}', "");
Expect(0, 42784, '\P{^ismodifiertoneletters}', "");
Expect(1, 42783, '\p{--Is_MODIFIER_TONE_letters}', "");
Expect(0, 42783, '\p{^--Is_MODIFIER_TONE_letters}', "");
Expect(0, 42783, '\P{--Is_MODIFIER_TONE_letters}', "");
Expect(1, 42783, '\P{^--Is_MODIFIER_TONE_letters}', "");
Expect(0, 42784, '\p{--Is_MODIFIER_TONE_letters}', "");
Expect(1, 42784, '\p{^--Is_MODIFIER_TONE_letters}', "");
Expect(1, 42784, '\P{--Is_MODIFIER_TONE_letters}', "");
Expect(0, 42784, '\P{^--Is_MODIFIER_TONE_letters}', "");
Error('\p{	_IN_Modifier_Tone_letters/a/}');
Error('\P{	_IN_Modifier_Tone_letters/a/}');
Expect(1, 42783, '\p{inmodifiertoneletters}', "");
Expect(0, 42783, '\p{^inmodifiertoneletters}', "");
Expect(0, 42783, '\P{inmodifiertoneletters}', "");
Expect(1, 42783, '\P{^inmodifiertoneletters}', "");
Expect(0, 42784, '\p{inmodifiertoneletters}', "");
Expect(1, 42784, '\p{^inmodifiertoneletters}', "");
Expect(1, 42784, '\P{inmodifiertoneletters}', "");
Expect(0, 42784, '\P{^inmodifiertoneletters}', "");
Expect(1, 42783, '\p{	_in_Modifier_Tone_Letters}', "");
Expect(0, 42783, '\p{^	_in_Modifier_Tone_Letters}', "");
Expect(0, 42783, '\P{	_in_Modifier_Tone_Letters}', "");
Expect(1, 42783, '\P{^	_in_Modifier_Tone_Letters}', "");
Expect(0, 42784, '\p{	_in_Modifier_Tone_Letters}', "");
Expect(1, 42784, '\p{^	_in_Modifier_Tone_Letters}', "");
Expect(1, 42784, '\P{	_in_Modifier_Tone_Letters}', "");
Expect(0, 42784, '\P{^	_in_Modifier_Tone_Letters}', "");
Error('\p{/a/_ Mongolian}');
Error('\P{/a/_ Mongolian}');
Expect(1, 6314, '\p{mongolian}', "");
Expect(0, 6314, '\p{^mongolian}', "");
Expect(0, 6314, '\P{mongolian}', "");
Expect(1, 6314, '\P{^mongolian}', "");
Expect(0, 6315, '\p{mongolian}', "");
Expect(1, 6315, '\p{^mongolian}', "");
Expect(1, 6315, '\P{mongolian}', "");
Expect(0, 6315, '\P{^mongolian}', "");
Expect(1, 6314, '\p{		mongolian}', "");
Expect(0, 6314, '\p{^		mongolian}', "");
Expect(0, 6314, '\P{		mongolian}', "");
Expect(1, 6314, '\P{^		mongolian}', "");
Expect(0, 6315, '\p{		mongolian}', "");
Expect(1, 6315, '\p{^		mongolian}', "");
Expect(1, 6315, '\P{		mongolian}', "");
Expect(0, 6315, '\P{^		mongolian}', "");
Error('\p{_	is_MONGOLIAN:=}');
Error('\P{_	is_MONGOLIAN:=}');
Expect(1, 6314, '\p{ismongolian}', "");
Expect(0, 6314, '\p{^ismongolian}', "");
Expect(0, 6314, '\P{ismongolian}', "");
Expect(1, 6314, '\P{^ismongolian}', "");
Expect(0, 6315, '\p{ismongolian}', "");
Expect(1, 6315, '\p{^ismongolian}', "");
Expect(1, 6315, '\P{ismongolian}', "");
Expect(0, 6315, '\P{^ismongolian}', "");
Expect(1, 6314, '\p{		is_mongolian}', "");
Expect(0, 6314, '\p{^		is_mongolian}', "");
Expect(0, 6314, '\P{		is_mongolian}', "");
Expect(1, 6314, '\P{^		is_mongolian}', "");
Expect(0, 6315, '\p{		is_mongolian}', "");
Expect(1, 6315, '\p{^		is_mongolian}', "");
Expect(1, 6315, '\P{		is_mongolian}', "");
Expect(0, 6315, '\P{^		is_mongolian}', "");
Error('\p{-Mong:=}');
Error('\P{-Mong:=}');
Expect(1, 6314, '\p{mong}', "");
Expect(0, 6314, '\p{^mong}', "");
Expect(0, 6314, '\P{mong}', "");
Expect(1, 6314, '\P{^mong}', "");
Expect(0, 6315, '\p{mong}', "");
Expect(1, 6315, '\p{^mong}', "");
Expect(1, 6315, '\P{mong}', "");
Expect(0, 6315, '\P{^mong}', "");
Expect(1, 6314, '\p{-Mong}', "");
Expect(0, 6314, '\p{^-Mong}', "");
Expect(0, 6314, '\P{-Mong}', "");
Expect(1, 6314, '\P{^-Mong}', "");
Expect(0, 6315, '\p{-Mong}', "");
Expect(1, 6315, '\p{^-Mong}', "");
Expect(1, 6315, '\P{-Mong}', "");
Expect(0, 6315, '\P{^-Mong}', "");
Error('\p{:=- IS_Mong}');
Error('\P{:=- IS_Mong}');
Expect(1, 6314, '\p{ismong}', "");
Expect(0, 6314, '\p{^ismong}', "");
Expect(0, 6314, '\P{ismong}', "");
Expect(1, 6314, '\P{^ismong}', "");
Expect(0, 6315, '\p{ismong}', "");
Expect(1, 6315, '\p{^ismong}', "");
Expect(1, 6315, '\P{ismong}', "");
Expect(0, 6315, '\P{^ismong}', "");
Expect(1, 6314, '\p{-IS_MONG}', "");
Expect(0, 6314, '\p{^-IS_MONG}', "");
Expect(0, 6314, '\P{-IS_MONG}', "");
Expect(1, 6314, '\P{^-IS_MONG}', "");
Expect(0, 6315, '\p{-IS_MONG}', "");
Expect(1, 6315, '\p{^-IS_MONG}', "");
Expect(1, 6315, '\P{-IS_MONG}', "");
Expect(0, 6315, '\P{^-IS_MONG}', "");
Error('\p{/a/_Musical_SYMBOLS}');
Error('\P{/a/_Musical_SYMBOLS}');
Expect(1, 119295, '\p{musicalsymbols}', "");
Expect(0, 119295, '\p{^musicalsymbols}', "");
Expect(0, 119295, '\P{musicalsymbols}', "");
Expect(1, 119295, '\P{^musicalsymbols}', "");
Expect(0, 119296, '\p{musicalsymbols}', "");
Expect(1, 119296, '\p{^musicalsymbols}', "");
Expect(1, 119296, '\P{musicalsymbols}', "");
Expect(0, 119296, '\P{^musicalsymbols}', "");
Expect(1, 119295, '\p{	-Musical_Symbols}', "");
Expect(0, 119295, '\p{^	-Musical_Symbols}', "");
Expect(0, 119295, '\P{	-Musical_Symbols}', "");
Expect(1, 119295, '\P{^	-Musical_Symbols}', "");
Expect(0, 119296, '\p{	-Musical_Symbols}', "");
Expect(1, 119296, '\p{^	-Musical_Symbols}', "");
Expect(1, 119296, '\P{	-Musical_Symbols}', "");
Expect(0, 119296, '\P{^	-Musical_Symbols}', "");
Error('\p{	_Is_Musical_SYMBOLS/a/}');
Error('\P{	_Is_Musical_SYMBOLS/a/}');
Expect(1, 119295, '\p{ismusicalsymbols}', "");
Expect(0, 119295, '\p{^ismusicalsymbols}', "");
Expect(0, 119295, '\P{ismusicalsymbols}', "");
Expect(1, 119295, '\P{^ismusicalsymbols}', "");
Expect(0, 119296, '\p{ismusicalsymbols}', "");
Expect(1, 119296, '\p{^ismusicalsymbols}', "");
Expect(1, 119296, '\P{ismusicalsymbols}', "");
Expect(0, 119296, '\P{^ismusicalsymbols}', "");
Expect(1, 119295, '\p{ IS_musical_Symbols}', "");
Expect(0, 119295, '\p{^ IS_musical_Symbols}', "");
Expect(0, 119295, '\P{ IS_musical_Symbols}', "");
Expect(1, 119295, '\P{^ IS_musical_Symbols}', "");
Expect(0, 119296, '\p{ IS_musical_Symbols}', "");
Expect(1, 119296, '\p{^ IS_musical_Symbols}', "");
Expect(1, 119296, '\P{ IS_musical_Symbols}', "");
Expect(0, 119296, '\P{^ IS_musical_Symbols}', "");
Error('\p{/a/In_musical_SYMBOLS}');
Error('\P{/a/In_musical_SYMBOLS}');
Expect(1, 119295, '\p{inmusicalsymbols}', "");
Expect(0, 119295, '\p{^inmusicalsymbols}', "");
Expect(0, 119295, '\P{inmusicalsymbols}', "");
Expect(1, 119295, '\P{^inmusicalsymbols}', "");
Expect(0, 119296, '\p{inmusicalsymbols}', "");
Expect(1, 119296, '\p{^inmusicalsymbols}', "");
Expect(1, 119296, '\P{inmusicalsymbols}', "");
Expect(0, 119296, '\P{^inmusicalsymbols}', "");
Expect(1, 119295, '\p{-	In_musical_Symbols}', "");
Expect(0, 119295, '\p{^-	In_musical_Symbols}', "");
Expect(0, 119295, '\P{-	In_musical_Symbols}', "");
Expect(1, 119295, '\P{^-	In_musical_Symbols}', "");
Expect(0, 119296, '\p{-	In_musical_Symbols}', "");
Expect(1, 119296, '\p{^-	In_musical_Symbols}', "");
Expect(1, 119296, '\P{-	In_musical_Symbols}', "");
Expect(0, 119296, '\P{^-	In_musical_Symbols}', "");
Error('\p{ music:=}');
Error('\P{ music:=}');
Expect(1, 119295, '\p{music}', "");
Expect(0, 119295, '\p{^music}', "");
Expect(0, 119295, '\P{music}', "");
Expect(1, 119295, '\P{^music}', "");
Expect(0, 119296, '\p{music}', "");
Expect(1, 119296, '\p{^music}', "");
Expect(1, 119296, '\P{music}', "");
Expect(0, 119296, '\P{^music}', "");
Expect(1, 119295, '\p{_ music}', "");
Expect(0, 119295, '\p{^_ music}', "");
Expect(0, 119295, '\P{_ music}', "");
Expect(1, 119295, '\P{^_ music}', "");
Expect(0, 119296, '\p{_ music}', "");
Expect(1, 119296, '\p{^_ music}', "");
Expect(1, 119296, '\P{_ music}', "");
Expect(0, 119296, '\P{^_ music}', "");
Error('\p{ -Is_music/a/}');
Error('\P{ -Is_music/a/}');
Expect(1, 119295, '\p{ismusic}', "");
Expect(0, 119295, '\p{^ismusic}', "");
Expect(0, 119295, '\P{ismusic}', "");
Expect(1, 119295, '\P{^ismusic}', "");
Expect(0, 119296, '\p{ismusic}', "");
Expect(1, 119296, '\p{^ismusic}', "");
Expect(1, 119296, '\P{ismusic}', "");
Expect(0, 119296, '\P{^ismusic}', "");
Expect(1, 119295, '\p{ IS_music}', "");
Expect(0, 119295, '\p{^ IS_music}', "");
Expect(0, 119295, '\P{ IS_music}', "");
Expect(1, 119295, '\P{^ IS_music}', "");
Expect(0, 119296, '\p{ IS_music}', "");
Expect(1, 119296, '\p{^ IS_music}', "");
Expect(1, 119296, '\P{ IS_music}', "");
Expect(0, 119296, '\P{^ IS_music}', "");
Error('\p{/a/_In_Music}');
Error('\P{/a/_In_Music}');
Expect(1, 119295, '\p{inmusic}', "");
Expect(0, 119295, '\p{^inmusic}', "");
Expect(0, 119295, '\P{inmusic}', "");
Expect(1, 119295, '\P{^inmusic}', "");
Expect(0, 119296, '\p{inmusic}', "");
Expect(1, 119296, '\p{^inmusic}', "");
Expect(1, 119296, '\P{inmusic}', "");
Expect(0, 119296, '\P{^inmusic}', "");
Expect(1, 119295, '\p{-	IN_MUSIC}', "");
Expect(0, 119295, '\p{^-	IN_MUSIC}', "");
Expect(0, 119295, '\P{-	IN_MUSIC}', "");
Expect(1, 119295, '\P{^-	IN_MUSIC}', "");
Expect(0, 119296, '\p{-	IN_MUSIC}', "");
Expect(1, 119296, '\p{^-	IN_MUSIC}', "");
Expect(1, 119296, '\P{-	IN_MUSIC}', "");
Expect(0, 119296, '\P{^-	IN_MUSIC}', "");
Error('\p{-/a/Myanmar}');
Error('\P{-/a/Myanmar}');
Expect(1, 43643, '\p{myanmar}', "");
Expect(0, 43643, '\p{^myanmar}', "");
Expect(0, 43643, '\P{myanmar}', "");
Expect(1, 43643, '\P{^myanmar}', "");
Expect(0, 43644, '\p{myanmar}', "");
Expect(1, 43644, '\p{^myanmar}', "");
Expect(1, 43644, '\P{myanmar}', "");
Expect(0, 43644, '\P{^myanmar}', "");
Expect(1, 43643, '\p{ Myanmar}', "");
Expect(0, 43643, '\p{^ Myanmar}', "");
Expect(0, 43643, '\P{ Myanmar}', "");
Expect(1, 43643, '\P{^ Myanmar}', "");
Expect(0, 43644, '\p{ Myanmar}', "");
Expect(1, 43644, '\p{^ Myanmar}', "");
Expect(1, 43644, '\P{ Myanmar}', "");
Expect(0, 43644, '\P{^ Myanmar}', "");
Error('\p{	_Is_myanmar/a/}');
Error('\P{	_Is_myanmar/a/}');
Expect(1, 43643, '\p{ismyanmar}', "");
Expect(0, 43643, '\p{^ismyanmar}', "");
Expect(0, 43643, '\P{ismyanmar}', "");
Expect(1, 43643, '\P{^ismyanmar}', "");
Expect(0, 43644, '\p{ismyanmar}', "");
Expect(1, 43644, '\p{^ismyanmar}', "");
Expect(1, 43644, '\P{ismyanmar}', "");
Expect(0, 43644, '\P{^ismyanmar}', "");
Expect(1, 43643, '\p{ IS_Myanmar}', "");
Expect(0, 43643, '\p{^ IS_Myanmar}', "");
Expect(0, 43643, '\P{ IS_Myanmar}', "");
Expect(1, 43643, '\P{^ IS_Myanmar}', "");
Expect(0, 43644, '\p{ IS_Myanmar}', "");
Expect(1, 43644, '\p{^ IS_Myanmar}', "");
Expect(1, 43644, '\P{ IS_Myanmar}', "");
Expect(0, 43644, '\P{^ IS_Myanmar}', "");
Error('\p{_:=MYMR}');
Error('\P{_:=MYMR}');
Expect(1, 43643, '\p{mymr}', "");
Expect(0, 43643, '\p{^mymr}', "");
Expect(0, 43643, '\P{mymr}', "");
Expect(1, 43643, '\P{^mymr}', "");
Expect(0, 43644, '\p{mymr}', "");
Expect(1, 43644, '\p{^mymr}', "");
Expect(1, 43644, '\P{mymr}', "");
Expect(0, 43644, '\P{^mymr}', "");
Expect(1, 43643, '\p{-mymr}', "");
Expect(0, 43643, '\p{^-mymr}', "");
Expect(0, 43643, '\P{-mymr}', "");
Expect(1, 43643, '\P{^-mymr}', "");
Expect(0, 43644, '\p{-mymr}', "");
Expect(1, 43644, '\p{^-mymr}', "");
Expect(1, 43644, '\P{-mymr}', "");
Expect(0, 43644, '\P{^-mymr}', "");
Error('\p{_IS_MYMR:=}');
Error('\P{_IS_MYMR:=}');
Expect(1, 43643, '\p{ismymr}', "");
Expect(0, 43643, '\p{^ismymr}', "");
Expect(0, 43643, '\P{ismymr}', "");
Expect(1, 43643, '\P{^ismymr}', "");
Expect(0, 43644, '\p{ismymr}', "");
Expect(1, 43644, '\p{^ismymr}', "");
Expect(1, 43644, '\P{ismymr}', "");
Expect(0, 43644, '\P{^ismymr}', "");
Expect(1, 43643, '\p{_Is_MYMR}', "");
Expect(0, 43643, '\p{^_Is_MYMR}', "");
Expect(0, 43643, '\P{_Is_MYMR}', "");
Expect(1, 43643, '\P{^_Is_MYMR}', "");
Expect(0, 43644, '\p{_Is_MYMR}', "");
Expect(1, 43644, '\p{^_Is_MYMR}', "");
Expect(1, 43644, '\P{_Is_MYMR}', "");
Expect(0, 43644, '\P{^_Is_MYMR}', "");
Error('\p{	/a/Myanmar_EXTENDED_A}');
Error('\P{	/a/Myanmar_EXTENDED_A}');
Expect(1, 43647, '\p{myanmarextendeda}', "");
Expect(0, 43647, '\p{^myanmarextendeda}', "");
Expect(0, 43647, '\P{myanmarextendeda}', "");
Expect(1, 43647, '\P{^myanmarextendeda}', "");
Expect(0, 43648, '\p{myanmarextendeda}', "");
Expect(1, 43648, '\p{^myanmarextendeda}', "");
Expect(1, 43648, '\P{myanmarextendeda}', "");
Expect(0, 43648, '\P{^myanmarextendeda}', "");
Expect(1, 43647, '\p{-_Myanmar_Extended_a}', "");
Expect(0, 43647, '\p{^-_Myanmar_Extended_a}', "");
Expect(0, 43647, '\P{-_Myanmar_Extended_a}', "");
Expect(1, 43647, '\P{^-_Myanmar_Extended_a}', "");
Expect(0, 43648, '\p{-_Myanmar_Extended_a}', "");
Expect(1, 43648, '\p{^-_Myanmar_Extended_a}', "");
Expect(1, 43648, '\P{-_Myanmar_Extended_a}', "");
Expect(0, 43648, '\P{^-_Myanmar_Extended_a}', "");
Error('\p{/a/-	is_myanmar_Extended_A}');
Error('\P{/a/-	is_myanmar_Extended_A}');
Expect(1, 43647, '\p{ismyanmarextendeda}', "");
Expect(0, 43647, '\p{^ismyanmarextendeda}', "");
Expect(0, 43647, '\P{ismyanmarextendeda}', "");
Expect(1, 43647, '\P{^ismyanmarextendeda}', "");
Expect(0, 43648, '\p{ismyanmarextendeda}', "");
Expect(1, 43648, '\p{^ismyanmarextendeda}', "");
Expect(1, 43648, '\P{ismyanmarextendeda}', "");
Expect(0, 43648, '\P{^ismyanmarextendeda}', "");
Expect(1, 43647, '\p{--IS_myanmar_Extended_A}', "");
Expect(0, 43647, '\p{^--IS_myanmar_Extended_A}', "");
Expect(0, 43647, '\P{--IS_myanmar_Extended_A}', "");
Expect(1, 43647, '\P{^--IS_myanmar_Extended_A}', "");
Expect(0, 43648, '\p{--IS_myanmar_Extended_A}', "");
Expect(1, 43648, '\p{^--IS_myanmar_Extended_A}', "");
Expect(1, 43648, '\P{--IS_myanmar_Extended_A}', "");
Expect(0, 43648, '\P{^--IS_myanmar_Extended_A}', "");
Error('\p{/a/__In_MYANMAR_EXTENDED_a}');
Error('\P{/a/__In_MYANMAR_EXTENDED_a}');
Expect(1, 43647, '\p{inmyanmarextendeda}', "");
Expect(0, 43647, '\p{^inmyanmarextendeda}', "");
Expect(0, 43647, '\P{inmyanmarextendeda}', "");
Expect(1, 43647, '\P{^inmyanmarextendeda}', "");
Expect(0, 43648, '\p{inmyanmarextendeda}', "");
Expect(1, 43648, '\p{^inmyanmarextendeda}', "");
Expect(1, 43648, '\P{inmyanmarextendeda}', "");
Expect(0, 43648, '\P{^inmyanmarextendeda}', "");
Expect(1, 43647, '\p{ In_myanmar_extended_a}', "");
Expect(0, 43647, '\p{^ In_myanmar_extended_a}', "");
Expect(0, 43647, '\P{ In_myanmar_extended_a}', "");
Expect(1, 43647, '\P{^ In_myanmar_extended_a}', "");
Expect(0, 43648, '\p{ In_myanmar_extended_a}', "");
Expect(1, 43648, '\p{^ In_myanmar_extended_a}', "");
Expect(1, 43648, '\P{ In_myanmar_extended_a}', "");
Expect(0, 43648, '\P{^ In_myanmar_extended_a}', "");
Error('\p{  myanmar_Ext_A:=}');
Error('\P{  myanmar_Ext_A:=}');
Expect(1, 43647, '\p{myanmarexta}', "");
Expect(0, 43647, '\p{^myanmarexta}', "");
Expect(0, 43647, '\P{myanmarexta}', "");
Expect(1, 43647, '\P{^myanmarexta}', "");
Expect(0, 43648, '\p{myanmarexta}', "");
Expect(1, 43648, '\p{^myanmarexta}', "");
Expect(1, 43648, '\P{myanmarexta}', "");
Expect(0, 43648, '\P{^myanmarexta}', "");
Expect(1, 43647, '\p{--Myanmar_Ext_A}', "");
Expect(0, 43647, '\p{^--Myanmar_Ext_A}', "");
Expect(0, 43647, '\P{--Myanmar_Ext_A}', "");
Expect(1, 43647, '\P{^--Myanmar_Ext_A}', "");
Expect(0, 43648, '\p{--Myanmar_Ext_A}', "");
Expect(1, 43648, '\p{^--Myanmar_Ext_A}', "");
Expect(1, 43648, '\P{--Myanmar_Ext_A}', "");
Expect(0, 43648, '\P{^--Myanmar_Ext_A}', "");
Error('\p{:=_Is_MYANMAR_EXT_A}');
Error('\P{:=_Is_MYANMAR_EXT_A}');
Expect(1, 43647, '\p{ismyanmarexta}', "");
Expect(0, 43647, '\p{^ismyanmarexta}', "");
Expect(0, 43647, '\P{ismyanmarexta}', "");
Expect(1, 43647, '\P{^ismyanmarexta}', "");
Expect(0, 43648, '\p{ismyanmarexta}', "");
Expect(1, 43648, '\p{^ismyanmarexta}', "");
Expect(1, 43648, '\P{ismyanmarexta}', "");
Expect(0, 43648, '\P{^ismyanmarexta}', "");
Expect(1, 43647, '\p{  Is_MYANMAR_EXT_A}', "");
Expect(0, 43647, '\p{^  Is_MYANMAR_EXT_A}', "");
Expect(0, 43647, '\P{  Is_MYANMAR_EXT_A}', "");
Expect(1, 43647, '\P{^  Is_MYANMAR_EXT_A}', "");
Expect(0, 43648, '\p{  Is_MYANMAR_EXT_A}', "");
Expect(1, 43648, '\p{^  Is_MYANMAR_EXT_A}', "");
Expect(1, 43648, '\P{  Is_MYANMAR_EXT_A}', "");
Expect(0, 43648, '\P{^  Is_MYANMAR_EXT_A}', "");
Error('\p{	In_Myanmar_ext_A/a/}');
Error('\P{	In_Myanmar_ext_A/a/}');
Expect(1, 43647, '\p{inmyanmarexta}', "");
Expect(0, 43647, '\p{^inmyanmarexta}', "");
Expect(0, 43647, '\P{inmyanmarexta}', "");
Expect(1, 43647, '\P{^inmyanmarexta}', "");
Expect(0, 43648, '\p{inmyanmarexta}', "");
Expect(1, 43648, '\p{^inmyanmarexta}', "");
Expect(1, 43648, '\P{inmyanmarexta}', "");
Expect(0, 43648, '\P{^inmyanmarexta}', "");
Expect(1, 43647, '\p{	 IN_Myanmar_EXT_A}', "");
Expect(0, 43647, '\p{^	 IN_Myanmar_EXT_A}', "");
Expect(0, 43647, '\P{	 IN_Myanmar_EXT_A}', "");
Expect(1, 43647, '\P{^	 IN_Myanmar_EXT_A}', "");
Expect(0, 43648, '\p{	 IN_Myanmar_EXT_A}', "");
Expect(1, 43648, '\p{^	 IN_Myanmar_EXT_A}', "");
Expect(1, 43648, '\P{	 IN_Myanmar_EXT_A}', "");
Expect(0, 43648, '\P{^	 IN_Myanmar_EXT_A}', "");
Error('\p{- new_Tai_Lue/a/}');
Error('\P{- new_Tai_Lue/a/}');
Expect(1, 6623, '\p{newtailue}', "");
Expect(0, 6623, '\p{^newtailue}', "");
Expect(0, 6623, '\P{newtailue}', "");
Expect(1, 6623, '\P{^newtailue}', "");
Expect(0, 6624, '\p{newtailue}', "");
Expect(1, 6624, '\p{^newtailue}', "");
Expect(1, 6624, '\P{newtailue}', "");
Expect(0, 6624, '\P{^newtailue}', "");
Expect(1, 6623, '\p{ New_tai_Lue}', "");
Expect(0, 6623, '\p{^ New_tai_Lue}', "");
Expect(0, 6623, '\P{ New_tai_Lue}', "");
Expect(1, 6623, '\P{^ New_tai_Lue}', "");
Expect(0, 6624, '\p{ New_tai_Lue}', "");
Expect(1, 6624, '\p{^ New_tai_Lue}', "");
Expect(1, 6624, '\P{ New_tai_Lue}', "");
Expect(0, 6624, '\P{^ New_tai_Lue}', "");
Error('\p{_:=Is_New_Tai_LUE}');
Error('\P{_:=Is_New_Tai_LUE}');
Expect(1, 6623, '\p{isnewtailue}', "");
Expect(0, 6623, '\p{^isnewtailue}', "");
Expect(0, 6623, '\P{isnewtailue}', "");
Expect(1, 6623, '\P{^isnewtailue}', "");
Expect(0, 6624, '\p{isnewtailue}', "");
Expect(1, 6624, '\p{^isnewtailue}', "");
Expect(1, 6624, '\P{isnewtailue}', "");
Expect(0, 6624, '\P{^isnewtailue}', "");
Expect(1, 6623, '\p{- IS_new_tai_Lue}', "");
Expect(0, 6623, '\p{^- IS_new_tai_Lue}', "");
Expect(0, 6623, '\P{- IS_new_tai_Lue}', "");
Expect(1, 6623, '\P{^- IS_new_tai_Lue}', "");
Expect(0, 6624, '\p{- IS_new_tai_Lue}', "");
Expect(1, 6624, '\p{^- IS_new_tai_Lue}', "");
Expect(1, 6624, '\P{- IS_new_tai_Lue}', "");
Expect(0, 6624, '\P{^- IS_new_tai_Lue}', "");
Error('\p{	TALU:=}');
Error('\P{	TALU:=}');
Expect(1, 6623, '\p{talu}', "");
Expect(0, 6623, '\p{^talu}', "");
Expect(0, 6623, '\P{talu}', "");
Expect(1, 6623, '\P{^talu}', "");
Expect(0, 6624, '\p{talu}', "");
Expect(1, 6624, '\p{^talu}', "");
Expect(1, 6624, '\P{talu}', "");
Expect(0, 6624, '\P{^talu}', "");
Expect(1, 6623, '\p{_-Talu}', "");
Expect(0, 6623, '\p{^_-Talu}', "");
Expect(0, 6623, '\P{_-Talu}', "");
Expect(1, 6623, '\P{^_-Talu}', "");
Expect(0, 6624, '\p{_-Talu}', "");
Expect(1, 6624, '\p{^_-Talu}', "");
Expect(1, 6624, '\P{_-Talu}', "");
Expect(0, 6624, '\P{^_-Talu}', "");
Error('\p{/a/_-IS_TALU}');
Error('\P{/a/_-IS_TALU}');
Expect(1, 6623, '\p{istalu}', "");
Expect(0, 6623, '\p{^istalu}', "");
Expect(0, 6623, '\P{istalu}', "");
Expect(1, 6623, '\P{^istalu}', "");
Expect(0, 6624, '\p{istalu}', "");
Expect(1, 6624, '\p{^istalu}', "");
Expect(1, 6624, '\P{istalu}', "");
Expect(0, 6624, '\P{^istalu}', "");
Expect(1, 6623, '\p{	-Is_talu}', "");
Expect(0, 6623, '\p{^	-Is_talu}', "");
Expect(0, 6623, '\P{	-Is_talu}', "");
Expect(1, 6623, '\P{^	-Is_talu}', "");
Expect(0, 6624, '\p{	-Is_talu}', "");
Expect(1, 6624, '\p{^	-Is_talu}', "");
Expect(1, 6624, '\P{	-Is_talu}', "");
Expect(0, 6624, '\P{^	-Is_talu}', "");
Error('\p{/a/--Nko}');
Error('\P{/a/--Nko}');
Expect(1, 2042, '\p{nko}', "");
Expect(0, 2042, '\p{^nko}', "");
Expect(0, 2042, '\P{nko}', "");
Expect(1, 2042, '\P{^nko}', "");
Expect(0, 2043, '\p{nko}', "");
Expect(1, 2043, '\p{^nko}', "");
Expect(1, 2043, '\P{nko}', "");
Expect(0, 2043, '\P{^nko}', "");
Expect(1, 2042, '\p{_NKO}', "");
Expect(0, 2042, '\p{^_NKO}', "");
Expect(0, 2042, '\P{_NKO}', "");
Expect(1, 2042, '\P{^_NKO}', "");
Expect(0, 2043, '\p{_NKO}', "");
Expect(1, 2043, '\p{^_NKO}', "");
Expect(1, 2043, '\P{_NKO}', "");
Expect(0, 2043, '\P{^_NKO}', "");
Error('\p{_:=Is_NKO}');
Error('\P{_:=Is_NKO}');
Expect(1, 2042, '\p{isnko}', "");
Expect(0, 2042, '\p{^isnko}', "");
Expect(0, 2042, '\P{isnko}', "");
Expect(1, 2042, '\P{^isnko}', "");
Expect(0, 2043, '\p{isnko}', "");
Expect(1, 2043, '\p{^isnko}', "");
Expect(1, 2043, '\P{isnko}', "");
Expect(0, 2043, '\P{^isnko}', "");
Expect(1, 2042, '\p{_ is_nko}', "");
Expect(0, 2042, '\p{^_ is_nko}', "");
Expect(0, 2042, '\P{_ is_nko}', "");
Expect(1, 2042, '\P{^_ is_nko}', "");
Expect(0, 2043, '\p{_ is_nko}', "");
Expect(1, 2043, '\p{^_ is_nko}', "");
Expect(1, 2043, '\P{_ is_nko}', "");
Expect(0, 2043, '\P{^_ is_nko}', "");
Error('\p{:=		nkoo}');
Error('\P{:=		nkoo}');
Expect(1, 2042, '\p{nkoo}', "");
Expect(0, 2042, '\p{^nkoo}', "");
Expect(0, 2042, '\P{nkoo}', "");
Expect(1, 2042, '\P{^nkoo}', "");
Expect(0, 2043, '\p{nkoo}', "");
Expect(1, 2043, '\p{^nkoo}', "");
Expect(1, 2043, '\P{nkoo}', "");
Expect(0, 2043, '\P{^nkoo}', "");
Expect(1, 2042, '\p{	_NKOO}', "");
Expect(0, 2042, '\p{^	_NKOO}', "");
Expect(0, 2042, '\P{	_NKOO}', "");
Expect(1, 2042, '\P{^	_NKOO}', "");
Expect(0, 2043, '\p{	_NKOO}', "");
Expect(1, 2043, '\p{^	_NKOO}', "");
Expect(1, 2043, '\P{	_NKOO}', "");
Expect(0, 2043, '\P{^	_NKOO}', "");
Error('\p{-:=Is_Nkoo}');
Error('\P{-:=Is_Nkoo}');
Expect(1, 2042, '\p{isnkoo}', "");
Expect(0, 2042, '\p{^isnkoo}', "");
Expect(0, 2042, '\P{isnkoo}', "");
Expect(1, 2042, '\P{^isnkoo}', "");
Expect(0, 2043, '\p{isnkoo}', "");
Expect(1, 2043, '\p{^isnkoo}', "");
Expect(1, 2043, '\P{isnkoo}', "");
Expect(0, 2043, '\P{^isnkoo}', "");
Expect(1, 2042, '\p{ is_nkoo}', "");
Expect(0, 2042, '\p{^ is_nkoo}', "");
Expect(0, 2042, '\P{ is_nkoo}', "");
Expect(1, 2042, '\P{^ is_nkoo}', "");
Expect(0, 2043, '\p{ is_nkoo}', "");
Expect(1, 2043, '\p{^ is_nkoo}', "");
Expect(1, 2043, '\P{ is_nkoo}', "");
Expect(0, 2043, '\P{^ is_nkoo}', "");
Error('\p{/a/_-no_BLOCK}');
Error('\P{/a/_-no_BLOCK}');
Expect(1, 918000, '\p{noblock}', "");
Expect(0, 918000, '\p{^noblock}', "");
Expect(0, 918000, '\P{noblock}', "");
Expect(1, 918000, '\P{^noblock}', "");
Expect(0, 983040, '\p{noblock}', "");
Expect(1, 983040, '\p{^noblock}', "");
Expect(1, 983040, '\P{noblock}', "");
Expect(0, 983040, '\P{^noblock}', "");
Expect(1, 918000, '\p{ -NO_Block}', "");
Expect(0, 918000, '\p{^ -NO_Block}', "");
Expect(0, 918000, '\P{ -NO_Block}', "");
Expect(1, 918000, '\P{^ -NO_Block}', "");
Expect(0, 983040, '\p{ -NO_Block}', "");
Expect(1, 983040, '\p{^ -NO_Block}', "");
Expect(1, 983040, '\P{ -NO_Block}', "");
Expect(0, 983040, '\P{^ -NO_Block}', "");
Error('\p{/a/IS_no_Block}');
Error('\P{/a/IS_no_Block}');
Expect(1, 918000, '\p{isnoblock}', "");
Expect(0, 918000, '\p{^isnoblock}', "");
Expect(0, 918000, '\P{isnoblock}', "");
Expect(1, 918000, '\P{^isnoblock}', "");
Expect(0, 983040, '\p{isnoblock}', "");
Expect(1, 983040, '\p{^isnoblock}', "");
Expect(1, 983040, '\P{isnoblock}', "");
Expect(0, 983040, '\P{^isnoblock}', "");
Expect(1, 918000, '\p{-_Is_no_block}', "");
Expect(0, 918000, '\p{^-_Is_no_block}', "");
Expect(0, 918000, '\P{-_Is_no_block}', "");
Expect(1, 918000, '\P{^-_Is_no_block}', "");
Expect(0, 983040, '\p{-_Is_no_block}', "");
Expect(1, 983040, '\p{^-_Is_no_block}', "");
Expect(1, 983040, '\P{-_Is_no_block}', "");
Expect(0, 983040, '\P{^-_Is_no_block}', "");
Error('\p{	:=In_no_BLOCK}');
Error('\P{	:=In_no_BLOCK}');
Expect(1, 918000, '\p{innoblock}', "");
Expect(0, 918000, '\p{^innoblock}', "");
Expect(0, 918000, '\P{innoblock}', "");
Expect(1, 918000, '\P{^innoblock}', "");
Expect(0, 983040, '\p{innoblock}', "");
Expect(1, 983040, '\p{^innoblock}', "");
Expect(1, 983040, '\P{innoblock}', "");
Expect(0, 983040, '\P{^innoblock}', "");
Expect(1, 918000, '\p{	 In_No_block}', "");
Expect(0, 918000, '\p{^	 In_No_block}', "");
Expect(0, 918000, '\P{	 In_No_block}', "");
Expect(1, 918000, '\P{^	 In_No_block}', "");
Expect(0, 983040, '\p{	 In_No_block}', "");
Expect(1, 983040, '\p{^	 In_No_block}', "");
Expect(1, 983040, '\P{	 In_No_block}', "");
Expect(0, 983040, '\P{^	 In_No_block}', "");
Error('\p{- NB/a/}');
Error('\P{- NB/a/}');
Expect(1, 918000, '\p{nb}', "");
Expect(0, 918000, '\p{^nb}', "");
Expect(0, 918000, '\P{nb}', "");
Expect(1, 918000, '\P{^nb}', "");
Expect(0, 983040, '\p{nb}', "");
Expect(1, 983040, '\p{^nb}', "");
Expect(1, 983040, '\P{nb}', "");
Expect(0, 983040, '\P{^nb}', "");
Expect(1, 918000, '\p{ _nb}', "");
Expect(0, 918000, '\p{^ _nb}', "");
Expect(0, 918000, '\P{ _nb}', "");
Expect(1, 918000, '\P{^ _nb}', "");
Expect(0, 983040, '\p{ _nb}', "");
Expect(1, 983040, '\p{^ _nb}', "");
Expect(1, 983040, '\P{ _nb}', "");
Expect(0, 983040, '\P{^ _nb}', "");
Error('\p{:=_-is_NB}');
Error('\P{:=_-is_NB}');
Expect(1, 918000, '\p{isnb}', "");
Expect(0, 918000, '\p{^isnb}', "");
Expect(0, 918000, '\P{isnb}', "");
Expect(1, 918000, '\P{^isnb}', "");
Expect(0, 983040, '\p{isnb}', "");
Expect(1, 983040, '\p{^isnb}', "");
Expect(1, 983040, '\P{isnb}', "");
Expect(0, 983040, '\P{^isnb}', "");
Expect(1, 918000, '\p{-is_NB}', "");
Expect(0, 918000, '\p{^-is_NB}', "");
Expect(0, 918000, '\P{-is_NB}', "");
Expect(1, 918000, '\P{^-is_NB}', "");
Expect(0, 983040, '\p{-is_NB}', "");
Expect(1, 983040, '\p{^-is_NB}', "");
Expect(1, 983040, '\P{-is_NB}', "");
Expect(0, 983040, '\P{^-is_NB}', "");
Error('\p{:=	In_NB}');
Error('\P{:=	In_NB}');
Expect(1, 918000, '\p{innb}', "");
Expect(0, 918000, '\p{^innb}', "");
Expect(0, 918000, '\P{innb}', "");
Expect(1, 918000, '\P{^innb}', "");
Expect(0, 983040, '\p{innb}', "");
Expect(1, 983040, '\p{^innb}', "");
Expect(1, 983040, '\P{innb}', "");
Expect(0, 983040, '\P{^innb}', "");
Expect(1, 918000, '\p{	in_nb}', "");
Expect(0, 918000, '\p{^	in_nb}', "");
Expect(0, 918000, '\P{	in_nb}', "");
Expect(1, 918000, '\P{^	in_nb}', "");
Expect(0, 983040, '\p{	in_nb}', "");
Expect(1, 983040, '\p{^	in_nb}', "");
Expect(1, 983040, '\P{	in_nb}', "");
Expect(0, 983040, '\P{^	in_nb}', "");
Error('\p{/a/		NONCHARACTER_Code_Point}');
Error('\P{/a/		NONCHARACTER_Code_Point}');
Expect(1, 1114111, '\p{noncharactercodepoint}', "");
Expect(0, 1114111, '\p{^noncharactercodepoint}', "");
Expect(0, 1114111, '\P{noncharactercodepoint}', "");
Expect(1, 1114111, '\P{^noncharactercodepoint}', "");
Expect(0, 1114109, '\p{noncharactercodepoint}', "");
Expect(1, 1114109, '\p{^noncharactercodepoint}', "");
Expect(1, 1114109, '\P{noncharactercodepoint}', "");
Expect(0, 1114109, '\P{^noncharactercodepoint}', "");
Expect(1, 1114111, '\p{__NONCHARACTER_code_POINT}', "");
Expect(0, 1114111, '\p{^__NONCHARACTER_code_POINT}', "");
Expect(0, 1114111, '\P{__NONCHARACTER_code_POINT}', "");
Expect(1, 1114111, '\P{^__NONCHARACTER_code_POINT}', "");
Expect(0, 1114109, '\p{__NONCHARACTER_code_POINT}', "");
Expect(1, 1114109, '\p{^__NONCHARACTER_code_POINT}', "");
Expect(1, 1114109, '\P{__NONCHARACTER_code_POINT}', "");
Expect(0, 1114109, '\P{^__NONCHARACTER_code_POINT}', "");
Error('\p{/a/ Is_Noncharacter_CODE_POINT}');
Error('\P{/a/ Is_Noncharacter_CODE_POINT}');
Expect(1, 1114111, '\p{isnoncharactercodepoint}', "");
Expect(0, 1114111, '\p{^isnoncharactercodepoint}', "");
Expect(0, 1114111, '\P{isnoncharactercodepoint}', "");
Expect(1, 1114111, '\P{^isnoncharactercodepoint}', "");
Expect(0, 1114109, '\p{isnoncharactercodepoint}', "");
Expect(1, 1114109, '\p{^isnoncharactercodepoint}', "");
Expect(1, 1114109, '\P{isnoncharactercodepoint}', "");
Expect(0, 1114109, '\P{^isnoncharactercodepoint}', "");
Expect(1, 1114111, '\p{_IS_Noncharacter_CODE_point}', "");
Expect(0, 1114111, '\p{^_IS_Noncharacter_CODE_point}', "");
Expect(0, 1114111, '\P{_IS_Noncharacter_CODE_point}', "");
Expect(1, 1114111, '\P{^_IS_Noncharacter_CODE_point}', "");
Expect(0, 1114109, '\p{_IS_Noncharacter_CODE_point}', "");
Expect(1, 1114109, '\p{^_IS_Noncharacter_CODE_point}', "");
Expect(1, 1114109, '\P{_IS_Noncharacter_CODE_point}', "");
Expect(0, 1114109, '\P{^_IS_Noncharacter_CODE_point}', "");
Error('\p{:=	-NChar}');
Error('\P{:=	-NChar}');
Expect(1, 1114111, '\p{nchar}', "");
Expect(0, 1114111, '\p{^nchar}', "");
Expect(0, 1114111, '\P{nchar}', "");
Expect(1, 1114111, '\P{^nchar}', "");
Expect(0, 1114109, '\p{nchar}', "");
Expect(1, 1114109, '\p{^nchar}', "");
Expect(1, 1114109, '\P{nchar}', "");
Expect(0, 1114109, '\P{^nchar}', "");
Expect(1, 1114111, '\p{ 	NChar}', "");
Expect(0, 1114111, '\p{^ 	NChar}', "");
Expect(0, 1114111, '\P{ 	NChar}', "");
Expect(1, 1114111, '\P{^ 	NChar}', "");
Expect(0, 1114109, '\p{ 	NChar}', "");
Expect(1, 1114109, '\p{^ 	NChar}', "");
Expect(1, 1114109, '\P{ 	NChar}', "");
Expect(0, 1114109, '\P{^ 	NChar}', "");
Error('\p{--is_NChar/a/}');
Error('\P{--is_NChar/a/}');
Expect(1, 1114111, '\p{isnchar}', "");
Expect(0, 1114111, '\p{^isnchar}', "");
Expect(0, 1114111, '\P{isnchar}', "");
Expect(1, 1114111, '\P{^isnchar}', "");
Expect(0, 1114109, '\p{isnchar}', "");
Expect(1, 1114109, '\p{^isnchar}', "");
Expect(1, 1114109, '\P{isnchar}', "");
Expect(0, 1114109, '\P{^isnchar}', "");
Expect(1, 1114111, '\p{ Is_NCHAR}', "");
Expect(0, 1114111, '\p{^ Is_NCHAR}', "");
Expect(0, 1114111, '\P{ Is_NCHAR}', "");
Expect(1, 1114111, '\P{^ Is_NCHAR}', "");
Expect(0, 1114109, '\p{ Is_NCHAR}', "");
Expect(1, 1114109, '\p{^ Is_NCHAR}', "");
Expect(1, 1114109, '\P{ Is_NCHAR}', "");
Expect(0, 1114109, '\P{^ Is_NCHAR}', "");
Error('\p{- NONSPACING_MARK/a/}');
Error('\P{- NONSPACING_MARK/a/}');
Expect(1, 917999, '\p{nonspacingmark}', "");
Expect(0, 917999, '\p{^nonspacingmark}', "");
Expect(0, 917999, '\P{nonspacingmark}', "");
Expect(1, 917999, '\P{^nonspacingmark}', "");
Expect(0, 918000, '\p{nonspacingmark}', "");
Expect(1, 918000, '\p{^nonspacingmark}', "");
Expect(1, 918000, '\P{nonspacingmark}', "");
Expect(0, 918000, '\P{^nonspacingmark}', "");
Expect(1, 917999, '\p{		nonspacing_Mark}', "");
Expect(0, 917999, '\p{^		nonspacing_Mark}', "");
Expect(0, 917999, '\P{		nonspacing_Mark}', "");
Expect(1, 917999, '\P{^		nonspacing_Mark}', "");
Expect(0, 918000, '\p{		nonspacing_Mark}', "");
Expect(1, 918000, '\p{^		nonspacing_Mark}', "");
Expect(1, 918000, '\P{		nonspacing_Mark}', "");
Expect(0, 918000, '\P{^		nonspacing_Mark}', "");
Error('\p{/a/IS_NONSPACING_MARK}');
Error('\P{/a/IS_NONSPACING_MARK}');
Expect(1, 917999, '\p{isnonspacingmark}', "");
Expect(0, 917999, '\p{^isnonspacingmark}', "");
Expect(0, 917999, '\P{isnonspacingmark}', "");
Expect(1, 917999, '\P{^isnonspacingmark}', "");
Expect(0, 918000, '\p{isnonspacingmark}', "");
Expect(1, 918000, '\p{^isnonspacingmark}', "");
Expect(1, 918000, '\P{isnonspacingmark}', "");
Expect(0, 918000, '\P{^isnonspacingmark}', "");
Expect(1, 917999, '\p{--Is_NONSPACING_MARK}', "");
Expect(0, 917999, '\p{^--Is_NONSPACING_MARK}', "");
Expect(0, 917999, '\P{--Is_NONSPACING_MARK}', "");
Expect(1, 917999, '\P{^--Is_NONSPACING_MARK}', "");
Expect(0, 918000, '\p{--Is_NONSPACING_MARK}', "");
Expect(1, 918000, '\p{^--Is_NONSPACING_MARK}', "");
Expect(1, 918000, '\P{--Is_NONSPACING_MARK}', "");
Expect(0, 918000, '\P{^--Is_NONSPACING_MARK}', "");
Error('\p{ _MN:=}');
Error('\P{ _MN:=}');
Expect(1, 917999, '\p{mn}', "");
Expect(0, 917999, '\p{^mn}', "");
Expect(0, 917999, '\P{mn}', "");
Expect(1, 917999, '\P{^mn}', "");
Expect(0, 918000, '\p{mn}', "");
Expect(1, 918000, '\p{^mn}', "");
Expect(1, 918000, '\P{mn}', "");
Expect(0, 918000, '\P{^mn}', "");
Expect(1, 917999, '\p{-Mn}', "");
Expect(0, 917999, '\p{^-Mn}', "");
Expect(0, 917999, '\P{-Mn}', "");
Expect(1, 917999, '\P{^-Mn}', "");
Expect(0, 918000, '\p{-Mn}', "");
Expect(1, 918000, '\p{^-Mn}', "");
Expect(1, 918000, '\P{-Mn}', "");
Expect(0, 918000, '\P{^-Mn}', "");
Error('\p{:= Is_MN}');
Error('\P{:= Is_MN}');
Expect(1, 917999, '\p{ismn}', "");
Expect(0, 917999, '\p{^ismn}', "");
Expect(0, 917999, '\P{ismn}', "");
Expect(1, 917999, '\P{^ismn}', "");
Expect(0, 918000, '\p{ismn}', "");
Expect(1, 918000, '\p{^ismn}', "");
Expect(1, 918000, '\P{ismn}', "");
Expect(0, 918000, '\P{^ismn}', "");
Expect(1, 917999, '\p{ 	is_Mn}', "");
Expect(0, 917999, '\p{^ 	is_Mn}', "");
Expect(0, 917999, '\P{ 	is_Mn}', "");
Expect(1, 917999, '\P{^ 	is_Mn}', "");
Expect(0, 918000, '\p{ 	is_Mn}', "");
Expect(1, 918000, '\p{^ 	is_Mn}', "");
Expect(1, 918000, '\P{ 	is_Mn}', "");
Expect(0, 918000, '\P{^ 	is_Mn}', "");
Error('\p{/a/_NUMBER}');
Error('\P{/a/_NUMBER}');
Expect(1, 127242, '\p{number}', "");
Expect(0, 127242, '\p{^number}', "");
Expect(0, 127242, '\P{number}', "");
Expect(1, 127242, '\P{^number}', "");
Expect(0, 127243, '\p{number}', "");
Expect(1, 127243, '\p{^number}', "");
Expect(1, 127243, '\P{number}', "");
Expect(0, 127243, '\P{^number}', "");
Expect(1, 127242, '\p{	_number}', "");
Expect(0, 127242, '\p{^	_number}', "");
Expect(0, 127242, '\P{	_number}', "");
Expect(1, 127242, '\P{^	_number}', "");
Expect(0, 127243, '\p{	_number}', "");
Expect(1, 127243, '\p{^	_number}', "");
Expect(1, 127243, '\P{	_number}', "");
Expect(0, 127243, '\P{^	_number}', "");
Error('\p{ /a/Is_number}');
Error('\P{ /a/Is_number}');
Expect(1, 127242, '\p{isnumber}', "");
Expect(0, 127242, '\p{^isnumber}', "");
Expect(0, 127242, '\P{isnumber}', "");
Expect(1, 127242, '\P{^isnumber}', "");
Expect(0, 127243, '\p{isnumber}', "");
Expect(1, 127243, '\p{^isnumber}', "");
Expect(1, 127243, '\P{isnumber}', "");
Expect(0, 127243, '\P{^isnumber}', "");
Expect(1, 127242, '\p{-Is_Number}', "");
Expect(0, 127242, '\p{^-Is_Number}', "");
Expect(0, 127242, '\P{-Is_Number}', "");
Expect(1, 127242, '\P{^-Is_Number}', "");
Expect(0, 127243, '\p{-Is_Number}', "");
Expect(1, 127243, '\p{^-Is_Number}', "");
Expect(1, 127243, '\P{-Is_Number}', "");
Expect(0, 127243, '\P{^-Is_Number}', "");
Error('\p{--n/a/}');
Error('\P{--n/a/}');
Expect(1, 127242, '\p{n}', "");
Expect(0, 127242, '\p{^n}', "");
Expect(0, 127242, '\P{n}', "");
Expect(1, 127242, '\P{^n}', "");
Expect(0, 127243, '\p{n}', "");
Expect(1, 127243, '\p{^n}', "");
Expect(1, 127243, '\P{n}', "");
Expect(0, 127243, '\P{^n}', "");
Expect(1, 127242, '\p{	N}', "");
Expect(0, 127242, '\p{^	N}', "");
Expect(0, 127242, '\P{	N}', "");
Expect(1, 127242, '\P{^	N}', "");
Expect(0, 127243, '\p{	N}', "");
Expect(1, 127243, '\p{^	N}', "");
Expect(1, 127243, '\P{	N}', "");
Expect(0, 127243, '\P{^	N}', "");
Error('\p{_ is_N/a/}');
Error('\P{_ is_N/a/}');
Expect(1, 127242, '\p{isn}', "");
Expect(0, 127242, '\p{^isn}', "");
Expect(0, 127242, '\P{isn}', "");
Expect(1, 127242, '\P{^isn}', "");
Expect(0, 127243, '\p{isn}', "");
Expect(1, 127243, '\p{^isn}', "");
Expect(1, 127243, '\P{isn}', "");
Expect(0, 127243, '\P{^isn}', "");
Expect(1, 127242, '\p{--Is_n}', "");
Expect(0, 127242, '\p{^--Is_n}', "");
Expect(0, 127242, '\P{--Is_n}', "");
Expect(1, 127242, '\P{^--Is_n}', "");
Expect(0, 127243, '\p{--Is_n}', "");
Expect(1, 127243, '\p{^--Is_n}', "");
Expect(1, 127243, '\P{--Is_n}', "");
Expect(0, 127243, '\P{^--Is_n}', "");
Error('\p{ Number_FORMS:=}');
Error('\P{ Number_FORMS:=}');
Expect(1, 8591, '\p{numberforms}', "");
Expect(0, 8591, '\p{^numberforms}', "");
Expect(0, 8591, '\P{numberforms}', "");
Expect(1, 8591, '\P{^numberforms}', "");
Expect(0, 8592, '\p{numberforms}', "");
Expect(1, 8592, '\p{^numberforms}', "");
Expect(1, 8592, '\P{numberforms}', "");
Expect(0, 8592, '\P{^numberforms}', "");
Expect(1, 8591, '\p{ 	NUMBER_Forms}', "");
Expect(0, 8591, '\p{^ 	NUMBER_Forms}', "");
Expect(0, 8591, '\P{ 	NUMBER_Forms}', "");
Expect(1, 8591, '\P{^ 	NUMBER_Forms}', "");
Expect(0, 8592, '\p{ 	NUMBER_Forms}', "");
Expect(1, 8592, '\p{^ 	NUMBER_Forms}', "");
Expect(1, 8592, '\P{ 	NUMBER_Forms}', "");
Expect(0, 8592, '\P{^ 	NUMBER_Forms}', "");
Error('\p{	Is_Number_Forms/a/}');
Error('\P{	Is_Number_Forms/a/}');
Expect(1, 8591, '\p{isnumberforms}', "");
Expect(0, 8591, '\p{^isnumberforms}', "");
Expect(0, 8591, '\P{isnumberforms}', "");
Expect(1, 8591, '\P{^isnumberforms}', "");
Expect(0, 8592, '\p{isnumberforms}', "");
Expect(1, 8592, '\p{^isnumberforms}', "");
Expect(1, 8592, '\P{isnumberforms}', "");
Expect(0, 8592, '\P{^isnumberforms}', "");
Expect(1, 8591, '\p{  IS_Number_Forms}', "");
Expect(0, 8591, '\p{^  IS_Number_Forms}', "");
Expect(0, 8591, '\P{  IS_Number_Forms}', "");
Expect(1, 8591, '\P{^  IS_Number_Forms}', "");
Expect(0, 8592, '\p{  IS_Number_Forms}', "");
Expect(1, 8592, '\p{^  IS_Number_Forms}', "");
Expect(1, 8592, '\P{  IS_Number_Forms}', "");
Expect(0, 8592, '\P{^  IS_Number_Forms}', "");
Error('\p{	in_Number_Forms/a/}');
Error('\P{	in_Number_Forms/a/}');
Expect(1, 8591, '\p{innumberforms}', "");
Expect(0, 8591, '\p{^innumberforms}', "");
Expect(0, 8591, '\P{innumberforms}', "");
Expect(1, 8591, '\P{^innumberforms}', "");
Expect(0, 8592, '\p{innumberforms}', "");
Expect(1, 8592, '\p{^innumberforms}', "");
Expect(1, 8592, '\P{innumberforms}', "");
Expect(0, 8592, '\P{^innumberforms}', "");
Expect(1, 8591, '\p{	In_NUMBER_FORMS}', "");
Expect(0, 8591, '\p{^	In_NUMBER_FORMS}', "");
Expect(0, 8591, '\P{	In_NUMBER_FORMS}', "");
Expect(1, 8591, '\P{^	In_NUMBER_FORMS}', "");
Expect(0, 8592, '\p{	In_NUMBER_FORMS}', "");
Expect(1, 8592, '\p{^	In_NUMBER_FORMS}', "");
Expect(1, 8592, '\P{	In_NUMBER_FORMS}', "");
Expect(0, 8592, '\P{^	In_NUMBER_FORMS}', "");
Error('\p{:=ogham}');
Error('\P{:=ogham}');
Expect(1, 5788, '\p{ogham}', "");
Expect(0, 5788, '\p{^ogham}', "");
Expect(0, 5788, '\P{ogham}', "");
Expect(1, 5788, '\P{^ogham}', "");
Expect(0, 5789, '\p{ogham}', "");
Expect(1, 5789, '\p{^ogham}', "");
Expect(1, 5789, '\P{ogham}', "");
Expect(0, 5789, '\P{^ogham}', "");
Expect(1, 5788, '\p{ -ogham}', "");
Expect(0, 5788, '\p{^ -ogham}', "");
Expect(0, 5788, '\P{ -ogham}', "");
Expect(1, 5788, '\P{^ -ogham}', "");
Expect(0, 5789, '\p{ -ogham}', "");
Expect(1, 5789, '\p{^ -ogham}', "");
Expect(1, 5789, '\P{ -ogham}', "");
Expect(0, 5789, '\P{^ -ogham}', "");
Error('\p{/a/-Is_Ogham}');
Error('\P{/a/-Is_Ogham}');
Expect(1, 5788, '\p{isogham}', "");
Expect(0, 5788, '\p{^isogham}', "");
Expect(0, 5788, '\P{isogham}', "");
Expect(1, 5788, '\P{^isogham}', "");
Expect(0, 5789, '\p{isogham}', "");
Expect(1, 5789, '\p{^isogham}', "");
Expect(1, 5789, '\P{isogham}', "");
Expect(0, 5789, '\P{^isogham}', "");
Expect(1, 5788, '\p{-	Is_Ogham}', "");
Expect(0, 5788, '\p{^-	Is_Ogham}', "");
Expect(0, 5788, '\P{-	Is_Ogham}', "");
Expect(1, 5788, '\P{^-	Is_Ogham}', "");
Expect(0, 5789, '\p{-	Is_Ogham}', "");
Expect(1, 5789, '\p{^-	Is_Ogham}', "");
Expect(1, 5789, '\P{-	Is_Ogham}', "");
Expect(0, 5789, '\P{^-	Is_Ogham}', "");
Error('\p{:=OGAM}');
Error('\P{:=OGAM}');
Expect(1, 5788, '\p{ogam}', "");
Expect(0, 5788, '\p{^ogam}', "");
Expect(0, 5788, '\P{ogam}', "");
Expect(1, 5788, '\P{^ogam}', "");
Expect(0, 5789, '\p{ogam}', "");
Expect(1, 5789, '\p{^ogam}', "");
Expect(1, 5789, '\P{ogam}', "");
Expect(0, 5789, '\P{^ogam}', "");
Expect(1, 5788, '\p{	 Ogam}', "");
Expect(0, 5788, '\p{^	 Ogam}', "");
Expect(0, 5788, '\P{	 Ogam}', "");
Expect(1, 5788, '\P{^	 Ogam}', "");
Expect(0, 5789, '\p{	 Ogam}', "");
Expect(1, 5789, '\p{^	 Ogam}', "");
Expect(1, 5789, '\P{	 Ogam}', "");
Expect(0, 5789, '\P{^	 Ogam}', "");
Error('\p{ -Is_Ogam:=}');
Error('\P{ -Is_Ogam:=}');
Expect(1, 5788, '\p{isogam}', "");
Expect(0, 5788, '\p{^isogam}', "");
Expect(0, 5788, '\P{isogam}', "");
Expect(1, 5788, '\P{^isogam}', "");
Expect(0, 5789, '\p{isogam}', "");
Expect(1, 5789, '\p{^isogam}', "");
Expect(1, 5789, '\P{isogam}', "");
Expect(0, 5789, '\P{^isogam}', "");
Expect(1, 5788, '\p{	 Is_Ogam}', "");
Expect(0, 5788, '\p{^	 Is_Ogam}', "");
Expect(0, 5788, '\P{	 Is_Ogam}', "");
Expect(1, 5788, '\P{^	 Is_Ogam}', "");
Expect(0, 5789, '\p{	 Is_Ogam}', "");
Expect(1, 5789, '\p{^	 Is_Ogam}', "");
Expect(1, 5789, '\P{	 Is_Ogam}', "");
Expect(0, 5789, '\P{^	 Is_Ogam}', "");
Error('\p{/a/--Ol_Chiki}');
Error('\P{/a/--Ol_Chiki}');
Expect(1, 7295, '\p{olchiki}', "");
Expect(0, 7295, '\p{^olchiki}', "");
Expect(0, 7295, '\P{olchiki}', "");
Expect(1, 7295, '\P{^olchiki}', "");
Expect(0, 7296, '\p{olchiki}', "");
Expect(1, 7296, '\p{^olchiki}', "");
Expect(1, 7296, '\P{olchiki}', "");
Expect(0, 7296, '\P{^olchiki}', "");
Expect(1, 7295, '\p{	-Ol_CHIKI}', "");
Expect(0, 7295, '\p{^	-Ol_CHIKI}', "");
Expect(0, 7295, '\P{	-Ol_CHIKI}', "");
Expect(1, 7295, '\P{^	-Ol_CHIKI}', "");
Expect(0, 7296, '\p{	-Ol_CHIKI}', "");
Expect(1, 7296, '\p{^	-Ol_CHIKI}', "");
Expect(1, 7296, '\P{	-Ol_CHIKI}', "");
Expect(0, 7296, '\P{^	-Ol_CHIKI}', "");
Error('\p{/a/_	Is_Ol_chiki}');
Error('\P{/a/_	Is_Ol_chiki}');
Expect(1, 7295, '\p{isolchiki}', "");
Expect(0, 7295, '\p{^isolchiki}', "");
Expect(0, 7295, '\P{isolchiki}', "");
Expect(1, 7295, '\P{^isolchiki}', "");
Expect(0, 7296, '\p{isolchiki}', "");
Expect(1, 7296, '\p{^isolchiki}', "");
Expect(1, 7296, '\P{isolchiki}', "");
Expect(0, 7296, '\P{^isolchiki}', "");
Expect(1, 7295, '\p{_ Is_Ol_CHIKI}', "");
Expect(0, 7295, '\p{^_ Is_Ol_CHIKI}', "");
Expect(0, 7295, '\P{_ Is_Ol_CHIKI}', "");
Expect(1, 7295, '\P{^_ Is_Ol_CHIKI}', "");
Expect(0, 7296, '\p{_ Is_Ol_CHIKI}', "");
Expect(1, 7296, '\p{^_ Is_Ol_CHIKI}', "");
Expect(1, 7296, '\P{_ Is_Ol_CHIKI}', "");
Expect(0, 7296, '\P{^_ Is_Ol_CHIKI}', "");
Error('\p{-/a/olck}');
Error('\P{-/a/olck}');
Expect(1, 7295, '\p{olck}', "");
Expect(0, 7295, '\p{^olck}', "");
Expect(0, 7295, '\P{olck}', "");
Expect(1, 7295, '\P{^olck}', "");
Expect(0, 7296, '\p{olck}', "");
Expect(1, 7296, '\p{^olck}', "");
Expect(1, 7296, '\P{olck}', "");
Expect(0, 7296, '\P{^olck}', "");
Expect(1, 7295, '\p{-olck}', "");
Expect(0, 7295, '\p{^-olck}', "");
Expect(0, 7295, '\P{-olck}', "");
Expect(1, 7295, '\P{^-olck}', "");
Expect(0, 7296, '\p{-olck}', "");
Expect(1, 7296, '\p{^-olck}', "");
Expect(1, 7296, '\P{-olck}', "");
Expect(0, 7296, '\P{^-olck}', "");
Error('\p{ Is_OLCK:=}');
Error('\P{ Is_OLCK:=}');
Expect(1, 7295, '\p{isolck}', "");
Expect(0, 7295, '\p{^isolck}', "");
Expect(0, 7295, '\P{isolck}', "");
Expect(1, 7295, '\P{^isolck}', "");
Expect(0, 7296, '\p{isolck}', "");
Expect(1, 7296, '\p{^isolck}', "");
Expect(1, 7296, '\P{isolck}', "");
Expect(0, 7296, '\P{^isolck}', "");
Expect(1, 7295, '\p{ 	is_OLCK}', "");
Expect(0, 7295, '\p{^ 	is_OLCK}', "");
Expect(0, 7295, '\P{ 	is_OLCK}', "");
Expect(1, 7295, '\P{^ 	is_OLCK}', "");
Expect(0, 7296, '\p{ 	is_OLCK}', "");
Expect(1, 7296, '\p{^ 	is_OLCK}', "");
Expect(1, 7296, '\P{ 	is_OLCK}', "");
Expect(0, 7296, '\P{^ 	is_OLCK}', "");
Error('\p{	:=OLD_Italic}');
Error('\P{	:=OLD_Italic}');
Expect(1, 66339, '\p{olditalic}', "");
Expect(0, 66339, '\p{^olditalic}', "");
Expect(0, 66339, '\P{olditalic}', "");
Expect(1, 66339, '\P{^olditalic}', "");
Expect(0, 66340, '\p{olditalic}', "");
Expect(1, 66340, '\p{^olditalic}', "");
Expect(1, 66340, '\P{olditalic}', "");
Expect(0, 66340, '\P{^olditalic}', "");
Expect(1, 66339, '\p{	old_Italic}', "");
Expect(0, 66339, '\p{^	old_Italic}', "");
Expect(0, 66339, '\P{	old_Italic}', "");
Expect(1, 66339, '\P{^	old_Italic}', "");
Expect(0, 66340, '\p{	old_Italic}', "");
Expect(1, 66340, '\p{^	old_Italic}', "");
Expect(1, 66340, '\P{	old_Italic}', "");
Expect(0, 66340, '\P{^	old_Italic}', "");
Error('\p{-/a/Is_Old_italic}');
Error('\P{-/a/Is_Old_italic}');
Expect(1, 66339, '\p{isolditalic}', "");
Expect(0, 66339, '\p{^isolditalic}', "");
Expect(0, 66339, '\P{isolditalic}', "");
Expect(1, 66339, '\P{^isolditalic}', "");
Expect(0, 66340, '\p{isolditalic}', "");
Expect(1, 66340, '\p{^isolditalic}', "");
Expect(1, 66340, '\P{isolditalic}', "");
Expect(0, 66340, '\P{^isolditalic}', "");
Expect(1, 66339, '\p{_ Is_Old_Italic}', "");
Expect(0, 66339, '\p{^_ Is_Old_Italic}', "");
Expect(0, 66339, '\P{_ Is_Old_Italic}', "");
Expect(1, 66339, '\P{^_ Is_Old_Italic}', "");
Expect(0, 66340, '\p{_ Is_Old_Italic}', "");
Expect(1, 66340, '\p{^_ Is_Old_Italic}', "");
Expect(1, 66340, '\P{_ Is_Old_Italic}', "");
Expect(0, 66340, '\P{^_ Is_Old_Italic}', "");
Error('\p{:=ital}');
Error('\P{:=ital}');
Expect(1, 66339, '\p{ital}', "");
Expect(0, 66339, '\p{^ital}', "");
Expect(0, 66339, '\P{ital}', "");
Expect(1, 66339, '\P{^ital}', "");
Expect(0, 66340, '\p{ital}', "");
Expect(1, 66340, '\p{^ital}', "");
Expect(1, 66340, '\P{ital}', "");
Expect(0, 66340, '\P{^ital}', "");
Expect(1, 66339, '\p{--Ital}', "");
Expect(0, 66339, '\p{^--Ital}', "");
Expect(0, 66339, '\P{--Ital}', "");
Expect(1, 66339, '\P{^--Ital}', "");
Expect(0, 66340, '\p{--Ital}', "");
Expect(1, 66340, '\p{^--Ital}', "");
Expect(1, 66340, '\P{--Ital}', "");
Expect(0, 66340, '\P{^--Ital}', "");
Error('\p{_:=Is_Ital}');
Error('\P{_:=Is_Ital}');
Expect(1, 66339, '\p{isital}', "");
Expect(0, 66339, '\p{^isital}', "");
Expect(0, 66339, '\P{isital}', "");
Expect(1, 66339, '\P{^isital}', "");
Expect(0, 66340, '\p{isital}', "");
Expect(1, 66340, '\p{^isital}', "");
Expect(1, 66340, '\P{isital}', "");
Expect(0, 66340, '\P{^isital}', "");
Expect(1, 66339, '\p{ is_ital}', "");
Expect(0, 66339, '\p{^ is_ital}', "");
Expect(0, 66339, '\P{ is_ital}', "");
Expect(1, 66339, '\P{^ is_ital}', "");
Expect(0, 66340, '\p{ is_ital}', "");
Expect(1, 66340, '\p{^ is_ital}', "");
Expect(1, 66340, '\P{ is_ital}', "");
Expect(0, 66340, '\P{^ is_ital}', "");
Error('\p{ /a/OLD_Persian}');
Error('\P{ /a/OLD_Persian}');
Expect(1, 66517, '\p{oldpersian}', "");
Expect(0, 66517, '\p{^oldpersian}', "");
Expect(0, 66517, '\P{oldpersian}', "");
Expect(1, 66517, '\P{^oldpersian}', "");
Expect(0, 66518, '\p{oldpersian}', "");
Expect(1, 66518, '\p{^oldpersian}', "");
Expect(1, 66518, '\P{oldpersian}', "");
Expect(0, 66518, '\P{^oldpersian}', "");
Expect(1, 66517, '\p{_OLD_persian}', "");
Expect(0, 66517, '\p{^_OLD_persian}', "");
Expect(0, 66517, '\P{_OLD_persian}', "");
Expect(1, 66517, '\P{^_OLD_persian}', "");
Expect(0, 66518, '\p{_OLD_persian}', "");
Expect(1, 66518, '\p{^_OLD_persian}', "");
Expect(1, 66518, '\P{_OLD_persian}', "");
Expect(0, 66518, '\P{^_OLD_persian}', "");
Error('\p{_	is_OLD_Persian:=}');
Error('\P{_	is_OLD_Persian:=}');
Expect(1, 66517, '\p{isoldpersian}', "");
Expect(0, 66517, '\p{^isoldpersian}', "");
Expect(0, 66517, '\P{isoldpersian}', "");
Expect(1, 66517, '\P{^isoldpersian}', "");
Expect(0, 66518, '\p{isoldpersian}', "");
Expect(1, 66518, '\p{^isoldpersian}', "");
Expect(1, 66518, '\P{isoldpersian}', "");
Expect(0, 66518, '\P{^isoldpersian}', "");
Expect(1, 66517, '\p{-_Is_OLD_persian}', "");
Expect(0, 66517, '\p{^-_Is_OLD_persian}', "");
Expect(0, 66517, '\P{-_Is_OLD_persian}', "");
Expect(1, 66517, '\P{^-_Is_OLD_persian}', "");
Expect(0, 66518, '\p{-_Is_OLD_persian}', "");
Expect(1, 66518, '\p{^-_Is_OLD_persian}', "");
Expect(1, 66518, '\P{-_Is_OLD_persian}', "");
Expect(0, 66518, '\P{^-_Is_OLD_persian}', "");
Error('\p{- xpeo:=}');
Error('\P{- xpeo:=}');
Expect(1, 66517, '\p{xpeo}', "");
Expect(0, 66517, '\p{^xpeo}', "");
Expect(0, 66517, '\P{xpeo}', "");
Expect(1, 66517, '\P{^xpeo}', "");
Expect(0, 66518, '\p{xpeo}', "");
Expect(1, 66518, '\p{^xpeo}', "");
Expect(1, 66518, '\P{xpeo}', "");
Expect(0, 66518, '\P{^xpeo}', "");
Expect(1, 66517, '\p{ _Xpeo}', "");
Expect(0, 66517, '\p{^ _Xpeo}', "");
Expect(0, 66517, '\P{ _Xpeo}', "");
Expect(1, 66517, '\P{^ _Xpeo}', "");
Expect(0, 66518, '\p{ _Xpeo}', "");
Expect(1, 66518, '\p{^ _Xpeo}', "");
Expect(1, 66518, '\P{ _Xpeo}', "");
Expect(0, 66518, '\P{^ _Xpeo}', "");
Error('\p{:= Is_XPEO}');
Error('\P{:= Is_XPEO}');
Expect(1, 66517, '\p{isxpeo}', "");
Expect(0, 66517, '\p{^isxpeo}', "");
Expect(0, 66517, '\P{isxpeo}', "");
Expect(1, 66517, '\P{^isxpeo}', "");
Expect(0, 66518, '\p{isxpeo}', "");
Expect(1, 66518, '\p{^isxpeo}', "");
Expect(1, 66518, '\P{isxpeo}', "");
Expect(0, 66518, '\P{^isxpeo}', "");
Expect(1, 66517, '\p{  is_Xpeo}', "");
Expect(0, 66517, '\p{^  is_Xpeo}', "");
Expect(0, 66517, '\P{  is_Xpeo}', "");
Expect(1, 66517, '\P{^  is_Xpeo}', "");
Expect(0, 66518, '\p{  is_Xpeo}', "");
Expect(1, 66518, '\p{^  is_Xpeo}', "");
Expect(1, 66518, '\P{  is_Xpeo}', "");
Expect(0, 66518, '\P{^  is_Xpeo}', "");
Error('\p{	-Old_South_Arabian/a/}');
Error('\P{	-Old_South_Arabian/a/}');
Expect(1, 68223, '\p{oldsoutharabian}', "");
Expect(0, 68223, '\p{^oldsoutharabian}', "");
Expect(0, 68223, '\P{oldsoutharabian}', "");
Expect(1, 68223, '\P{^oldsoutharabian}', "");
Expect(0, 68224, '\p{oldsoutharabian}', "");
Expect(1, 68224, '\p{^oldsoutharabian}', "");
Expect(1, 68224, '\P{oldsoutharabian}', "");
Expect(0, 68224, '\P{^oldsoutharabian}', "");
Expect(1, 68223, '\p{-_Old_SOUTH_Arabian}', "");
Expect(0, 68223, '\p{^-_Old_SOUTH_Arabian}', "");
Expect(0, 68223, '\P{-_Old_SOUTH_Arabian}', "");
Expect(1, 68223, '\P{^-_Old_SOUTH_Arabian}', "");
Expect(0, 68224, '\p{-_Old_SOUTH_Arabian}', "");
Expect(1, 68224, '\p{^-_Old_SOUTH_Arabian}', "");
Expect(1, 68224, '\P{-_Old_SOUTH_Arabian}', "");
Expect(0, 68224, '\P{^-_Old_SOUTH_Arabian}', "");
Error('\p{/a/	Is_old_SOUTH_Arabian}');
Error('\P{/a/	Is_old_SOUTH_Arabian}');
Expect(1, 68223, '\p{isoldsoutharabian}', "");
Expect(0, 68223, '\p{^isoldsoutharabian}', "");
Expect(0, 68223, '\P{isoldsoutharabian}', "");
Expect(1, 68223, '\P{^isoldsoutharabian}', "");
Expect(0, 68224, '\p{isoldsoutharabian}', "");
Expect(1, 68224, '\p{^isoldsoutharabian}', "");
Expect(1, 68224, '\P{isoldsoutharabian}', "");
Expect(0, 68224, '\P{^isoldsoutharabian}', "");
Expect(1, 68223, '\p{  IS_OLD_south_ARABIAN}', "");
Expect(0, 68223, '\p{^  IS_OLD_south_ARABIAN}', "");
Expect(0, 68223, '\P{  IS_OLD_south_ARABIAN}', "");
Expect(1, 68223, '\P{^  IS_OLD_south_ARABIAN}', "");
Expect(0, 68224, '\p{  IS_OLD_south_ARABIAN}', "");
Expect(1, 68224, '\p{^  IS_OLD_south_ARABIAN}', "");
Expect(1, 68224, '\P{  IS_OLD_south_ARABIAN}', "");
Expect(0, 68224, '\P{^  IS_OLD_south_ARABIAN}', "");
Error('\p{__SARB:=}');
Error('\P{__SARB:=}');
Expect(1, 68223, '\p{sarb}', "");
Expect(0, 68223, '\p{^sarb}', "");
Expect(0, 68223, '\P{sarb}', "");
Expect(1, 68223, '\P{^sarb}', "");
Expect(0, 68224, '\p{sarb}', "");
Expect(1, 68224, '\p{^sarb}', "");
Expect(1, 68224, '\P{sarb}', "");
Expect(0, 68224, '\P{^sarb}', "");
Expect(1, 68223, '\p{_sarb}', "");
Expect(0, 68223, '\p{^_sarb}', "");
Expect(0, 68223, '\P{_sarb}', "");
Expect(1, 68223, '\P{^_sarb}', "");
Expect(0, 68224, '\p{_sarb}', "");
Expect(1, 68224, '\p{^_sarb}', "");
Expect(1, 68224, '\P{_sarb}', "");
Expect(0, 68224, '\P{^_sarb}', "");
Error('\p{/a/ is_Sarb}');
Error('\P{/a/ is_Sarb}');
Expect(1, 68223, '\p{issarb}', "");
Expect(0, 68223, '\p{^issarb}', "");
Expect(0, 68223, '\P{issarb}', "");
Expect(1, 68223, '\P{^issarb}', "");
Expect(0, 68224, '\p{issarb}', "");
Expect(1, 68224, '\p{^issarb}', "");
Expect(1, 68224, '\P{issarb}', "");
Expect(0, 68224, '\P{^issarb}', "");
Expect(1, 68223, '\p{__is_Sarb}', "");
Expect(0, 68223, '\p{^__is_Sarb}', "");
Expect(0, 68223, '\P{__is_Sarb}', "");
Expect(1, 68223, '\P{^__is_Sarb}', "");
Expect(0, 68224, '\p{__is_Sarb}', "");
Expect(1, 68224, '\p{^__is_Sarb}', "");
Expect(1, 68224, '\P{__is_Sarb}', "");
Expect(0, 68224, '\P{^__is_Sarb}', "");
Error('\p{:=_	old_Turkic}');
Error('\P{:=_	old_Turkic}');
Expect(1, 68680, '\p{oldturkic}', "");
Expect(0, 68680, '\p{^oldturkic}', "");
Expect(0, 68680, '\P{oldturkic}', "");
Expect(1, 68680, '\P{^oldturkic}', "");
Expect(0, 68681, '\p{oldturkic}', "");
Expect(1, 68681, '\p{^oldturkic}', "");
Expect(1, 68681, '\P{oldturkic}', "");
Expect(0, 68681, '\P{^oldturkic}', "");
Expect(1, 68680, '\p{_	old_turkic}', "");
Expect(0, 68680, '\p{^_	old_turkic}', "");
Expect(0, 68680, '\P{_	old_turkic}', "");
Expect(1, 68680, '\P{^_	old_turkic}', "");
Expect(0, 68681, '\p{_	old_turkic}', "");
Expect(1, 68681, '\p{^_	old_turkic}', "");
Expect(1, 68681, '\P{_	old_turkic}', "");
Expect(0, 68681, '\P{^_	old_turkic}', "");
Error('\p{Is_OLD_Turkic/a/}');
Error('\P{Is_OLD_Turkic/a/}');
Expect(1, 68680, '\p{isoldturkic}', "");
Expect(0, 68680, '\p{^isoldturkic}', "");
Expect(0, 68680, '\P{isoldturkic}', "");
Expect(1, 68680, '\P{^isoldturkic}', "");
Expect(0, 68681, '\p{isoldturkic}', "");
Expect(1, 68681, '\p{^isoldturkic}', "");
Expect(1, 68681, '\P{isoldturkic}', "");
Expect(0, 68681, '\P{^isoldturkic}', "");
Expect(1, 68680, '\p{-is_OLD_TURKIC}', "");
Expect(0, 68680, '\p{^-is_OLD_TURKIC}', "");
Expect(0, 68680, '\P{-is_OLD_TURKIC}', "");
Expect(1, 68680, '\P{^-is_OLD_TURKIC}', "");
Expect(0, 68681, '\p{-is_OLD_TURKIC}', "");
Expect(1, 68681, '\p{^-is_OLD_TURKIC}', "");
Expect(1, 68681, '\P{-is_OLD_TURKIC}', "");
Expect(0, 68681, '\P{^-is_OLD_TURKIC}', "");
Error('\p{:=orkh}');
Error('\P{:=orkh}');
Expect(1, 68680, '\p{orkh}', "");
Expect(0, 68680, '\p{^orkh}', "");
Expect(0, 68680, '\P{orkh}', "");
Expect(1, 68680, '\P{^orkh}', "");
Expect(0, 68681, '\p{orkh}', "");
Expect(1, 68681, '\p{^orkh}', "");
Expect(1, 68681, '\P{orkh}', "");
Expect(0, 68681, '\P{^orkh}', "");
Expect(1, 68680, '\p{	orkh}', "");
Expect(0, 68680, '\p{^	orkh}', "");
Expect(0, 68680, '\P{	orkh}', "");
Expect(1, 68680, '\P{^	orkh}', "");
Expect(0, 68681, '\p{	orkh}', "");
Expect(1, 68681, '\p{^	orkh}', "");
Expect(1, 68681, '\P{	orkh}', "");
Expect(0, 68681, '\P{^	orkh}', "");
Error('\p{-	Is_orkh/a/}');
Error('\P{-	Is_orkh/a/}');
Expect(1, 68680, '\p{isorkh}', "");
Expect(0, 68680, '\p{^isorkh}', "");
Expect(0, 68680, '\P{isorkh}', "");
Expect(1, 68680, '\P{^isorkh}', "");
Expect(0, 68681, '\p{isorkh}', "");
Expect(1, 68681, '\p{^isorkh}', "");
Expect(1, 68681, '\P{isorkh}', "");
Expect(0, 68681, '\P{^isorkh}', "");
Expect(1, 68680, '\p{Is_ORKH}', "");
Expect(0, 68680, '\p{^Is_ORKH}', "");
Expect(0, 68680, '\P{Is_ORKH}', "");
Expect(1, 68680, '\P{^Is_ORKH}', "");
Expect(0, 68681, '\p{Is_ORKH}', "");
Expect(1, 68681, '\p{^Is_ORKH}', "");
Expect(1, 68681, '\P{Is_ORKH}', "");
Expect(0, 68681, '\P{^Is_ORKH}', "");
Error('\p{/a/Open_PUNCTUATION}');
Error('\P{/a/Open_PUNCTUATION}');
Expect(1, 65378, '\p{openpunctuation}', "");
Expect(0, 65378, '\p{^openpunctuation}', "");
Expect(0, 65378, '\P{openpunctuation}', "");
Expect(1, 65378, '\P{^openpunctuation}', "");
Expect(0, 65379, '\p{openpunctuation}', "");
Expect(1, 65379, '\p{^openpunctuation}', "");
Expect(1, 65379, '\P{openpunctuation}', "");
Expect(0, 65379, '\P{^openpunctuation}', "");
Expect(1, 65378, '\p{_	OPEN_punctuation}', "");
Expect(0, 65378, '\p{^_	OPEN_punctuation}', "");
Expect(0, 65378, '\P{_	OPEN_punctuation}', "");
Expect(1, 65378, '\P{^_	OPEN_punctuation}', "");
Expect(0, 65379, '\p{_	OPEN_punctuation}', "");
Expect(1, 65379, '\p{^_	OPEN_punctuation}', "");
Expect(1, 65379, '\P{_	OPEN_punctuation}', "");
Expect(0, 65379, '\P{^_	OPEN_punctuation}', "");
Error('\p{ /a/Is_open_punctuation}');
Error('\P{ /a/Is_open_punctuation}');
Expect(1, 65378, '\p{isopenpunctuation}', "");
Expect(0, 65378, '\p{^isopenpunctuation}', "");
Expect(0, 65378, '\P{isopenpunctuation}', "");
Expect(1, 65378, '\P{^isopenpunctuation}', "");
Expect(0, 65379, '\p{isopenpunctuation}', "");
Expect(1, 65379, '\p{^isopenpunctuation}', "");
Expect(1, 65379, '\P{isopenpunctuation}', "");
Expect(0, 65379, '\P{^isopenpunctuation}', "");
Expect(1, 65378, '\p{ _is_Open_Punctuation}', "");
Expect(0, 65378, '\p{^ _is_Open_Punctuation}', "");
Expect(0, 65378, '\P{ _is_Open_Punctuation}', "");
Expect(1, 65378, '\P{^ _is_Open_Punctuation}', "");
Expect(0, 65379, '\p{ _is_Open_Punctuation}', "");
Expect(1, 65379, '\p{^ _is_Open_Punctuation}', "");
Expect(1, 65379, '\P{ _is_Open_Punctuation}', "");
Expect(0, 65379, '\P{^ _is_Open_Punctuation}', "");
Error('\p{/a/		Ps}');
Error('\P{/a/		Ps}');
Expect(1, 65378, '\p{ps}', "");
Expect(0, 65378, '\p{^ps}', "");
Expect(0, 65378, '\P{ps}', "");
Expect(1, 65378, '\P{^ps}', "");
Expect(0, 65379, '\p{ps}', "");
Expect(1, 65379, '\p{^ps}', "");
Expect(1, 65379, '\P{ps}', "");
Expect(0, 65379, '\P{^ps}', "");
Expect(1, 65378, '\p{_ PS}', "");
Expect(0, 65378, '\p{^_ PS}', "");
Expect(0, 65378, '\P{_ PS}', "");
Expect(1, 65378, '\P{^_ PS}', "");
Expect(0, 65379, '\p{_ PS}', "");
Expect(1, 65379, '\p{^_ PS}', "");
Expect(1, 65379, '\P{_ PS}', "");
Expect(0, 65379, '\P{^_ PS}', "");
Error('\p{- Is_ps/a/}');
Error('\P{- Is_ps/a/}');
Expect(1, 65378, '\p{isps}', "");
Expect(0, 65378, '\p{^isps}', "");
Expect(0, 65378, '\P{isps}', "");
Expect(1, 65378, '\P{^isps}', "");
Expect(0, 65379, '\p{isps}', "");
Expect(1, 65379, '\p{^isps}', "");
Expect(1, 65379, '\P{isps}', "");
Expect(0, 65379, '\P{^isps}', "");
Expect(1, 65378, '\p{__Is_Ps}', "");
Expect(0, 65378, '\p{^__Is_Ps}', "");
Expect(0, 65378, '\P{__Is_Ps}', "");
Expect(1, 65378, '\P{^__Is_Ps}', "");
Expect(0, 65379, '\p{__Is_Ps}', "");
Expect(1, 65379, '\p{^__Is_Ps}', "");
Expect(1, 65379, '\P{__Is_Ps}', "");
Expect(0, 65379, '\P{^__Is_Ps}', "");
Error('\p{ optical_Character_Recognition:=}');
Error('\P{ optical_Character_Recognition:=}');
Expect(1, 9311, '\p{opticalcharacterrecognition}', "");
Expect(0, 9311, '\p{^opticalcharacterrecognition}', "");
Expect(0, 9311, '\P{opticalcharacterrecognition}', "");
Expect(1, 9311, '\P{^opticalcharacterrecognition}', "");
Expect(0, 9312, '\p{opticalcharacterrecognition}', "");
Expect(1, 9312, '\p{^opticalcharacterrecognition}', "");
Expect(1, 9312, '\P{opticalcharacterrecognition}', "");
Expect(0, 9312, '\P{^opticalcharacterrecognition}', "");
Expect(1, 9311, '\p{_ Optical_character_recognition}', "");
Expect(0, 9311, '\p{^_ Optical_character_recognition}', "");
Expect(0, 9311, '\P{_ Optical_character_recognition}', "");
Expect(1, 9311, '\P{^_ Optical_character_recognition}', "");
Expect(0, 9312, '\p{_ Optical_character_recognition}', "");
Expect(1, 9312, '\p{^_ Optical_character_recognition}', "");
Expect(1, 9312, '\P{_ Optical_character_recognition}', "");
Expect(0, 9312, '\P{^_ Optical_character_recognition}', "");
Error('\p{ _Is_optical_Character_Recognition/a/}');
Error('\P{ _Is_optical_Character_Recognition/a/}');
Expect(1, 9311, '\p{isopticalcharacterrecognition}', "");
Expect(0, 9311, '\p{^isopticalcharacterrecognition}', "");
Expect(0, 9311, '\P{isopticalcharacterrecognition}', "");
Expect(1, 9311, '\P{^isopticalcharacterrecognition}', "");
Expect(0, 9312, '\p{isopticalcharacterrecognition}', "");
Expect(1, 9312, '\p{^isopticalcharacterrecognition}', "");
Expect(1, 9312, '\P{isopticalcharacterrecognition}', "");
Expect(0, 9312, '\P{^isopticalcharacterrecognition}', "");
Expect(1, 9311, '\p{ -IS_Optical_CHARACTER_Recognition}', "");
Expect(0, 9311, '\p{^ -IS_Optical_CHARACTER_Recognition}', "");
Expect(0, 9311, '\P{ -IS_Optical_CHARACTER_Recognition}', "");
Expect(1, 9311, '\P{^ -IS_Optical_CHARACTER_Recognition}', "");
Expect(0, 9312, '\p{ -IS_Optical_CHARACTER_Recognition}', "");
Expect(1, 9312, '\p{^ -IS_Optical_CHARACTER_Recognition}', "");
Expect(1, 9312, '\P{ -IS_Optical_CHARACTER_Recognition}', "");
Expect(0, 9312, '\P{^ -IS_Optical_CHARACTER_Recognition}', "");
Error('\p{ IN_OPTICAL_CHARACTER_RECOGNITION/a/}');
Error('\P{ IN_OPTICAL_CHARACTER_RECOGNITION/a/}');
Expect(1, 9311, '\p{inopticalcharacterrecognition}', "");
Expect(0, 9311, '\p{^inopticalcharacterrecognition}', "");
Expect(0, 9311, '\P{inopticalcharacterrecognition}', "");
Expect(1, 9311, '\P{^inopticalcharacterrecognition}', "");
Expect(0, 9312, '\p{inopticalcharacterrecognition}', "");
Expect(1, 9312, '\p{^inopticalcharacterrecognition}', "");
Expect(1, 9312, '\P{inopticalcharacterrecognition}', "");
Expect(0, 9312, '\P{^inopticalcharacterrecognition}', "");
Expect(1, 9311, '\p{__IN_optical_Character_Recognition}', "");
Expect(0, 9311, '\p{^__IN_optical_Character_Recognition}', "");
Expect(0, 9311, '\P{__IN_optical_Character_Recognition}', "");
Expect(1, 9311, '\P{^__IN_optical_Character_Recognition}', "");
Expect(0, 9312, '\p{__IN_optical_Character_Recognition}', "");
Expect(1, 9312, '\p{^__IN_optical_Character_Recognition}', "");
Expect(1, 9312, '\P{__IN_optical_Character_Recognition}', "");
Expect(0, 9312, '\P{^__IN_optical_Character_Recognition}', "");
Error('\p{OCR/a/}');
Error('\P{OCR/a/}');
Expect(1, 9311, '\p{ocr}', "");
Expect(0, 9311, '\p{^ocr}', "");
Expect(0, 9311, '\P{ocr}', "");
Expect(1, 9311, '\P{^ocr}', "");
Expect(0, 9312, '\p{ocr}', "");
Expect(1, 9312, '\p{^ocr}', "");
Expect(1, 9312, '\P{ocr}', "");
Expect(0, 9312, '\P{^ocr}', "");
Expect(1, 9311, '\p{ _OCR}', "");
Expect(0, 9311, '\p{^ _OCR}', "");
Expect(0, 9311, '\P{ _OCR}', "");
Expect(1, 9311, '\P{^ _OCR}', "");
Expect(0, 9312, '\p{ _OCR}', "");
Expect(1, 9312, '\p{^ _OCR}', "");
Expect(1, 9312, '\P{ _OCR}', "");
Expect(0, 9312, '\P{^ _OCR}', "");
Error('\p{	_is_OCR:=}');
Error('\P{	_is_OCR:=}');
Expect(1, 9311, '\p{isocr}', "");
Expect(0, 9311, '\p{^isocr}', "");
Expect(0, 9311, '\P{isocr}', "");
Expect(1, 9311, '\P{^isocr}', "");
Expect(0, 9312, '\p{isocr}', "");
Expect(1, 9312, '\p{^isocr}', "");
Expect(1, 9312, '\P{isocr}', "");
Expect(0, 9312, '\P{^isocr}', "");
Expect(1, 9311, '\p{	-IS_OCR}', "");
Expect(0, 9311, '\p{^	-IS_OCR}', "");
Expect(0, 9311, '\P{	-IS_OCR}', "");
Expect(1, 9311, '\P{^	-IS_OCR}', "");
Expect(0, 9312, '\p{	-IS_OCR}', "");
Expect(1, 9312, '\p{^	-IS_OCR}', "");
Expect(1, 9312, '\P{	-IS_OCR}', "");
Expect(0, 9312, '\P{^	-IS_OCR}', "");
Error('\p{/a/_In_OCR}');
Error('\P{/a/_In_OCR}');
Expect(1, 9311, '\p{inocr}', "");
Expect(0, 9311, '\p{^inocr}', "");
Expect(0, 9311, '\P{inocr}', "");
Expect(1, 9311, '\P{^inocr}', "");
Expect(0, 9312, '\p{inocr}', "");
Expect(1, 9312, '\p{^inocr}', "");
Expect(1, 9312, '\P{inocr}', "");
Expect(0, 9312, '\P{^inocr}', "");
Expect(1, 9311, '\p{ _In_ocr}', "");
Expect(0, 9311, '\p{^ _In_ocr}', "");
Expect(0, 9311, '\P{ _In_ocr}', "");
Expect(1, 9311, '\P{^ _In_ocr}', "");
Expect(0, 9312, '\p{ _In_ocr}', "");
Expect(1, 9312, '\p{^ _In_ocr}', "");
Expect(1, 9312, '\P{ _In_ocr}', "");
Expect(0, 9312, '\P{^ _In_ocr}', "");
Error('\p{/a/-Oriya}');
Error('\P{/a/-Oriya}');
Expect(1, 2935, '\p{oriya}', "");
Expect(0, 2935, '\p{^oriya}', "");
Expect(0, 2935, '\P{oriya}', "");
Expect(1, 2935, '\P{^oriya}', "");
Expect(0, 2936, '\p{oriya}', "");
Expect(1, 2936, '\p{^oriya}', "");
Expect(1, 2936, '\P{oriya}', "");
Expect(0, 2936, '\P{^oriya}', "");
Expect(1, 2935, '\p{_ORIYA}', "");
Expect(0, 2935, '\p{^_ORIYA}', "");
Expect(0, 2935, '\P{_ORIYA}', "");
Expect(1, 2935, '\P{^_ORIYA}', "");
Expect(0, 2936, '\p{_ORIYA}', "");
Expect(1, 2936, '\p{^_ORIYA}', "");
Expect(1, 2936, '\P{_ORIYA}', "");
Expect(0, 2936, '\P{^_ORIYA}', "");
Error('\p{:=_ is_Oriya}');
Error('\P{:=_ is_Oriya}');
Expect(1, 2935, '\p{isoriya}', "");
Expect(0, 2935, '\p{^isoriya}', "");
Expect(0, 2935, '\P{isoriya}', "");
Expect(1, 2935, '\P{^isoriya}', "");
Expect(0, 2936, '\p{isoriya}', "");
Expect(1, 2936, '\p{^isoriya}', "");
Expect(1, 2936, '\P{isoriya}', "");
Expect(0, 2936, '\P{^isoriya}', "");
Expect(1, 2935, '\p{_Is_Oriya}', "");
Expect(0, 2935, '\p{^_Is_Oriya}', "");
Expect(0, 2935, '\P{_Is_Oriya}', "");
Expect(1, 2935, '\P{^_Is_Oriya}', "");
Expect(0, 2936, '\p{_Is_Oriya}', "");
Expect(1, 2936, '\p{^_Is_Oriya}', "");
Expect(1, 2936, '\P{_Is_Oriya}', "");
Expect(0, 2936, '\P{^_Is_Oriya}', "");
Error('\p{ Orya/a/}');
Error('\P{ Orya/a/}');
Expect(1, 2935, '\p{orya}', "");
Expect(0, 2935, '\p{^orya}', "");
Expect(0, 2935, '\P{orya}', "");
Expect(1, 2935, '\P{^orya}', "");
Expect(0, 2936, '\p{orya}', "");
Expect(1, 2936, '\p{^orya}', "");
Expect(1, 2936, '\P{orya}', "");
Expect(0, 2936, '\P{^orya}', "");
Expect(1, 2935, '\p{	ORYA}', "");
Expect(0, 2935, '\p{^	ORYA}', "");
Expect(0, 2935, '\P{	ORYA}', "");
Expect(1, 2935, '\P{^	ORYA}', "");
Expect(0, 2936, '\p{	ORYA}', "");
Expect(1, 2936, '\p{^	ORYA}', "");
Expect(1, 2936, '\P{	ORYA}', "");
Expect(0, 2936, '\P{^	ORYA}', "");
Error('\p{:= Is_ORYA}');
Error('\P{:= Is_ORYA}');
Expect(1, 2935, '\p{isorya}', "");
Expect(0, 2935, '\p{^isorya}', "");
Expect(0, 2935, '\P{isorya}', "");
Expect(1, 2935, '\P{^isorya}', "");
Expect(0, 2936, '\p{isorya}', "");
Expect(1, 2936, '\p{^isorya}', "");
Expect(1, 2936, '\P{isorya}', "");
Expect(0, 2936, '\P{^isorya}', "");
Expect(1, 2935, '\p{-_Is_Orya}', "");
Expect(0, 2935, '\p{^-_Is_Orya}', "");
Expect(0, 2935, '\P{-_Is_Orya}', "");
Expect(1, 2935, '\P{^-_Is_Orya}', "");
Expect(0, 2936, '\p{-_Is_Orya}', "");
Expect(1, 2936, '\p{^-_Is_Orya}', "");
Expect(1, 2936, '\P{-_Is_Orya}', "");
Expect(0, 2936, '\P{^-_Is_Orya}', "");
Error('\p{ -osmanya:=}');
Error('\P{ -osmanya:=}');
Expect(1, 66729, '\p{osmanya}', "");
Expect(0, 66729, '\p{^osmanya}', "");
Expect(0, 66729, '\P{osmanya}', "");
Expect(1, 66729, '\P{^osmanya}', "");
Expect(0, 66730, '\p{osmanya}', "");
Expect(1, 66730, '\p{^osmanya}', "");
Expect(1, 66730, '\P{osmanya}', "");
Expect(0, 66730, '\P{^osmanya}', "");
Expect(1, 66729, '\p{__Osmanya}', "");
Expect(0, 66729, '\p{^__Osmanya}', "");
Expect(0, 66729, '\P{__Osmanya}', "");
Expect(1, 66729, '\P{^__Osmanya}', "");
Expect(0, 66730, '\p{__Osmanya}', "");
Expect(1, 66730, '\p{^__Osmanya}', "");
Expect(1, 66730, '\P{__Osmanya}', "");
Expect(0, 66730, '\P{^__Osmanya}', "");
Error('\p{__Is_OSMANYA:=}');
Error('\P{__Is_OSMANYA:=}');
Expect(1, 66729, '\p{isosmanya}', "");
Expect(0, 66729, '\p{^isosmanya}', "");
Expect(0, 66729, '\P{isosmanya}', "");
Expect(1, 66729, '\P{^isosmanya}', "");
Expect(0, 66730, '\p{isosmanya}', "");
Expect(1, 66730, '\p{^isosmanya}', "");
Expect(1, 66730, '\P{isosmanya}', "");
Expect(0, 66730, '\P{^isosmanya}', "");
Expect(1, 66729, '\p{ _Is_OSMANYA}', "");
Expect(0, 66729, '\p{^ _Is_OSMANYA}', "");
Expect(0, 66729, '\P{ _Is_OSMANYA}', "");
Expect(1, 66729, '\P{^ _Is_OSMANYA}', "");
Expect(0, 66730, '\p{ _Is_OSMANYA}', "");
Expect(1, 66730, '\p{^ _Is_OSMANYA}', "");
Expect(1, 66730, '\P{ _Is_OSMANYA}', "");
Expect(0, 66730, '\P{^ _Is_OSMANYA}', "");
Error('\p{:= 	Osma}');
Error('\P{:= 	Osma}');
Expect(1, 66729, '\p{osma}', "");
Expect(0, 66729, '\p{^osma}', "");
Expect(0, 66729, '\P{osma}', "");
Expect(1, 66729, '\P{^osma}', "");
Expect(0, 66730, '\p{osma}', "");
Expect(1, 66730, '\p{^osma}', "");
Expect(1, 66730, '\P{osma}', "");
Expect(0, 66730, '\P{^osma}', "");
Expect(1, 66729, '\p{-_OSMA}', "");
Expect(0, 66729, '\p{^-_OSMA}', "");
Expect(0, 66729, '\P{-_OSMA}', "");
Expect(1, 66729, '\P{^-_OSMA}', "");
Expect(0, 66730, '\p{-_OSMA}', "");
Expect(1, 66730, '\p{^-_OSMA}', "");
Expect(1, 66730, '\P{-_OSMA}', "");
Expect(0, 66730, '\P{^-_OSMA}', "");
Error('\p{/a/_	Is_Osma}');
Error('\P{/a/_	Is_Osma}');
Expect(1, 66729, '\p{isosma}', "");
Expect(0, 66729, '\p{^isosma}', "");
Expect(0, 66729, '\P{isosma}', "");
Expect(1, 66729, '\P{^isosma}', "");
Expect(0, 66730, '\p{isosma}', "");
Expect(1, 66730, '\p{^isosma}', "");
Expect(1, 66730, '\P{isosma}', "");
Expect(0, 66730, '\P{^isosma}', "");
Expect(1, 66729, '\p{-Is_OSMA}', "");
Expect(0, 66729, '\p{^-Is_OSMA}', "");
Expect(0, 66729, '\P{-Is_OSMA}', "");
Expect(1, 66729, '\P{^-Is_OSMA}', "");
Expect(0, 66730, '\p{-Is_OSMA}', "");
Expect(1, 66730, '\p{^-Is_OSMA}', "");
Expect(1, 66730, '\P{-Is_OSMA}', "");
Expect(0, 66730, '\P{^-Is_OSMA}', "");
Error('\p{/a/- Other}');
Error('\P{/a/- Other}');
Expect(1, 918000, '\p{other}', "");
Expect(0, 918000, '\p{^other}', "");
Expect(0, 918000, '\P{other}', "");
Expect(1, 918000, '\P{^other}', "");
Expect(0, 917999, '\p{other}', "");
Expect(1, 917999, '\p{^other}', "");
Expect(1, 917999, '\P{other}', "");
Expect(0, 917999, '\P{^other}', "");
Expect(1, 918000, '\p{	 Other}', "");
Expect(0, 918000, '\p{^	 Other}', "");
Expect(0, 918000, '\P{	 Other}', "");
Expect(1, 918000, '\P{^	 Other}', "");
Expect(0, 917999, '\p{	 Other}', "");
Expect(1, 917999, '\p{^	 Other}', "");
Expect(1, 917999, '\P{	 Other}', "");
Expect(0, 917999, '\P{^	 Other}', "");
Error('\p{	-is_Other/a/}');
Error('\P{	-is_Other/a/}');
Expect(1, 918000, '\p{isother}', "");
Expect(0, 918000, '\p{^isother}', "");
Expect(0, 918000, '\P{isother}', "");
Expect(1, 918000, '\P{^isother}', "");
Expect(0, 917999, '\p{isother}', "");
Expect(1, 917999, '\p{^isother}', "");
Expect(1, 917999, '\P{isother}', "");
Expect(0, 917999, '\P{^isother}', "");
Expect(1, 918000, '\p{-_Is_other}', "");
Expect(0, 918000, '\p{^-_Is_other}', "");
Expect(0, 918000, '\P{-_Is_other}', "");
Expect(1, 918000, '\P{^-_Is_other}', "");
Expect(0, 917999, '\p{-_Is_other}', "");
Expect(1, 917999, '\p{^-_Is_other}', "");
Expect(1, 917999, '\P{-_Is_other}', "");
Expect(0, 917999, '\P{^-_Is_other}', "");
Error('\p{:=	_C}');
Error('\P{:=	_C}');
Expect(1, 918000, '\p{c}', "");
Expect(0, 918000, '\p{^c}', "");
Expect(0, 918000, '\P{c}', "");
Expect(1, 918000, '\P{^c}', "");
Expect(0, 917999, '\p{c}', "");
Expect(1, 917999, '\p{^c}', "");
Expect(1, 917999, '\P{c}', "");
Expect(0, 917999, '\P{^c}', "");
Expect(1, 918000, '\p{ C}', "");
Expect(0, 918000, '\p{^ C}', "");
Expect(0, 918000, '\P{ C}', "");
Expect(1, 918000, '\P{^ C}', "");
Expect(0, 917999, '\p{ C}', "");
Expect(1, 917999, '\p{^ C}', "");
Expect(1, 917999, '\P{ C}', "");
Expect(0, 917999, '\P{^ C}', "");
Error('\p{:= _IS_c}');
Error('\P{:= _IS_c}');
Expect(1, 918000, '\p{isc}', "");
Expect(0, 918000, '\p{^isc}', "");
Expect(0, 918000, '\P{isc}', "");
Expect(1, 918000, '\P{^isc}', "");
Expect(0, 917999, '\p{isc}', "");
Expect(1, 917999, '\p{^isc}', "");
Expect(1, 917999, '\P{isc}', "");
Expect(0, 917999, '\P{^isc}', "");
Expect(1, 918000, '\p{  Is_C}', "");
Expect(0, 918000, '\p{^  Is_C}', "");
Expect(0, 918000, '\P{  Is_C}', "");
Expect(1, 918000, '\P{^  Is_C}', "");
Expect(0, 917999, '\p{  Is_C}', "");
Expect(1, 917999, '\p{^  Is_C}', "");
Expect(1, 917999, '\P{  Is_C}', "");
Expect(0, 917999, '\P{^  Is_C}', "");
Error('\p{Other_Alphabetic}');
Error('\P{Other_Alphabetic}');
Error('\p{Is_Other_Alphabetic}');
Error('\P{Is_Other_Alphabetic}');
Error('\p{OAlpha}');
Error('\P{OAlpha}');
Error('\p{Is_OAlpha}');
Error('\P{Is_OAlpha}');
Error('\p{Other_Default_Ignorable_Code_Point}');
Error('\P{Other_Default_Ignorable_Code_Point}');
Error('\p{Is_Other_Default_Ignorable_Code_Point}');
Error('\P{Is_Other_Default_Ignorable_Code_Point}');
Error('\p{ODI}');
Error('\P{ODI}');
Error('\p{Is_ODI}');
Error('\P{Is_ODI}');
Error('\p{Other_Grapheme_Extend}');
Error('\P{Other_Grapheme_Extend}');
Error('\p{Is_Other_Grapheme_Extend}');
Error('\P{Is_Other_Grapheme_Extend}');
Error('\p{OGr_Ext}');
Error('\P{OGr_Ext}');
Error('\p{Is_OGr_Ext}');
Error('\P{Is_OGr_Ext}');
Error('\p{Other_ID_Continue}');
Error('\P{Other_ID_Continue}');
Error('\p{Is_Other_ID_Continue}');
Error('\P{Is_Other_ID_Continue}');
Error('\p{OIDC}');
Error('\P{OIDC}');
Error('\p{Is_OIDC}');
Error('\P{Is_OIDC}');
Error('\p{Other_ID_Start}');
Error('\P{Other_ID_Start}');
Error('\p{Is_Other_ID_Start}');
Error('\P{Is_Other_ID_Start}');
Error('\p{OIDS}');
Error('\P{OIDS}');
Error('\p{Is_OIDS}');
Error('\P{Is_OIDS}');
Error('\p{:=-other_Letter}');
Error('\P{:=-other_Letter}');
Expect(1, 195101, '\p{otherletter}', "");
Expect(0, 195101, '\p{^otherletter}', "");
Expect(0, 195101, '\P{otherletter}', "");
Expect(1, 195101, '\P{^otherletter}', "");
Expect(0, 195102, '\p{otherletter}', "");
Expect(1, 195102, '\p{^otherletter}', "");
Expect(1, 195102, '\P{otherletter}', "");
Expect(0, 195102, '\P{^otherletter}', "");
Expect(1, 195101, '\p{		other_Letter}', "");
Expect(0, 195101, '\p{^		other_Letter}', "");
Expect(0, 195101, '\P{		other_Letter}', "");
Expect(1, 195101, '\P{^		other_Letter}', "");
Expect(0, 195102, '\p{		other_Letter}', "");
Expect(1, 195102, '\p{^		other_Letter}', "");
Expect(1, 195102, '\P{		other_Letter}', "");
Expect(0, 195102, '\P{^		other_Letter}', "");
Error('\p{-:=IS_other_Letter}');
Error('\P{-:=IS_other_Letter}');
Expect(1, 195101, '\p{isotherletter}', "");
Expect(0, 195101, '\p{^isotherletter}', "");
Expect(0, 195101, '\P{isotherletter}', "");
Expect(1, 195101, '\P{^isotherletter}', "");
Expect(0, 195102, '\p{isotherletter}', "");
Expect(1, 195102, '\p{^isotherletter}', "");
Expect(1, 195102, '\P{isotherletter}', "");
Expect(0, 195102, '\P{^isotherletter}', "");
Expect(1, 195101, '\p{  Is_Other_LETTER}', "");
Expect(0, 195101, '\p{^  Is_Other_LETTER}', "");
Expect(0, 195101, '\P{  Is_Other_LETTER}', "");
Expect(1, 195101, '\P{^  Is_Other_LETTER}', "");
Expect(0, 195102, '\p{  Is_Other_LETTER}', "");
Expect(1, 195102, '\p{^  Is_Other_LETTER}', "");
Expect(1, 195102, '\P{  Is_Other_LETTER}', "");
Expect(0, 195102, '\P{^  Is_Other_LETTER}', "");
Error('\p{/a/Lo}');
Error('\P{/a/Lo}');
Expect(1, 195101, '\p{lo}', "");
Expect(0, 195101, '\p{^lo}', "");
Expect(0, 195101, '\P{lo}', "");
Expect(1, 195101, '\P{^lo}', "");
Expect(0, 195102, '\p{lo}', "");
Expect(1, 195102, '\p{^lo}', "");
Expect(1, 195102, '\P{lo}', "");
Expect(0, 195102, '\P{^lo}', "");
Expect(1, 195101, '\p{ 	Lo}', "");
Expect(0, 195101, '\p{^ 	Lo}', "");
Expect(0, 195101, '\P{ 	Lo}', "");
Expect(1, 195101, '\P{^ 	Lo}', "");
Expect(0, 195102, '\p{ 	Lo}', "");
Expect(1, 195102, '\p{^ 	Lo}', "");
Expect(1, 195102, '\P{ 	Lo}', "");
Expect(0, 195102, '\P{^ 	Lo}', "");
Error('\p{/a/-	Is_LO}');
Error('\P{/a/-	Is_LO}');
Expect(1, 195101, '\p{islo}', "");
Expect(0, 195101, '\p{^islo}', "");
Expect(0, 195101, '\P{islo}', "");
Expect(1, 195101, '\P{^islo}', "");
Expect(0, 195102, '\p{islo}', "");
Expect(1, 195102, '\p{^islo}', "");
Expect(1, 195102, '\P{islo}', "");
Expect(0, 195102, '\P{^islo}', "");
Expect(1, 195101, '\p{  Is_lo}', "");
Expect(0, 195101, '\p{^  Is_lo}', "");
Expect(0, 195101, '\P{  Is_lo}', "");
Expect(1, 195101, '\P{^  Is_lo}', "");
Expect(0, 195102, '\p{  Is_lo}', "");
Expect(1, 195102, '\p{^  Is_lo}', "");
Expect(1, 195102, '\P{  Is_lo}', "");
Expect(0, 195102, '\P{^  Is_lo}', "");
Error('\p{Other_Lowercase}');
Error('\P{Other_Lowercase}');
Error('\p{Is_Other_Lowercase}');
Error('\P{Is_Other_Lowercase}');
Error('\p{OLower}');
Error('\P{OLower}');
Error('\p{Is_OLower}');
Error('\P{Is_OLower}');
Error('\p{Other_Math}');
Error('\P{Other_Math}');
Error('\p{Is_Other_Math}');
Error('\P{Is_Other_Math}');
Error('\p{OMath}');
Error('\P{OMath}');
Error('\p{Is_OMath}');
Error('\P{Is_OMath}');
Error('\p{-:=Other_number}');
Error('\P{-:=Other_number}');
Expect(1, 127242, '\p{othernumber}', "");
Expect(0, 127242, '\p{^othernumber}', "");
Expect(0, 127242, '\P{othernumber}', "");
Expect(1, 127242, '\P{^othernumber}', "");
Expect(0, 127243, '\p{othernumber}', "");
Expect(1, 127243, '\p{^othernumber}', "");
Expect(1, 127243, '\P{othernumber}', "");
Expect(0, 127243, '\P{^othernumber}', "");
Expect(1, 127242, '\p{_OTHER_Number}', "");
Expect(0, 127242, '\p{^_OTHER_Number}', "");
Expect(0, 127242, '\P{_OTHER_Number}', "");
Expect(1, 127242, '\P{^_OTHER_Number}', "");
Expect(0, 127243, '\p{_OTHER_Number}', "");
Expect(1, 127243, '\p{^_OTHER_Number}', "");
Expect(1, 127243, '\P{_OTHER_Number}', "");
Expect(0, 127243, '\P{^_OTHER_Number}', "");
Error('\p{_	Is_Other_NUMBER/a/}');
Error('\P{_	Is_Other_NUMBER/a/}');
Expect(1, 127242, '\p{isothernumber}', "");
Expect(0, 127242, '\p{^isothernumber}', "");
Expect(0, 127242, '\P{isothernumber}', "");
Expect(1, 127242, '\P{^isothernumber}', "");
Expect(0, 127243, '\p{isothernumber}', "");
Expect(1, 127243, '\p{^isothernumber}', "");
Expect(1, 127243, '\P{isothernumber}', "");
Expect(0, 127243, '\P{^isothernumber}', "");
Expect(1, 127242, '\p{ is_Other_NUMBER}', "");
Expect(0, 127242, '\p{^ is_Other_NUMBER}', "");
Expect(0, 127242, '\P{ is_Other_NUMBER}', "");
Expect(1, 127242, '\P{^ is_Other_NUMBER}', "");
Expect(0, 127243, '\p{ is_Other_NUMBER}', "");
Expect(1, 127243, '\p{^ is_Other_NUMBER}', "");
Expect(1, 127243, '\P{ is_Other_NUMBER}', "");
Expect(0, 127243, '\P{^ is_Other_NUMBER}', "");
Error('\p{:=__No}');
Error('\P{:=__No}');
Expect(1, 127242, '\p{no}', "");
Expect(0, 127242, '\p{^no}', "");
Expect(0, 127242, '\P{no}', "");
Expect(1, 127242, '\P{^no}', "");
Expect(0, 127243, '\p{no}', "");
Expect(1, 127243, '\p{^no}', "");
Expect(1, 127243, '\P{no}', "");
Expect(0, 127243, '\P{^no}', "");
Expect(1, 127242, '\p{  NO}', "");
Expect(0, 127242, '\p{^  NO}', "");
Expect(0, 127242, '\P{  NO}', "");
Expect(1, 127242, '\P{^  NO}', "");
Expect(0, 127243, '\p{  NO}', "");
Expect(1, 127243, '\p{^  NO}', "");
Expect(1, 127243, '\P{  NO}', "");
Expect(0, 127243, '\P{^  NO}', "");
Error('\p{/a/IS_No}');
Error('\P{/a/IS_No}');
Expect(1, 127242, '\p{isno}', "");
Expect(0, 127242, '\p{^isno}', "");
Expect(0, 127242, '\P{isno}', "");
Expect(1, 127242, '\P{^isno}', "");
Expect(0, 127243, '\p{isno}', "");
Expect(1, 127243, '\p{^isno}', "");
Expect(1, 127243, '\P{isno}', "");
Expect(0, 127243, '\P{^isno}', "");
Expect(1, 127242, '\p{	Is_No}', "");
Expect(0, 127242, '\p{^	Is_No}', "");
Expect(0, 127242, '\P{	Is_No}', "");
Expect(1, 127242, '\P{^	Is_No}', "");
Expect(0, 127243, '\p{	Is_No}', "");
Expect(1, 127243, '\p{^	Is_No}', "");
Expect(1, 127243, '\P{	Is_No}', "");
Expect(0, 127243, '\P{^	Is_No}', "");
Error('\p{:=_ other_Punctuation}');
Error('\P{:=_ other_Punctuation}');
Expect(1, 74867, '\p{otherpunctuation}', "");
Expect(0, 74867, '\p{^otherpunctuation}', "");
Expect(0, 74867, '\P{otherpunctuation}', "");
Expect(1, 74867, '\P{^otherpunctuation}', "");
Expect(0, 74868, '\p{otherpunctuation}', "");
Expect(1, 74868, '\p{^otherpunctuation}', "");
Expect(1, 74868, '\P{otherpunctuation}', "");
Expect(0, 74868, '\P{^otherpunctuation}', "");
Expect(1, 74867, '\p{-Other_Punctuation}', "");
Expect(0, 74867, '\p{^-Other_Punctuation}', "");
Expect(0, 74867, '\P{-Other_Punctuation}', "");
Expect(1, 74867, '\P{^-Other_Punctuation}', "");
Expect(0, 74868, '\p{-Other_Punctuation}', "");
Expect(1, 74868, '\p{^-Other_Punctuation}', "");
Expect(1, 74868, '\P{-Other_Punctuation}', "");
Expect(0, 74868, '\P{^-Other_Punctuation}', "");
Error('\p{/a/_-Is_OTHER_PUNCTUATION}');
Error('\P{/a/_-Is_OTHER_PUNCTUATION}');
Expect(1, 74867, '\p{isotherpunctuation}', "");
Expect(0, 74867, '\p{^isotherpunctuation}', "");
Expect(0, 74867, '\P{isotherpunctuation}', "");
Expect(1, 74867, '\P{^isotherpunctuation}', "");
Expect(0, 74868, '\p{isotherpunctuation}', "");
Expect(1, 74868, '\p{^isotherpunctuation}', "");
Expect(1, 74868, '\P{isotherpunctuation}', "");
Expect(0, 74868, '\P{^isotherpunctuation}', "");
Expect(1, 74867, '\p{ IS_Other_punctuation}', "");
Expect(0, 74867, '\p{^ IS_Other_punctuation}', "");
Expect(0, 74867, '\P{ IS_Other_punctuation}', "");
Expect(1, 74867, '\P{^ IS_Other_punctuation}', "");
Expect(0, 74868, '\p{ IS_Other_punctuation}', "");
Expect(1, 74868, '\p{^ IS_Other_punctuation}', "");
Expect(1, 74868, '\P{ IS_Other_punctuation}', "");
Expect(0, 74868, '\P{^ IS_Other_punctuation}', "");
Error('\p{- Po:=}');
Error('\P{- Po:=}');
Expect(1, 74867, '\p{po}', "");
Expect(0, 74867, '\p{^po}', "");
Expect(0, 74867, '\P{po}', "");
Expect(1, 74867, '\P{^po}', "");
Expect(0, 74868, '\p{po}', "");
Expect(1, 74868, '\p{^po}', "");
Expect(1, 74868, '\P{po}', "");
Expect(0, 74868, '\P{^po}', "");
Expect(1, 74867, '\p{--Po}', "");
Expect(0, 74867, '\p{^--Po}', "");
Expect(0, 74867, '\P{--Po}', "");
Expect(1, 74867, '\P{^--Po}', "");
Expect(0, 74868, '\p{--Po}', "");
Expect(1, 74868, '\p{^--Po}', "");
Expect(1, 74868, '\P{--Po}', "");
Expect(0, 74868, '\P{^--Po}', "");
Error('\p{	/a/is_PO}');
Error('\P{	/a/is_PO}');
Expect(1, 74867, '\p{ispo}', "");
Expect(0, 74867, '\p{^ispo}', "");
Expect(0, 74867, '\P{ispo}', "");
Expect(1, 74867, '\P{^ispo}', "");
Expect(0, 74868, '\p{ispo}', "");
Expect(1, 74868, '\p{^ispo}', "");
Expect(1, 74868, '\P{ispo}', "");
Expect(0, 74868, '\P{^ispo}', "");
Expect(1, 74867, '\p{-_Is_Po}', "");
Expect(0, 74867, '\p{^-_Is_Po}', "");
Expect(0, 74867, '\P{-_Is_Po}', "");
Expect(1, 74867, '\P{^-_Is_Po}', "");
Expect(0, 74868, '\p{-_Is_Po}', "");
Expect(1, 74868, '\p{^-_Is_Po}', "");
Expect(1, 74868, '\P{-_Is_Po}', "");
Expect(0, 74868, '\P{^-_Is_Po}', "");
Error('\p{	Other_Symbol:=}');
Error('\P{	Other_Symbol:=}');
Expect(1, 128883, '\p{othersymbol}', "");
Expect(0, 128883, '\p{^othersymbol}', "");
Expect(0, 128883, '\P{othersymbol}', "");
Expect(1, 128883, '\P{^othersymbol}', "");
Expect(0, 128884, '\p{othersymbol}', "");
Expect(1, 128884, '\p{^othersymbol}', "");
Expect(1, 128884, '\P{othersymbol}', "");
Expect(0, 128884, '\P{^othersymbol}', "");
Expect(1, 128883, '\p{--Other_Symbol}', "");
Expect(0, 128883, '\p{^--Other_Symbol}', "");
Expect(0, 128883, '\P{--Other_Symbol}', "");
Expect(1, 128883, '\P{^--Other_Symbol}', "");
Expect(0, 128884, '\p{--Other_Symbol}', "");
Expect(1, 128884, '\p{^--Other_Symbol}', "");
Expect(1, 128884, '\P{--Other_Symbol}', "");
Expect(0, 128884, '\P{^--Other_Symbol}', "");
Error('\p{:=_ is_other_symbol}');
Error('\P{:=_ is_other_symbol}');
Expect(1, 128883, '\p{isothersymbol}', "");
Expect(0, 128883, '\p{^isothersymbol}', "");
Expect(0, 128883, '\P{isothersymbol}', "");
Expect(1, 128883, '\P{^isothersymbol}', "");
Expect(0, 128884, '\p{isothersymbol}', "");
Expect(1, 128884, '\p{^isothersymbol}', "");
Expect(1, 128884, '\P{isothersymbol}', "");
Expect(0, 128884, '\P{^isothersymbol}', "");
Expect(1, 128883, '\p{	Is_Other_symbol}', "");
Expect(0, 128883, '\p{^	Is_Other_symbol}', "");
Expect(0, 128883, '\P{	Is_Other_symbol}', "");
Expect(1, 128883, '\P{^	Is_Other_symbol}', "");
Expect(0, 128884, '\p{	Is_Other_symbol}', "");
Expect(1, 128884, '\p{^	Is_Other_symbol}', "");
Expect(1, 128884, '\P{	Is_Other_symbol}', "");
Expect(0, 128884, '\P{^	Is_Other_symbol}', "");
Error('\p{:= -so}');
Error('\P{:= -so}');
Expect(1, 128883, '\p{so}', "");
Expect(0, 128883, '\p{^so}', "");
Expect(0, 128883, '\P{so}', "");
Expect(1, 128883, '\P{^so}', "");
Expect(0, 128884, '\p{so}', "");
Expect(1, 128884, '\p{^so}', "");
Expect(1, 128884, '\P{so}', "");
Expect(0, 128884, '\P{^so}', "");
Expect(1, 128883, '\p{__So}', "");
Expect(0, 128883, '\p{^__So}', "");
Expect(0, 128883, '\P{__So}', "");
Expect(1, 128883, '\P{^__So}', "");
Expect(0, 128884, '\p{__So}', "");
Expect(1, 128884, '\p{^__So}', "");
Expect(1, 128884, '\P{__So}', "");
Expect(0, 128884, '\P{^__So}', "");
Error('\p{-IS_So/a/}');
Error('\P{-IS_So/a/}');
Expect(1, 128883, '\p{isso}', "");
Expect(0, 128883, '\p{^isso}', "");
Expect(0, 128883, '\P{isso}', "");
Expect(1, 128883, '\P{^isso}', "");
Expect(0, 128884, '\p{isso}', "");
Expect(1, 128884, '\p{^isso}', "");
Expect(1, 128884, '\P{isso}', "");
Expect(0, 128884, '\P{^isso}', "");
Expect(1, 128883, '\p{		is_SO}', "");
Expect(0, 128883, '\p{^		is_SO}', "");
Expect(0, 128883, '\P{		is_SO}', "");
Expect(1, 128883, '\P{^		is_SO}', "");
Expect(0, 128884, '\p{		is_SO}', "");
Expect(1, 128884, '\p{^		is_SO}', "");
Expect(1, 128884, '\P{		is_SO}', "");
Expect(0, 128884, '\P{^		is_SO}', "");
Error('\p{Other_Uppercase}');
Error('\P{Other_Uppercase}');
Error('\p{Is_Other_Uppercase}');
Error('\P{Is_Other_Uppercase}');
Error('\p{OUpper}');
Error('\P{OUpper}');
Error('\p{Is_OUpper}');
Error('\P{Is_OUpper}');
Error('\p{Paragraph_separator:=}');
Error('\P{Paragraph_separator:=}');
Expect(1, 8233, '\p{paragraphseparator}', "");
Expect(0, 8233, '\p{^paragraphseparator}', "");
Expect(0, 8233, '\P{paragraphseparator}', "");
Expect(1, 8233, '\P{^paragraphseparator}', "");
Expect(0, 8234, '\p{paragraphseparator}', "");
Expect(1, 8234, '\p{^paragraphseparator}', "");
Expect(1, 8234, '\P{paragraphseparator}', "");
Expect(0, 8234, '\P{^paragraphseparator}', "");
Expect(1, 8233, '\p{ 	PARAGRAPH_SEPARATOR}', "");
Expect(0, 8233, '\p{^ 	PARAGRAPH_SEPARATOR}', "");
Expect(0, 8233, '\P{ 	PARAGRAPH_SEPARATOR}', "");
Expect(1, 8233, '\P{^ 	PARAGRAPH_SEPARATOR}', "");
Expect(0, 8234, '\p{ 	PARAGRAPH_SEPARATOR}', "");
Expect(1, 8234, '\p{^ 	PARAGRAPH_SEPARATOR}', "");
Expect(1, 8234, '\P{ 	PARAGRAPH_SEPARATOR}', "");
Expect(0, 8234, '\P{^ 	PARAGRAPH_SEPARATOR}', "");
Error('\p{/a/IS_PARAGRAPH_separator}');
Error('\P{/a/IS_PARAGRAPH_separator}');
Expect(1, 8233, '\p{isparagraphseparator}', "");
Expect(0, 8233, '\p{^isparagraphseparator}', "");
Expect(0, 8233, '\P{isparagraphseparator}', "");
Expect(1, 8233, '\P{^isparagraphseparator}', "");
Expect(0, 8234, '\p{isparagraphseparator}', "");
Expect(1, 8234, '\p{^isparagraphseparator}', "");
Expect(1, 8234, '\P{isparagraphseparator}', "");
Expect(0, 8234, '\P{^isparagraphseparator}', "");
Expect(1, 8233, '\p{	Is_paragraph_Separator}', "");
Expect(0, 8233, '\p{^	Is_paragraph_Separator}', "");
Expect(0, 8233, '\P{	Is_paragraph_Separator}', "");
Expect(1, 8233, '\P{^	Is_paragraph_Separator}', "");
Expect(0, 8234, '\p{	Is_paragraph_Separator}', "");
Expect(1, 8234, '\p{^	Is_paragraph_Separator}', "");
Expect(1, 8234, '\P{	Is_paragraph_Separator}', "");
Expect(0, 8234, '\P{^	Is_paragraph_Separator}', "");
Error('\p{:=_-ZP}');
Error('\P{:=_-ZP}');
Expect(1, 8233, '\p{zp}', "");
Expect(0, 8233, '\p{^zp}', "");
Expect(0, 8233, '\P{zp}', "");
Expect(1, 8233, '\P{^zp}', "");
Expect(0, 8234, '\p{zp}', "");
Expect(1, 8234, '\p{^zp}', "");
Expect(1, 8234, '\P{zp}', "");
Expect(0, 8234, '\P{^zp}', "");
Expect(1, 8233, '\p{--ZP}', "");
Expect(0, 8233, '\p{^--ZP}', "");
Expect(0, 8233, '\P{--ZP}', "");
Expect(1, 8233, '\P{^--ZP}', "");
Expect(0, 8234, '\p{--ZP}', "");
Expect(1, 8234, '\p{^--ZP}', "");
Expect(1, 8234, '\P{--ZP}', "");
Expect(0, 8234, '\P{^--ZP}', "");
Error('\p{_is_Zp:=}');
Error('\P{_is_Zp:=}');
Expect(1, 8233, '\p{iszp}', "");
Expect(0, 8233, '\p{^iszp}', "");
Expect(0, 8233, '\P{iszp}', "");
Expect(1, 8233, '\P{^iszp}', "");
Expect(0, 8234, '\p{iszp}', "");
Expect(1, 8234, '\p{^iszp}', "");
Expect(1, 8234, '\P{iszp}', "");
Expect(0, 8234, '\P{^iszp}', "");
Expect(1, 8233, '\p{ _IS_ZP}', "");
Expect(0, 8233, '\p{^ _IS_ZP}', "");
Expect(0, 8233, '\P{ _IS_ZP}', "");
Expect(1, 8233, '\P{^ _IS_ZP}', "");
Expect(0, 8234, '\p{ _IS_ZP}', "");
Expect(1, 8234, '\p{^ _IS_ZP}', "");
Expect(1, 8234, '\P{ _IS_ZP}', "");
Expect(0, 8234, '\P{^ _IS_ZP}', "");
Error('\p{:=Pattern_syntax}');
Error('\P{:=Pattern_syntax}');
Expect(1, 65094, '\p{patternsyntax}', "");
Expect(0, 65094, '\p{^patternsyntax}', "");
Expect(0, 65094, '\P{patternsyntax}', "");
Expect(1, 65094, '\P{^patternsyntax}', "");
Expect(0, 65095, '\p{patternsyntax}', "");
Expect(1, 65095, '\p{^patternsyntax}', "");
Expect(1, 65095, '\P{patternsyntax}', "");
Expect(0, 65095, '\P{^patternsyntax}', "");
Expect(1, 65094, '\p{_-Pattern_SYNTAX}', "");
Expect(0, 65094, '\p{^_-Pattern_SYNTAX}', "");
Expect(0, 65094, '\P{_-Pattern_SYNTAX}', "");
Expect(1, 65094, '\P{^_-Pattern_SYNTAX}', "");
Expect(0, 65095, '\p{_-Pattern_SYNTAX}', "");
Expect(1, 65095, '\p{^_-Pattern_SYNTAX}', "");
Expect(1, 65095, '\P{_-Pattern_SYNTAX}', "");
Expect(0, 65095, '\P{^_-Pattern_SYNTAX}', "");
Error('\p{- IS_pattern_Syntax:=}');
Error('\P{- IS_pattern_Syntax:=}');
Expect(1, 65094, '\p{ispatternsyntax}', "");
Expect(0, 65094, '\p{^ispatternsyntax}', "");
Expect(0, 65094, '\P{ispatternsyntax}', "");
Expect(1, 65094, '\P{^ispatternsyntax}', "");
Expect(0, 65095, '\p{ispatternsyntax}', "");
Expect(1, 65095, '\p{^ispatternsyntax}', "");
Expect(1, 65095, '\P{ispatternsyntax}', "");
Expect(0, 65095, '\P{^ispatternsyntax}', "");
Expect(1, 65094, '\p{ 	Is_Pattern_SYNTAX}', "");
Expect(0, 65094, '\p{^ 	Is_Pattern_SYNTAX}', "");
Expect(0, 65094, '\P{ 	Is_Pattern_SYNTAX}', "");
Expect(1, 65094, '\P{^ 	Is_Pattern_SYNTAX}', "");
Expect(0, 65095, '\p{ 	Is_Pattern_SYNTAX}', "");
Expect(1, 65095, '\p{^ 	Is_Pattern_SYNTAX}', "");
Expect(1, 65095, '\P{ 	Is_Pattern_SYNTAX}', "");
Expect(0, 65095, '\P{^ 	Is_Pattern_SYNTAX}', "");
Error('\p{--pat_Syn/a/}');
Error('\P{--pat_Syn/a/}');
Expect(1, 65094, '\p{patsyn}', "");
Expect(0, 65094, '\p{^patsyn}', "");
Expect(0, 65094, '\P{patsyn}', "");
Expect(1, 65094, '\P{^patsyn}', "");
Expect(0, 65095, '\p{patsyn}', "");
Expect(1, 65095, '\p{^patsyn}', "");
Expect(1, 65095, '\P{patsyn}', "");
Expect(0, 65095, '\P{^patsyn}', "");
Expect(1, 65094, '\p{		Pat_Syn}', "");
Expect(0, 65094, '\p{^		Pat_Syn}', "");
Expect(0, 65094, '\P{		Pat_Syn}', "");
Expect(1, 65094, '\P{^		Pat_Syn}', "");
Expect(0, 65095, '\p{		Pat_Syn}', "");
Expect(1, 65095, '\p{^		Pat_Syn}', "");
Expect(1, 65095, '\P{		Pat_Syn}', "");
Expect(0, 65095, '\P{^		Pat_Syn}', "");
Error('\p{ _IS_Pat_SYN:=}');
Error('\P{ _IS_Pat_SYN:=}');
Expect(1, 65094, '\p{ispatsyn}', "");
Expect(0, 65094, '\p{^ispatsyn}', "");
Expect(0, 65094, '\P{ispatsyn}', "");
Expect(1, 65094, '\P{^ispatsyn}', "");
Expect(0, 65095, '\p{ispatsyn}', "");
Expect(1, 65095, '\p{^ispatsyn}', "");
Expect(1, 65095, '\P{ispatsyn}', "");
Expect(0, 65095, '\P{^ispatsyn}', "");
Expect(1, 65094, '\p{		IS_pat_Syn}', "");
Expect(0, 65094, '\p{^		IS_pat_Syn}', "");
Expect(0, 65094, '\P{		IS_pat_Syn}', "");
Expect(1, 65094, '\P{^		IS_pat_Syn}', "");
Expect(0, 65095, '\p{		IS_pat_Syn}', "");
Expect(1, 65095, '\p{^		IS_pat_Syn}', "");
Expect(1, 65095, '\P{		IS_pat_Syn}', "");
Expect(0, 65095, '\P{^		IS_pat_Syn}', "");
Error('\p{/a/_-pattern_WHITE_Space}');
Error('\P{/a/_-pattern_WHITE_Space}');
Expect(1, 8233, '\p{patternwhitespace}', "");
Expect(0, 8233, '\p{^patternwhitespace}', "");
Expect(0, 8233, '\P{patternwhitespace}', "");
Expect(1, 8233, '\P{^patternwhitespace}', "");
Expect(0, 8234, '\p{patternwhitespace}', "");
Expect(1, 8234, '\p{^patternwhitespace}', "");
Expect(1, 8234, '\P{patternwhitespace}', "");
Expect(0, 8234, '\P{^patternwhitespace}', "");
Expect(1, 8233, '\p{		PATTERN_White_Space}', "");
Expect(0, 8233, '\p{^		PATTERN_White_Space}', "");
Expect(0, 8233, '\P{		PATTERN_White_Space}', "");
Expect(1, 8233, '\P{^		PATTERN_White_Space}', "");
Expect(0, 8234, '\p{		PATTERN_White_Space}', "");
Expect(1, 8234, '\p{^		PATTERN_White_Space}', "");
Expect(1, 8234, '\P{		PATTERN_White_Space}', "");
Expect(0, 8234, '\P{^		PATTERN_White_Space}', "");
Error('\p{	:=Is_Pattern_White_Space}');
Error('\P{	:=Is_Pattern_White_Space}');
Expect(1, 8233, '\p{ispatternwhitespace}', "");
Expect(0, 8233, '\p{^ispatternwhitespace}', "");
Expect(0, 8233, '\P{ispatternwhitespace}', "");
Expect(1, 8233, '\P{^ispatternwhitespace}', "");
Expect(0, 8234, '\p{ispatternwhitespace}', "");
Expect(1, 8234, '\p{^ispatternwhitespace}', "");
Expect(1, 8234, '\P{ispatternwhitespace}', "");
Expect(0, 8234, '\P{^ispatternwhitespace}', "");
Expect(1, 8233, '\p{--IS_pattern_white_Space}', "");
Expect(0, 8233, '\p{^--IS_pattern_white_Space}', "");
Expect(0, 8233, '\P{--IS_pattern_white_Space}', "");
Expect(1, 8233, '\P{^--IS_pattern_white_Space}', "");
Expect(0, 8234, '\p{--IS_pattern_white_Space}', "");
Expect(1, 8234, '\p{^--IS_pattern_white_Space}', "");
Expect(1, 8234, '\P{--IS_pattern_white_Space}', "");
Expect(0, 8234, '\P{^--IS_pattern_white_Space}', "");
Error('\p{/a/	pat_ws}');
Error('\P{/a/	pat_ws}');
Expect(1, 8233, '\p{patws}', "");
Expect(0, 8233, '\p{^patws}', "");
Expect(0, 8233, '\P{patws}', "");
Expect(1, 8233, '\P{^patws}', "");
Expect(0, 8234, '\p{patws}', "");
Expect(1, 8234, '\p{^patws}', "");
Expect(1, 8234, '\P{patws}', "");
Expect(0, 8234, '\P{^patws}', "");
Expect(1, 8233, '\p{	_PAT_ws}', "");
Expect(0, 8233, '\p{^	_PAT_ws}', "");
Expect(0, 8233, '\P{	_PAT_ws}', "");
Expect(1, 8233, '\P{^	_PAT_ws}', "");
Expect(0, 8234, '\p{	_PAT_ws}', "");
Expect(1, 8234, '\p{^	_PAT_ws}', "");
Expect(1, 8234, '\P{	_PAT_ws}', "");
Expect(0, 8234, '\P{^	_PAT_ws}', "");
Error('\p{_/a/is_Pat_ws}');
Error('\P{_/a/is_Pat_ws}');
Expect(1, 8233, '\p{ispatws}', "");
Expect(0, 8233, '\p{^ispatws}', "");
Expect(0, 8233, '\P{ispatws}', "");
Expect(1, 8233, '\P{^ispatws}', "");
Expect(0, 8234, '\p{ispatws}', "");
Expect(1, 8234, '\p{^ispatws}', "");
Expect(1, 8234, '\P{ispatws}', "");
Expect(0, 8234, '\P{^ispatws}', "");
Expect(1, 8233, '\p{-	is_pat_WS}', "");
Expect(0, 8233, '\p{^-	is_pat_WS}', "");
Expect(0, 8233, '\P{-	is_pat_WS}', "");
Expect(1, 8233, '\P{^-	is_pat_WS}', "");
Expect(0, 8234, '\p{-	is_pat_WS}', "");
Expect(1, 8234, '\p{^-	is_pat_WS}', "");
Expect(1, 8234, '\P{-	is_pat_WS}', "");
Expect(0, 8234, '\P{^-	is_pat_WS}', "");
Error('\p{:=_ perlspace}');
Error('\P{:=_ perlspace}');
Expect(1, 32, '\p{perlspace}', "");
Expect(0, 32, '\p{^perlspace}', "");
Expect(0, 32, '\P{perlspace}', "");
Expect(1, 32, '\P{^perlspace}', "");
Expect(0, 33, '\p{perlspace}', "");
Expect(1, 33, '\p{^perlspace}', "");
Expect(1, 33, '\P{perlspace}', "");
Expect(0, 33, '\P{^perlspace}', "");
Expect(1, 32, '\p{-PerlSpace}', "");
Expect(0, 32, '\p{^-PerlSpace}', "");
Expect(0, 32, '\P{-PerlSpace}', "");
Expect(1, 32, '\P{^-PerlSpace}', "");
Expect(0, 33, '\p{-PerlSpace}', "");
Expect(1, 33, '\p{^-PerlSpace}', "");
Expect(1, 33, '\P{-PerlSpace}', "");
Expect(0, 33, '\P{^-PerlSpace}', "");
Error('\p{--Is_PERLSPACE:=}');
Error('\P{--Is_PERLSPACE:=}');
Expect(1, 32, '\p{isperlspace}', "");
Expect(0, 32, '\p{^isperlspace}', "");
Expect(0, 32, '\P{isperlspace}', "");
Expect(1, 32, '\P{^isperlspace}', "");
Expect(0, 33, '\p{isperlspace}', "");
Expect(1, 33, '\p{^isperlspace}', "");
Expect(1, 33, '\P{isperlspace}', "");
Expect(0, 33, '\P{^isperlspace}', "");
Expect(1, 32, '\p{-Is_PERLSPACE}', "");
Expect(0, 32, '\p{^-Is_PERLSPACE}', "");
Expect(0, 32, '\P{-Is_PERLSPACE}', "");
Expect(1, 32, '\P{^-Is_PERLSPACE}', "");
Expect(0, 33, '\p{-Is_PERLSPACE}', "");
Expect(1, 33, '\p{^-Is_PERLSPACE}', "");
Expect(1, 33, '\P{-Is_PERLSPACE}', "");
Expect(0, 33, '\P{^-Is_PERLSPACE}', "");
Error('\p{_/a/PerlWord}');
Error('\P{_/a/PerlWord}');
Expect(1, 122, '\p{perlword}', "");
Expect(0, 122, '\p{^perlword}', "");
Expect(0, 122, '\P{perlword}', "");
Expect(1, 122, '\P{^perlword}', "");
Expect(0, 123, '\p{perlword}', "");
Expect(1, 123, '\p{^perlword}', "");
Expect(1, 123, '\P{perlword}', "");
Expect(0, 123, '\P{^perlword}', "");
Expect(1, 122, '\p{	_PERLWORD}', "");
Expect(0, 122, '\p{^	_PERLWORD}', "");
Expect(0, 122, '\P{	_PERLWORD}', "");
Expect(1, 122, '\P{^	_PERLWORD}', "");
Expect(0, 123, '\p{	_PERLWORD}', "");
Expect(1, 123, '\p{^	_PERLWORD}', "");
Expect(1, 123, '\P{	_PERLWORD}', "");
Expect(0, 123, '\P{^	_PERLWORD}', "");
Error('\p{ 	POSIXWORD:=}');
Error('\P{ 	POSIXWORD:=}');
Expect(1, 122, '\p{posixword}', "");
Expect(0, 122, '\p{^posixword}', "");
Expect(0, 122, '\P{posixword}', "");
Expect(1, 122, '\P{^posixword}', "");
Expect(0, 123, '\p{posixword}', "");
Expect(1, 123, '\p{^posixword}', "");
Expect(1, 123, '\P{posixword}', "");
Expect(0, 123, '\P{^posixword}', "");
Expect(1, 122, '\p{-_POSIXWORD}', "");
Expect(0, 122, '\p{^-_POSIXWORD}', "");
Expect(0, 122, '\P{-_POSIXWORD}', "");
Expect(1, 122, '\P{^-_POSIXWORD}', "");
Expect(0, 123, '\p{-_POSIXWORD}', "");
Expect(1, 123, '\p{^-_POSIXWORD}', "");
Expect(1, 123, '\P{-_POSIXWORD}', "");
Expect(0, 123, '\P{^-_POSIXWORD}', "");
Error('\p{/a/-	IS_PerlWord}');
Error('\P{/a/-	IS_PerlWord}');
Expect(1, 122, '\p{isperlword}', "");
Expect(0, 122, '\p{^isperlword}', "");
Expect(0, 122, '\P{isperlword}', "");
Expect(1, 122, '\P{^isperlword}', "");
Expect(0, 123, '\p{isperlword}', "");
Expect(1, 123, '\p{^isperlword}', "");
Expect(1, 123, '\P{isperlword}', "");
Expect(0, 123, '\P{^isperlword}', "");
Expect(1, 122, '\p{- IS_PerlWord}', "");
Expect(0, 122, '\p{^- IS_PerlWord}', "");
Expect(0, 122, '\P{- IS_PerlWord}', "");
Expect(1, 122, '\P{^- IS_PerlWord}', "");
Expect(0, 123, '\p{- IS_PerlWord}', "");
Expect(1, 123, '\p{^- IS_PerlWord}', "");
Expect(1, 123, '\P{- IS_PerlWord}', "");
Expect(0, 123, '\P{^- IS_PerlWord}', "");
Error('\p{ is_PosixWord/a/}');
Error('\P{ is_PosixWord/a/}');
Expect(1, 122, '\p{isposixword}', "");
Expect(0, 122, '\p{^isposixword}', "");
Expect(0, 122, '\P{isposixword}', "");
Expect(1, 122, '\P{^isposixword}', "");
Expect(0, 123, '\p{isposixword}', "");
Expect(1, 123, '\p{^isposixword}', "");
Expect(1, 123, '\P{isposixword}', "");
Expect(0, 123, '\P{^isposixword}', "");
Expect(1, 122, '\p{	is_posixword}', "");
Expect(0, 122, '\p{^	is_posixword}', "");
Expect(0, 122, '\P{	is_posixword}', "");
Expect(1, 122, '\P{^	is_posixword}', "");
Expect(0, 123, '\p{	is_posixword}', "");
Expect(1, 123, '\p{^	is_posixword}', "");
Expect(1, 123, '\P{	is_posixword}', "");
Expect(0, 123, '\P{^	is_posixword}', "");
Error('\p{	phags_Pa/a/}');
Error('\P{	phags_Pa/a/}');
Expect(1, 43127, '\p{phagspa}', "");
Expect(0, 43127, '\p{^phagspa}', "");
Expect(0, 43127, '\P{phagspa}', "");
Expect(1, 43127, '\P{^phagspa}', "");
Expect(0, 43128, '\p{phagspa}', "");
Expect(1, 43128, '\p{^phagspa}', "");
Expect(1, 43128, '\P{phagspa}', "");
Expect(0, 43128, '\P{^phagspa}', "");
Expect(1, 43127, '\p{	-phags_pa}', "");
Expect(0, 43127, '\p{^	-phags_pa}', "");
Expect(0, 43127, '\P{	-phags_pa}', "");
Expect(1, 43127, '\P{^	-phags_pa}', "");
Expect(0, 43128, '\p{	-phags_pa}', "");
Expect(1, 43128, '\p{^	-phags_pa}', "");
Expect(1, 43128, '\P{	-phags_pa}', "");
Expect(0, 43128, '\P{^	-phags_pa}', "");
Error('\p{:=	 Is_Phags_pa}');
Error('\P{:=	 Is_Phags_pa}');
Expect(1, 43127, '\p{isphagspa}', "");
Expect(0, 43127, '\p{^isphagspa}', "");
Expect(0, 43127, '\P{isphagspa}', "");
Expect(1, 43127, '\P{^isphagspa}', "");
Expect(0, 43128, '\p{isphagspa}', "");
Expect(1, 43128, '\p{^isphagspa}', "");
Expect(1, 43128, '\P{isphagspa}', "");
Expect(0, 43128, '\P{^isphagspa}', "");
Expect(1, 43127, '\p{-IS_phags_pa}', "");
Expect(0, 43127, '\p{^-IS_phags_pa}', "");
Expect(0, 43127, '\P{-IS_phags_pa}', "");
Expect(1, 43127, '\P{^-IS_phags_pa}', "");
Expect(0, 43128, '\p{-IS_phags_pa}', "");
Expect(1, 43128, '\p{^-IS_phags_pa}', "");
Expect(1, 43128, '\P{-IS_phags_pa}', "");
Expect(0, 43128, '\P{^-IS_phags_pa}', "");
Error('\p{/a/__PHAG}');
Error('\P{/a/__PHAG}');
Expect(1, 43127, '\p{phag}', "");
Expect(0, 43127, '\p{^phag}', "");
Expect(0, 43127, '\P{phag}', "");
Expect(1, 43127, '\P{^phag}', "");
Expect(0, 43128, '\p{phag}', "");
Expect(1, 43128, '\p{^phag}', "");
Expect(1, 43128, '\P{phag}', "");
Expect(0, 43128, '\P{^phag}', "");
Expect(1, 43127, '\p{	Phag}', "");
Expect(0, 43127, '\p{^	Phag}', "");
Expect(0, 43127, '\P{	Phag}', "");
Expect(1, 43127, '\P{^	Phag}', "");
Expect(0, 43128, '\p{	Phag}', "");
Expect(1, 43128, '\p{^	Phag}', "");
Expect(1, 43128, '\P{	Phag}', "");
Expect(0, 43128, '\P{^	Phag}', "");
Error('\p{_:=is_PHAG}');
Error('\P{_:=is_PHAG}');
Expect(1, 43127, '\p{isphag}', "");
Expect(0, 43127, '\p{^isphag}', "");
Expect(0, 43127, '\P{isphag}', "");
Expect(1, 43127, '\P{^isphag}', "");
Expect(0, 43128, '\p{isphag}', "");
Expect(1, 43128, '\p{^isphag}', "");
Expect(1, 43128, '\P{isphag}', "");
Expect(0, 43128, '\P{^isphag}', "");
Expect(1, 43127, '\p{ 	Is_phag}', "");
Expect(0, 43127, '\p{^ 	Is_phag}', "");
Expect(0, 43127, '\P{ 	Is_phag}', "");
Expect(1, 43127, '\P{^ 	Is_phag}', "");
Expect(0, 43128, '\p{ 	Is_phag}', "");
Expect(1, 43128, '\p{^ 	Is_phag}', "");
Expect(1, 43128, '\P{ 	Is_phag}', "");
Expect(0, 43128, '\P{^ 	Is_phag}', "");
Error('\p{__Phaistos_DISC/a/}');
Error('\P{__Phaistos_DISC/a/}');
Expect(1, 66047, '\p{phaistosdisc}', "");
Expect(0, 66047, '\p{^phaistosdisc}', "");
Expect(0, 66047, '\P{phaistosdisc}', "");
Expect(1, 66047, '\P{^phaistosdisc}', "");
Expect(0, 66048, '\p{phaistosdisc}', "");
Expect(1, 66048, '\p{^phaistosdisc}', "");
Expect(1, 66048, '\P{phaistosdisc}', "");
Expect(0, 66048, '\P{^phaistosdisc}', "");
Expect(1, 66047, '\p{ 	Phaistos_DISC}', "");
Expect(0, 66047, '\p{^ 	Phaistos_DISC}', "");
Expect(0, 66047, '\P{ 	Phaistos_DISC}', "");
Expect(1, 66047, '\P{^ 	Phaistos_DISC}', "");
Expect(0, 66048, '\p{ 	Phaistos_DISC}', "");
Expect(1, 66048, '\p{^ 	Phaistos_DISC}', "");
Expect(1, 66048, '\P{ 	Phaistos_DISC}', "");
Expect(0, 66048, '\P{^ 	Phaistos_DISC}', "");
Error('\p{__Is_Phaistos_Disc:=}');
Error('\P{__Is_Phaistos_Disc:=}');
Expect(1, 66047, '\p{isphaistosdisc}', "");
Expect(0, 66047, '\p{^isphaistosdisc}', "");
Expect(0, 66047, '\P{isphaistosdisc}', "");
Expect(1, 66047, '\P{^isphaistosdisc}', "");
Expect(0, 66048, '\p{isphaistosdisc}', "");
Expect(1, 66048, '\p{^isphaistosdisc}', "");
Expect(1, 66048, '\P{isphaistosdisc}', "");
Expect(0, 66048, '\P{^isphaistosdisc}', "");
Expect(1, 66047, '\p{-Is_phaistos_Disc}', "");
Expect(0, 66047, '\p{^-Is_phaistos_Disc}', "");
Expect(0, 66047, '\P{-Is_phaistos_Disc}', "");
Expect(1, 66047, '\P{^-Is_phaistos_Disc}', "");
Expect(0, 66048, '\p{-Is_phaistos_Disc}', "");
Expect(1, 66048, '\p{^-Is_phaistos_Disc}', "");
Expect(1, 66048, '\P{-Is_phaistos_Disc}', "");
Expect(0, 66048, '\P{^-Is_phaistos_Disc}', "");
Error('\p{/a/- In_phaistos_Disc}');
Error('\P{/a/- In_phaistos_Disc}');
Expect(1, 66047, '\p{inphaistosdisc}', "");
Expect(0, 66047, '\p{^inphaistosdisc}', "");
Expect(0, 66047, '\P{inphaistosdisc}', "");
Expect(1, 66047, '\P{^inphaistosdisc}', "");
Expect(0, 66048, '\p{inphaistosdisc}', "");
Expect(1, 66048, '\p{^inphaistosdisc}', "");
Expect(1, 66048, '\P{inphaistosdisc}', "");
Expect(0, 66048, '\P{^inphaistosdisc}', "");
Expect(1, 66047, '\p{_IN_phaistos_DISC}', "");
Expect(0, 66047, '\p{^_IN_phaistos_DISC}', "");
Expect(0, 66047, '\P{_IN_phaistos_DISC}', "");
Expect(1, 66047, '\P{^_IN_phaistos_DISC}', "");
Expect(0, 66048, '\p{_IN_phaistos_DISC}', "");
Expect(1, 66048, '\p{^_IN_phaistos_DISC}', "");
Expect(1, 66048, '\P{_IN_phaistos_DISC}', "");
Expect(0, 66048, '\P{^_IN_phaistos_DISC}', "");
Error('\p{_PHAISTOS/a/}');
Error('\P{_PHAISTOS/a/}');
Expect(1, 66047, '\p{phaistos}', "");
Expect(0, 66047, '\p{^phaistos}', "");
Expect(0, 66047, '\P{phaistos}', "");
Expect(1, 66047, '\P{^phaistos}', "");
Expect(0, 66048, '\p{phaistos}', "");
Expect(1, 66048, '\p{^phaistos}', "");
Expect(1, 66048, '\P{phaistos}', "");
Expect(0, 66048, '\P{^phaistos}', "");
Expect(1, 66047, '\p{  phaistos}', "");
Expect(0, 66047, '\p{^  phaistos}', "");
Expect(0, 66047, '\P{  phaistos}', "");
Expect(1, 66047, '\P{^  phaistos}', "");
Expect(0, 66048, '\p{  phaistos}', "");
Expect(1, 66048, '\p{^  phaistos}', "");
Expect(1, 66048, '\P{  phaistos}', "");
Expect(0, 66048, '\P{^  phaistos}', "");
Error('\p{/a/_ Is_Phaistos}');
Error('\P{/a/_ Is_Phaistos}');
Expect(1, 66047, '\p{isphaistos}', "");
Expect(0, 66047, '\p{^isphaistos}', "");
Expect(0, 66047, '\P{isphaistos}', "");
Expect(1, 66047, '\P{^isphaistos}', "");
Expect(0, 66048, '\p{isphaistos}', "");
Expect(1, 66048, '\p{^isphaistos}', "");
Expect(1, 66048, '\P{isphaistos}', "");
Expect(0, 66048, '\P{^isphaistos}', "");
Expect(1, 66047, '\p{_-Is_phaistos}', "");
Expect(0, 66047, '\p{^_-Is_phaistos}', "");
Expect(0, 66047, '\P{_-Is_phaistos}', "");
Expect(1, 66047, '\P{^_-Is_phaistos}', "");
Expect(0, 66048, '\p{_-Is_phaistos}', "");
Expect(1, 66048, '\p{^_-Is_phaistos}', "");
Expect(1, 66048, '\P{_-Is_phaistos}', "");
Expect(0, 66048, '\P{^_-Is_phaistos}', "");
Error('\p{	/a/In_PHAISTOS}');
Error('\P{	/a/In_PHAISTOS}');
Expect(1, 66047, '\p{inphaistos}', "");
Expect(0, 66047, '\p{^inphaistos}', "");
Expect(0, 66047, '\P{inphaistos}', "");
Expect(1, 66047, '\P{^inphaistos}', "");
Expect(0, 66048, '\p{inphaistos}', "");
Expect(1, 66048, '\p{^inphaistos}', "");
Expect(1, 66048, '\P{inphaistos}', "");
Expect(0, 66048, '\P{^inphaistos}', "");
Expect(1, 66047, '\p{ -In_PHAISTOS}', "");
Expect(0, 66047, '\p{^ -In_PHAISTOS}', "");
Expect(0, 66047, '\P{ -In_PHAISTOS}', "");
Expect(1, 66047, '\P{^ -In_PHAISTOS}', "");
Expect(0, 66048, '\p{ -In_PHAISTOS}', "");
Expect(1, 66048, '\p{^ -In_PHAISTOS}', "");
Expect(1, 66048, '\P{ -In_PHAISTOS}', "");
Expect(0, 66048, '\P{^ -In_PHAISTOS}', "");
Error('\p{ /a/PHOENICIAN}');
Error('\P{ /a/PHOENICIAN}');
Expect(1, 67871, '\p{phoenician}', "");
Expect(0, 67871, '\p{^phoenician}', "");
Expect(0, 67871, '\P{phoenician}', "");
Expect(1, 67871, '\P{^phoenician}', "");
Expect(0, 67872, '\p{phoenician}', "");
Expect(1, 67872, '\p{^phoenician}', "");
Expect(1, 67872, '\P{phoenician}', "");
Expect(0, 67872, '\P{^phoenician}', "");
Expect(1, 67871, '\p{_-Phoenician}', "");
Expect(0, 67871, '\p{^_-Phoenician}', "");
Expect(0, 67871, '\P{_-Phoenician}', "");
Expect(1, 67871, '\P{^_-Phoenician}', "");
Expect(0, 67872, '\p{_-Phoenician}', "");
Expect(1, 67872, '\p{^_-Phoenician}', "");
Expect(1, 67872, '\P{_-Phoenician}', "");
Expect(0, 67872, '\P{^_-Phoenician}', "");
Error('\p{/a/-Is_phoenician}');
Error('\P{/a/-Is_phoenician}');
Expect(1, 67871, '\p{isphoenician}', "");
Expect(0, 67871, '\p{^isphoenician}', "");
Expect(0, 67871, '\P{isphoenician}', "");
Expect(1, 67871, '\P{^isphoenician}', "");
Expect(0, 67872, '\p{isphoenician}', "");
Expect(1, 67872, '\p{^isphoenician}', "");
Expect(1, 67872, '\P{isphoenician}', "");
Expect(0, 67872, '\P{^isphoenician}', "");
Expect(1, 67871, '\p{_Is_Phoenician}', "");
Expect(0, 67871, '\p{^_Is_Phoenician}', "");
Expect(0, 67871, '\P{_Is_Phoenician}', "");
Expect(1, 67871, '\P{^_Is_Phoenician}', "");
Expect(0, 67872, '\p{_Is_Phoenician}', "");
Expect(1, 67872, '\p{^_Is_Phoenician}', "");
Expect(1, 67872, '\P{_Is_Phoenician}', "");
Expect(0, 67872, '\P{^_Is_Phoenician}', "");
Error('\p{ 	PHNX:=}');
Error('\P{ 	PHNX:=}');
Expect(1, 67871, '\p{phnx}', "");
Expect(0, 67871, '\p{^phnx}', "");
Expect(0, 67871, '\P{phnx}', "");
Expect(1, 67871, '\P{^phnx}', "");
Expect(0, 67872, '\p{phnx}', "");
Expect(1, 67872, '\p{^phnx}', "");
Expect(1, 67872, '\P{phnx}', "");
Expect(0, 67872, '\P{^phnx}', "");
Expect(1, 67871, '\p{	Phnx}', "");
Expect(0, 67871, '\p{^	Phnx}', "");
Expect(0, 67871, '\P{	Phnx}', "");
Expect(1, 67871, '\P{^	Phnx}', "");
Expect(0, 67872, '\p{	Phnx}', "");
Expect(1, 67872, '\p{^	Phnx}', "");
Expect(1, 67872, '\P{	Phnx}', "");
Expect(0, 67872, '\P{^	Phnx}', "");
Error('\p{_	Is_phnx:=}');
Error('\P{_	Is_phnx:=}');
Expect(1, 67871, '\p{isphnx}', "");
Expect(0, 67871, '\p{^isphnx}', "");
Expect(0, 67871, '\P{isphnx}', "");
Expect(1, 67871, '\P{^isphnx}', "");
Expect(0, 67872, '\p{isphnx}', "");
Expect(1, 67872, '\p{^isphnx}', "");
Expect(1, 67872, '\P{isphnx}', "");
Expect(0, 67872, '\P{^isphnx}', "");
Expect(1, 67871, '\p{ 	Is_PHNX}', "");
Expect(0, 67871, '\p{^ 	Is_PHNX}', "");
Expect(0, 67871, '\P{ 	Is_PHNX}', "");
Expect(1, 67871, '\P{^ 	Is_PHNX}', "");
Expect(0, 67872, '\p{ 	Is_PHNX}', "");
Expect(1, 67872, '\p{^ 	Is_PHNX}', "");
Expect(1, 67872, '\P{ 	Is_PHNX}', "");
Expect(0, 67872, '\P{^ 	Is_PHNX}', "");
Error('\p{	/a/phonetic_extensions}');
Error('\P{	/a/phonetic_extensions}');
Expect(1, 7551, '\p{phoneticextensions}', "");
Expect(0, 7551, '\p{^phoneticextensions}', "");
Expect(0, 7551, '\P{phoneticextensions}', "");
Expect(1, 7551, '\P{^phoneticextensions}', "");
Expect(0, 7552, '\p{phoneticextensions}', "");
Expect(1, 7552, '\p{^phoneticextensions}', "");
Expect(1, 7552, '\P{phoneticextensions}', "");
Expect(0, 7552, '\P{^phoneticextensions}', "");
Expect(1, 7551, '\p{	_PHONETIC_EXTENSIONS}', "");
Expect(0, 7551, '\p{^	_PHONETIC_EXTENSIONS}', "");
Expect(0, 7551, '\P{	_PHONETIC_EXTENSIONS}', "");
Expect(1, 7551, '\P{^	_PHONETIC_EXTENSIONS}', "");
Expect(0, 7552, '\p{	_PHONETIC_EXTENSIONS}', "");
Expect(1, 7552, '\p{^	_PHONETIC_EXTENSIONS}', "");
Expect(1, 7552, '\P{	_PHONETIC_EXTENSIONS}', "");
Expect(0, 7552, '\P{^	_PHONETIC_EXTENSIONS}', "");
Error('\p{-:=IS_Phonetic_EXTENSIONS}');
Error('\P{-:=IS_Phonetic_EXTENSIONS}');
Expect(1, 7551, '\p{isphoneticextensions}', "");
Expect(0, 7551, '\p{^isphoneticextensions}', "");
Expect(0, 7551, '\P{isphoneticextensions}', "");
Expect(1, 7551, '\P{^isphoneticextensions}', "");
Expect(0, 7552, '\p{isphoneticextensions}', "");
Expect(1, 7552, '\p{^isphoneticextensions}', "");
Expect(1, 7552, '\P{isphoneticextensions}', "");
Expect(0, 7552, '\P{^isphoneticextensions}', "");
Expect(1, 7551, '\p{_	is_phonetic_extensions}', "");
Expect(0, 7551, '\p{^_	is_phonetic_extensions}', "");
Expect(0, 7551, '\P{_	is_phonetic_extensions}', "");
Expect(1, 7551, '\P{^_	is_phonetic_extensions}', "");
Expect(0, 7552, '\p{_	is_phonetic_extensions}', "");
Expect(1, 7552, '\p{^_	is_phonetic_extensions}', "");
Expect(1, 7552, '\P{_	is_phonetic_extensions}', "");
Expect(0, 7552, '\P{^_	is_phonetic_extensions}', "");
Error('\p{/a/--in_Phonetic_EXTENSIONS}');
Error('\P{/a/--in_Phonetic_EXTENSIONS}');
Expect(1, 7551, '\p{inphoneticextensions}', "");
Expect(0, 7551, '\p{^inphoneticextensions}', "");
Expect(0, 7551, '\P{inphoneticextensions}', "");
Expect(1, 7551, '\P{^inphoneticextensions}', "");
Expect(0, 7552, '\p{inphoneticextensions}', "");
Expect(1, 7552, '\p{^inphoneticextensions}', "");
Expect(1, 7552, '\P{inphoneticextensions}', "");
Expect(0, 7552, '\P{^inphoneticextensions}', "");
Expect(1, 7551, '\p{	_IN_PHONETIC_Extensions}', "");
Expect(0, 7551, '\p{^	_IN_PHONETIC_Extensions}', "");
Expect(0, 7551, '\P{	_IN_PHONETIC_Extensions}', "");
Expect(1, 7551, '\P{^	_IN_PHONETIC_Extensions}', "");
Expect(0, 7552, '\p{	_IN_PHONETIC_Extensions}', "");
Expect(1, 7552, '\p{^	_IN_PHONETIC_Extensions}', "");
Expect(1, 7552, '\P{	_IN_PHONETIC_Extensions}', "");
Expect(0, 7552, '\P{^	_IN_PHONETIC_Extensions}', "");
Error('\p{:=Phonetic_EXT}');
Error('\P{:=Phonetic_EXT}');
Expect(1, 7551, '\p{phoneticext}', "");
Expect(0, 7551, '\p{^phoneticext}', "");
Expect(0, 7551, '\P{phoneticext}', "");
Expect(1, 7551, '\P{^phoneticext}', "");
Expect(0, 7552, '\p{phoneticext}', "");
Expect(1, 7552, '\p{^phoneticext}', "");
Expect(1, 7552, '\P{phoneticext}', "");
Expect(0, 7552, '\P{^phoneticext}', "");
Expect(1, 7551, '\p{_phonetic_Ext}', "");
Expect(0, 7551, '\p{^_phonetic_Ext}', "");
Expect(0, 7551, '\P{_phonetic_Ext}', "");
Expect(1, 7551, '\P{^_phonetic_Ext}', "");
Expect(0, 7552, '\p{_phonetic_Ext}', "");
Expect(1, 7552, '\p{^_phonetic_Ext}', "");
Expect(1, 7552, '\P{_phonetic_Ext}', "");
Expect(0, 7552, '\P{^_phonetic_Ext}', "");
Error('\p{ 	is_phonetic_Ext/a/}');
Error('\P{ 	is_phonetic_Ext/a/}');
Expect(1, 7551, '\p{isphoneticext}', "");
Expect(0, 7551, '\p{^isphoneticext}', "");
Expect(0, 7551, '\P{isphoneticext}', "");
Expect(1, 7551, '\P{^isphoneticext}', "");
Expect(0, 7552, '\p{isphoneticext}', "");
Expect(1, 7552, '\p{^isphoneticext}', "");
Expect(1, 7552, '\P{isphoneticext}', "");
Expect(0, 7552, '\P{^isphoneticext}', "");
Expect(1, 7551, '\p{__Is_Phonetic_EXT}', "");
Expect(0, 7551, '\p{^__Is_Phonetic_EXT}', "");
Expect(0, 7551, '\P{__Is_Phonetic_EXT}', "");
Expect(1, 7551, '\P{^__Is_Phonetic_EXT}', "");
Expect(0, 7552, '\p{__Is_Phonetic_EXT}', "");
Expect(1, 7552, '\p{^__Is_Phonetic_EXT}', "");
Expect(1, 7552, '\P{__Is_Phonetic_EXT}', "");
Expect(0, 7552, '\P{^__Is_Phonetic_EXT}', "");
Error('\p{:=	-In_Phonetic_EXT}');
Error('\P{:=	-In_Phonetic_EXT}');
Expect(1, 7551, '\p{inphoneticext}', "");
Expect(0, 7551, '\p{^inphoneticext}', "");
Expect(0, 7551, '\P{inphoneticext}', "");
Expect(1, 7551, '\P{^inphoneticext}', "");
Expect(0, 7552, '\p{inphoneticext}', "");
Expect(1, 7552, '\p{^inphoneticext}', "");
Expect(1, 7552, '\P{inphoneticext}', "");
Expect(0, 7552, '\P{^inphoneticext}', "");
Expect(1, 7551, '\p{  in_PHONETIC_Ext}', "");
Expect(0, 7551, '\p{^  in_PHONETIC_Ext}', "");
Expect(0, 7551, '\P{  in_PHONETIC_Ext}', "");
Expect(1, 7551, '\P{^  in_PHONETIC_Ext}', "");
Expect(0, 7552, '\p{  in_PHONETIC_Ext}', "");
Expect(1, 7552, '\p{^  in_PHONETIC_Ext}', "");
Expect(1, 7552, '\P{  in_PHONETIC_Ext}', "");
Expect(0, 7552, '\P{^  in_PHONETIC_Ext}', "");
Error('\p{ _Phonetic_Extensions_supplement:=}');
Error('\P{ _Phonetic_Extensions_supplement:=}');
Expect(1, 7615, '\p{phoneticextensionssupplement}', "");
Expect(0, 7615, '\p{^phoneticextensionssupplement}', "");
Expect(0, 7615, '\P{phoneticextensionssupplement}', "");
Expect(1, 7615, '\P{^phoneticextensionssupplement}', "");
Expect(0, 7616, '\p{phoneticextensionssupplement}', "");
Expect(1, 7616, '\p{^phoneticextensionssupplement}', "");
Expect(1, 7616, '\P{phoneticextensionssupplement}', "");
Expect(0, 7616, '\P{^phoneticextensionssupplement}', "");
Expect(1, 7615, '\p{ 	Phonetic_extensions_Supplement}', "");
Expect(0, 7615, '\p{^ 	Phonetic_extensions_Supplement}', "");
Expect(0, 7615, '\P{ 	Phonetic_extensions_Supplement}', "");
Expect(1, 7615, '\P{^ 	Phonetic_extensions_Supplement}', "");
Expect(0, 7616, '\p{ 	Phonetic_extensions_Supplement}', "");
Expect(1, 7616, '\p{^ 	Phonetic_extensions_Supplement}', "");
Expect(1, 7616, '\P{ 	Phonetic_extensions_Supplement}', "");
Expect(0, 7616, '\P{^ 	Phonetic_extensions_Supplement}', "");
Error('\p{:=- is_Phonetic_Extensions_SUPPLEMENT}');
Error('\P{:=- is_Phonetic_Extensions_SUPPLEMENT}');
Expect(1, 7615, '\p{isphoneticextensionssupplement}', "");
Expect(0, 7615, '\p{^isphoneticextensionssupplement}', "");
Expect(0, 7615, '\P{isphoneticextensionssupplement}', "");
Expect(1, 7615, '\P{^isphoneticextensionssupplement}', "");
Expect(0, 7616, '\p{isphoneticextensionssupplement}', "");
Expect(1, 7616, '\p{^isphoneticextensionssupplement}', "");
Expect(1, 7616, '\P{isphoneticextensionssupplement}', "");
Expect(0, 7616, '\P{^isphoneticextensionssupplement}', "");
Expect(1, 7615, '\p{	Is_Phonetic_extensions_Supplement}', "");
Expect(0, 7615, '\p{^	Is_Phonetic_extensions_Supplement}', "");
Expect(0, 7615, '\P{	Is_Phonetic_extensions_Supplement}', "");
Expect(1, 7615, '\P{^	Is_Phonetic_extensions_Supplement}', "");
Expect(0, 7616, '\p{	Is_Phonetic_extensions_Supplement}', "");
Expect(1, 7616, '\p{^	Is_Phonetic_extensions_Supplement}', "");
Expect(1, 7616, '\P{	Is_Phonetic_extensions_Supplement}', "");
Expect(0, 7616, '\P{^	Is_Phonetic_extensions_Supplement}', "");
Error('\p{ 	IN_PHONETIC_Extensions_Supplement/a/}');
Error('\P{ 	IN_PHONETIC_Extensions_Supplement/a/}');
Expect(1, 7615, '\p{inphoneticextensionssupplement}', "");
Expect(0, 7615, '\p{^inphoneticextensionssupplement}', "");
Expect(0, 7615, '\P{inphoneticextensionssupplement}', "");
Expect(1, 7615, '\P{^inphoneticextensionssupplement}', "");
Expect(0, 7616, '\p{inphoneticextensionssupplement}', "");
Expect(1, 7616, '\p{^inphoneticextensionssupplement}', "");
Expect(1, 7616, '\P{inphoneticextensionssupplement}', "");
Expect(0, 7616, '\P{^inphoneticextensionssupplement}', "");
Expect(1, 7615, '\p{ in_PHONETIC_EXTENSIONS_supplement}', "");
Expect(0, 7615, '\p{^ in_PHONETIC_EXTENSIONS_supplement}', "");
Expect(0, 7615, '\P{ in_PHONETIC_EXTENSIONS_supplement}', "");
Expect(1, 7615, '\P{^ in_PHONETIC_EXTENSIONS_supplement}', "");
Expect(0, 7616, '\p{ in_PHONETIC_EXTENSIONS_supplement}', "");
Expect(1, 7616, '\p{^ in_PHONETIC_EXTENSIONS_supplement}', "");
Expect(1, 7616, '\P{ in_PHONETIC_EXTENSIONS_supplement}', "");
Expect(0, 7616, '\P{^ in_PHONETIC_EXTENSIONS_supplement}', "");
Error('\p{ PHONETIC_ext_SUP:=}');
Error('\P{ PHONETIC_ext_SUP:=}');
Expect(1, 7615, '\p{phoneticextsup}', "");
Expect(0, 7615, '\p{^phoneticextsup}', "");
Expect(0, 7615, '\P{phoneticextsup}', "");
Expect(1, 7615, '\P{^phoneticextsup}', "");
Expect(0, 7616, '\p{phoneticextsup}', "");
Expect(1, 7616, '\p{^phoneticextsup}', "");
Expect(1, 7616, '\P{phoneticextsup}', "");
Expect(0, 7616, '\P{^phoneticextsup}', "");
Expect(1, 7615, '\p{- PHONETIC_EXT_Sup}', "");
Expect(0, 7615, '\p{^- PHONETIC_EXT_Sup}', "");
Expect(0, 7615, '\P{- PHONETIC_EXT_Sup}', "");
Expect(1, 7615, '\P{^- PHONETIC_EXT_Sup}', "");
Expect(0, 7616, '\p{- PHONETIC_EXT_Sup}', "");
Expect(1, 7616, '\p{^- PHONETIC_EXT_Sup}', "");
Expect(1, 7616, '\P{- PHONETIC_EXT_Sup}', "");
Expect(0, 7616, '\P{^- PHONETIC_EXT_Sup}', "");
Error('\p{-/a/Is_Phonetic_ext_SUP}');
Error('\P{-/a/Is_Phonetic_ext_SUP}');
Expect(1, 7615, '\p{isphoneticextsup}', "");
Expect(0, 7615, '\p{^isphoneticextsup}', "");
Expect(0, 7615, '\P{isphoneticextsup}', "");
Expect(1, 7615, '\P{^isphoneticextsup}', "");
Expect(0, 7616, '\p{isphoneticextsup}', "");
Expect(1, 7616, '\p{^isphoneticextsup}', "");
Expect(1, 7616, '\P{isphoneticextsup}', "");
Expect(0, 7616, '\P{^isphoneticextsup}', "");
Expect(1, 7615, '\p{ 	is_Phonetic_ext_Sup}', "");
Expect(0, 7615, '\p{^ 	is_Phonetic_ext_Sup}', "");
Expect(0, 7615, '\P{ 	is_Phonetic_ext_Sup}', "");
Expect(1, 7615, '\P{^ 	is_Phonetic_ext_Sup}', "");
Expect(0, 7616, '\p{ 	is_Phonetic_ext_Sup}', "");
Expect(1, 7616, '\p{^ 	is_Phonetic_ext_Sup}', "");
Expect(1, 7616, '\P{ 	is_Phonetic_ext_Sup}', "");
Expect(0, 7616, '\P{^ 	is_Phonetic_ext_Sup}', "");
Error('\p{	In_phonetic_Ext_SUP:=}');
Error('\P{	In_phonetic_Ext_SUP:=}');
Expect(1, 7615, '\p{inphoneticextsup}', "");
Expect(0, 7615, '\p{^inphoneticextsup}', "");
Expect(0, 7615, '\P{inphoneticextsup}', "");
Expect(1, 7615, '\P{^inphoneticextsup}', "");
Expect(0, 7616, '\p{inphoneticextsup}', "");
Expect(1, 7616, '\p{^inphoneticextsup}', "");
Expect(1, 7616, '\P{inphoneticextsup}', "");
Expect(0, 7616, '\P{^inphoneticextsup}', "");
Expect(1, 7615, '\p{ -IN_Phonetic_Ext_Sup}', "");
Expect(0, 7615, '\p{^ -IN_Phonetic_Ext_Sup}', "");
Expect(0, 7615, '\P{ -IN_Phonetic_Ext_Sup}', "");
Expect(1, 7615, '\P{^ -IN_Phonetic_Ext_Sup}', "");
Expect(0, 7616, '\p{ -IN_Phonetic_Ext_Sup}', "");
Expect(1, 7616, '\p{^ -IN_Phonetic_Ext_Sup}', "");
Expect(1, 7616, '\P{ -IN_Phonetic_Ext_Sup}', "");
Expect(0, 7616, '\P{^ -IN_Phonetic_Ext_Sup}', "");
Error('\p{:= -Playing_Cards}');
Error('\P{:= -Playing_Cards}');
Expect(1, 127231, '\p{playingcards}', "");
Expect(0, 127231, '\p{^playingcards}', "");
Expect(0, 127231, '\P{playingcards}', "");
Expect(1, 127231, '\P{^playingcards}', "");
Expect(0, 127232, '\p{playingcards}', "");
Expect(1, 127232, '\p{^playingcards}', "");
Expect(1, 127232, '\P{playingcards}', "");
Expect(0, 127232, '\P{^playingcards}', "");
Expect(1, 127231, '\p{  Playing_Cards}', "");
Expect(0, 127231, '\p{^  Playing_Cards}', "");
Expect(0, 127231, '\P{  Playing_Cards}', "");
Expect(1, 127231, '\P{^  Playing_Cards}', "");
Expect(0, 127232, '\p{  Playing_Cards}', "");
Expect(1, 127232, '\p{^  Playing_Cards}', "");
Expect(1, 127232, '\P{  Playing_Cards}', "");
Expect(0, 127232, '\P{^  Playing_Cards}', "");
Error('\p{:= Is_PLAYING_Cards}');
Error('\P{:= Is_PLAYING_Cards}');
Expect(1, 127231, '\p{isplayingcards}', "");
Expect(0, 127231, '\p{^isplayingcards}', "");
Expect(0, 127231, '\P{isplayingcards}', "");
Expect(1, 127231, '\P{^isplayingcards}', "");
Expect(0, 127232, '\p{isplayingcards}', "");
Expect(1, 127232, '\p{^isplayingcards}', "");
Expect(1, 127232, '\P{isplayingcards}', "");
Expect(0, 127232, '\P{^isplayingcards}', "");
Expect(1, 127231, '\p{  Is_Playing_Cards}', "");
Expect(0, 127231, '\p{^  Is_Playing_Cards}', "");
Expect(0, 127231, '\P{  Is_Playing_Cards}', "");
Expect(1, 127231, '\P{^  Is_Playing_Cards}', "");
Expect(0, 127232, '\p{  Is_Playing_Cards}', "");
Expect(1, 127232, '\p{^  Is_Playing_Cards}', "");
Expect(1, 127232, '\P{  Is_Playing_Cards}', "");
Expect(0, 127232, '\P{^  Is_Playing_Cards}', "");
Error('\p{ /a/In_PLAYING_CARDS}');
Error('\P{ /a/In_PLAYING_CARDS}');
Expect(1, 127231, '\p{inplayingcards}', "");
Expect(0, 127231, '\p{^inplayingcards}', "");
Expect(0, 127231, '\P{inplayingcards}', "");
Expect(1, 127231, '\P{^inplayingcards}', "");
Expect(0, 127232, '\p{inplayingcards}', "");
Expect(1, 127232, '\p{^inplayingcards}', "");
Expect(1, 127232, '\P{inplayingcards}', "");
Expect(0, 127232, '\P{^inplayingcards}', "");
Expect(1, 127231, '\p{--In_playing_cards}', "");
Expect(0, 127231, '\p{^--In_playing_cards}', "");
Expect(0, 127231, '\P{--In_playing_cards}', "");
Expect(1, 127231, '\P{^--In_playing_cards}', "");
Expect(0, 127232, '\p{--In_playing_cards}', "");
Expect(1, 127232, '\p{^--In_playing_cards}', "");
Expect(1, 127232, '\P{--In_playing_cards}', "");
Expect(0, 127232, '\P{^--In_playing_cards}', "");
Error('\p{_:=posixalnum}');
Error('\P{_:=posixalnum}');
Expect(1, 122, '\p{posixalnum}', "");
Expect(0, 122, '\p{^posixalnum}', "");
Expect(0, 122, '\P{posixalnum}', "");
Expect(1, 122, '\P{^posixalnum}', "");
Expect(0, 123, '\p{posixalnum}', "");
Expect(1, 123, '\p{^posixalnum}', "");
Expect(1, 123, '\P{posixalnum}', "");
Expect(0, 123, '\P{^posixalnum}', "");
Expect(1, 122, '\p{_ PosixAlnum}', "");
Expect(0, 122, '\p{^_ PosixAlnum}', "");
Expect(0, 122, '\P{_ PosixAlnum}', "");
Expect(1, 122, '\P{^_ PosixAlnum}', "");
Expect(0, 123, '\p{_ PosixAlnum}', "");
Expect(1, 123, '\p{^_ PosixAlnum}', "");
Expect(1, 123, '\P{_ PosixAlnum}', "");
Expect(0, 123, '\P{^_ PosixAlnum}', "");
Error('\p{:=is_posixalnum}');
Error('\P{:=is_posixalnum}');
Expect(1, 122, '\p{isposixalnum}', "");
Expect(0, 122, '\p{^isposixalnum}', "");
Expect(0, 122, '\P{isposixalnum}', "");
Expect(1, 122, '\P{^isposixalnum}', "");
Expect(0, 123, '\p{isposixalnum}', "");
Expect(1, 123, '\p{^isposixalnum}', "");
Expect(1, 123, '\P{isposixalnum}', "");
Expect(0, 123, '\P{^isposixalnum}', "");
Expect(1, 122, '\p{_	Is_PosixAlnum}', "");
Expect(0, 122, '\p{^_	Is_PosixAlnum}', "");
Expect(0, 122, '\P{_	Is_PosixAlnum}', "");
Expect(1, 122, '\P{^_	Is_PosixAlnum}', "");
Expect(0, 123, '\p{_	Is_PosixAlnum}', "");
Expect(1, 123, '\p{^_	Is_PosixAlnum}', "");
Expect(1, 123, '\P{_	Is_PosixAlnum}', "");
Expect(0, 123, '\P{^_	Is_PosixAlnum}', "");
Error('\p{-:=posixalpha}');
Error('\P{-:=posixalpha}');
Expect(1, 122, '\p{posixalpha}', "");
Expect(0, 122, '\p{^posixalpha}', "");
Expect(0, 122, '\P{posixalpha}', "");
Expect(1, 122, '\P{^posixalpha}', "");
Expect(0, 123, '\p{posixalpha}', "");
Expect(1, 123, '\p{^posixalpha}', "");
Expect(1, 123, '\P{posixalpha}', "");
Expect(0, 123, '\P{^posixalpha}', "");
Expect(1, 122, '\p{	PosixAlpha}', "");
Expect(0, 122, '\p{^	PosixAlpha}', "");
Expect(0, 122, '\P{	PosixAlpha}', "");
Expect(1, 122, '\P{^	PosixAlpha}', "");
Expect(0, 123, '\p{	PosixAlpha}', "");
Expect(1, 123, '\p{^	PosixAlpha}', "");
Expect(1, 123, '\P{	PosixAlpha}', "");
Expect(0, 123, '\P{^	PosixAlpha}', "");
Error('\p{/a/Is_POSIXALPHA}');
Error('\P{/a/Is_POSIXALPHA}');
Expect(1, 122, '\p{isposixalpha}', "");
Expect(0, 122, '\p{^isposixalpha}', "");
Expect(0, 122, '\P{isposixalpha}', "");
Expect(1, 122, '\P{^isposixalpha}', "");
Expect(0, 123, '\p{isposixalpha}', "");
Expect(1, 123, '\p{^isposixalpha}', "");
Expect(1, 123, '\P{isposixalpha}', "");
Expect(0, 123, '\P{^isposixalpha}', "");
Expect(1, 122, '\p{ IS_posixalpha}', "");
Expect(0, 122, '\p{^ IS_posixalpha}', "");
Expect(0, 122, '\P{ IS_posixalpha}', "");
Expect(1, 122, '\P{^ IS_posixalpha}', "");
Expect(0, 123, '\p{ IS_posixalpha}', "");
Expect(1, 123, '\p{^ IS_posixalpha}', "");
Expect(1, 123, '\P{ IS_posixalpha}', "");
Expect(0, 123, '\P{^ IS_posixalpha}', "");
Error('\p{ :=POSIXBLANK}');
Error('\P{ :=POSIXBLANK}');
Expect(1, 32, '\p{posixblank}', "");
Expect(0, 32, '\p{^posixblank}', "");
Expect(0, 32, '\P{posixblank}', "");
Expect(1, 32, '\P{^posixblank}', "");
Expect(0, 33, '\p{posixblank}', "");
Expect(1, 33, '\p{^posixblank}', "");
Expect(1, 33, '\P{posixblank}', "");
Expect(0, 33, '\P{^posixblank}', "");
Expect(1, 32, '\p{_-PosixBlank}', "");
Expect(0, 32, '\p{^_-PosixBlank}', "");
Expect(0, 32, '\P{_-PosixBlank}', "");
Expect(1, 32, '\P{^_-PosixBlank}', "");
Expect(0, 33, '\p{_-PosixBlank}', "");
Expect(1, 33, '\p{^_-PosixBlank}', "");
Expect(1, 33, '\P{_-PosixBlank}', "");
Expect(0, 33, '\P{^_-PosixBlank}', "");
Error('\p{_:=Is_posixblank}');
Error('\P{_:=Is_posixblank}');
Expect(1, 32, '\p{isposixblank}', "");
Expect(0, 32, '\p{^isposixblank}', "");
Expect(0, 32, '\P{isposixblank}', "");
Expect(1, 32, '\P{^isposixblank}', "");
Expect(0, 33, '\p{isposixblank}', "");
Expect(1, 33, '\p{^isposixblank}', "");
Expect(1, 33, '\P{isposixblank}', "");
Expect(0, 33, '\P{^isposixblank}', "");
Expect(1, 32, '\p{_Is_posixblank}', "");
Expect(0, 32, '\p{^_Is_posixblank}', "");
Expect(0, 32, '\P{_Is_posixblank}', "");
Expect(1, 32, '\P{^_Is_posixblank}', "");
Expect(0, 33, '\p{_Is_posixblank}', "");
Expect(1, 33, '\p{^_Is_posixblank}', "");
Expect(1, 33, '\P{_Is_posixblank}', "");
Expect(0, 33, '\P{^_Is_posixblank}', "");
Error('\p{_ POSIXCNTRL/a/}');
Error('\P{_ POSIXCNTRL/a/}');
Expect(1, 127, '\p{posixcntrl}', "");
Expect(0, 127, '\p{^posixcntrl}', "");
Expect(0, 127, '\P{posixcntrl}', "");
Expect(1, 127, '\P{^posixcntrl}', "");
Expect(0, 128, '\p{posixcntrl}', "");
Expect(1, 128, '\p{^posixcntrl}', "");
Expect(1, 128, '\P{posixcntrl}', "");
Expect(0, 128, '\P{^posixcntrl}', "");
Expect(1, 127, '\p{  posixcntrl}', "");
Expect(0, 127, '\p{^  posixcntrl}', "");
Expect(0, 127, '\P{  posixcntrl}', "");
Expect(1, 127, '\P{^  posixcntrl}', "");
Expect(0, 128, '\p{  posixcntrl}', "");
Expect(1, 128, '\p{^  posixcntrl}', "");
Expect(1, 128, '\P{  posixcntrl}', "");
Expect(0, 128, '\P{^  posixcntrl}', "");
Error('\p{/a/-Is_PosixCntrl}');
Error('\P{/a/-Is_PosixCntrl}');
Expect(1, 127, '\p{isposixcntrl}', "");
Expect(0, 127, '\p{^isposixcntrl}', "");
Expect(0, 127, '\P{isposixcntrl}', "");
Expect(1, 127, '\P{^isposixcntrl}', "");
Expect(0, 128, '\p{isposixcntrl}', "");
Expect(1, 128, '\p{^isposixcntrl}', "");
Expect(1, 128, '\P{isposixcntrl}', "");
Expect(0, 128, '\P{^isposixcntrl}', "");
Expect(1, 127, '\p{ _IS_PosixCntrl}', "");
Expect(0, 127, '\p{^ _IS_PosixCntrl}', "");
Expect(0, 127, '\P{ _IS_PosixCntrl}', "");
Expect(1, 127, '\P{^ _IS_PosixCntrl}', "");
Expect(0, 128, '\p{ _IS_PosixCntrl}', "");
Expect(1, 128, '\p{^ _IS_PosixCntrl}', "");
Expect(1, 128, '\P{ _IS_PosixCntrl}', "");
Expect(0, 128, '\P{^ _IS_PosixCntrl}', "");
Error('\p{ 	posixdigit/a/}');
Error('\P{ 	posixdigit/a/}');
Expect(1, 57, '\p{posixdigit}', "");
Expect(0, 57, '\p{^posixdigit}', "");
Expect(0, 57, '\P{posixdigit}', "");
Expect(1, 57, '\P{^posixdigit}', "");
Expect(0, 58, '\p{posixdigit}', "");
Expect(1, 58, '\p{^posixdigit}', "");
Expect(1, 58, '\P{posixdigit}', "");
Expect(0, 58, '\P{^posixdigit}', "");
Expect(1, 57, '\p{	PosixDigit}', "");
Expect(0, 57, '\p{^	PosixDigit}', "");
Expect(0, 57, '\P{	PosixDigit}', "");
Expect(1, 57, '\P{^	PosixDigit}', "");
Expect(0, 58, '\p{	PosixDigit}', "");
Expect(1, 58, '\p{^	PosixDigit}', "");
Expect(1, 58, '\P{	PosixDigit}', "");
Expect(0, 58, '\P{^	PosixDigit}', "");
Error('\p{:=_IS_POSIXDIGIT}');
Error('\P{:=_IS_POSIXDIGIT}');
Expect(1, 57, '\p{isposixdigit}', "");
Expect(0, 57, '\p{^isposixdigit}', "");
Expect(0, 57, '\P{isposixdigit}', "");
Expect(1, 57, '\P{^isposixdigit}', "");
Expect(0, 58, '\p{isposixdigit}', "");
Expect(1, 58, '\p{^isposixdigit}', "");
Expect(1, 58, '\P{isposixdigit}', "");
Expect(0, 58, '\P{^isposixdigit}', "");
Expect(1, 57, '\p{	_is_PosixDigit}', "");
Expect(0, 57, '\p{^	_is_PosixDigit}', "");
Expect(0, 57, '\P{	_is_PosixDigit}', "");
Expect(1, 57, '\P{^	_is_PosixDigit}', "");
Expect(0, 58, '\p{	_is_PosixDigit}', "");
Expect(1, 58, '\p{^	_is_PosixDigit}', "");
Expect(1, 58, '\P{	_is_PosixDigit}', "");
Expect(0, 58, '\P{^	_is_PosixDigit}', "");
Error('\p{-	POSIXGRAPH/a/}');
Error('\P{-	POSIXGRAPH/a/}');
Expect(1, 126, '\p{posixgraph}', "");
Expect(0, 126, '\p{^posixgraph}', "");
Expect(0, 126, '\P{posixgraph}', "");
Expect(1, 126, '\P{^posixgraph}', "");
Expect(0, 127, '\p{posixgraph}', "");
Expect(1, 127, '\p{^posixgraph}', "");
Expect(1, 127, '\P{posixgraph}', "");
Expect(0, 127, '\P{^posixgraph}', "");
Expect(1, 126, '\p{__posixgraph}', "");
Expect(0, 126, '\p{^__posixgraph}', "");
Expect(0, 126, '\P{__posixgraph}', "");
Expect(1, 126, '\P{^__posixgraph}', "");
Expect(0, 127, '\p{__posixgraph}', "");
Expect(1, 127, '\p{^__posixgraph}', "");
Expect(1, 127, '\P{__posixgraph}', "");
Expect(0, 127, '\P{^__posixgraph}', "");
Error('\p{:=Is_posixgraph}');
Error('\P{:=Is_posixgraph}');
Expect(1, 126, '\p{isposixgraph}', "");
Expect(0, 126, '\p{^isposixgraph}', "");
Expect(0, 126, '\P{isposixgraph}', "");
Expect(1, 126, '\P{^isposixgraph}', "");
Expect(0, 127, '\p{isposixgraph}', "");
Expect(1, 127, '\p{^isposixgraph}', "");
Expect(1, 127, '\P{isposixgraph}', "");
Expect(0, 127, '\P{^isposixgraph}', "");
Expect(1, 126, '\p{	 IS_posixgraph}', "");
Expect(0, 126, '\p{^	 IS_posixgraph}', "");
Expect(0, 126, '\P{	 IS_posixgraph}', "");
Expect(1, 126, '\P{^	 IS_posixgraph}', "");
Expect(0, 127, '\p{	 IS_posixgraph}', "");
Expect(1, 127, '\p{^	 IS_posixgraph}', "");
Expect(1, 127, '\P{	 IS_posixgraph}', "");
Expect(0, 127, '\P{^	 IS_posixgraph}', "");
Error('\p{ /a/POSIXLOWER}');
Error('\P{ /a/POSIXLOWER}');
Expect(1, 122, '\p{posixlower}', "");
Expect(0, 122, '\p{^posixlower}', "");
Expect(0, 122, '\P{posixlower}', "");
Expect(1, 122, '\P{^posixlower}', "");
Expect(0, 123, '\p{posixlower}', "");
Expect(1, 123, '\p{^posixlower}', "");
Expect(1, 123, '\P{posixlower}', "");
Expect(0, 123, '\P{^posixlower}', "");
Expect(1, 122, '\p{- POSIXLOWER}', "");
Expect(0, 122, '\p{^- POSIXLOWER}', "");
Expect(0, 122, '\P{- POSIXLOWER}', "");
Expect(1, 122, '\P{^- POSIXLOWER}', "");
Expect(0, 123, '\p{- POSIXLOWER}', "");
Expect(1, 123, '\p{^- POSIXLOWER}', "");
Expect(1, 123, '\P{- POSIXLOWER}', "");
Expect(0, 123, '\P{^- POSIXLOWER}', "");
Error('\p{ IS_PosixLower/a/}');
Error('\P{ IS_PosixLower/a/}');
Expect(1, 122, '\p{isposixlower}', "");
Expect(0, 122, '\p{^isposixlower}', "");
Expect(0, 122, '\P{isposixlower}', "");
Expect(1, 122, '\P{^isposixlower}', "");
Expect(0, 123, '\p{isposixlower}', "");
Expect(1, 123, '\p{^isposixlower}', "");
Expect(1, 123, '\P{isposixlower}', "");
Expect(0, 123, '\P{^isposixlower}', "");
Expect(1, 122, '\p{	-IS_PosixLower}', "");
Expect(0, 122, '\p{^	-IS_PosixLower}', "");
Expect(0, 122, '\P{	-IS_PosixLower}', "");
Expect(1, 122, '\P{^	-IS_PosixLower}', "");
Expect(0, 123, '\p{	-IS_PosixLower}', "");
Expect(1, 123, '\p{^	-IS_PosixLower}', "");
Expect(1, 123, '\P{	-IS_PosixLower}', "");
Expect(0, 123, '\P{^	-IS_PosixLower}', "");
Error('\p{_/a/PosixPrint}');
Error('\P{_/a/PosixPrint}');
Expect(1, 126, '\p{posixprint}', "");
Expect(0, 126, '\p{^posixprint}', "");
Expect(0, 126, '\P{posixprint}', "");
Expect(1, 126, '\P{^posixprint}', "");
Expect(0, 127, '\p{posixprint}', "");
Expect(1, 127, '\p{^posixprint}', "");
Expect(1, 127, '\P{posixprint}', "");
Expect(0, 127, '\P{^posixprint}', "");
Expect(1, 126, '\p{_PosixPrint}', "");
Expect(0, 126, '\p{^_PosixPrint}', "");
Expect(0, 126, '\P{_PosixPrint}', "");
Expect(1, 126, '\P{^_PosixPrint}', "");
Expect(0, 127, '\p{_PosixPrint}', "");
Expect(1, 127, '\p{^_PosixPrint}', "");
Expect(1, 127, '\P{_PosixPrint}', "");
Expect(0, 127, '\P{^_PosixPrint}', "");
Error('\p{/a/Is_PosixPrint}');
Error('\P{/a/Is_PosixPrint}');
Expect(1, 126, '\p{isposixprint}', "");
Expect(0, 126, '\p{^isposixprint}', "");
Expect(0, 126, '\P{isposixprint}', "");
Expect(1, 126, '\P{^isposixprint}', "");
Expect(0, 127, '\p{isposixprint}', "");
Expect(1, 127, '\p{^isposixprint}', "");
Expect(1, 127, '\P{isposixprint}', "");
Expect(0, 127, '\P{^isposixprint}', "");
Expect(1, 126, '\p{	-Is_posixprint}', "");
Expect(0, 126, '\p{^	-Is_posixprint}', "");
Expect(0, 126, '\P{	-Is_posixprint}', "");
Expect(1, 126, '\P{^	-Is_posixprint}', "");
Expect(0, 127, '\p{	-Is_posixprint}', "");
Expect(1, 127, '\p{^	-Is_posixprint}', "");
Expect(1, 127, '\P{	-Is_posixprint}', "");
Expect(0, 127, '\P{^	-Is_posixprint}', "");
Error('\p{ /a/PosixPunct}');
Error('\P{ /a/PosixPunct}');
Expect(1, 126, '\p{posixpunct}', "");
Expect(0, 126, '\p{^posixpunct}', "");
Expect(0, 126, '\P{posixpunct}', "");
Expect(1, 126, '\P{^posixpunct}', "");
Expect(0, 127, '\p{posixpunct}', "");
Expect(1, 127, '\p{^posixpunct}', "");
Expect(1, 127, '\P{posixpunct}', "");
Expect(0, 127, '\P{^posixpunct}', "");
Expect(1, 126, '\p{_posixpunct}', "");
Expect(0, 126, '\p{^_posixpunct}', "");
Expect(0, 126, '\P{_posixpunct}', "");
Expect(1, 126, '\P{^_posixpunct}', "");
Expect(0, 127, '\p{_posixpunct}', "");
Expect(1, 127, '\p{^_posixpunct}', "");
Expect(1, 127, '\P{_posixpunct}', "");
Expect(0, 127, '\P{^_posixpunct}', "");
Error('\p{-Is_POSIXPUNCT:=}');
Error('\P{-Is_POSIXPUNCT:=}');
Expect(1, 126, '\p{isposixpunct}', "");
Expect(0, 126, '\p{^isposixpunct}', "");
Expect(0, 126, '\P{isposixpunct}', "");
Expect(1, 126, '\P{^isposixpunct}', "");
Expect(0, 127, '\p{isposixpunct}', "");
Expect(1, 127, '\p{^isposixpunct}', "");
Expect(1, 127, '\P{isposixpunct}', "");
Expect(0, 127, '\P{^isposixpunct}', "");
Expect(1, 126, '\p{_is_posixpunct}', "");
Expect(0, 126, '\p{^_is_posixpunct}', "");
Expect(0, 126, '\P{_is_posixpunct}', "");
Expect(1, 126, '\P{^_is_posixpunct}', "");
Expect(0, 127, '\p{_is_posixpunct}', "");
Expect(1, 127, '\p{^_is_posixpunct}', "");
Expect(1, 127, '\P{_is_posixpunct}', "");
Expect(0, 127, '\P{^_is_posixpunct}', "");
Error('\p{	POSIXSPACE:=}');
Error('\P{	POSIXSPACE:=}');
Expect(1, 32, '\p{posixspace}', "");
Expect(0, 32, '\p{^posixspace}', "");
Expect(0, 32, '\P{posixspace}', "");
Expect(1, 32, '\P{^posixspace}', "");
Expect(0, 33, '\p{posixspace}', "");
Expect(1, 33, '\p{^posixspace}', "");
Expect(1, 33, '\P{posixspace}', "");
Expect(0, 33, '\P{^posixspace}', "");
Expect(1, 32, '\p{ PosixSpace}', "");
Expect(0, 32, '\p{^ PosixSpace}', "");
Expect(0, 32, '\P{ PosixSpace}', "");
Expect(1, 32, '\P{^ PosixSpace}', "");
Expect(0, 33, '\p{ PosixSpace}', "");
Expect(1, 33, '\p{^ PosixSpace}', "");
Expect(1, 33, '\P{ PosixSpace}', "");
Expect(0, 33, '\P{^ PosixSpace}', "");
Error('\p{	/a/Is_PosixSpace}');
Error('\P{	/a/Is_PosixSpace}');
Expect(1, 32, '\p{isposixspace}', "");
Expect(0, 32, '\p{^isposixspace}', "");
Expect(0, 32, '\P{isposixspace}', "");
Expect(1, 32, '\P{^isposixspace}', "");
Expect(0, 33, '\p{isposixspace}', "");
Expect(1, 33, '\p{^isposixspace}', "");
Expect(1, 33, '\P{isposixspace}', "");
Expect(0, 33, '\P{^isposixspace}', "");
Expect(1, 32, '\p{ Is_POSIXSPACE}', "");
Expect(0, 32, '\p{^ Is_POSIXSPACE}', "");
Expect(0, 32, '\P{ Is_POSIXSPACE}', "");
Expect(1, 32, '\P{^ Is_POSIXSPACE}', "");
Expect(0, 33, '\p{ Is_POSIXSPACE}', "");
Expect(1, 33, '\p{^ Is_POSIXSPACE}', "");
Expect(1, 33, '\P{ Is_POSIXSPACE}', "");
Expect(0, 33, '\P{^ Is_POSIXSPACE}', "");
Error('\p{/a/	posixupper}');
Error('\P{/a/	posixupper}');
Expect(1, 90, '\p{posixupper}', "");
Expect(0, 90, '\p{^posixupper}', "");
Expect(0, 90, '\P{posixupper}', "");
Expect(1, 90, '\P{^posixupper}', "");
Expect(0, 91, '\p{posixupper}', "");
Expect(1, 91, '\p{^posixupper}', "");
Expect(1, 91, '\P{posixupper}', "");
Expect(0, 91, '\P{^posixupper}', "");
Expect(1, 90, '\p{PosixUpper}', "");
Expect(0, 90, '\p{^PosixUpper}', "");
Expect(0, 90, '\P{PosixUpper}', "");
Expect(1, 90, '\P{^PosixUpper}', "");
Expect(0, 91, '\p{PosixUpper}', "");
Expect(1, 91, '\p{^PosixUpper}', "");
Expect(1, 91, '\P{PosixUpper}', "");
Expect(0, 91, '\P{^PosixUpper}', "");
Error('\p{/a/IS_PosixUpper}');
Error('\P{/a/IS_PosixUpper}');
Expect(1, 90, '\p{isposixupper}', "");
Expect(0, 90, '\p{^isposixupper}', "");
Expect(0, 90, '\P{isposixupper}', "");
Expect(1, 90, '\P{^isposixupper}', "");
Expect(0, 91, '\p{isposixupper}', "");
Expect(1, 91, '\p{^isposixupper}', "");
Expect(1, 91, '\P{isposixupper}', "");
Expect(0, 91, '\P{^isposixupper}', "");
Expect(1, 90, '\p{-_Is_POSIXUPPER}', "");
Expect(0, 90, '\p{^-_Is_POSIXUPPER}', "");
Expect(0, 90, '\P{-_Is_POSIXUPPER}', "");
Expect(1, 90, '\P{^-_Is_POSIXUPPER}', "");
Expect(0, 91, '\p{-_Is_POSIXUPPER}', "");
Expect(1, 91, '\p{^-_Is_POSIXUPPER}', "");
Expect(1, 91, '\P{-_Is_POSIXUPPER}', "");
Expect(0, 91, '\P{^-_Is_POSIXUPPER}', "");
Error('\p{	PosixXDigit/a/}');
Error('\P{	PosixXDigit/a/}');
Expect(1, 102, '\p{posixxdigit}', "");
Expect(0, 102, '\p{^posixxdigit}', "");
Expect(0, 102, '\P{posixxdigit}', "");
Expect(1, 102, '\P{^posixxdigit}', "");
Expect(0, 103, '\p{posixxdigit}', "");
Expect(1, 103, '\p{^posixxdigit}', "");
Expect(1, 103, '\P{posixxdigit}', "");
Expect(0, 103, '\P{^posixxdigit}', "");
Expect(1, 102, '\p{_PosixXDigit}', "");
Expect(0, 102, '\p{^_PosixXDigit}', "");
Expect(0, 102, '\P{_PosixXDigit}', "");
Expect(1, 102, '\P{^_PosixXDigit}', "");
Expect(0, 103, '\p{_PosixXDigit}', "");
Expect(1, 103, '\p{^_PosixXDigit}', "");
Expect(1, 103, '\P{_PosixXDigit}', "");
Expect(0, 103, '\P{^_PosixXDigit}', "");
Error('\p{-	Is_PosixXDigit/a/}');
Error('\P{-	Is_PosixXDigit/a/}');
Expect(1, 102, '\p{isposixxdigit}', "");
Expect(0, 102, '\p{^isposixxdigit}', "");
Expect(0, 102, '\P{isposixxdigit}', "");
Expect(1, 102, '\P{^isposixxdigit}', "");
Expect(0, 103, '\p{isposixxdigit}', "");
Expect(1, 103, '\p{^isposixxdigit}', "");
Expect(1, 103, '\P{isposixxdigit}', "");
Expect(0, 103, '\P{^isposixxdigit}', "");
Expect(1, 102, '\p{Is_PosixXDigit}', "");
Expect(0, 102, '\p{^Is_PosixXDigit}', "");
Expect(0, 102, '\P{Is_PosixXDigit}', "");
Expect(1, 102, '\P{^Is_PosixXDigit}', "");
Expect(0, 103, '\p{Is_PosixXDigit}', "");
Expect(1, 103, '\p{^Is_PosixXDigit}', "");
Expect(1, 103, '\P{Is_PosixXDigit}', "");
Expect(0, 103, '\P{^Is_PosixXDigit}', "");
Error('\p{/a/--ASCII_hex_digit}');
Error('\P{/a/--ASCII_hex_digit}');
Expect(1, 102, '\p{asciihexdigit}', "");
Expect(0, 102, '\p{^asciihexdigit}', "");
Expect(0, 102, '\P{asciihexdigit}', "");
Expect(1, 102, '\P{^asciihexdigit}', "");
Expect(0, 103, '\p{asciihexdigit}', "");
Expect(1, 103, '\p{^asciihexdigit}', "");
Expect(1, 103, '\P{asciihexdigit}', "");
Expect(0, 103, '\P{^asciihexdigit}', "");
Expect(1, 102, '\p{		ASCII_Hex_Digit}', "");
Expect(0, 102, '\p{^		ASCII_Hex_Digit}', "");
Expect(0, 102, '\P{		ASCII_Hex_Digit}', "");
Expect(1, 102, '\P{^		ASCII_Hex_Digit}', "");
Expect(0, 103, '\p{		ASCII_Hex_Digit}', "");
Expect(1, 103, '\p{^		ASCII_Hex_Digit}', "");
Expect(1, 103, '\P{		ASCII_Hex_Digit}', "");
Expect(0, 103, '\P{^		ASCII_Hex_Digit}', "");
Error('\p{	IS_ASCII_Hex_Digit/a/}');
Error('\P{	IS_ASCII_Hex_Digit/a/}');
Expect(1, 102, '\p{isasciihexdigit}', "");
Expect(0, 102, '\p{^isasciihexdigit}', "");
Expect(0, 102, '\P{isasciihexdigit}', "");
Expect(1, 102, '\P{^isasciihexdigit}', "");
Expect(0, 103, '\p{isasciihexdigit}', "");
Expect(1, 103, '\p{^isasciihexdigit}', "");
Expect(1, 103, '\P{isasciihexdigit}', "");
Expect(0, 103, '\P{^isasciihexdigit}', "");
Expect(1, 102, '\p{is_ASCII_hex_digit}', "");
Expect(0, 102, '\p{^is_ASCII_hex_digit}', "");
Expect(0, 102, '\P{is_ASCII_hex_digit}', "");
Expect(1, 102, '\P{^is_ASCII_hex_digit}', "");
Expect(0, 103, '\p{is_ASCII_hex_digit}', "");
Expect(1, 103, '\p{^is_ASCII_hex_digit}', "");
Expect(1, 103, '\P{is_ASCII_hex_digit}', "");
Expect(0, 103, '\P{^is_ASCII_hex_digit}', "");
Error('\p{_ AHex:=}');
Error('\P{_ AHex:=}');
Expect(1, 102, '\p{ahex}', "");
Expect(0, 102, '\p{^ahex}', "");
Expect(0, 102, '\P{ahex}', "");
Expect(1, 102, '\P{^ahex}', "");
Expect(0, 103, '\p{ahex}', "");
Expect(1, 103, '\p{^ahex}', "");
Expect(1, 103, '\P{ahex}', "");
Expect(0, 103, '\P{^ahex}', "");
Expect(1, 102, '\p{ AHex}', "");
Expect(0, 102, '\p{^ AHex}', "");
Expect(0, 102, '\P{ AHex}', "");
Expect(1, 102, '\P{^ AHex}', "");
Expect(0, 103, '\p{ AHex}', "");
Expect(1, 103, '\p{^ AHex}', "");
Expect(1, 103, '\P{ AHex}', "");
Expect(0, 103, '\P{^ AHex}', "");
Error('\p{:=		is_AHex}');
Error('\P{:=		is_AHex}');
Expect(1, 102, '\p{isahex}', "");
Expect(0, 102, '\p{^isahex}', "");
Expect(0, 102, '\P{isahex}', "");
Expect(1, 102, '\P{^isahex}', "");
Expect(0, 103, '\p{isahex}', "");
Expect(1, 103, '\p{^isahex}', "");
Expect(1, 103, '\P{isahex}', "");
Expect(0, 103, '\P{^isahex}', "");
Expect(1, 102, '\p{		IS_AHEX}', "");
Expect(0, 102, '\p{^		IS_AHEX}', "");
Expect(0, 102, '\P{		IS_AHEX}', "");
Expect(1, 102, '\P{^		IS_AHEX}', "");
Expect(0, 103, '\p{		IS_AHEX}', "");
Expect(1, 103, '\p{^		IS_AHEX}', "");
Expect(1, 103, '\P{		IS_AHEX}', "");
Expect(0, 103, '\P{^		IS_AHEX}', "");
Error('\p{-:=print}');
Error('\P{-:=print}');
Expect(1, 1114109, '\p{print}', "");
Expect(0, 1114109, '\p{^print}', "");
Expect(0, 1114109, '\P{print}', "");
Expect(1, 1114109, '\P{^print}', "");
Expect(0, 918000, '\p{print}', "");
Expect(1, 918000, '\p{^print}', "");
Expect(1, 918000, '\P{print}', "");
Expect(0, 918000, '\P{^print}', "");
Expect(1, 1114109, '\p{__Print}', "");
Expect(0, 1114109, '\p{^__Print}', "");
Expect(0, 1114109, '\P{__Print}', "");
Expect(1, 1114109, '\P{^__Print}', "");
Expect(0, 918000, '\p{__Print}', "");
Expect(1, 918000, '\p{^__Print}', "");
Expect(1, 918000, '\P{__Print}', "");
Expect(0, 918000, '\P{^__Print}', "");
Error('\p{/a/ _xposixprint}');
Error('\P{/a/ _xposixprint}');
Expect(1, 1114109, '\p{xposixprint}', "");
Expect(0, 1114109, '\p{^xposixprint}', "");
Expect(0, 1114109, '\P{xposixprint}', "");
Expect(1, 1114109, '\P{^xposixprint}', "");
Expect(0, 918000, '\p{xposixprint}', "");
Expect(1, 918000, '\p{^xposixprint}', "");
Expect(1, 918000, '\P{xposixprint}', "");
Expect(0, 918000, '\P{^xposixprint}', "");
Expect(1, 1114109, '\p{ XPosixPrint}', "");
Expect(0, 1114109, '\p{^ XPosixPrint}', "");
Expect(0, 1114109, '\P{ XPosixPrint}', "");
Expect(1, 1114109, '\P{^ XPosixPrint}', "");
Expect(0, 918000, '\p{ XPosixPrint}', "");
Expect(1, 918000, '\p{^ XPosixPrint}', "");
Expect(1, 918000, '\P{ XPosixPrint}', "");
Expect(0, 918000, '\P{^ XPosixPrint}', "");
Error('\p{ IS_print:=}');
Error('\P{ IS_print:=}');
Expect(1, 1114109, '\p{isprint}', "");
Expect(0, 1114109, '\p{^isprint}', "");
Expect(0, 1114109, '\P{isprint}', "");
Expect(1, 1114109, '\P{^isprint}', "");
Expect(0, 918000, '\p{isprint}', "");
Expect(1, 918000, '\p{^isprint}', "");
Expect(1, 918000, '\P{isprint}', "");
Expect(0, 918000, '\P{^isprint}', "");
Expect(1, 1114109, '\p{ _Is_print}', "");
Expect(0, 1114109, '\p{^ _Is_print}', "");
Expect(0, 1114109, '\P{ _Is_print}', "");
Expect(1, 1114109, '\P{^ _Is_print}', "");
Expect(0, 918000, '\p{ _Is_print}', "");
Expect(1, 918000, '\p{^ _Is_print}', "");
Expect(1, 918000, '\P{ _Is_print}', "");
Expect(0, 918000, '\P{^ _Is_print}', "");
Error('\p{/a/	Is_XPosixPrint}');
Error('\P{/a/	Is_XPosixPrint}');
Expect(1, 1114109, '\p{isxposixprint}', "");
Expect(0, 1114109, '\p{^isxposixprint}', "");
Expect(0, 1114109, '\P{isxposixprint}', "");
Expect(1, 1114109, '\P{^isxposixprint}', "");
Expect(0, 918000, '\p{isxposixprint}', "");
Expect(1, 918000, '\p{^isxposixprint}', "");
Expect(1, 918000, '\P{isxposixprint}', "");
Expect(0, 918000, '\P{^isxposixprint}', "");
Expect(1, 1114109, '\p{- Is_xposixprint}', "");
Expect(0, 1114109, '\p{^- Is_xposixprint}', "");
Expect(0, 1114109, '\P{- Is_xposixprint}', "");
Expect(1, 1114109, '\P{^- Is_xposixprint}', "");
Expect(0, 918000, '\p{- Is_xposixprint}', "");
Expect(1, 918000, '\p{^- Is_xposixprint}', "");
Expect(1, 918000, '\P{- Is_xposixprint}', "");
Expect(0, 918000, '\P{^- Is_xposixprint}', "");
Error('\p{/a/_PRIVATE_USE}');
Error('\P{/a/_PRIVATE_USE}');
Expect(1, 1114109, '\p{privateuse}', "");
Expect(0, 1114109, '\p{^privateuse}', "");
Expect(0, 1114109, '\P{privateuse}', "");
Expect(1, 1114109, '\P{^privateuse}', "");
Expect(0, 63744, '\p{privateuse}', "");
Expect(1, 63744, '\p{^privateuse}', "");
Expect(1, 63744, '\P{privateuse}', "");
Expect(0, 63744, '\P{^privateuse}', "");
Expect(1, 1114109, '\p{- Private_Use}', "");
Expect(0, 1114109, '\p{^- Private_Use}', "");
Expect(0, 1114109, '\P{- Private_Use}', "");
Expect(1, 1114109, '\P{^- Private_Use}', "");
Expect(0, 63744, '\p{- Private_Use}', "");
Expect(1, 63744, '\p{^- Private_Use}', "");
Expect(1, 63744, '\P{- Private_Use}', "");
Expect(0, 63744, '\P{^- Private_Use}', "");
Error('\p{/a/-Is_private_Use}');
Error('\P{/a/-Is_private_Use}');
Expect(1, 1114109, '\p{isprivateuse}', "");
Expect(0, 1114109, '\p{^isprivateuse}', "");
Expect(0, 1114109, '\P{isprivateuse}', "");
Expect(1, 1114109, '\P{^isprivateuse}', "");
Expect(0, 63744, '\p{isprivateuse}', "");
Expect(1, 63744, '\p{^isprivateuse}', "");
Expect(1, 63744, '\P{isprivateuse}', "");
Expect(0, 63744, '\P{^isprivateuse}', "");
Expect(1, 1114109, '\p{ 	IS_Private_Use}', "");
Expect(0, 1114109, '\p{^ 	IS_Private_Use}', "");
Expect(0, 1114109, '\P{ 	IS_Private_Use}', "");
Expect(1, 1114109, '\P{^ 	IS_Private_Use}', "");
Expect(0, 63744, '\p{ 	IS_Private_Use}', "");
Expect(1, 63744, '\p{^ 	IS_Private_Use}', "");
Expect(1, 63744, '\P{ 	IS_Private_Use}', "");
Expect(0, 63744, '\P{^ 	IS_Private_Use}', "");
Error('\p{/a/	-Co}');
Error('\P{/a/	-Co}');
Expect(1, 1114109, '\p{co}', "");
Expect(0, 1114109, '\p{^co}', "");
Expect(0, 1114109, '\P{co}', "");
Expect(1, 1114109, '\P{^co}', "");
Expect(0, 63744, '\p{co}', "");
Expect(1, 63744, '\p{^co}', "");
Expect(1, 63744, '\P{co}', "");
Expect(0, 63744, '\P{^co}', "");
Expect(1, 1114109, '\p{ _Co}', "");
Expect(0, 1114109, '\p{^ _Co}', "");
Expect(0, 1114109, '\P{ _Co}', "");
Expect(1, 1114109, '\P{^ _Co}', "");
Expect(0, 63744, '\p{ _Co}', "");
Expect(1, 63744, '\p{^ _Co}', "");
Expect(1, 63744, '\P{ _Co}', "");
Expect(0, 63744, '\P{^ _Co}', "");
Error('\p{	:=Is_co}');
Error('\P{	:=Is_co}');
Expect(1, 1114109, '\p{isco}', "");
Expect(0, 1114109, '\p{^isco}', "");
Expect(0, 1114109, '\P{isco}', "");
Expect(1, 1114109, '\P{^isco}', "");
Expect(0, 63744, '\p{isco}', "");
Expect(1, 63744, '\p{^isco}', "");
Expect(1, 63744, '\P{isco}', "");
Expect(0, 63744, '\P{^isco}', "");
Expect(1, 1114109, '\p{	-is_CO}', "");
Expect(0, 1114109, '\p{^	-is_CO}', "");
Expect(0, 1114109, '\P{	-is_CO}', "");
Expect(1, 1114109, '\P{^	-is_CO}', "");
Expect(0, 63744, '\p{	-is_CO}', "");
Expect(1, 63744, '\p{^	-is_CO}', "");
Expect(1, 63744, '\P{	-is_CO}', "");
Expect(0, 63744, '\P{^	-is_CO}', "");
Error('\p{__PRIVATE_USE_AREA:=}');
Error('\P{__PRIVATE_USE_AREA:=}');
Expect(1, 63743, '\p{privateusearea}', "");
Expect(0, 63743, '\p{^privateusearea}', "");
Expect(0, 63743, '\P{privateusearea}', "");
Expect(1, 63743, '\P{^privateusearea}', "");
Expect(0, 63744, '\p{privateusearea}', "");
Expect(1, 63744, '\p{^privateusearea}', "");
Expect(1, 63744, '\P{privateusearea}', "");
Expect(0, 63744, '\P{^privateusearea}', "");
Expect(1, 63743, '\p{_ private_Use_Area}', "");
Expect(0, 63743, '\p{^_ private_Use_Area}', "");
Expect(0, 63743, '\P{_ private_Use_Area}', "");
Expect(1, 63743, '\P{^_ private_Use_Area}', "");
Expect(0, 63744, '\p{_ private_Use_Area}', "");
Expect(1, 63744, '\p{^_ private_Use_Area}', "");
Expect(1, 63744, '\P{_ private_Use_Area}', "");
Expect(0, 63744, '\P{^_ private_Use_Area}', "");
Error('\p{/a/	Is_private_Use_Area}');
Error('\P{/a/	Is_private_Use_Area}');
Expect(1, 63743, '\p{isprivateusearea}', "");
Expect(0, 63743, '\p{^isprivateusearea}', "");
Expect(0, 63743, '\P{isprivateusearea}', "");
Expect(1, 63743, '\P{^isprivateusearea}', "");
Expect(0, 63744, '\p{isprivateusearea}', "");
Expect(1, 63744, '\p{^isprivateusearea}', "");
Expect(1, 63744, '\P{isprivateusearea}', "");
Expect(0, 63744, '\P{^isprivateusearea}', "");
Expect(1, 63743, '\p{__Is_private_Use_Area}', "");
Expect(0, 63743, '\p{^__Is_private_Use_Area}', "");
Expect(0, 63743, '\P{__Is_private_Use_Area}', "");
Expect(1, 63743, '\P{^__Is_private_Use_Area}', "");
Expect(0, 63744, '\p{__Is_private_Use_Area}', "");
Expect(1, 63744, '\p{^__Is_private_Use_Area}', "");
Expect(1, 63744, '\P{__Is_private_Use_Area}', "");
Expect(0, 63744, '\P{^__Is_private_Use_Area}', "");
Error('\p{/a/ 	in_PRIVATE_Use_Area}');
Error('\P{/a/ 	in_PRIVATE_Use_Area}');
Expect(1, 63743, '\p{inprivateusearea}', "");
Expect(0, 63743, '\p{^inprivateusearea}', "");
Expect(0, 63743, '\P{inprivateusearea}', "");
Expect(1, 63743, '\P{^inprivateusearea}', "");
Expect(0, 63744, '\p{inprivateusearea}', "");
Expect(1, 63744, '\p{^inprivateusearea}', "");
Expect(1, 63744, '\P{inprivateusearea}', "");
Expect(0, 63744, '\P{^inprivateusearea}', "");
Expect(1, 63743, '\p{- IN_PRIVATE_USE_AREA}', "");
Expect(0, 63743, '\p{^- IN_PRIVATE_USE_AREA}', "");
Expect(0, 63743, '\P{- IN_PRIVATE_USE_AREA}', "");
Expect(1, 63743, '\P{^- IN_PRIVATE_USE_AREA}', "");
Expect(0, 63744, '\p{- IN_PRIVATE_USE_AREA}', "");
Expect(1, 63744, '\p{^- IN_PRIVATE_USE_AREA}', "");
Expect(1, 63744, '\P{- IN_PRIVATE_USE_AREA}', "");
Expect(0, 63744, '\P{^- IN_PRIVATE_USE_AREA}', "");
Error('\p{:=PUA}');
Error('\P{:=PUA}');
Expect(1, 63743, '\p{pua}', "");
Expect(0, 63743, '\p{^pua}', "");
Expect(0, 63743, '\P{pua}', "");
Expect(1, 63743, '\P{^pua}', "");
Expect(0, 63744, '\p{pua}', "");
Expect(1, 63744, '\p{^pua}', "");
Expect(1, 63744, '\P{pua}', "");
Expect(0, 63744, '\P{^pua}', "");
Expect(1, 63743, '\p{	_pua}', "");
Expect(0, 63743, '\p{^	_pua}', "");
Expect(0, 63743, '\P{	_pua}', "");
Expect(1, 63743, '\P{^	_pua}', "");
Expect(0, 63744, '\p{	_pua}', "");
Expect(1, 63744, '\p{^	_pua}', "");
Expect(1, 63744, '\P{	_pua}', "");
Expect(0, 63744, '\P{^	_pua}', "");
Error('\p{ _Is_PUA/a/}');
Error('\P{ _Is_PUA/a/}');
Expect(1, 63743, '\p{ispua}', "");
Expect(0, 63743, '\p{^ispua}', "");
Expect(0, 63743, '\P{ispua}', "");
Expect(1, 63743, '\P{^ispua}', "");
Expect(0, 63744, '\p{ispua}', "");
Expect(1, 63744, '\p{^ispua}', "");
Expect(1, 63744, '\P{ispua}', "");
Expect(0, 63744, '\P{^ispua}', "");
Expect(1, 63743, '\p{_Is_PUA}', "");
Expect(0, 63743, '\p{^_Is_PUA}', "");
Expect(0, 63743, '\P{_Is_PUA}', "");
Expect(1, 63743, '\P{^_Is_PUA}', "");
Expect(0, 63744, '\p{_Is_PUA}', "");
Expect(1, 63744, '\p{^_Is_PUA}', "");
Expect(1, 63744, '\P{_Is_PUA}', "");
Expect(0, 63744, '\P{^_Is_PUA}', "");
Error('\p{/a/In_PUA}');
Error('\P{/a/In_PUA}');
Expect(1, 63743, '\p{inpua}', "");
Expect(0, 63743, '\p{^inpua}', "");
Expect(0, 63743, '\P{inpua}', "");
Expect(1, 63743, '\P{^inpua}', "");
Expect(0, 63744, '\p{inpua}', "");
Expect(1, 63744, '\p{^inpua}', "");
Expect(1, 63744, '\P{inpua}', "");
Expect(0, 63744, '\P{^inpua}', "");
Expect(1, 63743, '\p{_in_PUA}', "");
Expect(0, 63743, '\p{^_in_PUA}', "");
Expect(0, 63743, '\P{_in_PUA}', "");
Expect(1, 63743, '\P{^_in_PUA}', "");
Expect(0, 63744, '\p{_in_PUA}', "");
Expect(1, 63744, '\p{^_in_PUA}', "");
Expect(1, 63744, '\P{_in_PUA}', "");
Expect(0, 63744, '\P{^_in_PUA}', "");
Error('\p{:=-_in_Private_Use}');
Error('\P{:=-_in_Private_Use}');
Expect(1, 63743, '\p{inprivateuse}', "");
Expect(0, 63743, '\p{^inprivateuse}', "");
Expect(0, 63743, '\P{inprivateuse}', "");
Expect(1, 63743, '\P{^inprivateuse}', "");
Expect(0, 63744, '\p{inprivateuse}', "");
Expect(1, 63744, '\p{^inprivateuse}', "");
Expect(1, 63744, '\P{inprivateuse}', "");
Expect(0, 63744, '\P{^inprivateuse}', "");
Expect(1, 63743, '\p{	_In_private_Use}', "");
Expect(0, 63743, '\p{^	_In_private_Use}', "");
Expect(0, 63743, '\P{	_In_private_Use}', "");
Expect(1, 63743, '\P{^	_In_private_Use}', "");
Expect(0, 63744, '\p{	_In_private_Use}', "");
Expect(1, 63744, '\p{^	_In_private_Use}', "");
Expect(1, 63744, '\P{	_In_private_Use}', "");
Expect(0, 63744, '\P{^	_In_private_Use}', "");
Error('\p{-	Punct:=}');
Error('\P{-	Punct:=}');
Expect(1, 74867, '\p{punct}', "");
Expect(0, 74867, '\p{^punct}', "");
Expect(0, 74867, '\P{punct}', "");
Expect(1, 74867, '\P{^punct}', "");
Expect(0, 74868, '\p{punct}', "");
Expect(1, 74868, '\p{^punct}', "");
Expect(1, 74868, '\P{punct}', "");
Expect(0, 74868, '\P{^punct}', "");
Expect(1, 74867, '\p{-Punct}', "");
Expect(0, 74867, '\p{^-Punct}', "");
Expect(0, 74867, '\P{-Punct}', "");
Expect(1, 74867, '\P{^-Punct}', "");
Expect(0, 74868, '\p{-Punct}', "");
Expect(1, 74868, '\p{^-Punct}', "");
Expect(1, 74868, '\P{-Punct}', "");
Expect(0, 74868, '\P{^-Punct}', "");
Error('\p{:= 	IS_Punct}');
Error('\P{:= 	IS_Punct}');
Expect(1, 74867, '\p{ispunct}', "");
Expect(0, 74867, '\p{^ispunct}', "");
Expect(0, 74867, '\P{ispunct}', "");
Expect(1, 74867, '\P{^ispunct}', "");
Expect(0, 74868, '\p{ispunct}', "");
Expect(1, 74868, '\p{^ispunct}', "");
Expect(1, 74868, '\P{ispunct}', "");
Expect(0, 74868, '\P{^ispunct}', "");
Expect(1, 74867, '\p{-is_Punct}', "");
Expect(0, 74867, '\p{^-is_Punct}', "");
Expect(0, 74867, '\P{-is_Punct}', "");
Expect(1, 74867, '\P{^-is_Punct}', "");
Expect(0, 74868, '\p{-is_Punct}', "");
Expect(1, 74868, '\p{^-is_Punct}', "");
Expect(1, 74868, '\P{-is_Punct}', "");
Expect(0, 74868, '\P{^-is_Punct}', "");
Error('\p{_ punctuation:=}');
Error('\P{_ punctuation:=}');
Expect(1, 74867, '\p{punctuation}', "");
Expect(0, 74867, '\p{^punctuation}', "");
Expect(0, 74867, '\P{punctuation}', "");
Expect(1, 74867, '\P{^punctuation}', "");
Expect(0, 74868, '\p{punctuation}', "");
Expect(1, 74868, '\p{^punctuation}', "");
Expect(1, 74868, '\P{punctuation}', "");
Expect(0, 74868, '\P{^punctuation}', "");
Expect(1, 74867, '\p{	_PUNCTUATION}', "");
Expect(0, 74867, '\p{^	_PUNCTUATION}', "");
Expect(0, 74867, '\P{	_PUNCTUATION}', "");
Expect(1, 74867, '\P{^	_PUNCTUATION}', "");
Expect(0, 74868, '\p{	_PUNCTUATION}', "");
Expect(1, 74868, '\p{^	_PUNCTUATION}', "");
Expect(1, 74868, '\P{	_PUNCTUATION}', "");
Expect(0, 74868, '\P{^	_PUNCTUATION}', "");
Error('\p{	is_Punctuation/a/}');
Error('\P{	is_Punctuation/a/}');
Expect(1, 74867, '\p{ispunctuation}', "");
Expect(0, 74867, '\p{^ispunctuation}', "");
Expect(0, 74867, '\P{ispunctuation}', "");
Expect(1, 74867, '\P{^ispunctuation}', "");
Expect(0, 74868, '\p{ispunctuation}', "");
Expect(1, 74868, '\p{^ispunctuation}', "");
Expect(1, 74868, '\P{ispunctuation}', "");
Expect(0, 74868, '\P{^ispunctuation}', "");
Expect(1, 74867, '\p{	_Is_Punctuation}', "");
Expect(0, 74867, '\p{^	_Is_Punctuation}', "");
Expect(0, 74867, '\P{	_Is_Punctuation}', "");
Expect(1, 74867, '\P{^	_Is_Punctuation}', "");
Expect(0, 74868, '\p{	_Is_Punctuation}', "");
Expect(1, 74868, '\p{^	_Is_Punctuation}', "");
Expect(1, 74868, '\P{	_Is_Punctuation}', "");
Expect(0, 74868, '\P{^	_Is_Punctuation}', "");
Error('\p{:= P}');
Error('\P{:= P}');
Expect(1, 74867, '\p{p}', "");
Expect(0, 74867, '\p{^p}', "");
Expect(0, 74867, '\P{p}', "");
Expect(1, 74867, '\P{^p}', "");
Expect(0, 74868, '\p{p}', "");
Expect(1, 74868, '\p{^p}', "");
Expect(1, 74868, '\P{p}', "");
Expect(0, 74868, '\P{^p}', "");
Expect(1, 74867, '\p{_P}', "");
Expect(0, 74867, '\p{^_P}', "");
Expect(0, 74867, '\P{_P}', "");
Expect(1, 74867, '\P{^_P}', "");
Expect(0, 74868, '\p{_P}', "");
Expect(1, 74868, '\p{^_P}', "");
Expect(1, 74868, '\P{_P}', "");
Expect(0, 74868, '\P{^_P}', "");
Error('\p{/a/Is_p}');
Error('\P{/a/Is_p}');
Expect(1, 74867, '\p{isp}', "");
Expect(0, 74867, '\p{^isp}', "");
Expect(0, 74867, '\P{isp}', "");
Expect(1, 74867, '\P{^isp}', "");
Expect(0, 74868, '\p{isp}', "");
Expect(1, 74868, '\p{^isp}', "");
Expect(1, 74868, '\P{isp}', "");
Expect(0, 74868, '\P{^isp}', "");
Expect(1, 74867, '\p{-	Is_p}', "");
Expect(0, 74867, '\p{^-	Is_p}', "");
Expect(0, 74867, '\P{-	Is_p}', "");
Expect(1, 74867, '\P{^-	Is_p}', "");
Expect(0, 74868, '\p{-	Is_p}', "");
Expect(1, 74868, '\p{^-	Is_p}', "");
Expect(1, 74868, '\P{-	Is_p}', "");
Expect(0, 74868, '\P{^-	Is_p}', "");
Error('\p{ /a/quotation_mark}');
Error('\P{ /a/quotation_mark}');
Expect(1, 65379, '\p{quotationmark}', "");
Expect(0, 65379, '\p{^quotationmark}', "");
Expect(0, 65379, '\P{quotationmark}', "");
Expect(1, 65379, '\P{^quotationmark}', "");
Expect(0, 65380, '\p{quotationmark}', "");
Expect(1, 65380, '\p{^quotationmark}', "");
Expect(1, 65380, '\P{quotationmark}', "");
Expect(0, 65380, '\P{^quotationmark}', "");
Expect(1, 65379, '\p{ -Quotation_Mark}', "");
Expect(0, 65379, '\p{^ -Quotation_Mark}', "");
Expect(0, 65379, '\P{ -Quotation_Mark}', "");
Expect(1, 65379, '\P{^ -Quotation_Mark}', "");
Expect(0, 65380, '\p{ -Quotation_Mark}', "");
Expect(1, 65380, '\p{^ -Quotation_Mark}', "");
Expect(1, 65380, '\P{ -Quotation_Mark}', "");
Expect(0, 65380, '\P{^ -Quotation_Mark}', "");
Error('\p{ /a/Is_QUOTATION_mark}');
Error('\P{ /a/Is_QUOTATION_mark}');
Expect(1, 65379, '\p{isquotationmark}', "");
Expect(0, 65379, '\p{^isquotationmark}', "");
Expect(0, 65379, '\P{isquotationmark}', "");
Expect(1, 65379, '\P{^isquotationmark}', "");
Expect(0, 65380, '\p{isquotationmark}', "");
Expect(1, 65380, '\p{^isquotationmark}', "");
Expect(1, 65380, '\P{isquotationmark}', "");
Expect(0, 65380, '\P{^isquotationmark}', "");
Expect(1, 65379, '\p{is_Quotation_Mark}', "");
Expect(0, 65379, '\p{^is_Quotation_Mark}', "");
Expect(0, 65379, '\P{is_Quotation_Mark}', "");
Expect(1, 65379, '\P{^is_Quotation_Mark}', "");
Expect(0, 65380, '\p{is_Quotation_Mark}', "");
Expect(1, 65380, '\p{^is_Quotation_Mark}', "");
Expect(1, 65380, '\P{is_Quotation_Mark}', "");
Expect(0, 65380, '\P{^is_Quotation_Mark}', "");
Error('\p{-:=QMARK}');
Error('\P{-:=QMARK}');
Expect(1, 65379, '\p{qmark}', "");
Expect(0, 65379, '\p{^qmark}', "");
Expect(0, 65379, '\P{qmark}', "");
Expect(1, 65379, '\P{^qmark}', "");
Expect(0, 65380, '\p{qmark}', "");
Expect(1, 65380, '\p{^qmark}', "");
Expect(1, 65380, '\P{qmark}', "");
Expect(0, 65380, '\P{^qmark}', "");
Expect(1, 65379, '\p{	_QMark}', "");
Expect(0, 65379, '\p{^	_QMark}', "");
Expect(0, 65379, '\P{	_QMark}', "");
Expect(1, 65379, '\P{^	_QMark}', "");
Expect(0, 65380, '\p{	_QMark}', "");
Expect(1, 65380, '\p{^	_QMark}', "");
Expect(1, 65380, '\P{	_QMark}', "");
Expect(0, 65380, '\P{^	_QMark}', "");
Error('\p{/a/--is_QMark}');
Error('\P{/a/--is_QMark}');
Expect(1, 65379, '\p{isqmark}', "");
Expect(0, 65379, '\p{^isqmark}', "");
Expect(0, 65379, '\P{isqmark}', "");
Expect(1, 65379, '\P{^isqmark}', "");
Expect(0, 65380, '\p{isqmark}', "");
Expect(1, 65380, '\p{^isqmark}', "");
Expect(1, 65380, '\P{isqmark}', "");
Expect(0, 65380, '\P{^isqmark}', "");
Expect(1, 65379, '\p{	_IS_QMark}', "");
Expect(0, 65379, '\p{^	_IS_QMark}', "");
Expect(0, 65379, '\P{	_IS_QMark}', "");
Expect(1, 65379, '\P{^	_IS_QMark}', "");
Expect(0, 65380, '\p{	_IS_QMark}', "");
Expect(1, 65380, '\p{^	_IS_QMark}', "");
Expect(1, 65380, '\P{	_IS_QMark}', "");
Expect(0, 65380, '\P{^	_IS_QMark}', "");
Error('\p{ 	radical/a/}');
Error('\P{ 	radical/a/}');
Expect(1, 12245, '\p{radical}', "");
Expect(0, 12245, '\p{^radical}', "");
Expect(0, 12245, '\P{radical}', "");
Expect(1, 12245, '\P{^radical}', "");
Expect(0, 12246, '\p{radical}', "");
Expect(1, 12246, '\p{^radical}', "");
Expect(1, 12246, '\P{radical}', "");
Expect(0, 12246, '\P{^radical}', "");
Expect(1, 12245, '\p{ -Radical}', "");
Expect(0, 12245, '\p{^ -Radical}', "");
Expect(0, 12245, '\P{ -Radical}', "");
Expect(1, 12245, '\P{^ -Radical}', "");
Expect(0, 12246, '\p{ -Radical}', "");
Expect(1, 12246, '\p{^ -Radical}', "");
Expect(1, 12246, '\P{ -Radical}', "");
Expect(0, 12246, '\P{^ -Radical}', "");
Error('\p{	Is_Radical/a/}');
Error('\P{	Is_Radical/a/}');
Expect(1, 12245, '\p{isradical}', "");
Expect(0, 12245, '\p{^isradical}', "");
Expect(0, 12245, '\P{isradical}', "");
Expect(1, 12245, '\P{^isradical}', "");
Expect(0, 12246, '\p{isradical}', "");
Expect(1, 12246, '\p{^isradical}', "");
Expect(1, 12246, '\P{isradical}', "");
Expect(0, 12246, '\P{^isradical}', "");
Expect(1, 12245, '\p{ is_radical}', "");
Expect(0, 12245, '\p{^ is_radical}', "");
Expect(0, 12245, '\P{ is_radical}', "");
Expect(1, 12245, '\P{^ is_radical}', "");
Expect(0, 12246, '\p{ is_radical}', "");
Expect(1, 12246, '\p{^ is_radical}', "");
Expect(1, 12246, '\P{ is_radical}', "");
Expect(0, 12246, '\P{^ is_radical}', "");
Error('\p{:=_Rejang}');
Error('\P{:=_Rejang}');
Expect(1, 43359, '\p{rejang}', "");
Expect(0, 43359, '\p{^rejang}', "");
Expect(0, 43359, '\P{rejang}', "");
Expect(1, 43359, '\P{^rejang}', "");
Expect(0, 43360, '\p{rejang}', "");
Expect(1, 43360, '\p{^rejang}', "");
Expect(1, 43360, '\P{rejang}', "");
Expect(0, 43360, '\P{^rejang}', "");
Expect(1, 43359, '\p{-_REJANG}', "");
Expect(0, 43359, '\p{^-_REJANG}', "");
Expect(0, 43359, '\P{-_REJANG}', "");
Expect(1, 43359, '\P{^-_REJANG}', "");
Expect(0, 43360, '\p{-_REJANG}', "");
Expect(1, 43360, '\p{^-_REJANG}', "");
Expect(1, 43360, '\P{-_REJANG}', "");
Expect(0, 43360, '\P{^-_REJANG}', "");
Error('\p{:=_-IS_rejang}');
Error('\P{:=_-IS_rejang}');
Expect(1, 43359, '\p{isrejang}', "");
Expect(0, 43359, '\p{^isrejang}', "");
Expect(0, 43359, '\P{isrejang}', "");
Expect(1, 43359, '\P{^isrejang}', "");
Expect(0, 43360, '\p{isrejang}', "");
Expect(1, 43360, '\p{^isrejang}', "");
Expect(1, 43360, '\P{isrejang}', "");
Expect(0, 43360, '\P{^isrejang}', "");
Expect(1, 43359, '\p{_	is_Rejang}', "");
Expect(0, 43359, '\p{^_	is_Rejang}', "");
Expect(0, 43359, '\P{_	is_Rejang}', "");
Expect(1, 43359, '\P{^_	is_Rejang}', "");
Expect(0, 43360, '\p{_	is_Rejang}', "");
Expect(1, 43360, '\p{^_	is_Rejang}', "");
Expect(1, 43360, '\P{_	is_Rejang}', "");
Expect(0, 43360, '\P{^_	is_Rejang}', "");
Error('\p{ RJNG/a/}');
Error('\P{ RJNG/a/}');
Expect(1, 43359, '\p{rjng}', "");
Expect(0, 43359, '\p{^rjng}', "");
Expect(0, 43359, '\P{rjng}', "");
Expect(1, 43359, '\P{^rjng}', "");
Expect(0, 43360, '\p{rjng}', "");
Expect(1, 43360, '\p{^rjng}', "");
Expect(1, 43360, '\P{rjng}', "");
Expect(0, 43360, '\P{^rjng}', "");
Expect(1, 43359, '\p{--rjng}', "");
Expect(0, 43359, '\p{^--rjng}', "");
Expect(0, 43359, '\P{--rjng}', "");
Expect(1, 43359, '\P{^--rjng}', "");
Expect(0, 43360, '\p{--rjng}', "");
Expect(1, 43360, '\p{^--rjng}', "");
Expect(1, 43360, '\P{--rjng}', "");
Expect(0, 43360, '\P{^--rjng}', "");
Error('\p{:=-	is_rjng}');
Error('\P{:=-	is_rjng}');
Expect(1, 43359, '\p{isrjng}', "");
Expect(0, 43359, '\p{^isrjng}', "");
Expect(0, 43359, '\P{isrjng}', "");
Expect(1, 43359, '\P{^isrjng}', "");
Expect(0, 43360, '\p{isrjng}', "");
Expect(1, 43360, '\p{^isrjng}', "");
Expect(1, 43360, '\P{isrjng}', "");
Expect(0, 43360, '\P{^isrjng}', "");
Expect(1, 43359, '\p{--is_Rjng}', "");
Expect(0, 43359, '\p{^--is_Rjng}', "");
Expect(0, 43359, '\P{--is_Rjng}', "");
Expect(1, 43359, '\P{^--is_Rjng}', "");
Expect(0, 43360, '\p{--is_Rjng}', "");
Expect(1, 43360, '\p{^--is_Rjng}', "");
Expect(1, 43360, '\P{--is_Rjng}', "");
Expect(0, 43360, '\P{^--is_Rjng}', "");
Error('\p{/a/_	Rumi_numeral_symbols}');
Error('\P{/a/_	Rumi_numeral_symbols}');
Expect(1, 69247, '\p{ruminumeralsymbols}', "");
Expect(0, 69247, '\p{^ruminumeralsymbols}', "");
Expect(0, 69247, '\P{ruminumeralsymbols}', "");
Expect(1, 69247, '\P{^ruminumeralsymbols}', "");
Expect(0, 69248, '\p{ruminumeralsymbols}', "");
Expect(1, 69248, '\p{^ruminumeralsymbols}', "");
Expect(1, 69248, '\P{ruminumeralsymbols}', "");
Expect(0, 69248, '\P{^ruminumeralsymbols}', "");
Expect(1, 69247, '\p{ _rumi_Numeral_Symbols}', "");
Expect(0, 69247, '\p{^ _rumi_Numeral_Symbols}', "");
Expect(0, 69247, '\P{ _rumi_Numeral_Symbols}', "");
Expect(1, 69247, '\P{^ _rumi_Numeral_Symbols}', "");
Expect(0, 69248, '\p{ _rumi_Numeral_Symbols}', "");
Expect(1, 69248, '\p{^ _rumi_Numeral_Symbols}', "");
Expect(1, 69248, '\P{ _rumi_Numeral_Symbols}', "");
Expect(0, 69248, '\P{^ _rumi_Numeral_Symbols}', "");
Error('\p{:=		Is_Rumi_NUMERAL_symbols}');
Error('\P{:=		Is_Rumi_NUMERAL_symbols}');
Expect(1, 69247, '\p{isruminumeralsymbols}', "");
Expect(0, 69247, '\p{^isruminumeralsymbols}', "");
Expect(0, 69247, '\P{isruminumeralsymbols}', "");
Expect(1, 69247, '\P{^isruminumeralsymbols}', "");
Expect(0, 69248, '\p{isruminumeralsymbols}', "");
Expect(1, 69248, '\p{^isruminumeralsymbols}', "");
Expect(1, 69248, '\P{isruminumeralsymbols}', "");
Expect(0, 69248, '\P{^isruminumeralsymbols}', "");
Expect(1, 69247, '\p{-IS_Rumi_Numeral_Symbols}', "");
Expect(0, 69247, '\p{^-IS_Rumi_Numeral_Symbols}', "");
Expect(0, 69247, '\P{-IS_Rumi_Numeral_Symbols}', "");
Expect(1, 69247, '\P{^-IS_Rumi_Numeral_Symbols}', "");
Expect(0, 69248, '\p{-IS_Rumi_Numeral_Symbols}', "");
Expect(1, 69248, '\p{^-IS_Rumi_Numeral_Symbols}', "");
Expect(1, 69248, '\P{-IS_Rumi_Numeral_Symbols}', "");
Expect(0, 69248, '\P{^-IS_Rumi_Numeral_Symbols}', "");
Error('\p{	/a/IN_RUMI_Numeral_symbols}');
Error('\P{	/a/IN_RUMI_Numeral_symbols}');
Expect(1, 69247, '\p{inruminumeralsymbols}', "");
Expect(0, 69247, '\p{^inruminumeralsymbols}', "");
Expect(0, 69247, '\P{inruminumeralsymbols}', "");
Expect(1, 69247, '\P{^inruminumeralsymbols}', "");
Expect(0, 69248, '\p{inruminumeralsymbols}', "");
Expect(1, 69248, '\p{^inruminumeralsymbols}', "");
Expect(1, 69248, '\P{inruminumeralsymbols}', "");
Expect(0, 69248, '\P{^inruminumeralsymbols}', "");
Expect(1, 69247, '\p{	 In_Rumi_numeral_Symbols}', "");
Expect(0, 69247, '\p{^	 In_Rumi_numeral_Symbols}', "");
Expect(0, 69247, '\P{	 In_Rumi_numeral_Symbols}', "");
Expect(1, 69247, '\P{^	 In_Rumi_numeral_Symbols}', "");
Expect(0, 69248, '\p{	 In_Rumi_numeral_Symbols}', "");
Expect(1, 69248, '\p{^	 In_Rumi_numeral_Symbols}', "");
Expect(1, 69248, '\P{	 In_Rumi_numeral_Symbols}', "");
Expect(0, 69248, '\P{^	 In_Rumi_numeral_Symbols}', "");
Error('\p{:= _RUMI}');
Error('\P{:= _RUMI}');
Expect(1, 69247, '\p{rumi}', "");
Expect(0, 69247, '\p{^rumi}', "");
Expect(0, 69247, '\P{rumi}', "");
Expect(1, 69247, '\P{^rumi}', "");
Expect(0, 69248, '\p{rumi}', "");
Expect(1, 69248, '\p{^rumi}', "");
Expect(1, 69248, '\P{rumi}', "");
Expect(0, 69248, '\P{^rumi}', "");
Expect(1, 69247, '\p{RUMI}', "");
Expect(0, 69247, '\p{^RUMI}', "");
Expect(0, 69247, '\P{RUMI}', "");
Expect(1, 69247, '\P{^RUMI}', "");
Expect(0, 69248, '\p{RUMI}', "");
Expect(1, 69248, '\p{^RUMI}', "");
Expect(1, 69248, '\P{RUMI}', "");
Expect(0, 69248, '\P{^RUMI}', "");
Error('\p{	IS_RUMI/a/}');
Error('\P{	IS_RUMI/a/}');
Expect(1, 69247, '\p{isrumi}', "");
Expect(0, 69247, '\p{^isrumi}', "");
Expect(0, 69247, '\P{isrumi}', "");
Expect(1, 69247, '\P{^isrumi}', "");
Expect(0, 69248, '\p{isrumi}', "");
Expect(1, 69248, '\p{^isrumi}', "");
Expect(1, 69248, '\P{isrumi}', "");
Expect(0, 69248, '\P{^isrumi}', "");
Expect(1, 69247, '\p{		Is_rumi}', "");
Expect(0, 69247, '\p{^		Is_rumi}', "");
Expect(0, 69247, '\P{		Is_rumi}', "");
Expect(1, 69247, '\P{^		Is_rumi}', "");
Expect(0, 69248, '\p{		Is_rumi}', "");
Expect(1, 69248, '\p{^		Is_rumi}', "");
Expect(1, 69248, '\P{		Is_rumi}', "");
Expect(0, 69248, '\P{^		Is_rumi}', "");
Error('\p{_ In_rumi:=}');
Error('\P{_ In_rumi:=}');
Expect(1, 69247, '\p{inrumi}', "");
Expect(0, 69247, '\p{^inrumi}', "");
Expect(0, 69247, '\P{inrumi}', "");
Expect(1, 69247, '\P{^inrumi}', "");
Expect(0, 69248, '\p{inrumi}', "");
Expect(1, 69248, '\p{^inrumi}', "");
Expect(1, 69248, '\P{inrumi}', "");
Expect(0, 69248, '\P{^inrumi}', "");
Expect(1, 69247, '\p{	IN_RUMI}', "");
Expect(0, 69247, '\p{^	IN_RUMI}', "");
Expect(0, 69247, '\P{	IN_RUMI}', "");
Expect(1, 69247, '\P{^	IN_RUMI}', "");
Expect(0, 69248, '\p{	IN_RUMI}', "");
Expect(1, 69248, '\p{^	IN_RUMI}', "");
Expect(1, 69248, '\P{	IN_RUMI}', "");
Expect(0, 69248, '\P{^	IN_RUMI}', "");
Error('\p{/a/  Runic}');
Error('\P{/a/  Runic}');
Expect(1, 5872, '\p{runic}', "");
Expect(0, 5872, '\p{^runic}', "");
Expect(0, 5872, '\P{runic}', "");
Expect(1, 5872, '\P{^runic}', "");
Expect(0, 5873, '\p{runic}', "");
Expect(1, 5873, '\p{^runic}', "");
Expect(1, 5873, '\P{runic}', "");
Expect(0, 5873, '\P{^runic}', "");
Expect(1, 5872, '\p{ Runic}', "");
Expect(0, 5872, '\p{^ Runic}', "");
Expect(0, 5872, '\P{ Runic}', "");
Expect(1, 5872, '\P{^ Runic}', "");
Expect(0, 5873, '\p{ Runic}', "");
Expect(1, 5873, '\p{^ Runic}', "");
Expect(1, 5873, '\P{ Runic}', "");
Expect(0, 5873, '\P{^ Runic}', "");
Error('\p{_	Is_RUNIC/a/}');
Error('\P{_	Is_RUNIC/a/}');
Expect(1, 5872, '\p{isrunic}', "");
Expect(0, 5872, '\p{^isrunic}', "");
Expect(0, 5872, '\P{isrunic}', "");
Expect(1, 5872, '\P{^isrunic}', "");
Expect(0, 5873, '\p{isrunic}', "");
Expect(1, 5873, '\p{^isrunic}', "");
Expect(1, 5873, '\P{isrunic}', "");
Expect(0, 5873, '\P{^isrunic}', "");
Expect(1, 5872, '\p{	IS_runic}', "");
Expect(0, 5872, '\p{^	IS_runic}', "");
Expect(0, 5872, '\P{	IS_runic}', "");
Expect(1, 5872, '\P{^	IS_runic}', "");
Expect(0, 5873, '\p{	IS_runic}', "");
Expect(1, 5873, '\p{^	IS_runic}', "");
Expect(1, 5873, '\P{	IS_runic}', "");
Expect(0, 5873, '\P{^	IS_runic}', "");
Error('\p{:=--Runr}');
Error('\P{:=--Runr}');
Expect(1, 5872, '\p{runr}', "");
Expect(0, 5872, '\p{^runr}', "");
Expect(0, 5872, '\P{runr}', "");
Expect(1, 5872, '\P{^runr}', "");
Expect(0, 5873, '\p{runr}', "");
Expect(1, 5873, '\p{^runr}', "");
Expect(1, 5873, '\P{runr}', "");
Expect(0, 5873, '\P{^runr}', "");
Expect(1, 5872, '\p{_Runr}', "");
Expect(0, 5872, '\p{^_Runr}', "");
Expect(0, 5872, '\P{_Runr}', "");
Expect(1, 5872, '\P{^_Runr}', "");
Expect(0, 5873, '\p{_Runr}', "");
Expect(1, 5873, '\p{^_Runr}', "");
Expect(1, 5873, '\P{_Runr}', "");
Expect(0, 5873, '\P{^_Runr}', "");
Error('\p{ Is_runr/a/}');
Error('\P{ Is_runr/a/}');
Expect(1, 5872, '\p{isrunr}', "");
Expect(0, 5872, '\p{^isrunr}', "");
Expect(0, 5872, '\P{isrunr}', "");
Expect(1, 5872, '\P{^isrunr}', "");
Expect(0, 5873, '\p{isrunr}', "");
Expect(1, 5873, '\p{^isrunr}', "");
Expect(1, 5873, '\P{isrunr}', "");
Expect(0, 5873, '\P{^isrunr}', "");
Expect(1, 5872, '\p{_	Is_RUNR}', "");
Expect(0, 5872, '\p{^_	Is_RUNR}', "");
Expect(0, 5872, '\P{_	Is_RUNR}', "");
Expect(1, 5872, '\P{^_	Is_RUNR}', "");
Expect(0, 5873, '\p{_	Is_RUNR}', "");
Expect(1, 5873, '\p{^_	Is_RUNR}', "");
Expect(1, 5873, '\P{_	Is_RUNR}', "");
Expect(0, 5873, '\P{^_	Is_RUNR}', "");
Error('\p{-/a/STERM}');
Error('\P{-/a/STERM}');
Expect(1, 70086, '\p{sterm}', "");
Expect(0, 70086, '\p{^sterm}', "");
Expect(0, 70086, '\P{sterm}', "");
Expect(1, 70086, '\P{^sterm}', "");
Expect(0, 70087, '\p{sterm}', "");
Expect(1, 70087, '\p{^sterm}', "");
Expect(1, 70087, '\P{sterm}', "");
Expect(0, 70087, '\P{^sterm}', "");
Expect(1, 70086, '\p{-	sterm}', "");
Expect(0, 70086, '\p{^-	sterm}', "");
Expect(0, 70086, '\P{-	sterm}', "");
Expect(1, 70086, '\P{^-	sterm}', "");
Expect(0, 70087, '\p{-	sterm}', "");
Expect(1, 70087, '\p{^-	sterm}', "");
Expect(1, 70087, '\P{-	sterm}', "");
Expect(0, 70087, '\P{^-	sterm}', "");
Error('\p{__Is_sterm/a/}');
Error('\P{__Is_sterm/a/}');
Expect(1, 70086, '\p{issterm}', "");
Expect(0, 70086, '\p{^issterm}', "");
Expect(0, 70086, '\P{issterm}', "");
Expect(1, 70086, '\P{^issterm}', "");
Expect(0, 70087, '\p{issterm}', "");
Expect(1, 70087, '\p{^issterm}', "");
Expect(1, 70087, '\P{issterm}', "");
Expect(0, 70087, '\P{^issterm}', "");
Expect(1, 70086, '\p{-	is_STerm}', "");
Expect(0, 70086, '\p{^-	is_STerm}', "");
Expect(0, 70086, '\P{-	is_STerm}', "");
Expect(1, 70086, '\P{^-	is_STerm}', "");
Expect(0, 70087, '\p{-	is_STerm}', "");
Expect(1, 70087, '\p{^-	is_STerm}', "");
Expect(1, 70087, '\P{-	is_STerm}', "");
Expect(0, 70087, '\P{^-	is_STerm}', "");
Error('\p{/a/samaritan}');
Error('\P{/a/samaritan}');
Expect(1, 2110, '\p{samaritan}', "");
Expect(0, 2110, '\p{^samaritan}', "");
Expect(0, 2110, '\P{samaritan}', "");
Expect(1, 2110, '\P{^samaritan}', "");
Expect(0, 2111, '\p{samaritan}', "");
Expect(1, 2111, '\p{^samaritan}', "");
Expect(1, 2111, '\P{samaritan}', "");
Expect(0, 2111, '\P{^samaritan}', "");
Expect(1, 2110, '\p{_SAMARITAN}', "");
Expect(0, 2110, '\p{^_SAMARITAN}', "");
Expect(0, 2110, '\P{_SAMARITAN}', "");
Expect(1, 2110, '\P{^_SAMARITAN}', "");
Expect(0, 2111, '\p{_SAMARITAN}', "");
Expect(1, 2111, '\p{^_SAMARITAN}', "");
Expect(1, 2111, '\P{_SAMARITAN}', "");
Expect(0, 2111, '\P{^_SAMARITAN}', "");
Error('\p{ Is_SAMARITAN:=}');
Error('\P{ Is_SAMARITAN:=}');
Expect(1, 2110, '\p{issamaritan}', "");
Expect(0, 2110, '\p{^issamaritan}', "");
Expect(0, 2110, '\P{issamaritan}', "");
Expect(1, 2110, '\P{^issamaritan}', "");
Expect(0, 2111, '\p{issamaritan}', "");
Expect(1, 2111, '\p{^issamaritan}', "");
Expect(1, 2111, '\P{issamaritan}', "");
Expect(0, 2111, '\P{^issamaritan}', "");
Expect(1, 2110, '\p{	 is_samaritan}', "");
Expect(0, 2110, '\p{^	 is_samaritan}', "");
Expect(0, 2110, '\P{	 is_samaritan}', "");
Expect(1, 2110, '\P{^	 is_samaritan}', "");
Expect(0, 2111, '\p{	 is_samaritan}', "");
Expect(1, 2111, '\p{^	 is_samaritan}', "");
Expect(1, 2111, '\P{	 is_samaritan}', "");
Expect(0, 2111, '\P{^	 is_samaritan}', "");
Error('\p{:= Samr}');
Error('\P{:= Samr}');
Expect(1, 2110, '\p{samr}', "");
Expect(0, 2110, '\p{^samr}', "");
Expect(0, 2110, '\P{samr}', "");
Expect(1, 2110, '\P{^samr}', "");
Expect(0, 2111, '\p{samr}', "");
Expect(1, 2111, '\p{^samr}', "");
Expect(1, 2111, '\P{samr}', "");
Expect(0, 2111, '\P{^samr}', "");
Expect(1, 2110, '\p{ 	Samr}', "");
Expect(0, 2110, '\p{^ 	Samr}', "");
Expect(0, 2110, '\P{ 	Samr}', "");
Expect(1, 2110, '\P{^ 	Samr}', "");
Expect(0, 2111, '\p{ 	Samr}', "");
Expect(1, 2111, '\p{^ 	Samr}', "");
Expect(1, 2111, '\P{ 	Samr}', "");
Expect(0, 2111, '\P{^ 	Samr}', "");
Error('\p{:=-Is_SAMR}');
Error('\P{:=-Is_SAMR}');
Expect(1, 2110, '\p{issamr}', "");
Expect(0, 2110, '\p{^issamr}', "");
Expect(0, 2110, '\P{issamr}', "");
Expect(1, 2110, '\P{^issamr}', "");
Expect(0, 2111, '\p{issamr}', "");
Expect(1, 2111, '\p{^issamr}', "");
Expect(1, 2111, '\P{issamr}', "");
Expect(0, 2111, '\P{^issamr}', "");
Expect(1, 2110, '\p{	_Is_Samr}', "");
Expect(0, 2110, '\p{^	_Is_Samr}', "");
Expect(0, 2110, '\P{	_Is_Samr}', "");
Expect(1, 2110, '\P{^	_Is_Samr}', "");
Expect(0, 2111, '\p{	_Is_Samr}', "");
Expect(1, 2111, '\p{^	_Is_Samr}', "");
Expect(1, 2111, '\P{	_Is_Samr}', "");
Expect(0, 2111, '\P{^	_Is_Samr}', "");
Error('\p{	/a/Saurashtra}');
Error('\P{	/a/Saurashtra}');
Expect(1, 43225, '\p{saurashtra}', "");
Expect(0, 43225, '\p{^saurashtra}', "");
Expect(0, 43225, '\P{saurashtra}', "");
Expect(1, 43225, '\P{^saurashtra}', "");
Expect(0, 43226, '\p{saurashtra}', "");
Expect(1, 43226, '\p{^saurashtra}', "");
Expect(1, 43226, '\P{saurashtra}', "");
Expect(0, 43226, '\P{^saurashtra}', "");
Expect(1, 43225, '\p{	_saurashtra}', "");
Expect(0, 43225, '\p{^	_saurashtra}', "");
Expect(0, 43225, '\P{	_saurashtra}', "");
Expect(1, 43225, '\P{^	_saurashtra}', "");
Expect(0, 43226, '\p{	_saurashtra}', "");
Expect(1, 43226, '\p{^	_saurashtra}', "");
Expect(1, 43226, '\P{	_saurashtra}', "");
Expect(0, 43226, '\P{^	_saurashtra}', "");
Error('\p{	/a/Is_Saurashtra}');
Error('\P{	/a/Is_Saurashtra}');
Expect(1, 43225, '\p{issaurashtra}', "");
Expect(0, 43225, '\p{^issaurashtra}', "");
Expect(0, 43225, '\P{issaurashtra}', "");
Expect(1, 43225, '\P{^issaurashtra}', "");
Expect(0, 43226, '\p{issaurashtra}', "");
Expect(1, 43226, '\p{^issaurashtra}', "");
Expect(1, 43226, '\P{issaurashtra}', "");
Expect(0, 43226, '\P{^issaurashtra}', "");
Expect(1, 43225, '\p{_ is_Saurashtra}', "");
Expect(0, 43225, '\p{^_ is_Saurashtra}', "");
Expect(0, 43225, '\P{_ is_Saurashtra}', "");
Expect(1, 43225, '\P{^_ is_Saurashtra}', "");
Expect(0, 43226, '\p{_ is_Saurashtra}', "");
Expect(1, 43226, '\p{^_ is_Saurashtra}', "");
Expect(1, 43226, '\P{_ is_Saurashtra}', "");
Expect(0, 43226, '\P{^_ is_Saurashtra}', "");
Error('\p{:= saur}');
Error('\P{:= saur}');
Expect(1, 43225, '\p{saur}', "");
Expect(0, 43225, '\p{^saur}', "");
Expect(0, 43225, '\P{saur}', "");
Expect(1, 43225, '\P{^saur}', "");
Expect(0, 43226, '\p{saur}', "");
Expect(1, 43226, '\p{^saur}', "");
Expect(1, 43226, '\P{saur}', "");
Expect(0, 43226, '\P{^saur}', "");
Expect(1, 43225, '\p{ 	Saur}', "");
Expect(0, 43225, '\p{^ 	Saur}', "");
Expect(0, 43225, '\P{ 	Saur}', "");
Expect(1, 43225, '\P{^ 	Saur}', "");
Expect(0, 43226, '\p{ 	Saur}', "");
Expect(1, 43226, '\p{^ 	Saur}', "");
Expect(1, 43226, '\P{ 	Saur}', "");
Expect(0, 43226, '\P{^ 	Saur}', "");
Error('\p{/a/is_Saur}');
Error('\P{/a/is_Saur}');
Expect(1, 43225, '\p{issaur}', "");
Expect(0, 43225, '\p{^issaur}', "");
Expect(0, 43225, '\P{issaur}', "");
Expect(1, 43225, '\P{^issaur}', "");
Expect(0, 43226, '\p{issaur}', "");
Expect(1, 43226, '\p{^issaur}', "");
Expect(1, 43226, '\P{issaur}', "");
Expect(0, 43226, '\P{^issaur}', "");
Expect(1, 43225, '\p{	IS_Saur}', "");
Expect(0, 43225, '\p{^	IS_Saur}', "");
Expect(0, 43225, '\P{	IS_Saur}', "");
Expect(1, 43225, '\P{^	IS_Saur}', "");
Expect(0, 43226, '\p{	IS_Saur}', "");
Expect(1, 43226, '\p{^	IS_Saur}', "");
Expect(1, 43226, '\P{	IS_Saur}', "");
Expect(0, 43226, '\P{^	IS_Saur}', "");
Error('\p{/a/-Separator}');
Error('\P{/a/-Separator}');
Expect(1, 12288, '\p{separator}', "");
Expect(0, 12288, '\p{^separator}', "");
Expect(0, 12288, '\P{separator}', "");
Expect(1, 12288, '\P{^separator}', "");
Expect(0, 12289, '\p{separator}', "");
Expect(1, 12289, '\p{^separator}', "");
Expect(1, 12289, '\P{separator}', "");
Expect(0, 12289, '\P{^separator}', "");
Expect(1, 12288, '\p{-	separator}', "");
Expect(0, 12288, '\p{^-	separator}', "");
Expect(0, 12288, '\P{-	separator}', "");
Expect(1, 12288, '\P{^-	separator}', "");
Expect(0, 12289, '\p{-	separator}', "");
Expect(1, 12289, '\p{^-	separator}', "");
Expect(1, 12289, '\P{-	separator}', "");
Expect(0, 12289, '\P{^-	separator}', "");
Error('\p{/a/is_SEPARATOR}');
Error('\P{/a/is_SEPARATOR}');
Expect(1, 12288, '\p{isseparator}', "");
Expect(0, 12288, '\p{^isseparator}', "");
Expect(0, 12288, '\P{isseparator}', "");
Expect(1, 12288, '\P{^isseparator}', "");
Expect(0, 12289, '\p{isseparator}', "");
Expect(1, 12289, '\p{^isseparator}', "");
Expect(1, 12289, '\P{isseparator}', "");
Expect(0, 12289, '\P{^isseparator}', "");
Expect(1, 12288, '\p{_-is_Separator}', "");
Expect(0, 12288, '\p{^_-is_Separator}', "");
Expect(0, 12288, '\P{_-is_Separator}', "");
Expect(1, 12288, '\P{^_-is_Separator}', "");
Expect(0, 12289, '\p{_-is_Separator}', "");
Expect(1, 12289, '\p{^_-is_Separator}', "");
Expect(1, 12289, '\P{_-is_Separator}', "");
Expect(0, 12289, '\P{^_-is_Separator}', "");
Error('\p{-Z/a/}');
Error('\P{-Z/a/}');
Expect(1, 12288, '\p{z}', "");
Expect(0, 12288, '\p{^z}', "");
Expect(0, 12288, '\P{z}', "");
Expect(1, 12288, '\P{^z}', "");
Expect(0, 12289, '\p{z}', "");
Expect(1, 12289, '\p{^z}', "");
Expect(1, 12289, '\P{z}', "");
Expect(0, 12289, '\P{^z}', "");
Expect(1, 12288, '\p{	Z}', "");
Expect(0, 12288, '\p{^	Z}', "");
Expect(0, 12288, '\P{	Z}', "");
Expect(1, 12288, '\P{^	Z}', "");
Expect(0, 12289, '\p{	Z}', "");
Expect(1, 12289, '\p{^	Z}', "");
Expect(1, 12289, '\P{	Z}', "");
Expect(0, 12289, '\P{^	Z}', "");
Error('\p{ 	Is_Z:=}');
Error('\P{ 	Is_Z:=}');
Expect(1, 12288, '\p{isz}', "");
Expect(0, 12288, '\p{^isz}', "");
Expect(0, 12288, '\P{isz}', "");
Expect(1, 12288, '\P{^isz}', "");
Expect(0, 12289, '\p{isz}', "");
Expect(1, 12289, '\p{^isz}', "");
Expect(1, 12289, '\P{isz}', "");
Expect(0, 12289, '\P{^isz}', "");
Expect(1, 12288, '\p{		is_Z}', "");
Expect(0, 12288, '\p{^		is_Z}', "");
Expect(0, 12288, '\P{		is_Z}', "");
Expect(1, 12288, '\P{^		is_Z}', "");
Expect(0, 12289, '\p{		is_Z}', "");
Expect(1, 12289, '\p{^		is_Z}', "");
Expect(1, 12289, '\P{		is_Z}', "");
Expect(0, 12289, '\P{^		is_Z}', "");
Error('\p{:=__SHARADA}');
Error('\P{:=__SHARADA}');
Expect(1, 70105, '\p{sharada}', "");
Expect(0, 70105, '\p{^sharada}', "");
Expect(0, 70105, '\P{sharada}', "");
Expect(1, 70105, '\P{^sharada}', "");
Expect(0, 70106, '\p{sharada}', "");
Expect(1, 70106, '\p{^sharada}', "");
Expect(1, 70106, '\P{sharada}', "");
Expect(0, 70106, '\P{^sharada}', "");
Expect(1, 70105, '\p{_	sharada}', "");
Expect(0, 70105, '\p{^_	sharada}', "");
Expect(0, 70105, '\P{_	sharada}', "");
Expect(1, 70105, '\P{^_	sharada}', "");
Expect(0, 70106, '\p{_	sharada}', "");
Expect(1, 70106, '\p{^_	sharada}', "");
Expect(1, 70106, '\P{_	sharada}', "");
Expect(0, 70106, '\P{^_	sharada}', "");
Error('\p{/a/ Is_Sharada}');
Error('\P{/a/ Is_Sharada}');
Expect(1, 70105, '\p{issharada}', "");
Expect(0, 70105, '\p{^issharada}', "");
Expect(0, 70105, '\P{issharada}', "");
Expect(1, 70105, '\P{^issharada}', "");
Expect(0, 70106, '\p{issharada}', "");
Expect(1, 70106, '\p{^issharada}', "");
Expect(1, 70106, '\P{issharada}', "");
Expect(0, 70106, '\P{^issharada}', "");
Expect(1, 70105, '\p{__IS_sharada}', "");
Expect(0, 70105, '\p{^__IS_sharada}', "");
Expect(0, 70105, '\P{__IS_sharada}', "");
Expect(1, 70105, '\P{^__IS_sharada}', "");
Expect(0, 70106, '\p{__IS_sharada}', "");
Expect(1, 70106, '\p{^__IS_sharada}', "");
Expect(1, 70106, '\P{__IS_sharada}', "");
Expect(0, 70106, '\P{^__IS_sharada}', "");
Error('\p{ /a/SHRD}');
Error('\P{ /a/SHRD}');
Expect(1, 70105, '\p{shrd}', "");
Expect(0, 70105, '\p{^shrd}', "");
Expect(0, 70105, '\P{shrd}', "");
Expect(1, 70105, '\P{^shrd}', "");
Expect(0, 70106, '\p{shrd}', "");
Expect(1, 70106, '\p{^shrd}', "");
Expect(1, 70106, '\P{shrd}', "");
Expect(0, 70106, '\P{^shrd}', "");
Expect(1, 70105, '\p{ SHRD}', "");
Expect(0, 70105, '\p{^ SHRD}', "");
Expect(0, 70105, '\P{ SHRD}', "");
Expect(1, 70105, '\P{^ SHRD}', "");
Expect(0, 70106, '\p{ SHRD}', "");
Expect(1, 70106, '\p{^ SHRD}', "");
Expect(1, 70106, '\P{ SHRD}', "");
Expect(0, 70106, '\P{^ SHRD}', "");
Error('\p{-:=Is_Shrd}');
Error('\P{-:=Is_Shrd}');
Expect(1, 70105, '\p{isshrd}', "");
Expect(0, 70105, '\p{^isshrd}', "");
Expect(0, 70105, '\P{isshrd}', "");
Expect(1, 70105, '\P{^isshrd}', "");
Expect(0, 70106, '\p{isshrd}', "");
Expect(1, 70106, '\p{^isshrd}', "");
Expect(1, 70106, '\P{isshrd}', "");
Expect(0, 70106, '\P{^isshrd}', "");
Expect(1, 70105, '\p{ -Is_Shrd}', "");
Expect(0, 70105, '\p{^ -Is_Shrd}', "");
Expect(0, 70105, '\P{ -Is_Shrd}', "");
Expect(1, 70105, '\P{^ -Is_Shrd}', "");
Expect(0, 70106, '\p{ -Is_Shrd}', "");
Expect(1, 70106, '\p{^ -Is_Shrd}', "");
Expect(1, 70106, '\P{ -Is_Shrd}', "");
Expect(0, 70106, '\P{^ -Is_Shrd}', "");
Error('\p{:=shavian}');
Error('\P{:=shavian}');
Expect(1, 66687, '\p{shavian}', "");
Expect(0, 66687, '\p{^shavian}', "");
Expect(0, 66687, '\P{shavian}', "");
Expect(1, 66687, '\P{^shavian}', "");
Expect(0, 66688, '\p{shavian}', "");
Expect(1, 66688, '\p{^shavian}', "");
Expect(1, 66688, '\P{shavian}', "");
Expect(0, 66688, '\P{^shavian}', "");
Expect(1, 66687, '\p{ -Shavian}', "");
Expect(0, 66687, '\p{^ -Shavian}', "");
Expect(0, 66687, '\P{ -Shavian}', "");
Expect(1, 66687, '\P{^ -Shavian}', "");
Expect(0, 66688, '\p{ -Shavian}', "");
Expect(1, 66688, '\p{^ -Shavian}', "");
Expect(1, 66688, '\P{ -Shavian}', "");
Expect(0, 66688, '\P{^ -Shavian}', "");
Error('\p{ IS_Shavian/a/}');
Error('\P{ IS_Shavian/a/}');
Expect(1, 66687, '\p{isshavian}', "");
Expect(0, 66687, '\p{^isshavian}', "");
Expect(0, 66687, '\P{isshavian}', "");
Expect(1, 66687, '\P{^isshavian}', "");
Expect(0, 66688, '\p{isshavian}', "");
Expect(1, 66688, '\p{^isshavian}', "");
Expect(1, 66688, '\P{isshavian}', "");
Expect(0, 66688, '\P{^isshavian}', "");
Expect(1, 66687, '\p{is_Shavian}', "");
Expect(0, 66687, '\p{^is_Shavian}', "");
Expect(0, 66687, '\P{is_Shavian}', "");
Expect(1, 66687, '\P{^is_Shavian}', "");
Expect(0, 66688, '\p{is_Shavian}', "");
Expect(1, 66688, '\p{^is_Shavian}', "");
Expect(1, 66688, '\P{is_Shavian}', "");
Expect(0, 66688, '\P{^is_Shavian}', "");
Error('\p{_-shaw:=}');
Error('\P{_-shaw:=}');
Expect(1, 66687, '\p{shaw}', "");
Expect(0, 66687, '\p{^shaw}', "");
Expect(0, 66687, '\P{shaw}', "");
Expect(1, 66687, '\P{^shaw}', "");
Expect(0, 66688, '\p{shaw}', "");
Expect(1, 66688, '\p{^shaw}', "");
Expect(1, 66688, '\P{shaw}', "");
Expect(0, 66688, '\P{^shaw}', "");
Expect(1, 66687, '\p{_SHAW}', "");
Expect(0, 66687, '\p{^_SHAW}', "");
Expect(0, 66687, '\P{_SHAW}', "");
Expect(1, 66687, '\P{^_SHAW}', "");
Expect(0, 66688, '\p{_SHAW}', "");
Expect(1, 66688, '\p{^_SHAW}', "");
Expect(1, 66688, '\P{_SHAW}', "");
Expect(0, 66688, '\P{^_SHAW}', "");
Error('\p{- is_SHAW:=}');
Error('\P{- is_SHAW:=}');
Expect(1, 66687, '\p{isshaw}', "");
Expect(0, 66687, '\p{^isshaw}', "");
Expect(0, 66687, '\P{isshaw}', "");
Expect(1, 66687, '\P{^isshaw}', "");
Expect(0, 66688, '\p{isshaw}', "");
Expect(1, 66688, '\p{^isshaw}', "");
Expect(1, 66688, '\P{isshaw}', "");
Expect(0, 66688, '\P{^isshaw}', "");
Expect(1, 66687, '\p{	 IS_Shaw}', "");
Expect(0, 66687, '\p{^	 IS_Shaw}', "");
Expect(0, 66687, '\P{	 IS_Shaw}', "");
Expect(1, 66687, '\P{^	 IS_Shaw}', "");
Expect(0, 66688, '\p{	 IS_Shaw}', "");
Expect(1, 66688, '\p{^	 IS_Shaw}', "");
Expect(1, 66688, '\P{	 IS_Shaw}', "");
Expect(0, 66688, '\P{^	 IS_Shaw}', "");
Error('\p{:= 	sinhala}');
Error('\P{:= 	sinhala}');
Expect(1, 3572, '\p{sinhala}', "");
Expect(0, 3572, '\p{^sinhala}', "");
Expect(0, 3572, '\P{sinhala}', "");
Expect(1, 3572, '\P{^sinhala}', "");
Expect(0, 3573, '\p{sinhala}', "");
Expect(1, 3573, '\p{^sinhala}', "");
Expect(1, 3573, '\P{sinhala}', "");
Expect(0, 3573, '\P{^sinhala}', "");
Error('\p{:=_ is_Sinhala}');
Error('\P{:=_ is_Sinhala}');
Expect(1, 3572, '\p{issinhala}', "");
Expect(0, 3572, '\p{^issinhala}', "");
Expect(0, 3572, '\P{issinhala}', "");
Expect(1, 3572, '\P{^issinhala}', "");
Expect(0, 3573, '\p{issinhala}', "");
Expect(1, 3573, '\p{^issinhala}', "");
Expect(1, 3573, '\P{issinhala}', "");
Expect(0, 3573, '\P{^issinhala}', "");
Expect(1, 3572, '\p{_ is_SINHALA}', "");
Expect(0, 3572, '\p{^_ is_SINHALA}', "");
Expect(0, 3572, '\P{_ is_SINHALA}', "");
Expect(1, 3572, '\P{^_ is_SINHALA}', "");
Expect(0, 3573, '\p{_ is_SINHALA}', "");
Expect(1, 3573, '\p{^_ is_SINHALA}', "");
Expect(1, 3573, '\P{_ is_SINHALA}', "");
Expect(0, 3573, '\P{^_ is_SINHALA}', "");
Error('\p{-:=SINH}');
Error('\P{-:=SINH}');
Expect(1, 3572, '\p{sinh}', "");
Expect(0, 3572, '\p{^sinh}', "");
Expect(0, 3572, '\P{sinh}', "");
Expect(1, 3572, '\P{^sinh}', "");
Expect(0, 3573, '\p{sinh}', "");
Expect(1, 3573, '\p{^sinh}', "");
Expect(1, 3573, '\P{sinh}', "");
Expect(0, 3573, '\P{^sinh}', "");
Expect(1, 3572, '\p{ SINH}', "");
Expect(0, 3572, '\p{^ SINH}', "");
Expect(0, 3572, '\P{ SINH}', "");
Expect(1, 3572, '\P{^ SINH}', "");
Expect(0, 3573, '\p{ SINH}', "");
Expect(1, 3573, '\p{^ SINH}', "");
Expect(1, 3573, '\P{ SINH}', "");
Expect(0, 3573, '\P{^ SINH}', "");
Error('\p{-:=is_Sinh}');
Error('\P{-:=is_Sinh}');
Expect(1, 3572, '\p{issinh}', "");
Expect(0, 3572, '\p{^issinh}', "");
Expect(0, 3572, '\P{issinh}', "");
Expect(1, 3572, '\P{^issinh}', "");
Expect(0, 3573, '\p{issinh}', "");
Expect(1, 3573, '\p{^issinh}', "");
Expect(1, 3573, '\P{issinh}', "");
Expect(0, 3573, '\P{^issinh}', "");
Expect(1, 3572, '\p{_	Is_Sinh}', "");
Expect(0, 3572, '\p{^_	Is_Sinh}', "");
Expect(0, 3572, '\P{_	Is_Sinh}', "");
Expect(1, 3572, '\P{^_	Is_Sinh}', "");
Expect(0, 3573, '\p{_	Is_Sinh}', "");
Expect(1, 3573, '\p{^_	Is_Sinh}', "");
Expect(1, 3573, '\P{_	Is_Sinh}', "");
Expect(0, 3573, '\P{^_	Is_Sinh}', "");
Error('\p{/a/Small_FORM_variants}');
Error('\P{/a/Small_FORM_variants}');
Expect(1, 65135, '\p{smallformvariants}', "");
Expect(0, 65135, '\p{^smallformvariants}', "");
Expect(0, 65135, '\P{smallformvariants}', "");
Expect(1, 65135, '\P{^smallformvariants}', "");
Expect(0, 65136, '\p{smallformvariants}', "");
Expect(1, 65136, '\p{^smallformvariants}', "");
Expect(1, 65136, '\P{smallformvariants}', "");
Expect(0, 65136, '\P{^smallformvariants}', "");
Expect(1, 65135, '\p{-	Small_Form_Variants}', "");
Expect(0, 65135, '\p{^-	Small_Form_Variants}', "");
Expect(0, 65135, '\P{-	Small_Form_Variants}', "");
Expect(1, 65135, '\P{^-	Small_Form_Variants}', "");
Expect(0, 65136, '\p{-	Small_Form_Variants}', "");
Expect(1, 65136, '\p{^-	Small_Form_Variants}', "");
Expect(1, 65136, '\P{-	Small_Form_Variants}', "");
Expect(0, 65136, '\P{^-	Small_Form_Variants}', "");
Error('\p{ :=is_small_Form_Variants}');
Error('\P{ :=is_small_Form_Variants}');
Expect(1, 65135, '\p{issmallformvariants}', "");
Expect(0, 65135, '\p{^issmallformvariants}', "");
Expect(0, 65135, '\P{issmallformvariants}', "");
Expect(1, 65135, '\P{^issmallformvariants}', "");
Expect(0, 65136, '\p{issmallformvariants}', "");
Expect(1, 65136, '\p{^issmallformvariants}', "");
Expect(1, 65136, '\P{issmallformvariants}', "");
Expect(0, 65136, '\P{^issmallformvariants}', "");
Expect(1, 65135, '\p{	Is_Small_Form_VARIANTS}', "");
Expect(0, 65135, '\p{^	Is_Small_Form_VARIANTS}', "");
Expect(0, 65135, '\P{	Is_Small_Form_VARIANTS}', "");
Expect(1, 65135, '\P{^	Is_Small_Form_VARIANTS}', "");
Expect(0, 65136, '\p{	Is_Small_Form_VARIANTS}', "");
Expect(1, 65136, '\p{^	Is_Small_Form_VARIANTS}', "");
Expect(1, 65136, '\P{	Is_Small_Form_VARIANTS}', "");
Expect(0, 65136, '\P{^	Is_Small_Form_VARIANTS}', "");
Error('\p{_:=IN_small_FORM_variants}');
Error('\P{_:=IN_small_FORM_variants}');
Expect(1, 65135, '\p{insmallformvariants}', "");
Expect(0, 65135, '\p{^insmallformvariants}', "");
Expect(0, 65135, '\P{insmallformvariants}', "");
Expect(1, 65135, '\P{^insmallformvariants}', "");
Expect(0, 65136, '\p{insmallformvariants}', "");
Expect(1, 65136, '\p{^insmallformvariants}', "");
Expect(1, 65136, '\P{insmallformvariants}', "");
Expect(0, 65136, '\P{^insmallformvariants}', "");
Expect(1, 65135, '\p{	-In_Small_form_VARIANTS}', "");
Expect(0, 65135, '\p{^	-In_Small_form_VARIANTS}', "");
Expect(0, 65135, '\P{	-In_Small_form_VARIANTS}', "");
Expect(1, 65135, '\P{^	-In_Small_form_VARIANTS}', "");
Expect(0, 65136, '\p{	-In_Small_form_VARIANTS}', "");
Expect(1, 65136, '\p{^	-In_Small_form_VARIANTS}', "");
Expect(1, 65136, '\P{	-In_Small_form_VARIANTS}', "");
Expect(0, 65136, '\P{^	-In_Small_form_VARIANTS}', "");
Error('\p{/a/small_Forms}');
Error('\P{/a/small_Forms}');
Expect(1, 65135, '\p{smallforms}', "");
Expect(0, 65135, '\p{^smallforms}', "");
Expect(0, 65135, '\P{smallforms}', "");
Expect(1, 65135, '\P{^smallforms}', "");
Expect(0, 65136, '\p{smallforms}', "");
Expect(1, 65136, '\p{^smallforms}', "");
Expect(1, 65136, '\P{smallforms}', "");
Expect(0, 65136, '\P{^smallforms}', "");
Expect(1, 65135, '\p{ -SMALL_forms}', "");
Expect(0, 65135, '\p{^ -SMALL_forms}', "");
Expect(0, 65135, '\P{ -SMALL_forms}', "");
Expect(1, 65135, '\P{^ -SMALL_forms}', "");
Expect(0, 65136, '\p{ -SMALL_forms}', "");
Expect(1, 65136, '\p{^ -SMALL_forms}', "");
Expect(1, 65136, '\P{ -SMALL_forms}', "");
Expect(0, 65136, '\P{^ -SMALL_forms}', "");
Error('\p{--IS_small_Forms/a/}');
Error('\P{--IS_small_Forms/a/}');
Expect(1, 65135, '\p{issmallforms}', "");
Expect(0, 65135, '\p{^issmallforms}', "");
Expect(0, 65135, '\P{issmallforms}', "");
Expect(1, 65135, '\P{^issmallforms}', "");
Expect(0, 65136, '\p{issmallforms}', "");
Expect(1, 65136, '\p{^issmallforms}', "");
Expect(1, 65136, '\P{issmallforms}', "");
Expect(0, 65136, '\P{^issmallforms}', "");
Expect(1, 65135, '\p{ -IS_small_Forms}', "");
Expect(0, 65135, '\p{^ -IS_small_Forms}', "");
Expect(0, 65135, '\P{ -IS_small_Forms}', "");
Expect(1, 65135, '\P{^ -IS_small_Forms}', "");
Expect(0, 65136, '\p{ -IS_small_Forms}', "");
Expect(1, 65136, '\p{^ -IS_small_Forms}', "");
Expect(1, 65136, '\P{ -IS_small_Forms}', "");
Expect(0, 65136, '\P{^ -IS_small_Forms}', "");
Error('\p{_/a/in_Small_FORMS}');
Error('\P{_/a/in_Small_FORMS}');
Expect(1, 65135, '\p{insmallforms}', "");
Expect(0, 65135, '\p{^insmallforms}', "");
Expect(0, 65135, '\P{insmallforms}', "");
Expect(1, 65135, '\P{^insmallforms}', "");
Expect(0, 65136, '\p{insmallforms}', "");
Expect(1, 65136, '\p{^insmallforms}', "");
Expect(1, 65136, '\P{insmallforms}', "");
Expect(0, 65136, '\P{^insmallforms}', "");
Expect(1, 65135, '\p{_-In_Small_Forms}', "");
Expect(0, 65135, '\p{^_-In_Small_Forms}', "");
Expect(0, 65135, '\P{_-In_Small_Forms}', "");
Expect(1, 65135, '\P{^_-In_Small_Forms}', "");
Expect(0, 65136, '\p{_-In_Small_Forms}', "");
Expect(1, 65136, '\p{^_-In_Small_Forms}', "");
Expect(1, 65136, '\P{_-In_Small_Forms}', "");
Expect(0, 65136, '\P{^_-In_Small_Forms}', "");
Error('\p{-sora_SOMPENG/a/}');
Error('\P{-sora_SOMPENG/a/}');
Expect(1, 69881, '\p{sorasompeng}', "");
Expect(0, 69881, '\p{^sorasompeng}', "");
Expect(0, 69881, '\P{sorasompeng}', "");
Expect(1, 69881, '\P{^sorasompeng}', "");
Expect(0, 69882, '\p{sorasompeng}', "");
Expect(1, 69882, '\p{^sorasompeng}', "");
Expect(1, 69882, '\P{sorasompeng}', "");
Expect(0, 69882, '\P{^sorasompeng}', "");
Expect(1, 69881, '\p{_sora_Sompeng}', "");
Expect(0, 69881, '\p{^_sora_Sompeng}', "");
Expect(0, 69881, '\P{_sora_Sompeng}', "");
Expect(1, 69881, '\P{^_sora_Sompeng}', "");
Expect(0, 69882, '\p{_sora_Sompeng}', "");
Expect(1, 69882, '\p{^_sora_Sompeng}', "");
Expect(1, 69882, '\P{_sora_Sompeng}', "");
Expect(0, 69882, '\P{^_sora_Sompeng}', "");
Error('\p{ :=Is_Sora_sompeng}');
Error('\P{ :=Is_Sora_sompeng}');
Expect(1, 69881, '\p{issorasompeng}', "");
Expect(0, 69881, '\p{^issorasompeng}', "");
Expect(0, 69881, '\P{issorasompeng}', "");
Expect(1, 69881, '\P{^issorasompeng}', "");
Expect(0, 69882, '\p{issorasompeng}', "");
Expect(1, 69882, '\p{^issorasompeng}', "");
Expect(1, 69882, '\P{issorasompeng}', "");
Expect(0, 69882, '\P{^issorasompeng}', "");
Expect(1, 69881, '\p{ _IS_SORA_Sompeng}', "");
Expect(0, 69881, '\p{^ _IS_SORA_Sompeng}', "");
Expect(0, 69881, '\P{ _IS_SORA_Sompeng}', "");
Expect(1, 69881, '\P{^ _IS_SORA_Sompeng}', "");
Expect(0, 69882, '\p{ _IS_SORA_Sompeng}', "");
Expect(1, 69882, '\p{^ _IS_SORA_Sompeng}', "");
Expect(1, 69882, '\P{ _IS_SORA_Sompeng}', "");
Expect(0, 69882, '\P{^ _IS_SORA_Sompeng}', "");
Error('\p{_-sora:=}');
Error('\P{_-sora:=}');
Expect(1, 69881, '\p{sora}', "");
Expect(0, 69881, '\p{^sora}', "");
Expect(0, 69881, '\P{sora}', "");
Expect(1, 69881, '\P{^sora}', "");
Expect(0, 69882, '\p{sora}', "");
Expect(1, 69882, '\p{^sora}', "");
Expect(1, 69882, '\P{sora}', "");
Expect(0, 69882, '\P{^sora}', "");
Expect(1, 69881, '\p{_-SORA}', "");
Expect(0, 69881, '\p{^_-SORA}', "");
Expect(0, 69881, '\P{_-SORA}', "");
Expect(1, 69881, '\P{^_-SORA}', "");
Expect(0, 69882, '\p{_-SORA}', "");
Expect(1, 69882, '\p{^_-SORA}', "");
Expect(1, 69882, '\P{_-SORA}', "");
Expect(0, 69882, '\P{^_-SORA}', "");
Error('\p{:=is_Sora}');
Error('\P{:=is_Sora}');
Expect(1, 69881, '\p{issora}', "");
Expect(0, 69881, '\p{^issora}', "");
Expect(0, 69881, '\P{issora}', "");
Expect(1, 69881, '\P{^issora}', "");
Expect(0, 69882, '\p{issora}', "");
Expect(1, 69882, '\p{^issora}', "");
Expect(1, 69882, '\P{issora}', "");
Expect(0, 69882, '\P{^issora}', "");
Expect(1, 69881, '\p{_ IS_Sora}', "");
Expect(0, 69881, '\p{^_ IS_Sora}', "");
Expect(0, 69881, '\P{_ IS_Sora}', "");
Expect(1, 69881, '\P{^_ IS_Sora}', "");
Expect(0, 69882, '\p{_ IS_Sora}', "");
Expect(1, 69882, '\p{^_ IS_Sora}', "");
Expect(1, 69882, '\P{_ IS_Sora}', "");
Expect(0, 69882, '\P{^_ IS_Sora}', "");
Error('\p{ /a/Space}');
Error('\P{ /a/Space}');
Expect(1, 12288, '\p{space}', "");
Expect(0, 12288, '\p{^space}', "");
Expect(0, 12288, '\P{space}', "");
Expect(1, 12288, '\P{^space}', "");
Expect(0, 12289, '\p{space}', "");
Expect(1, 12289, '\p{^space}', "");
Expect(1, 12289, '\P{space}', "");
Expect(0, 12289, '\P{^space}', "");
Expect(1, 12288, '\p{ _SPACE}', "");
Expect(0, 12288, '\p{^ _SPACE}', "");
Expect(0, 12288, '\P{ _SPACE}', "");
Expect(1, 12288, '\P{^ _SPACE}', "");
Expect(0, 12289, '\p{ _SPACE}', "");
Expect(1, 12289, '\p{^ _SPACE}', "");
Expect(1, 12289, '\P{ _SPACE}', "");
Expect(0, 12289, '\P{^ _SPACE}', "");
Error('\p{ /a/xposixspace}');
Error('\P{ /a/xposixspace}');
Expect(1, 12288, '\p{xposixspace}', "");
Expect(0, 12288, '\p{^xposixspace}', "");
Expect(0, 12288, '\P{xposixspace}', "");
Expect(1, 12288, '\P{^xposixspace}', "");
Expect(0, 12289, '\p{xposixspace}', "");
Expect(1, 12289, '\p{^xposixspace}', "");
Expect(1, 12289, '\P{xposixspace}', "");
Expect(0, 12289, '\P{^xposixspace}', "");
Expect(1, 12288, '\p{_-XPosixSpace}', "");
Expect(0, 12288, '\p{^_-XPosixSpace}', "");
Expect(0, 12288, '\P{_-XPosixSpace}', "");
Expect(1, 12288, '\P{^_-XPosixSpace}', "");
Expect(0, 12289, '\p{_-XPosixSpace}', "");
Expect(1, 12289, '\p{^_-XPosixSpace}', "");
Expect(1, 12289, '\P{_-XPosixSpace}', "");
Expect(0, 12289, '\P{^_-XPosixSpace}', "");
Error('\p{/a/	 Is_space}');
Error('\P{/a/	 Is_space}');
Expect(1, 12288, '\p{isspace}', "");
Expect(0, 12288, '\p{^isspace}', "");
Expect(0, 12288, '\P{isspace}', "");
Expect(1, 12288, '\P{^isspace}', "");
Expect(0, 12289, '\p{isspace}', "");
Expect(1, 12289, '\p{^isspace}', "");
Expect(1, 12289, '\P{isspace}', "");
Expect(0, 12289, '\P{^isspace}', "");
Expect(1, 12288, '\p{__Is_Space}', "");
Expect(0, 12288, '\p{^__Is_Space}', "");
Expect(0, 12288, '\P{__Is_Space}', "");
Expect(1, 12288, '\P{^__Is_Space}', "");
Expect(0, 12289, '\p{__Is_Space}', "");
Expect(1, 12289, '\p{^__Is_Space}', "");
Expect(1, 12289, '\P{__Is_Space}', "");
Expect(0, 12289, '\P{^__Is_Space}', "");
Error('\p{ _is_XPosixSpace:=}');
Error('\P{ _is_XPosixSpace:=}');
Expect(1, 12288, '\p{isxposixspace}', "");
Expect(0, 12288, '\p{^isxposixspace}', "");
Expect(0, 12288, '\P{isxposixspace}', "");
Expect(1, 12288, '\P{^isxposixspace}', "");
Expect(0, 12289, '\p{isxposixspace}', "");
Expect(1, 12289, '\p{^isxposixspace}', "");
Expect(1, 12289, '\P{isxposixspace}', "");
Expect(0, 12289, '\P{^isxposixspace}', "");
Expect(1, 12288, '\p{-is_XPosixSpace}', "");
Expect(0, 12288, '\p{^-is_XPosixSpace}', "");
Expect(0, 12288, '\P{-is_XPosixSpace}', "");
Expect(1, 12288, '\P{^-is_XPosixSpace}', "");
Expect(0, 12289, '\p{-is_XPosixSpace}', "");
Expect(1, 12289, '\p{^-is_XPosixSpace}', "");
Expect(1, 12289, '\P{-is_XPosixSpace}', "");
Expect(0, 12289, '\P{^-is_XPosixSpace}', "");
Error('\p{:=_SPACE_SEPARATOR}');
Error('\P{:=_SPACE_SEPARATOR}');
Expect(1, 12288, '\p{spaceseparator}', "");
Expect(0, 12288, '\p{^spaceseparator}', "");
Expect(0, 12288, '\P{spaceseparator}', "");
Expect(1, 12288, '\P{^spaceseparator}', "");
Expect(0, 12289, '\p{spaceseparator}', "");
Expect(1, 12289, '\p{^spaceseparator}', "");
Expect(1, 12289, '\P{spaceseparator}', "");
Expect(0, 12289, '\P{^spaceseparator}', "");
Expect(1, 12288, '\p{- Space_separator}', "");
Expect(0, 12288, '\p{^- Space_separator}', "");
Expect(0, 12288, '\P{- Space_separator}', "");
Expect(1, 12288, '\P{^- Space_separator}', "");
Expect(0, 12289, '\p{- Space_separator}', "");
Expect(1, 12289, '\p{^- Space_separator}', "");
Expect(1, 12289, '\P{- Space_separator}', "");
Expect(0, 12289, '\P{^- Space_separator}', "");
Error('\p{	_Is_Space_SEPARATOR:=}');
Error('\P{	_Is_Space_SEPARATOR:=}');
Expect(1, 12288, '\p{isspaceseparator}', "");
Expect(0, 12288, '\p{^isspaceseparator}', "");
Expect(0, 12288, '\P{isspaceseparator}', "");
Expect(1, 12288, '\P{^isspaceseparator}', "");
Expect(0, 12289, '\p{isspaceseparator}', "");
Expect(1, 12289, '\p{^isspaceseparator}', "");
Expect(1, 12289, '\P{isspaceseparator}', "");
Expect(0, 12289, '\P{^isspaceseparator}', "");
Expect(1, 12288, '\p{Is_Space_Separator}', "");
Expect(0, 12288, '\p{^Is_Space_Separator}', "");
Expect(0, 12288, '\P{Is_Space_Separator}', "");
Expect(1, 12288, '\P{^Is_Space_Separator}', "");
Expect(0, 12289, '\p{Is_Space_Separator}', "");
Expect(1, 12289, '\p{^Is_Space_Separator}', "");
Expect(1, 12289, '\P{Is_Space_Separator}', "");
Expect(0, 12289, '\P{^Is_Space_Separator}', "");
Error('\p{__ZS/a/}');
Error('\P{__ZS/a/}');
Expect(1, 12288, '\p{zs}', "");
Expect(0, 12288, '\p{^zs}', "");
Expect(0, 12288, '\P{zs}', "");
Expect(1, 12288, '\P{^zs}', "");
Expect(0, 12289, '\p{zs}', "");
Expect(1, 12289, '\p{^zs}', "");
Expect(1, 12289, '\P{zs}', "");
Expect(0, 12289, '\P{^zs}', "");
Expect(1, 12288, '\p{	zs}', "");
Expect(0, 12288, '\p{^	zs}', "");
Expect(0, 12288, '\P{	zs}', "");
Expect(1, 12288, '\P{^	zs}', "");
Expect(0, 12289, '\p{	zs}', "");
Expect(1, 12289, '\p{^	zs}', "");
Expect(1, 12289, '\P{	zs}', "");
Expect(0, 12289, '\P{^	zs}', "");
Error('\p{:=		IS_zs}');
Error('\P{:=		IS_zs}');
Expect(1, 12288, '\p{iszs}', "");
Expect(0, 12288, '\p{^iszs}', "");
Expect(0, 12288, '\P{iszs}', "");
Expect(1, 12288, '\P{^iszs}', "");
Expect(0, 12289, '\p{iszs}', "");
Expect(1, 12289, '\p{^iszs}', "");
Expect(1, 12289, '\P{iszs}', "");
Expect(0, 12289, '\P{^iszs}', "");
Expect(1, 12288, '\p{-_is_ZS}', "");
Expect(0, 12288, '\p{^-_is_ZS}', "");
Expect(0, 12288, '\P{-_is_ZS}', "");
Expect(1, 12288, '\P{^-_is_ZS}', "");
Expect(0, 12289, '\p{-_is_ZS}', "");
Expect(1, 12289, '\p{^-_is_ZS}', "");
Expect(1, 12289, '\P{-_is_ZS}', "");
Expect(0, 12289, '\P{^-_is_ZS}', "");
Error('\p{/a/spacing_mark}');
Error('\P{/a/spacing_mark}');
Expect(1, 119154, '\p{spacingmark}', "");
Expect(0, 119154, '\p{^spacingmark}', "");
Expect(0, 119154, '\P{spacingmark}', "");
Expect(1, 119154, '\P{^spacingmark}', "");
Expect(0, 119155, '\p{spacingmark}', "");
Expect(1, 119155, '\p{^spacingmark}', "");
Expect(1, 119155, '\P{spacingmark}', "");
Expect(0, 119155, '\P{^spacingmark}', "");
Expect(1, 119154, '\p{		Spacing_Mark}', "");
Expect(0, 119154, '\p{^		Spacing_Mark}', "");
Expect(0, 119154, '\P{		Spacing_Mark}', "");
Expect(1, 119154, '\P{^		Spacing_Mark}', "");
Expect(0, 119155, '\p{		Spacing_Mark}', "");
Expect(1, 119155, '\p{^		Spacing_Mark}', "");
Expect(1, 119155, '\P{		Spacing_Mark}', "");
Expect(0, 119155, '\P{^		Spacing_Mark}', "");
Error('\p{:=Is_Spacing_Mark}');
Error('\P{:=Is_Spacing_Mark}');
Expect(1, 119154, '\p{isspacingmark}', "");
Expect(0, 119154, '\p{^isspacingmark}', "");
Expect(0, 119154, '\P{isspacingmark}', "");
Expect(1, 119154, '\P{^isspacingmark}', "");
Expect(0, 119155, '\p{isspacingmark}', "");
Expect(1, 119155, '\p{^isspacingmark}', "");
Expect(1, 119155, '\P{isspacingmark}', "");
Expect(0, 119155, '\P{^isspacingmark}', "");
Expect(1, 119154, '\p{ _Is_Spacing_MARK}', "");
Expect(0, 119154, '\p{^ _Is_Spacing_MARK}', "");
Expect(0, 119154, '\P{ _Is_Spacing_MARK}', "");
Expect(1, 119154, '\P{^ _Is_Spacing_MARK}', "");
Expect(0, 119155, '\p{ _Is_Spacing_MARK}', "");
Expect(1, 119155, '\p{^ _Is_Spacing_MARK}', "");
Expect(1, 119155, '\P{ _Is_Spacing_MARK}', "");
Expect(0, 119155, '\P{^ _Is_Spacing_MARK}', "");
Error('\p{:=_MC}');
Error('\P{:=_MC}');
Expect(1, 119154, '\p{mc}', "");
Expect(0, 119154, '\p{^mc}', "");
Expect(0, 119154, '\P{mc}', "");
Expect(1, 119154, '\P{^mc}', "");
Expect(0, 119155, '\p{mc}', "");
Expect(1, 119155, '\p{^mc}', "");
Expect(1, 119155, '\P{mc}', "");
Expect(0, 119155, '\P{^mc}', "");
Expect(1, 119154, '\p{_-Mc}', "");
Expect(0, 119154, '\p{^_-Mc}', "");
Expect(0, 119154, '\P{_-Mc}', "");
Expect(1, 119154, '\P{^_-Mc}', "");
Expect(0, 119155, '\p{_-Mc}', "");
Expect(1, 119155, '\p{^_-Mc}', "");
Expect(1, 119155, '\P{_-Mc}', "");
Expect(0, 119155, '\P{^_-Mc}', "");
Error('\p{:= -IS_Mc}');
Error('\P{:= -IS_Mc}');
Expect(1, 119154, '\p{ismc}', "");
Expect(0, 119154, '\p{^ismc}', "");
Expect(0, 119154, '\P{ismc}', "");
Expect(1, 119154, '\P{^ismc}', "");
Expect(0, 119155, '\p{ismc}', "");
Expect(1, 119155, '\p{^ismc}', "");
Expect(1, 119155, '\P{ismc}', "");
Expect(0, 119155, '\P{^ismc}', "");
Expect(1, 119154, '\p{ is_MC}', "");
Expect(0, 119154, '\p{^ is_MC}', "");
Expect(0, 119154, '\P{ is_MC}', "");
Expect(1, 119154, '\P{^ is_MC}', "");
Expect(0, 119155, '\p{ is_MC}', "");
Expect(1, 119155, '\p{^ is_MC}', "");
Expect(1, 119155, '\P{ is_MC}', "");
Expect(0, 119155, '\P{^ is_MC}', "");
Error('\p{/a/	_SPACING_MODIFIER_Letters}');
Error('\P{/a/	_SPACING_MODIFIER_Letters}');
Expect(1, 767, '\p{spacingmodifierletters}', "");
Expect(0, 767, '\p{^spacingmodifierletters}', "");
Expect(0, 767, '\P{spacingmodifierletters}', "");
Expect(1, 767, '\P{^spacingmodifierletters}', "");
Expect(0, 768, '\p{spacingmodifierletters}', "");
Expect(1, 768, '\p{^spacingmodifierletters}', "");
Expect(1, 768, '\P{spacingmodifierletters}', "");
Expect(0, 768, '\P{^spacingmodifierletters}', "");
Expect(1, 767, '\p{ spacing_modifier_Letters}', "");
Expect(0, 767, '\p{^ spacing_modifier_Letters}', "");
Expect(0, 767, '\P{ spacing_modifier_Letters}', "");
Expect(1, 767, '\P{^ spacing_modifier_Letters}', "");
Expect(0, 768, '\p{ spacing_modifier_Letters}', "");
Expect(1, 768, '\p{^ spacing_modifier_Letters}', "");
Expect(1, 768, '\P{ spacing_modifier_Letters}', "");
Expect(0, 768, '\P{^ spacing_modifier_Letters}', "");
Error('\p{:=	-is_Spacing_Modifier_letters}');
Error('\P{:=	-is_Spacing_Modifier_letters}');
Expect(1, 767, '\p{isspacingmodifierletters}', "");
Expect(0, 767, '\p{^isspacingmodifierletters}', "");
Expect(0, 767, '\P{isspacingmodifierletters}', "");
Expect(1, 767, '\P{^isspacingmodifierletters}', "");
Expect(0, 768, '\p{isspacingmodifierletters}', "");
Expect(1, 768, '\p{^isspacingmodifierletters}', "");
Expect(1, 768, '\P{isspacingmodifierletters}', "");
Expect(0, 768, '\P{^isspacingmodifierletters}', "");
Expect(1, 767, '\p{- IS_SPACING_modifier_LETTERS}', "");
Expect(0, 767, '\p{^- IS_SPACING_modifier_LETTERS}', "");
Expect(0, 767, '\P{- IS_SPACING_modifier_LETTERS}', "");
Expect(1, 767, '\P{^- IS_SPACING_modifier_LETTERS}', "");
Expect(0, 768, '\p{- IS_SPACING_modifier_LETTERS}', "");
Expect(1, 768, '\p{^- IS_SPACING_modifier_LETTERS}', "");
Expect(1, 768, '\P{- IS_SPACING_modifier_LETTERS}', "");
Expect(0, 768, '\P{^- IS_SPACING_modifier_LETTERS}', "");
Error('\p{-:=in_spacing_MODIFIER_Letters}');
Error('\P{-:=in_spacing_MODIFIER_Letters}');
Expect(1, 767, '\p{inspacingmodifierletters}', "");
Expect(0, 767, '\p{^inspacingmodifierletters}', "");
Expect(0, 767, '\P{inspacingmodifierletters}', "");
Expect(1, 767, '\P{^inspacingmodifierletters}', "");
Expect(0, 768, '\p{inspacingmodifierletters}', "");
Expect(1, 768, '\p{^inspacingmodifierletters}', "");
Expect(1, 768, '\P{inspacingmodifierletters}', "");
Expect(0, 768, '\P{^inspacingmodifierletters}', "");
Expect(1, 767, '\p{  In_SPACING_Modifier_LETTERS}', "");
Expect(0, 767, '\p{^  In_SPACING_Modifier_LETTERS}', "");
Expect(0, 767, '\P{  In_SPACING_Modifier_LETTERS}', "");
Expect(1, 767, '\P{^  In_SPACING_Modifier_LETTERS}', "");
Expect(0, 768, '\p{  In_SPACING_Modifier_LETTERS}', "");
Expect(1, 768, '\p{^  In_SPACING_Modifier_LETTERS}', "");
Expect(1, 768, '\P{  In_SPACING_Modifier_LETTERS}', "");
Expect(0, 768, '\P{^  In_SPACING_Modifier_LETTERS}', "");
Error('\p{/a/ Modifier_Letters}');
Error('\P{/a/ Modifier_Letters}');
Expect(1, 767, '\p{modifierletters}', "");
Expect(0, 767, '\p{^modifierletters}', "");
Expect(0, 767, '\P{modifierletters}', "");
Expect(1, 767, '\P{^modifierletters}', "");
Expect(0, 768, '\p{modifierletters}', "");
Expect(1, 768, '\p{^modifierletters}', "");
Expect(1, 768, '\P{modifierletters}', "");
Expect(0, 768, '\P{^modifierletters}', "");
Expect(1, 767, '\p{- MODIFIER_LETTERS}', "");
Expect(0, 767, '\p{^- MODIFIER_LETTERS}', "");
Expect(0, 767, '\P{- MODIFIER_LETTERS}', "");
Expect(1, 767, '\P{^- MODIFIER_LETTERS}', "");
Expect(0, 768, '\p{- MODIFIER_LETTERS}', "");
Expect(1, 768, '\p{^- MODIFIER_LETTERS}', "");
Expect(1, 768, '\P{- MODIFIER_LETTERS}', "");
Expect(0, 768, '\P{^- MODIFIER_LETTERS}', "");
Error('\p{/a/  Is_modifier_letters}');
Error('\P{/a/  Is_modifier_letters}');
Expect(1, 767, '\p{ismodifierletters}', "");
Expect(0, 767, '\p{^ismodifierletters}', "");
Expect(0, 767, '\P{ismodifierletters}', "");
Expect(1, 767, '\P{^ismodifierletters}', "");
Expect(0, 768, '\p{ismodifierletters}', "");
Expect(1, 768, '\p{^ismodifierletters}', "");
Expect(1, 768, '\P{ismodifierletters}', "");
Expect(0, 768, '\P{^ismodifierletters}', "");
Expect(1, 767, '\p{ -Is_Modifier_letters}', "");
Expect(0, 767, '\p{^ -Is_Modifier_letters}', "");
Expect(0, 767, '\P{ -Is_Modifier_letters}', "");
Expect(1, 767, '\P{^ -Is_Modifier_letters}', "");
Expect(0, 768, '\p{ -Is_Modifier_letters}', "");
Expect(1, 768, '\p{^ -Is_Modifier_letters}', "");
Expect(1, 768, '\P{ -Is_Modifier_letters}', "");
Expect(0, 768, '\P{^ -Is_Modifier_letters}', "");
Error('\p{_ in_Modifier_LETTERS:=}');
Error('\P{_ in_Modifier_LETTERS:=}');
Expect(1, 767, '\p{inmodifierletters}', "");
Expect(0, 767, '\p{^inmodifierletters}', "");
Expect(0, 767, '\P{inmodifierletters}', "");
Expect(1, 767, '\P{^inmodifierletters}', "");
Expect(0, 768, '\p{inmodifierletters}', "");
Expect(1, 768, '\p{^inmodifierletters}', "");
Expect(1, 768, '\P{inmodifierletters}', "");
Expect(0, 768, '\P{^inmodifierletters}', "");
Expect(1, 767, '\p{	IN_Modifier_Letters}', "");
Expect(0, 767, '\p{^	IN_Modifier_Letters}', "");
Expect(0, 767, '\P{	IN_Modifier_Letters}', "");
Expect(1, 767, '\P{^	IN_Modifier_Letters}', "");
Expect(0, 768, '\p{	IN_Modifier_Letters}', "");
Expect(1, 768, '\p{^	IN_Modifier_Letters}', "");
Expect(1, 768, '\P{	IN_Modifier_Letters}', "");
Expect(0, 768, '\P{^	IN_Modifier_Letters}', "");
Error('\p{:= Specials}');
Error('\P{:= Specials}');
Expect(1, 65520, '\p{specials}', "");
Expect(0, 65520, '\p{^specials}', "");
Expect(0, 65520, '\P{specials}', "");
Expect(1, 65520, '\P{^specials}', "");
Expect(0, 65536, '\p{specials}', "");
Expect(1, 65536, '\p{^specials}', "");
Expect(1, 65536, '\P{specials}', "");
Expect(0, 65536, '\P{^specials}', "");
Expect(1, 65520, '\p{		SPECIALS}', "");
Expect(0, 65520, '\p{^		SPECIALS}', "");
Expect(0, 65520, '\P{		SPECIALS}', "");
Expect(1, 65520, '\P{^		SPECIALS}', "");
Expect(0, 65536, '\p{		SPECIALS}', "");
Expect(1, 65536, '\p{^		SPECIALS}', "");
Expect(1, 65536, '\P{		SPECIALS}', "");
Expect(0, 65536, '\P{^		SPECIALS}', "");
Error('\p{:=_ Is_specials}');
Error('\P{:=_ Is_specials}');
Expect(1, 65520, '\p{isspecials}', "");
Expect(0, 65520, '\p{^isspecials}', "");
Expect(0, 65520, '\P{isspecials}', "");
Expect(1, 65520, '\P{^isspecials}', "");
Expect(0, 65536, '\p{isspecials}', "");
Expect(1, 65536, '\p{^isspecials}', "");
Expect(1, 65536, '\P{isspecials}', "");
Expect(0, 65536, '\P{^isspecials}', "");
Expect(1, 65520, '\p{Is_specials}', "");
Expect(0, 65520, '\p{^Is_specials}', "");
Expect(0, 65520, '\P{Is_specials}', "");
Expect(1, 65520, '\P{^Is_specials}', "");
Expect(0, 65536, '\p{Is_specials}', "");
Expect(1, 65536, '\p{^Is_specials}', "");
Expect(1, 65536, '\P{Is_specials}', "");
Expect(0, 65536, '\P{^Is_specials}', "");
Error('\p{:=--IN_specials}');
Error('\P{:=--IN_specials}');
Expect(1, 65520, '\p{inspecials}', "");
Expect(0, 65520, '\p{^inspecials}', "");
Expect(0, 65520, '\P{inspecials}', "");
Expect(1, 65520, '\P{^inspecials}', "");
Expect(0, 65536, '\p{inspecials}', "");
Expect(1, 65536, '\p{^inspecials}', "");
Expect(1, 65536, '\P{inspecials}', "");
Expect(0, 65536, '\P{^inspecials}', "");
Expect(1, 65520, '\p{In_specials}', "");
Expect(0, 65520, '\p{^In_specials}', "");
Expect(0, 65520, '\P{In_specials}', "");
Expect(1, 65520, '\P{^In_specials}', "");
Expect(0, 65536, '\p{In_specials}', "");
Expect(1, 65536, '\p{^In_specials}', "");
Expect(1, 65536, '\P{In_specials}', "");
Expect(0, 65536, '\P{^In_specials}', "");
Error('\p{-	SUNDANESE/a/}');
Error('\P{-	SUNDANESE/a/}');
Expect(1, 7367, '\p{sundanese}', "");
Expect(0, 7367, '\p{^sundanese}', "");
Expect(0, 7367, '\P{sundanese}', "");
Expect(1, 7367, '\P{^sundanese}', "");
Expect(0, 7368, '\p{sundanese}', "");
Expect(1, 7368, '\p{^sundanese}', "");
Expect(1, 7368, '\P{sundanese}', "");
Expect(0, 7368, '\P{^sundanese}', "");
Expect(1, 7367, '\p{_-SUNDANESE}', "");
Expect(0, 7367, '\p{^_-SUNDANESE}', "");
Expect(0, 7367, '\P{_-SUNDANESE}', "");
Expect(1, 7367, '\P{^_-SUNDANESE}', "");
Expect(0, 7368, '\p{_-SUNDANESE}', "");
Expect(1, 7368, '\p{^_-SUNDANESE}', "");
Expect(1, 7368, '\P{_-SUNDANESE}', "");
Expect(0, 7368, '\P{^_-SUNDANESE}', "");
Error('\p{__Is_Sundanese:=}');
Error('\P{__Is_Sundanese:=}');
Expect(1, 7367, '\p{issundanese}', "");
Expect(0, 7367, '\p{^issundanese}', "");
Expect(0, 7367, '\P{issundanese}', "");
Expect(1, 7367, '\P{^issundanese}', "");
Expect(0, 7368, '\p{issundanese}', "");
Expect(1, 7368, '\p{^issundanese}', "");
Expect(1, 7368, '\P{issundanese}', "");
Expect(0, 7368, '\P{^issundanese}', "");
Expect(1, 7367, '\p{	_is_Sundanese}', "");
Expect(0, 7367, '\p{^	_is_Sundanese}', "");
Expect(0, 7367, '\P{	_is_Sundanese}', "");
Expect(1, 7367, '\P{^	_is_Sundanese}', "");
Expect(0, 7368, '\p{	_is_Sundanese}', "");
Expect(1, 7368, '\p{^	_is_Sundanese}', "");
Expect(1, 7368, '\P{	_is_Sundanese}', "");
Expect(0, 7368, '\P{^	_is_Sundanese}', "");
Error('\p{/a/_ SUND}');
Error('\P{/a/_ SUND}');
Expect(1, 7367, '\p{sund}', "");
Expect(0, 7367, '\p{^sund}', "");
Expect(0, 7367, '\P{sund}', "");
Expect(1, 7367, '\P{^sund}', "");
Expect(0, 7368, '\p{sund}', "");
Expect(1, 7368, '\p{^sund}', "");
Expect(1, 7368, '\P{sund}', "");
Expect(0, 7368, '\P{^sund}', "");
Expect(1, 7367, '\p{-_SUND}', "");
Expect(0, 7367, '\p{^-_SUND}', "");
Expect(0, 7367, '\P{-_SUND}', "");
Expect(1, 7367, '\P{^-_SUND}', "");
Expect(0, 7368, '\p{-_SUND}', "");
Expect(1, 7368, '\p{^-_SUND}', "");
Expect(1, 7368, '\P{-_SUND}', "");
Expect(0, 7368, '\P{^-_SUND}', "");
Error('\p{:=  is_SUND}');
Error('\P{:=  is_SUND}');
Expect(1, 7367, '\p{issund}', "");
Expect(0, 7367, '\p{^issund}', "");
Expect(0, 7367, '\P{issund}', "");
Expect(1, 7367, '\P{^issund}', "");
Expect(0, 7368, '\p{issund}', "");
Expect(1, 7368, '\p{^issund}', "");
Expect(1, 7368, '\P{issund}', "");
Expect(0, 7368, '\P{^issund}', "");
Expect(1, 7367, '\p{ Is_Sund}', "");
Expect(0, 7367, '\p{^ Is_Sund}', "");
Expect(0, 7367, '\P{ Is_Sund}', "");
Expect(1, 7367, '\P{^ Is_Sund}', "");
Expect(0, 7368, '\p{ Is_Sund}', "");
Expect(1, 7368, '\p{^ Is_Sund}', "");
Expect(1, 7368, '\P{ Is_Sund}', "");
Expect(0, 7368, '\P{^ Is_Sund}', "");
Error('\p{_ Sundanese_Supplement/a/}');
Error('\P{_ Sundanese_Supplement/a/}');
Expect(1, 7375, '\p{sundanesesupplement}', "");
Expect(0, 7375, '\p{^sundanesesupplement}', "");
Expect(0, 7375, '\P{sundanesesupplement}', "");
Expect(1, 7375, '\P{^sundanesesupplement}', "");
Expect(0, 7376, '\p{sundanesesupplement}', "");
Expect(1, 7376, '\p{^sundanesesupplement}', "");
Expect(1, 7376, '\P{sundanesesupplement}', "");
Expect(0, 7376, '\P{^sundanesesupplement}', "");
Expect(1, 7375, '\p{-_SUNDANESE_Supplement}', "");
Expect(0, 7375, '\p{^-_SUNDANESE_Supplement}', "");
Expect(0, 7375, '\P{-_SUNDANESE_Supplement}', "");
Expect(1, 7375, '\P{^-_SUNDANESE_Supplement}', "");
Expect(0, 7376, '\p{-_SUNDANESE_Supplement}', "");
Expect(1, 7376, '\p{^-_SUNDANESE_Supplement}', "");
Expect(1, 7376, '\P{-_SUNDANESE_Supplement}', "");
Expect(0, 7376, '\P{^-_SUNDANESE_Supplement}', "");
Error('\p{_/a/IS_SUNDANESE_Supplement}');
Error('\P{_/a/IS_SUNDANESE_Supplement}');
Expect(1, 7375, '\p{issundanesesupplement}', "");
Expect(0, 7375, '\p{^issundanesesupplement}', "");
Expect(0, 7375, '\P{issundanesesupplement}', "");
Expect(1, 7375, '\P{^issundanesesupplement}', "");
Expect(0, 7376, '\p{issundanesesupplement}', "");
Expect(1, 7376, '\p{^issundanesesupplement}', "");
Expect(1, 7376, '\P{issundanesesupplement}', "");
Expect(0, 7376, '\P{^issundanesesupplement}', "");
Expect(1, 7375, '\p{_Is_SUNDANESE_Supplement}', "");
Expect(0, 7375, '\p{^_Is_SUNDANESE_Supplement}', "");
Expect(0, 7375, '\P{_Is_SUNDANESE_Supplement}', "");
Expect(1, 7375, '\P{^_Is_SUNDANESE_Supplement}', "");
Expect(0, 7376, '\p{_Is_SUNDANESE_Supplement}', "");
Expect(1, 7376, '\p{^_Is_SUNDANESE_Supplement}', "");
Expect(1, 7376, '\P{_Is_SUNDANESE_Supplement}', "");
Expect(0, 7376, '\P{^_Is_SUNDANESE_Supplement}', "");
Error('\p{	:=In_sundanese_supplement}');
Error('\P{	:=In_sundanese_supplement}');
Expect(1, 7375, '\p{insundanesesupplement}', "");
Expect(0, 7375, '\p{^insundanesesupplement}', "");
Expect(0, 7375, '\P{insundanesesupplement}', "");
Expect(1, 7375, '\P{^insundanesesupplement}', "");
Expect(0, 7376, '\p{insundanesesupplement}', "");
Expect(1, 7376, '\p{^insundanesesupplement}', "");
Expect(1, 7376, '\P{insundanesesupplement}', "");
Expect(0, 7376, '\P{^insundanesesupplement}', "");
Expect(1, 7375, '\p{--in_SUNDANESE_supplement}', "");
Expect(0, 7375, '\p{^--in_SUNDANESE_supplement}', "");
Expect(0, 7375, '\P{--in_SUNDANESE_supplement}', "");
Expect(1, 7375, '\P{^--in_SUNDANESE_supplement}', "");
Expect(0, 7376, '\p{--in_SUNDANESE_supplement}', "");
Expect(1, 7376, '\p{^--in_SUNDANESE_supplement}', "");
Expect(1, 7376, '\P{--in_SUNDANESE_supplement}', "");
Expect(0, 7376, '\P{^--in_SUNDANESE_supplement}', "");
Error('\p{-/a/SUNDANESE_Sup}');
Error('\P{-/a/SUNDANESE_Sup}');
Expect(1, 7375, '\p{sundanesesup}', "");
Expect(0, 7375, '\p{^sundanesesup}', "");
Expect(0, 7375, '\P{sundanesesup}', "");
Expect(1, 7375, '\P{^sundanesesup}', "");
Expect(0, 7376, '\p{sundanesesup}', "");
Expect(1, 7376, '\p{^sundanesesup}', "");
Expect(1, 7376, '\P{sundanesesup}', "");
Expect(0, 7376, '\P{^sundanesesup}', "");
Expect(1, 7375, '\p{-sundanese_SUP}', "");
Expect(0, 7375, '\p{^-sundanese_SUP}', "");
Expect(0, 7375, '\P{-sundanese_SUP}', "");
Expect(1, 7375, '\P{^-sundanese_SUP}', "");
Expect(0, 7376, '\p{-sundanese_SUP}', "");
Expect(1, 7376, '\p{^-sundanese_SUP}', "");
Expect(1, 7376, '\P{-sundanese_SUP}', "");
Expect(0, 7376, '\P{^-sundanese_SUP}', "");
Error('\p{:=_	Is_Sundanese_Sup}');
Error('\P{:=_	Is_Sundanese_Sup}');
Expect(1, 7375, '\p{issundanesesup}', "");
Expect(0, 7375, '\p{^issundanesesup}', "");
Expect(0, 7375, '\P{issundanesesup}', "");
Expect(1, 7375, '\P{^issundanesesup}', "");
Expect(0, 7376, '\p{issundanesesup}', "");
Expect(1, 7376, '\p{^issundanesesup}', "");
Expect(1, 7376, '\P{issundanesesup}', "");
Expect(0, 7376, '\P{^issundanesesup}', "");
Expect(1, 7375, '\p{_	Is_SUNDANESE_SUP}', "");
Expect(0, 7375, '\p{^_	Is_SUNDANESE_SUP}', "");
Expect(0, 7375, '\P{_	Is_SUNDANESE_SUP}', "");
Expect(1, 7375, '\P{^_	Is_SUNDANESE_SUP}', "");
Expect(0, 7376, '\p{_	Is_SUNDANESE_SUP}', "");
Expect(1, 7376, '\p{^_	Is_SUNDANESE_SUP}', "");
Expect(1, 7376, '\P{_	Is_SUNDANESE_SUP}', "");
Expect(0, 7376, '\P{^_	Is_SUNDANESE_SUP}', "");
Error('\p{/a/-	In_sundanese_Sup}');
Error('\P{/a/-	In_sundanese_Sup}');
Expect(1, 7375, '\p{insundanesesup}', "");
Expect(0, 7375, '\p{^insundanesesup}', "");
Expect(0, 7375, '\P{insundanesesup}', "");
Expect(1, 7375, '\P{^insundanesesup}', "");
Expect(0, 7376, '\p{insundanesesup}', "");
Expect(1, 7376, '\p{^insundanesesup}', "");
Expect(1, 7376, '\P{insundanesesup}', "");
Expect(0, 7376, '\P{^insundanesesup}', "");
Expect(1, 7375, '\p{ -In_sundanese_sup}', "");
Expect(0, 7375, '\p{^ -In_sundanese_sup}', "");
Expect(0, 7375, '\P{ -In_sundanese_sup}', "");
Expect(1, 7375, '\P{^ -In_sundanese_sup}', "");
Expect(0, 7376, '\p{ -In_sundanese_sup}', "");
Expect(1, 7376, '\p{^ -In_sundanese_sup}', "");
Expect(1, 7376, '\P{ -In_sundanese_sup}', "");
Expect(0, 7376, '\P{^ -In_sundanese_sup}', "");
Error('\p{	:=SUPERSCRIPTS_And_Subscripts}');
Error('\P{	:=SUPERSCRIPTS_And_Subscripts}');
Expect(1, 8351, '\p{superscriptsandsubscripts}', "");
Expect(0, 8351, '\p{^superscriptsandsubscripts}', "");
Expect(0, 8351, '\P{superscriptsandsubscripts}', "");
Expect(1, 8351, '\P{^superscriptsandsubscripts}', "");
Expect(0, 8352, '\p{superscriptsandsubscripts}', "");
Expect(1, 8352, '\p{^superscriptsandsubscripts}', "");
Expect(1, 8352, '\P{superscriptsandsubscripts}', "");
Expect(0, 8352, '\P{^superscriptsandsubscripts}', "");
Expect(1, 8351, '\p{ SUPERSCRIPTS_And_subscripts}', "");
Expect(0, 8351, '\p{^ SUPERSCRIPTS_And_subscripts}', "");
Expect(0, 8351, '\P{ SUPERSCRIPTS_And_subscripts}', "");
Expect(1, 8351, '\P{^ SUPERSCRIPTS_And_subscripts}', "");
Expect(0, 8352, '\p{ SUPERSCRIPTS_And_subscripts}', "");
Expect(1, 8352, '\p{^ SUPERSCRIPTS_And_subscripts}', "");
Expect(1, 8352, '\P{ SUPERSCRIPTS_And_subscripts}', "");
Expect(0, 8352, '\P{^ SUPERSCRIPTS_And_subscripts}', "");
Error('\p{/a/-Is_Superscripts_AND_subscripts}');
Error('\P{/a/-Is_Superscripts_AND_subscripts}');
Expect(1, 8351, '\p{issuperscriptsandsubscripts}', "");
Expect(0, 8351, '\p{^issuperscriptsandsubscripts}', "");
Expect(0, 8351, '\P{issuperscriptsandsubscripts}', "");
Expect(1, 8351, '\P{^issuperscriptsandsubscripts}', "");
Expect(0, 8352, '\p{issuperscriptsandsubscripts}', "");
Expect(1, 8352, '\p{^issuperscriptsandsubscripts}', "");
Expect(1, 8352, '\P{issuperscriptsandsubscripts}', "");
Expect(0, 8352, '\P{^issuperscriptsandsubscripts}', "");
Expect(1, 8351, '\p{ 	IS_Superscripts_And_subscripts}', "");
Expect(0, 8351, '\p{^ 	IS_Superscripts_And_subscripts}', "");
Expect(0, 8351, '\P{ 	IS_Superscripts_And_subscripts}', "");
Expect(1, 8351, '\P{^ 	IS_Superscripts_And_subscripts}', "");
Expect(0, 8352, '\p{ 	IS_Superscripts_And_subscripts}', "");
Expect(1, 8352, '\p{^ 	IS_Superscripts_And_subscripts}', "");
Expect(1, 8352, '\P{ 	IS_Superscripts_And_subscripts}', "");
Expect(0, 8352, '\P{^ 	IS_Superscripts_And_subscripts}', "");
Error('\p{-/a/In_SUPERSCRIPTS_and_SUBSCRIPTS}');
Error('\P{-/a/In_SUPERSCRIPTS_and_SUBSCRIPTS}');
Expect(1, 8351, '\p{insuperscriptsandsubscripts}', "");
Expect(0, 8351, '\p{^insuperscriptsandsubscripts}', "");
Expect(0, 8351, '\P{insuperscriptsandsubscripts}', "");
Expect(1, 8351, '\P{^insuperscriptsandsubscripts}', "");
Expect(0, 8352, '\p{insuperscriptsandsubscripts}', "");
Expect(1, 8352, '\p{^insuperscriptsandsubscripts}', "");
Expect(1, 8352, '\P{insuperscriptsandsubscripts}', "");
Expect(0, 8352, '\P{^insuperscriptsandsubscripts}', "");
Expect(1, 8351, '\p{	In_Superscripts_And_Subscripts}', "");
Expect(0, 8351, '\p{^	In_Superscripts_And_Subscripts}', "");
Expect(0, 8351, '\P{	In_Superscripts_And_Subscripts}', "");
Expect(1, 8351, '\P{^	In_Superscripts_And_Subscripts}', "");
Expect(0, 8352, '\p{	In_Superscripts_And_Subscripts}', "");
Expect(1, 8352, '\p{^	In_Superscripts_And_Subscripts}', "");
Expect(1, 8352, '\P{	In_Superscripts_And_Subscripts}', "");
Expect(0, 8352, '\P{^	In_Superscripts_And_Subscripts}', "");
Error('\p{- super_And_Sub:=}');
Error('\P{- super_And_Sub:=}');
Expect(1, 8351, '\p{superandsub}', "");
Expect(0, 8351, '\p{^superandsub}', "");
Expect(0, 8351, '\P{superandsub}', "");
Expect(1, 8351, '\P{^superandsub}', "");
Expect(0, 8352, '\p{superandsub}', "");
Expect(1, 8352, '\p{^superandsub}', "");
Expect(1, 8352, '\P{superandsub}', "");
Expect(0, 8352, '\P{^superandsub}', "");
Expect(1, 8351, '\p{ _Super_AND_Sub}', "");
Expect(0, 8351, '\p{^ _Super_AND_Sub}', "");
Expect(0, 8351, '\P{ _Super_AND_Sub}', "");
Expect(1, 8351, '\P{^ _Super_AND_Sub}', "");
Expect(0, 8352, '\p{ _Super_AND_Sub}', "");
Expect(1, 8352, '\p{^ _Super_AND_Sub}', "");
Expect(1, 8352, '\P{ _Super_AND_Sub}', "");
Expect(0, 8352, '\P{^ _Super_AND_Sub}', "");
Error('\p{ :=is_super_and_Sub}');
Error('\P{ :=is_super_and_Sub}');
Expect(1, 8351, '\p{issuperandsub}', "");
Expect(0, 8351, '\p{^issuperandsub}', "");
Expect(0, 8351, '\P{issuperandsub}', "");
Expect(1, 8351, '\P{^issuperandsub}', "");
Expect(0, 8352, '\p{issuperandsub}', "");
Expect(1, 8352, '\p{^issuperandsub}', "");
Expect(1, 8352, '\P{issuperandsub}', "");
Expect(0, 8352, '\P{^issuperandsub}', "");
Expect(1, 8351, '\p{	-Is_super_And_SUB}', "");
Expect(0, 8351, '\p{^	-Is_super_And_SUB}', "");
Expect(0, 8351, '\P{	-Is_super_And_SUB}', "");
Expect(1, 8351, '\P{^	-Is_super_And_SUB}', "");
Expect(0, 8352, '\p{	-Is_super_And_SUB}', "");
Expect(1, 8352, '\p{^	-Is_super_And_SUB}', "");
Expect(1, 8352, '\P{	-Is_super_And_SUB}', "");
Expect(0, 8352, '\P{^	-Is_super_And_SUB}', "");
Error('\p{  In_Super_And_sub:=}');
Error('\P{  In_Super_And_sub:=}');
Expect(1, 8351, '\p{insuperandsub}', "");
Expect(0, 8351, '\p{^insuperandsub}', "");
Expect(0, 8351, '\P{insuperandsub}', "");
Expect(1, 8351, '\P{^insuperandsub}', "");
Expect(0, 8352, '\p{insuperandsub}', "");
Expect(1, 8352, '\p{^insuperandsub}', "");
Expect(1, 8352, '\P{insuperandsub}', "");
Expect(0, 8352, '\P{^insuperandsub}', "");
Expect(1, 8351, '\p{	In_super_and_Sub}', "");
Expect(0, 8351, '\p{^	In_super_and_Sub}', "");
Expect(0, 8351, '\P{	In_super_and_Sub}', "");
Expect(1, 8351, '\P{^	In_super_and_Sub}', "");
Expect(0, 8352, '\p{	In_super_and_Sub}', "");
Expect(1, 8352, '\p{^	In_super_and_Sub}', "");
Expect(1, 8352, '\P{	In_super_and_Sub}', "");
Expect(0, 8352, '\P{^	In_super_and_Sub}', "");
Error('\p{/a/	SUPPLEMENTAL_Arrows_A}');
Error('\P{/a/	SUPPLEMENTAL_Arrows_A}');
Expect(1, 10239, '\p{supplementalarrowsa}', "");
Expect(0, 10239, '\p{^supplementalarrowsa}', "");
Expect(0, 10239, '\P{supplementalarrowsa}', "");
Expect(1, 10239, '\P{^supplementalarrowsa}', "");
Expect(0, 10240, '\p{supplementalarrowsa}', "");
Expect(1, 10240, '\p{^supplementalarrowsa}', "");
Expect(1, 10240, '\P{supplementalarrowsa}', "");
Expect(0, 10240, '\P{^supplementalarrowsa}', "");
Expect(1, 10239, '\p{	supplemental_Arrows_a}', "");
Expect(0, 10239, '\p{^	supplemental_Arrows_a}', "");
Expect(0, 10239, '\P{	supplemental_Arrows_a}', "");
Expect(1, 10239, '\P{^	supplemental_Arrows_a}', "");
Expect(0, 10240, '\p{	supplemental_Arrows_a}', "");
Expect(1, 10240, '\p{^	supplemental_Arrows_a}', "");
Expect(1, 10240, '\P{	supplemental_Arrows_a}', "");
Expect(0, 10240, '\P{^	supplemental_Arrows_a}', "");
Error('\p{:=IS_Supplemental_arrows_A}');
Error('\P{:=IS_Supplemental_arrows_A}');
Expect(1, 10239, '\p{issupplementalarrowsa}', "");
Expect(0, 10239, '\p{^issupplementalarrowsa}', "");
Expect(0, 10239, '\P{issupplementalarrowsa}', "");
Expect(1, 10239, '\P{^issupplementalarrowsa}', "");
Expect(0, 10240, '\p{issupplementalarrowsa}', "");
Expect(1, 10240, '\p{^issupplementalarrowsa}', "");
Expect(1, 10240, '\P{issupplementalarrowsa}', "");
Expect(0, 10240, '\P{^issupplementalarrowsa}', "");
Expect(1, 10239, '\p{__is_Supplemental_arrows_A}', "");
Expect(0, 10239, '\p{^__is_Supplemental_arrows_A}', "");
Expect(0, 10239, '\P{__is_Supplemental_arrows_A}', "");
Expect(1, 10239, '\P{^__is_Supplemental_arrows_A}', "");
Expect(0, 10240, '\p{__is_Supplemental_arrows_A}', "");
Expect(1, 10240, '\p{^__is_Supplemental_arrows_A}', "");
Expect(1, 10240, '\P{__is_Supplemental_arrows_A}', "");
Expect(0, 10240, '\P{^__is_Supplemental_arrows_A}', "");
Error('\p{ 	in_Supplemental_arrows_A:=}');
Error('\P{ 	in_Supplemental_arrows_A:=}');
Expect(1, 10239, '\p{insupplementalarrowsa}', "");
Expect(0, 10239, '\p{^insupplementalarrowsa}', "");
Expect(0, 10239, '\P{insupplementalarrowsa}', "");
Expect(1, 10239, '\P{^insupplementalarrowsa}', "");
Expect(0, 10240, '\p{insupplementalarrowsa}', "");
Expect(1, 10240, '\p{^insupplementalarrowsa}', "");
Expect(1, 10240, '\P{insupplementalarrowsa}', "");
Expect(0, 10240, '\P{^insupplementalarrowsa}', "");
Expect(1, 10239, '\p{_ In_SUPPLEMENTAL_Arrows_A}', "");
Expect(0, 10239, '\p{^_ In_SUPPLEMENTAL_Arrows_A}', "");
Expect(0, 10239, '\P{_ In_SUPPLEMENTAL_Arrows_A}', "");
Expect(1, 10239, '\P{^_ In_SUPPLEMENTAL_Arrows_A}', "");
Expect(0, 10240, '\p{_ In_SUPPLEMENTAL_Arrows_A}', "");
Expect(1, 10240, '\p{^_ In_SUPPLEMENTAL_Arrows_A}', "");
Expect(1, 10240, '\P{_ In_SUPPLEMENTAL_Arrows_A}', "");
Expect(0, 10240, '\P{^_ In_SUPPLEMENTAL_Arrows_A}', "");
Error('\p{ Sup_arrows_a/a/}');
Error('\P{ Sup_arrows_a/a/}');
Expect(1, 10239, '\p{suparrowsa}', "");
Expect(0, 10239, '\p{^suparrowsa}', "");
Expect(0, 10239, '\P{suparrowsa}', "");
Expect(1, 10239, '\P{^suparrowsa}', "");
Expect(0, 10240, '\p{suparrowsa}', "");
Expect(1, 10240, '\p{^suparrowsa}', "");
Expect(1, 10240, '\P{suparrowsa}', "");
Expect(0, 10240, '\P{^suparrowsa}', "");
Expect(1, 10239, '\p{	sup_Arrows_A}', "");
Expect(0, 10239, '\p{^	sup_Arrows_A}', "");
Expect(0, 10239, '\P{	sup_Arrows_A}', "");
Expect(1, 10239, '\P{^	sup_Arrows_A}', "");
Expect(0, 10240, '\p{	sup_Arrows_A}', "");
Expect(1, 10240, '\p{^	sup_Arrows_A}', "");
Expect(1, 10240, '\P{	sup_Arrows_A}', "");
Expect(0, 10240, '\P{^	sup_Arrows_A}', "");
Error('\p{	/a/IS_SUP_arrows_a}');
Error('\P{	/a/IS_SUP_arrows_a}');
Expect(1, 10239, '\p{issuparrowsa}', "");
Expect(0, 10239, '\p{^issuparrowsa}', "");
Expect(0, 10239, '\P{issuparrowsa}', "");
Expect(1, 10239, '\P{^issuparrowsa}', "");
Expect(0, 10240, '\p{issuparrowsa}', "");
Expect(1, 10240, '\p{^issuparrowsa}', "");
Expect(1, 10240, '\P{issuparrowsa}', "");
Expect(0, 10240, '\P{^issuparrowsa}', "");
Expect(1, 10239, '\p{	 Is_Sup_Arrows_A}', "");
Expect(0, 10239, '\p{^	 Is_Sup_Arrows_A}', "");
Expect(0, 10239, '\P{	 Is_Sup_Arrows_A}', "");
Expect(1, 10239, '\P{^	 Is_Sup_Arrows_A}', "");
Expect(0, 10240, '\p{	 Is_Sup_Arrows_A}', "");
Expect(1, 10240, '\p{^	 Is_Sup_Arrows_A}', "");
Expect(1, 10240, '\P{	 Is_Sup_Arrows_A}', "");
Expect(0, 10240, '\P{^	 Is_Sup_Arrows_A}', "");
Error('\p{:=	 IN_Sup_ARROWS_A}');
Error('\P{:=	 IN_Sup_ARROWS_A}');
Expect(1, 10239, '\p{insuparrowsa}', "");
Expect(0, 10239, '\p{^insuparrowsa}', "");
Expect(0, 10239, '\P{insuparrowsa}', "");
Expect(1, 10239, '\P{^insuparrowsa}', "");
Expect(0, 10240, '\p{insuparrowsa}', "");
Expect(1, 10240, '\p{^insuparrowsa}', "");
Expect(1, 10240, '\P{insuparrowsa}', "");
Expect(0, 10240, '\P{^insuparrowsa}', "");
Expect(1, 10239, '\p{In_Sup_ARROWS_A}', "");
Expect(0, 10239, '\p{^In_Sup_ARROWS_A}', "");
Expect(0, 10239, '\P{In_Sup_ARROWS_A}', "");
Expect(1, 10239, '\P{^In_Sup_ARROWS_A}', "");
Expect(0, 10240, '\p{In_Sup_ARROWS_A}', "");
Expect(1, 10240, '\p{^In_Sup_ARROWS_A}', "");
Expect(1, 10240, '\P{In_Sup_ARROWS_A}', "");
Expect(0, 10240, '\P{^In_Sup_ARROWS_A}', "");
Error('\p{  SUPPLEMENTAL_ARROWS_B/a/}');
Error('\P{  SUPPLEMENTAL_ARROWS_B/a/}');
Expect(1, 10623, '\p{supplementalarrowsb}', "");
Expect(0, 10623, '\p{^supplementalarrowsb}', "");
Expect(0, 10623, '\P{supplementalarrowsb}', "");
Expect(1, 10623, '\P{^supplementalarrowsb}', "");
Expect(0, 10624, '\p{supplementalarrowsb}', "");
Expect(1, 10624, '\p{^supplementalarrowsb}', "");
Expect(1, 10624, '\P{supplementalarrowsb}', "");
Expect(0, 10624, '\P{^supplementalarrowsb}', "");
Expect(1, 10623, '\p{--Supplemental_Arrows_B}', "");
Expect(0, 10623, '\p{^--Supplemental_Arrows_B}', "");
Expect(0, 10623, '\P{--Supplemental_Arrows_B}', "");
Expect(1, 10623, '\P{^--Supplemental_Arrows_B}', "");
Expect(0, 10624, '\p{--Supplemental_Arrows_B}', "");
Expect(1, 10624, '\p{^--Supplemental_Arrows_B}', "");
Expect(1, 10624, '\P{--Supplemental_Arrows_B}', "");
Expect(0, 10624, '\P{^--Supplemental_Arrows_B}', "");
Error('\p{ /a/Is_Supplemental_arrows_b}');
Error('\P{ /a/Is_Supplemental_arrows_b}');
Expect(1, 10623, '\p{issupplementalarrowsb}', "");
Expect(0, 10623, '\p{^issupplementalarrowsb}', "");
Expect(0, 10623, '\P{issupplementalarrowsb}', "");
Expect(1, 10623, '\P{^issupplementalarrowsb}', "");
Expect(0, 10624, '\p{issupplementalarrowsb}', "");
Expect(1, 10624, '\p{^issupplementalarrowsb}', "");
Expect(1, 10624, '\P{issupplementalarrowsb}', "");
Expect(0, 10624, '\P{^issupplementalarrowsb}', "");
Expect(1, 10623, '\p{	Is_SUPPLEMENTAL_ARROWS_B}', "");
Expect(0, 10623, '\p{^	Is_SUPPLEMENTAL_ARROWS_B}', "");
Expect(0, 10623, '\P{	Is_SUPPLEMENTAL_ARROWS_B}', "");
Expect(1, 10623, '\P{^	Is_SUPPLEMENTAL_ARROWS_B}', "");
Expect(0, 10624, '\p{	Is_SUPPLEMENTAL_ARROWS_B}', "");
Expect(1, 10624, '\p{^	Is_SUPPLEMENTAL_ARROWS_B}', "");
Expect(1, 10624, '\P{	Is_SUPPLEMENTAL_ARROWS_B}', "");
Expect(0, 10624, '\P{^	Is_SUPPLEMENTAL_ARROWS_B}', "");
Error('\p{_ IN_Supplemental_Arrows_b:=}');
Error('\P{_ IN_Supplemental_Arrows_b:=}');
Expect(1, 10623, '\p{insupplementalarrowsb}', "");
Expect(0, 10623, '\p{^insupplementalarrowsb}', "");
Expect(0, 10623, '\P{insupplementalarrowsb}', "");
Expect(1, 10623, '\P{^insupplementalarrowsb}', "");
Expect(0, 10624, '\p{insupplementalarrowsb}', "");
Expect(1, 10624, '\p{^insupplementalarrowsb}', "");
Expect(1, 10624, '\P{insupplementalarrowsb}', "");
Expect(0, 10624, '\P{^insupplementalarrowsb}', "");
Expect(1, 10623, '\p{  IN_Supplemental_ARROWS_b}', "");
Expect(0, 10623, '\p{^  IN_Supplemental_ARROWS_b}', "");
Expect(0, 10623, '\P{  IN_Supplemental_ARROWS_b}', "");
Expect(1, 10623, '\P{^  IN_Supplemental_ARROWS_b}', "");
Expect(0, 10624, '\p{  IN_Supplemental_ARROWS_b}', "");
Expect(1, 10624, '\p{^  IN_Supplemental_ARROWS_b}', "");
Expect(1, 10624, '\P{  IN_Supplemental_ARROWS_b}', "");
Expect(0, 10624, '\P{^  IN_Supplemental_ARROWS_b}', "");
Error('\p{:=-sup_arrows_B}');
Error('\P{:=-sup_arrows_B}');
Expect(1, 10623, '\p{suparrowsb}', "");
Expect(0, 10623, '\p{^suparrowsb}', "");
Expect(0, 10623, '\P{suparrowsb}', "");
Expect(1, 10623, '\P{^suparrowsb}', "");
Expect(0, 10624, '\p{suparrowsb}', "");
Expect(1, 10624, '\p{^suparrowsb}', "");
Expect(1, 10624, '\P{suparrowsb}', "");
Expect(0, 10624, '\P{^suparrowsb}', "");
Expect(1, 10623, '\p{	 Sup_ARROWS_B}', "");
Expect(0, 10623, '\p{^	 Sup_ARROWS_B}', "");
Expect(0, 10623, '\P{	 Sup_ARROWS_B}', "");
Expect(1, 10623, '\P{^	 Sup_ARROWS_B}', "");
Expect(0, 10624, '\p{	 Sup_ARROWS_B}', "");
Expect(1, 10624, '\p{^	 Sup_ARROWS_B}', "");
Expect(1, 10624, '\P{	 Sup_ARROWS_B}', "");
Expect(0, 10624, '\P{^	 Sup_ARROWS_B}', "");
Error('\p{_is_SUP_Arrows_b/a/}');
Error('\P{_is_SUP_Arrows_b/a/}');
Expect(1, 10623, '\p{issuparrowsb}', "");
Expect(0, 10623, '\p{^issuparrowsb}', "");
Expect(0, 10623, '\P{issuparrowsb}', "");
Expect(1, 10623, '\P{^issuparrowsb}', "");
Expect(0, 10624, '\p{issuparrowsb}', "");
Expect(1, 10624, '\p{^issuparrowsb}', "");
Expect(1, 10624, '\P{issuparrowsb}', "");
Expect(0, 10624, '\P{^issuparrowsb}', "");
Expect(1, 10623, '\p{ _is_Sup_arrows_B}', "");
Expect(0, 10623, '\p{^ _is_Sup_arrows_B}', "");
Expect(0, 10623, '\P{ _is_Sup_arrows_B}', "");
Expect(1, 10623, '\P{^ _is_Sup_arrows_B}', "");
Expect(0, 10624, '\p{ _is_Sup_arrows_B}', "");
Expect(1, 10624, '\p{^ _is_Sup_arrows_B}', "");
Expect(1, 10624, '\P{ _is_Sup_arrows_B}', "");
Expect(0, 10624, '\P{^ _is_Sup_arrows_B}', "");
Error('\p{	In_Sup_Arrows_b:=}');
Error('\P{	In_Sup_Arrows_b:=}');
Expect(1, 10623, '\p{insuparrowsb}', "");
Expect(0, 10623, '\p{^insuparrowsb}', "");
Expect(0, 10623, '\P{insuparrowsb}', "");
Expect(1, 10623, '\P{^insuparrowsb}', "");
Expect(0, 10624, '\p{insuparrowsb}', "");
Expect(1, 10624, '\p{^insuparrowsb}', "");
Expect(1, 10624, '\P{insuparrowsb}', "");
Expect(0, 10624, '\P{^insuparrowsb}', "");
Expect(1, 10623, '\p{ 	In_Sup_Arrows_b}', "");
Expect(0, 10623, '\p{^ 	In_Sup_Arrows_b}', "");
Expect(0, 10623, '\P{ 	In_Sup_Arrows_b}', "");
Expect(1, 10623, '\P{^ 	In_Sup_Arrows_b}', "");
Expect(0, 10624, '\p{ 	In_Sup_Arrows_b}', "");
Expect(1, 10624, '\p{^ 	In_Sup_Arrows_b}', "");
Expect(1, 10624, '\P{ 	In_Sup_Arrows_b}', "");
Expect(0, 10624, '\P{^ 	In_Sup_Arrows_b}', "");
Error('\p{	:=Supplemental_Mathematical_OPERATORS}');
Error('\P{	:=Supplemental_Mathematical_OPERATORS}');
Expect(1, 11007, '\p{supplementalmathematicaloperators}', "");
Expect(0, 11007, '\p{^supplementalmathematicaloperators}', "");
Expect(0, 11007, '\P{supplementalmathematicaloperators}', "");
Expect(1, 11007, '\P{^supplementalmathematicaloperators}', "");
Expect(0, 11008, '\p{supplementalmathematicaloperators}', "");
Expect(1, 11008, '\p{^supplementalmathematicaloperators}', "");
Expect(1, 11008, '\P{supplementalmathematicaloperators}', "");
Expect(0, 11008, '\P{^supplementalmathematicaloperators}', "");
Expect(1, 11007, '\p{	_Supplemental_MATHEMATICAL_Operators}', "");
Expect(0, 11007, '\p{^	_Supplemental_MATHEMATICAL_Operators}', "");
Expect(0, 11007, '\P{	_Supplemental_MATHEMATICAL_Operators}', "");
Expect(1, 11007, '\P{^	_Supplemental_MATHEMATICAL_Operators}', "");
Expect(0, 11008, '\p{	_Supplemental_MATHEMATICAL_Operators}', "");
Expect(1, 11008, '\p{^	_Supplemental_MATHEMATICAL_Operators}', "");
Expect(1, 11008, '\P{	_Supplemental_MATHEMATICAL_Operators}', "");
Expect(0, 11008, '\P{^	_Supplemental_MATHEMATICAL_Operators}', "");
Error('\p{  Is_Supplemental_MATHEMATICAL_Operators/a/}');
Error('\P{  Is_Supplemental_MATHEMATICAL_Operators/a/}');
Expect(1, 11007, '\p{issupplementalmathematicaloperators}', "");
Expect(0, 11007, '\p{^issupplementalmathematicaloperators}', "");
Expect(0, 11007, '\P{issupplementalmathematicaloperators}', "");
Expect(1, 11007, '\P{^issupplementalmathematicaloperators}', "");
Expect(0, 11008, '\p{issupplementalmathematicaloperators}', "");
Expect(1, 11008, '\p{^issupplementalmathematicaloperators}', "");
Expect(1, 11008, '\P{issupplementalmathematicaloperators}', "");
Expect(0, 11008, '\P{^issupplementalmathematicaloperators}', "");
Expect(1, 11007, '\p{	Is_supplemental_Mathematical_operators}', "");
Expect(0, 11007, '\p{^	Is_supplemental_Mathematical_operators}', "");
Expect(0, 11007, '\P{	Is_supplemental_Mathematical_operators}', "");
Expect(1, 11007, '\P{^	Is_supplemental_Mathematical_operators}', "");
Expect(0, 11008, '\p{	Is_supplemental_Mathematical_operators}', "");
Expect(1, 11008, '\p{^	Is_supplemental_Mathematical_operators}', "");
Expect(1, 11008, '\P{	Is_supplemental_Mathematical_operators}', "");
Expect(0, 11008, '\P{^	Is_supplemental_Mathematical_operators}', "");
Error('\p{/a/ in_Supplemental_mathematical_Operators}');
Error('\P{/a/ in_Supplemental_mathematical_Operators}');
Expect(1, 11007, '\p{insupplementalmathematicaloperators}', "");
Expect(0, 11007, '\p{^insupplementalmathematicaloperators}', "");
Expect(0, 11007, '\P{insupplementalmathematicaloperators}', "");
Expect(1, 11007, '\P{^insupplementalmathematicaloperators}', "");
Expect(0, 11008, '\p{insupplementalmathematicaloperators}', "");
Expect(1, 11008, '\p{^insupplementalmathematicaloperators}', "");
Expect(1, 11008, '\P{insupplementalmathematicaloperators}', "");
Expect(0, 11008, '\P{^insupplementalmathematicaloperators}', "");
Expect(1, 11007, '\p{-	In_Supplemental_mathematical_operators}', "");
Expect(0, 11007, '\p{^-	In_Supplemental_mathematical_operators}', "");
Expect(0, 11007, '\P{-	In_Supplemental_mathematical_operators}', "");
Expect(1, 11007, '\P{^-	In_Supplemental_mathematical_operators}', "");
Expect(0, 11008, '\p{-	In_Supplemental_mathematical_operators}', "");
Expect(1, 11008, '\p{^-	In_Supplemental_mathematical_operators}', "");
Expect(1, 11008, '\P{-	In_Supplemental_mathematical_operators}', "");
Expect(0, 11008, '\P{^-	In_Supplemental_mathematical_operators}', "");
Error('\p{:=Sup_math_OPERATORS}');
Error('\P{:=Sup_math_OPERATORS}');
Expect(1, 11007, '\p{supmathoperators}', "");
Expect(0, 11007, '\p{^supmathoperators}', "");
Expect(0, 11007, '\P{supmathoperators}', "");
Expect(1, 11007, '\P{^supmathoperators}', "");
Expect(0, 11008, '\p{supmathoperators}', "");
Expect(1, 11008, '\p{^supmathoperators}', "");
Expect(1, 11008, '\P{supmathoperators}', "");
Expect(0, 11008, '\P{^supmathoperators}', "");
Expect(1, 11007, '\p{- Sup_MATH_Operators}', "");
Expect(0, 11007, '\p{^- Sup_MATH_Operators}', "");
Expect(0, 11007, '\P{- Sup_MATH_Operators}', "");
Expect(1, 11007, '\P{^- Sup_MATH_Operators}', "");
Expect(0, 11008, '\p{- Sup_MATH_Operators}', "");
Expect(1, 11008, '\p{^- Sup_MATH_Operators}', "");
Expect(1, 11008, '\P{- Sup_MATH_Operators}', "");
Expect(0, 11008, '\P{^- Sup_MATH_Operators}', "");
Error('\p{Is_Sup_Math_Operators/a/}');
Error('\P{Is_Sup_Math_Operators/a/}');
Expect(1, 11007, '\p{issupmathoperators}', "");
Expect(0, 11007, '\p{^issupmathoperators}', "");
Expect(0, 11007, '\P{issupmathoperators}', "");
Expect(1, 11007, '\P{^issupmathoperators}', "");
Expect(0, 11008, '\p{issupmathoperators}', "");
Expect(1, 11008, '\p{^issupmathoperators}', "");
Expect(1, 11008, '\P{issupmathoperators}', "");
Expect(0, 11008, '\P{^issupmathoperators}', "");
Expect(1, 11007, '\p{-	IS_sup_MATH_Operators}', "");
Expect(0, 11007, '\p{^-	IS_sup_MATH_Operators}', "");
Expect(0, 11007, '\P{-	IS_sup_MATH_Operators}', "");
Expect(1, 11007, '\P{^-	IS_sup_MATH_Operators}', "");
Expect(0, 11008, '\p{-	IS_sup_MATH_Operators}', "");
Expect(1, 11008, '\p{^-	IS_sup_MATH_Operators}', "");
Expect(1, 11008, '\P{-	IS_sup_MATH_Operators}', "");
Expect(0, 11008, '\P{^-	IS_sup_MATH_Operators}', "");
Error('\p{:= in_Sup_math_Operators}');
Error('\P{:= in_Sup_math_Operators}');
Expect(1, 11007, '\p{insupmathoperators}', "");
Expect(0, 11007, '\p{^insupmathoperators}', "");
Expect(0, 11007, '\P{insupmathoperators}', "");
Expect(1, 11007, '\P{^insupmathoperators}', "");
Expect(0, 11008, '\p{insupmathoperators}', "");
Expect(1, 11008, '\p{^insupmathoperators}', "");
Expect(1, 11008, '\P{insupmathoperators}', "");
Expect(0, 11008, '\P{^insupmathoperators}', "");
Expect(1, 11007, '\p{ 	IN_SUP_Math_Operators}', "");
Expect(0, 11007, '\p{^ 	IN_SUP_Math_Operators}', "");
Expect(0, 11007, '\P{ 	IN_SUP_Math_Operators}', "");
Expect(1, 11007, '\P{^ 	IN_SUP_Math_Operators}', "");
Expect(0, 11008, '\p{ 	IN_SUP_Math_Operators}', "");
Expect(1, 11008, '\p{^ 	IN_SUP_Math_Operators}', "");
Expect(1, 11008, '\P{ 	IN_SUP_Math_Operators}', "");
Expect(0, 11008, '\P{^ 	IN_SUP_Math_Operators}', "");
Error('\p{:=	supplemental_Punctuation}');
Error('\P{:=	supplemental_Punctuation}');
Expect(1, 11903, '\p{supplementalpunctuation}', "");
Expect(0, 11903, '\p{^supplementalpunctuation}', "");
Expect(0, 11903, '\P{supplementalpunctuation}', "");
Expect(1, 11903, '\P{^supplementalpunctuation}', "");
Expect(0, 11904, '\p{supplementalpunctuation}', "");
Expect(1, 11904, '\p{^supplementalpunctuation}', "");
Expect(1, 11904, '\P{supplementalpunctuation}', "");
Expect(0, 11904, '\P{^supplementalpunctuation}', "");
Expect(1, 11903, '\p{-supplemental_PUNCTUATION}', "");
Expect(0, 11903, '\p{^-supplemental_PUNCTUATION}', "");
Expect(0, 11903, '\P{-supplemental_PUNCTUATION}', "");
Expect(1, 11903, '\P{^-supplemental_PUNCTUATION}', "");
Expect(0, 11904, '\p{-supplemental_PUNCTUATION}', "");
Expect(1, 11904, '\p{^-supplemental_PUNCTUATION}', "");
Expect(1, 11904, '\P{-supplemental_PUNCTUATION}', "");
Expect(0, 11904, '\P{^-supplemental_PUNCTUATION}', "");
Error('\p{	/a/IS_Supplemental_Punctuation}');
Error('\P{	/a/IS_Supplemental_Punctuation}');
Expect(1, 11903, '\p{issupplementalpunctuation}', "");
Expect(0, 11903, '\p{^issupplementalpunctuation}', "");
Expect(0, 11903, '\P{issupplementalpunctuation}', "");
Expect(1, 11903, '\P{^issupplementalpunctuation}', "");
Expect(0, 11904, '\p{issupplementalpunctuation}', "");
Expect(1, 11904, '\p{^issupplementalpunctuation}', "");
Expect(1, 11904, '\P{issupplementalpunctuation}', "");
Expect(0, 11904, '\P{^issupplementalpunctuation}', "");
Expect(1, 11903, '\p{	-Is_Supplemental_Punctuation}', "");
Expect(0, 11903, '\p{^	-Is_Supplemental_Punctuation}', "");
Expect(0, 11903, '\P{	-Is_Supplemental_Punctuation}', "");
Expect(1, 11903, '\P{^	-Is_Supplemental_Punctuation}', "");
Expect(0, 11904, '\p{	-Is_Supplemental_Punctuation}', "");
Expect(1, 11904, '\p{^	-Is_Supplemental_Punctuation}', "");
Expect(1, 11904, '\P{	-Is_Supplemental_Punctuation}', "");
Expect(0, 11904, '\P{^	-Is_Supplemental_Punctuation}', "");
Error('\p{ :=IN_Supplemental_Punctuation}');
Error('\P{ :=IN_Supplemental_Punctuation}');
Expect(1, 11903, '\p{insupplementalpunctuation}', "");
Expect(0, 11903, '\p{^insupplementalpunctuation}', "");
Expect(0, 11903, '\P{insupplementalpunctuation}', "");
Expect(1, 11903, '\P{^insupplementalpunctuation}', "");
Expect(0, 11904, '\p{insupplementalpunctuation}', "");
Expect(1, 11904, '\p{^insupplementalpunctuation}', "");
Expect(1, 11904, '\P{insupplementalpunctuation}', "");
Expect(0, 11904, '\P{^insupplementalpunctuation}', "");
Expect(1, 11903, '\p{ -In_Supplemental_punctuation}', "");
Expect(0, 11903, '\p{^ -In_Supplemental_punctuation}', "");
Expect(0, 11903, '\P{ -In_Supplemental_punctuation}', "");
Expect(1, 11903, '\P{^ -In_Supplemental_punctuation}', "");
Expect(0, 11904, '\p{ -In_Supplemental_punctuation}', "");
Expect(1, 11904, '\p{^ -In_Supplemental_punctuation}', "");
Expect(1, 11904, '\P{ -In_Supplemental_punctuation}', "");
Expect(0, 11904, '\P{^ -In_Supplemental_punctuation}', "");
Error('\p{/a/	 Sup_punctuation}');
Error('\P{/a/	 Sup_punctuation}');
Expect(1, 11903, '\p{suppunctuation}', "");
Expect(0, 11903, '\p{^suppunctuation}', "");
Expect(0, 11903, '\P{suppunctuation}', "");
Expect(1, 11903, '\P{^suppunctuation}', "");
Expect(0, 11904, '\p{suppunctuation}', "");
Expect(1, 11904, '\p{^suppunctuation}', "");
Expect(1, 11904, '\P{suppunctuation}', "");
Expect(0, 11904, '\P{^suppunctuation}', "");
Expect(1, 11903, '\p{	-Sup_PUNCTUATION}', "");
Expect(0, 11903, '\p{^	-Sup_PUNCTUATION}', "");
Expect(0, 11903, '\P{	-Sup_PUNCTUATION}', "");
Expect(1, 11903, '\P{^	-Sup_PUNCTUATION}', "");
Expect(0, 11904, '\p{	-Sup_PUNCTUATION}', "");
Expect(1, 11904, '\p{^	-Sup_PUNCTUATION}', "");
Expect(1, 11904, '\P{	-Sup_PUNCTUATION}', "");
Expect(0, 11904, '\P{^	-Sup_PUNCTUATION}', "");
Error('\p{_:=is_sup_Punctuation}');
Error('\P{_:=is_sup_Punctuation}');
Expect(1, 11903, '\p{issuppunctuation}', "");
Expect(0, 11903, '\p{^issuppunctuation}', "");
Expect(0, 11903, '\P{issuppunctuation}', "");
Expect(1, 11903, '\P{^issuppunctuation}', "");
Expect(0, 11904, '\p{issuppunctuation}', "");
Expect(1, 11904, '\p{^issuppunctuation}', "");
Expect(1, 11904, '\P{issuppunctuation}', "");
Expect(0, 11904, '\P{^issuppunctuation}', "");
Expect(1, 11903, '\p{ 	is_SUP_Punctuation}', "");
Expect(0, 11903, '\p{^ 	is_SUP_Punctuation}', "");
Expect(0, 11903, '\P{ 	is_SUP_Punctuation}', "");
Expect(1, 11903, '\P{^ 	is_SUP_Punctuation}', "");
Expect(0, 11904, '\p{ 	is_SUP_Punctuation}', "");
Expect(1, 11904, '\p{^ 	is_SUP_Punctuation}', "");
Expect(1, 11904, '\P{ 	is_SUP_Punctuation}', "");
Expect(0, 11904, '\P{^ 	is_SUP_Punctuation}', "");
Error('\p{- In_sup_Punctuation:=}');
Error('\P{- In_sup_Punctuation:=}');
Expect(1, 11903, '\p{insuppunctuation}', "");
Expect(0, 11903, '\p{^insuppunctuation}', "");
Expect(0, 11903, '\P{insuppunctuation}', "");
Expect(1, 11903, '\P{^insuppunctuation}', "");
Expect(0, 11904, '\p{insuppunctuation}', "");
Expect(1, 11904, '\p{^insuppunctuation}', "");
Expect(1, 11904, '\P{insuppunctuation}', "");
Expect(0, 11904, '\P{^insuppunctuation}', "");
Expect(1, 11903, '\p{_	In_Sup_Punctuation}', "");
Expect(0, 11903, '\p{^_	In_Sup_Punctuation}', "");
Expect(0, 11903, '\P{_	In_Sup_Punctuation}', "");
Expect(1, 11903, '\P{^_	In_Sup_Punctuation}', "");
Expect(0, 11904, '\p{_	In_Sup_Punctuation}', "");
Expect(1, 11904, '\p{^_	In_Sup_Punctuation}', "");
Expect(1, 11904, '\P{_	In_Sup_Punctuation}', "");
Expect(0, 11904, '\P{^_	In_Sup_Punctuation}', "");
Error('\p{- Supplementary_Private_use_AREA_A/a/}');
Error('\P{- Supplementary_Private_use_AREA_A/a/}');
Expect(1, 983040, '\p{supplementaryprivateuseareaa}', "");
Expect(0, 983040, '\p{^supplementaryprivateuseareaa}', "");
Expect(0, 983040, '\P{supplementaryprivateuseareaa}', "");
Expect(1, 983040, '\P{^supplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\p{supplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\p{^supplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\P{supplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\P{^supplementaryprivateuseareaa}', "");
Expect(1, 983040, '\p{ 	Supplementary_private_USE_Area_A}', "");
Expect(0, 983040, '\p{^ 	Supplementary_private_USE_Area_A}', "");
Expect(0, 983040, '\P{ 	Supplementary_private_USE_Area_A}', "");
Expect(1, 983040, '\P{^ 	Supplementary_private_USE_Area_A}', "");
Expect(0, 1048576, '\p{ 	Supplementary_private_USE_Area_A}', "");
Expect(1, 1048576, '\p{^ 	Supplementary_private_USE_Area_A}', "");
Expect(1, 1048576, '\P{ 	Supplementary_private_USE_Area_A}', "");
Expect(0, 1048576, '\P{^ 	Supplementary_private_USE_Area_A}', "");
Error('\p{--Is_supplementary_private_Use_area_A:=}');
Error('\P{--Is_supplementary_private_Use_area_A:=}');
Expect(1, 983040, '\p{issupplementaryprivateuseareaa}', "");
Expect(0, 983040, '\p{^issupplementaryprivateuseareaa}', "");
Expect(0, 983040, '\P{issupplementaryprivateuseareaa}', "");
Expect(1, 983040, '\P{^issupplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\p{issupplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\p{^issupplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\P{issupplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\P{^issupplementaryprivateuseareaa}', "");
Expect(1, 983040, '\p{ -is_supplementary_private_Use_Area_A}', "");
Expect(0, 983040, '\p{^ -is_supplementary_private_Use_Area_A}', "");
Expect(0, 983040, '\P{ -is_supplementary_private_Use_Area_A}', "");
Expect(1, 983040, '\P{^ -is_supplementary_private_Use_Area_A}', "");
Expect(0, 1048576, '\p{ -is_supplementary_private_Use_Area_A}', "");
Expect(1, 1048576, '\p{^ -is_supplementary_private_Use_Area_A}', "");
Expect(1, 1048576, '\P{ -is_supplementary_private_Use_Area_A}', "");
Expect(0, 1048576, '\P{^ -is_supplementary_private_Use_Area_A}', "");
Error('\p{		IN_Supplementary_PRIVATE_Use_area_a/a/}');
Error('\P{		IN_Supplementary_PRIVATE_Use_area_a/a/}');
Expect(1, 983040, '\p{insupplementaryprivateuseareaa}', "");
Expect(0, 983040, '\p{^insupplementaryprivateuseareaa}', "");
Expect(0, 983040, '\P{insupplementaryprivateuseareaa}', "");
Expect(1, 983040, '\P{^insupplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\p{insupplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\p{^insupplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\P{insupplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\P{^insupplementaryprivateuseareaa}', "");
Expect(1, 983040, '\p{ -IN_supplementary_private_Use_area_A}', "");
Expect(0, 983040, '\p{^ -IN_supplementary_private_Use_area_A}', "");
Expect(0, 983040, '\P{ -IN_supplementary_private_Use_area_A}', "");
Expect(1, 983040, '\P{^ -IN_supplementary_private_Use_area_A}', "");
Expect(0, 1048576, '\p{ -IN_supplementary_private_Use_area_A}', "");
Expect(1, 1048576, '\p{^ -IN_supplementary_private_Use_area_A}', "");
Expect(1, 1048576, '\P{ -IN_supplementary_private_Use_area_A}', "");
Expect(0, 1048576, '\P{^ -IN_supplementary_private_Use_area_A}', "");
Error('\p{	_Sup_PUA_A/a/}');
Error('\P{	_Sup_PUA_A/a/}');
Expect(1, 983040, '\p{suppuaa}', "");
Expect(0, 983040, '\p{^suppuaa}', "");
Expect(0, 983040, '\P{suppuaa}', "");
Expect(1, 983040, '\P{^suppuaa}', "");
Expect(0, 1048576, '\p{suppuaa}', "");
Expect(1, 1048576, '\p{^suppuaa}', "");
Expect(1, 1048576, '\P{suppuaa}', "");
Expect(0, 1048576, '\P{^suppuaa}', "");
Expect(1, 983040, '\p{Sup_PUA_A}', "");
Expect(0, 983040, '\p{^Sup_PUA_A}', "");
Expect(0, 983040, '\P{Sup_PUA_A}', "");
Expect(1, 983040, '\P{^Sup_PUA_A}', "");
Expect(0, 1048576, '\p{Sup_PUA_A}', "");
Expect(1, 1048576, '\p{^Sup_PUA_A}', "");
Expect(1, 1048576, '\P{Sup_PUA_A}', "");
Expect(0, 1048576, '\P{^Sup_PUA_A}', "");
Error('\p{	/a/is_Sup_pua_a}');
Error('\P{	/a/is_Sup_pua_a}');
Expect(1, 983040, '\p{issuppuaa}', "");
Expect(0, 983040, '\p{^issuppuaa}', "");
Expect(0, 983040, '\P{issuppuaa}', "");
Expect(1, 983040, '\P{^issuppuaa}', "");
Expect(0, 1048576, '\p{issuppuaa}', "");
Expect(1, 1048576, '\p{^issuppuaa}', "");
Expect(1, 1048576, '\P{issuppuaa}', "");
Expect(0, 1048576, '\P{^issuppuaa}', "");
Expect(1, 983040, '\p{is_sup_pua_A}', "");
Expect(0, 983040, '\p{^is_sup_pua_A}', "");
Expect(0, 983040, '\P{is_sup_pua_A}', "");
Expect(1, 983040, '\P{^is_sup_pua_A}', "");
Expect(0, 1048576, '\p{is_sup_pua_A}', "");
Expect(1, 1048576, '\p{^is_sup_pua_A}', "");
Expect(1, 1048576, '\P{is_sup_pua_A}', "");
Expect(0, 1048576, '\P{^is_sup_pua_A}', "");
Error('\p{:=_IN_Sup_pua_A}');
Error('\P{:=_IN_Sup_pua_A}');
Expect(1, 983040, '\p{insuppuaa}', "");
Expect(0, 983040, '\p{^insuppuaa}', "");
Expect(0, 983040, '\P{insuppuaa}', "");
Expect(1, 983040, '\P{^insuppuaa}', "");
Expect(0, 1048576, '\p{insuppuaa}', "");
Expect(1, 1048576, '\p{^insuppuaa}', "");
Expect(1, 1048576, '\P{insuppuaa}', "");
Expect(0, 1048576, '\P{^insuppuaa}', "");
Expect(1, 983040, '\p{	In_Sup_pua_A}', "");
Expect(0, 983040, '\p{^	In_Sup_pua_A}', "");
Expect(0, 983040, '\P{	In_Sup_pua_A}', "");
Expect(1, 983040, '\P{^	In_Sup_pua_A}', "");
Expect(0, 1048576, '\p{	In_Sup_pua_A}', "");
Expect(1, 1048576, '\p{^	In_Sup_pua_A}', "");
Expect(1, 1048576, '\P{	In_Sup_pua_A}', "");
Expect(0, 1048576, '\P{^	In_Sup_pua_A}', "");
Error('\p{-:=SUPPLEMENTARY_private_Use_Area_B}');
Error('\P{-:=SUPPLEMENTARY_private_Use_Area_B}');
Expect(1, 1048576, '\p{supplementaryprivateuseareab}', "");
Expect(0, 1048576, '\p{^supplementaryprivateuseareab}', "");
Expect(0, 1048576, '\P{supplementaryprivateuseareab}', "");
Expect(1, 1048576, '\P{^supplementaryprivateuseareab}', "");
Expect(0, 1, '\p{supplementaryprivateuseareab}', "");
Expect(1, 1, '\p{^supplementaryprivateuseareab}', "");
Expect(1, 1, '\P{supplementaryprivateuseareab}', "");
Expect(0, 1, '\P{^supplementaryprivateuseareab}', "");
Expect(1, 1048576, '\p{-	Supplementary_PRIVATE_USE_AREA_B}', "");
Expect(0, 1048576, '\p{^-	Supplementary_PRIVATE_USE_AREA_B}', "");
Expect(0, 1048576, '\P{-	Supplementary_PRIVATE_USE_AREA_B}', "");
Expect(1, 1048576, '\P{^-	Supplementary_PRIVATE_USE_AREA_B}', "");
Expect(0, 1, '\p{-	Supplementary_PRIVATE_USE_AREA_B}', "");
Expect(1, 1, '\p{^-	Supplementary_PRIVATE_USE_AREA_B}', "");
Expect(1, 1, '\P{-	Supplementary_PRIVATE_USE_AREA_B}', "");
Expect(0, 1, '\P{^-	Supplementary_PRIVATE_USE_AREA_B}', "");
Error('\p{/a/IS_SUPPLEMENTARY_Private_use_Area_b}');
Error('\P{/a/IS_SUPPLEMENTARY_Private_use_Area_b}');
Expect(1, 1048576, '\p{issupplementaryprivateuseareab}', "");
Expect(0, 1048576, '\p{^issupplementaryprivateuseareab}', "");
Expect(0, 1048576, '\P{issupplementaryprivateuseareab}', "");
Expect(1, 1048576, '\P{^issupplementaryprivateuseareab}', "");
Expect(0, 1, '\p{issupplementaryprivateuseareab}', "");
Expect(1, 1, '\p{^issupplementaryprivateuseareab}', "");
Expect(1, 1, '\P{issupplementaryprivateuseareab}', "");
Expect(0, 1, '\P{^issupplementaryprivateuseareab}', "");
Expect(1, 1048576, '\p{is_Supplementary_private_Use_Area_B}', "");
Expect(0, 1048576, '\p{^is_Supplementary_private_Use_Area_B}', "");
Expect(0, 1048576, '\P{is_Supplementary_private_Use_Area_B}', "");
Expect(1, 1048576, '\P{^is_Supplementary_private_Use_Area_B}', "");
Expect(0, 1, '\p{is_Supplementary_private_Use_Area_B}', "");
Expect(1, 1, '\p{^is_Supplementary_private_Use_Area_B}', "");
Expect(1, 1, '\P{is_Supplementary_private_Use_Area_B}', "");
Expect(0, 1, '\P{^is_Supplementary_private_Use_Area_B}', "");
Error('\p{:=_-In_Supplementary_Private_use_Area_B}');
Error('\P{:=_-In_Supplementary_Private_use_Area_B}');
Expect(1, 1048576, '\p{insupplementaryprivateuseareab}', "");
Expect(0, 1048576, '\p{^insupplementaryprivateuseareab}', "");
Expect(0, 1048576, '\P{insupplementaryprivateuseareab}', "");
Expect(1, 1048576, '\P{^insupplementaryprivateuseareab}', "");
Expect(0, 1, '\p{insupplementaryprivateuseareab}', "");
Expect(1, 1, '\p{^insupplementaryprivateuseareab}', "");
Expect(1, 1, '\P{insupplementaryprivateuseareab}', "");
Expect(0, 1, '\P{^insupplementaryprivateuseareab}', "");
Expect(1, 1048576, '\p{-In_Supplementary_private_USE_Area_B}', "");
Expect(0, 1048576, '\p{^-In_Supplementary_private_USE_Area_B}', "");
Expect(0, 1048576, '\P{-In_Supplementary_private_USE_Area_B}', "");
Expect(1, 1048576, '\P{^-In_Supplementary_private_USE_Area_B}', "");
Expect(0, 1, '\p{-In_Supplementary_private_USE_Area_B}', "");
Expect(1, 1, '\p{^-In_Supplementary_private_USE_Area_B}', "");
Expect(1, 1, '\P{-In_Supplementary_private_USE_Area_B}', "");
Expect(0, 1, '\P{^-In_Supplementary_private_USE_Area_B}', "");
Error('\p{:=- Sup_pua_B}');
Error('\P{:=- Sup_pua_B}');
Expect(1, 1048576, '\p{suppuab}', "");
Expect(0, 1048576, '\p{^suppuab}', "");
Expect(0, 1048576, '\P{suppuab}', "");
Expect(1, 1048576, '\P{^suppuab}', "");
Expect(0, 1, '\p{suppuab}', "");
Expect(1, 1, '\p{^suppuab}', "");
Expect(1, 1, '\P{suppuab}', "");
Expect(0, 1, '\P{^suppuab}', "");
Expect(1, 1048576, '\p{_sup_PUA_B}', "");
Expect(0, 1048576, '\p{^_sup_PUA_B}', "");
Expect(0, 1048576, '\P{_sup_PUA_B}', "");
Expect(1, 1048576, '\P{^_sup_PUA_B}', "");
Expect(0, 1, '\p{_sup_PUA_B}', "");
Expect(1, 1, '\p{^_sup_PUA_B}', "");
Expect(1, 1, '\P{_sup_PUA_B}', "");
Expect(0, 1, '\P{^_sup_PUA_B}', "");
Error('\p{/a/is_sup_pua_B}');
Error('\P{/a/is_sup_pua_B}');
Expect(1, 1048576, '\p{issuppuab}', "");
Expect(0, 1048576, '\p{^issuppuab}', "");
Expect(0, 1048576, '\P{issuppuab}', "");
Expect(1, 1048576, '\P{^issuppuab}', "");
Expect(0, 1, '\p{issuppuab}', "");
Expect(1, 1, '\p{^issuppuab}', "");
Expect(1, 1, '\P{issuppuab}', "");
Expect(0, 1, '\P{^issuppuab}', "");
Expect(1, 1048576, '\p{_-is_Sup_PUA_B}', "");
Expect(0, 1048576, '\p{^_-is_Sup_PUA_B}', "");
Expect(0, 1048576, '\P{_-is_Sup_PUA_B}', "");
Expect(1, 1048576, '\P{^_-is_Sup_PUA_B}', "");
Expect(0, 1, '\p{_-is_Sup_PUA_B}', "");
Expect(1, 1, '\p{^_-is_Sup_PUA_B}', "");
Expect(1, 1, '\P{_-is_Sup_PUA_B}', "");
Expect(0, 1, '\P{^_-is_Sup_PUA_B}', "");
Error('\p{ :=in_sup_pua_B}');
Error('\P{ :=in_sup_pua_B}');
Expect(1, 1048576, '\p{insuppuab}', "");
Expect(0, 1048576, '\p{^insuppuab}', "");
Expect(0, 1048576, '\P{insuppuab}', "");
Expect(1, 1048576, '\P{^insuppuab}', "");
Expect(0, 1, '\p{insuppuab}', "");
Expect(1, 1, '\p{^insuppuab}', "");
Expect(1, 1, '\P{insuppuab}', "");
Expect(0, 1, '\P{^insuppuab}', "");
Expect(1, 1048576, '\p{in_SUP_PUA_B}', "");
Expect(0, 1048576, '\p{^in_SUP_PUA_B}', "");
Expect(0, 1048576, '\P{in_SUP_PUA_B}', "");
Expect(1, 1048576, '\P{^in_SUP_PUA_B}', "");
Expect(0, 1, '\p{in_SUP_PUA_B}', "");
Expect(1, 1, '\p{^in_SUP_PUA_B}', "");
Expect(1, 1, '\P{in_SUP_PUA_B}', "");
Expect(0, 1, '\P{^in_SUP_PUA_B}', "");
Error('\p{- Surrogate/a/}');
Error('\P{- Surrogate/a/}');
Expect(1, 57343, '\p{surrogate}', "");
Expect(0, 57343, '\p{^surrogate}', "");
Expect(0, 57343, '\P{surrogate}', "");
Expect(1, 57343, '\P{^surrogate}', "");
Expect(0, 57344, '\p{surrogate}', "");
Expect(1, 57344, '\p{^surrogate}', "");
Expect(1, 57344, '\P{surrogate}', "");
Expect(0, 57344, '\P{^surrogate}', "");
Expect(1, 57343, '\p{_ surrogate}', "");
Expect(0, 57343, '\p{^_ surrogate}', "");
Expect(0, 57343, '\P{_ surrogate}', "");
Expect(1, 57343, '\P{^_ surrogate}', "");
Expect(0, 57344, '\p{_ surrogate}', "");
Expect(1, 57344, '\p{^_ surrogate}', "");
Expect(1, 57344, '\P{_ surrogate}', "");
Expect(0, 57344, '\P{^_ surrogate}', "");
Error('\p{/a/	IS_Surrogate}');
Error('\P{/a/	IS_Surrogate}');
Expect(1, 57343, '\p{issurrogate}', "");
Expect(0, 57343, '\p{^issurrogate}', "");
Expect(0, 57343, '\P{issurrogate}', "");
Expect(1, 57343, '\P{^issurrogate}', "");
Expect(0, 57344, '\p{issurrogate}', "");
Expect(1, 57344, '\p{^issurrogate}', "");
Expect(1, 57344, '\P{issurrogate}', "");
Expect(0, 57344, '\P{^issurrogate}', "");
Expect(1, 57343, '\p{_IS_Surrogate}', "");
Expect(0, 57343, '\p{^_IS_Surrogate}', "");
Expect(0, 57343, '\P{_IS_Surrogate}', "");
Expect(1, 57343, '\P{^_IS_Surrogate}', "");
Expect(0, 57344, '\p{_IS_Surrogate}', "");
Expect(1, 57344, '\p{^_IS_Surrogate}', "");
Expect(1, 57344, '\P{_IS_Surrogate}', "");
Expect(0, 57344, '\P{^_IS_Surrogate}', "");
Error('\p{/a/  CS}');
Error('\P{/a/  CS}');
Expect(1, 57343, '\p{cs}', "");
Expect(0, 57343, '\p{^cs}', "");
Expect(0, 57343, '\P{cs}', "");
Expect(1, 57343, '\P{^cs}', "");
Expect(0, 57344, '\p{cs}', "");
Expect(1, 57344, '\p{^cs}', "");
Expect(1, 57344, '\P{cs}', "");
Expect(0, 57344, '\P{^cs}', "");
Expect(1, 57343, '\p{ _CS}', "");
Expect(0, 57343, '\p{^ _CS}', "");
Expect(0, 57343, '\P{ _CS}', "");
Expect(1, 57343, '\P{^ _CS}', "");
Expect(0, 57344, '\p{ _CS}', "");
Expect(1, 57344, '\p{^ _CS}', "");
Expect(1, 57344, '\P{ _CS}', "");
Expect(0, 57344, '\P{^ _CS}', "");
Error('\p{_IS_cs:=}');
Error('\P{_IS_cs:=}');
Expect(1, 57343, '\p{iscs}', "");
Expect(0, 57343, '\p{^iscs}', "");
Expect(0, 57343, '\P{iscs}', "");
Expect(1, 57343, '\P{^iscs}', "");
Expect(0, 57344, '\p{iscs}', "");
Expect(1, 57344, '\p{^iscs}', "");
Expect(1, 57344, '\P{iscs}', "");
Expect(0, 57344, '\P{^iscs}', "");
Expect(1, 57343, '\p{ IS_CS}', "");
Expect(0, 57343, '\p{^ IS_CS}', "");
Expect(0, 57343, '\P{ IS_CS}', "");
Expect(1, 57343, '\P{^ IS_CS}', "");
Expect(0, 57344, '\p{ IS_CS}', "");
Expect(1, 57344, '\p{^ IS_CS}', "");
Expect(1, 57344, '\P{ IS_CS}', "");
Expect(0, 57344, '\P{^ IS_CS}', "");
Error('\p{/a/ 	syloti_nagri}');
Error('\P{/a/ 	syloti_nagri}');
Expect(1, 43051, '\p{sylotinagri}', "");
Expect(0, 43051, '\p{^sylotinagri}', "");
Expect(0, 43051, '\P{sylotinagri}', "");
Expect(1, 43051, '\P{^sylotinagri}', "");
Expect(0, 43052, '\p{sylotinagri}', "");
Expect(1, 43052, '\p{^sylotinagri}', "");
Expect(1, 43052, '\P{sylotinagri}', "");
Expect(0, 43052, '\P{^sylotinagri}', "");
Expect(1, 43051, '\p{--SYLOTI_NAGRI}', "");
Expect(0, 43051, '\p{^--SYLOTI_NAGRI}', "");
Expect(0, 43051, '\P{--SYLOTI_NAGRI}', "");
Expect(1, 43051, '\P{^--SYLOTI_NAGRI}', "");
Expect(0, 43052, '\p{--SYLOTI_NAGRI}', "");
Expect(1, 43052, '\p{^--SYLOTI_NAGRI}', "");
Expect(1, 43052, '\P{--SYLOTI_NAGRI}', "");
Expect(0, 43052, '\P{^--SYLOTI_NAGRI}', "");
Error('\p{ :=is_Syloti_NAGRI}');
Error('\P{ :=is_Syloti_NAGRI}');
Expect(1, 43051, '\p{issylotinagri}', "");
Expect(0, 43051, '\p{^issylotinagri}', "");
Expect(0, 43051, '\P{issylotinagri}', "");
Expect(1, 43051, '\P{^issylotinagri}', "");
Expect(0, 43052, '\p{issylotinagri}', "");
Expect(1, 43052, '\p{^issylotinagri}', "");
Expect(1, 43052, '\P{issylotinagri}', "");
Expect(0, 43052, '\P{^issylotinagri}', "");
Expect(1, 43051, '\p{-is_Syloti_Nagri}', "");
Expect(0, 43051, '\p{^-is_Syloti_Nagri}', "");
Expect(0, 43051, '\P{-is_Syloti_Nagri}', "");
Expect(1, 43051, '\P{^-is_Syloti_Nagri}', "");
Expect(0, 43052, '\p{-is_Syloti_Nagri}', "");
Expect(1, 43052, '\p{^-is_Syloti_Nagri}', "");
Expect(1, 43052, '\P{-is_Syloti_Nagri}', "");
Expect(0, 43052, '\P{^-is_Syloti_Nagri}', "");
Error('\p{:= -sylo}');
Error('\P{:= -sylo}');
Expect(1, 43051, '\p{sylo}', "");
Expect(0, 43051, '\p{^sylo}', "");
Expect(0, 43051, '\P{sylo}', "");
Expect(1, 43051, '\P{^sylo}', "");
Expect(0, 43052, '\p{sylo}', "");
Expect(1, 43052, '\p{^sylo}', "");
Expect(1, 43052, '\P{sylo}', "");
Expect(0, 43052, '\P{^sylo}', "");
Expect(1, 43051, '\p{  SYLO}', "");
Expect(0, 43051, '\p{^  SYLO}', "");
Expect(0, 43051, '\P{  SYLO}', "");
Expect(1, 43051, '\P{^  SYLO}', "");
Expect(0, 43052, '\p{  SYLO}', "");
Expect(1, 43052, '\p{^  SYLO}', "");
Expect(1, 43052, '\P{  SYLO}', "");
Expect(0, 43052, '\P{^  SYLO}', "");
Error('\p{  Is_SYLO/a/}');
Error('\P{  Is_SYLO/a/}');
Expect(1, 43051, '\p{issylo}', "");
Expect(0, 43051, '\p{^issylo}', "");
Expect(0, 43051, '\P{issylo}', "");
Expect(1, 43051, '\P{^issylo}', "");
Expect(0, 43052, '\p{issylo}', "");
Expect(1, 43052, '\p{^issylo}', "");
Expect(1, 43052, '\P{issylo}', "");
Expect(0, 43052, '\P{^issylo}', "");
Expect(1, 43051, '\p{_-is_sylo}', "");
Expect(0, 43051, '\p{^_-is_sylo}', "");
Expect(0, 43051, '\P{_-is_sylo}', "");
Expect(1, 43051, '\P{^_-is_sylo}', "");
Expect(0, 43052, '\p{_-is_sylo}', "");
Expect(1, 43052, '\p{^_-is_sylo}', "");
Expect(1, 43052, '\P{_-is_sylo}', "");
Expect(0, 43052, '\P{^_-is_sylo}', "");
Error('\p{_-symbol:=}');
Error('\P{_-symbol:=}');
Expect(1, 128883, '\p{symbol}', "");
Expect(0, 128883, '\p{^symbol}', "");
Expect(0, 128883, '\P{symbol}', "");
Expect(1, 128883, '\P{^symbol}', "");
Expect(0, 128884, '\p{symbol}', "");
Expect(1, 128884, '\p{^symbol}', "");
Expect(1, 128884, '\P{symbol}', "");
Expect(0, 128884, '\P{^symbol}', "");
Expect(1, 128883, '\p{	_Symbol}', "");
Expect(0, 128883, '\p{^	_Symbol}', "");
Expect(0, 128883, '\P{	_Symbol}', "");
Expect(1, 128883, '\P{^	_Symbol}', "");
Expect(0, 128884, '\p{	_Symbol}', "");
Expect(1, 128884, '\p{^	_Symbol}', "");
Expect(1, 128884, '\P{	_Symbol}', "");
Expect(0, 128884, '\P{^	_Symbol}', "");
Error('\p{/a/_-is_Symbol}');
Error('\P{/a/_-is_Symbol}');
Expect(1, 128883, '\p{issymbol}', "");
Expect(0, 128883, '\p{^issymbol}', "");
Expect(0, 128883, '\P{issymbol}', "");
Expect(1, 128883, '\P{^issymbol}', "");
Expect(0, 128884, '\p{issymbol}', "");
Expect(1, 128884, '\p{^issymbol}', "");
Expect(1, 128884, '\P{issymbol}', "");
Expect(0, 128884, '\P{^issymbol}', "");
Expect(1, 128883, '\p{_ Is_symbol}', "");
Expect(0, 128883, '\p{^_ Is_symbol}', "");
Expect(0, 128883, '\P{_ Is_symbol}', "");
Expect(1, 128883, '\P{^_ Is_symbol}', "");
Expect(0, 128884, '\p{_ Is_symbol}', "");
Expect(1, 128884, '\p{^_ Is_symbol}', "");
Expect(1, 128884, '\P{_ Is_symbol}', "");
Expect(0, 128884, '\P{^_ Is_symbol}', "");
Error('\p{:=_	s}');
Error('\P{:=_	s}');
Expect(1, 128883, '\p{s}', "");
Expect(0, 128883, '\p{^s}', "");
Expect(0, 128883, '\P{s}', "");
Expect(1, 128883, '\P{^s}', "");
Expect(0, 128884, '\p{s}', "");
Expect(1, 128884, '\p{^s}', "");
Expect(1, 128884, '\P{s}', "");
Expect(0, 128884, '\P{^s}', "");
Expect(1, 128883, '\p{_S}', "");
Expect(0, 128883, '\p{^_S}', "");
Expect(0, 128883, '\P{_S}', "");
Expect(1, 128883, '\P{^_S}', "");
Expect(0, 128884, '\p{_S}', "");
Expect(1, 128884, '\p{^_S}', "");
Expect(1, 128884, '\P{_S}', "");
Expect(0, 128884, '\P{^_S}', "");
Error('\p{_ is_S:=}');
Error('\P{_ is_S:=}');
Expect(1, 128883, '\p{iss}', "");
Expect(0, 128883, '\p{^iss}', "");
Expect(0, 128883, '\P{iss}', "");
Expect(1, 128883, '\P{^iss}', "");
Expect(0, 128884, '\p{iss}', "");
Expect(1, 128884, '\p{^iss}', "");
Expect(1, 128884, '\P{iss}', "");
Expect(0, 128884, '\P{^iss}', "");
Expect(1, 128883, '\p{-_Is_s}', "");
Expect(0, 128883, '\p{^-_Is_s}', "");
Expect(0, 128883, '\P{-_Is_s}', "");
Expect(1, 128883, '\P{^-_Is_s}', "");
Expect(0, 128884, '\p{-_Is_s}', "");
Expect(1, 128884, '\p{^-_Is_s}', "");
Expect(1, 128884, '\P{-_Is_s}', "");
Expect(0, 128884, '\P{^-_Is_s}', "");
Error('\p{:=Syriac}');
Error('\P{:=Syriac}');
Expect(1, 1871, '\p{syriac}', "");
Expect(0, 1871, '\p{^syriac}', "");
Expect(0, 1871, '\P{syriac}', "");
Expect(1, 1871, '\P{^syriac}', "");
Expect(0, 1872, '\p{syriac}', "");
Expect(1, 1872, '\p{^syriac}', "");
Expect(1, 1872, '\P{syriac}', "");
Expect(0, 1872, '\P{^syriac}', "");
Error('\p{/a/-_Is_Syriac}');
Error('\P{/a/-_Is_Syriac}');
Expect(1, 1871, '\p{issyriac}', "");
Expect(0, 1871, '\p{^issyriac}', "");
Expect(0, 1871, '\P{issyriac}', "");
Expect(1, 1871, '\P{^issyriac}', "");
Expect(0, 1872, '\p{issyriac}', "");
Expect(1, 1872, '\p{^issyriac}', "");
Expect(1, 1872, '\P{issyriac}', "");
Expect(0, 1872, '\P{^issyriac}', "");
Expect(1, 1871, '\p{is_SYRIAC}', "");
Expect(0, 1871, '\p{^is_SYRIAC}', "");
Expect(0, 1871, '\P{is_SYRIAC}', "");
Expect(1, 1871, '\P{^is_SYRIAC}', "");
Expect(0, 1872, '\p{is_SYRIAC}', "");
Expect(1, 1872, '\p{^is_SYRIAC}', "");
Expect(1, 1872, '\P{is_SYRIAC}', "");
Expect(0, 1872, '\P{^is_SYRIAC}', "");
Error('\p{__Syrc:=}');
Error('\P{__Syrc:=}');
Expect(1, 1871, '\p{syrc}', "");
Expect(0, 1871, '\p{^syrc}', "");
Expect(0, 1871, '\P{syrc}', "");
Expect(1, 1871, '\P{^syrc}', "");
Expect(0, 1872, '\p{syrc}', "");
Expect(1, 1872, '\p{^syrc}', "");
Expect(1, 1872, '\P{syrc}', "");
Expect(0, 1872, '\P{^syrc}', "");
Expect(1, 1871, '\p{-_syrc}', "");
Expect(0, 1871, '\p{^-_syrc}', "");
Expect(0, 1871, '\P{-_syrc}', "");
Expect(1, 1871, '\P{^-_syrc}', "");
Expect(0, 1872, '\p{-_syrc}', "");
Expect(1, 1872, '\p{^-_syrc}', "");
Expect(1, 1872, '\P{-_syrc}', "");
Expect(0, 1872, '\P{^-_syrc}', "");
Error('\p{ /a/is_Syrc}');
Error('\P{ /a/is_Syrc}');
Expect(1, 1871, '\p{issyrc}', "");
Expect(0, 1871, '\p{^issyrc}', "");
Expect(0, 1871, '\P{issyrc}', "");
Expect(1, 1871, '\P{^issyrc}', "");
Expect(0, 1872, '\p{issyrc}', "");
Expect(1, 1872, '\p{^issyrc}', "");
Expect(1, 1872, '\P{issyrc}', "");
Expect(0, 1872, '\P{^issyrc}', "");
Expect(1, 1871, '\p{	_is_Syrc}', "");
Expect(0, 1871, '\p{^	_is_Syrc}', "");
Expect(0, 1871, '\P{	_is_Syrc}', "");
Expect(1, 1871, '\P{^	_is_Syrc}', "");
Expect(0, 1872, '\p{	_is_Syrc}', "");
Expect(1, 1872, '\p{^	_is_Syrc}', "");
Expect(1, 1872, '\P{	_is_Syrc}', "");
Expect(0, 1872, '\P{^	_is_Syrc}', "");
Error('\p{	:=Tagalog}');
Error('\P{	:=Tagalog}');
Expect(1, 5908, '\p{tagalog}', "");
Expect(0, 5908, '\p{^tagalog}', "");
Expect(0, 5908, '\P{tagalog}', "");
Expect(1, 5908, '\P{^tagalog}', "");
Expect(0, 5909, '\p{tagalog}', "");
Expect(1, 5909, '\p{^tagalog}', "");
Expect(1, 5909, '\P{tagalog}', "");
Expect(0, 5909, '\P{^tagalog}', "");
Expect(1, 5908, '\p{- Tagalog}', "");
Expect(0, 5908, '\p{^- Tagalog}', "");
Expect(0, 5908, '\P{- Tagalog}', "");
Expect(1, 5908, '\P{^- Tagalog}', "");
Expect(0, 5909, '\p{- Tagalog}', "");
Expect(1, 5909, '\p{^- Tagalog}', "");
Expect(1, 5909, '\P{- Tagalog}', "");
Expect(0, 5909, '\P{^- Tagalog}', "");
Error('\p{ _IS_Tagalog:=}');
Error('\P{ _IS_Tagalog:=}');
Expect(1, 5908, '\p{istagalog}', "");
Expect(0, 5908, '\p{^istagalog}', "");
Expect(0, 5908, '\P{istagalog}', "");
Expect(1, 5908, '\P{^istagalog}', "");
Expect(0, 5909, '\p{istagalog}', "");
Expect(1, 5909, '\p{^istagalog}', "");
Expect(1, 5909, '\P{istagalog}', "");
Expect(0, 5909, '\P{^istagalog}', "");
Expect(1, 5908, '\p{- Is_Tagalog}', "");
Expect(0, 5908, '\p{^- Is_Tagalog}', "");
Expect(0, 5908, '\P{- Is_Tagalog}', "");
Expect(1, 5908, '\P{^- Is_Tagalog}', "");
Expect(0, 5909, '\p{- Is_Tagalog}', "");
Expect(1, 5909, '\p{^- Is_Tagalog}', "");
Expect(1, 5909, '\P{- Is_Tagalog}', "");
Expect(0, 5909, '\P{^- Is_Tagalog}', "");
Error('\p{__Tglg:=}');
Error('\P{__Tglg:=}');
Expect(1, 5908, '\p{tglg}', "");
Expect(0, 5908, '\p{^tglg}', "");
Expect(0, 5908, '\P{tglg}', "");
Expect(1, 5908, '\P{^tglg}', "");
Expect(0, 5909, '\p{tglg}', "");
Expect(1, 5909, '\p{^tglg}', "");
Expect(1, 5909, '\P{tglg}', "");
Expect(0, 5909, '\P{^tglg}', "");
Expect(1, 5908, '\p{-TGLG}', "");
Expect(0, 5908, '\p{^-TGLG}', "");
Expect(0, 5908, '\P{-TGLG}', "");
Expect(1, 5908, '\P{^-TGLG}', "");
Expect(0, 5909, '\p{-TGLG}', "");
Expect(1, 5909, '\p{^-TGLG}', "");
Expect(1, 5909, '\P{-TGLG}', "");
Expect(0, 5909, '\P{^-TGLG}', "");
Error('\p{/a/ _IS_TGLG}');
Error('\P{/a/ _IS_TGLG}');
Expect(1, 5908, '\p{istglg}', "");
Expect(0, 5908, '\p{^istglg}', "");
Expect(0, 5908, '\P{istglg}', "");
Expect(1, 5908, '\P{^istglg}', "");
Expect(0, 5909, '\p{istglg}', "");
Expect(1, 5909, '\p{^istglg}', "");
Expect(1, 5909, '\P{istglg}', "");
Expect(0, 5909, '\P{^istglg}', "");
Expect(1, 5908, '\p{	Is_TGLG}', "");
Expect(0, 5908, '\p{^	Is_TGLG}', "");
Expect(0, 5908, '\P{	Is_TGLG}', "");
Expect(1, 5908, '\P{^	Is_TGLG}', "");
Expect(0, 5909, '\p{	Is_TGLG}', "");
Expect(1, 5909, '\p{^	Is_TGLG}', "");
Expect(1, 5909, '\P{	Is_TGLG}', "");
Expect(0, 5909, '\P{^	Is_TGLG}', "");
Error('\p{:=_tagbanwa}');
Error('\P{:=_tagbanwa}');
Expect(1, 6003, '\p{tagbanwa}', "");
Expect(0, 6003, '\p{^tagbanwa}', "");
Expect(0, 6003, '\P{tagbanwa}', "");
Expect(1, 6003, '\P{^tagbanwa}', "");
Expect(0, 6004, '\p{tagbanwa}', "");
Expect(1, 6004, '\p{^tagbanwa}', "");
Expect(1, 6004, '\P{tagbanwa}', "");
Expect(0, 6004, '\P{^tagbanwa}', "");
Expect(1, 6003, '\p{_	tagbanwa}', "");
Expect(0, 6003, '\p{^_	tagbanwa}', "");
Expect(0, 6003, '\P{_	tagbanwa}', "");
Expect(1, 6003, '\P{^_	tagbanwa}', "");
Expect(0, 6004, '\p{_	tagbanwa}', "");
Expect(1, 6004, '\p{^_	tagbanwa}', "");
Expect(1, 6004, '\P{_	tagbanwa}', "");
Expect(0, 6004, '\P{^_	tagbanwa}', "");
Error('\p{ /a/IS_tagbanwa}');
Error('\P{ /a/IS_tagbanwa}');
Expect(1, 6003, '\p{istagbanwa}', "");
Expect(0, 6003, '\p{^istagbanwa}', "");
Expect(0, 6003, '\P{istagbanwa}', "");
Expect(1, 6003, '\P{^istagbanwa}', "");
Expect(0, 6004, '\p{istagbanwa}', "");
Expect(1, 6004, '\p{^istagbanwa}', "");
Expect(1, 6004, '\P{istagbanwa}', "");
Expect(0, 6004, '\P{^istagbanwa}', "");
Expect(1, 6003, '\p{		Is_Tagbanwa}', "");
Expect(0, 6003, '\p{^		Is_Tagbanwa}', "");
Expect(0, 6003, '\P{		Is_Tagbanwa}', "");
Expect(1, 6003, '\P{^		Is_Tagbanwa}', "");
Expect(0, 6004, '\p{		Is_Tagbanwa}', "");
Expect(1, 6004, '\p{^		Is_Tagbanwa}', "");
Expect(1, 6004, '\P{		Is_Tagbanwa}', "");
Expect(0, 6004, '\P{^		Is_Tagbanwa}', "");
Error('\p{	/a/Tagb}');
Error('\P{	/a/Tagb}');
Expect(1, 6003, '\p{tagb}', "");
Expect(0, 6003, '\p{^tagb}', "");
Expect(0, 6003, '\P{tagb}', "");
Expect(1, 6003, '\P{^tagb}', "");
Expect(0, 6004, '\p{tagb}', "");
Expect(1, 6004, '\p{^tagb}', "");
Expect(1, 6004, '\P{tagb}', "");
Expect(0, 6004, '\P{^tagb}', "");
Expect(1, 6003, '\p{-TAGB}', "");
Expect(0, 6003, '\p{^-TAGB}', "");
Expect(0, 6003, '\P{-TAGB}', "");
Expect(1, 6003, '\P{^-TAGB}', "");
Expect(0, 6004, '\p{-TAGB}', "");
Expect(1, 6004, '\p{^-TAGB}', "");
Expect(1, 6004, '\P{-TAGB}', "");
Expect(0, 6004, '\P{^-TAGB}', "");
Error('\p{	Is_Tagb:=}');
Error('\P{	Is_Tagb:=}');
Expect(1, 6003, '\p{istagb}', "");
Expect(0, 6003, '\p{^istagb}', "");
Expect(0, 6003, '\P{istagb}', "");
Expect(1, 6003, '\P{^istagb}', "");
Expect(0, 6004, '\p{istagb}', "");
Expect(1, 6004, '\p{^istagb}', "");
Expect(1, 6004, '\P{istagb}', "");
Expect(0, 6004, '\P{^istagb}', "");
Expect(1, 6003, '\p{- is_tagb}', "");
Expect(0, 6003, '\p{^- is_tagb}', "");
Expect(0, 6003, '\P{- is_tagb}', "");
Expect(1, 6003, '\P{^- is_tagb}', "");
Expect(0, 6004, '\p{- is_tagb}', "");
Expect(1, 6004, '\p{^- is_tagb}', "");
Expect(1, 6004, '\P{- is_tagb}', "");
Expect(0, 6004, '\P{^- is_tagb}', "");
Error('\p{/a/Tags}');
Error('\P{/a/Tags}');
Expect(1, 917631, '\p{tags}', "");
Expect(0, 917631, '\p{^tags}', "");
Expect(0, 917631, '\P{tags}', "");
Expect(1, 917631, '\P{^tags}', "");
Expect(0, 917632, '\p{tags}', "");
Expect(1, 917632, '\p{^tags}', "");
Expect(1, 917632, '\P{tags}', "");
Expect(0, 917632, '\P{^tags}', "");
Expect(1, 917631, '\p{	tags}', "");
Expect(0, 917631, '\p{^	tags}', "");
Expect(0, 917631, '\P{	tags}', "");
Expect(1, 917631, '\P{^	tags}', "");
Expect(0, 917632, '\p{	tags}', "");
Expect(1, 917632, '\p{^	tags}', "");
Expect(1, 917632, '\P{	tags}', "");
Expect(0, 917632, '\P{^	tags}', "");
Error('\p{-Is_TAGS:=}');
Error('\P{-Is_TAGS:=}');
Expect(1, 917631, '\p{istags}', "");
Expect(0, 917631, '\p{^istags}', "");
Expect(0, 917631, '\P{istags}', "");
Expect(1, 917631, '\P{^istags}', "");
Expect(0, 917632, '\p{istags}', "");
Expect(1, 917632, '\p{^istags}', "");
Expect(1, 917632, '\P{istags}', "");
Expect(0, 917632, '\P{^istags}', "");
Expect(1, 917631, '\p{_	is_tags}', "");
Expect(0, 917631, '\p{^_	is_tags}', "");
Expect(0, 917631, '\P{_	is_tags}', "");
Expect(1, 917631, '\P{^_	is_tags}', "");
Expect(0, 917632, '\p{_	is_tags}', "");
Expect(1, 917632, '\p{^_	is_tags}', "");
Expect(1, 917632, '\P{_	is_tags}', "");
Expect(0, 917632, '\P{^_	is_tags}', "");
Error('\p{/a/ in_tags}');
Error('\P{/a/ in_tags}');
Expect(1, 917631, '\p{intags}', "");
Expect(0, 917631, '\p{^intags}', "");
Expect(0, 917631, '\P{intags}', "");
Expect(1, 917631, '\P{^intags}', "");
Expect(0, 917632, '\p{intags}', "");
Expect(1, 917632, '\p{^intags}', "");
Expect(1, 917632, '\P{intags}', "");
Expect(0, 917632, '\P{^intags}', "");
Expect(1, 917631, '\p{-	in_Tags}', "");
Expect(0, 917631, '\p{^-	in_Tags}', "");
Expect(0, 917631, '\P{-	in_Tags}', "");
Expect(1, 917631, '\P{^-	in_Tags}', "");
Expect(0, 917632, '\p{-	in_Tags}', "");
Expect(1, 917632, '\p{^-	in_Tags}', "");
Expect(1, 917632, '\P{-	in_Tags}', "");
Expect(0, 917632, '\P{^-	in_Tags}', "");
Error('\p{:=_	TAI_Le}');
Error('\P{:=_	TAI_Le}');
Expect(1, 6516, '\p{taile}', "");
Expect(0, 6516, '\p{^taile}', "");
Expect(0, 6516, '\P{taile}', "");
Expect(1, 6516, '\P{^taile}', "");
Expect(0, 6517, '\p{taile}', "");
Expect(1, 6517, '\p{^taile}', "");
Expect(1, 6517, '\P{taile}', "");
Expect(0, 6517, '\P{^taile}', "");
Expect(1, 6516, '\p{		tai_Le}', "");
Expect(0, 6516, '\p{^		tai_Le}', "");
Expect(0, 6516, '\P{		tai_Le}', "");
Expect(1, 6516, '\P{^		tai_Le}', "");
Expect(0, 6517, '\p{		tai_Le}', "");
Expect(1, 6517, '\p{^		tai_Le}', "");
Expect(1, 6517, '\P{		tai_Le}', "");
Expect(0, 6517, '\P{^		tai_Le}', "");
Error('\p{	 is_TAI_LE/a/}');
Error('\P{	 is_TAI_LE/a/}');
Expect(1, 6516, '\p{istaile}', "");
Expect(0, 6516, '\p{^istaile}', "");
Expect(0, 6516, '\P{istaile}', "");
Expect(1, 6516, '\P{^istaile}', "");
Expect(0, 6517, '\p{istaile}', "");
Expect(1, 6517, '\p{^istaile}', "");
Expect(1, 6517, '\P{istaile}', "");
Expect(0, 6517, '\P{^istaile}', "");
Expect(1, 6516, '\p{-is_TAI_Le}', "");
Expect(0, 6516, '\p{^-is_TAI_Le}', "");
Expect(0, 6516, '\P{-is_TAI_Le}', "");
Expect(1, 6516, '\P{^-is_TAI_Le}', "");
Expect(0, 6517, '\p{-is_TAI_Le}', "");
Expect(1, 6517, '\p{^-is_TAI_Le}', "");
Expect(1, 6517, '\P{-is_TAI_Le}', "");
Expect(0, 6517, '\P{^-is_TAI_Le}', "");
Error('\p{:= -TALE}');
Error('\P{:= -TALE}');
Expect(1, 6516, '\p{tale}', "");
Expect(0, 6516, '\p{^tale}', "");
Expect(0, 6516, '\P{tale}', "");
Expect(1, 6516, '\P{^tale}', "");
Expect(0, 6517, '\p{tale}', "");
Expect(1, 6517, '\p{^tale}', "");
Expect(1, 6517, '\P{tale}', "");
Expect(0, 6517, '\P{^tale}', "");
Expect(1, 6516, '\p{		Tale}', "");
Expect(0, 6516, '\p{^		Tale}', "");
Expect(0, 6516, '\P{		Tale}', "");
Expect(1, 6516, '\P{^		Tale}', "");
Expect(0, 6517, '\p{		Tale}', "");
Expect(1, 6517, '\p{^		Tale}', "");
Expect(1, 6517, '\P{		Tale}', "");
Expect(0, 6517, '\P{^		Tale}', "");
Error('\p{:=	is_tale}');
Error('\P{:=	is_tale}');
Expect(1, 6516, '\p{istale}', "");
Expect(0, 6516, '\p{^istale}', "");
Expect(0, 6516, '\P{istale}', "");
Expect(1, 6516, '\P{^istale}', "");
Expect(0, 6517, '\p{istale}', "");
Expect(1, 6517, '\p{^istale}', "");
Expect(1, 6517, '\P{istale}', "");
Expect(0, 6517, '\P{^istale}', "");
Expect(1, 6516, '\p{- IS_TALE}', "");
Expect(0, 6516, '\p{^- IS_TALE}', "");
Expect(0, 6516, '\P{- IS_TALE}', "");
Expect(1, 6516, '\P{^- IS_TALE}', "");
Expect(0, 6517, '\p{- IS_TALE}', "");
Expect(1, 6517, '\p{^- IS_TALE}', "");
Expect(1, 6517, '\P{- IS_TALE}', "");
Expect(0, 6517, '\P{^- IS_TALE}', "");
Error('\p{	-Tai_Tham:=}');
Error('\P{	-Tai_Tham:=}');
Expect(1, 6829, '\p{taitham}', "");
Expect(0, 6829, '\p{^taitham}', "");
Expect(0, 6829, '\P{taitham}', "");
Expect(1, 6829, '\P{^taitham}', "");
Expect(0, 6830, '\p{taitham}', "");
Expect(1, 6830, '\p{^taitham}', "");
Expect(1, 6830, '\P{taitham}', "");
Expect(0, 6830, '\P{^taitham}', "");
Expect(1, 6829, '\p{-	TAI_Tham}', "");
Expect(0, 6829, '\p{^-	TAI_Tham}', "");
Expect(0, 6829, '\P{-	TAI_Tham}', "");
Expect(1, 6829, '\P{^-	TAI_Tham}', "");
Expect(0, 6830, '\p{-	TAI_Tham}', "");
Expect(1, 6830, '\p{^-	TAI_Tham}', "");
Expect(1, 6830, '\P{-	TAI_Tham}', "");
Expect(0, 6830, '\P{^-	TAI_Tham}', "");
Error('\p{ 	Is_tai_Tham:=}');
Error('\P{ 	Is_tai_Tham:=}');
Expect(1, 6829, '\p{istaitham}', "");
Expect(0, 6829, '\p{^istaitham}', "");
Expect(0, 6829, '\P{istaitham}', "");
Expect(1, 6829, '\P{^istaitham}', "");
Expect(0, 6830, '\p{istaitham}', "");
Expect(1, 6830, '\p{^istaitham}', "");
Expect(1, 6830, '\P{istaitham}', "");
Expect(0, 6830, '\P{^istaitham}', "");
Expect(1, 6829, '\p{_ Is_Tai_THAM}', "");
Expect(0, 6829, '\p{^_ Is_Tai_THAM}', "");
Expect(0, 6829, '\P{_ Is_Tai_THAM}', "");
Expect(1, 6829, '\P{^_ Is_Tai_THAM}', "");
Expect(0, 6830, '\p{_ Is_Tai_THAM}', "");
Expect(1, 6830, '\p{^_ Is_Tai_THAM}', "");
Expect(1, 6830, '\P{_ Is_Tai_THAM}', "");
Expect(0, 6830, '\P{^_ Is_Tai_THAM}', "");
Error('\p{lana:=}');
Error('\P{lana:=}');
Expect(1, 6829, '\p{lana}', "");
Expect(0, 6829, '\p{^lana}', "");
Expect(0, 6829, '\P{lana}', "");
Expect(1, 6829, '\P{^lana}', "");
Expect(0, 6830, '\p{lana}', "");
Expect(1, 6830, '\p{^lana}', "");
Expect(1, 6830, '\P{lana}', "");
Expect(0, 6830, '\P{^lana}', "");
Expect(1, 6829, '\p{_-Lana}', "");
Expect(0, 6829, '\p{^_-Lana}', "");
Expect(0, 6829, '\P{_-Lana}', "");
Expect(1, 6829, '\P{^_-Lana}', "");
Expect(0, 6830, '\p{_-Lana}', "");
Expect(1, 6830, '\p{^_-Lana}', "");
Expect(1, 6830, '\P{_-Lana}', "");
Expect(0, 6830, '\P{^_-Lana}', "");
Error('\p{/a/	is_lana}');
Error('\P{/a/	is_lana}');
Expect(1, 6829, '\p{islana}', "");
Expect(0, 6829, '\p{^islana}', "");
Expect(0, 6829, '\P{islana}', "");
Expect(1, 6829, '\P{^islana}', "");
Expect(0, 6830, '\p{islana}', "");
Expect(1, 6830, '\p{^islana}', "");
Expect(1, 6830, '\P{islana}', "");
Expect(0, 6830, '\P{^islana}', "");
Expect(1, 6829, '\p{_Is_Lana}', "");
Expect(0, 6829, '\p{^_Is_Lana}', "");
Expect(0, 6829, '\P{_Is_Lana}', "");
Expect(1, 6829, '\P{^_Is_Lana}', "");
Expect(0, 6830, '\p{_Is_Lana}', "");
Expect(1, 6830, '\p{^_Is_Lana}', "");
Expect(1, 6830, '\P{_Is_Lana}', "");
Expect(0, 6830, '\P{^_Is_Lana}', "");
Error('\p{:=-TAI_Viet}');
Error('\P{:=-TAI_Viet}');
Expect(1, 43743, '\p{taiviet}', "");
Expect(0, 43743, '\p{^taiviet}', "");
Expect(0, 43743, '\P{taiviet}', "");
Expect(1, 43743, '\P{^taiviet}', "");
Expect(0, 43744, '\p{taiviet}', "");
Expect(1, 43744, '\p{^taiviet}', "");
Expect(1, 43744, '\P{taiviet}', "");
Expect(0, 43744, '\P{^taiviet}', "");
Expect(1, 43743, '\p{ 	Tai_Viet}', "");
Expect(0, 43743, '\p{^ 	Tai_Viet}', "");
Expect(0, 43743, '\P{ 	Tai_Viet}', "");
Expect(1, 43743, '\P{^ 	Tai_Viet}', "");
Expect(0, 43744, '\p{ 	Tai_Viet}', "");
Expect(1, 43744, '\p{^ 	Tai_Viet}', "");
Expect(1, 43744, '\P{ 	Tai_Viet}', "");
Expect(0, 43744, '\P{^ 	Tai_Viet}', "");
Error('\p{  is_tai_Viet:=}');
Error('\P{  is_tai_Viet:=}');
Expect(1, 43743, '\p{istaiviet}', "");
Expect(0, 43743, '\p{^istaiviet}', "");
Expect(0, 43743, '\P{istaiviet}', "");
Expect(1, 43743, '\P{^istaiviet}', "");
Expect(0, 43744, '\p{istaiviet}', "");
Expect(1, 43744, '\p{^istaiviet}', "");
Expect(1, 43744, '\P{istaiviet}', "");
Expect(0, 43744, '\P{^istaiviet}', "");
Expect(1, 43743, '\p{	 Is_Tai_Viet}', "");
Expect(0, 43743, '\p{^	 Is_Tai_Viet}', "");
Expect(0, 43743, '\P{	 Is_Tai_Viet}', "");
Expect(1, 43743, '\P{^	 Is_Tai_Viet}', "");
Expect(0, 43744, '\p{	 Is_Tai_Viet}', "");
Expect(1, 43744, '\p{^	 Is_Tai_Viet}', "");
Expect(1, 43744, '\P{	 Is_Tai_Viet}', "");
Expect(0, 43744, '\P{^	 Is_Tai_Viet}', "");
Error('\p{ /a/tavt}');
Error('\P{ /a/tavt}');
Expect(1, 43743, '\p{tavt}', "");
Expect(0, 43743, '\p{^tavt}', "");
Expect(0, 43743, '\P{tavt}', "");
Expect(1, 43743, '\P{^tavt}', "");
Expect(0, 43744, '\p{tavt}', "");
Expect(1, 43744, '\p{^tavt}', "");
Expect(1, 43744, '\P{tavt}', "");
Expect(0, 43744, '\P{^tavt}', "");
Expect(1, 43743, '\p{ TAVT}', "");
Expect(0, 43743, '\p{^ TAVT}', "");
Expect(0, 43743, '\P{ TAVT}', "");
Expect(1, 43743, '\P{^ TAVT}', "");
Expect(0, 43744, '\p{ TAVT}', "");
Expect(1, 43744, '\p{^ TAVT}', "");
Expect(1, 43744, '\P{ TAVT}', "");
Expect(0, 43744, '\P{^ TAVT}', "");
Error('\p{ Is_Tavt:=}');
Error('\P{ Is_Tavt:=}');
Expect(1, 43743, '\p{istavt}', "");
Expect(0, 43743, '\p{^istavt}', "");
Expect(0, 43743, '\P{istavt}', "");
Expect(1, 43743, '\P{^istavt}', "");
Expect(0, 43744, '\p{istavt}', "");
Expect(1, 43744, '\p{^istavt}', "");
Expect(1, 43744, '\P{istavt}', "");
Expect(0, 43744, '\P{^istavt}', "");
Expect(1, 43743, '\p{-is_TAVT}', "");
Expect(0, 43743, '\p{^-is_TAVT}', "");
Expect(0, 43743, '\P{-is_TAVT}', "");
Expect(1, 43743, '\P{^-is_TAVT}', "");
Expect(0, 43744, '\p{-is_TAVT}', "");
Expect(1, 43744, '\p{^-is_TAVT}', "");
Expect(1, 43744, '\P{-is_TAVT}', "");
Expect(0, 43744, '\P{^-is_TAVT}', "");
Error('\p{	 tai_Xuan_jing_Symbols/a/}');
Error('\P{	 tai_Xuan_jing_Symbols/a/}');
Expect(1, 119647, '\p{taixuanjingsymbols}', "");
Expect(0, 119647, '\p{^taixuanjingsymbols}', "");
Expect(0, 119647, '\P{taixuanjingsymbols}', "");
Expect(1, 119647, '\P{^taixuanjingsymbols}', "");
Expect(0, 119648, '\p{taixuanjingsymbols}', "");
Expect(1, 119648, '\p{^taixuanjingsymbols}', "");
Expect(1, 119648, '\P{taixuanjingsymbols}', "");
Expect(0, 119648, '\P{^taixuanjingsymbols}', "");
Expect(1, 119647, '\p{	 TAI_xuan_jing_symbols}', "");
Expect(0, 119647, '\p{^	 TAI_xuan_jing_symbols}', "");
Expect(0, 119647, '\P{	 TAI_xuan_jing_symbols}', "");
Expect(1, 119647, '\P{^	 TAI_xuan_jing_symbols}', "");
Expect(0, 119648, '\p{	 TAI_xuan_jing_symbols}', "");
Expect(1, 119648, '\p{^	 TAI_xuan_jing_symbols}', "");
Expect(1, 119648, '\P{	 TAI_xuan_jing_symbols}', "");
Expect(0, 119648, '\P{^	 TAI_xuan_jing_symbols}', "");
Error('\p{:=-	is_TAI_XUAN_Jing_Symbols}');
Error('\P{:=-	is_TAI_XUAN_Jing_Symbols}');
Expect(1, 119647, '\p{istaixuanjingsymbols}', "");
Expect(0, 119647, '\p{^istaixuanjingsymbols}', "");
Expect(0, 119647, '\P{istaixuanjingsymbols}', "");
Expect(1, 119647, '\P{^istaixuanjingsymbols}', "");
Expect(0, 119648, '\p{istaixuanjingsymbols}', "");
Expect(1, 119648, '\p{^istaixuanjingsymbols}', "");
Expect(1, 119648, '\P{istaixuanjingsymbols}', "");
Expect(0, 119648, '\P{^istaixuanjingsymbols}', "");
Expect(1, 119647, '\p{	Is_Tai_Xuan_jing_Symbols}', "");
Expect(0, 119647, '\p{^	Is_Tai_Xuan_jing_Symbols}', "");
Expect(0, 119647, '\P{	Is_Tai_Xuan_jing_Symbols}', "");
Expect(1, 119647, '\P{^	Is_Tai_Xuan_jing_Symbols}', "");
Expect(0, 119648, '\p{	Is_Tai_Xuan_jing_Symbols}', "");
Expect(1, 119648, '\p{^	Is_Tai_Xuan_jing_Symbols}', "");
Expect(1, 119648, '\P{	Is_Tai_Xuan_jing_Symbols}', "");
Expect(0, 119648, '\P{^	Is_Tai_Xuan_jing_Symbols}', "");
Error('\p{/a/_	in_TAI_Xuan_jing_Symbols}');
Error('\P{/a/_	in_TAI_Xuan_jing_Symbols}');
Expect(1, 119647, '\p{intaixuanjingsymbols}', "");
Expect(0, 119647, '\p{^intaixuanjingsymbols}', "");
Expect(0, 119647, '\P{intaixuanjingsymbols}', "");
Expect(1, 119647, '\P{^intaixuanjingsymbols}', "");
Expect(0, 119648, '\p{intaixuanjingsymbols}', "");
Expect(1, 119648, '\p{^intaixuanjingsymbols}', "");
Expect(1, 119648, '\P{intaixuanjingsymbols}', "");
Expect(0, 119648, '\P{^intaixuanjingsymbols}', "");
Expect(1, 119647, '\p{	_In_TAI_Xuan_Jing_symbols}', "");
Expect(0, 119647, '\p{^	_In_TAI_Xuan_Jing_symbols}', "");
Expect(0, 119647, '\P{	_In_TAI_Xuan_Jing_symbols}', "");
Expect(1, 119647, '\P{^	_In_TAI_Xuan_Jing_symbols}', "");
Expect(0, 119648, '\p{	_In_TAI_Xuan_Jing_symbols}', "");
Expect(1, 119648, '\p{^	_In_TAI_Xuan_Jing_symbols}', "");
Expect(1, 119648, '\P{	_In_TAI_Xuan_Jing_symbols}', "");
Expect(0, 119648, '\P{^	_In_TAI_Xuan_Jing_symbols}', "");
Error('\p{_-TAI_Xuan_Jing:=}');
Error('\P{_-TAI_Xuan_Jing:=}');
Expect(1, 119647, '\p{taixuanjing}', "");
Expect(0, 119647, '\p{^taixuanjing}', "");
Expect(0, 119647, '\P{taixuanjing}', "");
Expect(1, 119647, '\P{^taixuanjing}', "");
Expect(0, 119648, '\p{taixuanjing}', "");
Expect(1, 119648, '\p{^taixuanjing}', "");
Expect(1, 119648, '\P{taixuanjing}', "");
Expect(0, 119648, '\P{^taixuanjing}', "");
Expect(1, 119647, '\p{ _tai_xuan_JING}', "");
Expect(0, 119647, '\p{^ _tai_xuan_JING}', "");
Expect(0, 119647, '\P{ _tai_xuan_JING}', "");
Expect(1, 119647, '\P{^ _tai_xuan_JING}', "");
Expect(0, 119648, '\p{ _tai_xuan_JING}', "");
Expect(1, 119648, '\p{^ _tai_xuan_JING}', "");
Expect(1, 119648, '\P{ _tai_xuan_JING}', "");
Expect(0, 119648, '\P{^ _tai_xuan_JING}', "");
Error('\p{:= _is_tai_Xuan_JING}');
Error('\P{:= _is_tai_Xuan_JING}');
Expect(1, 119647, '\p{istaixuanjing}', "");
Expect(0, 119647, '\p{^istaixuanjing}', "");
Expect(0, 119647, '\P{istaixuanjing}', "");
Expect(1, 119647, '\P{^istaixuanjing}', "");
Expect(0, 119648, '\p{istaixuanjing}', "");
Expect(1, 119648, '\p{^istaixuanjing}', "");
Expect(1, 119648, '\P{istaixuanjing}', "");
Expect(0, 119648, '\P{^istaixuanjing}', "");
Expect(1, 119647, '\p{-	Is_tai_Xuan_jing}', "");
Expect(0, 119647, '\p{^-	Is_tai_Xuan_jing}', "");
Expect(0, 119647, '\P{-	Is_tai_Xuan_jing}', "");
Expect(1, 119647, '\P{^-	Is_tai_Xuan_jing}', "");
Expect(0, 119648, '\p{-	Is_tai_Xuan_jing}', "");
Expect(1, 119648, '\p{^-	Is_tai_Xuan_jing}', "");
Expect(1, 119648, '\P{-	Is_tai_Xuan_jing}', "");
Expect(0, 119648, '\P{^-	Is_tai_Xuan_jing}', "");
Error('\p{-	IN_TAI_xuan_jing/a/}');
Error('\P{-	IN_TAI_xuan_jing/a/}');
Expect(1, 119647, '\p{intaixuanjing}', "");
Expect(0, 119647, '\p{^intaixuanjing}', "");
Expect(0, 119647, '\P{intaixuanjing}', "");
Expect(1, 119647, '\P{^intaixuanjing}', "");
Expect(0, 119648, '\p{intaixuanjing}', "");
Expect(1, 119648, '\p{^intaixuanjing}', "");
Expect(1, 119648, '\P{intaixuanjing}', "");
Expect(0, 119648, '\P{^intaixuanjing}', "");
Expect(1, 119647, '\p{ _IN_Tai_Xuan_jing}', "");
Expect(0, 119647, '\p{^ _IN_Tai_Xuan_jing}', "");
Expect(0, 119647, '\P{ _IN_Tai_Xuan_jing}', "");
Expect(1, 119647, '\P{^ _IN_Tai_Xuan_jing}', "");
Expect(0, 119648, '\p{ _IN_Tai_Xuan_jing}', "");
Expect(1, 119648, '\p{^ _IN_Tai_Xuan_jing}', "");
Expect(1, 119648, '\P{ _IN_Tai_Xuan_jing}', "");
Expect(0, 119648, '\P{^ _IN_Tai_Xuan_jing}', "");
Error('\p{-takri/a/}');
Error('\P{-takri/a/}');
Expect(1, 71369, '\p{takri}', "");
Expect(0, 71369, '\p{^takri}', "");
Expect(0, 71369, '\P{takri}', "");
Expect(1, 71369, '\P{^takri}', "");
Expect(0, 71370, '\p{takri}', "");
Expect(1, 71370, '\p{^takri}', "");
Expect(1, 71370, '\P{takri}', "");
Expect(0, 71370, '\P{^takri}', "");
Expect(1, 71369, '\p{  Takri}', "");
Expect(0, 71369, '\p{^  Takri}', "");
Expect(0, 71369, '\P{  Takri}', "");
Expect(1, 71369, '\P{^  Takri}', "");
Expect(0, 71370, '\p{  Takri}', "");
Expect(1, 71370, '\p{^  Takri}', "");
Expect(1, 71370, '\P{  Takri}', "");
Expect(0, 71370, '\P{^  Takri}', "");
Error('\p{_-IS_takri:=}');
Error('\P{_-IS_takri:=}');
Expect(1, 71369, '\p{istakri}', "");
Expect(0, 71369, '\p{^istakri}', "");
Expect(0, 71369, '\P{istakri}', "");
Expect(1, 71369, '\P{^istakri}', "");
Expect(0, 71370, '\p{istakri}', "");
Expect(1, 71370, '\p{^istakri}', "");
Expect(1, 71370, '\P{istakri}', "");
Expect(0, 71370, '\P{^istakri}', "");
Expect(1, 71369, '\p{_	is_TAKRI}', "");
Expect(0, 71369, '\p{^_	is_TAKRI}', "");
Expect(0, 71369, '\P{_	is_TAKRI}', "");
Expect(1, 71369, '\P{^_	is_TAKRI}', "");
Expect(0, 71370, '\p{_	is_TAKRI}', "");
Expect(1, 71370, '\p{^_	is_TAKRI}', "");
Expect(1, 71370, '\P{_	is_TAKRI}', "");
Expect(0, 71370, '\P{^_	is_TAKRI}', "");
Error('\p{:= 	Takr}');
Error('\P{:= 	Takr}');
Expect(1, 71369, '\p{takr}', "");
Expect(0, 71369, '\p{^takr}', "");
Expect(0, 71369, '\P{takr}', "");
Expect(1, 71369, '\P{^takr}', "");
Expect(0, 71370, '\p{takr}', "");
Expect(1, 71370, '\p{^takr}', "");
Expect(1, 71370, '\P{takr}', "");
Expect(0, 71370, '\P{^takr}', "");
Expect(1, 71369, '\p{--Takr}', "");
Expect(0, 71369, '\p{^--Takr}', "");
Expect(0, 71369, '\P{--Takr}', "");
Expect(1, 71369, '\P{^--Takr}', "");
Expect(0, 71370, '\p{--Takr}', "");
Expect(1, 71370, '\p{^--Takr}', "");
Expect(1, 71370, '\P{--Takr}', "");
Expect(0, 71370, '\P{^--Takr}', "");
Error('\p{_/a/Is_TAKR}');
Error('\P{_/a/Is_TAKR}');
Expect(1, 71369, '\p{istakr}', "");
Expect(0, 71369, '\p{^istakr}', "");
Expect(0, 71369, '\P{istakr}', "");
Expect(1, 71369, '\P{^istakr}', "");
Expect(0, 71370, '\p{istakr}', "");
Expect(1, 71370, '\p{^istakr}', "");
Expect(1, 71370, '\P{istakr}', "");
Expect(0, 71370, '\P{^istakr}', "");
Expect(1, 71369, '\p{-Is_takr}', "");
Expect(0, 71369, '\p{^-Is_takr}', "");
Expect(0, 71369, '\P{-Is_takr}', "");
Expect(1, 71369, '\P{^-Is_takr}', "");
Expect(0, 71370, '\p{-Is_takr}', "");
Expect(1, 71370, '\p{^-Is_takr}', "");
Expect(1, 71370, '\P{-Is_takr}', "");
Expect(0, 71370, '\P{^-Is_takr}', "");
Error('\p{Tamil:=}');
Error('\P{Tamil:=}');
Expect(1, 3066, '\p{tamil}', "");
Expect(0, 3066, '\p{^tamil}', "");
Expect(0, 3066, '\P{tamil}', "");
Expect(1, 3066, '\P{^tamil}', "");
Expect(0, 3067, '\p{tamil}', "");
Expect(1, 3067, '\p{^tamil}', "");
Expect(1, 3067, '\P{tamil}', "");
Expect(0, 3067, '\P{^tamil}', "");
Expect(1, 3066, '\p{-tamil}', "");
Expect(0, 3066, '\p{^-tamil}', "");
Expect(0, 3066, '\P{-tamil}', "");
Expect(1, 3066, '\P{^-tamil}', "");
Expect(0, 3067, '\p{-tamil}', "");
Expect(1, 3067, '\p{^-tamil}', "");
Expect(1, 3067, '\P{-tamil}', "");
Expect(0, 3067, '\P{^-tamil}', "");
Error('\p{/a/__Is_TAMIL}');
Error('\P{/a/__Is_TAMIL}');
Expect(1, 3066, '\p{istamil}', "");
Expect(0, 3066, '\p{^istamil}', "");
Expect(0, 3066, '\P{istamil}', "");
Expect(1, 3066, '\P{^istamil}', "");
Expect(0, 3067, '\p{istamil}', "");
Expect(1, 3067, '\p{^istamil}', "");
Expect(1, 3067, '\P{istamil}', "");
Expect(0, 3067, '\P{^istamil}', "");
Expect(1, 3066, '\p{	_is_tamil}', "");
Expect(0, 3066, '\p{^	_is_tamil}', "");
Expect(0, 3066, '\P{	_is_tamil}', "");
Expect(1, 3066, '\P{^	_is_tamil}', "");
Expect(0, 3067, '\p{	_is_tamil}', "");
Expect(1, 3067, '\p{^	_is_tamil}', "");
Expect(1, 3067, '\P{	_is_tamil}', "");
Expect(0, 3067, '\P{^	_is_tamil}', "");
Error('\p{/a/  Taml}');
Error('\P{/a/  Taml}');
Expect(1, 3066, '\p{taml}', "");
Expect(0, 3066, '\p{^taml}', "");
Expect(0, 3066, '\P{taml}', "");
Expect(1, 3066, '\P{^taml}', "");
Expect(0, 3067, '\p{taml}', "");
Expect(1, 3067, '\p{^taml}', "");
Expect(1, 3067, '\P{taml}', "");
Expect(0, 3067, '\P{^taml}', "");
Expect(1, 3066, '\p{		Taml}', "");
Expect(0, 3066, '\p{^		Taml}', "");
Expect(0, 3066, '\P{		Taml}', "");
Expect(1, 3066, '\P{^		Taml}', "");
Expect(0, 3067, '\p{		Taml}', "");
Expect(1, 3067, '\p{^		Taml}', "");
Expect(1, 3067, '\P{		Taml}', "");
Expect(0, 3067, '\P{^		Taml}', "");
Error('\p{:=_Is_taml}');
Error('\P{:=_Is_taml}');
Expect(1, 3066, '\p{istaml}', "");
Expect(0, 3066, '\p{^istaml}', "");
Expect(0, 3066, '\P{istaml}', "");
Expect(1, 3066, '\P{^istaml}', "");
Expect(0, 3067, '\p{istaml}', "");
Expect(1, 3067, '\p{^istaml}', "");
Expect(1, 3067, '\P{istaml}', "");
Expect(0, 3067, '\P{^istaml}', "");
Expect(1, 3066, '\p{_Is_taml}', "");
Expect(0, 3066, '\p{^_Is_taml}', "");
Expect(0, 3066, '\P{_Is_taml}', "");
Expect(1, 3066, '\P{^_Is_taml}', "");
Expect(0, 3067, '\p{_Is_taml}', "");
Expect(1, 3067, '\p{^_Is_taml}', "");
Expect(1, 3067, '\P{_Is_taml}', "");
Expect(0, 3067, '\P{^_Is_taml}', "");
Error('\p{/a/Telugu}');
Error('\P{/a/Telugu}');
Expect(1, 3199, '\p{telugu}', "");
Expect(0, 3199, '\p{^telugu}', "");
Expect(0, 3199, '\P{telugu}', "");
Expect(1, 3199, '\P{^telugu}', "");
Expect(0, 3200, '\p{telugu}', "");
Expect(1, 3200, '\p{^telugu}', "");
Expect(1, 3200, '\P{telugu}', "");
Expect(0, 3200, '\P{^telugu}', "");
Expect(1, 3199, '\p{_Telugu}', "");
Expect(0, 3199, '\p{^_Telugu}', "");
Expect(0, 3199, '\P{_Telugu}', "");
Expect(1, 3199, '\P{^_Telugu}', "");
Expect(0, 3200, '\p{_Telugu}', "");
Expect(1, 3200, '\p{^_Telugu}', "");
Expect(1, 3200, '\P{_Telugu}', "");
Expect(0, 3200, '\P{^_Telugu}', "");
Error('\p{:= _Is_telugu}');
Error('\P{:= _Is_telugu}');
Expect(1, 3199, '\p{istelugu}', "");
Expect(0, 3199, '\p{^istelugu}', "");
Expect(0, 3199, '\P{istelugu}', "");
Expect(1, 3199, '\P{^istelugu}', "");
Expect(0, 3200, '\p{istelugu}', "");
Expect(1, 3200, '\p{^istelugu}', "");
Expect(1, 3200, '\P{istelugu}', "");
Expect(0, 3200, '\P{^istelugu}', "");
Expect(1, 3199, '\p{_ Is_Telugu}', "");
Expect(0, 3199, '\p{^_ Is_Telugu}', "");
Expect(0, 3199, '\P{_ Is_Telugu}', "");
Expect(1, 3199, '\P{^_ Is_Telugu}', "");
Expect(0, 3200, '\p{_ Is_Telugu}', "");
Expect(1, 3200, '\p{^_ Is_Telugu}', "");
Expect(1, 3200, '\P{_ Is_Telugu}', "");
Expect(0, 3200, '\P{^_ Is_Telugu}', "");
Error('\p{:=-Telu}');
Error('\P{:=-Telu}');
Expect(1, 3199, '\p{telu}', "");
Expect(0, 3199, '\p{^telu}', "");
Expect(0, 3199, '\P{telu}', "");
Expect(1, 3199, '\P{^telu}', "");
Expect(0, 3200, '\p{telu}', "");
Expect(1, 3200, '\p{^telu}', "");
Expect(1, 3200, '\P{telu}', "");
Expect(0, 3200, '\P{^telu}', "");
Expect(1, 3199, '\p{	Telu}', "");
Expect(0, 3199, '\p{^	Telu}', "");
Expect(0, 3199, '\P{	Telu}', "");
Expect(1, 3199, '\P{^	Telu}', "");
Expect(0, 3200, '\p{	Telu}', "");
Expect(1, 3200, '\p{^	Telu}', "");
Expect(1, 3200, '\P{	Telu}', "");
Expect(0, 3200, '\P{^	Telu}', "");
Error('\p{_/a/IS_TELU}');
Error('\P{_/a/IS_TELU}');
Expect(1, 3199, '\p{istelu}', "");
Expect(0, 3199, '\p{^istelu}', "");
Expect(0, 3199, '\P{istelu}', "");
Expect(1, 3199, '\P{^istelu}', "");
Expect(0, 3200, '\p{istelu}', "");
Expect(1, 3200, '\p{^istelu}', "");
Expect(1, 3200, '\P{istelu}', "");
Expect(0, 3200, '\P{^istelu}', "");
Expect(1, 3199, '\p{	Is_Telu}', "");
Expect(0, 3199, '\p{^	Is_Telu}', "");
Expect(0, 3199, '\P{	Is_Telu}', "");
Expect(1, 3199, '\P{^	Is_Telu}', "");
Expect(0, 3200, '\p{	Is_Telu}', "");
Expect(1, 3200, '\p{^	Is_Telu}', "");
Expect(1, 3200, '\P{	Is_Telu}', "");
Expect(0, 3200, '\P{^	Is_Telu}', "");
Error('\p{_/a/Terminal_punctuation}');
Error('\P{_/a/Terminal_punctuation}');
Expect(1, 74867, '\p{terminalpunctuation}', "");
Expect(0, 74867, '\p{^terminalpunctuation}', "");
Expect(0, 74867, '\P{terminalpunctuation}', "");
Expect(1, 74867, '\P{^terminalpunctuation}', "");
Expect(0, 74868, '\p{terminalpunctuation}', "");
Expect(1, 74868, '\p{^terminalpunctuation}', "");
Expect(1, 74868, '\P{terminalpunctuation}', "");
Expect(0, 74868, '\P{^terminalpunctuation}', "");
Expect(1, 74867, '\p{	_terminal_Punctuation}', "");
Expect(0, 74867, '\p{^	_terminal_Punctuation}', "");
Expect(0, 74867, '\P{	_terminal_Punctuation}', "");
Expect(1, 74867, '\P{^	_terminal_Punctuation}', "");
Expect(0, 74868, '\p{	_terminal_Punctuation}', "");
Expect(1, 74868, '\p{^	_terminal_Punctuation}', "");
Expect(1, 74868, '\P{	_terminal_Punctuation}', "");
Expect(0, 74868, '\P{^	_terminal_Punctuation}', "");
Error('\p{/a/_-Is_TERMINAL_Punctuation}');
Error('\P{/a/_-Is_TERMINAL_Punctuation}');
Expect(1, 74867, '\p{isterminalpunctuation}', "");
Expect(0, 74867, '\p{^isterminalpunctuation}', "");
Expect(0, 74867, '\P{isterminalpunctuation}', "");
Expect(1, 74867, '\P{^isterminalpunctuation}', "");
Expect(0, 74868, '\p{isterminalpunctuation}', "");
Expect(1, 74868, '\p{^isterminalpunctuation}', "");
Expect(1, 74868, '\P{isterminalpunctuation}', "");
Expect(0, 74868, '\P{^isterminalpunctuation}', "");
Expect(1, 74867, '\p{	-IS_Terminal_Punctuation}', "");
Expect(0, 74867, '\p{^	-IS_Terminal_Punctuation}', "");
Expect(0, 74867, '\P{	-IS_Terminal_Punctuation}', "");
Expect(1, 74867, '\P{^	-IS_Terminal_Punctuation}', "");
Expect(0, 74868, '\p{	-IS_Terminal_Punctuation}', "");
Expect(1, 74868, '\p{^	-IS_Terminal_Punctuation}', "");
Expect(1, 74868, '\P{	-IS_Terminal_Punctuation}', "");
Expect(0, 74868, '\P{^	-IS_Terminal_Punctuation}', "");
Error('\p{-_Term/a/}');
Error('\P{-_Term/a/}');
Expect(1, 74867, '\p{term}', "");
Expect(0, 74867, '\p{^term}', "");
Expect(0, 74867, '\P{term}', "");
Expect(1, 74867, '\P{^term}', "");
Expect(0, 74868, '\p{term}', "");
Expect(1, 74868, '\p{^term}', "");
Expect(1, 74868, '\P{term}', "");
Expect(0, 74868, '\P{^term}', "");
Expect(1, 74867, '\p{	Term}', "");
Expect(0, 74867, '\p{^	Term}', "");
Expect(0, 74867, '\P{	Term}', "");
Expect(1, 74867, '\P{^	Term}', "");
Expect(0, 74868, '\p{	Term}', "");
Expect(1, 74868, '\p{^	Term}', "");
Expect(1, 74868, '\P{	Term}', "");
Expect(0, 74868, '\P{^	Term}', "");
Error('\p{/a/IS_Term}');
Error('\P{/a/IS_Term}');
Expect(1, 74867, '\p{isterm}', "");
Expect(0, 74867, '\p{^isterm}', "");
Expect(0, 74867, '\P{isterm}', "");
Expect(1, 74867, '\P{^isterm}', "");
Expect(0, 74868, '\p{isterm}', "");
Expect(1, 74868, '\p{^isterm}', "");
Expect(1, 74868, '\P{isterm}', "");
Expect(0, 74868, '\P{^isterm}', "");
Expect(1, 74867, '\p{-	Is_Term}', "");
Expect(0, 74867, '\p{^-	Is_Term}', "");
Expect(0, 74867, '\P{-	Is_Term}', "");
Expect(1, 74867, '\P{^-	Is_Term}', "");
Expect(0, 74868, '\p{-	Is_Term}', "");
Expect(1, 74868, '\p{^-	Is_Term}', "");
Expect(1, 74868, '\P{-	Is_Term}', "");
Expect(0, 74868, '\P{^-	Is_Term}', "");
Error('\p{/a/- Thaana}');
Error('\P{/a/- Thaana}');
Expect(1, 1969, '\p{thaana}', "");
Expect(0, 1969, '\p{^thaana}', "");
Expect(0, 1969, '\P{thaana}', "");
Expect(1, 1969, '\P{^thaana}', "");
Expect(0, 1970, '\p{thaana}', "");
Expect(1, 1970, '\p{^thaana}', "");
Expect(1, 1970, '\P{thaana}', "");
Expect(0, 1970, '\P{^thaana}', "");
Error('\p{ Is_Thaana:=}');
Error('\P{ Is_Thaana:=}');
Expect(1, 1969, '\p{isthaana}', "");
Expect(0, 1969, '\p{^isthaana}', "");
Expect(0, 1969, '\P{isthaana}', "");
Expect(1, 1969, '\P{^isthaana}', "");
Expect(0, 1970, '\p{isthaana}', "");
Expect(1, 1970, '\p{^isthaana}', "");
Expect(1, 1970, '\P{isthaana}', "");
Expect(0, 1970, '\P{^isthaana}', "");
Expect(1, 1969, '\p{- Is_thaana}', "");
Expect(0, 1969, '\p{^- Is_thaana}', "");
Expect(0, 1969, '\P{- Is_thaana}', "");
Expect(1, 1969, '\P{^- Is_thaana}', "");
Expect(0, 1970, '\p{- Is_thaana}', "");
Expect(1, 1970, '\p{^- Is_thaana}', "");
Expect(1, 1970, '\P{- Is_thaana}', "");
Expect(0, 1970, '\P{^- Is_thaana}', "");
Error('\p{-	THAA/a/}');
Error('\P{-	THAA/a/}');
Expect(1, 1969, '\p{thaa}', "");
Expect(0, 1969, '\p{^thaa}', "");
Expect(0, 1969, '\P{thaa}', "");
Expect(1, 1969, '\P{^thaa}', "");
Expect(0, 1970, '\p{thaa}', "");
Expect(1, 1970, '\p{^thaa}', "");
Expect(1, 1970, '\P{thaa}', "");
Expect(0, 1970, '\P{^thaa}', "");
Expect(1, 1969, '\p{_-Thaa}', "");
Expect(0, 1969, '\p{^_-Thaa}', "");
Expect(0, 1969, '\P{_-Thaa}', "");
Expect(1, 1969, '\P{^_-Thaa}', "");
Expect(0, 1970, '\p{_-Thaa}', "");
Expect(1, 1970, '\p{^_-Thaa}', "");
Expect(1, 1970, '\P{_-Thaa}', "");
Expect(0, 1970, '\P{^_-Thaa}', "");
Error('\p{/a/_	Is_Thaa}');
Error('\P{/a/_	Is_Thaa}');
Expect(1, 1969, '\p{isthaa}', "");
Expect(0, 1969, '\p{^isthaa}', "");
Expect(0, 1969, '\P{isthaa}', "");
Expect(1, 1969, '\P{^isthaa}', "");
Expect(0, 1970, '\p{isthaa}', "");
Expect(1, 1970, '\p{^isthaa}', "");
Expect(1, 1970, '\P{isthaa}', "");
Expect(0, 1970, '\P{^isthaa}', "");
Expect(1, 1969, '\p{_	Is_Thaa}', "");
Expect(0, 1969, '\p{^_	Is_Thaa}', "");
Expect(0, 1969, '\P{_	Is_Thaa}', "");
Expect(1, 1969, '\P{^_	Is_Thaa}', "");
Expect(0, 1970, '\p{_	Is_Thaa}', "");
Expect(1, 1970, '\p{^_	Is_Thaa}', "");
Expect(1, 1970, '\P{_	Is_Thaa}', "");
Expect(0, 1970, '\P{^_	Is_Thaa}', "");
Error('\p{ /a/thai}');
Error('\P{ /a/thai}');
Expect(1, 3675, '\p{thai}', "");
Expect(0, 3675, '\p{^thai}', "");
Expect(0, 3675, '\P{thai}', "");
Expect(1, 3675, '\P{^thai}', "");
Expect(0, 3676, '\p{thai}', "");
Expect(1, 3676, '\p{^thai}', "");
Expect(1, 3676, '\P{thai}', "");
Expect(0, 3676, '\P{^thai}', "");
Expect(1, 3675, '\p{ -thai}', "");
Expect(0, 3675, '\p{^ -thai}', "");
Expect(0, 3675, '\P{ -thai}', "");
Expect(1, 3675, '\P{^ -thai}', "");
Expect(0, 3676, '\p{ -thai}', "");
Expect(1, 3676, '\p{^ -thai}', "");
Expect(1, 3676, '\P{ -thai}', "");
Expect(0, 3676, '\P{^ -thai}', "");
Error('\p{-_IS_Thai/a/}');
Error('\P{-_IS_Thai/a/}');
Expect(1, 3675, '\p{isthai}', "");
Expect(0, 3675, '\p{^isthai}', "");
Expect(0, 3675, '\P{isthai}', "");
Expect(1, 3675, '\P{^isthai}', "");
Expect(0, 3676, '\p{isthai}', "");
Expect(1, 3676, '\p{^isthai}', "");
Expect(1, 3676, '\P{isthai}', "");
Expect(0, 3676, '\P{^isthai}', "");
Expect(1, 3675, '\p{	_Is_THAI}', "");
Expect(0, 3675, '\p{^	_Is_THAI}', "");
Expect(0, 3675, '\P{	_Is_THAI}', "");
Expect(1, 3675, '\P{^	_Is_THAI}', "");
Expect(0, 3676, '\p{	_Is_THAI}', "");
Expect(1, 3676, '\p{^	_Is_THAI}', "");
Expect(1, 3676, '\P{	_Is_THAI}', "");
Expect(0, 3676, '\P{^	_Is_THAI}', "");
Error('\p{	 TIBETAN/a/}');
Error('\P{	 TIBETAN/a/}');
Expect(1, 4058, '\p{tibetan}', "");
Expect(0, 4058, '\p{^tibetan}', "");
Expect(0, 4058, '\P{tibetan}', "");
Expect(1, 4058, '\P{^tibetan}', "");
Expect(0, 4059, '\p{tibetan}', "");
Expect(1, 4059, '\p{^tibetan}', "");
Expect(1, 4059, '\P{tibetan}', "");
Expect(0, 4059, '\P{^tibetan}', "");
Expect(1, 4058, '\p{		tibetan}', "");
Expect(0, 4058, '\p{^		tibetan}', "");
Expect(0, 4058, '\P{		tibetan}', "");
Expect(1, 4058, '\P{^		tibetan}', "");
Expect(0, 4059, '\p{		tibetan}', "");
Expect(1, 4059, '\p{^		tibetan}', "");
Expect(1, 4059, '\P{		tibetan}', "");
Expect(0, 4059, '\P{^		tibetan}', "");
Error('\p{--Is_Tibetan/a/}');
Error('\P{--Is_Tibetan/a/}');
Expect(1, 4058, '\p{istibetan}', "");
Expect(0, 4058, '\p{^istibetan}', "");
Expect(0, 4058, '\P{istibetan}', "");
Expect(1, 4058, '\P{^istibetan}', "");
Expect(0, 4059, '\p{istibetan}', "");
Expect(1, 4059, '\p{^istibetan}', "");
Expect(1, 4059, '\P{istibetan}', "");
Expect(0, 4059, '\P{^istibetan}', "");
Expect(1, 4058, '\p{_IS_tibetan}', "");
Expect(0, 4058, '\p{^_IS_tibetan}', "");
Expect(0, 4058, '\P{_IS_tibetan}', "");
Expect(1, 4058, '\P{^_IS_tibetan}', "");
Expect(0, 4059, '\p{_IS_tibetan}', "");
Expect(1, 4059, '\p{^_IS_tibetan}', "");
Expect(1, 4059, '\P{_IS_tibetan}', "");
Expect(0, 4059, '\P{^_IS_tibetan}', "");
Error('\p{/a/	-Tibt}');
Error('\P{/a/	-Tibt}');
Expect(1, 4058, '\p{tibt}', "");
Expect(0, 4058, '\p{^tibt}', "");
Expect(0, 4058, '\P{tibt}', "");
Expect(1, 4058, '\P{^tibt}', "");
Expect(0, 4059, '\p{tibt}', "");
Expect(1, 4059, '\p{^tibt}', "");
Expect(1, 4059, '\P{tibt}', "");
Expect(0, 4059, '\P{^tibt}', "");
Expect(1, 4058, '\p{	Tibt}', "");
Expect(0, 4058, '\p{^	Tibt}', "");
Expect(0, 4058, '\P{	Tibt}', "");
Expect(1, 4058, '\P{^	Tibt}', "");
Expect(0, 4059, '\p{	Tibt}', "");
Expect(1, 4059, '\p{^	Tibt}', "");
Expect(1, 4059, '\P{	Tibt}', "");
Expect(0, 4059, '\P{^	Tibt}', "");
Error('\p{:=	 Is_TIBT}');
Error('\P{:=	 Is_TIBT}');
Expect(1, 4058, '\p{istibt}', "");
Expect(0, 4058, '\p{^istibt}', "");
Expect(0, 4058, '\P{istibt}', "");
Expect(1, 4058, '\P{^istibt}', "");
Expect(0, 4059, '\p{istibt}', "");
Expect(1, 4059, '\p{^istibt}', "");
Expect(1, 4059, '\P{istibt}', "");
Expect(0, 4059, '\P{^istibt}', "");
Expect(1, 4058, '\p{		IS_tibt}', "");
Expect(0, 4058, '\p{^		IS_tibt}', "");
Expect(0, 4058, '\P{		IS_tibt}', "");
Expect(1, 4058, '\P{^		IS_tibt}', "");
Expect(0, 4059, '\p{		IS_tibt}', "");
Expect(1, 4059, '\p{^		IS_tibt}', "");
Expect(1, 4059, '\P{		IS_tibt}', "");
Expect(0, 4059, '\P{^		IS_tibt}', "");
Error('\p{:=  Tifinagh}');
Error('\P{:=  Tifinagh}');
Expect(1, 11647, '\p{tifinagh}', "");
Expect(0, 11647, '\p{^tifinagh}', "");
Expect(0, 11647, '\P{tifinagh}', "");
Expect(1, 11647, '\P{^tifinagh}', "");
Expect(0, 11648, '\p{tifinagh}', "");
Expect(1, 11648, '\p{^tifinagh}', "");
Expect(1, 11648, '\P{tifinagh}', "");
Expect(0, 11648, '\P{^tifinagh}', "");
Expect(1, 11647, '\p{  TIFINAGH}', "");
Expect(0, 11647, '\p{^  TIFINAGH}', "");
Expect(0, 11647, '\P{  TIFINAGH}', "");
Expect(1, 11647, '\P{^  TIFINAGH}', "");
Expect(0, 11648, '\p{  TIFINAGH}', "");
Expect(1, 11648, '\p{^  TIFINAGH}', "");
Expect(1, 11648, '\P{  TIFINAGH}', "");
Expect(0, 11648, '\P{^  TIFINAGH}', "");
Error('\p{:=  Is_TIFINAGH}');
Error('\P{:=  Is_TIFINAGH}');
Expect(1, 11647, '\p{istifinagh}', "");
Expect(0, 11647, '\p{^istifinagh}', "");
Expect(0, 11647, '\P{istifinagh}', "");
Expect(1, 11647, '\P{^istifinagh}', "");
Expect(0, 11648, '\p{istifinagh}', "");
Expect(1, 11648, '\p{^istifinagh}', "");
Expect(1, 11648, '\P{istifinagh}', "");
Expect(0, 11648, '\P{^istifinagh}', "");
Expect(1, 11647, '\p{-	Is_Tifinagh}', "");
Expect(0, 11647, '\p{^-	Is_Tifinagh}', "");
Expect(0, 11647, '\P{-	Is_Tifinagh}', "");
Expect(1, 11647, '\P{^-	Is_Tifinagh}', "");
Expect(0, 11648, '\p{-	Is_Tifinagh}', "");
Expect(1, 11648, '\p{^-	Is_Tifinagh}', "");
Expect(1, 11648, '\P{-	Is_Tifinagh}', "");
Expect(0, 11648, '\P{^-	Is_Tifinagh}', "");
Error('\p{:=-TFNG}');
Error('\P{:=-TFNG}');
Expect(1, 11647, '\p{tfng}', "");
Expect(0, 11647, '\p{^tfng}', "");
Expect(0, 11647, '\P{tfng}', "");
Expect(1, 11647, '\P{^tfng}', "");
Expect(0, 11648, '\p{tfng}', "");
Expect(1, 11648, '\p{^tfng}', "");
Expect(1, 11648, '\P{tfng}', "");
Expect(0, 11648, '\P{^tfng}', "");
Expect(1, 11647, '\p{-tfng}', "");
Expect(0, 11647, '\p{^-tfng}', "");
Expect(0, 11647, '\P{-tfng}', "");
Expect(1, 11647, '\P{^-tfng}', "");
Expect(0, 11648, '\p{-tfng}', "");
Expect(1, 11648, '\p{^-tfng}', "");
Expect(1, 11648, '\P{-tfng}', "");
Expect(0, 11648, '\P{^-tfng}', "");
Error('\p{- is_Tfng/a/}');
Error('\P{- is_Tfng/a/}');
Expect(1, 11647, '\p{istfng}', "");
Expect(0, 11647, '\p{^istfng}', "");
Expect(0, 11647, '\P{istfng}', "");
Expect(1, 11647, '\P{^istfng}', "");
Expect(0, 11648, '\p{istfng}', "");
Expect(1, 11648, '\p{^istfng}', "");
Expect(1, 11648, '\P{istfng}', "");
Expect(0, 11648, '\P{^istfng}', "");
Expect(1, 11647, '\p{ IS_tfng}', "");
Expect(0, 11647, '\p{^ IS_tfng}', "");
Expect(0, 11647, '\P{ IS_tfng}', "");
Expect(1, 11647, '\P{^ IS_tfng}', "");
Expect(0, 11648, '\p{ IS_tfng}', "");
Expect(1, 11648, '\p{^ IS_tfng}', "");
Expect(1, 11648, '\P{ IS_tfng}', "");
Expect(0, 11648, '\P{^ IS_tfng}', "");
Error('\p{-titlecase/a/}');
Error('\P{-titlecase/a/}');
Expect(1, 8188, '\p{titlecase}', "");
Expect(0, 8188, '\p{^titlecase}', "");
Expect(0, 8188, '\P{titlecase}', "");
Expect(1, 8188, '\P{^titlecase}', "");
Expect(0, 8189, '\p{titlecase}', "");
Expect(1, 8189, '\p{^titlecase}', "");
Expect(1, 8189, '\P{titlecase}', "");
Expect(0, 8189, '\P{^titlecase}', "");
Expect(1, 8188, '\p{--TITLECASE}', "");
Expect(0, 8188, '\p{^--TITLECASE}', "");
Expect(0, 8188, '\P{--TITLECASE}', "");
Expect(1, 8188, '\P{^--TITLECASE}', "");
Expect(0, 8189, '\p{--TITLECASE}', "");
Expect(1, 8189, '\p{^--TITLECASE}', "");
Expect(1, 8189, '\P{--TITLECASE}', "");
Expect(0, 8189, '\P{^--TITLECASE}', "");
Error('\p{ title:=}');
Error('\P{ title:=}');
Expect(1, 8188, '\p{title}', "");
Expect(0, 8188, '\p{^title}', "");
Expect(0, 8188, '\P{title}', "");
Expect(1, 8188, '\P{^title}', "");
Expect(0, 8189, '\p{title}', "");
Expect(1, 8189, '\p{^title}', "");
Expect(1, 8189, '\P{title}', "");
Expect(0, 8189, '\P{^title}', "");
Expect(1, 8188, '\p{_-TITLE}', "");
Expect(0, 8188, '\p{^_-TITLE}', "");
Expect(0, 8188, '\P{_-TITLE}', "");
Expect(1, 8188, '\P{^_-TITLE}', "");
Expect(0, 8189, '\p{_-TITLE}', "");
Expect(1, 8189, '\p{^_-TITLE}', "");
Expect(1, 8189, '\P{_-TITLE}', "");
Expect(0, 8189, '\P{^_-TITLE}', "");
Error('\p{_is_TITLECASE/a/}');
Error('\P{_is_TITLECASE/a/}');
Expect(1, 8188, '\p{istitlecase}', "");
Expect(0, 8188, '\p{^istitlecase}', "");
Expect(0, 8188, '\P{istitlecase}', "");
Expect(1, 8188, '\P{^istitlecase}', "");
Expect(0, 8189, '\p{istitlecase}', "");
Expect(1, 8189, '\p{^istitlecase}', "");
Expect(1, 8189, '\P{istitlecase}', "");
Expect(0, 8189, '\P{^istitlecase}', "");
Expect(1, 8188, '\p{ -Is_TITLECASE}', "");
Expect(0, 8188, '\p{^ -Is_TITLECASE}', "");
Expect(0, 8188, '\P{ -Is_TITLECASE}', "");
Expect(1, 8188, '\P{^ -Is_TITLECASE}', "");
Expect(0, 8189, '\p{ -Is_TITLECASE}', "");
Expect(1, 8189, '\p{^ -Is_TITLECASE}', "");
Expect(1, 8189, '\P{ -Is_TITLECASE}', "");
Expect(0, 8189, '\P{^ -Is_TITLECASE}', "");
Error('\p{- Is_title/a/}');
Error('\P{- Is_title/a/}');
Expect(1, 8188, '\p{istitle}', "");
Expect(0, 8188, '\p{^istitle}', "");
Expect(0, 8188, '\P{istitle}', "");
Expect(1, 8188, '\P{^istitle}', "");
Expect(0, 8189, '\p{istitle}', "");
Expect(1, 8189, '\p{^istitle}', "");
Expect(1, 8189, '\P{istitle}', "");
Expect(0, 8189, '\P{^istitle}', "");
Expect(1, 8188, '\p{ 	IS_title}', "");
Expect(0, 8188, '\p{^ 	IS_title}', "");
Expect(0, 8188, '\P{ 	IS_title}', "");
Expect(1, 8188, '\P{^ 	IS_title}', "");
Expect(0, 8189, '\p{ 	IS_title}', "");
Expect(1, 8189, '\p{^ 	IS_title}', "");
Expect(1, 8189, '\P{ 	IS_title}', "");
Expect(0, 8189, '\P{^ 	IS_title}', "");
Error('\p{ /a/Titlecase_Letter}');
Error('\P{ /a/Titlecase_Letter}');
Expect(1, 8188, '\p{titlecaseletter}', "");
Expect(0, 8188, '\p{^titlecaseletter}', "");
Expect(0, 8188, '\P{titlecaseletter}', "");
Expect(1, 8188, '\P{^titlecaseletter}', "");
Expect(0, 8189, '\p{titlecaseletter}', "");
Expect(1, 8189, '\p{^titlecaseletter}', "");
Expect(1, 8189, '\P{titlecaseletter}', "");
Expect(0, 8189, '\P{^titlecaseletter}', "");
Expect(1, 8188, '\p{  TITLECASE_letter}', "");
Expect(0, 8188, '\p{^  TITLECASE_letter}', "");
Expect(0, 8188, '\P{  TITLECASE_letter}', "");
Expect(1, 8188, '\P{^  TITLECASE_letter}', "");
Expect(0, 8189, '\p{  TITLECASE_letter}', "");
Expect(1, 8189, '\p{^  TITLECASE_letter}', "");
Expect(1, 8189, '\P{  TITLECASE_letter}', "");
Expect(0, 8189, '\P{^  TITLECASE_letter}', "");
Error('\p{	:=IS_TITLECASE_Letter}');
Error('\P{	:=IS_TITLECASE_Letter}');
Expect(1, 8188, '\p{istitlecaseletter}', "");
Expect(0, 8188, '\p{^istitlecaseletter}', "");
Expect(0, 8188, '\P{istitlecaseletter}', "");
Expect(1, 8188, '\P{^istitlecaseletter}', "");
Expect(0, 8189, '\p{istitlecaseletter}', "");
Expect(1, 8189, '\p{^istitlecaseletter}', "");
Expect(1, 8189, '\P{istitlecaseletter}', "");
Expect(0, 8189, '\P{^istitlecaseletter}', "");
Expect(1, 8188, '\p{- Is_titlecase_letter}', "");
Expect(0, 8188, '\p{^- Is_titlecase_letter}', "");
Expect(0, 8188, '\P{- Is_titlecase_letter}', "");
Expect(1, 8188, '\P{^- Is_titlecase_letter}', "");
Expect(0, 8189, '\p{- Is_titlecase_letter}', "");
Expect(1, 8189, '\p{^- Is_titlecase_letter}', "");
Expect(1, 8189, '\P{- Is_titlecase_letter}', "");
Expect(0, 8189, '\P{^- Is_titlecase_letter}', "");
Error('\p{	/a/lt}');
Error('\P{	/a/lt}');
Expect(1, 8188, '\p{lt}', "");
Expect(0, 8188, '\p{^lt}', "");
Expect(0, 8188, '\P{lt}', "");
Expect(1, 8188, '\P{^lt}', "");
Expect(0, 8189, '\p{lt}', "");
Expect(1, 8189, '\p{^lt}', "");
Expect(1, 8189, '\P{lt}', "");
Expect(0, 8189, '\P{^lt}', "");
Expect(1, 8188, '\p{Lt}', "");
Expect(0, 8188, '\p{^Lt}', "");
Expect(0, 8188, '\P{Lt}', "");
Expect(1, 8188, '\P{^Lt}', "");
Expect(0, 8189, '\p{Lt}', "");
Expect(1, 8189, '\p{^Lt}', "");
Expect(1, 8189, '\P{Lt}', "");
Expect(0, 8189, '\P{^Lt}', "");
Error('\p{ :=IS_lt}');
Error('\P{ :=IS_lt}');
Expect(1, 8188, '\p{islt}', "");
Expect(0, 8188, '\p{^islt}', "");
Expect(0, 8188, '\P{islt}', "");
Expect(1, 8188, '\P{^islt}', "");
Expect(0, 8189, '\p{islt}', "");
Expect(1, 8189, '\p{^islt}', "");
Expect(1, 8189, '\P{islt}', "");
Expect(0, 8189, '\P{^islt}', "");
Expect(1, 8188, '\p{_Is_Lt}', "");
Expect(0, 8188, '\p{^_Is_Lt}', "");
Expect(0, 8188, '\P{_Is_Lt}', "");
Expect(1, 8188, '\P{^_Is_Lt}', "");
Expect(0, 8189, '\p{_Is_Lt}', "");
Expect(1, 8189, '\p{^_Is_Lt}', "");
Expect(1, 8189, '\P{_Is_Lt}', "");
Expect(0, 8189, '\P{^_Is_Lt}', "");
Error('\p{:= 	transport_And_MAP_Symbols}');
Error('\P{:= 	transport_And_MAP_Symbols}');
Expect(1, 128767, '\p{transportandmapsymbols}', "");
Expect(0, 128767, '\p{^transportandmapsymbols}', "");
Expect(0, 128767, '\P{transportandmapsymbols}', "");
Expect(1, 128767, '\P{^transportandmapsymbols}', "");
Expect(0, 128768, '\p{transportandmapsymbols}', "");
Expect(1, 128768, '\p{^transportandmapsymbols}', "");
Expect(1, 128768, '\P{transportandmapsymbols}', "");
Expect(0, 128768, '\P{^transportandmapsymbols}', "");
Expect(1, 128767, '\p{_	Transport_And_map_Symbols}', "");
Expect(0, 128767, '\p{^_	Transport_And_map_Symbols}', "");
Expect(0, 128767, '\P{_	Transport_And_map_Symbols}', "");
Expect(1, 128767, '\P{^_	Transport_And_map_Symbols}', "");
Expect(0, 128768, '\p{_	Transport_And_map_Symbols}', "");
Expect(1, 128768, '\p{^_	Transport_And_map_Symbols}', "");
Expect(1, 128768, '\P{_	Transport_And_map_Symbols}', "");
Expect(0, 128768, '\P{^_	Transport_And_map_Symbols}', "");
Error('\p{  is_Transport_And_map_SYMBOLS:=}');
Error('\P{  is_Transport_And_map_SYMBOLS:=}');
Expect(1, 128767, '\p{istransportandmapsymbols}', "");
Expect(0, 128767, '\p{^istransportandmapsymbols}', "");
Expect(0, 128767, '\P{istransportandmapsymbols}', "");
Expect(1, 128767, '\P{^istransportandmapsymbols}', "");
Expect(0, 128768, '\p{istransportandmapsymbols}', "");
Expect(1, 128768, '\p{^istransportandmapsymbols}', "");
Expect(1, 128768, '\P{istransportandmapsymbols}', "");
Expect(0, 128768, '\P{^istransportandmapsymbols}', "");
Expect(1, 128767, '\p{--Is_transport_AND_Map_symbols}', "");
Expect(0, 128767, '\p{^--Is_transport_AND_Map_symbols}', "");
Expect(0, 128767, '\P{--Is_transport_AND_Map_symbols}', "");
Expect(1, 128767, '\P{^--Is_transport_AND_Map_symbols}', "");
Expect(0, 128768, '\p{--Is_transport_AND_Map_symbols}', "");
Expect(1, 128768, '\p{^--Is_transport_AND_Map_symbols}', "");
Expect(1, 128768, '\P{--Is_transport_AND_Map_symbols}', "");
Expect(0, 128768, '\P{^--Is_transport_AND_Map_symbols}', "");
Error('\p{:=--in_transport_and_MAP_SYMBOLS}');
Error('\P{:=--in_transport_and_MAP_SYMBOLS}');
Expect(1, 128767, '\p{intransportandmapsymbols}', "");
Expect(0, 128767, '\p{^intransportandmapsymbols}', "");
Expect(0, 128767, '\P{intransportandmapsymbols}', "");
Expect(1, 128767, '\P{^intransportandmapsymbols}', "");
Expect(0, 128768, '\p{intransportandmapsymbols}', "");
Expect(1, 128768, '\p{^intransportandmapsymbols}', "");
Expect(1, 128768, '\P{intransportandmapsymbols}', "");
Expect(0, 128768, '\P{^intransportandmapsymbols}', "");
Expect(1, 128767, '\p{	_IN_Transport_And_map_SYMBOLS}', "");
Expect(0, 128767, '\p{^	_IN_Transport_And_map_SYMBOLS}', "");
Expect(0, 128767, '\P{	_IN_Transport_And_map_SYMBOLS}', "");
Expect(1, 128767, '\P{^	_IN_Transport_And_map_SYMBOLS}', "");
Expect(0, 128768, '\p{	_IN_Transport_And_map_SYMBOLS}', "");
Expect(1, 128768, '\p{^	_IN_Transport_And_map_SYMBOLS}', "");
Expect(1, 128768, '\P{	_IN_Transport_And_map_SYMBOLS}', "");
Expect(0, 128768, '\P{^	_IN_Transport_And_map_SYMBOLS}', "");
Error('\p{-/a/transport_And_map}');
Error('\P{-/a/transport_And_map}');
Expect(1, 128767, '\p{transportandmap}', "");
Expect(0, 128767, '\p{^transportandmap}', "");
Expect(0, 128767, '\P{transportandmap}', "");
Expect(1, 128767, '\P{^transportandmap}', "");
Expect(0, 128768, '\p{transportandmap}', "");
Expect(1, 128768, '\p{^transportandmap}', "");
Expect(1, 128768, '\P{transportandmap}', "");
Expect(0, 128768, '\P{^transportandmap}', "");
Expect(1, 128767, '\p{- Transport_AND_Map}', "");
Expect(0, 128767, '\p{^- Transport_AND_Map}', "");
Expect(0, 128767, '\P{- Transport_AND_Map}', "");
Expect(1, 128767, '\P{^- Transport_AND_Map}', "");
Expect(0, 128768, '\p{- Transport_AND_Map}', "");
Expect(1, 128768, '\p{^- Transport_AND_Map}', "");
Expect(1, 128768, '\P{- Transport_AND_Map}', "");
Expect(0, 128768, '\P{^- Transport_AND_Map}', "");
Error('\p{:=	 is_TRANSPORT_And_Map}');
Error('\P{:=	 is_TRANSPORT_And_Map}');
Expect(1, 128767, '\p{istransportandmap}', "");
Expect(0, 128767, '\p{^istransportandmap}', "");
Expect(0, 128767, '\P{istransportandmap}', "");
Expect(1, 128767, '\P{^istransportandmap}', "");
Expect(0, 128768, '\p{istransportandmap}', "");
Expect(1, 128768, '\p{^istransportandmap}', "");
Expect(1, 128768, '\P{istransportandmap}', "");
Expect(0, 128768, '\P{^istransportandmap}', "");
Expect(1, 128767, '\p{- Is_TRANSPORT_and_MAP}', "");
Expect(0, 128767, '\p{^- Is_TRANSPORT_and_MAP}', "");
Expect(0, 128767, '\P{- Is_TRANSPORT_and_MAP}', "");
Expect(1, 128767, '\P{^- Is_TRANSPORT_and_MAP}', "");
Expect(0, 128768, '\p{- Is_TRANSPORT_and_MAP}', "");
Expect(1, 128768, '\p{^- Is_TRANSPORT_and_MAP}', "");
Expect(1, 128768, '\P{- Is_TRANSPORT_and_MAP}', "");
Expect(0, 128768, '\P{^- Is_TRANSPORT_and_MAP}', "");
Error('\p{/a/-	In_Transport_And_map}');
Error('\P{/a/-	In_Transport_And_map}');
Expect(1, 128767, '\p{intransportandmap}', "");
Expect(0, 128767, '\p{^intransportandmap}', "");
Expect(0, 128767, '\P{intransportandmap}', "");
Expect(1, 128767, '\P{^intransportandmap}', "");
Expect(0, 128768, '\p{intransportandmap}', "");
Expect(1, 128768, '\p{^intransportandmap}', "");
Expect(1, 128768, '\P{intransportandmap}', "");
Expect(0, 128768, '\P{^intransportandmap}', "");
Expect(1, 128767, '\p{_-In_transport_and_map}', "");
Expect(0, 128767, '\p{^_-In_transport_and_map}', "");
Expect(0, 128767, '\P{_-In_transport_and_map}', "");
Expect(1, 128767, '\P{^_-In_transport_and_map}', "");
Expect(0, 128768, '\p{_-In_transport_and_map}', "");
Expect(1, 128768, '\p{^_-In_transport_and_map}', "");
Expect(1, 128768, '\P{_-In_transport_and_map}', "");
Expect(0, 128768, '\P{^_-In_transport_and_map}', "");
Error('\p{_:=Ugaritic}');
Error('\P{_:=Ugaritic}');
Expect(1, 66463, '\p{ugaritic}', "");
Expect(0, 66463, '\p{^ugaritic}', "");
Expect(0, 66463, '\P{ugaritic}', "");
Expect(1, 66463, '\P{^ugaritic}', "");
Expect(0, 66464, '\p{ugaritic}', "");
Expect(1, 66464, '\p{^ugaritic}', "");
Expect(1, 66464, '\P{ugaritic}', "");
Expect(0, 66464, '\P{^ugaritic}', "");
Expect(1, 66463, '\p{		Ugaritic}', "");
Expect(0, 66463, '\p{^		Ugaritic}', "");
Expect(0, 66463, '\P{		Ugaritic}', "");
Expect(1, 66463, '\P{^		Ugaritic}', "");
Expect(0, 66464, '\p{		Ugaritic}', "");
Expect(1, 66464, '\p{^		Ugaritic}', "");
Expect(1, 66464, '\P{		Ugaritic}', "");
Expect(0, 66464, '\P{^		Ugaritic}', "");
Error('\p{ IS_UGARITIC:=}');
Error('\P{ IS_UGARITIC:=}');
Expect(1, 66463, '\p{isugaritic}', "");
Expect(0, 66463, '\p{^isugaritic}', "");
Expect(0, 66463, '\P{isugaritic}', "");
Expect(1, 66463, '\P{^isugaritic}', "");
Expect(0, 66464, '\p{isugaritic}', "");
Expect(1, 66464, '\p{^isugaritic}', "");
Expect(1, 66464, '\P{isugaritic}', "");
Expect(0, 66464, '\P{^isugaritic}', "");
Expect(1, 66463, '\p{_Is_ugaritic}', "");
Expect(0, 66463, '\p{^_Is_ugaritic}', "");
Expect(0, 66463, '\P{_Is_ugaritic}', "");
Expect(1, 66463, '\P{^_Is_ugaritic}', "");
Expect(0, 66464, '\p{_Is_ugaritic}', "");
Expect(1, 66464, '\p{^_Is_ugaritic}', "");
Expect(1, 66464, '\P{_Is_ugaritic}', "");
Expect(0, 66464, '\P{^_Is_ugaritic}', "");
Error('\p{:=--ugar}');
Error('\P{:=--ugar}');
Expect(1, 66463, '\p{ugar}', "");
Expect(0, 66463, '\p{^ugar}', "");
Expect(0, 66463, '\P{ugar}', "");
Expect(1, 66463, '\P{^ugar}', "");
Expect(0, 66464, '\p{ugar}', "");
Expect(1, 66464, '\p{^ugar}', "");
Expect(1, 66464, '\P{ugar}', "");
Expect(0, 66464, '\P{^ugar}', "");
Expect(1, 66463, '\p{ _ugar}', "");
Expect(0, 66463, '\p{^ _ugar}', "");
Expect(0, 66463, '\P{ _ugar}', "");
Expect(1, 66463, '\P{^ _ugar}', "");
Expect(0, 66464, '\p{ _ugar}', "");
Expect(1, 66464, '\p{^ _ugar}', "");
Expect(1, 66464, '\P{ _ugar}', "");
Expect(0, 66464, '\P{^ _ugar}', "");
Error('\p{__is_Ugar:=}');
Error('\P{__is_Ugar:=}');
Expect(1, 66463, '\p{isugar}', "");
Expect(0, 66463, '\p{^isugar}', "");
Expect(0, 66463, '\P{isugar}', "");
Expect(1, 66463, '\P{^isugar}', "");
Expect(0, 66464, '\p{isugar}', "");
Expect(1, 66464, '\p{^isugar}', "");
Expect(1, 66464, '\P{isugar}', "");
Expect(0, 66464, '\P{^isugar}', "");
Expect(1, 66463, '\p{_IS_ugar}', "");
Expect(0, 66463, '\p{^_IS_ugar}', "");
Expect(0, 66463, '\P{_IS_ugar}', "");
Expect(1, 66463, '\P{^_IS_ugar}', "");
Expect(0, 66464, '\p{_IS_ugar}', "");
Expect(1, 66464, '\p{^_IS_ugar}', "");
Expect(1, 66464, '\P{_IS_ugar}', "");
Expect(0, 66464, '\P{^_IS_ugar}', "");
Error('\p{/a/-_Unassigned}');
Error('\P{/a/-_Unassigned}');
Expect(1, 918000, '\p{unassigned}', "");
Expect(0, 918000, '\p{^unassigned}', "");
Expect(0, 918000, '\P{unassigned}', "");
Expect(1, 918000, '\P{^unassigned}', "");
Expect(0, 1114109, '\p{unassigned}', "");
Expect(1, 1114109, '\p{^unassigned}', "");
Expect(1, 1114109, '\P{unassigned}', "");
Expect(0, 1114109, '\P{^unassigned}', "");
Expect(1, 918000, '\p{ Unassigned}', "");
Expect(0, 918000, '\p{^ Unassigned}', "");
Expect(0, 918000, '\P{ Unassigned}', "");
Expect(1, 918000, '\P{^ Unassigned}', "");
Expect(0, 1114109, '\p{ Unassigned}', "");
Expect(1, 1114109, '\p{^ Unassigned}', "");
Expect(1, 1114109, '\P{ Unassigned}', "");
Expect(0, 1114109, '\P{^ Unassigned}', "");
Error('\p{/a/ is_UNASSIGNED}');
Error('\P{/a/ is_UNASSIGNED}');
Expect(1, 918000, '\p{isunassigned}', "");
Expect(0, 918000, '\p{^isunassigned}', "");
Expect(0, 918000, '\P{isunassigned}', "");
Expect(1, 918000, '\P{^isunassigned}', "");
Expect(0, 1114109, '\p{isunassigned}', "");
Expect(1, 1114109, '\p{^isunassigned}', "");
Expect(1, 1114109, '\P{isunassigned}', "");
Expect(0, 1114109, '\P{^isunassigned}', "");
Expect(1, 918000, '\p{  Is_Unassigned}', "");
Expect(0, 918000, '\p{^  Is_Unassigned}', "");
Expect(0, 918000, '\P{  Is_Unassigned}', "");
Expect(1, 918000, '\P{^  Is_Unassigned}', "");
Expect(0, 1114109, '\p{  Is_Unassigned}', "");
Expect(1, 1114109, '\p{^  Is_Unassigned}', "");
Expect(1, 1114109, '\P{  Is_Unassigned}', "");
Expect(0, 1114109, '\P{^  Is_Unassigned}', "");
Error('\p{_:=cn}');
Error('\P{_:=cn}');
Expect(1, 918000, '\p{cn}', "");
Expect(0, 918000, '\p{^cn}', "");
Expect(0, 918000, '\P{cn}', "");
Expect(1, 918000, '\P{^cn}', "");
Expect(0, 1114109, '\p{cn}', "");
Expect(1, 1114109, '\p{^cn}', "");
Expect(1, 1114109, '\P{cn}', "");
Expect(0, 1114109, '\P{^cn}', "");
Expect(1, 918000, '\p{-cn}', "");
Expect(0, 918000, '\p{^-cn}', "");
Expect(0, 918000, '\P{-cn}', "");
Expect(1, 918000, '\P{^-cn}', "");
Expect(0, 1114109, '\p{-cn}', "");
Expect(1, 1114109, '\p{^-cn}', "");
Expect(1, 1114109, '\P{-cn}', "");
Expect(0, 1114109, '\P{^-cn}', "");
Error('\p{  is_cn/a/}');
Error('\P{  is_cn/a/}');
Expect(1, 918000, '\p{iscn}', "");
Expect(0, 918000, '\p{^iscn}', "");
Expect(0, 918000, '\P{iscn}', "");
Expect(1, 918000, '\P{^iscn}', "");
Expect(0, 1114109, '\p{iscn}', "");
Expect(1, 1114109, '\p{^iscn}', "");
Expect(1, 1114109, '\P{iscn}', "");
Expect(0, 1114109, '\P{^iscn}', "");
Expect(1, 918000, '\p{-	Is_cn}', "");
Expect(0, 918000, '\p{^-	Is_cn}', "");
Expect(0, 918000, '\P{-	Is_cn}', "");
Expect(1, 918000, '\P{^-	Is_cn}', "");
Expect(0, 1114109, '\p{-	Is_cn}', "");
Expect(1, 1114109, '\p{^-	Is_cn}', "");
Expect(1, 1114109, '\P{-	Is_cn}', "");
Expect(0, 1114109, '\P{^-	Is_cn}', "");
Error('\p{ _unified_Canadian_ABORIGINAL_Syllabics/a/}');
Error('\P{ _unified_Canadian_ABORIGINAL_Syllabics/a/}');
Expect(1, 5759, '\p{unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\p{^unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\P{unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\P{^unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\p{unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\p{^unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\P{unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\P{^unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\p{__UNIFIED_CANADIAN_aboriginal_Syllabics}', "");
Expect(0, 5759, '\p{^__UNIFIED_CANADIAN_aboriginal_Syllabics}', "");
Expect(0, 5759, '\P{__UNIFIED_CANADIAN_aboriginal_Syllabics}', "");
Expect(1, 5759, '\P{^__UNIFIED_CANADIAN_aboriginal_Syllabics}', "");
Expect(0, 5760, '\p{__UNIFIED_CANADIAN_aboriginal_Syllabics}', "");
Expect(1, 5760, '\p{^__UNIFIED_CANADIAN_aboriginal_Syllabics}', "");
Expect(1, 5760, '\P{__UNIFIED_CANADIAN_aboriginal_Syllabics}', "");
Expect(0, 5760, '\P{^__UNIFIED_CANADIAN_aboriginal_Syllabics}', "");
Error('\p{_:=Is_UNIFIED_canadian_Aboriginal_syllabics}');
Error('\P{_:=Is_UNIFIED_canadian_Aboriginal_syllabics}');
Expect(1, 5759, '\p{isunifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\p{^isunifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\P{isunifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\P{^isunifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\p{isunifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\p{^isunifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\P{isunifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\P{^isunifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\p{  is_UNIFIED_Canadian_ABORIGINAL_syllabics}', "");
Expect(0, 5759, '\p{^  is_UNIFIED_Canadian_ABORIGINAL_syllabics}', "");
Expect(0, 5759, '\P{  is_UNIFIED_Canadian_ABORIGINAL_syllabics}', "");
Expect(1, 5759, '\P{^  is_UNIFIED_Canadian_ABORIGINAL_syllabics}', "");
Expect(0, 5760, '\p{  is_UNIFIED_Canadian_ABORIGINAL_syllabics}', "");
Expect(1, 5760, '\p{^  is_UNIFIED_Canadian_ABORIGINAL_syllabics}', "");
Expect(1, 5760, '\P{  is_UNIFIED_Canadian_ABORIGINAL_syllabics}', "");
Expect(0, 5760, '\P{^  is_UNIFIED_Canadian_ABORIGINAL_syllabics}', "");
Error('\p{/a/  IN_Unified_canadian_ABORIGINAL_Syllabics}');
Error('\P{/a/  IN_Unified_canadian_ABORIGINAL_Syllabics}');
Expect(1, 5759, '\p{inunifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\p{^inunifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\P{inunifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\P{^inunifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\p{inunifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\p{^inunifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\P{inunifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\P{^inunifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\p{_In_UNIFIED_Canadian_aboriginal_Syllabics}', "");
Expect(0, 5759, '\p{^_In_UNIFIED_Canadian_aboriginal_Syllabics}', "");
Expect(0, 5759, '\P{_In_UNIFIED_Canadian_aboriginal_Syllabics}', "");
Expect(1, 5759, '\P{^_In_UNIFIED_Canadian_aboriginal_Syllabics}', "");
Expect(0, 5760, '\p{_In_UNIFIED_Canadian_aboriginal_Syllabics}', "");
Expect(1, 5760, '\p{^_In_UNIFIED_Canadian_aboriginal_Syllabics}', "");
Expect(1, 5760, '\P{_In_UNIFIED_Canadian_aboriginal_Syllabics}', "");
Expect(0, 5760, '\P{^_In_UNIFIED_Canadian_aboriginal_Syllabics}', "");
Error('\p{/a/-_ucas}');
Error('\P{/a/-_ucas}');
Expect(1, 5759, '\p{ucas}', "");
Expect(0, 5759, '\p{^ucas}', "");
Expect(0, 5759, '\P{ucas}', "");
Expect(1, 5759, '\P{^ucas}', "");
Expect(0, 5760, '\p{ucas}', "");
Expect(1, 5760, '\p{^ucas}', "");
Expect(1, 5760, '\P{ucas}', "");
Expect(0, 5760, '\P{^ucas}', "");
Expect(1, 5759, '\p{_ucas}', "");
Expect(0, 5759, '\p{^_ucas}', "");
Expect(0, 5759, '\P{_ucas}', "");
Expect(1, 5759, '\P{^_ucas}', "");
Expect(0, 5760, '\p{_ucas}', "");
Expect(1, 5760, '\p{^_ucas}', "");
Expect(1, 5760, '\P{_ucas}', "");
Expect(0, 5760, '\P{^_ucas}', "");
Error('\p{-_IS_UCAS:=}');
Error('\P{-_IS_UCAS:=}');
Expect(1, 5759, '\p{isucas}', "");
Expect(0, 5759, '\p{^isucas}', "");
Expect(0, 5759, '\P{isucas}', "");
Expect(1, 5759, '\P{^isucas}', "");
Expect(0, 5760, '\p{isucas}', "");
Expect(1, 5760, '\p{^isucas}', "");
Expect(1, 5760, '\P{isucas}', "");
Expect(0, 5760, '\P{^isucas}', "");
Expect(1, 5759, '\p{_-IS_UCAS}', "");
Expect(0, 5759, '\p{^_-IS_UCAS}', "");
Expect(0, 5759, '\P{_-IS_UCAS}', "");
Expect(1, 5759, '\P{^_-IS_UCAS}', "");
Expect(0, 5760, '\p{_-IS_UCAS}', "");
Expect(1, 5760, '\p{^_-IS_UCAS}', "");
Expect(1, 5760, '\P{_-IS_UCAS}', "");
Expect(0, 5760, '\P{^_-IS_UCAS}', "");
Error('\p{ /a/In_ucas}');
Error('\P{ /a/In_ucas}');
Expect(1, 5759, '\p{inucas}', "");
Expect(0, 5759, '\p{^inucas}', "");
Expect(0, 5759, '\P{inucas}', "");
Expect(1, 5759, '\P{^inucas}', "");
Expect(0, 5760, '\p{inucas}', "");
Expect(1, 5760, '\p{^inucas}', "");
Expect(1, 5760, '\P{inucas}', "");
Expect(0, 5760, '\P{^inucas}', "");
Expect(1, 5759, '\p{ IN_ucas}', "");
Expect(0, 5759, '\p{^ IN_ucas}', "");
Expect(0, 5759, '\P{ IN_ucas}', "");
Expect(1, 5759, '\P{^ IN_ucas}', "");
Expect(0, 5760, '\p{ IN_ucas}', "");
Expect(1, 5760, '\p{^ IN_ucas}', "");
Expect(1, 5760, '\P{ IN_ucas}', "");
Expect(0, 5760, '\P{^ IN_ucas}', "");
Error('\p{_/a/Canadian_syllabics}');
Error('\P{_/a/Canadian_syllabics}');
Expect(1, 5759, '\p{canadiansyllabics}', "");
Expect(0, 5759, '\p{^canadiansyllabics}', "");
Expect(0, 5759, '\P{canadiansyllabics}', "");
Expect(1, 5759, '\P{^canadiansyllabics}', "");
Expect(0, 5760, '\p{canadiansyllabics}', "");
Expect(1, 5760, '\p{^canadiansyllabics}', "");
Expect(1, 5760, '\P{canadiansyllabics}', "");
Expect(0, 5760, '\P{^canadiansyllabics}', "");
Expect(1, 5759, '\p{-Canadian_Syllabics}', "");
Expect(0, 5759, '\p{^-Canadian_Syllabics}', "");
Expect(0, 5759, '\P{-Canadian_Syllabics}', "");
Expect(1, 5759, '\P{^-Canadian_Syllabics}', "");
Expect(0, 5760, '\p{-Canadian_Syllabics}', "");
Expect(1, 5760, '\p{^-Canadian_Syllabics}', "");
Expect(1, 5760, '\P{-Canadian_Syllabics}', "");
Expect(0, 5760, '\P{^-Canadian_Syllabics}', "");
Error('\p{/a/_ Is_CANADIAN_SYLLABICS}');
Error('\P{/a/_ Is_CANADIAN_SYLLABICS}');
Expect(1, 5759, '\p{iscanadiansyllabics}', "");
Expect(0, 5759, '\p{^iscanadiansyllabics}', "");
Expect(0, 5759, '\P{iscanadiansyllabics}', "");
Expect(1, 5759, '\P{^iscanadiansyllabics}', "");
Expect(0, 5760, '\p{iscanadiansyllabics}', "");
Expect(1, 5760, '\p{^iscanadiansyllabics}', "");
Expect(1, 5760, '\P{iscanadiansyllabics}', "");
Expect(0, 5760, '\P{^iscanadiansyllabics}', "");
Expect(1, 5759, '\p{Is_canadian_SYLLABICS}', "");
Expect(0, 5759, '\p{^Is_canadian_SYLLABICS}', "");
Expect(0, 5759, '\P{Is_canadian_SYLLABICS}', "");
Expect(1, 5759, '\P{^Is_canadian_SYLLABICS}', "");
Expect(0, 5760, '\p{Is_canadian_SYLLABICS}', "");
Expect(1, 5760, '\p{^Is_canadian_SYLLABICS}', "");
Expect(1, 5760, '\P{Is_canadian_SYLLABICS}', "");
Expect(0, 5760, '\P{^Is_canadian_SYLLABICS}', "");
Error('\p{/a/_-In_Canadian_Syllabics}');
Error('\P{/a/_-In_Canadian_Syllabics}');
Expect(1, 5759, '\p{incanadiansyllabics}', "");
Expect(0, 5759, '\p{^incanadiansyllabics}', "");
Expect(0, 5759, '\P{incanadiansyllabics}', "");
Expect(1, 5759, '\P{^incanadiansyllabics}', "");
Expect(0, 5760, '\p{incanadiansyllabics}', "");
Expect(1, 5760, '\p{^incanadiansyllabics}', "");
Expect(1, 5760, '\P{incanadiansyllabics}', "");
Expect(0, 5760, '\P{^incanadiansyllabics}', "");
Expect(1, 5759, '\p{	In_canadian_syllabics}', "");
Expect(0, 5759, '\p{^	In_canadian_syllabics}', "");
Expect(0, 5759, '\P{	In_canadian_syllabics}', "");
Expect(1, 5759, '\P{^	In_canadian_syllabics}', "");
Expect(0, 5760, '\p{	In_canadian_syllabics}', "");
Expect(1, 5760, '\p{^	In_canadian_syllabics}', "");
Expect(1, 5760, '\P{	In_canadian_syllabics}', "");
Expect(0, 5760, '\P{^	In_canadian_syllabics}', "");
Error('\p{:=unified_canadian_Aboriginal_SYLLABICS_extended}');
Error('\P{:=unified_canadian_Aboriginal_SYLLABICS_extended}');
Expect(1, 6399, '\p{unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\p{^unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\P{unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\P{^unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\p{unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\p{^unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\P{unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\P{^unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\p{_ unified_CANADIAN_ABORIGINAL_syllabics_Extended}', "");
Expect(0, 6399, '\p{^_ unified_CANADIAN_ABORIGINAL_syllabics_Extended}', "");
Expect(0, 6399, '\P{_ unified_CANADIAN_ABORIGINAL_syllabics_Extended}', "");
Expect(1, 6399, '\P{^_ unified_CANADIAN_ABORIGINAL_syllabics_Extended}', "");
Expect(0, 6400, '\p{_ unified_CANADIAN_ABORIGINAL_syllabics_Extended}', "");
Expect(1, 6400, '\p{^_ unified_CANADIAN_ABORIGINAL_syllabics_Extended}', "");
Expect(1, 6400, '\P{_ unified_CANADIAN_ABORIGINAL_syllabics_Extended}', "");
Expect(0, 6400, '\P{^_ unified_CANADIAN_ABORIGINAL_syllabics_Extended}', "");
Error('\p{	 is_unified_Canadian_Aboriginal_SYLLABICS_Extended:=}');
Error('\P{	 is_unified_Canadian_Aboriginal_SYLLABICS_Extended:=}');
Expect(1, 6399, '\p{isunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\p{^isunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\P{isunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\P{^isunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\p{isunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\p{^isunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\P{isunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\P{^isunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\p{--IS_unified_Canadian_Aboriginal_Syllabics_extended}', "");
Expect(0, 6399, '\p{^--IS_unified_Canadian_Aboriginal_Syllabics_extended}', "");
Expect(0, 6399, '\P{--IS_unified_Canadian_Aboriginal_Syllabics_extended}', "");
Expect(1, 6399, '\P{^--IS_unified_Canadian_Aboriginal_Syllabics_extended}', "");
Expect(0, 6400, '\p{--IS_unified_Canadian_Aboriginal_Syllabics_extended}', "");
Expect(1, 6400, '\p{^--IS_unified_Canadian_Aboriginal_Syllabics_extended}', "");
Expect(1, 6400, '\P{--IS_unified_Canadian_Aboriginal_Syllabics_extended}', "");
Expect(0, 6400, '\P{^--IS_unified_Canadian_Aboriginal_Syllabics_extended}', "");
Error('\p{	/a/IN_Unified_Canadian_Aboriginal_Syllabics_Extended}');
Error('\P{	/a/IN_Unified_Canadian_Aboriginal_Syllabics_Extended}');
Expect(1, 6399, '\p{inunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\p{^inunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\P{inunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\P{^inunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\p{inunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\p{^inunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\P{inunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\P{^inunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\p{- IN_Unified_CANADIAN_Aboriginal_Syllabics_extended}', "");
Expect(0, 6399, '\p{^- IN_Unified_CANADIAN_Aboriginal_Syllabics_extended}', "");
Expect(0, 6399, '\P{- IN_Unified_CANADIAN_Aboriginal_Syllabics_extended}', "");
Expect(1, 6399, '\P{^- IN_Unified_CANADIAN_Aboriginal_Syllabics_extended}', "");
Expect(0, 6400, '\p{- IN_Unified_CANADIAN_Aboriginal_Syllabics_extended}', "");
Expect(1, 6400, '\p{^- IN_Unified_CANADIAN_Aboriginal_Syllabics_extended}', "");
Expect(1, 6400, '\P{- IN_Unified_CANADIAN_Aboriginal_Syllabics_extended}', "");
Expect(0, 6400, '\P{^- IN_Unified_CANADIAN_Aboriginal_Syllabics_extended}', "");
Error('\p{/a/ ucas_Ext}');
Error('\P{/a/ ucas_Ext}');
Expect(1, 6399, '\p{ucasext}', "");
Expect(0, 6399, '\p{^ucasext}', "");
Expect(0, 6399, '\P{ucasext}', "");
Expect(1, 6399, '\P{^ucasext}', "");
Expect(0, 6400, '\p{ucasext}', "");
Expect(1, 6400, '\p{^ucasext}', "");
Expect(1, 6400, '\P{ucasext}', "");
Expect(0, 6400, '\P{^ucasext}', "");
Expect(1, 6399, '\p{-_UCAS_ext}', "");
Expect(0, 6399, '\p{^-_UCAS_ext}', "");
Expect(0, 6399, '\P{-_UCAS_ext}', "");
Expect(1, 6399, '\P{^-_UCAS_ext}', "");
Expect(0, 6400, '\p{-_UCAS_ext}', "");
Expect(1, 6400, '\p{^-_UCAS_ext}', "");
Expect(1, 6400, '\P{-_UCAS_ext}', "");
Expect(0, 6400, '\P{^-_UCAS_ext}', "");
Error('\p{	Is_UCAS_Ext:=}');
Error('\P{	Is_UCAS_Ext:=}');
Expect(1, 6399, '\p{isucasext}', "");
Expect(0, 6399, '\p{^isucasext}', "");
Expect(0, 6399, '\P{isucasext}', "");
Expect(1, 6399, '\P{^isucasext}', "");
Expect(0, 6400, '\p{isucasext}', "");
Expect(1, 6400, '\p{^isucasext}', "");
Expect(1, 6400, '\P{isucasext}', "");
Expect(0, 6400, '\P{^isucasext}', "");
Expect(1, 6399, '\p{	Is_UCAS_Ext}', "");
Expect(0, 6399, '\p{^	Is_UCAS_Ext}', "");
Expect(0, 6399, '\P{	Is_UCAS_Ext}', "");
Expect(1, 6399, '\P{^	Is_UCAS_Ext}', "");
Expect(0, 6400, '\p{	Is_UCAS_Ext}', "");
Expect(1, 6400, '\p{^	Is_UCAS_Ext}', "");
Expect(1, 6400, '\P{	Is_UCAS_Ext}', "");
Expect(0, 6400, '\P{^	Is_UCAS_Ext}', "");
Error('\p{	:=in_UCAS_Ext}');
Error('\P{	:=in_UCAS_Ext}');
Expect(1, 6399, '\p{inucasext}', "");
Expect(0, 6399, '\p{^inucasext}', "");
Expect(0, 6399, '\P{inucasext}', "");
Expect(1, 6399, '\P{^inucasext}', "");
Expect(0, 6400, '\p{inucasext}', "");
Expect(1, 6400, '\p{^inucasext}', "");
Expect(1, 6400, '\P{inucasext}', "");
Expect(0, 6400, '\P{^inucasext}', "");
Expect(1, 6399, '\p{_ IN_UCAS_ext}', "");
Expect(0, 6399, '\p{^_ IN_UCAS_ext}', "");
Expect(0, 6399, '\P{_ IN_UCAS_ext}', "");
Expect(1, 6399, '\P{^_ IN_UCAS_ext}', "");
Expect(0, 6400, '\p{_ IN_UCAS_ext}', "");
Expect(1, 6400, '\p{^_ IN_UCAS_ext}', "");
Expect(1, 6400, '\P{_ IN_UCAS_ext}', "");
Expect(0, 6400, '\P{^_ IN_UCAS_ext}', "");
Error('\p{/a/UNIFIED_Ideograph}');
Error('\P{/a/UNIFIED_Ideograph}');
Expect(1, 178205, '\p{unifiedideograph}', "");
Expect(0, 178205, '\p{^unifiedideograph}', "");
Expect(0, 178205, '\P{unifiedideograph}', "");
Expect(1, 178205, '\P{^unifiedideograph}', "");
Expect(0, 178206, '\p{unifiedideograph}', "");
Expect(1, 178206, '\p{^unifiedideograph}', "");
Expect(1, 178206, '\P{unifiedideograph}', "");
Expect(0, 178206, '\P{^unifiedideograph}', "");
Expect(1, 178205, '\p{ 	Unified_Ideograph}', "");
Expect(0, 178205, '\p{^ 	Unified_Ideograph}', "");
Expect(0, 178205, '\P{ 	Unified_Ideograph}', "");
Expect(1, 178205, '\P{^ 	Unified_Ideograph}', "");
Expect(0, 178206, '\p{ 	Unified_Ideograph}', "");
Expect(1, 178206, '\p{^ 	Unified_Ideograph}', "");
Expect(1, 178206, '\P{ 	Unified_Ideograph}', "");
Expect(0, 178206, '\P{^ 	Unified_Ideograph}', "");
Error('\p{/a/is_Unified_Ideograph}');
Error('\P{/a/is_Unified_Ideograph}');
Expect(1, 178205, '\p{isunifiedideograph}', "");
Expect(0, 178205, '\p{^isunifiedideograph}', "");
Expect(0, 178205, '\P{isunifiedideograph}', "");
Expect(1, 178205, '\P{^isunifiedideograph}', "");
Expect(0, 178206, '\p{isunifiedideograph}', "");
Expect(1, 178206, '\p{^isunifiedideograph}', "");
Expect(1, 178206, '\P{isunifiedideograph}', "");
Expect(0, 178206, '\P{^isunifiedideograph}', "");
Expect(1, 178205, '\p{-Is_UNIFIED_IDEOGRAPH}', "");
Expect(0, 178205, '\p{^-Is_UNIFIED_IDEOGRAPH}', "");
Expect(0, 178205, '\P{-Is_UNIFIED_IDEOGRAPH}', "");
Expect(1, 178205, '\P{^-Is_UNIFIED_IDEOGRAPH}', "");
Expect(0, 178206, '\p{-Is_UNIFIED_IDEOGRAPH}', "");
Expect(1, 178206, '\p{^-Is_UNIFIED_IDEOGRAPH}', "");
Expect(1, 178206, '\P{-Is_UNIFIED_IDEOGRAPH}', "");
Expect(0, 178206, '\P{^-Is_UNIFIED_IDEOGRAPH}', "");
Error('\p{		UIdeo:=}');
Error('\P{		UIdeo:=}');
Expect(1, 178205, '\p{uideo}', "");
Expect(0, 178205, '\p{^uideo}', "");
Expect(0, 178205, '\P{uideo}', "");
Expect(1, 178205, '\P{^uideo}', "");
Expect(0, 178206, '\p{uideo}', "");
Expect(1, 178206, '\p{^uideo}', "");
Expect(1, 178206, '\P{uideo}', "");
Expect(0, 178206, '\P{^uideo}', "");
Expect(1, 178205, '\p{_-UIDEO}', "");
Expect(0, 178205, '\p{^_-UIDEO}', "");
Expect(0, 178205, '\P{_-UIDEO}', "");
Expect(1, 178205, '\P{^_-UIDEO}', "");
Expect(0, 178206, '\p{_-UIDEO}', "");
Expect(1, 178206, '\p{^_-UIDEO}', "");
Expect(1, 178206, '\P{_-UIDEO}', "");
Expect(0, 178206, '\P{^_-UIDEO}', "");
Error('\p{	:=Is_UIdeo}');
Error('\P{	:=Is_UIdeo}');
Expect(1, 178205, '\p{isuideo}', "");
Expect(0, 178205, '\p{^isuideo}', "");
Expect(0, 178205, '\P{isuideo}', "");
Expect(1, 178205, '\P{^isuideo}', "");
Expect(0, 178206, '\p{isuideo}', "");
Expect(1, 178206, '\p{^isuideo}', "");
Expect(1, 178206, '\P{isuideo}', "");
Expect(0, 178206, '\P{^isuideo}', "");
Expect(1, 178205, '\p{-Is_UIdeo}', "");
Expect(0, 178205, '\p{^-Is_UIdeo}', "");
Expect(0, 178205, '\P{-Is_UIdeo}', "");
Expect(1, 178205, '\P{^-Is_UIdeo}', "");
Expect(0, 178206, '\p{-Is_UIdeo}', "");
Expect(1, 178206, '\p{^-Is_UIdeo}', "");
Expect(1, 178206, '\P{-Is_UIdeo}', "");
Expect(0, 178206, '\P{^-Is_UIdeo}', "");
Error('\p{ :=Unknown}');
Error('\P{ :=Unknown}');
Expect(1, 918000, '\p{unknown}', "");
Expect(0, 918000, '\p{^unknown}', "");
Expect(0, 918000, '\P{unknown}', "");
Expect(1, 918000, '\P{^unknown}', "");
Expect(0, 917999, '\p{unknown}', "");
Expect(1, 917999, '\p{^unknown}', "");
Expect(1, 917999, '\P{unknown}', "");
Expect(0, 917999, '\P{^unknown}', "");
Expect(1, 918000, '\p{-_unknown}', "");
Expect(0, 918000, '\p{^-_unknown}', "");
Expect(0, 918000, '\P{-_unknown}', "");
Expect(1, 918000, '\P{^-_unknown}', "");
Expect(0, 917999, '\p{-_unknown}', "");
Expect(1, 917999, '\p{^-_unknown}', "");
Expect(1, 917999, '\P{-_unknown}', "");
Expect(0, 917999, '\P{^-_unknown}', "");
Error('\p{--IS_Unknown/a/}');
Error('\P{--IS_Unknown/a/}');
Expect(1, 918000, '\p{isunknown}', "");
Expect(0, 918000, '\p{^isunknown}', "");
Expect(0, 918000, '\P{isunknown}', "");
Expect(1, 918000, '\P{^isunknown}', "");
Expect(0, 917999, '\p{isunknown}', "");
Expect(1, 917999, '\p{^isunknown}', "");
Expect(1, 917999, '\P{isunknown}', "");
Expect(0, 917999, '\P{^isunknown}', "");
Expect(1, 918000, '\p{ is_UNKNOWN}', "");
Expect(0, 918000, '\p{^ is_UNKNOWN}', "");
Expect(0, 918000, '\P{ is_UNKNOWN}', "");
Expect(1, 918000, '\P{^ is_UNKNOWN}', "");
Expect(0, 917999, '\p{ is_UNKNOWN}', "");
Expect(1, 917999, '\p{^ is_UNKNOWN}', "");
Expect(1, 917999, '\P{ is_UNKNOWN}', "");
Expect(0, 917999, '\P{^ is_UNKNOWN}', "");
Error('\p{_ Zzzz:=}');
Error('\P{_ Zzzz:=}');
Expect(1, 918000, '\p{zzzz}', "");
Expect(0, 918000, '\p{^zzzz}', "");
Expect(0, 918000, '\P{zzzz}', "");
Expect(1, 918000, '\P{^zzzz}', "");
Expect(0, 917999, '\p{zzzz}', "");
Expect(1, 917999, '\p{^zzzz}', "");
Expect(1, 917999, '\P{zzzz}', "");
Expect(0, 917999, '\P{^zzzz}', "");
Expect(1, 918000, '\p{ -zzzz}', "");
Expect(0, 918000, '\p{^ -zzzz}', "");
Expect(0, 918000, '\P{ -zzzz}', "");
Expect(1, 918000, '\P{^ -zzzz}', "");
Expect(0, 917999, '\p{ -zzzz}', "");
Expect(1, 917999, '\p{^ -zzzz}', "");
Expect(1, 917999, '\P{ -zzzz}', "");
Expect(0, 917999, '\P{^ -zzzz}', "");
Error('\p{is_Zzzz:=}');
Error('\P{is_Zzzz:=}');
Expect(1, 918000, '\p{iszzzz}', "");
Expect(0, 918000, '\p{^iszzzz}', "");
Expect(0, 918000, '\P{iszzzz}', "");
Expect(1, 918000, '\P{^iszzzz}', "");
Expect(0, 917999, '\p{iszzzz}', "");
Expect(1, 917999, '\p{^iszzzz}', "");
Expect(1, 917999, '\P{iszzzz}', "");
Expect(0, 917999, '\P{^iszzzz}', "");
Expect(1, 918000, '\p{	 Is_Zzzz}', "");
Expect(0, 918000, '\p{^	 Is_Zzzz}', "");
Expect(0, 918000, '\P{	 Is_Zzzz}', "");
Expect(1, 918000, '\P{^	 Is_Zzzz}', "");
Expect(0, 917999, '\p{	 Is_Zzzz}', "");
Expect(1, 917999, '\p{^	 Is_Zzzz}', "");
Expect(1, 917999, '\P{	 Is_Zzzz}', "");
Expect(0, 917999, '\P{^	 Is_Zzzz}', "");
Error('\p{:=_	upper}');
Error('\P{:=_	upper}');
Expect(1, 120778, '\p{upper}', "");
Expect(0, 120778, '\p{^upper}', "");
Expect(0, 120778, '\P{upper}', "");
Expect(1, 120778, '\P{^upper}', "");
Expect(0, 120779, '\p{upper}', "");
Expect(1, 120779, '\p{^upper}', "");
Expect(1, 120779, '\P{upper}', "");
Expect(0, 120779, '\P{^upper}', "");
Expect(1, 120778, '\p{_ upper}', "");
Expect(0, 120778, '\p{^_ upper}', "");
Expect(0, 120778, '\P{_ upper}', "");
Expect(1, 120778, '\P{^_ upper}', "");
Expect(0, 120779, '\p{_ upper}', "");
Expect(1, 120779, '\p{^_ upper}', "");
Expect(1, 120779, '\P{_ upper}', "");
Expect(0, 120779, '\P{^_ upper}', "");
Error('\p{ :=XPosixUpper}');
Error('\P{ :=XPosixUpper}');
Expect(1, 120778, '\p{xposixupper}', "");
Expect(0, 120778, '\p{^xposixupper}', "");
Expect(0, 120778, '\P{xposixupper}', "");
Expect(1, 120778, '\P{^xposixupper}', "");
Expect(0, 120779, '\p{xposixupper}', "");
Expect(1, 120779, '\p{^xposixupper}', "");
Expect(1, 120779, '\P{xposixupper}', "");
Expect(0, 120779, '\P{^xposixupper}', "");
Expect(1, 120778, '\p{	XPosixUpper}', "");
Expect(0, 120778, '\p{^	XPosixUpper}', "");
Expect(0, 120778, '\P{	XPosixUpper}', "");
Expect(1, 120778, '\P{^	XPosixUpper}', "");
Expect(0, 120779, '\p{	XPosixUpper}', "");
Expect(1, 120779, '\p{^	XPosixUpper}', "");
Expect(1, 120779, '\P{	XPosixUpper}', "");
Expect(0, 120779, '\P{^	XPosixUpper}', "");
Error('\p{-/a/IS_Upper}');
Error('\P{-/a/IS_Upper}');
Expect(1, 120778, '\p{isupper}', "");
Expect(0, 120778, '\p{^isupper}', "");
Expect(0, 120778, '\P{isupper}', "");
Expect(1, 120778, '\P{^isupper}', "");
Expect(0, 120779, '\p{isupper}', "");
Expect(1, 120779, '\p{^isupper}', "");
Expect(1, 120779, '\P{isupper}', "");
Expect(0, 120779, '\P{^isupper}', "");
Expect(1, 120778, '\p{-Is_UPPER}', "");
Expect(0, 120778, '\p{^-Is_UPPER}', "");
Expect(0, 120778, '\P{-Is_UPPER}', "");
Expect(1, 120778, '\P{^-Is_UPPER}', "");
Expect(0, 120779, '\p{-Is_UPPER}', "");
Expect(1, 120779, '\p{^-Is_UPPER}', "");
Expect(1, 120779, '\P{-Is_UPPER}', "");
Expect(0, 120779, '\P{^-Is_UPPER}', "");
Error('\p{ :=IS_xposixupper}');
Error('\P{ :=IS_xposixupper}');
Expect(1, 120778, '\p{isxposixupper}', "");
Expect(0, 120778, '\p{^isxposixupper}', "");
Expect(0, 120778, '\P{isxposixupper}', "");
Expect(1, 120778, '\P{^isxposixupper}', "");
Expect(0, 120779, '\p{isxposixupper}', "");
Expect(1, 120779, '\p{^isxposixupper}', "");
Expect(1, 120779, '\P{isxposixupper}', "");
Expect(0, 120779, '\P{^isxposixupper}', "");
Expect(1, 120778, '\p{--IS_XPosixUpper}', "");
Expect(0, 120778, '\p{^--IS_XPosixUpper}', "");
Expect(0, 120778, '\P{--IS_XPosixUpper}', "");
Expect(1, 120778, '\P{^--IS_XPosixUpper}', "");
Expect(0, 120779, '\p{--IS_XPosixUpper}', "");
Expect(1, 120779, '\p{^--IS_XPosixUpper}', "");
Expect(1, 120779, '\P{--IS_XPosixUpper}', "");
Expect(0, 120779, '\P{^--IS_XPosixUpper}', "");
Error('\p{:=_-Uppercase}');
Error('\P{:=_-Uppercase}');
Expect(1, 120778, '\p{uppercase}', "");
Expect(0, 120778, '\p{^uppercase}', "");
Expect(0, 120778, '\P{uppercase}', "");
Expect(1, 120778, '\P{^uppercase}', "");
Expect(0, 120779, '\p{uppercase}', "");
Expect(1, 120779, '\p{^uppercase}', "");
Expect(1, 120779, '\P{uppercase}', "");
Expect(0, 120779, '\P{^uppercase}', "");
Expect(1, 120778, '\p{__uppercase}', "");
Expect(0, 120778, '\p{^__uppercase}', "");
Expect(0, 120778, '\P{__uppercase}', "");
Expect(1, 120778, '\P{^__uppercase}', "");
Expect(0, 120779, '\p{__uppercase}', "");
Expect(1, 120779, '\p{^__uppercase}', "");
Expect(1, 120779, '\P{__uppercase}', "");
Expect(0, 120779, '\P{^__uppercase}', "");
Error('\p{	IS_uppercase/a/}');
Error('\P{	IS_uppercase/a/}');
Expect(1, 120778, '\p{isuppercase}', "");
Expect(0, 120778, '\p{^isuppercase}', "");
Expect(0, 120778, '\P{isuppercase}', "");
Expect(1, 120778, '\P{^isuppercase}', "");
Expect(0, 120779, '\p{isuppercase}', "");
Expect(1, 120779, '\p{^isuppercase}', "");
Expect(1, 120779, '\P{isuppercase}', "");
Expect(0, 120779, '\P{^isuppercase}', "");
Expect(1, 120778, '\p{ Is_uppercase}', "");
Expect(0, 120778, '\p{^ Is_uppercase}', "");
Expect(0, 120778, '\P{ Is_uppercase}', "");
Expect(1, 120778, '\P{^ Is_uppercase}', "");
Expect(0, 120779, '\p{ Is_uppercase}', "");
Expect(1, 120779, '\p{^ Is_uppercase}', "");
Expect(1, 120779, '\P{ Is_uppercase}', "");
Expect(0, 120779, '\P{^ Is_uppercase}', "");
Error('\p{_	Uppercase_Letter:=}');
Error('\P{_	Uppercase_Letter:=}');
Expect(1, 120778, '\p{uppercaseletter}', "");
Expect(0, 120778, '\p{^uppercaseletter}', "");
Expect(0, 120778, '\P{uppercaseletter}', "");
Expect(1, 120778, '\P{^uppercaseletter}', "");
Expect(0, 120779, '\p{uppercaseletter}', "");
Expect(1, 120779, '\p{^uppercaseletter}', "");
Expect(1, 120779, '\P{uppercaseletter}', "");
Expect(0, 120779, '\P{^uppercaseletter}', "");
Expect(1, 120778, '\p{ UPPERCASE_letter}', "");
Expect(0, 120778, '\p{^ UPPERCASE_letter}', "");
Expect(0, 120778, '\P{ UPPERCASE_letter}', "");
Expect(1, 120778, '\P{^ UPPERCASE_letter}', "");
Expect(0, 120779, '\p{ UPPERCASE_letter}', "");
Expect(1, 120779, '\p{^ UPPERCASE_letter}', "");
Expect(1, 120779, '\P{ UPPERCASE_letter}', "");
Expect(0, 120779, '\P{^ UPPERCASE_letter}', "");
Error('\p{		is_Uppercase_Letter:=}');
Error('\P{		is_Uppercase_Letter:=}');
Expect(1, 120778, '\p{isuppercaseletter}', "");
Expect(0, 120778, '\p{^isuppercaseletter}', "");
Expect(0, 120778, '\P{isuppercaseletter}', "");
Expect(1, 120778, '\P{^isuppercaseletter}', "");
Expect(0, 120779, '\p{isuppercaseletter}', "");
Expect(1, 120779, '\p{^isuppercaseletter}', "");
Expect(1, 120779, '\P{isuppercaseletter}', "");
Expect(0, 120779, '\P{^isuppercaseletter}', "");
Expect(1, 120778, '\p{	 Is_UPPERCASE_LETTER}', "");
Expect(0, 120778, '\p{^	 Is_UPPERCASE_LETTER}', "");
Expect(0, 120778, '\P{	 Is_UPPERCASE_LETTER}', "");
Expect(1, 120778, '\P{^	 Is_UPPERCASE_LETTER}', "");
Expect(0, 120779, '\p{	 Is_UPPERCASE_LETTER}', "");
Expect(1, 120779, '\p{^	 Is_UPPERCASE_LETTER}', "");
Expect(1, 120779, '\P{	 Is_UPPERCASE_LETTER}', "");
Expect(0, 120779, '\P{^	 Is_UPPERCASE_LETTER}', "");
Error('\p{-/a/Lu}');
Error('\P{-/a/Lu}');
Expect(1, 120778, '\p{lu}', "");
Expect(0, 120778, '\p{^lu}', "");
Expect(0, 120778, '\P{lu}', "");
Expect(1, 120778, '\P{^lu}', "");
Expect(0, 120779, '\p{lu}', "");
Expect(1, 120779, '\p{^lu}', "");
Expect(1, 120779, '\P{lu}', "");
Expect(0, 120779, '\P{^lu}', "");
Expect(1, 120778, '\p{_	lu}', "");
Expect(0, 120778, '\p{^_	lu}', "");
Expect(0, 120778, '\P{_	lu}', "");
Expect(1, 120778, '\P{^_	lu}', "");
Expect(0, 120779, '\p{_	lu}', "");
Expect(1, 120779, '\p{^_	lu}', "");
Expect(1, 120779, '\P{_	lu}', "");
Expect(0, 120779, '\P{^_	lu}', "");
Error('\p{:= -IS_Lu}');
Error('\P{:= -IS_Lu}');
Expect(1, 120778, '\p{islu}', "");
Expect(0, 120778, '\p{^islu}', "");
Expect(0, 120778, '\P{islu}', "");
Expect(1, 120778, '\P{^islu}', "");
Expect(0, 120779, '\p{islu}', "");
Expect(1, 120779, '\p{^islu}', "");
Expect(1, 120779, '\P{islu}', "");
Expect(0, 120779, '\P{^islu}', "");
Expect(1, 120778, '\p{	is_Lu}', "");
Expect(0, 120778, '\p{^	is_Lu}', "");
Expect(0, 120778, '\P{	is_Lu}', "");
Expect(1, 120778, '\P{^	is_Lu}', "");
Expect(0, 120779, '\p{	is_Lu}', "");
Expect(1, 120779, '\p{^	is_Lu}', "");
Expect(1, 120779, '\P{	is_Lu}', "");
Expect(0, 120779, '\P{^	is_Lu}', "");
Error('\p{- Vai/a/}');
Error('\P{- Vai/a/}');
Expect(1, 42539, '\p{vai}', "");
Expect(0, 42539, '\p{^vai}', "");
Expect(0, 42539, '\P{vai}', "");
Expect(1, 42539, '\P{^vai}', "");
Expect(0, 42540, '\p{vai}', "");
Expect(1, 42540, '\p{^vai}', "");
Expect(1, 42540, '\P{vai}', "");
Expect(0, 42540, '\P{^vai}', "");
Expect(1, 42539, '\p{ -Vai}', "");
Expect(0, 42539, '\p{^ -Vai}', "");
Expect(0, 42539, '\P{ -Vai}', "");
Expect(1, 42539, '\P{^ -Vai}', "");
Expect(0, 42540, '\p{ -Vai}', "");
Expect(1, 42540, '\p{^ -Vai}', "");
Expect(1, 42540, '\P{ -Vai}', "");
Expect(0, 42540, '\P{^ -Vai}', "");
Error('\p{:=-	Is_Vai}');
Error('\P{:=-	Is_Vai}');
Expect(1, 42539, '\p{isvai}', "");
Expect(0, 42539, '\p{^isvai}', "");
Expect(0, 42539, '\P{isvai}', "");
Expect(1, 42539, '\P{^isvai}', "");
Expect(0, 42540, '\p{isvai}', "");
Expect(1, 42540, '\p{^isvai}', "");
Expect(1, 42540, '\P{isvai}', "");
Expect(0, 42540, '\P{^isvai}', "");
Expect(1, 42539, '\p{		IS_Vai}', "");
Expect(0, 42539, '\p{^		IS_Vai}', "");
Expect(0, 42539, '\P{		IS_Vai}', "");
Expect(1, 42539, '\P{^		IS_Vai}', "");
Expect(0, 42540, '\p{		IS_Vai}', "");
Expect(1, 42540, '\p{^		IS_Vai}', "");
Expect(1, 42540, '\P{		IS_Vai}', "");
Expect(0, 42540, '\P{^		IS_Vai}', "");
Error('\p{ VAII:=}');
Error('\P{ VAII:=}');
Expect(1, 42539, '\p{vaii}', "");
Expect(0, 42539, '\p{^vaii}', "");
Expect(0, 42539, '\P{vaii}', "");
Expect(1, 42539, '\P{^vaii}', "");
Expect(0, 42540, '\p{vaii}', "");
Expect(1, 42540, '\p{^vaii}', "");
Expect(1, 42540, '\P{vaii}', "");
Expect(0, 42540, '\P{^vaii}', "");
Expect(1, 42539, '\p{  vaii}', "");
Expect(0, 42539, '\p{^  vaii}', "");
Expect(0, 42539, '\P{  vaii}', "");
Expect(1, 42539, '\P{^  vaii}', "");
Expect(0, 42540, '\p{  vaii}', "");
Expect(1, 42540, '\p{^  vaii}', "");
Expect(1, 42540, '\P{  vaii}', "");
Expect(0, 42540, '\P{^  vaii}', "");
Error('\p{_/a/IS_Vaii}');
Error('\P{_/a/IS_Vaii}');
Expect(1, 42539, '\p{isvaii}', "");
Expect(0, 42539, '\p{^isvaii}', "");
Expect(0, 42539, '\P{isvaii}', "");
Expect(1, 42539, '\P{^isvaii}', "");
Expect(0, 42540, '\p{isvaii}', "");
Expect(1, 42540, '\p{^isvaii}', "");
Expect(1, 42540, '\P{isvaii}', "");
Expect(0, 42540, '\P{^isvaii}', "");
Expect(1, 42539, '\p{	-IS_VAII}', "");
Expect(0, 42539, '\p{^	-IS_VAII}', "");
Expect(0, 42539, '\P{	-IS_VAII}', "");
Expect(1, 42539, '\P{^	-IS_VAII}', "");
Expect(0, 42540, '\p{	-IS_VAII}', "");
Expect(1, 42540, '\p{^	-IS_VAII}', "");
Expect(1, 42540, '\P{	-IS_VAII}', "");
Expect(0, 42540, '\P{^	-IS_VAII}', "");
Error('\p{/a/Variation_Selector}');
Error('\P{/a/Variation_Selector}');
Expect(1, 917999, '\p{variationselector}', "");
Expect(0, 917999, '\p{^variationselector}', "");
Expect(0, 917999, '\P{variationselector}', "");
Expect(1, 917999, '\P{^variationselector}', "");
Expect(0, 918000, '\p{variationselector}', "");
Expect(1, 918000, '\p{^variationselector}', "");
Expect(1, 918000, '\P{variationselector}', "");
Expect(0, 918000, '\P{^variationselector}', "");
Expect(1, 917999, '\p{- Variation_Selector}', "");
Expect(0, 917999, '\p{^- Variation_Selector}', "");
Expect(0, 917999, '\P{- Variation_Selector}', "");
Expect(1, 917999, '\P{^- Variation_Selector}', "");
Expect(0, 918000, '\p{- Variation_Selector}', "");
Expect(1, 918000, '\p{^- Variation_Selector}', "");
Expect(1, 918000, '\P{- Variation_Selector}', "");
Expect(0, 918000, '\P{^- Variation_Selector}', "");
Error('\p{:=is_Variation_Selector}');
Error('\P{:=is_Variation_Selector}');
Expect(1, 917999, '\p{isvariationselector}', "");
Expect(0, 917999, '\p{^isvariationselector}', "");
Expect(0, 917999, '\P{isvariationselector}', "");
Expect(1, 917999, '\P{^isvariationselector}', "");
Expect(0, 918000, '\p{isvariationselector}', "");
Expect(1, 918000, '\p{^isvariationselector}', "");
Expect(1, 918000, '\P{isvariationselector}', "");
Expect(0, 918000, '\P{^isvariationselector}', "");
Expect(1, 917999, '\p{_Is_VARIATION_SELECTOR}', "");
Expect(0, 917999, '\p{^_Is_VARIATION_SELECTOR}', "");
Expect(0, 917999, '\P{_Is_VARIATION_SELECTOR}', "");
Expect(1, 917999, '\P{^_Is_VARIATION_SELECTOR}', "");
Expect(0, 918000, '\p{_Is_VARIATION_SELECTOR}', "");
Expect(1, 918000, '\p{^_Is_VARIATION_SELECTOR}', "");
Expect(1, 918000, '\P{_Is_VARIATION_SELECTOR}', "");
Expect(0, 918000, '\P{^_Is_VARIATION_SELECTOR}', "");
Error('\p{:=  VS}');
Error('\P{:=  VS}');
Expect(1, 917999, '\p{vs}', "");
Expect(0, 917999, '\p{^vs}', "");
Expect(0, 917999, '\P{vs}', "");
Expect(1, 917999, '\P{^vs}', "");
Expect(0, 918000, '\p{vs}', "");
Expect(1, 918000, '\p{^vs}', "");
Expect(1, 918000, '\P{vs}', "");
Expect(0, 918000, '\P{^vs}', "");
Expect(1, 917999, '\p{	_VS}', "");
Expect(0, 917999, '\p{^	_VS}', "");
Expect(0, 917999, '\P{	_VS}', "");
Expect(1, 917999, '\P{^	_VS}', "");
Expect(0, 918000, '\p{	_VS}', "");
Expect(1, 918000, '\p{^	_VS}', "");
Expect(1, 918000, '\P{	_VS}', "");
Expect(0, 918000, '\P{^	_VS}', "");
Error('\p{_is_vs:=}');
Error('\P{_is_vs:=}');
Expect(1, 917999, '\p{isvs}', "");
Expect(0, 917999, '\p{^isvs}', "");
Expect(0, 917999, '\P{isvs}', "");
Expect(1, 917999, '\P{^isvs}', "");
Expect(0, 918000, '\p{isvs}', "");
Expect(1, 918000, '\p{^isvs}', "");
Expect(1, 918000, '\P{isvs}', "");
Expect(0, 918000, '\P{^isvs}', "");
Expect(1, 917999, '\p{-Is_VS}', "");
Expect(0, 917999, '\p{^-Is_VS}', "");
Expect(0, 917999, '\P{-Is_VS}', "");
Expect(1, 917999, '\P{^-Is_VS}', "");
Expect(0, 918000, '\p{-Is_VS}', "");
Expect(1, 918000, '\p{^-Is_VS}', "");
Expect(1, 918000, '\P{-Is_VS}', "");
Expect(0, 918000, '\P{^-Is_VS}', "");
Error('\p{/a/_-Variation_SELECTORS}');
Error('\P{/a/_-Variation_SELECTORS}');
Expect(1, 65039, '\p{variationselectors}', "");
Expect(0, 65039, '\p{^variationselectors}', "");
Expect(0, 65039, '\P{variationselectors}', "");
Expect(1, 65039, '\P{^variationselectors}', "");
Expect(0, 65040, '\p{variationselectors}', "");
Expect(1, 65040, '\p{^variationselectors}', "");
Expect(1, 65040, '\P{variationselectors}', "");
Expect(0, 65040, '\P{^variationselectors}', "");
Expect(1, 65039, '\p{-Variation_selectors}', "");
Expect(0, 65039, '\p{^-Variation_selectors}', "");
Expect(0, 65039, '\P{-Variation_selectors}', "");
Expect(1, 65039, '\P{^-Variation_selectors}', "");
Expect(0, 65040, '\p{-Variation_selectors}', "");
Expect(1, 65040, '\p{^-Variation_selectors}', "");
Expect(1, 65040, '\P{-Variation_selectors}', "");
Expect(0, 65040, '\P{^-Variation_selectors}', "");
Error('\p{-/a/Is_Variation_Selectors}');
Error('\P{-/a/Is_Variation_Selectors}');
Expect(1, 65039, '\p{isvariationselectors}', "");
Expect(0, 65039, '\p{^isvariationselectors}', "");
Expect(0, 65039, '\P{isvariationselectors}', "");
Expect(1, 65039, '\P{^isvariationselectors}', "");
Expect(0, 65040, '\p{isvariationselectors}', "");
Expect(1, 65040, '\p{^isvariationselectors}', "");
Expect(1, 65040, '\P{isvariationselectors}', "");
Expect(0, 65040, '\P{^isvariationselectors}', "");
Expect(1, 65039, '\p{-_Is_variation_Selectors}', "");
Expect(0, 65039, '\p{^-_Is_variation_Selectors}', "");
Expect(0, 65039, '\P{-_Is_variation_Selectors}', "");
Expect(1, 65039, '\P{^-_Is_variation_Selectors}', "");
Expect(0, 65040, '\p{-_Is_variation_Selectors}', "");
Expect(1, 65040, '\p{^-_Is_variation_Selectors}', "");
Expect(1, 65040, '\P{-_Is_variation_Selectors}', "");
Expect(0, 65040, '\P{^-_Is_variation_Selectors}', "");
Error('\p{	-in_VARIATION_selectors/a/}');
Error('\P{	-in_VARIATION_selectors/a/}');
Expect(1, 65039, '\p{invariationselectors}', "");
Expect(0, 65039, '\p{^invariationselectors}', "");
Expect(0, 65039, '\P{invariationselectors}', "");
Expect(1, 65039, '\P{^invariationselectors}', "");
Expect(0, 65040, '\p{invariationselectors}', "");
Expect(1, 65040, '\p{^invariationselectors}', "");
Expect(1, 65040, '\P{invariationselectors}', "");
Expect(0, 65040, '\P{^invariationselectors}', "");
Expect(1, 65039, '\p{- In_VARIATION_Selectors}', "");
Expect(0, 65039, '\p{^- In_VARIATION_Selectors}', "");
Expect(0, 65039, '\P{- In_VARIATION_Selectors}', "");
Expect(1, 65039, '\P{^- In_VARIATION_Selectors}', "");
Expect(0, 65040, '\p{- In_VARIATION_Selectors}', "");
Expect(1, 65040, '\p{^- In_VARIATION_Selectors}', "");
Expect(1, 65040, '\P{- In_VARIATION_Selectors}', "");
Expect(0, 65040, '\P{^- In_VARIATION_Selectors}', "");
Error('\p{_	In_VS:=}');
Error('\P{_	In_VS:=}');
Expect(1, 65039, '\p{invs}', "");
Expect(0, 65039, '\p{^invs}', "");
Expect(0, 65039, '\P{invs}', "");
Expect(1, 65039, '\P{^invs}', "");
Expect(0, 65040, '\p{invs}', "");
Expect(1, 65040, '\p{^invs}', "");
Expect(1, 65040, '\P{invs}', "");
Expect(0, 65040, '\P{^invs}', "");
Expect(1, 65039, '\p{_-In_VS}', "");
Expect(0, 65039, '\p{^_-In_VS}', "");
Expect(0, 65039, '\P{_-In_VS}', "");
Expect(1, 65039, '\P{^_-In_VS}', "");
Expect(0, 65040, '\p{_-In_VS}', "");
Expect(1, 65040, '\p{^_-In_VS}', "");
Expect(1, 65040, '\P{_-In_VS}', "");
Expect(0, 65040, '\P{^_-In_VS}', "");
Error('\p{_/a/Variation_selectors_Supplement}');
Error('\P{_/a/Variation_selectors_Supplement}');
Expect(1, 917999, '\p{variationselectorssupplement}', "");
Expect(0, 917999, '\p{^variationselectorssupplement}', "");
Expect(0, 917999, '\P{variationselectorssupplement}', "");
Expect(1, 917999, '\P{^variationselectorssupplement}', "");
Expect(0, 918000, '\p{variationselectorssupplement}', "");
Expect(1, 918000, '\p{^variationselectorssupplement}', "");
Expect(1, 918000, '\P{variationselectorssupplement}', "");
Expect(0, 918000, '\P{^variationselectorssupplement}', "");
Expect(1, 917999, '\p{	 variation_Selectors_supplement}', "");
Expect(0, 917999, '\p{^	 variation_Selectors_supplement}', "");
Expect(0, 917999, '\P{	 variation_Selectors_supplement}', "");
Expect(1, 917999, '\P{^	 variation_Selectors_supplement}', "");
Expect(0, 918000, '\p{	 variation_Selectors_supplement}', "");
Expect(1, 918000, '\p{^	 variation_Selectors_supplement}', "");
Expect(1, 918000, '\P{	 variation_Selectors_supplement}', "");
Expect(0, 918000, '\P{^	 variation_Selectors_supplement}', "");
Error('\p{ Is_Variation_Selectors_Supplement/a/}');
Error('\P{ Is_Variation_Selectors_Supplement/a/}');
Expect(1, 917999, '\p{isvariationselectorssupplement}', "");
Expect(0, 917999, '\p{^isvariationselectorssupplement}', "");
Expect(0, 917999, '\P{isvariationselectorssupplement}', "");
Expect(1, 917999, '\P{^isvariationselectorssupplement}', "");
Expect(0, 918000, '\p{isvariationselectorssupplement}', "");
Expect(1, 918000, '\p{^isvariationselectorssupplement}', "");
Expect(1, 918000, '\P{isvariationselectorssupplement}', "");
Expect(0, 918000, '\P{^isvariationselectorssupplement}', "");
Expect(1, 917999, '\p{_ is_VARIATION_SELECTORS_supplement}', "");
Expect(0, 917999, '\p{^_ is_VARIATION_SELECTORS_supplement}', "");
Expect(0, 917999, '\P{_ is_VARIATION_SELECTORS_supplement}', "");
Expect(1, 917999, '\P{^_ is_VARIATION_SELECTORS_supplement}', "");
Expect(0, 918000, '\p{_ is_VARIATION_SELECTORS_supplement}', "");
Expect(1, 918000, '\p{^_ is_VARIATION_SELECTORS_supplement}', "");
Expect(1, 918000, '\P{_ is_VARIATION_SELECTORS_supplement}', "");
Expect(0, 918000, '\P{^_ is_VARIATION_SELECTORS_supplement}', "");
Error('\p{_-in_Variation_selectors_Supplement:=}');
Error('\P{_-in_Variation_selectors_Supplement:=}');
Expect(1, 917999, '\p{invariationselectorssupplement}', "");
Expect(0, 917999, '\p{^invariationselectorssupplement}', "");
Expect(0, 917999, '\P{invariationselectorssupplement}', "");
Expect(1, 917999, '\P{^invariationselectorssupplement}', "");
Expect(0, 918000, '\p{invariationselectorssupplement}', "");
Expect(1, 918000, '\p{^invariationselectorssupplement}', "");
Expect(1, 918000, '\P{invariationselectorssupplement}', "");
Expect(0, 918000, '\P{^invariationselectorssupplement}', "");
Expect(1, 917999, '\p{__IN_Variation_SELECTORS_SUPPLEMENT}', "");
Expect(0, 917999, '\p{^__IN_Variation_SELECTORS_SUPPLEMENT}', "");
Expect(0, 917999, '\P{__IN_Variation_SELECTORS_SUPPLEMENT}', "");
Expect(1, 917999, '\P{^__IN_Variation_SELECTORS_SUPPLEMENT}', "");
Expect(0, 918000, '\p{__IN_Variation_SELECTORS_SUPPLEMENT}', "");
Expect(1, 918000, '\p{^__IN_Variation_SELECTORS_SUPPLEMENT}', "");
Expect(1, 918000, '\P{__IN_Variation_SELECTORS_SUPPLEMENT}', "");
Expect(0, 918000, '\P{^__IN_Variation_SELECTORS_SUPPLEMENT}', "");
Error('\p{/a/_-VS_sup}');
Error('\P{/a/_-VS_sup}');
Expect(1, 917999, '\p{vssup}', "");
Expect(0, 917999, '\p{^vssup}', "");
Expect(0, 917999, '\P{vssup}', "");
Expect(1, 917999, '\P{^vssup}', "");
Expect(0, 918000, '\p{vssup}', "");
Expect(1, 918000, '\p{^vssup}', "");
Expect(1, 918000, '\P{vssup}', "");
Expect(0, 918000, '\P{^vssup}', "");
Expect(1, 917999, '\p{_VS_Sup}', "");
Expect(0, 917999, '\p{^_VS_Sup}', "");
Expect(0, 917999, '\P{_VS_Sup}', "");
Expect(1, 917999, '\P{^_VS_Sup}', "");
Expect(0, 918000, '\p{_VS_Sup}', "");
Expect(1, 918000, '\p{^_VS_Sup}', "");
Expect(1, 918000, '\P{_VS_Sup}', "");
Expect(0, 918000, '\P{^_VS_Sup}', "");
Error('\p{	IS_VS_Sup/a/}');
Error('\P{	IS_VS_Sup/a/}');
Expect(1, 917999, '\p{isvssup}', "");
Expect(0, 917999, '\p{^isvssup}', "");
Expect(0, 917999, '\P{isvssup}', "");
Expect(1, 917999, '\P{^isvssup}', "");
Expect(0, 918000, '\p{isvssup}', "");
Expect(1, 918000, '\p{^isvssup}', "");
Expect(1, 918000, '\P{isvssup}', "");
Expect(0, 918000, '\P{^isvssup}', "");
Expect(1, 917999, '\p{ -Is_VS_SUP}', "");
Expect(0, 917999, '\p{^ -Is_VS_SUP}', "");
Expect(0, 917999, '\P{ -Is_VS_SUP}', "");
Expect(1, 917999, '\P{^ -Is_VS_SUP}', "");
Expect(0, 918000, '\p{ -Is_VS_SUP}', "");
Expect(1, 918000, '\p{^ -Is_VS_SUP}', "");
Expect(1, 918000, '\P{ -Is_VS_SUP}', "");
Expect(0, 918000, '\P{^ -Is_VS_SUP}', "");
Error('\p{ _in_VS_sup/a/}');
Error('\P{ _in_VS_sup/a/}');
Expect(1, 917999, '\p{invssup}', "");
Expect(0, 917999, '\p{^invssup}', "");
Expect(0, 917999, '\P{invssup}', "");
Expect(1, 917999, '\P{^invssup}', "");
Expect(0, 918000, '\p{invssup}', "");
Expect(1, 918000, '\p{^invssup}', "");
Expect(1, 918000, '\P{invssup}', "");
Expect(0, 918000, '\P{^invssup}', "");
Expect(1, 917999, '\p{ In_VS_sup}', "");
Expect(0, 917999, '\p{^ In_VS_sup}', "");
Expect(0, 917999, '\P{ In_VS_sup}', "");
Expect(1, 917999, '\P{^ In_VS_sup}', "");
Expect(0, 918000, '\p{ In_VS_sup}', "");
Expect(1, 918000, '\p{^ In_VS_sup}', "");
Expect(1, 918000, '\P{ In_VS_sup}', "");
Expect(0, 918000, '\P{^ In_VS_sup}', "");
Error('\p{:= Vedic_extensions}');
Error('\P{:= Vedic_extensions}');
Expect(1, 7423, '\p{vedicextensions}', "");
Expect(0, 7423, '\p{^vedicextensions}', "");
Expect(0, 7423, '\P{vedicextensions}', "");
Expect(1, 7423, '\P{^vedicextensions}', "");
Expect(0, 7424, '\p{vedicextensions}', "");
Expect(1, 7424, '\p{^vedicextensions}', "");
Expect(1, 7424, '\P{vedicextensions}', "");
Expect(0, 7424, '\P{^vedicextensions}', "");
Expect(1, 7423, '\p{ 	vedic_Extensions}', "");
Expect(0, 7423, '\p{^ 	vedic_Extensions}', "");
Expect(0, 7423, '\P{ 	vedic_Extensions}', "");
Expect(1, 7423, '\P{^ 	vedic_Extensions}', "");
Expect(0, 7424, '\p{ 	vedic_Extensions}', "");
Expect(1, 7424, '\p{^ 	vedic_Extensions}', "");
Expect(1, 7424, '\P{ 	vedic_Extensions}', "");
Expect(0, 7424, '\P{^ 	vedic_Extensions}', "");
Error('\p{-Is_Vedic_extensions:=}');
Error('\P{-Is_Vedic_extensions:=}');
Expect(1, 7423, '\p{isvedicextensions}', "");
Expect(0, 7423, '\p{^isvedicextensions}', "");
Expect(0, 7423, '\P{isvedicextensions}', "");
Expect(1, 7423, '\P{^isvedicextensions}', "");
Expect(0, 7424, '\p{isvedicextensions}', "");
Expect(1, 7424, '\p{^isvedicextensions}', "");
Expect(1, 7424, '\P{isvedicextensions}', "");
Expect(0, 7424, '\P{^isvedicextensions}', "");
Expect(1, 7423, '\p{	 Is_Vedic_extensions}', "");
Expect(0, 7423, '\p{^	 Is_Vedic_extensions}', "");
Expect(0, 7423, '\P{	 Is_Vedic_extensions}', "");
Expect(1, 7423, '\P{^	 Is_Vedic_extensions}', "");
Expect(0, 7424, '\p{	 Is_Vedic_extensions}', "");
Expect(1, 7424, '\p{^	 Is_Vedic_extensions}', "");
Expect(1, 7424, '\P{	 Is_Vedic_extensions}', "");
Expect(0, 7424, '\P{^	 Is_Vedic_extensions}', "");
Error('\p{	IN_Vedic_extensions/a/}');
Error('\P{	IN_Vedic_extensions/a/}');
Expect(1, 7423, '\p{invedicextensions}', "");
Expect(0, 7423, '\p{^invedicextensions}', "");
Expect(0, 7423, '\P{invedicextensions}', "");
Expect(1, 7423, '\P{^invedicextensions}', "");
Expect(0, 7424, '\p{invedicextensions}', "");
Expect(1, 7424, '\p{^invedicextensions}', "");
Expect(1, 7424, '\P{invedicextensions}', "");
Expect(0, 7424, '\P{^invedicextensions}', "");
Expect(1, 7423, '\p{_	in_Vedic_extensions}', "");
Expect(0, 7423, '\p{^_	in_Vedic_extensions}', "");
Expect(0, 7423, '\P{_	in_Vedic_extensions}', "");
Expect(1, 7423, '\P{^_	in_Vedic_extensions}', "");
Expect(0, 7424, '\p{_	in_Vedic_extensions}', "");
Expect(1, 7424, '\p{^_	in_Vedic_extensions}', "");
Expect(1, 7424, '\P{_	in_Vedic_extensions}', "");
Expect(0, 7424, '\P{^_	in_Vedic_extensions}', "");
Error('\p{	 vedic_Ext/a/}');
Error('\P{	 vedic_Ext/a/}');
Expect(1, 7423, '\p{vedicext}', "");
Expect(0, 7423, '\p{^vedicext}', "");
Expect(0, 7423, '\P{vedicext}', "");
Expect(1, 7423, '\P{^vedicext}', "");
Expect(0, 7424, '\p{vedicext}', "");
Expect(1, 7424, '\p{^vedicext}', "");
Expect(1, 7424, '\P{vedicext}', "");
Expect(0, 7424, '\P{^vedicext}', "");
Expect(1, 7423, '\p{--Vedic_Ext}', "");
Expect(0, 7423, '\p{^--Vedic_Ext}', "");
Expect(0, 7423, '\P{--Vedic_Ext}', "");
Expect(1, 7423, '\P{^--Vedic_Ext}', "");
Expect(0, 7424, '\p{--Vedic_Ext}', "");
Expect(1, 7424, '\p{^--Vedic_Ext}', "");
Expect(1, 7424, '\P{--Vedic_Ext}', "");
Expect(0, 7424, '\P{^--Vedic_Ext}', "");
Error('\p{:=	_is_Vedic_EXT}');
Error('\P{:=	_is_Vedic_EXT}');
Expect(1, 7423, '\p{isvedicext}', "");
Expect(0, 7423, '\p{^isvedicext}', "");
Expect(0, 7423, '\P{isvedicext}', "");
Expect(1, 7423, '\P{^isvedicext}', "");
Expect(0, 7424, '\p{isvedicext}', "");
Expect(1, 7424, '\p{^isvedicext}', "");
Expect(1, 7424, '\P{isvedicext}', "");
Expect(0, 7424, '\P{^isvedicext}', "");
Expect(1, 7423, '\p{- Is_Vedic_Ext}', "");
Expect(0, 7423, '\p{^- Is_Vedic_Ext}', "");
Expect(0, 7423, '\P{- Is_Vedic_Ext}', "");
Expect(1, 7423, '\P{^- Is_Vedic_Ext}', "");
Expect(0, 7424, '\p{- Is_Vedic_Ext}', "");
Expect(1, 7424, '\p{^- Is_Vedic_Ext}', "");
Expect(1, 7424, '\P{- Is_Vedic_Ext}', "");
Expect(0, 7424, '\P{^- Is_Vedic_Ext}', "");
Error('\p{/a/	IN_Vedic_Ext}');
Error('\P{/a/	IN_Vedic_Ext}');
Expect(1, 7423, '\p{invedicext}', "");
Expect(0, 7423, '\p{^invedicext}', "");
Expect(0, 7423, '\P{invedicext}', "");
Expect(1, 7423, '\P{^invedicext}', "");
Expect(0, 7424, '\p{invedicext}', "");
Expect(1, 7424, '\p{^invedicext}', "");
Expect(1, 7424, '\P{invedicext}', "");
Expect(0, 7424, '\P{^invedicext}', "");
Expect(1, 7423, '\p{_	In_VEDIC_Ext}', "");
Expect(0, 7423, '\p{^_	In_VEDIC_Ext}', "");
Expect(0, 7423, '\P{_	In_VEDIC_Ext}', "");
Expect(1, 7423, '\P{^_	In_VEDIC_Ext}', "");
Expect(0, 7424, '\p{_	In_VEDIC_Ext}', "");
Expect(1, 7424, '\p{^_	In_VEDIC_Ext}', "");
Expect(1, 7424, '\P{_	In_VEDIC_Ext}', "");
Expect(0, 7424, '\P{^_	In_VEDIC_Ext}', "");
Error('\p{_/a/VERTSPACE}');
Error('\P{_/a/VERTSPACE}');
Expect(1, 8233, '\p{vertspace}', "");
Expect(0, 8233, '\p{^vertspace}', "");
Expect(0, 8233, '\P{vertspace}', "");
Expect(1, 8233, '\P{^vertspace}', "");
Expect(0, 8234, '\p{vertspace}', "");
Expect(1, 8234, '\p{^vertspace}', "");
Expect(1, 8234, '\P{vertspace}', "");
Expect(0, 8234, '\P{^vertspace}', "");
Expect(1, 8233, '\p{-vertspace}', "");
Expect(0, 8233, '\p{^-vertspace}', "");
Expect(0, 8233, '\P{-vertspace}', "");
Expect(1, 8233, '\P{^-vertspace}', "");
Expect(0, 8234, '\p{-vertspace}', "");
Expect(1, 8234, '\p{^-vertspace}', "");
Expect(1, 8234, '\P{-vertspace}', "");
Expect(0, 8234, '\P{^-vertspace}', "");
Error('\p{_:=IS_vertspace}');
Error('\P{_:=IS_vertspace}');
Expect(1, 8233, '\p{isvertspace}', "");
Expect(0, 8233, '\p{^isvertspace}', "");
Expect(0, 8233, '\P{isvertspace}', "");
Expect(1, 8233, '\P{^isvertspace}', "");
Expect(0, 8234, '\p{isvertspace}', "");
Expect(1, 8234, '\p{^isvertspace}', "");
Expect(1, 8234, '\P{isvertspace}', "");
Expect(0, 8234, '\P{^isvertspace}', "");
Expect(1, 8233, '\p{ IS_VertSpace}', "");
Expect(0, 8233, '\p{^ IS_VertSpace}', "");
Expect(0, 8233, '\P{ IS_VertSpace}', "");
Expect(1, 8233, '\P{^ IS_VertSpace}', "");
Expect(0, 8234, '\p{ IS_VertSpace}', "");
Expect(1, 8234, '\p{^ IS_VertSpace}', "");
Expect(1, 8234, '\P{ IS_VertSpace}', "");
Expect(0, 8234, '\P{^ IS_VertSpace}', "");
Error('\p{	/a/vertical_Forms}');
Error('\P{	/a/vertical_Forms}');
Expect(1, 65055, '\p{verticalforms}', "");
Expect(0, 65055, '\p{^verticalforms}', "");
Expect(0, 65055, '\P{verticalforms}', "");
Expect(1, 65055, '\P{^verticalforms}', "");
Expect(0, 65056, '\p{verticalforms}', "");
Expect(1, 65056, '\p{^verticalforms}', "");
Expect(1, 65056, '\P{verticalforms}', "");
Expect(0, 65056, '\P{^verticalforms}', "");
Expect(1, 65055, '\p{__Vertical_forms}', "");
Expect(0, 65055, '\p{^__Vertical_forms}', "");
Expect(0, 65055, '\P{__Vertical_forms}', "");
Expect(1, 65055, '\P{^__Vertical_forms}', "");
Expect(0, 65056, '\p{__Vertical_forms}', "");
Expect(1, 65056, '\p{^__Vertical_forms}', "");
Expect(1, 65056, '\P{__Vertical_forms}', "");
Expect(0, 65056, '\P{^__Vertical_forms}', "");
Error('\p{:=-Is_vertical_forms}');
Error('\P{:=-Is_vertical_forms}');
Expect(1, 65055, '\p{isverticalforms}', "");
Expect(0, 65055, '\p{^isverticalforms}', "");
Expect(0, 65055, '\P{isverticalforms}', "");
Expect(1, 65055, '\P{^isverticalforms}', "");
Expect(0, 65056, '\p{isverticalforms}', "");
Expect(1, 65056, '\p{^isverticalforms}', "");
Expect(1, 65056, '\P{isverticalforms}', "");
Expect(0, 65056, '\P{^isverticalforms}', "");
Expect(1, 65055, '\p{_ Is_VERTICAL_Forms}', "");
Expect(0, 65055, '\p{^_ Is_VERTICAL_Forms}', "");
Expect(0, 65055, '\P{_ Is_VERTICAL_Forms}', "");
Expect(1, 65055, '\P{^_ Is_VERTICAL_Forms}', "");
Expect(0, 65056, '\p{_ Is_VERTICAL_Forms}', "");
Expect(1, 65056, '\p{^_ Is_VERTICAL_Forms}', "");
Expect(1, 65056, '\P{_ Is_VERTICAL_Forms}', "");
Expect(0, 65056, '\P{^_ Is_VERTICAL_Forms}', "");
Error('\p{:=In_Vertical_Forms}');
Error('\P{:=In_Vertical_Forms}');
Expect(1, 65055, '\p{inverticalforms}', "");
Expect(0, 65055, '\p{^inverticalforms}', "");
Expect(0, 65055, '\P{inverticalforms}', "");
Expect(1, 65055, '\P{^inverticalforms}', "");
Expect(0, 65056, '\p{inverticalforms}', "");
Expect(1, 65056, '\p{^inverticalforms}', "");
Expect(1, 65056, '\P{inverticalforms}', "");
Expect(0, 65056, '\P{^inverticalforms}', "");
Expect(1, 65055, '\p{ _In_Vertical_FORMS}', "");
Expect(0, 65055, '\p{^ _In_Vertical_FORMS}', "");
Expect(0, 65055, '\P{ _In_Vertical_FORMS}', "");
Expect(1, 65055, '\P{^ _In_Vertical_FORMS}', "");
Expect(0, 65056, '\p{ _In_Vertical_FORMS}', "");
Expect(1, 65056, '\p{^ _In_Vertical_FORMS}', "");
Expect(1, 65056, '\P{ _In_Vertical_FORMS}', "");
Expect(0, 65056, '\P{^ _In_Vertical_FORMS}', "");
Error('\p{ -WHITE_SPACE/a/}');
Error('\P{ -WHITE_SPACE/a/}');
Expect(1, 12288, '\p{whitespace}', "");
Expect(0, 12288, '\p{^whitespace}', "");
Expect(0, 12288, '\P{whitespace}', "");
Expect(1, 12288, '\P{^whitespace}', "");
Expect(0, 12289, '\p{whitespace}', "");
Expect(1, 12289, '\p{^whitespace}', "");
Expect(1, 12289, '\P{whitespace}', "");
Expect(0, 12289, '\P{^whitespace}', "");
Expect(1, 12288, '\p{-	White_space}', "");
Expect(0, 12288, '\p{^-	White_space}', "");
Expect(0, 12288, '\P{-	White_space}', "");
Expect(1, 12288, '\P{^-	White_space}', "");
Expect(0, 12289, '\p{-	White_space}', "");
Expect(1, 12289, '\p{^-	White_space}', "");
Expect(1, 12289, '\P{-	White_space}', "");
Expect(0, 12289, '\P{^-	White_space}', "");
Error('\p{/a/-	Is_white_Space}');
Error('\P{/a/-	Is_white_Space}');
Expect(1, 12288, '\p{iswhitespace}', "");
Expect(0, 12288, '\p{^iswhitespace}', "");
Expect(0, 12288, '\P{iswhitespace}', "");
Expect(1, 12288, '\P{^iswhitespace}', "");
Expect(0, 12289, '\p{iswhitespace}', "");
Expect(1, 12289, '\p{^iswhitespace}', "");
Expect(1, 12289, '\P{iswhitespace}', "");
Expect(0, 12289, '\P{^iswhitespace}', "");
Expect(1, 12288, '\p{-	Is_White_SPACE}', "");
Expect(0, 12288, '\p{^-	Is_White_SPACE}', "");
Expect(0, 12288, '\P{-	Is_White_SPACE}', "");
Expect(1, 12288, '\P{^-	Is_White_SPACE}', "");
Expect(0, 12289, '\p{-	Is_White_SPACE}', "");
Expect(1, 12289, '\p{^-	Is_White_SPACE}', "");
Expect(1, 12289, '\P{-	Is_White_SPACE}', "");
Expect(0, 12289, '\P{^-	Is_White_SPACE}', "");
Error('\p{ /a/WSPACE}');
Error('\P{ /a/WSPACE}');
Expect(1, 12288, '\p{wspace}', "");
Expect(0, 12288, '\p{^wspace}', "");
Expect(0, 12288, '\P{wspace}', "");
Expect(1, 12288, '\P{^wspace}', "");
Expect(0, 12289, '\p{wspace}', "");
Expect(1, 12289, '\p{^wspace}', "");
Expect(1, 12289, '\P{wspace}', "");
Expect(0, 12289, '\P{^wspace}', "");
Expect(1, 12288, '\p{	-WSpace}', "");
Expect(0, 12288, '\p{^	-WSpace}', "");
Expect(0, 12288, '\P{	-WSpace}', "");
Expect(1, 12288, '\P{^	-WSpace}', "");
Expect(0, 12289, '\p{	-WSpace}', "");
Expect(1, 12289, '\p{^	-WSpace}', "");
Expect(1, 12289, '\P{	-WSpace}', "");
Expect(0, 12289, '\P{^	-WSpace}', "");
Error('\p{:= _IS_WSpace}');
Error('\P{:= _IS_WSpace}');
Expect(1, 12288, '\p{iswspace}', "");
Expect(0, 12288, '\p{^iswspace}', "");
Expect(0, 12288, '\P{iswspace}', "");
Expect(1, 12288, '\P{^iswspace}', "");
Expect(0, 12289, '\p{iswspace}', "");
Expect(1, 12289, '\p{^iswspace}', "");
Expect(1, 12289, '\P{iswspace}', "");
Expect(0, 12289, '\P{^iswspace}', "");
Expect(1, 12288, '\p{	_Is_WSpace}', "");
Expect(0, 12288, '\p{^	_Is_WSpace}', "");
Expect(0, 12288, '\P{	_Is_WSpace}', "");
Expect(1, 12288, '\P{^	_Is_WSpace}', "");
Expect(0, 12289, '\p{	_Is_WSpace}', "");
Expect(1, 12289, '\p{^	_Is_WSpace}', "");
Expect(1, 12289, '\P{	_Is_WSpace}', "");
Expect(0, 12289, '\P{^	_Is_WSpace}', "");
Error('\p{- word:=}');
Error('\P{- word:=}');
Expect(1, 917999, '\p{word}', "");
Expect(0, 917999, '\p{^word}', "");
Expect(0, 917999, '\P{word}', "");
Expect(1, 917999, '\P{^word}', "");
Expect(0, 918000, '\p{word}', "");
Expect(1, 918000, '\p{^word}', "");
Expect(1, 918000, '\P{word}', "");
Expect(0, 918000, '\P{^word}', "");
Expect(1, 917999, '\p{ WORD}', "");
Expect(0, 917999, '\p{^ WORD}', "");
Expect(0, 917999, '\P{ WORD}', "");
Expect(1, 917999, '\P{^ WORD}', "");
Expect(0, 918000, '\p{ WORD}', "");
Expect(1, 918000, '\p{^ WORD}', "");
Expect(1, 918000, '\P{ WORD}', "");
Expect(0, 918000, '\P{^ WORD}', "");
Error('\p{-	xposixword/a/}');
Error('\P{-	xposixword/a/}');
Expect(1, 917999, '\p{xposixword}', "");
Expect(0, 917999, '\p{^xposixword}', "");
Expect(0, 917999, '\P{xposixword}', "");
Expect(1, 917999, '\P{^xposixword}', "");
Expect(0, 918000, '\p{xposixword}', "");
Expect(1, 918000, '\p{^xposixword}', "");
Expect(1, 918000, '\P{xposixword}', "");
Expect(0, 918000, '\P{^xposixword}', "");
Error('\p{ /a/Is_word}');
Error('\P{ /a/Is_word}');
Expect(1, 917999, '\p{isword}', "");
Expect(0, 917999, '\p{^isword}', "");
Expect(0, 917999, '\P{isword}', "");
Expect(1, 917999, '\P{^isword}', "");
Expect(0, 918000, '\p{isword}', "");
Expect(1, 918000, '\p{^isword}', "");
Expect(1, 918000, '\P{isword}', "");
Expect(0, 918000, '\P{^isword}', "");
Expect(1, 917999, '\p{-	IS_Word}', "");
Expect(0, 917999, '\p{^-	IS_Word}', "");
Expect(0, 917999, '\P{-	IS_Word}', "");
Expect(1, 917999, '\P{^-	IS_Word}', "");
Expect(0, 918000, '\p{-	IS_Word}', "");
Expect(1, 918000, '\p{^-	IS_Word}', "");
Expect(1, 918000, '\P{-	IS_Word}', "");
Expect(0, 918000, '\P{^-	IS_Word}', "");
Error('\p{-_Is_XPosixWord:=}');
Error('\P{-_Is_XPosixWord:=}');
Expect(1, 917999, '\p{isxposixword}', "");
Expect(0, 917999, '\p{^isxposixword}', "");
Expect(0, 917999, '\P{isxposixword}', "");
Expect(1, 917999, '\P{^isxposixword}', "");
Expect(0, 918000, '\p{isxposixword}', "");
Expect(1, 918000, '\p{^isxposixword}', "");
Expect(1, 918000, '\P{isxposixword}', "");
Expect(0, 918000, '\P{^isxposixword}', "");
Expect(1, 917999, '\p{	 Is_XPOSIXWORD}', "");
Expect(0, 917999, '\p{^	 Is_XPOSIXWORD}', "");
Expect(0, 917999, '\P{	 Is_XPOSIXWORD}', "");
Expect(1, 917999, '\P{^	 Is_XPOSIXWORD}', "");
Expect(0, 918000, '\p{	 Is_XPOSIXWORD}', "");
Expect(1, 918000, '\p{^	 Is_XPOSIXWORD}', "");
Expect(1, 918000, '\P{	 Is_XPOSIXWORD}', "");
Expect(0, 918000, '\P{^	 Is_XPOSIXWORD}', "");
Error('\p{ XDigit/a/}');
Error('\P{ XDigit/a/}');
Expect(1, 65350, '\p{xdigit}', "");
Expect(0, 65350, '\p{^xdigit}', "");
Expect(0, 65350, '\P{xdigit}', "");
Expect(1, 65350, '\P{^xdigit}', "");
Expect(0, 65351, '\p{xdigit}', "");
Expect(1, 65351, '\p{^xdigit}', "");
Expect(1, 65351, '\P{xdigit}', "");
Expect(0, 65351, '\P{^xdigit}', "");
Expect(1, 65350, '\p{	xdigit}', "");
Expect(0, 65350, '\p{^	xdigit}', "");
Expect(0, 65350, '\P{	xdigit}', "");
Expect(1, 65350, '\P{^	xdigit}', "");
Expect(0, 65351, '\p{	xdigit}', "");
Expect(1, 65351, '\p{^	xdigit}', "");
Expect(1, 65351, '\P{	xdigit}', "");
Expect(0, 65351, '\P{^	xdigit}', "");
Error('\p{ -XPOSIXXDIGIT:=}');
Error('\P{ -XPOSIXXDIGIT:=}');
Expect(1, 65350, '\p{xposixxdigit}', "");
Expect(0, 65350, '\p{^xposixxdigit}', "");
Expect(0, 65350, '\P{xposixxdigit}', "");
Expect(1, 65350, '\P{^xposixxdigit}', "");
Expect(0, 65351, '\p{xposixxdigit}', "");
Expect(1, 65351, '\p{^xposixxdigit}', "");
Expect(1, 65351, '\P{xposixxdigit}', "");
Expect(0, 65351, '\P{^xposixxdigit}', "");
Expect(1, 65350, '\p{-XPosixXDigit}', "");
Expect(0, 65350, '\p{^-XPosixXDigit}', "");
Expect(0, 65350, '\P{-XPosixXDigit}', "");
Expect(1, 65350, '\P{^-XPosixXDigit}', "");
Expect(0, 65351, '\p{-XPosixXDigit}', "");
Expect(1, 65351, '\p{^-XPosixXDigit}', "");
Expect(1, 65351, '\P{-XPosixXDigit}', "");
Expect(0, 65351, '\P{^-XPosixXDigit}', "");
Error('\p{/a/	is_XDigit}');
Error('\P{/a/	is_XDigit}');
Expect(1, 65350, '\p{isxdigit}', "");
Expect(0, 65350, '\p{^isxdigit}', "");
Expect(0, 65350, '\P{isxdigit}', "");
Expect(1, 65350, '\P{^isxdigit}', "");
Expect(0, 65351, '\p{isxdigit}', "");
Expect(1, 65351, '\p{^isxdigit}', "");
Expect(1, 65351, '\P{isxdigit}', "");
Expect(0, 65351, '\P{^isxdigit}', "");
Expect(1, 65350, '\p{ -Is_xdigit}', "");
Expect(0, 65350, '\p{^ -Is_xdigit}', "");
Expect(0, 65350, '\P{ -Is_xdigit}', "");
Expect(1, 65350, '\P{^ -Is_xdigit}', "");
Expect(0, 65351, '\p{ -Is_xdigit}', "");
Expect(1, 65351, '\p{^ -Is_xdigit}', "");
Expect(1, 65351, '\P{ -Is_xdigit}', "");
Expect(0, 65351, '\P{^ -Is_xdigit}', "");
Error('\p{/a/_Is_XPOSIXXDIGIT}');
Error('\P{/a/_Is_XPOSIXXDIGIT}');
Expect(1, 65350, '\p{isxposixxdigit}', "");
Expect(0, 65350, '\p{^isxposixxdigit}', "");
Expect(0, 65350, '\P{isxposixxdigit}', "");
Expect(1, 65350, '\P{^isxposixxdigit}', "");
Expect(0, 65351, '\p{isxposixxdigit}', "");
Expect(1, 65351, '\p{^isxposixxdigit}', "");
Expect(1, 65351, '\P{isxposixxdigit}', "");
Expect(0, 65351, '\P{^isxposixxdigit}', "");
Expect(1, 65350, '\p{_IS_XPosixXDigit}', "");
Expect(0, 65350, '\p{^_IS_XPosixXDigit}', "");
Expect(0, 65350, '\P{_IS_XPosixXDigit}', "");
Expect(1, 65350, '\P{^_IS_XPosixXDigit}', "");
Expect(0, 65351, '\p{_IS_XPosixXDigit}', "");
Expect(1, 65351, '\p{^_IS_XPosixXDigit}', "");
Expect(1, 65351, '\P{_IS_XPosixXDigit}', "");
Expect(0, 65351, '\P{^_IS_XPosixXDigit}', "");
Error('\p{--hex_DIGIT:=}');
Error('\P{--hex_DIGIT:=}');
Expect(1, 65350, '\p{hexdigit}', "");
Expect(0, 65350, '\p{^hexdigit}', "");
Expect(0, 65350, '\P{hexdigit}', "");
Expect(1, 65350, '\P{^hexdigit}', "");
Expect(0, 65351, '\p{hexdigit}', "");
Expect(1, 65351, '\p{^hexdigit}', "");
Expect(1, 65351, '\P{hexdigit}', "");
Expect(0, 65351, '\P{^hexdigit}', "");
Expect(1, 65350, '\p{ -Hex_Digit}', "");
Expect(0, 65350, '\p{^ -Hex_Digit}', "");
Expect(0, 65350, '\P{ -Hex_Digit}', "");
Expect(1, 65350, '\P{^ -Hex_Digit}', "");
Expect(0, 65351, '\p{ -Hex_Digit}', "");
Expect(1, 65351, '\p{^ -Hex_Digit}', "");
Expect(1, 65351, '\P{ -Hex_Digit}', "");
Expect(0, 65351, '\P{^ -Hex_Digit}', "");
Error('\p{--IS_hex_DIGIT:=}');
Error('\P{--IS_hex_DIGIT:=}');
Expect(1, 65350, '\p{ishexdigit}', "");
Expect(0, 65350, '\p{^ishexdigit}', "");
Expect(0, 65350, '\P{ishexdigit}', "");
Expect(1, 65350, '\P{^ishexdigit}', "");
Expect(0, 65351, '\p{ishexdigit}', "");
Expect(1, 65351, '\p{^ishexdigit}', "");
Expect(1, 65351, '\P{ishexdigit}', "");
Expect(0, 65351, '\P{^ishexdigit}', "");
Expect(1, 65350, '\p{_	IS_Hex_DIGIT}', "");
Expect(0, 65350, '\p{^_	IS_Hex_DIGIT}', "");
Expect(0, 65350, '\P{_	IS_Hex_DIGIT}', "");
Expect(1, 65350, '\P{^_	IS_Hex_DIGIT}', "");
Expect(0, 65351, '\p{_	IS_Hex_DIGIT}', "");
Expect(1, 65351, '\p{^_	IS_Hex_DIGIT}', "");
Expect(1, 65351, '\P{_	IS_Hex_DIGIT}', "");
Expect(0, 65351, '\P{^_	IS_Hex_DIGIT}', "");
Error('\p{	HEX/a/}');
Error('\P{	HEX/a/}');
Expect(1, 65350, '\p{hex}', "");
Expect(0, 65350, '\p{^hex}', "");
Expect(0, 65350, '\P{hex}', "");
Expect(1, 65350, '\P{^hex}', "");
Expect(0, 65351, '\p{hex}', "");
Expect(1, 65351, '\p{^hex}', "");
Expect(1, 65351, '\P{hex}', "");
Expect(0, 65351, '\P{^hex}', "");
Expect(1, 65350, '\p{ HEX}', "");
Expect(0, 65350, '\p{^ HEX}', "");
Expect(0, 65350, '\P{ HEX}', "");
Expect(1, 65350, '\P{^ HEX}', "");
Expect(0, 65351, '\p{ HEX}', "");
Expect(1, 65351, '\p{^ HEX}', "");
Expect(1, 65351, '\P{ HEX}', "");
Expect(0, 65351, '\P{^ HEX}', "");
Error('\p{ /a/IS_HEX}');
Error('\P{ /a/IS_HEX}');
Expect(1, 65350, '\p{ishex}', "");
Expect(0, 65350, '\p{^ishex}', "");
Expect(0, 65350, '\P{ishex}', "");
Expect(1, 65350, '\P{^ishex}', "");
Expect(0, 65351, '\p{ishex}', "");
Expect(1, 65351, '\p{^ishex}', "");
Expect(1, 65351, '\P{ishex}', "");
Expect(0, 65351, '\P{^ishex}', "");
Expect(1, 65350, '\p{	 is_Hex}', "");
Expect(0, 65350, '\p{^	 is_Hex}', "");
Expect(0, 65350, '\P{	 is_Hex}', "");
Expect(1, 65350, '\P{^	 is_Hex}', "");
Expect(0, 65351, '\p{	 is_Hex}', "");
Expect(1, 65351, '\p{^	 is_Hex}', "");
Expect(1, 65351, '\P{	 is_Hex}', "");
Expect(0, 65351, '\P{^	 is_Hex}', "");
Error('\p{:=  XID_Continue}');
Error('\P{:=  XID_Continue}');
Expect(1, 917999, '\p{xidcontinue}', "");
Expect(0, 917999, '\p{^xidcontinue}', "");
Expect(0, 917999, '\P{xidcontinue}', "");
Expect(1, 917999, '\P{^xidcontinue}', "");
Expect(0, 918000, '\p{xidcontinue}', "");
Expect(1, 918000, '\p{^xidcontinue}', "");
Expect(1, 918000, '\P{xidcontinue}', "");
Expect(0, 918000, '\P{^xidcontinue}', "");
Expect(1, 917999, '\p{-XID_Continue}', "");
Expect(0, 917999, '\p{^-XID_Continue}', "");
Expect(0, 917999, '\P{-XID_Continue}', "");
Expect(1, 917999, '\P{^-XID_Continue}', "");
Expect(0, 918000, '\p{-XID_Continue}', "");
Expect(1, 918000, '\p{^-XID_Continue}', "");
Expect(1, 918000, '\P{-XID_Continue}', "");
Expect(0, 918000, '\P{^-XID_Continue}', "");
Error('\p{ _Is_XID_continue:=}');
Error('\P{ _Is_XID_continue:=}');
Expect(1, 917999, '\p{isxidcontinue}', "");
Expect(0, 917999, '\p{^isxidcontinue}', "");
Expect(0, 917999, '\P{isxidcontinue}', "");
Expect(1, 917999, '\P{^isxidcontinue}', "");
Expect(0, 918000, '\p{isxidcontinue}', "");
Expect(1, 918000, '\p{^isxidcontinue}', "");
Expect(1, 918000, '\P{isxidcontinue}', "");
Expect(0, 918000, '\P{^isxidcontinue}', "");
Expect(1, 917999, '\p{	 Is_XID_CONTINUE}', "");
Expect(0, 917999, '\p{^	 Is_XID_CONTINUE}', "");
Expect(0, 917999, '\P{	 Is_XID_CONTINUE}', "");
Expect(1, 917999, '\P{^	 Is_XID_CONTINUE}', "");
Expect(0, 918000, '\p{	 Is_XID_CONTINUE}', "");
Expect(1, 918000, '\p{^	 Is_XID_CONTINUE}', "");
Expect(1, 918000, '\P{	 Is_XID_CONTINUE}', "");
Expect(0, 918000, '\P{^	 Is_XID_CONTINUE}', "");
Error('\p{-:=XIDC}');
Error('\P{-:=XIDC}');
Expect(1, 917999, '\p{xidc}', "");
Expect(0, 917999, '\p{^xidc}', "");
Expect(0, 917999, '\P{xidc}', "");
Expect(1, 917999, '\P{^xidc}', "");
Expect(0, 918000, '\p{xidc}', "");
Expect(1, 918000, '\p{^xidc}', "");
Expect(1, 918000, '\P{xidc}', "");
Expect(0, 918000, '\P{^xidc}', "");
Expect(1, 917999, '\p{-XIDC}', "");
Expect(0, 917999, '\p{^-XIDC}', "");
Expect(0, 917999, '\P{-XIDC}', "");
Expect(1, 917999, '\P{^-XIDC}', "");
Expect(0, 918000, '\p{-XIDC}', "");
Expect(1, 918000, '\p{^-XIDC}', "");
Expect(1, 918000, '\P{-XIDC}', "");
Expect(0, 918000, '\P{^-XIDC}', "");
Error('\p{	:=is_xidc}');
Error('\P{	:=is_xidc}');
Expect(1, 917999, '\p{isxidc}', "");
Expect(0, 917999, '\p{^isxidc}', "");
Expect(0, 917999, '\P{isxidc}', "");
Expect(1, 917999, '\P{^isxidc}', "");
Expect(0, 918000, '\p{isxidc}', "");
Expect(1, 918000, '\p{^isxidc}', "");
Expect(1, 918000, '\P{isxidc}', "");
Expect(0, 918000, '\P{^isxidc}', "");
Expect(1, 917999, '\p{	Is_XIDC}', "");
Expect(0, 917999, '\p{^	Is_XIDC}', "");
Expect(0, 917999, '\P{	Is_XIDC}', "");
Expect(1, 917999, '\P{^	Is_XIDC}', "");
Expect(0, 918000, '\p{	Is_XIDC}', "");
Expect(1, 918000, '\p{^	Is_XIDC}', "");
Expect(1, 918000, '\P{	Is_XIDC}', "");
Expect(0, 918000, '\P{^	Is_XIDC}', "");
Error('\p{-/a/XID_Start}');
Error('\P{-/a/XID_Start}');
Expect(1, 195101, '\p{xidstart}', "");
Expect(0, 195101, '\p{^xidstart}', "");
Expect(0, 195101, '\P{xidstart}', "");
Expect(1, 195101, '\P{^xidstart}', "");
Expect(0, 195102, '\p{xidstart}', "");
Expect(1, 195102, '\p{^xidstart}', "");
Expect(1, 195102, '\P{xidstart}', "");
Expect(0, 195102, '\P{^xidstart}', "");
Expect(1, 195101, '\p{	XID_Start}', "");
Expect(0, 195101, '\p{^	XID_Start}', "");
Expect(0, 195101, '\P{	XID_Start}', "");
Expect(1, 195101, '\P{^	XID_Start}', "");
Expect(0, 195102, '\p{	XID_Start}', "");
Expect(1, 195102, '\p{^	XID_Start}', "");
Expect(1, 195102, '\P{	XID_Start}', "");
Expect(0, 195102, '\P{^	XID_Start}', "");
Error('\p{_Is_xid_Start:=}');
Error('\P{_Is_xid_Start:=}');
Expect(1, 195101, '\p{isxidstart}', "");
Expect(0, 195101, '\p{^isxidstart}', "");
Expect(0, 195101, '\P{isxidstart}', "");
Expect(1, 195101, '\P{^isxidstart}', "");
Expect(0, 195102, '\p{isxidstart}', "");
Expect(1, 195102, '\p{^isxidstart}', "");
Expect(1, 195102, '\P{isxidstart}', "");
Expect(0, 195102, '\P{^isxidstart}', "");
Expect(1, 195101, '\p{_Is_XID_START}', "");
Expect(0, 195101, '\p{^_Is_XID_START}', "");
Expect(0, 195101, '\P{_Is_XID_START}', "");
Expect(1, 195101, '\P{^_Is_XID_START}', "");
Expect(0, 195102, '\p{_Is_XID_START}', "");
Expect(1, 195102, '\p{^_Is_XID_START}', "");
Expect(1, 195102, '\P{_Is_XID_START}', "");
Expect(0, 195102, '\P{^_Is_XID_START}', "");
Error('\p{/a/--xids}');
Error('\P{/a/--xids}');
Expect(1, 195101, '\p{xids}', "");
Expect(0, 195101, '\p{^xids}', "");
Expect(0, 195101, '\P{xids}', "");
Expect(1, 195101, '\P{^xids}', "");
Expect(0, 195102, '\p{xids}', "");
Expect(1, 195102, '\p{^xids}', "");
Expect(1, 195102, '\P{xids}', "");
Expect(0, 195102, '\P{^xids}', "");
Expect(1, 195101, '\p{__xids}', "");
Expect(0, 195101, '\p{^__xids}', "");
Expect(0, 195101, '\P{__xids}', "");
Expect(1, 195101, '\P{^__xids}', "");
Expect(0, 195102, '\p{__xids}', "");
Expect(1, 195102, '\p{^__xids}', "");
Expect(1, 195102, '\P{__xids}', "");
Expect(0, 195102, '\P{^__xids}', "");
Error('\p{	:=Is_XIDS}');
Error('\P{	:=Is_XIDS}');
Expect(1, 195101, '\p{isxids}', "");
Expect(0, 195101, '\p{^isxids}', "");
Expect(0, 195101, '\P{isxids}', "");
Expect(1, 195101, '\P{^isxids}', "");
Expect(0, 195102, '\p{isxids}', "");
Expect(1, 195102, '\p{^isxids}', "");
Expect(1, 195102, '\P{isxids}', "");
Expect(0, 195102, '\P{^isxids}', "");
Expect(1, 195101, '\p{ 	is_xids}', "");
Expect(0, 195101, '\p{^ 	is_xids}', "");
Expect(0, 195101, '\P{ 	is_xids}', "");
Expect(1, 195101, '\P{^ 	is_xids}', "");
Expect(0, 195102, '\p{ 	is_xids}', "");
Expect(1, 195102, '\p{^ 	is_xids}', "");
Expect(1, 195102, '\P{ 	is_xids}', "");
Expect(0, 195102, '\P{^ 	is_xids}', "");
Error('\p{:=  XPerlSpace}');
Error('\P{:=  XPerlSpace}');
Expect(1, 12288, '\p{xperlspace}', "");
Expect(0, 12288, '\p{^xperlspace}', "");
Expect(0, 12288, '\P{xperlspace}', "");
Expect(1, 12288, '\P{^xperlspace}', "");
Expect(0, 12289, '\p{xperlspace}', "");
Expect(1, 12289, '\p{^xperlspace}', "");
Expect(1, 12289, '\P{xperlspace}', "");
Expect(0, 12289, '\P{^xperlspace}', "");
Expect(1, 12288, '\p{_XPERLSPACE}', "");
Expect(0, 12288, '\p{^_XPERLSPACE}', "");
Expect(0, 12288, '\P{_XPERLSPACE}', "");
Expect(1, 12288, '\P{^_XPERLSPACE}', "");
Expect(0, 12289, '\p{_XPERLSPACE}', "");
Expect(1, 12289, '\p{^_XPERLSPACE}', "");
Expect(1, 12289, '\P{_XPERLSPACE}', "");
Expect(0, 12289, '\P{^_XPERLSPACE}', "");
Error('\p{- SpacePerl/a/}');
Error('\P{- SpacePerl/a/}');
Expect(1, 12288, '\p{spaceperl}', "");
Expect(0, 12288, '\p{^spaceperl}', "");
Expect(0, 12288, '\P{spaceperl}', "");
Expect(1, 12288, '\P{^spaceperl}', "");
Expect(0, 12289, '\p{spaceperl}', "");
Expect(1, 12289, '\p{^spaceperl}', "");
Expect(1, 12289, '\P{spaceperl}', "");
Expect(0, 12289, '\P{^spaceperl}', "");
Expect(1, 12288, '\p{ 	SpacePerl}', "");
Expect(0, 12288, '\p{^ 	SpacePerl}', "");
Expect(0, 12288, '\P{ 	SpacePerl}', "");
Expect(1, 12288, '\P{^ 	SpacePerl}', "");
Expect(0, 12289, '\p{ 	SpacePerl}', "");
Expect(1, 12289, '\p{^ 	SpacePerl}', "");
Expect(1, 12289, '\P{ 	SpacePerl}', "");
Expect(0, 12289, '\P{^ 	SpacePerl}', "");
Error('\p{ :=is_XPerlSpace}');
Error('\P{ :=is_XPerlSpace}');
Expect(1, 12288, '\p{isxperlspace}', "");
Expect(0, 12288, '\p{^isxperlspace}', "");
Expect(0, 12288, '\P{isxperlspace}', "");
Expect(1, 12288, '\P{^isxperlspace}', "");
Expect(0, 12289, '\p{isxperlspace}', "");
Expect(1, 12289, '\p{^isxperlspace}', "");
Expect(1, 12289, '\P{isxperlspace}', "");
Expect(0, 12289, '\P{^isxperlspace}', "");
Expect(1, 12288, '\p{_	Is_XPERLSPACE}', "");
Expect(0, 12288, '\p{^_	Is_XPERLSPACE}', "");
Expect(0, 12288, '\P{_	Is_XPERLSPACE}', "");
Expect(1, 12288, '\P{^_	Is_XPERLSPACE}', "");
Expect(0, 12289, '\p{_	Is_XPERLSPACE}', "");
Expect(1, 12289, '\p{^_	Is_XPERLSPACE}', "");
Expect(1, 12289, '\P{_	Is_XPERLSPACE}', "");
Expect(0, 12289, '\P{^_	Is_XPERLSPACE}', "");
Error('\p{-:=is_SPACEPERL}');
Error('\P{-:=is_SPACEPERL}');
Expect(1, 12288, '\p{isspaceperl}', "");
Expect(0, 12288, '\p{^isspaceperl}', "");
Expect(0, 12288, '\P{isspaceperl}', "");
Expect(1, 12288, '\P{^isspaceperl}', "");
Expect(0, 12289, '\p{isspaceperl}', "");
Expect(1, 12289, '\p{^isspaceperl}', "");
Expect(1, 12289, '\P{isspaceperl}', "");
Expect(0, 12289, '\P{^isspaceperl}', "");
Expect(1, 12288, '\p{__IS_spaceperl}', "");
Expect(0, 12288, '\p{^__IS_spaceperl}', "");
Expect(0, 12288, '\P{__IS_spaceperl}', "");
Expect(1, 12288, '\P{^__IS_spaceperl}', "");
Expect(0, 12289, '\p{__IS_spaceperl}', "");
Expect(1, 12289, '\p{^__IS_spaceperl}', "");
Expect(1, 12289, '\P{__IS_spaceperl}', "");
Expect(0, 12289, '\P{^__IS_spaceperl}', "");
Error('\p{ :=XPOSIXPUNCT}');
Error('\P{ :=XPOSIXPUNCT}');
Expect(1, 74867, '\p{xposixpunct}', "");
Expect(0, 74867, '\p{^xposixpunct}', "");
Expect(0, 74867, '\P{xposixpunct}', "");
Expect(1, 74867, '\P{^xposixpunct}', "");
Expect(0, 74868, '\p{xposixpunct}', "");
Expect(1, 74868, '\p{^xposixpunct}', "");
Expect(1, 74868, '\P{xposixpunct}', "");
Expect(0, 74868, '\P{^xposixpunct}', "");
Expect(1, 74867, '\p{	XPosixPunct}', "");
Expect(0, 74867, '\p{^	XPosixPunct}', "");
Expect(0, 74867, '\P{	XPosixPunct}', "");
Expect(1, 74867, '\P{^	XPosixPunct}', "");
Expect(0, 74868, '\p{	XPosixPunct}', "");
Expect(1, 74868, '\p{^	XPosixPunct}', "");
Expect(1, 74868, '\P{	XPosixPunct}', "");
Expect(0, 74868, '\P{^	XPosixPunct}', "");
Error('\p{_/a/IS_xposixpunct}');
Error('\P{_/a/IS_xposixpunct}');
Expect(1, 74867, '\p{isxposixpunct}', "");
Expect(0, 74867, '\p{^isxposixpunct}', "");
Expect(0, 74867, '\P{isxposixpunct}', "");
Expect(1, 74867, '\P{^isxposixpunct}', "");
Expect(0, 74868, '\p{isxposixpunct}', "");
Expect(1, 74868, '\p{^isxposixpunct}', "");
Expect(1, 74868, '\P{isxposixpunct}', "");
Expect(0, 74868, '\P{^isxposixpunct}', "");
Expect(1, 74867, '\p{-Is_XPosixPunct}', "");
Expect(0, 74867, '\p{^-Is_XPosixPunct}', "");
Expect(0, 74867, '\P{-Is_XPosixPunct}', "");
Expect(1, 74867, '\P{^-Is_XPosixPunct}', "");
Expect(0, 74868, '\p{-Is_XPosixPunct}', "");
Expect(1, 74868, '\p{^-Is_XPosixPunct}', "");
Expect(1, 74868, '\P{-Is_XPosixPunct}', "");
Expect(0, 74868, '\P{^-Is_XPosixPunct}', "");
Error('\p{yi:=}');
Error('\P{yi:=}');
Expect(1, 42182, '\p{yi}', "");
Expect(0, 42182, '\p{^yi}', "");
Expect(0, 42182, '\P{yi}', "");
Expect(1, 42182, '\P{^yi}', "");
Expect(0, 42183, '\p{yi}', "");
Expect(1, 42183, '\p{^yi}', "");
Expect(1, 42183, '\P{yi}', "");
Expect(0, 42183, '\P{^yi}', "");
Expect(1, 42182, '\p{ _Yi}', "");
Expect(0, 42182, '\p{^ _Yi}', "");
Expect(0, 42182, '\P{ _Yi}', "");
Expect(1, 42182, '\P{^ _Yi}', "");
Expect(0, 42183, '\p{ _Yi}', "");
Expect(1, 42183, '\p{^ _Yi}', "");
Expect(1, 42183, '\P{ _Yi}', "");
Expect(0, 42183, '\P{^ _Yi}', "");
Error('\p{:=Is_Yi}');
Error('\P{:=Is_Yi}');
Expect(1, 42182, '\p{isyi}', "");
Expect(0, 42182, '\p{^isyi}', "");
Expect(0, 42182, '\P{isyi}', "");
Expect(1, 42182, '\P{^isyi}', "");
Expect(0, 42183, '\p{isyi}', "");
Expect(1, 42183, '\p{^isyi}', "");
Expect(1, 42183, '\P{isyi}', "");
Expect(0, 42183, '\P{^isyi}', "");
Expect(1, 42182, '\p{-Is_Yi}', "");
Expect(0, 42182, '\p{^-Is_Yi}', "");
Expect(0, 42182, '\P{-Is_Yi}', "");
Expect(1, 42182, '\P{^-Is_Yi}', "");
Expect(0, 42183, '\p{-Is_Yi}', "");
Expect(1, 42183, '\p{^-Is_Yi}', "");
Expect(1, 42183, '\P{-Is_Yi}', "");
Expect(0, 42183, '\P{^-Is_Yi}', "");
Error('\p{	YIII:=}');
Error('\P{	YIII:=}');
Expect(1, 42182, '\p{yiii}', "");
Expect(0, 42182, '\p{^yiii}', "");
Expect(0, 42182, '\P{yiii}', "");
Expect(1, 42182, '\P{^yiii}', "");
Expect(0, 42183, '\p{yiii}', "");
Expect(1, 42183, '\p{^yiii}', "");
Expect(1, 42183, '\P{yiii}', "");
Expect(0, 42183, '\P{^yiii}', "");
Expect(1, 42182, '\p{_-yiii}', "");
Expect(0, 42182, '\p{^_-yiii}', "");
Expect(0, 42182, '\P{_-yiii}', "");
Expect(1, 42182, '\P{^_-yiii}', "");
Expect(0, 42183, '\p{_-yiii}', "");
Expect(1, 42183, '\p{^_-yiii}', "");
Expect(1, 42183, '\P{_-yiii}', "");
Expect(0, 42183, '\P{^_-yiii}', "");
Error('\p{/a/__IS_Yiii}');
Error('\P{/a/__IS_Yiii}');
Expect(1, 42182, '\p{isyiii}', "");
Expect(0, 42182, '\p{^isyiii}', "");
Expect(0, 42182, '\P{isyiii}', "");
Expect(1, 42182, '\P{^isyiii}', "");
Expect(0, 42183, '\p{isyiii}', "");
Expect(1, 42183, '\p{^isyiii}', "");
Expect(1, 42183, '\P{isyiii}', "");
Expect(0, 42183, '\P{^isyiii}', "");
Expect(1, 42182, '\p{  IS_yiii}', "");
Expect(0, 42182, '\p{^  IS_yiii}', "");
Expect(0, 42182, '\P{  IS_yiii}', "");
Expect(1, 42182, '\P{^  IS_yiii}', "");
Expect(0, 42183, '\p{  IS_yiii}', "");
Expect(1, 42183, '\p{^  IS_yiii}', "");
Expect(1, 42183, '\P{  IS_yiii}', "");
Expect(0, 42183, '\P{^  IS_yiii}', "");
Error('\p{ _YI_radicals:=}');
Error('\P{ _YI_radicals:=}');
Expect(1, 42191, '\p{yiradicals}', "");
Expect(0, 42191, '\p{^yiradicals}', "");
Expect(0, 42191, '\P{yiradicals}', "");
Expect(1, 42191, '\P{^yiradicals}', "");
Expect(0, 42192, '\p{yiradicals}', "");
Expect(1, 42192, '\p{^yiradicals}', "");
Expect(1, 42192, '\P{yiradicals}', "");
Expect(0, 42192, '\P{^yiradicals}', "");
Expect(1, 42191, '\p{- YI_Radicals}', "");
Expect(0, 42191, '\p{^- YI_Radicals}', "");
Expect(0, 42191, '\P{- YI_Radicals}', "");
Expect(1, 42191, '\P{^- YI_Radicals}', "");
Expect(0, 42192, '\p{- YI_Radicals}', "");
Expect(1, 42192, '\p{^- YI_Radicals}', "");
Expect(1, 42192, '\P{- YI_Radicals}', "");
Expect(0, 42192, '\P{^- YI_Radicals}', "");
Error('\p{		IS_Yi_RADICALS/a/}');
Error('\P{		IS_Yi_RADICALS/a/}');
Expect(1, 42191, '\p{isyiradicals}', "");
Expect(0, 42191, '\p{^isyiradicals}', "");
Expect(0, 42191, '\P{isyiradicals}', "");
Expect(1, 42191, '\P{^isyiradicals}', "");
Expect(0, 42192, '\p{isyiradicals}', "");
Expect(1, 42192, '\p{^isyiradicals}', "");
Expect(1, 42192, '\P{isyiradicals}', "");
Expect(0, 42192, '\P{^isyiradicals}', "");
Expect(1, 42191, '\p{ _Is_Yi_Radicals}', "");
Expect(0, 42191, '\p{^ _Is_Yi_Radicals}', "");
Expect(0, 42191, '\P{ _Is_Yi_Radicals}', "");
Expect(1, 42191, '\P{^ _Is_Yi_Radicals}', "");
Expect(0, 42192, '\p{ _Is_Yi_Radicals}', "");
Expect(1, 42192, '\p{^ _Is_Yi_Radicals}', "");
Expect(1, 42192, '\P{ _Is_Yi_Radicals}', "");
Expect(0, 42192, '\P{^ _Is_Yi_Radicals}', "");
Error('\p{_In_Yi_RADICALS:=}');
Error('\P{_In_Yi_RADICALS:=}');
Expect(1, 42191, '\p{inyiradicals}', "");
Expect(0, 42191, '\p{^inyiradicals}', "");
Expect(0, 42191, '\P{inyiradicals}', "");
Expect(1, 42191, '\P{^inyiradicals}', "");
Expect(0, 42192, '\p{inyiradicals}', "");
Expect(1, 42192, '\p{^inyiradicals}', "");
Expect(1, 42192, '\P{inyiradicals}', "");
Expect(0, 42192, '\P{^inyiradicals}', "");
Expect(1, 42191, '\p{_in_yi_RADICALS}', "");
Expect(0, 42191, '\p{^_in_yi_RADICALS}', "");
Expect(0, 42191, '\P{_in_yi_RADICALS}', "");
Expect(1, 42191, '\P{^_in_yi_RADICALS}', "");
Expect(0, 42192, '\p{_in_yi_RADICALS}', "");
Expect(1, 42192, '\p{^_in_yi_RADICALS}', "");
Expect(1, 42192, '\P{_in_yi_RADICALS}', "");
Expect(0, 42192, '\P{^_in_yi_RADICALS}', "");
Error('\p{	:=YI_Syllables}');
Error('\P{	:=YI_Syllables}');
Expect(1, 42127, '\p{yisyllables}', "");
Expect(0, 42127, '\p{^yisyllables}', "");
Expect(0, 42127, '\P{yisyllables}', "");
Expect(1, 42127, '\P{^yisyllables}', "");
Expect(0, 42128, '\p{yisyllables}', "");
Expect(1, 42128, '\p{^yisyllables}', "");
Expect(1, 42128, '\P{yisyllables}', "");
Expect(0, 42128, '\P{^yisyllables}', "");
Expect(1, 42127, '\p{_	YI_SYLLABLES}', "");
Expect(0, 42127, '\p{^_	YI_SYLLABLES}', "");
Expect(0, 42127, '\P{_	YI_SYLLABLES}', "");
Expect(1, 42127, '\P{^_	YI_SYLLABLES}', "");
Expect(0, 42128, '\p{_	YI_SYLLABLES}', "");
Expect(1, 42128, '\p{^_	YI_SYLLABLES}', "");
Expect(1, 42128, '\P{_	YI_SYLLABLES}', "");
Expect(0, 42128, '\P{^_	YI_SYLLABLES}', "");
Error('\p{_:=is_Yi_Syllables}');
Error('\P{_:=is_Yi_Syllables}');
Expect(1, 42127, '\p{isyisyllables}', "");
Expect(0, 42127, '\p{^isyisyllables}', "");
Expect(0, 42127, '\P{isyisyllables}', "");
Expect(1, 42127, '\P{^isyisyllables}', "");
Expect(0, 42128, '\p{isyisyllables}', "");
Expect(1, 42128, '\p{^isyisyllables}', "");
Expect(1, 42128, '\P{isyisyllables}', "");
Expect(0, 42128, '\P{^isyisyllables}', "");
Expect(1, 42127, '\p{-	IS_yi_SYLLABLES}', "");
Expect(0, 42127, '\p{^-	IS_yi_SYLLABLES}', "");
Expect(0, 42127, '\P{-	IS_yi_SYLLABLES}', "");
Expect(1, 42127, '\P{^-	IS_yi_SYLLABLES}', "");
Expect(0, 42128, '\p{-	IS_yi_SYLLABLES}', "");
Expect(1, 42128, '\p{^-	IS_yi_SYLLABLES}', "");
Expect(1, 42128, '\P{-	IS_yi_SYLLABLES}', "");
Expect(0, 42128, '\P{^-	IS_yi_SYLLABLES}', "");
Error('\p{_:=In_YI_Syllables}');
Error('\P{_:=In_YI_Syllables}');
Expect(1, 42127, '\p{inyisyllables}', "");
Expect(0, 42127, '\p{^inyisyllables}', "");
Expect(0, 42127, '\P{inyisyllables}', "");
Expect(1, 42127, '\P{^inyisyllables}', "");
Expect(0, 42128, '\p{inyisyllables}', "");
Expect(1, 42128, '\p{^inyisyllables}', "");
Expect(1, 42128, '\P{inyisyllables}', "");
Expect(0, 42128, '\P{^inyisyllables}', "");
Expect(1, 42127, '\p{__in_Yi_Syllables}', "");
Expect(0, 42127, '\p{^__in_Yi_Syllables}', "");
Expect(0, 42127, '\P{__in_Yi_Syllables}', "");
Expect(1, 42127, '\P{^__in_Yi_Syllables}', "");
Expect(0, 42128, '\p{__in_Yi_Syllables}', "");
Expect(1, 42128, '\p{^__in_Yi_Syllables}', "");
Expect(1, 42128, '\P{__in_Yi_Syllables}', "");
Expect(0, 42128, '\P{^__in_Yi_Syllables}', "");
Error('\p{/a/_Yijing_HEXAGRAM_Symbols}');
Error('\P{/a/_Yijing_HEXAGRAM_Symbols}');
Expect(1, 19967, '\p{yijinghexagramsymbols}', "");
Expect(0, 19967, '\p{^yijinghexagramsymbols}', "");
Expect(0, 19967, '\P{yijinghexagramsymbols}', "");
Expect(1, 19967, '\P{^yijinghexagramsymbols}', "");
Expect(0, 19968, '\p{yijinghexagramsymbols}', "");
Expect(1, 19968, '\p{^yijinghexagramsymbols}', "");
Expect(1, 19968, '\P{yijinghexagramsymbols}', "");
Expect(0, 19968, '\P{^yijinghexagramsymbols}', "");
Expect(1, 19967, '\p{ 	Yijing_HEXAGRAM_SYMBOLS}', "");
Expect(0, 19967, '\p{^ 	Yijing_HEXAGRAM_SYMBOLS}', "");
Expect(0, 19967, '\P{ 	Yijing_HEXAGRAM_SYMBOLS}', "");
Expect(1, 19967, '\P{^ 	Yijing_HEXAGRAM_SYMBOLS}', "");
Expect(0, 19968, '\p{ 	Yijing_HEXAGRAM_SYMBOLS}', "");
Expect(1, 19968, '\p{^ 	Yijing_HEXAGRAM_SYMBOLS}', "");
Expect(1, 19968, '\P{ 	Yijing_HEXAGRAM_SYMBOLS}', "");
Expect(0, 19968, '\P{^ 	Yijing_HEXAGRAM_SYMBOLS}', "");
Error('\p{:= 	IS_yijing_Hexagram_SYMBOLS}');
Error('\P{:= 	IS_yijing_Hexagram_SYMBOLS}');
Expect(1, 19967, '\p{isyijinghexagramsymbols}', "");
Expect(0, 19967, '\p{^isyijinghexagramsymbols}', "");
Expect(0, 19967, '\P{isyijinghexagramsymbols}', "");
Expect(1, 19967, '\P{^isyijinghexagramsymbols}', "");
Expect(0, 19968, '\p{isyijinghexagramsymbols}', "");
Expect(1, 19968, '\p{^isyijinghexagramsymbols}', "");
Expect(1, 19968, '\P{isyijinghexagramsymbols}', "");
Expect(0, 19968, '\P{^isyijinghexagramsymbols}', "");
Expect(1, 19967, '\p{-_is_Yijing_hexagram_symbols}', "");
Expect(0, 19967, '\p{^-_is_Yijing_hexagram_symbols}', "");
Expect(0, 19967, '\P{-_is_Yijing_hexagram_symbols}', "");
Expect(1, 19967, '\P{^-_is_Yijing_hexagram_symbols}', "");
Expect(0, 19968, '\p{-_is_Yijing_hexagram_symbols}', "");
Expect(1, 19968, '\p{^-_is_Yijing_hexagram_symbols}', "");
Expect(1, 19968, '\P{-_is_Yijing_hexagram_symbols}', "");
Expect(0, 19968, '\P{^-_is_Yijing_hexagram_symbols}', "");
Error('\p{-	in_YIJING_Hexagram_SYMBOLS:=}');
Error('\P{-	in_YIJING_Hexagram_SYMBOLS:=}');
Expect(1, 19967, '\p{inyijinghexagramsymbols}', "");
Expect(0, 19967, '\p{^inyijinghexagramsymbols}', "");
Expect(0, 19967, '\P{inyijinghexagramsymbols}', "");
Expect(1, 19967, '\P{^inyijinghexagramsymbols}', "");
Expect(0, 19968, '\p{inyijinghexagramsymbols}', "");
Expect(1, 19968, '\p{^inyijinghexagramsymbols}', "");
Expect(1, 19968, '\P{inyijinghexagramsymbols}', "");
Expect(0, 19968, '\P{^inyijinghexagramsymbols}', "");
Expect(1, 19967, '\p{In_Yijing_Hexagram_symbols}', "");
Expect(0, 19967, '\p{^In_Yijing_Hexagram_symbols}', "");
Expect(0, 19967, '\P{In_Yijing_Hexagram_symbols}', "");
Expect(1, 19967, '\P{^In_Yijing_Hexagram_symbols}', "");
Expect(0, 19968, '\p{In_Yijing_Hexagram_symbols}', "");
Expect(1, 19968, '\p{^In_Yijing_Hexagram_symbols}', "");
Expect(1, 19968, '\P{In_Yijing_Hexagram_symbols}', "");
Expect(0, 19968, '\P{^In_Yijing_Hexagram_symbols}', "");
Error('\p{/a/_ yijing}');
Error('\P{/a/_ yijing}');
Expect(1, 19967, '\p{yijing}', "");
Expect(0, 19967, '\p{^yijing}', "");
Expect(0, 19967, '\P{yijing}', "");
Expect(1, 19967, '\P{^yijing}', "");
Expect(0, 19968, '\p{yijing}', "");
Expect(1, 19968, '\p{^yijing}', "");
Expect(1, 19968, '\P{yijing}', "");
Expect(0, 19968, '\P{^yijing}', "");
Expect(1, 19967, '\p{		YIJING}', "");
Expect(0, 19967, '\p{^		YIJING}', "");
Expect(0, 19967, '\P{		YIJING}', "");
Expect(1, 19967, '\P{^		YIJING}', "");
Expect(0, 19968, '\p{		YIJING}', "");
Expect(1, 19968, '\p{^		YIJING}', "");
Expect(1, 19968, '\P{		YIJING}', "");
Expect(0, 19968, '\P{^		YIJING}', "");
Error('\p{/a/ _Is_YIJING}');
Error('\P{/a/ _Is_YIJING}');
Expect(1, 19967, '\p{isyijing}', "");
Expect(0, 19967, '\p{^isyijing}', "");
Expect(0, 19967, '\P{isyijing}', "");
Expect(1, 19967, '\P{^isyijing}', "");
Expect(0, 19968, '\p{isyijing}', "");
Expect(1, 19968, '\p{^isyijing}', "");
Expect(1, 19968, '\P{isyijing}', "");
Expect(0, 19968, '\P{^isyijing}', "");
Expect(1, 19967, '\p{Is_yijing}', "");
Expect(0, 19967, '\p{^Is_yijing}', "");
Expect(0, 19967, '\P{Is_yijing}', "");
Expect(1, 19967, '\P{^Is_yijing}', "");
Expect(0, 19968, '\p{Is_yijing}', "");
Expect(1, 19968, '\p{^Is_yijing}', "");
Expect(1, 19968, '\P{Is_yijing}', "");
Expect(0, 19968, '\P{^Is_yijing}', "");
Error('\p{-:=in_Yijing}');
Error('\P{-:=in_Yijing}');
Expect(1, 19967, '\p{inyijing}', "");
Expect(0, 19967, '\p{^inyijing}', "");
Expect(0, 19967, '\P{inyijing}', "");
Expect(1, 19967, '\P{^inyijing}', "");
Expect(0, 19968, '\p{inyijing}', "");
Expect(1, 19968, '\p{^inyijing}', "");
Expect(1, 19968, '\P{inyijing}', "");
Expect(0, 19968, '\P{^inyijing}', "");
Expect(1, 19967, '\p{	_in_Yijing}', "");
Expect(0, 19967, '\p{^	_in_Yijing}', "");
Expect(0, 19967, '\P{	_in_Yijing}', "");
Expect(1, 19967, '\P{^	_in_Yijing}', "");
Expect(0, 19968, '\p{	_in_Yijing}', "");
Expect(1, 19968, '\p{^	_in_Yijing}', "");
Expect(1, 19968, '\P{	_in_Yijing}', "");
Expect(0, 19968, '\P{^	_in_Yijing}', "");
Error('\p{/a/ SOFT_dotted}');
Error('\P{/a/ SOFT_dotted}');
Expect(1, 120467, '\p{softdotted}', "");
Expect(0, 120467, '\p{^softdotted}', "");
Expect(0, 120467, '\P{softdotted}', "");
Expect(1, 120467, '\P{^softdotted}', "");
Expect(0, 120468, '\p{softdotted}', "");
Expect(1, 120468, '\p{^softdotted}', "");
Expect(1, 120468, '\P{softdotted}', "");
Expect(0, 120468, '\P{^softdotted}', "");
Expect(1, 120467, '\p{_SOFT_DOTTED}', "");
Expect(0, 120467, '\p{^_SOFT_DOTTED}', "");
Expect(0, 120467, '\P{_SOFT_DOTTED}', "");
Expect(1, 120467, '\P{^_SOFT_DOTTED}', "");
Expect(0, 120468, '\p{_SOFT_DOTTED}', "");
Expect(1, 120468, '\p{^_SOFT_DOTTED}', "");
Expect(1, 120468, '\P{_SOFT_DOTTED}', "");
Expect(0, 120468, '\P{^_SOFT_DOTTED}', "");
Error('\p{_-Is_Soft_Dotted/a/}');
Error('\P{_-Is_Soft_Dotted/a/}');
Expect(1, 120467, '\p{issoftdotted}', "");
Expect(0, 120467, '\p{^issoftdotted}', "");
Expect(0, 120467, '\P{issoftdotted}', "");
Expect(1, 120467, '\P{^issoftdotted}', "");
Expect(0, 120468, '\p{issoftdotted}', "");
Expect(1, 120468, '\p{^issoftdotted}', "");
Expect(1, 120468, '\P{issoftdotted}', "");
Expect(0, 120468, '\P{^issoftdotted}', "");
Expect(1, 120467, '\p{-_Is_SOFT_dotted}', "");
Expect(0, 120467, '\p{^-_Is_SOFT_dotted}', "");
Expect(0, 120467, '\P{-_Is_SOFT_dotted}', "");
Expect(1, 120467, '\P{^-_Is_SOFT_dotted}', "");
Expect(0, 120468, '\p{-_Is_SOFT_dotted}', "");
Expect(1, 120468, '\p{^-_Is_SOFT_dotted}', "");
Expect(1, 120468, '\P{-_Is_SOFT_dotted}', "");
Expect(0, 120468, '\P{^-_Is_SOFT_dotted}', "");
Error('\p{ SD/a/}');
Error('\P{ SD/a/}');
Expect(1, 120467, '\p{sd}', "");
Expect(0, 120467, '\p{^sd}', "");
Expect(0, 120467, '\P{sd}', "");
Expect(1, 120467, '\P{^sd}', "");
Expect(0, 120468, '\p{sd}', "");
Expect(1, 120468, '\p{^sd}', "");
Expect(1, 120468, '\P{sd}', "");
Expect(0, 120468, '\P{^sd}', "");
Expect(1, 120467, '\p{-sd}', "");
Expect(0, 120467, '\p{^-sd}', "");
Expect(0, 120467, '\P{-sd}', "");
Expect(1, 120467, '\P{^-sd}', "");
Expect(0, 120468, '\p{-sd}', "");
Expect(1, 120468, '\p{^-sd}', "");
Expect(1, 120468, '\P{-sd}', "");
Expect(0, 120468, '\P{^-sd}', "");
Error('\p{/a/		is_SD}');
Error('\P{/a/		is_SD}');
Expect(1, 120467, '\p{issd}', "");
Expect(0, 120467, '\p{^issd}', "");
Expect(0, 120467, '\P{issd}', "");
Expect(1, 120467, '\P{^issd}', "");
Expect(0, 120468, '\p{issd}', "");
Expect(1, 120468, '\p{^issd}', "");
Expect(1, 120468, '\P{issd}', "");
Expect(0, 120468, '\P{^issd}', "");
Expect(1, 120467, '\p{- IS_SD}', "");
Expect(0, 120467, '\p{^- IS_SD}', "");
Expect(0, 120467, '\P{- IS_SD}', "");
Expect(1, 120467, '\P{^- IS_SD}', "");
Expect(0, 120468, '\p{- IS_SD}', "");
Expect(1, 120468, '\p{^- IS_SD}', "");
Expect(1, 120468, '\P{- IS_SD}', "");
Expect(0, 120468, '\P{^- IS_SD}', "");
Error('\p{-_CanonDCIJ:=}');
Error('\P{-_CanonDCIJ:=}');
Expect(1, 120467, '\p{_canondcij}', "");
Expect(0, 120467, '\p{^_canondcij}', "");
Expect(0, 120467, '\P{_canondcij}', "");
Expect(1, 120467, '\P{^_canondcij}', "");
Expect(0, 120468, '\p{_canondcij}', "");
Expect(1, 120468, '\p{^_canondcij}', "");
Expect(1, 120468, '\P{_canondcij}', "");
Expect(0, 120468, '\P{^_canondcij}', "");
Error('\p{:=	CASE_Ignorable}');
Error('\P{:=	CASE_Ignorable}');
Expect(1, 917999, '\p{caseignorable}', "");
Expect(0, 917999, '\p{^caseignorable}', "");
Expect(0, 917999, '\P{caseignorable}', "");
Expect(1, 917999, '\P{^caseignorable}', "");
Expect(0, 918000, '\p{caseignorable}', "");
Expect(1, 918000, '\p{^caseignorable}', "");
Expect(1, 918000, '\P{caseignorable}', "");
Expect(0, 918000, '\P{^caseignorable}', "");
Expect(1, 917999, '\p{	Case_ignorable}', "");
Expect(0, 917999, '\p{^	Case_ignorable}', "");
Expect(0, 917999, '\P{	Case_ignorable}', "");
Expect(1, 917999, '\P{^	Case_ignorable}', "");
Expect(0, 918000, '\p{	Case_ignorable}', "");
Expect(1, 918000, '\p{^	Case_ignorable}', "");
Expect(1, 918000, '\P{	Case_ignorable}', "");
Expect(0, 918000, '\P{^	Case_ignorable}', "");
Error('\p{ is_Case_IGNORABLE/a/}');
Error('\P{ is_Case_IGNORABLE/a/}');
Expect(1, 917999, '\p{iscaseignorable}', "");
Expect(0, 917999, '\p{^iscaseignorable}', "");
Expect(0, 917999, '\P{iscaseignorable}', "");
Expect(1, 917999, '\P{^iscaseignorable}', "");
Expect(0, 918000, '\p{iscaseignorable}', "");
Expect(1, 918000, '\p{^iscaseignorable}', "");
Expect(1, 918000, '\P{iscaseignorable}', "");
Expect(0, 918000, '\P{^iscaseignorable}', "");
Expect(1, 917999, '\p{--Is_CASE_Ignorable}', "");
Expect(0, 917999, '\p{^--Is_CASE_Ignorable}', "");
Expect(0, 917999, '\P{--Is_CASE_Ignorable}', "");
Expect(1, 917999, '\P{^--Is_CASE_Ignorable}', "");
Expect(0, 918000, '\p{--Is_CASE_Ignorable}', "");
Expect(1, 918000, '\p{^--Is_CASE_Ignorable}', "");
Expect(1, 918000, '\P{--Is_CASE_Ignorable}', "");
Expect(0, 918000, '\P{^--Is_CASE_Ignorable}', "");
Error('\p{-:=CI}');
Error('\P{-:=CI}');
Expect(1, 917999, '\p{ci}', "");
Expect(0, 917999, '\p{^ci}', "");
Expect(0, 917999, '\P{ci}', "");
Expect(1, 917999, '\P{^ci}', "");
Expect(0, 918000, '\p{ci}', "");
Expect(1, 918000, '\p{^ci}', "");
Expect(1, 918000, '\P{ci}', "");
Expect(0, 918000, '\P{^ci}', "");
Expect(1, 917999, '\p{_	CI}', "");
Expect(0, 917999, '\p{^_	CI}', "");
Expect(0, 917999, '\P{_	CI}', "");
Expect(1, 917999, '\P{^_	CI}', "");
Expect(0, 918000, '\p{_	CI}', "");
Expect(1, 918000, '\p{^_	CI}', "");
Expect(1, 918000, '\P{_	CI}', "");
Expect(0, 918000, '\P{^_	CI}', "");
Error('\p{_Is_CI:=}');
Error('\P{_Is_CI:=}');
Expect(1, 917999, '\p{isci}', "");
Expect(0, 917999, '\p{^isci}', "");
Expect(0, 917999, '\P{isci}', "");
Expect(1, 917999, '\P{^isci}', "");
Expect(0, 918000, '\p{isci}', "");
Expect(1, 918000, '\p{^isci}', "");
Expect(1, 918000, '\P{isci}', "");
Expect(0, 918000, '\P{^isci}', "");
Expect(1, 917999, '\p{	is_CI}', "");
Expect(0, 917999, '\p{^	is_CI}', "");
Expect(0, 917999, '\P{	is_CI}', "");
Expect(1, 917999, '\P{^	is_CI}', "");
Expect(0, 918000, '\p{	is_CI}', "");
Expect(1, 918000, '\p{^	is_CI}', "");
Expect(1, 918000, '\P{	is_CI}', "");
Expect(0, 918000, '\P{^	is_CI}', "");
Error('\p{  _CASE_IGNORABLE:=}');
Error('\P{  _CASE_IGNORABLE:=}');
Expect(1, 917999, '\p{_Case_Ignorable}', "");
Expect(0, 917999, '\p{^_Case_Ignorable}', "");
Expect(0, 917999, '\P{_Case_Ignorable}', "");
Expect(1, 917999, '\P{^_Case_Ignorable}', "");
Expect(0, 918000, '\p{_Case_Ignorable}', "");
Expect(1, 918000, '\p{^_Case_Ignorable}', "");
Expect(1, 918000, '\P{_Case_Ignorable}', "");
Expect(0, 918000, '\P{^_Case_Ignorable}', "");
Error('\p{	__CombAbove/a/}');
Error('\P{	__CombAbove/a/}');
Expect(1, 119364, '\p{_CombAbove}', "");
Expect(0, 119364, '\p{^_CombAbove}', "");
Expect(0, 119364, '\P{_CombAbove}', "");
Expect(1, 119364, '\P{^_CombAbove}', "");
Expect(0, 119365, '\p{_CombAbove}', "");
Expect(1, 119365, '\p{^_CombAbove}', "");
Expect(1, 119365, '\P{_CombAbove}', "");
Expect(0, 119365, '\P{^_CombAbove}', "");
Error('\p{	/a/_COMBABOVE}');
Error('\P{	/a/_COMBABOVE}');
Expect(1, 119364, '\p{_COMBABOVE}', "");
Expect(0, 119364, '\p{^_COMBABOVE}', "");
Expect(0, 119364, '\P{_COMBABOVE}', "");
Expect(1, 119364, '\P{^_COMBABOVE}', "");
Expect(0, 119365, '\p{_COMBABOVE}', "");
Expect(1, 119365, '\p{^_COMBABOVE}', "");
Expect(1, 119365, '\P{_COMBABOVE}', "");
Expect(0, 119365, '\P{^_COMBABOVE}', "");
Error('\p{/a/-	_PERL_Any_FOLDS}');
Error('\P{/a/-	_PERL_Any_FOLDS}');
Expect(1, 66639, '\p{_PERL_Any_folds}', "");
Expect(0, 66639, '\p{^_PERL_Any_folds}', "");
Expect(0, 66639, '\P{_PERL_Any_folds}', "");
Expect(1, 66639, '\P{^_PERL_Any_folds}', "");
Expect(0, 66640, '\p{_PERL_Any_folds}', "");
Expect(1, 66640, '\p{^_PERL_Any_folds}', "");
Expect(1, 66640, '\P{_PERL_Any_folds}', "");
Expect(0, 66640, '\P{^_PERL_Any_folds}', "");
Error('\p{	/a/_perl_Any_FOLDS}');
Error('\P{	/a/_perl_Any_FOLDS}');
Expect(1, 66639, '\p{_Perl_any_folds}', "");
Expect(0, 66639, '\p{^_Perl_any_folds}', "");
Expect(0, 66639, '\P{_Perl_any_folds}', "");
Expect(1, 66639, '\P{^_Perl_any_folds}', "");
Expect(0, 66640, '\p{_Perl_any_folds}', "");
Expect(1, 66640, '\p{^_Perl_any_folds}', "");
Expect(1, 66640, '\P{_Perl_any_folds}', "");
Expect(0, 66640, '\P{^_Perl_any_folds}', "");
Error('\p{/a/	__PERL_CHARNAME_Begin}');
Error('\P{/a/	__PERL_CHARNAME_Begin}');
Expect(1, 195101, '\p{_perl_Charname_BEGIN}', "");
Expect(0, 195101, '\p{^_perl_Charname_BEGIN}', "");
Expect(0, 195101, '\P{_perl_Charname_BEGIN}', "");
Expect(1, 195101, '\P{^_perl_Charname_BEGIN}', "");
Expect(0, 195102, '\p{_perl_Charname_BEGIN}', "");
Expect(1, 195102, '\p{^_perl_Charname_BEGIN}', "");
Expect(1, 195102, '\P{_perl_Charname_BEGIN}', "");
Expect(0, 195102, '\P{^_perl_Charname_BEGIN}', "");
Error('\p{	-_PERL_CHARNAME_Begin/a/}');
Error('\P{	-_PERL_CHARNAME_Begin/a/}');
Expect(1, 195101, '\p{_perl_charname_Begin}', "");
Expect(0, 195101, '\p{^_perl_charname_Begin}', "");
Expect(0, 195101, '\P{_perl_charname_Begin}', "");
Expect(1, 195101, '\P{^_perl_charname_Begin}', "");
Expect(0, 195102, '\p{_perl_charname_Begin}', "");
Expect(1, 195102, '\p{^_perl_charname_Begin}', "");
Expect(1, 195102, '\P{_perl_charname_Begin}', "");
Expect(0, 195102, '\P{^_perl_charname_Begin}', "");
Error('\p{	:=_perl_CHARNAME_Continue}');
Error('\P{	:=_perl_CHARNAME_Continue}');
Expect(1, 917999, '\p{_PERL_charname_CONTINUE}', "");
Expect(0, 917999, '\p{^_PERL_charname_CONTINUE}', "");
Expect(0, 917999, '\P{_PERL_charname_CONTINUE}', "");
Expect(1, 917999, '\P{^_PERL_charname_CONTINUE}', "");
Expect(0, 918000, '\p{_PERL_charname_CONTINUE}', "");
Expect(1, 918000, '\p{^_PERL_charname_CONTINUE}', "");
Expect(1, 918000, '\P{_PERL_charname_CONTINUE}', "");
Expect(0, 918000, '\P{^_PERL_charname_CONTINUE}', "");
Error('\p{:=	__PERL_Charname_continue}');
Error('\P{:=	__PERL_Charname_continue}');
Expect(1, 917999, '\p{_Perl_Charname_continue}', "");
Expect(0, 917999, '\p{^_Perl_Charname_continue}', "");
Expect(0, 917999, '\P{_Perl_Charname_continue}', "");
Expect(1, 917999, '\P{^_Perl_Charname_continue}', "");
Expect(0, 918000, '\p{_Perl_Charname_continue}', "");
Expect(1, 918000, '\p{^_Perl_Charname_continue}', "");
Expect(1, 918000, '\P{_Perl_Charname_continue}', "");
Expect(0, 918000, '\P{^_Perl_Charname_continue}', "");
Error('\p{__PERL_Folds_To_MULTI_char:=}');
Error('\P{__PERL_Folds_To_MULTI_char:=}');
Expect(1, 64279, '\p{_Perl_Folds_To_Multi_CHAR}', "");
Expect(0, 64279, '\p{^_Perl_Folds_To_Multi_CHAR}', "");
Expect(0, 64279, '\P{_Perl_Folds_To_Multi_CHAR}', "");
Expect(1, 64279, '\P{^_Perl_Folds_To_Multi_CHAR}', "");
Expect(0, 64280, '\p{_Perl_Folds_To_Multi_CHAR}', "");
Expect(1, 64280, '\p{^_Perl_Folds_To_Multi_CHAR}', "");
Expect(1, 64280, '\P{_Perl_Folds_To_Multi_CHAR}', "");
Expect(0, 64280, '\P{^_Perl_Folds_To_Multi_CHAR}', "");
Error('\p{		_Perl_FOLDS_to_multi_CHAR/a/}');
Error('\P{		_Perl_FOLDS_to_multi_CHAR/a/}');
Expect(1, 64279, '\p{_Perl_Folds_To_MULTI_Char}', "");
Expect(0, 64279, '\p{^_Perl_Folds_To_MULTI_Char}', "");
Expect(0, 64279, '\P{_Perl_Folds_To_MULTI_Char}', "");
Expect(1, 64279, '\P{^_Perl_Folds_To_MULTI_Char}', "");
Expect(0, 64280, '\p{_Perl_Folds_To_MULTI_Char}', "");
Expect(1, 64280, '\p{^_Perl_Folds_To_MULTI_Char}', "");
Expect(1, 64280, '\P{_Perl_Folds_To_MULTI_Char}', "");
Expect(0, 64280, '\P{^_Perl_Folds_To_MULTI_Char}', "");
Error('\p{_:=_Perl_idcont}');
Error('\P{_:=_Perl_idcont}');
Expect(1, 917999, '\p{_PERL_IDCONT}', "");
Expect(0, 917999, '\p{^_PERL_IDCONT}', "");
Expect(0, 917999, '\P{_PERL_IDCONT}', "");
Expect(1, 917999, '\P{^_PERL_IDCONT}', "");
Expect(0, 918000, '\p{_PERL_IDCONT}', "");
Expect(1, 918000, '\p{^_PERL_IDCONT}', "");
Expect(1, 918000, '\P{_PERL_IDCONT}', "");
Expect(0, 918000, '\P{^_PERL_IDCONT}', "");
Error('\p{:=_Perl_IDCont}');
Error('\P{:=_Perl_IDCont}');
Expect(1, 917999, '\p{_Perl_IDCONT}', "");
Expect(0, 917999, '\p{^_Perl_IDCONT}', "");
Expect(0, 917999, '\P{_Perl_IDCONT}', "");
Expect(1, 917999, '\P{^_Perl_IDCONT}', "");
Expect(0, 918000, '\p{_Perl_IDCONT}', "");
Expect(1, 918000, '\p{^_Perl_IDCONT}', "");
Expect(1, 918000, '\P{_Perl_IDCONT}', "");
Expect(0, 918000, '\P{^_Perl_IDCONT}', "");
Error('\p{:=-	_Perl_IDSTART}');
Error('\P{:=-	_Perl_IDSTART}');
Expect(1, 195101, '\p{_PERL_IDStart}', "");
Expect(0, 195101, '\p{^_PERL_IDStart}', "");
Expect(0, 195101, '\P{_PERL_IDStart}', "");
Expect(1, 195101, '\P{^_PERL_IDStart}', "");
Expect(0, 195102, '\p{_PERL_IDStart}', "");
Expect(1, 195102, '\p{^_PERL_IDStart}', "");
Expect(1, 195102, '\P{_PERL_IDStart}', "");
Expect(0, 195102, '\P{^_PERL_IDStart}', "");
Error('\p{/a/__PERL_IDStart}');
Error('\P{/a/__PERL_IDStart}');
Expect(1, 195101, '\p{_Perl_IDStart}', "");
Expect(0, 195101, '\p{^_Perl_IDStart}', "");
Expect(0, 195101, '\P{_Perl_IDStart}', "");
Expect(1, 195101, '\P{^_Perl_IDStart}', "");
Expect(0, 195102, '\p{_Perl_IDStart}', "");
Expect(1, 195102, '\p{^_Perl_IDStart}', "");
Expect(1, 195102, '\P{_Perl_IDStart}', "");
Expect(0, 195102, '\P{^_Perl_IDStart}', "");
Error('\p{ -_Perl_Problematic_locale_foldeds_Start/a/}');
Error('\P{ -_Perl_Problematic_locale_foldeds_Start/a/}');
Expect(1, 64262, '\p{_PERL_Problematic_locale_FOLDEDS_Start}', "");
Expect(0, 64262, '\p{^_PERL_Problematic_locale_FOLDEDS_Start}', "");
Expect(0, 64262, '\P{_PERL_Problematic_locale_FOLDEDS_Start}', "");
Expect(1, 64262, '\P{^_PERL_Problematic_locale_FOLDEDS_Start}', "");
Expect(0, 64263, '\p{_PERL_Problematic_locale_FOLDEDS_Start}', "");
Expect(1, 64263, '\p{^_PERL_Problematic_locale_FOLDEDS_Start}', "");
Expect(1, 64263, '\P{_PERL_Problematic_locale_FOLDEDS_Start}', "");
Expect(0, 64263, '\P{^_PERL_Problematic_locale_FOLDEDS_Start}', "");
Error('\p{ /a/_Perl_problematic_LOCALE_FOLDEDS_Start}');
Error('\P{ /a/_Perl_problematic_LOCALE_FOLDEDS_Start}');
Expect(1, 64262, '\p{_PERL_Problematic_Locale_Foldeds_Start}', "");
Expect(0, 64262, '\p{^_PERL_Problematic_Locale_Foldeds_Start}', "");
Expect(0, 64262, '\P{_PERL_Problematic_Locale_Foldeds_Start}', "");
Expect(1, 64262, '\P{^_PERL_Problematic_Locale_Foldeds_Start}', "");
Expect(0, 64263, '\p{_PERL_Problematic_Locale_Foldeds_Start}', "");
Expect(1, 64263, '\p{^_PERL_Problematic_Locale_Foldeds_Start}', "");
Expect(1, 64263, '\P{_PERL_Problematic_Locale_Foldeds_Start}', "");
Expect(0, 64263, '\P{^_PERL_Problematic_Locale_Foldeds_Start}', "");
Error('\p{  _Perl_problematic_locale_Folds:=}');
Error('\P{  _Perl_problematic_locale_Folds:=}');
Expect(1, 64262, '\p{_Perl_problematic_LOCALE_folds}', "");
Expect(0, 64262, '\p{^_Perl_problematic_LOCALE_folds}', "");
Expect(0, 64262, '\P{_Perl_problematic_LOCALE_folds}', "");
Expect(1, 64262, '\P{^_Perl_problematic_LOCALE_folds}', "");
Expect(0, 64263, '\p{_Perl_problematic_LOCALE_folds}', "");
Expect(1, 64263, '\p{^_Perl_problematic_LOCALE_folds}', "");
Expect(1, 64263, '\P{_Perl_problematic_LOCALE_folds}', "");
Expect(0, 64263, '\P{^_Perl_problematic_LOCALE_folds}', "");
Error('\p{_:=_PERL_Problematic_Locale_Folds}');
Error('\P{_:=_PERL_Problematic_Locale_Folds}');
Expect(1, 64262, '\p{_Perl_problematic_Locale_Folds}', "");
Expect(0, 64262, '\p{^_Perl_problematic_Locale_Folds}', "");
Expect(0, 64262, '\P{_Perl_problematic_Locale_Folds}', "");
Expect(1, 64262, '\P{^_Perl_problematic_Locale_Folds}', "");
Expect(0, 64263, '\p{_Perl_problematic_Locale_Folds}', "");
Expect(1, 64263, '\p{^_Perl_problematic_Locale_Folds}', "");
Expect(1, 64263, '\P{_Perl_problematic_Locale_Folds}', "");
Expect(0, 64263, '\P{^_Perl_problematic_Locale_Folds}', "");
Error('\p{:=__Perl_QUOTEMETA}');
Error('\P{:=__Perl_QUOTEMETA}');
Expect(1, 921599, '\p{_Perl_Quotemeta}', "");
Expect(0, 921599, '\p{^_Perl_Quotemeta}', "");
Expect(0, 921599, '\P{_Perl_Quotemeta}', "");
Expect(1, 921599, '\P{^_Perl_Quotemeta}', "");
Expect(0, 921600, '\p{_Perl_Quotemeta}', "");
Expect(1, 921600, '\p{^_Perl_Quotemeta}', "");
Expect(1, 921600, '\P{_Perl_Quotemeta}', "");
Expect(0, 921600, '\P{^_Perl_Quotemeta}', "");
Error('\p{-:=_PERL_Quotemeta}');
Error('\P{-:=_PERL_Quotemeta}');
Expect(1, 921599, '\p{_perl_QUOTEMETA}', "");
Expect(0, 921599, '\p{^_perl_QUOTEMETA}', "");
Expect(0, 921599, '\P{_perl_QUOTEMETA}', "");
Expect(1, 921599, '\P{^_perl_QUOTEMETA}', "");
Expect(0, 921600, '\p{_perl_QUOTEMETA}', "");
Expect(1, 921600, '\p{^_perl_QUOTEMETA}', "");
Expect(1, 921600, '\P{_perl_QUOTEMETA}', "");
Expect(0, 921600, '\P{^_perl_QUOTEMETA}', "");
Error('\p{	:=_X_EXTEND}');
Error('\P{	:=_X_EXTEND}');
Expect(1, 917999, '\p{_X_extend}', "");
Expect(0, 917999, '\p{^_X_extend}', "");
Expect(0, 917999, '\P{_X_extend}', "");
Expect(1, 917999, '\P{^_X_extend}', "");
Expect(0, 918000, '\p{_X_extend}', "");
Expect(1, 918000, '\p{^_X_extend}', "");
Expect(1, 918000, '\P{_X_extend}', "");
Expect(0, 918000, '\P{^_X_extend}', "");
Error('\p{- _x_Extend/a/}');
Error('\P{- _x_Extend/a/}');
Expect(1, 917999, '\p{_X_Extend}', "");
Expect(0, 917999, '\p{^_X_Extend}', "");
Expect(0, 917999, '\P{_X_Extend}', "");
Expect(1, 917999, '\P{^_X_Extend}', "");
Expect(0, 918000, '\p{_X_Extend}', "");
Expect(1, 918000, '\p{^_X_Extend}', "");
Expect(1, 918000, '\P{_X_Extend}', "");
Expect(0, 918000, '\P{^_X_Extend}', "");
Error('\p{ -_x_GCB_L/a/}');
Error('\P{ -_x_GCB_L/a/}');
Expect(1, 43388, '\p{_X_gcb_L}', "");
Expect(0, 43388, '\p{^_X_gcb_L}', "");
Expect(0, 43388, '\P{_X_gcb_L}', "");
Expect(1, 43388, '\P{^_X_gcb_L}', "");
Expect(0, 43389, '\p{_X_gcb_L}', "");
Expect(1, 43389, '\p{^_X_gcb_L}', "");
Expect(1, 43389, '\P{_X_gcb_L}', "");
Expect(0, 43389, '\P{^_X_gcb_L}', "");
Error('\p{ 	_x_GCB_L:=}');
Error('\P{ 	_x_GCB_L:=}');
Expect(1, 43388, '\p{_x_GCB_l}', "");
Expect(0, 43388, '\p{^_x_GCB_l}', "");
Expect(0, 43388, '\P{_x_GCB_l}', "");
Expect(1, 43388, '\P{^_x_GCB_l}', "");
Expect(0, 43389, '\p{_x_GCB_l}', "");
Expect(1, 43389, '\p{^_x_GCB_l}', "");
Expect(1, 43389, '\P{_x_GCB_l}', "");
Expect(0, 43389, '\P{^_x_GCB_l}', "");
Error('\p{_X_GCB_LV:=}');
Error('\P{_X_GCB_LV:=}');
Expect(1, 55176, '\p{_X_gcb_LV}', "");
Expect(0, 55176, '\p{^_X_gcb_LV}', "");
Expect(0, 55176, '\P{_X_gcb_LV}', "");
Expect(1, 55176, '\P{^_X_gcb_LV}', "");
Expect(0, 55177, '\p{_X_gcb_LV}', "");
Expect(1, 55177, '\p{^_X_gcb_LV}', "");
Expect(1, 55177, '\P{_X_gcb_LV}', "");
Expect(0, 55177, '\P{^_X_gcb_LV}', "");
Error('\p{/a/	_x_gcb_LV}');
Error('\P{/a/	_x_gcb_LV}');
Expect(1, 55176, '\p{_X_GCB_LV}', "");
Expect(0, 55176, '\p{^_X_GCB_LV}', "");
Expect(0, 55176, '\P{_X_GCB_LV}', "");
Expect(1, 55176, '\P{^_X_GCB_LV}', "");
Expect(0, 55177, '\p{_X_GCB_LV}', "");
Expect(1, 55177, '\p{^_X_GCB_LV}', "");
Expect(1, 55177, '\P{_X_GCB_LV}', "");
Expect(0, 55177, '\P{^_X_GCB_LV}', "");
Error('\p{_ _X_GCB_lvt/a/}');
Error('\P{_ _X_GCB_lvt/a/}');
Expect(1, 55203, '\p{_X_GCB_LVT}', "");
Expect(0, 55203, '\p{^_X_GCB_LVT}', "");
Expect(0, 55203, '\P{_X_GCB_LVT}', "");
Expect(1, 55203, '\P{^_X_GCB_LVT}', "");
Expect(0, 55204, '\p{_X_GCB_LVT}', "");
Expect(1, 55204, '\p{^_X_GCB_LVT}', "");
Expect(1, 55204, '\P{_X_GCB_LVT}', "");
Expect(0, 55204, '\P{^_X_GCB_LVT}', "");
Error('\p{:=___X_GCB_LVT}');
Error('\P{:=___X_GCB_LVT}');
Error('\p{  _X_GCB_prepend/a/}');
Error('\P{  _X_GCB_prepend/a/}');
Expect(0, 1, '\p{_X_GCB_Prepend}', "");
Expect(1, 1, '\p{^_X_GCB_Prepend}', "");
Expect(1, 1, '\P{_X_GCB_Prepend}', "");
Expect(0, 1, '\P{^_X_GCB_Prepend}', "");
Error('\p{  _X_gcb_prepend/a/}');
Error('\P{  _X_gcb_prepend/a/}');
Expect(0, 1, '\p{_X_gcb_PREPEND}', "");
Expect(1, 1, '\p{^_X_gcb_PREPEND}', "");
Expect(1, 1, '\P{_X_gcb_PREPEND}', "");
Expect(0, 1, '\P{^_X_gcb_PREPEND}', "");
Error('\p{:=_x_GCB_T}');
Error('\P{:=_x_GCB_T}');
Expect(1, 55291, '\p{_X_gcb_t}', "");
Expect(0, 55291, '\p{^_X_gcb_t}', "");
Expect(0, 55291, '\P{_X_gcb_t}', "");
Expect(1, 55291, '\P{^_X_gcb_t}', "");
Expect(0, 55292, '\p{_X_gcb_t}', "");
Expect(1, 55292, '\p{^_X_gcb_t}', "");
Expect(1, 55292, '\P{_X_gcb_t}', "");
Expect(0, 55292, '\P{^_X_gcb_t}', "");
Error('\p{:=_X_gcb_T}');
Error('\P{:=_X_gcb_T}');
Expect(1, 55291, '\p{_X_GCB_t}', "");
Expect(0, 55291, '\p{^_X_GCB_t}', "");
Expect(0, 55291, '\P{_X_GCB_t}', "");
Expect(1, 55291, '\P{^_X_GCB_t}', "");
Expect(0, 55292, '\p{_X_GCB_t}', "");
Expect(1, 55292, '\p{^_X_GCB_t}', "");
Expect(1, 55292, '\P{_X_GCB_t}', "");
Expect(0, 55292, '\P{^_X_GCB_t}', "");
Error('\p{ :=_X_gcb_V}');
Error('\P{ :=_X_gcb_V}');
Expect(1, 55238, '\p{_X_GCB_V}', "");
Expect(0, 55238, '\p{^_X_GCB_V}', "");
Expect(0, 55238, '\P{_X_GCB_V}', "");
Expect(1, 55238, '\P{^_X_GCB_V}', "");
Expect(0, 55239, '\p{_X_GCB_V}', "");
Expect(1, 55239, '\p{^_X_GCB_V}', "");
Expect(1, 55239, '\P{_X_GCB_V}', "");
Expect(0, 55239, '\P{^_X_GCB_V}', "");
Error('\p{:=_X_GCB_V}');
Error('\P{:=_X_GCB_V}');
Error('\p{___X_LV_LVT_V:=}');
Error('\P{___X_LV_LVT_V:=}');
Expect(1, 55238, '\p{_X_LV_LVT_V}', "");
Expect(0, 55238, '\p{^_X_LV_LVT_V}', "");
Expect(0, 55238, '\P{_X_LV_LVT_V}', "");
Expect(1, 55238, '\P{^_X_LV_LVT_V}', "");
Expect(0, 55239, '\p{_X_LV_LVT_V}', "");
Expect(1, 55239, '\p{^_X_LV_LVT_V}', "");
Expect(1, 55239, '\P{_X_LV_LVT_V}', "");
Expect(0, 55239, '\P{^_X_LV_LVT_V}', "");
Error('\p{ /a/_X_lv_lvt_v}');
Error('\P{ /a/_X_lv_lvt_v}');
Expect(1, 55238, '\p{_x_LV_LVT_V}', "");
Expect(0, 55238, '\p{^_x_LV_LVT_V}', "");
Expect(0, 55238, '\P{_x_LV_LVT_V}', "");
Expect(1, 55238, '\P{^_x_LV_LVT_V}', "");
Expect(0, 55239, '\p{_x_LV_LVT_V}', "");
Expect(1, 55239, '\p{^_x_LV_LVT_V}', "");
Expect(1, 55239, '\P{_x_LV_LVT_V}', "");
Expect(0, 55239, '\P{^_x_LV_LVT_V}', "");
Error('\p{ _X_RI/a/}');
Error('\P{ _X_RI/a/}');
Expect(1, 127487, '\p{_X_RI}', "");
Expect(0, 127487, '\p{^_X_RI}', "");
Expect(0, 127487, '\P{_X_RI}', "");
Expect(1, 127487, '\P{^_X_RI}', "");
Expect(0, 127488, '\p{_X_RI}', "");
Expect(1, 127488, '\p{^_X_RI}', "");
Expect(1, 127488, '\P{_X_RI}', "");
Expect(0, 127488, '\P{^_X_RI}', "");
Error('\p{_-_x_RI/a/}');
Error('\P{_-_x_RI/a/}');
Error('\p{ 	_X_Regular_Begin/a/}');
Error('\P{ 	_X_Regular_Begin/a/}');
Expect(1, 921600, '\p{_X_regular_begin}', "");
Expect(0, 921600, '\p{^_X_regular_begin}', "");
Expect(0, 921600, '\P{_X_regular_begin}', "");
Expect(1, 921600, '\P{^_X_regular_begin}', "");
Expect(0, 921599, '\p{_X_regular_begin}', "");
Expect(1, 921599, '\p{^_X_regular_begin}', "");
Expect(1, 921599, '\P{_X_regular_begin}', "");
Expect(0, 921599, '\P{^_X_regular_begin}', "");
Error('\p{-/a/_X_REGULAR_Begin}');
Error('\P{-/a/_X_REGULAR_Begin}');
Expect(1, 921600, '\p{_X_regular_Begin}', "");
Expect(0, 921600, '\p{^_X_regular_Begin}', "");
Expect(0, 921600, '\P{_X_regular_Begin}', "");
Expect(1, 921600, '\P{^_X_regular_Begin}', "");
Expect(0, 921599, '\p{_X_regular_Begin}', "");
Expect(1, 921599, '\p{^_X_regular_Begin}', "");
Expect(1, 921599, '\P{_X_regular_Begin}', "");
Expect(0, 921599, '\P{^_X_regular_Begin}', "");
Error('\p{/a/ _x_SPECIAL_Begin_start}');
Error('\P{/a/ _x_SPECIAL_Begin_start}');
Expect(1, 127487, '\p{_x_SPECIAL_Begin_Start}', "");
Expect(0, 127487, '\p{^_x_SPECIAL_Begin_Start}', "");
Expect(0, 127487, '\P{_x_SPECIAL_Begin_Start}', "");
Expect(1, 127487, '\P{^_x_SPECIAL_Begin_Start}', "");
Expect(0, 127488, '\p{_x_SPECIAL_Begin_Start}', "");
Expect(1, 127488, '\p{^_x_SPECIAL_Begin_Start}', "");
Expect(1, 127488, '\P{_x_SPECIAL_Begin_Start}', "");
Expect(0, 127488, '\P{^_x_SPECIAL_Begin_Start}', "");
Error('\p{	:=_X_SPECIAL_Begin_Start}');
Error('\P{	:=_X_SPECIAL_Begin_Start}');
Expect(1, 127487, '\p{_X_Special_BEGIN_Start}', "");
Expect(0, 127487, '\p{^_X_Special_BEGIN_Start}', "");
Expect(0, 127487, '\P{_X_Special_BEGIN_Start}', "");
Expect(1, 127487, '\P{^_X_Special_BEGIN_Start}', "");
Expect(0, 127488, '\p{_X_Special_BEGIN_Start}', "");
Expect(1, 127488, '\p{^_X_Special_BEGIN_Start}', "");
Expect(1, 127488, '\P{_X_Special_BEGIN_Start}', "");
Expect(0, 127488, '\P{^_X_Special_BEGIN_Start}', "");
Error('\p{Script=/a/Arabic}');
Error('\P{Script=/a/Arabic}');
Expect(1, 126705, '\p{Script=arabic}', "");
Expect(0, 126705, '\p{^Script=arabic}', "");
Expect(0, 126705, '\P{Script=arabic}', "");
Expect(1, 126705, '\P{^Script=arabic}', "");
Expect(0, 126706, '\p{Script=arabic}', "");
Expect(1, 126706, '\p{^Script=arabic}', "");
Expect(1, 126706, '\P{Script=arabic}', "");
Expect(0, 126706, '\P{^Script=arabic}', "");
Expect(1, 126705, '\p{Script=--arabic}', "");
Expect(0, 126705, '\p{^Script=--arabic}', "");
Expect(0, 126705, '\P{Script=--arabic}', "");
Expect(1, 126705, '\P{^Script=--arabic}', "");
Expect(0, 126706, '\p{Script=--arabic}', "");
Expect(1, 126706, '\p{^Script=--arabic}', "");
Expect(1, 126706, '\P{Script=--arabic}', "");
Expect(0, 126706, '\P{^Script=--arabic}', "");
Error('\p{Sc=/a/-arab}');
Error('\P{Sc=/a/-arab}');
Expect(1, 126705, '\p{Sc=arab}', "");
Expect(0, 126705, '\p{^Sc=arab}', "");
Expect(0, 126705, '\P{Sc=arab}', "");
Expect(1, 126705, '\P{^Sc=arab}', "");
Expect(0, 126706, '\p{Sc=arab}', "");
Expect(1, 126706, '\p{^Sc=arab}', "");
Expect(1, 126706, '\P{Sc=arab}', "");
Expect(0, 126706, '\P{^Sc=arab}', "");
Expect(1, 126705, '\p{Sc=	Arab}', "");
Expect(0, 126705, '\p{^Sc=	Arab}', "");
Expect(0, 126705, '\P{Sc=	Arab}', "");
Expect(1, 126705, '\P{^Sc=	Arab}', "");
Expect(0, 126706, '\p{Sc=	Arab}', "");
Expect(1, 126706, '\p{^Sc=	Arab}', "");
Expect(1, 126706, '\P{Sc=	Arab}', "");
Expect(0, 126706, '\P{^Sc=	Arab}', "");
Error('\p{Is_Script=-Arabic/a/}');
Error('\P{Is_Script=-Arabic/a/}');
Expect(1, 126705, '\p{Is_Script=arabic}', "");
Expect(0, 126705, '\p{^Is_Script=arabic}', "");
Expect(0, 126705, '\P{Is_Script=arabic}', "");
Expect(1, 126705, '\P{^Is_Script=arabic}', "");
Expect(0, 126706, '\p{Is_Script=arabic}', "");
Expect(1, 126706, '\p{^Is_Script=arabic}', "");
Expect(1, 126706, '\P{Is_Script=arabic}', "");
Expect(0, 126706, '\P{^Is_Script=arabic}', "");
Expect(1, 126705, '\p{Is_Script=	_Arabic}', "");
Expect(0, 126705, '\p{^Is_Script=	_Arabic}', "");
Expect(0, 126705, '\P{Is_Script=	_Arabic}', "");
Expect(1, 126705, '\P{^Is_Script=	_Arabic}', "");
Expect(0, 126706, '\p{Is_Script=	_Arabic}', "");
Expect(1, 126706, '\p{^Is_Script=	_Arabic}', "");
Expect(1, 126706, '\P{Is_Script=	_Arabic}', "");
Expect(0, 126706, '\P{^Is_Script=	_Arabic}', "");
Error('\p{Is_Sc:   /a/		ARAB}');
Error('\P{Is_Sc:   /a/		ARAB}');
Expect(1, 126705, '\p{Is_Sc=arab}', "");
Expect(0, 126705, '\p{^Is_Sc=arab}', "");
Expect(0, 126705, '\P{Is_Sc=arab}', "");
Expect(1, 126705, '\P{^Is_Sc=arab}', "");
Expect(0, 126706, '\p{Is_Sc=arab}', "");
Expect(1, 126706, '\p{^Is_Sc=arab}', "");
Expect(1, 126706, '\P{Is_Sc=arab}', "");
Expect(0, 126706, '\P{^Is_Sc=arab}', "");
Expect(1, 126705, '\p{Is_Sc=	arab}', "");
Expect(0, 126705, '\p{^Is_Sc=	arab}', "");
Expect(0, 126705, '\P{Is_Sc=	arab}', "");
Expect(1, 126705, '\P{^Is_Sc=	arab}', "");
Expect(0, 126706, '\p{Is_Sc=	arab}', "");
Expect(1, 126706, '\p{^Is_Sc=	arab}', "");
Expect(1, 126706, '\P{Is_Sc=	arab}', "");
Expect(0, 126706, '\P{^Is_Sc=	arab}', "");
Error('\p{Script=_	IMPERIAL_aramaic:=}');
Error('\P{Script=_	IMPERIAL_aramaic:=}');
Expect(1, 67679, '\p{Script=imperialaramaic}', "");
Expect(0, 67679, '\p{^Script=imperialaramaic}', "");
Expect(0, 67679, '\P{Script=imperialaramaic}', "");
Expect(1, 67679, '\P{^Script=imperialaramaic}', "");
Expect(0, 67680, '\p{Script=imperialaramaic}', "");
Expect(1, 67680, '\p{^Script=imperialaramaic}', "");
Expect(1, 67680, '\P{Script=imperialaramaic}', "");
Expect(0, 67680, '\P{^Script=imperialaramaic}', "");
Expect(1, 67679, '\p{Script=_ Imperial_aramaic}', "");
Expect(0, 67679, '\p{^Script=_ Imperial_aramaic}', "");
Expect(0, 67679, '\P{Script=_ Imperial_aramaic}', "");
Expect(1, 67679, '\P{^Script=_ Imperial_aramaic}', "");
Expect(0, 67680, '\p{Script=_ Imperial_aramaic}', "");
Expect(1, 67680, '\p{^Script=_ Imperial_aramaic}', "");
Expect(1, 67680, '\P{Script=_ Imperial_aramaic}', "");
Expect(0, 67680, '\P{^Script=_ Imperial_aramaic}', "");
Error('\p{Sc=	:=Armi}');
Error('\P{Sc=	:=Armi}');
Expect(1, 67679, '\p{Sc=armi}', "");
Expect(0, 67679, '\p{^Sc=armi}', "");
Expect(0, 67679, '\P{Sc=armi}', "");
Expect(1, 67679, '\P{^Sc=armi}', "");
Expect(0, 67680, '\p{Sc=armi}', "");
Expect(1, 67680, '\p{^Sc=armi}', "");
Expect(1, 67680, '\P{Sc=armi}', "");
Expect(0, 67680, '\P{^Sc=armi}', "");
Expect(1, 67679, '\p{Sc=_ ARMI}', "");
Expect(0, 67679, '\p{^Sc=_ ARMI}', "");
Expect(0, 67679, '\P{Sc=_ ARMI}', "");
Expect(1, 67679, '\P{^Sc=_ ARMI}', "");
Expect(0, 67680, '\p{Sc=_ ARMI}', "");
Expect(1, 67680, '\p{^Sc=_ ARMI}', "");
Expect(1, 67680, '\P{Sc=_ ARMI}', "");
Expect(0, 67680, '\P{^Sc=_ ARMI}', "");
Error('\p{Is_Script=/a/_-Imperial_Aramaic}');
Error('\P{Is_Script=/a/_-Imperial_Aramaic}');
Expect(1, 67679, '\p{Is_Script=imperialaramaic}', "");
Expect(0, 67679, '\p{^Is_Script=imperialaramaic}', "");
Expect(0, 67679, '\P{Is_Script=imperialaramaic}', "");
Expect(1, 67679, '\P{^Is_Script=imperialaramaic}', "");
Expect(0, 67680, '\p{Is_Script=imperialaramaic}', "");
Expect(1, 67680, '\p{^Is_Script=imperialaramaic}', "");
Expect(1, 67680, '\P{Is_Script=imperialaramaic}', "");
Expect(0, 67680, '\P{^Is_Script=imperialaramaic}', "");
Expect(1, 67679, '\p{Is_Script=  Imperial_aramaic}', "");
Expect(0, 67679, '\p{^Is_Script=  Imperial_aramaic}', "");
Expect(0, 67679, '\P{Is_Script=  Imperial_aramaic}', "");
Expect(1, 67679, '\P{^Is_Script=  Imperial_aramaic}', "");
Expect(0, 67680, '\p{Is_Script=  Imperial_aramaic}', "");
Expect(1, 67680, '\p{^Is_Script=  Imperial_aramaic}', "");
Expect(1, 67680, '\P{Is_Script=  Imperial_aramaic}', "");
Expect(0, 67680, '\P{^Is_Script=  Imperial_aramaic}', "");
Error('\p{Is_Sc=		Armi/a/}');
Error('\P{Is_Sc=		Armi/a/}');
Expect(1, 67679, '\p{Is_Sc=armi}', "");
Expect(0, 67679, '\p{^Is_Sc=armi}', "");
Expect(0, 67679, '\P{Is_Sc=armi}', "");
Expect(1, 67679, '\P{^Is_Sc=armi}', "");
Expect(0, 67680, '\p{Is_Sc=armi}', "");
Expect(1, 67680, '\p{^Is_Sc=armi}', "");
Expect(1, 67680, '\P{Is_Sc=armi}', "");
Expect(0, 67680, '\P{^Is_Sc=armi}', "");
Error('\p{Script=  Armenian/a/}');
Error('\P{Script=  Armenian/a/}');
Expect(1, 64279, '\p{Script=armenian}', "");
Expect(0, 64279, '\p{^Script=armenian}', "");
Expect(0, 64279, '\P{Script=armenian}', "");
Expect(1, 64279, '\P{^Script=armenian}', "");
Expect(0, 64280, '\p{Script=armenian}', "");
Expect(1, 64280, '\p{^Script=armenian}', "");
Expect(1, 64280, '\P{Script=armenian}', "");
Expect(0, 64280, '\P{^Script=armenian}', "");
Expect(1, 64279, '\p{Script= _armenian}', "");
Expect(0, 64279, '\p{^Script= _armenian}', "");
Expect(0, 64279, '\P{Script= _armenian}', "");
Expect(1, 64279, '\P{^Script= _armenian}', "");
Expect(0, 64280, '\p{Script= _armenian}', "");
Expect(1, 64280, '\p{^Script= _armenian}', "");
Expect(1, 64280, '\P{Script= _armenian}', "");
Expect(0, 64280, '\P{^Script= _armenian}', "");
Error('\p{Sc=/a/	 Armn}');
Error('\P{Sc=/a/	 Armn}');
Expect(1, 64279, '\p{Sc=armn}', "");
Expect(0, 64279, '\p{^Sc=armn}', "");
Expect(0, 64279, '\P{Sc=armn}', "");
Expect(1, 64279, '\P{^Sc=armn}', "");
Expect(0, 64280, '\p{Sc=armn}', "");
Expect(1, 64280, '\p{^Sc=armn}', "");
Expect(1, 64280, '\P{Sc=armn}', "");
Expect(0, 64280, '\P{^Sc=armn}', "");
Expect(1, 64279, '\p{Sc=--armn}', "");
Expect(0, 64279, '\p{^Sc=--armn}', "");
Expect(0, 64279, '\P{Sc=--armn}', "");
Expect(1, 64279, '\P{^Sc=--armn}', "");
Expect(0, 64280, '\p{Sc=--armn}', "");
Expect(1, 64280, '\p{^Sc=--armn}', "");
Expect(1, 64280, '\P{Sc=--armn}', "");
Expect(0, 64280, '\P{^Sc=--armn}', "");
Error('\p{Is_Script=/a/_Armenian}');
Error('\P{Is_Script=/a/_Armenian}');
Expect(1, 64279, '\p{Is_Script=armenian}', "");
Expect(0, 64279, '\p{^Is_Script=armenian}', "");
Expect(0, 64279, '\P{Is_Script=armenian}', "");
Expect(1, 64279, '\P{^Is_Script=armenian}', "");
Expect(0, 64280, '\p{Is_Script=armenian}', "");
Expect(1, 64280, '\p{^Is_Script=armenian}', "");
Expect(1, 64280, '\P{Is_Script=armenian}', "");
Expect(0, 64280, '\P{^Is_Script=armenian}', "");
Expect(1, 64279, '\p{Is_Script=	_armenian}', "");
Expect(0, 64279, '\p{^Is_Script=	_armenian}', "");
Expect(0, 64279, '\P{Is_Script=	_armenian}', "");
Expect(1, 64279, '\P{^Is_Script=	_armenian}', "");
Expect(0, 64280, '\p{Is_Script=	_armenian}', "");
Expect(1, 64280, '\p{^Is_Script=	_armenian}', "");
Expect(1, 64280, '\P{Is_Script=	_armenian}', "");
Expect(0, 64280, '\P{^Is_Script=	_armenian}', "");
Error('\p{Is_Sc=	/a/ARMN}');
Error('\P{Is_Sc=	/a/ARMN}');
Expect(1, 64279, '\p{Is_Sc=armn}', "");
Expect(0, 64279, '\p{^Is_Sc=armn}', "");
Expect(0, 64279, '\P{Is_Sc=armn}', "");
Expect(1, 64279, '\P{^Is_Sc=armn}', "");
Expect(0, 64280, '\p{Is_Sc=armn}', "");
Expect(1, 64280, '\p{^Is_Sc=armn}', "");
Expect(1, 64280, '\P{Is_Sc=armn}', "");
Expect(0, 64280, '\P{^Is_Sc=armn}', "");
Expect(1, 64279, '\p{Is_Sc= _ARMN}', "");
Expect(0, 64279, '\p{^Is_Sc= _ARMN}', "");
Expect(0, 64279, '\P{Is_Sc= _ARMN}', "");
Expect(1, 64279, '\P{^Is_Sc= _ARMN}', "");
Expect(0, 64280, '\p{Is_Sc= _ARMN}', "");
Expect(1, 64280, '\p{^Is_Sc= _ARMN}', "");
Expect(1, 64280, '\P{Is_Sc= _ARMN}', "");
Expect(0, 64280, '\P{^Is_Sc= _ARMN}', "");
Error('\p{Script= _avestan/a/}');
Error('\P{Script= _avestan/a/}');
Expect(1, 68415, '\p{Script=avestan}', "");
Expect(0, 68415, '\p{^Script=avestan}', "");
Expect(0, 68415, '\P{Script=avestan}', "");
Expect(1, 68415, '\P{^Script=avestan}', "");
Expect(0, 68416, '\p{Script=avestan}', "");
Expect(1, 68416, '\p{^Script=avestan}', "");
Expect(1, 68416, '\P{Script=avestan}', "");
Expect(0, 68416, '\P{^Script=avestan}', "");
Expect(1, 68415, '\p{Script=-AVESTAN}', "");
Expect(0, 68415, '\p{^Script=-AVESTAN}', "");
Expect(0, 68415, '\P{Script=-AVESTAN}', "");
Expect(1, 68415, '\P{^Script=-AVESTAN}', "");
Expect(0, 68416, '\p{Script=-AVESTAN}', "");
Expect(1, 68416, '\p{^Script=-AVESTAN}', "");
Expect(1, 68416, '\P{Script=-AVESTAN}', "");
Expect(0, 68416, '\P{^Script=-AVESTAN}', "");
Error('\p{Sc:	:= _avst}');
Error('\P{Sc:	:= _avst}');
Expect(1, 68415, '\p{Sc=avst}', "");
Expect(0, 68415, '\p{^Sc=avst}', "");
Expect(0, 68415, '\P{Sc=avst}', "");
Expect(1, 68415, '\P{^Sc=avst}', "");
Expect(0, 68416, '\p{Sc=avst}', "");
Expect(1, 68416, '\p{^Sc=avst}', "");
Expect(1, 68416, '\P{Sc=avst}', "");
Expect(0, 68416, '\P{^Sc=avst}', "");
Expect(1, 68415, '\p{Sc:    _Avst}', "");
Expect(0, 68415, '\p{^Sc:    _Avst}', "");
Expect(0, 68415, '\P{Sc:    _Avst}', "");
Expect(1, 68415, '\P{^Sc:    _Avst}', "");
Expect(0, 68416, '\p{Sc:    _Avst}', "");
Expect(1, 68416, '\p{^Sc:    _Avst}', "");
Expect(1, 68416, '\P{Sc:    _Avst}', "");
Expect(0, 68416, '\P{^Sc:    _Avst}', "");
Error('\p{Is_Script=-	Avestan/a/}');
Error('\P{Is_Script=-	Avestan/a/}');
Expect(1, 68415, '\p{Is_Script=avestan}', "");
Expect(0, 68415, '\p{^Is_Script=avestan}', "");
Expect(0, 68415, '\P{Is_Script=avestan}', "");
Expect(1, 68415, '\P{^Is_Script=avestan}', "");
Expect(0, 68416, '\p{Is_Script=avestan}', "");
Expect(1, 68416, '\p{^Is_Script=avestan}', "");
Expect(1, 68416, '\P{Is_Script=avestan}', "");
Expect(0, 68416, '\P{^Is_Script=avestan}', "");
Expect(1, 68415, '\p{Is_Script=Avestan}', "");
Expect(0, 68415, '\p{^Is_Script=Avestan}', "");
Expect(0, 68415, '\P{Is_Script=Avestan}', "");
Expect(1, 68415, '\P{^Is_Script=Avestan}', "");
Expect(0, 68416, '\p{Is_Script=Avestan}', "");
Expect(1, 68416, '\p{^Is_Script=Avestan}', "");
Expect(1, 68416, '\P{Is_Script=Avestan}', "");
Expect(0, 68416, '\P{^Is_Script=Avestan}', "");
Error('\p{Is_Sc=-avst/a/}');
Error('\P{Is_Sc=-avst/a/}');
Expect(1, 68415, '\p{Is_Sc=avst}', "");
Expect(0, 68415, '\p{^Is_Sc=avst}', "");
Expect(0, 68415, '\P{Is_Sc=avst}', "");
Expect(1, 68415, '\P{^Is_Sc=avst}', "");
Expect(0, 68416, '\p{Is_Sc=avst}', "");
Expect(1, 68416, '\p{^Is_Sc=avst}', "");
Expect(1, 68416, '\P{Is_Sc=avst}', "");
Expect(0, 68416, '\P{^Is_Sc=avst}', "");
Expect(1, 68415, '\p{Is_Sc=	Avst}', "");
Expect(0, 68415, '\p{^Is_Sc=	Avst}', "");
Expect(0, 68415, '\P{Is_Sc=	Avst}', "");
Expect(1, 68415, '\P{^Is_Sc=	Avst}', "");
Expect(0, 68416, '\p{Is_Sc=	Avst}', "");
Expect(1, 68416, '\p{^Is_Sc=	Avst}', "");
Expect(1, 68416, '\P{Is_Sc=	Avst}', "");
Expect(0, 68416, '\P{^Is_Sc=	Avst}', "");
Error('\p{Script:	/a/ 	Balinese}');
Error('\P{Script:	/a/ 	Balinese}');
Expect(1, 7036, '\p{Script=balinese}', "");
Expect(0, 7036, '\p{^Script=balinese}', "");
Expect(0, 7036, '\P{Script=balinese}', "");
Expect(1, 7036, '\P{^Script=balinese}', "");
Expect(0, 7037, '\p{Script=balinese}', "");
Expect(1, 7037, '\p{^Script=balinese}', "");
Expect(1, 7037, '\P{Script=balinese}', "");
Expect(0, 7037, '\P{^Script=balinese}', "");
Expect(1, 7036, '\p{Script=-Balinese}', "");
Expect(0, 7036, '\p{^Script=-Balinese}', "");
Expect(0, 7036, '\P{Script=-Balinese}', "");
Expect(1, 7036, '\P{^Script=-Balinese}', "");
Expect(0, 7037, '\p{Script=-Balinese}', "");
Expect(1, 7037, '\p{^Script=-Balinese}', "");
Expect(1, 7037, '\P{Script=-Balinese}', "");
Expect(0, 7037, '\P{^Script=-Balinese}', "");
Error('\p{Sc= /a/Bali}');
Error('\P{Sc= /a/Bali}');
Expect(1, 7036, '\p{Sc=bali}', "");
Expect(0, 7036, '\p{^Sc=bali}', "");
Expect(0, 7036, '\P{Sc=bali}', "");
Expect(1, 7036, '\P{^Sc=bali}', "");
Expect(0, 7037, '\p{Sc=bali}', "");
Expect(1, 7037, '\p{^Sc=bali}', "");
Expect(1, 7037, '\P{Sc=bali}', "");
Expect(0, 7037, '\P{^Sc=bali}', "");
Expect(1, 7036, '\p{Sc=--BALI}', "");
Expect(0, 7036, '\p{^Sc=--BALI}', "");
Expect(0, 7036, '\P{Sc=--BALI}', "");
Expect(1, 7036, '\P{^Sc=--BALI}', "");
Expect(0, 7037, '\p{Sc=--BALI}', "");
Expect(1, 7037, '\p{^Sc=--BALI}', "");
Expect(1, 7037, '\P{Sc=--BALI}', "");
Expect(0, 7037, '\P{^Sc=--BALI}', "");
Error('\p{Is_Script=:=-Balinese}');
Error('\P{Is_Script=:=-Balinese}');
Expect(1, 7036, '\p{Is_Script=balinese}', "");
Expect(0, 7036, '\p{^Is_Script=balinese}', "");
Expect(0, 7036, '\P{Is_Script=balinese}', "");
Expect(1, 7036, '\P{^Is_Script=balinese}', "");
Expect(0, 7037, '\p{Is_Script=balinese}', "");
Expect(1, 7037, '\p{^Is_Script=balinese}', "");
Expect(1, 7037, '\P{Is_Script=balinese}', "");
Expect(0, 7037, '\P{^Is_Script=balinese}', "");
Expect(1, 7036, '\p{Is_Script=__Balinese}', "");
Expect(0, 7036, '\p{^Is_Script=__Balinese}', "");
Expect(0, 7036, '\P{Is_Script=__Balinese}', "");
Expect(1, 7036, '\P{^Is_Script=__Balinese}', "");
Expect(0, 7037, '\p{Is_Script=__Balinese}', "");
Expect(1, 7037, '\p{^Is_Script=__Balinese}', "");
Expect(1, 7037, '\P{Is_Script=__Balinese}', "");
Expect(0, 7037, '\P{^Is_Script=__Balinese}', "");
Error('\p{Is_Sc= BALI:=}');
Error('\P{Is_Sc= BALI:=}');
Expect(1, 7036, '\p{Is_Sc=bali}', "");
Expect(0, 7036, '\p{^Is_Sc=bali}', "");
Expect(0, 7036, '\P{Is_Sc=bali}', "");
Expect(1, 7036, '\P{^Is_Sc=bali}', "");
Expect(0, 7037, '\p{Is_Sc=bali}', "");
Expect(1, 7037, '\p{^Is_Sc=bali}', "");
Expect(1, 7037, '\P{Is_Sc=bali}', "");
Expect(0, 7037, '\P{^Is_Sc=bali}', "");
Error('\p{Script=/a/_-bamum}');
Error('\P{Script=/a/_-bamum}');
Expect(1, 92728, '\p{Script=bamum}', "");
Expect(0, 92728, '\p{^Script=bamum}', "");
Expect(0, 92728, '\P{Script=bamum}', "");
Expect(1, 92728, '\P{^Script=bamum}', "");
Expect(0, 92729, '\p{Script=bamum}', "");
Expect(1, 92729, '\p{^Script=bamum}', "");
Expect(1, 92729, '\P{Script=bamum}', "");
Expect(0, 92729, '\P{^Script=bamum}', "");
Expect(1, 92728, '\p{Script=	 bamum}', "");
Expect(0, 92728, '\p{^Script=	 bamum}', "");
Expect(0, 92728, '\P{Script=	 bamum}', "");
Expect(1, 92728, '\P{^Script=	 bamum}', "");
Expect(0, 92729, '\p{Script=	 bamum}', "");
Expect(1, 92729, '\p{^Script=	 bamum}', "");
Expect(1, 92729, '\P{Script=	 bamum}', "");
Expect(0, 92729, '\P{^Script=	 bamum}', "");
Error('\p{Sc=:= -bamu}');
Error('\P{Sc=:= -bamu}');
Expect(1, 92728, '\p{Sc: bamu}', "");
Expect(0, 92728, '\p{^Sc: bamu}', "");
Expect(0, 92728, '\P{Sc: bamu}', "");
Expect(1, 92728, '\P{^Sc: bamu}', "");
Expect(0, 92729, '\p{Sc: bamu}', "");
Expect(1, 92729, '\p{^Sc: bamu}', "");
Expect(1, 92729, '\P{Sc: bamu}', "");
Expect(0, 92729, '\P{^Sc: bamu}', "");
Expect(1, 92728, '\p{Sc=_Bamu}', "");
Expect(0, 92728, '\p{^Sc=_Bamu}', "");
Expect(0, 92728, '\P{Sc=_Bamu}', "");
Expect(1, 92728, '\P{^Sc=_Bamu}', "");
Expect(0, 92729, '\p{Sc=_Bamu}', "");
Expect(1, 92729, '\p{^Sc=_Bamu}', "");
Expect(1, 92729, '\P{Sc=_Bamu}', "");
Expect(0, 92729, '\P{^Sc=_Bamu}', "");
Error('\p{Is_Script=-/a/Bamum}');
Error('\P{Is_Script=-/a/Bamum}');
Expect(1, 92728, '\p{Is_Script=bamum}', "");
Expect(0, 92728, '\p{^Is_Script=bamum}', "");
Expect(0, 92728, '\P{Is_Script=bamum}', "");
Expect(1, 92728, '\P{^Is_Script=bamum}', "");
Expect(0, 92729, '\p{Is_Script=bamum}', "");
Expect(1, 92729, '\p{^Is_Script=bamum}', "");
Expect(1, 92729, '\P{Is_Script=bamum}', "");
Expect(0, 92729, '\P{^Is_Script=bamum}', "");
Expect(1, 92728, '\p{Is_Script=	Bamum}', "");
Expect(0, 92728, '\p{^Is_Script=	Bamum}', "");
Expect(0, 92728, '\P{Is_Script=	Bamum}', "");
Expect(1, 92728, '\P{^Is_Script=	Bamum}', "");
Expect(0, 92729, '\p{Is_Script=	Bamum}', "");
Expect(1, 92729, '\p{^Is_Script=	Bamum}', "");
Expect(1, 92729, '\P{Is_Script=	Bamum}', "");
Expect(0, 92729, '\P{^Is_Script=	Bamum}', "");
Error('\p{Is_Sc= BAMU:=}');
Error('\P{Is_Sc= BAMU:=}');
Expect(1, 92728, '\p{Is_Sc=bamu}', "");
Expect(0, 92728, '\p{^Is_Sc=bamu}', "");
Expect(0, 92728, '\P{Is_Sc=bamu}', "");
Expect(1, 92728, '\P{^Is_Sc=bamu}', "");
Expect(0, 92729, '\p{Is_Sc=bamu}', "");
Expect(1, 92729, '\p{^Is_Sc=bamu}', "");
Expect(1, 92729, '\P{Is_Sc=bamu}', "");
Expect(0, 92729, '\P{^Is_Sc=bamu}', "");
Expect(1, 92728, '\p{Is_Sc=	Bamu}', "");
Expect(0, 92728, '\p{^Is_Sc=	Bamu}', "");
Expect(0, 92728, '\P{Is_Sc=	Bamu}', "");
Expect(1, 92728, '\P{^Is_Sc=	Bamu}', "");
Expect(0, 92729, '\p{Is_Sc=	Bamu}', "");
Expect(1, 92729, '\p{^Is_Sc=	Bamu}', "");
Expect(1, 92729, '\P{Is_Sc=	Bamu}', "");
Expect(0, 92729, '\P{^Is_Sc=	Bamu}', "");
Error('\p{Script:-/a/BATAK}');
Error('\P{Script:-/a/BATAK}');
Expect(1, 7167, '\p{Script=batak}', "");
Expect(0, 7167, '\p{^Script=batak}', "");
Expect(0, 7167, '\P{Script=batak}', "");
Expect(1, 7167, '\P{^Script=batak}', "");
Expect(0, 7168, '\p{Script=batak}', "");
Expect(1, 7168, '\p{^Script=batak}', "");
Expect(1, 7168, '\P{Script=batak}', "");
Expect(0, 7168, '\P{^Script=batak}', "");
Expect(1, 7167, '\p{Script:		-batak}', "");
Expect(0, 7167, '\p{^Script:		-batak}', "");
Expect(0, 7167, '\P{Script:		-batak}', "");
Expect(1, 7167, '\P{^Script:		-batak}', "");
Expect(0, 7168, '\p{Script:		-batak}', "");
Expect(1, 7168, '\p{^Script:		-batak}', "");
Expect(1, 7168, '\P{Script:		-batak}', "");
Expect(0, 7168, '\P{^Script:		-batak}', "");
Error('\p{Sc:   :=batk}');
Error('\P{Sc:   :=batk}');
Expect(1, 7167, '\p{Sc=batk}', "");
Expect(0, 7167, '\p{^Sc=batk}', "");
Expect(0, 7167, '\P{Sc=batk}', "");
Expect(1, 7167, '\P{^Sc=batk}', "");
Expect(0, 7168, '\p{Sc=batk}', "");
Expect(1, 7168, '\p{^Sc=batk}', "");
Expect(1, 7168, '\P{Sc=batk}', "");
Expect(0, 7168, '\P{^Sc=batk}', "");
Expect(1, 7167, '\p{Sc=	-BATK}', "");
Expect(0, 7167, '\p{^Sc=	-BATK}', "");
Expect(0, 7167, '\P{Sc=	-BATK}', "");
Expect(1, 7167, '\P{^Sc=	-BATK}', "");
Expect(0, 7168, '\p{Sc=	-BATK}', "");
Expect(1, 7168, '\p{^Sc=	-BATK}', "");
Expect(1, 7168, '\P{Sc=	-BATK}', "");
Expect(0, 7168, '\P{^Sc=	-BATK}', "");
Error('\p{Is_Script=	Batak/a/}');
Error('\P{Is_Script=	Batak/a/}');
Expect(1, 7167, '\p{Is_Script=batak}', "");
Expect(0, 7167, '\p{^Is_Script=batak}', "");
Expect(0, 7167, '\P{Is_Script=batak}', "");
Expect(1, 7167, '\P{^Is_Script=batak}', "");
Expect(0, 7168, '\p{Is_Script=batak}', "");
Expect(1, 7168, '\p{^Is_Script=batak}', "");
Expect(1, 7168, '\P{Is_Script=batak}', "");
Expect(0, 7168, '\P{^Is_Script=batak}', "");
Expect(1, 7167, '\p{Is_Script=	-Batak}', "");
Expect(0, 7167, '\p{^Is_Script=	-Batak}', "");
Expect(0, 7167, '\P{Is_Script=	-Batak}', "");
Expect(1, 7167, '\P{^Is_Script=	-Batak}', "");
Expect(0, 7168, '\p{Is_Script=	-Batak}', "");
Expect(1, 7168, '\p{^Is_Script=	-Batak}', "");
Expect(1, 7168, '\P{Is_Script=	-Batak}', "");
Expect(0, 7168, '\P{^Is_Script=	-Batak}', "");
Error('\p{Is_Sc=/a/ -BATK}');
Error('\P{Is_Sc=/a/ -BATK}');
Expect(1, 7167, '\p{Is_Sc=batk}', "");
Expect(0, 7167, '\p{^Is_Sc=batk}', "");
Expect(0, 7167, '\P{Is_Sc=batk}', "");
Expect(1, 7167, '\P{^Is_Sc=batk}', "");
Expect(0, 7168, '\p{Is_Sc=batk}', "");
Expect(1, 7168, '\p{^Is_Sc=batk}', "");
Expect(1, 7168, '\P{Is_Sc=batk}', "");
Expect(0, 7168, '\P{^Is_Sc=batk}', "");
Expect(1, 7167, '\p{Is_Sc=--BATK}', "");
Expect(0, 7167, '\p{^Is_Sc=--BATK}', "");
Expect(0, 7167, '\P{Is_Sc=--BATK}', "");
Expect(1, 7167, '\P{^Is_Sc=--BATK}', "");
Expect(0, 7168, '\p{Is_Sc=--BATK}', "");
Expect(1, 7168, '\p{^Is_Sc=--BATK}', "");
Expect(1, 7168, '\P{Is_Sc=--BATK}', "");
Expect(0, 7168, '\P{^Is_Sc=--BATK}', "");
Error('\p{Script=	 BENGALI:=}');
Error('\P{Script=	 BENGALI:=}');
Expect(1, 2555, '\p{Script=bengali}', "");
Expect(0, 2555, '\p{^Script=bengali}', "");
Expect(0, 2555, '\P{Script=bengali}', "");
Expect(1, 2555, '\P{^Script=bengali}', "");
Expect(0, 2556, '\p{Script=bengali}', "");
Expect(1, 2556, '\p{^Script=bengali}', "");
Expect(1, 2556, '\P{Script=bengali}', "");
Expect(0, 2556, '\P{^Script=bengali}', "");
Expect(1, 2555, '\p{Script:   - Bengali}', "");
Expect(0, 2555, '\p{^Script:   - Bengali}', "");
Expect(0, 2555, '\P{Script:   - Bengali}', "");
Expect(1, 2555, '\P{^Script:   - Bengali}', "");
Expect(0, 2556, '\p{Script:   - Bengali}', "");
Expect(1, 2556, '\p{^Script:   - Bengali}', "");
Expect(1, 2556, '\P{Script:   - Bengali}', "");
Expect(0, 2556, '\P{^Script:   - Bengali}', "");
Error('\p{Sc:	:=		Beng}');
Error('\P{Sc:	:=		Beng}');
Expect(1, 2555, '\p{Sc=beng}', "");
Expect(0, 2555, '\p{^Sc=beng}', "");
Expect(0, 2555, '\P{Sc=beng}', "");
Expect(1, 2555, '\P{^Sc=beng}', "");
Expect(0, 2556, '\p{Sc=beng}', "");
Expect(1, 2556, '\p{^Sc=beng}', "");
Expect(1, 2556, '\P{Sc=beng}', "");
Expect(0, 2556, '\P{^Sc=beng}', "");
Expect(1, 2555, '\p{Sc=_ beng}', "");
Expect(0, 2555, '\p{^Sc=_ beng}', "");
Expect(0, 2555, '\P{Sc=_ beng}', "");
Expect(1, 2555, '\P{^Sc=_ beng}', "");
Expect(0, 2556, '\p{Sc=_ beng}', "");
Expect(1, 2556, '\p{^Sc=_ beng}', "");
Expect(1, 2556, '\P{Sc=_ beng}', "");
Expect(0, 2556, '\P{^Sc=_ beng}', "");
Error('\p{Is_Script=-/a/BENGALI}');
Error('\P{Is_Script=-/a/BENGALI}');
Expect(1, 2555, '\p{Is_Script=bengali}', "");
Expect(0, 2555, '\p{^Is_Script=bengali}', "");
Expect(0, 2555, '\P{Is_Script=bengali}', "");
Expect(1, 2555, '\P{^Is_Script=bengali}', "");
Expect(0, 2556, '\p{Is_Script=bengali}', "");
Expect(1, 2556, '\p{^Is_Script=bengali}', "");
Expect(1, 2556, '\P{Is_Script=bengali}', "");
Expect(0, 2556, '\P{^Is_Script=bengali}', "");
Expect(1, 2555, '\p{Is_Script=_bengali}', "");
Expect(0, 2555, '\p{^Is_Script=_bengali}', "");
Expect(0, 2555, '\P{Is_Script=_bengali}', "");
Expect(1, 2555, '\P{^Is_Script=_bengali}', "");
Expect(0, 2556, '\p{Is_Script=_bengali}', "");
Expect(1, 2556, '\p{^Is_Script=_bengali}', "");
Expect(1, 2556, '\P{Is_Script=_bengali}', "");
Expect(0, 2556, '\P{^Is_Script=_bengali}', "");
Error('\p{Is_Sc: :=Beng}');
Error('\P{Is_Sc: :=Beng}');
Expect(1, 2555, '\p{Is_Sc=beng}', "");
Expect(0, 2555, '\p{^Is_Sc=beng}', "");
Expect(0, 2555, '\P{Is_Sc=beng}', "");
Expect(1, 2555, '\P{^Is_Sc=beng}', "");
Expect(0, 2556, '\p{Is_Sc=beng}', "");
Expect(1, 2556, '\p{^Is_Sc=beng}', "");
Expect(1, 2556, '\P{Is_Sc=beng}', "");
Expect(0, 2556, '\P{^Is_Sc=beng}', "");
Expect(1, 2555, '\p{Is_Sc=_beng}', "");
Expect(0, 2555, '\p{^Is_Sc=_beng}', "");
Expect(0, 2555, '\P{Is_Sc=_beng}', "");
Expect(1, 2555, '\P{^Is_Sc=_beng}', "");
Expect(0, 2556, '\p{Is_Sc=_beng}', "");
Expect(1, 2556, '\p{^Is_Sc=_beng}', "");
Expect(1, 2556, '\P{Is_Sc=_beng}', "");
Expect(0, 2556, '\P{^Is_Sc=_beng}', "");
Error('\p{Script=:=Bopomofo}');
Error('\P{Script=:=Bopomofo}');
Expect(1, 12730, '\p{Script=bopomofo}', "");
Expect(0, 12730, '\p{^Script=bopomofo}', "");
Expect(0, 12730, '\P{Script=bopomofo}', "");
Expect(1, 12730, '\P{^Script=bopomofo}', "");
Expect(0, 12731, '\p{Script=bopomofo}', "");
Expect(1, 12731, '\p{^Script=bopomofo}', "");
Expect(1, 12731, '\P{Script=bopomofo}', "");
Expect(0, 12731, '\P{^Script=bopomofo}', "");
Expect(1, 12730, '\p{Script=	bopomofo}', "");
Expect(0, 12730, '\p{^Script=	bopomofo}', "");
Expect(0, 12730, '\P{Script=	bopomofo}', "");
Expect(1, 12730, '\P{^Script=	bopomofo}', "");
Expect(0, 12731, '\p{Script=	bopomofo}', "");
Expect(1, 12731, '\p{^Script=	bopomofo}', "");
Expect(1, 12731, '\P{Script=	bopomofo}', "");
Expect(0, 12731, '\P{^Script=	bopomofo}', "");
Error('\p{Sc=:=bopo}');
Error('\P{Sc=:=bopo}');
Expect(1, 12730, '\p{Sc=bopo}', "");
Expect(0, 12730, '\p{^Sc=bopo}', "");
Expect(0, 12730, '\P{Sc=bopo}', "");
Expect(1, 12730, '\P{^Sc=bopo}', "");
Expect(0, 12731, '\p{Sc=bopo}', "");
Expect(1, 12731, '\p{^Sc=bopo}', "");
Expect(1, 12731, '\P{Sc=bopo}', "");
Expect(0, 12731, '\P{^Sc=bopo}', "");
Expect(1, 12730, '\p{Sc=Bopo}', "");
Expect(0, 12730, '\p{^Sc=Bopo}', "");
Expect(0, 12730, '\P{Sc=Bopo}', "");
Expect(1, 12730, '\P{^Sc=Bopo}', "");
Expect(0, 12731, '\p{Sc=Bopo}', "");
Expect(1, 12731, '\p{^Sc=Bopo}', "");
Expect(1, 12731, '\P{Sc=Bopo}', "");
Expect(0, 12731, '\P{^Sc=Bopo}', "");
Error('\p{Is_Script=_-bopomofo:=}');
Error('\P{Is_Script=_-bopomofo:=}');
Expect(1, 12730, '\p{Is_Script=bopomofo}', "");
Expect(0, 12730, '\p{^Is_Script=bopomofo}', "");
Expect(0, 12730, '\P{Is_Script=bopomofo}', "");
Expect(1, 12730, '\P{^Is_Script=bopomofo}', "");
Expect(0, 12731, '\p{Is_Script=bopomofo}', "");
Expect(1, 12731, '\p{^Is_Script=bopomofo}', "");
Expect(1, 12731, '\P{Is_Script=bopomofo}', "");
Expect(0, 12731, '\P{^Is_Script=bopomofo}', "");
Expect(1, 12730, '\p{Is_Script=  bopomofo}', "");
Expect(0, 12730, '\p{^Is_Script=  bopomofo}', "");
Expect(0, 12730, '\P{Is_Script=  bopomofo}', "");
Expect(1, 12730, '\P{^Is_Script=  bopomofo}', "");
Expect(0, 12731, '\p{Is_Script=  bopomofo}', "");
Expect(1, 12731, '\p{^Is_Script=  bopomofo}', "");
Expect(1, 12731, '\P{Is_Script=  bopomofo}', "");
Expect(0, 12731, '\P{^Is_Script=  bopomofo}', "");
Error('\p{Is_Sc=:=-bopo}');
Error('\P{Is_Sc=:=-bopo}');
Expect(1, 12730, '\p{Is_Sc:	bopo}', "");
Expect(0, 12730, '\p{^Is_Sc:	bopo}', "");
Expect(0, 12730, '\P{Is_Sc:	bopo}', "");
Expect(1, 12730, '\P{^Is_Sc:	bopo}', "");
Expect(0, 12731, '\p{Is_Sc:	bopo}', "");
Expect(1, 12731, '\p{^Is_Sc:	bopo}', "");
Expect(1, 12731, '\P{Is_Sc:	bopo}', "");
Expect(0, 12731, '\P{^Is_Sc:	bopo}', "");
Error('\p{Script=/a/-_brahmi}');
Error('\P{Script=/a/-_brahmi}');
Expect(1, 69743, '\p{Script=brahmi}', "");
Expect(0, 69743, '\p{^Script=brahmi}', "");
Expect(0, 69743, '\P{Script=brahmi}', "");
Expect(1, 69743, '\P{^Script=brahmi}', "");
Expect(0, 69744, '\p{Script=brahmi}', "");
Expect(1, 69744, '\p{^Script=brahmi}', "");
Expect(1, 69744, '\P{Script=brahmi}', "");
Expect(0, 69744, '\P{^Script=brahmi}', "");
Expect(1, 69743, '\p{Script=_ BRAHMI}', "");
Expect(0, 69743, '\p{^Script=_ BRAHMI}', "");
Expect(0, 69743, '\P{Script=_ BRAHMI}', "");
Expect(1, 69743, '\P{^Script=_ BRAHMI}', "");
Expect(0, 69744, '\p{Script=_ BRAHMI}', "");
Expect(1, 69744, '\p{^Script=_ BRAHMI}', "");
Expect(1, 69744, '\P{Script=_ BRAHMI}', "");
Expect(0, 69744, '\P{^Script=_ BRAHMI}', "");
Error('\p{Sc=-Brah/a/}');
Error('\P{Sc=-Brah/a/}');
Expect(1, 69743, '\p{Sc=brah}', "");
Expect(0, 69743, '\p{^Sc=brah}', "");
Expect(0, 69743, '\P{Sc=brah}', "");
Expect(1, 69743, '\P{^Sc=brah}', "");
Expect(0, 69744, '\p{Sc=brah}', "");
Expect(1, 69744, '\p{^Sc=brah}', "");
Expect(1, 69744, '\P{Sc=brah}', "");
Expect(0, 69744, '\P{^Sc=brah}', "");
Expect(1, 69743, '\p{Sc:-Brah}', "");
Expect(0, 69743, '\p{^Sc:-Brah}', "");
Expect(0, 69743, '\P{Sc:-Brah}', "");
Expect(1, 69743, '\P{^Sc:-Brah}', "");
Expect(0, 69744, '\p{Sc:-Brah}', "");
Expect(1, 69744, '\p{^Sc:-Brah}', "");
Expect(1, 69744, '\P{Sc:-Brah}', "");
Expect(0, 69744, '\P{^Sc:-Brah}', "");
Error('\p{Is_Script:	 BRAHMI:=}');
Error('\P{Is_Script:	 BRAHMI:=}');
Expect(1, 69743, '\p{Is_Script: brahmi}', "");
Expect(0, 69743, '\p{^Is_Script: brahmi}', "");
Expect(0, 69743, '\P{Is_Script: brahmi}', "");
Expect(1, 69743, '\P{^Is_Script: brahmi}', "");
Expect(0, 69744, '\p{Is_Script: brahmi}', "");
Expect(1, 69744, '\p{^Is_Script: brahmi}', "");
Expect(1, 69744, '\P{Is_Script: brahmi}', "");
Expect(0, 69744, '\P{^Is_Script: brahmi}', "");
Expect(1, 69743, '\p{Is_Script=-Brahmi}', "");
Expect(0, 69743, '\p{^Is_Script=-Brahmi}', "");
Expect(0, 69743, '\P{Is_Script=-Brahmi}', "");
Expect(1, 69743, '\P{^Is_Script=-Brahmi}', "");
Expect(0, 69744, '\p{Is_Script=-Brahmi}', "");
Expect(1, 69744, '\p{^Is_Script=-Brahmi}', "");
Expect(1, 69744, '\P{Is_Script=-Brahmi}', "");
Expect(0, 69744, '\P{^Is_Script=-Brahmi}', "");
Error('\p{Is_Sc=-_brah:=}');
Error('\P{Is_Sc=-_brah:=}');
Expect(1, 69743, '\p{Is_Sc=brah}', "");
Expect(0, 69743, '\p{^Is_Sc=brah}', "");
Expect(0, 69743, '\P{Is_Sc=brah}', "");
Expect(1, 69743, '\P{^Is_Sc=brah}', "");
Expect(0, 69744, '\p{Is_Sc=brah}', "");
Expect(1, 69744, '\p{^Is_Sc=brah}', "");
Expect(1, 69744, '\P{Is_Sc=brah}', "");
Expect(0, 69744, '\P{^Is_Sc=brah}', "");
Expect(1, 69743, '\p{Is_Sc=	_BRAH}', "");
Expect(0, 69743, '\p{^Is_Sc=	_BRAH}', "");
Expect(0, 69743, '\P{Is_Sc=	_BRAH}', "");
Expect(1, 69743, '\P{^Is_Sc=	_BRAH}', "");
Expect(0, 69744, '\p{Is_Sc=	_BRAH}', "");
Expect(1, 69744, '\p{^Is_Sc=	_BRAH}', "");
Expect(1, 69744, '\P{Is_Sc=	_BRAH}', "");
Expect(0, 69744, '\P{^Is_Sc=	_BRAH}', "");
Error('\p{Script=	:=BRAILLE}');
Error('\P{Script=	:=BRAILLE}');
Expect(1, 10495, '\p{Script=braille}', "");
Expect(0, 10495, '\p{^Script=braille}', "");
Expect(0, 10495, '\P{Script=braille}', "");
Expect(1, 10495, '\P{^Script=braille}', "");
Expect(0, 10496, '\p{Script=braille}', "");
Expect(1, 10496, '\p{^Script=braille}', "");
Expect(1, 10496, '\P{Script=braille}', "");
Expect(0, 10496, '\P{^Script=braille}', "");
Expect(1, 10495, '\p{Script= braille}', "");
Expect(0, 10495, '\p{^Script= braille}', "");
Expect(0, 10495, '\P{Script= braille}', "");
Expect(1, 10495, '\P{^Script= braille}', "");
Expect(0, 10496, '\p{Script= braille}', "");
Expect(1, 10496, '\p{^Script= braille}', "");
Expect(1, 10496, '\P{Script= braille}', "");
Expect(0, 10496, '\P{^Script= braille}', "");
Error('\p{Sc=	:=Brai}');
Error('\P{Sc=	:=Brai}');
Expect(1, 10495, '\p{Sc=brai}', "");
Expect(0, 10495, '\p{^Sc=brai}', "");
Expect(0, 10495, '\P{Sc=brai}', "");
Expect(1, 10495, '\P{^Sc=brai}', "");
Expect(0, 10496, '\p{Sc=brai}', "");
Expect(1, 10496, '\p{^Sc=brai}', "");
Expect(1, 10496, '\P{Sc=brai}', "");
Expect(0, 10496, '\P{^Sc=brai}', "");
Expect(1, 10495, '\p{Sc=Brai}', "");
Expect(0, 10495, '\p{^Sc=Brai}', "");
Expect(0, 10495, '\P{Sc=Brai}', "");
Expect(1, 10495, '\P{^Sc=Brai}', "");
Expect(0, 10496, '\p{Sc=Brai}', "");
Expect(1, 10496, '\p{^Sc=Brai}', "");
Expect(1, 10496, '\P{Sc=Brai}', "");
Expect(0, 10496, '\P{^Sc=Brai}', "");
Error('\p{Is_Script= Braille/a/}');
Error('\P{Is_Script= Braille/a/}');
Expect(1, 10495, '\p{Is_Script=braille}', "");
Expect(0, 10495, '\p{^Is_Script=braille}', "");
Expect(0, 10495, '\P{Is_Script=braille}', "");
Expect(1, 10495, '\P{^Is_Script=braille}', "");
Expect(0, 10496, '\p{Is_Script=braille}', "");
Expect(1, 10496, '\p{^Is_Script=braille}', "");
Expect(1, 10496, '\P{Is_Script=braille}', "");
Expect(0, 10496, '\P{^Is_Script=braille}', "");
Expect(1, 10495, '\p{Is_Script: _braille}', "");
Expect(0, 10495, '\p{^Is_Script: _braille}', "");
Expect(0, 10495, '\P{Is_Script: _braille}', "");
Expect(1, 10495, '\P{^Is_Script: _braille}', "");
Expect(0, 10496, '\p{Is_Script: _braille}', "");
Expect(1, 10496, '\p{^Is_Script: _braille}', "");
Expect(1, 10496, '\P{Is_Script: _braille}', "");
Expect(0, 10496, '\P{^Is_Script: _braille}', "");
Error('\p{Is_Sc=_-BRAI:=}');
Error('\P{Is_Sc=_-BRAI:=}');
Expect(1, 10495, '\p{Is_Sc=brai}', "");
Expect(0, 10495, '\p{^Is_Sc=brai}', "");
Expect(0, 10495, '\P{Is_Sc=brai}', "");
Expect(1, 10495, '\P{^Is_Sc=brai}', "");
Expect(0, 10496, '\p{Is_Sc=brai}', "");
Expect(1, 10496, '\p{^Is_Sc=brai}', "");
Expect(1, 10496, '\P{Is_Sc=brai}', "");
Expect(0, 10496, '\P{^Is_Sc=brai}', "");
Expect(1, 10495, '\p{Is_Sc=-_Brai}', "");
Expect(0, 10495, '\p{^Is_Sc=-_Brai}', "");
Expect(0, 10495, '\P{Is_Sc=-_Brai}', "");
Expect(1, 10495, '\P{^Is_Sc=-_Brai}', "");
Expect(0, 10496, '\p{Is_Sc=-_Brai}', "");
Expect(1, 10496, '\p{^Is_Sc=-_Brai}', "");
Expect(1, 10496, '\P{Is_Sc=-_Brai}', "");
Expect(0, 10496, '\P{^Is_Sc=-_Brai}', "");
Error('\p{Script= _buginese/a/}');
Error('\P{Script= _buginese/a/}');
Expect(1, 6687, '\p{Script=buginese}', "");
Expect(0, 6687, '\p{^Script=buginese}', "");
Expect(0, 6687, '\P{Script=buginese}', "");
Expect(1, 6687, '\P{^Script=buginese}', "");
Expect(0, 6688, '\p{Script=buginese}', "");
Expect(1, 6688, '\p{^Script=buginese}', "");
Expect(1, 6688, '\P{Script=buginese}', "");
Expect(0, 6688, '\P{^Script=buginese}', "");
Expect(1, 6687, '\p{Script=  Buginese}', "");
Expect(0, 6687, '\p{^Script=  Buginese}', "");
Expect(0, 6687, '\P{Script=  Buginese}', "");
Expect(1, 6687, '\P{^Script=  Buginese}', "");
Expect(0, 6688, '\p{Script=  Buginese}', "");
Expect(1, 6688, '\p{^Script=  Buginese}', "");
Expect(1, 6688, '\P{Script=  Buginese}', "");
Expect(0, 6688, '\P{^Script=  Buginese}', "");
Error('\p{Sc=:=_ Bugi}');
Error('\P{Sc=:=_ Bugi}');
Expect(1, 6687, '\p{Sc:   bugi}', "");
Expect(0, 6687, '\p{^Sc:   bugi}', "");
Expect(0, 6687, '\P{Sc:   bugi}', "");
Expect(1, 6687, '\P{^Sc:   bugi}', "");
Expect(0, 6688, '\p{Sc:   bugi}', "");
Expect(1, 6688, '\p{^Sc:   bugi}', "");
Expect(1, 6688, '\P{Sc:   bugi}', "");
Expect(0, 6688, '\P{^Sc:   bugi}', "");
Expect(1, 6687, '\p{Sc=-	BUGI}', "");
Expect(0, 6687, '\p{^Sc=-	BUGI}', "");
Expect(0, 6687, '\P{Sc=-	BUGI}', "");
Expect(1, 6687, '\P{^Sc=-	BUGI}', "");
Expect(0, 6688, '\p{Sc=-	BUGI}', "");
Expect(1, 6688, '\p{^Sc=-	BUGI}', "");
Expect(1, 6688, '\P{Sc=-	BUGI}', "");
Expect(0, 6688, '\P{^Sc=-	BUGI}', "");
Error('\p{Is_Script=-/a/BUGINESE}');
Error('\P{Is_Script=-/a/BUGINESE}');
Expect(1, 6687, '\p{Is_Script=buginese}', "");
Expect(0, 6687, '\p{^Is_Script=buginese}', "");
Expect(0, 6687, '\P{Is_Script=buginese}', "");
Expect(1, 6687, '\P{^Is_Script=buginese}', "");
Expect(0, 6688, '\p{Is_Script=buginese}', "");
Expect(1, 6688, '\p{^Is_Script=buginese}', "");
Expect(1, 6688, '\P{Is_Script=buginese}', "");
Expect(0, 6688, '\P{^Is_Script=buginese}', "");
Expect(1, 6687, '\p{Is_Script=_	Buginese}', "");
Expect(0, 6687, '\p{^Is_Script=_	Buginese}', "");
Expect(0, 6687, '\P{Is_Script=_	Buginese}', "");
Expect(1, 6687, '\P{^Is_Script=_	Buginese}', "");
Expect(0, 6688, '\p{Is_Script=_	Buginese}', "");
Expect(1, 6688, '\p{^Is_Script=_	Buginese}', "");
Expect(1, 6688, '\P{Is_Script=_	Buginese}', "");
Expect(0, 6688, '\P{^Is_Script=_	Buginese}', "");
Error('\p{Is_Sc=/a/-Bugi}');
Error('\P{Is_Sc=/a/-Bugi}');
Expect(1, 6687, '\p{Is_Sc=bugi}', "");
Expect(0, 6687, '\p{^Is_Sc=bugi}', "");
Expect(0, 6687, '\P{Is_Sc=bugi}', "");
Expect(1, 6687, '\P{^Is_Sc=bugi}', "");
Expect(0, 6688, '\p{Is_Sc=bugi}', "");
Expect(1, 6688, '\p{^Is_Sc=bugi}', "");
Expect(1, 6688, '\P{Is_Sc=bugi}', "");
Expect(0, 6688, '\P{^Is_Sc=bugi}', "");
Expect(1, 6687, '\p{Is_Sc:   	-Bugi}', "");
Expect(0, 6687, '\p{^Is_Sc:   	-Bugi}', "");
Expect(0, 6687, '\P{Is_Sc:   	-Bugi}', "");
Expect(1, 6687, '\P{^Is_Sc:   	-Bugi}', "");
Expect(0, 6688, '\p{Is_Sc:   	-Bugi}', "");
Expect(1, 6688, '\p{^Is_Sc:   	-Bugi}', "");
Expect(1, 6688, '\P{Is_Sc:   	-Bugi}', "");
Expect(0, 6688, '\P{^Is_Sc:   	-Bugi}', "");
Error('\p{Script=/a/_ BUHID}');
Error('\P{Script=/a/_ BUHID}');
Expect(1, 5971, '\p{Script=buhid}', "");
Expect(0, 5971, '\p{^Script=buhid}', "");
Expect(0, 5971, '\P{Script=buhid}', "");
Expect(1, 5971, '\P{^Script=buhid}', "");
Expect(0, 5972, '\p{Script=buhid}', "");
Expect(1, 5972, '\p{^Script=buhid}', "");
Expect(1, 5972, '\P{Script=buhid}', "");
Expect(0, 5972, '\P{^Script=buhid}', "");
Expect(1, 5971, '\p{Script=_-BUHID}', "");
Expect(0, 5971, '\p{^Script=_-BUHID}', "");
Expect(0, 5971, '\P{Script=_-BUHID}', "");
Expect(1, 5971, '\P{^Script=_-BUHID}', "");
Expect(0, 5972, '\p{Script=_-BUHID}', "");
Expect(1, 5972, '\p{^Script=_-BUHID}', "");
Expect(1, 5972, '\P{Script=_-BUHID}', "");
Expect(0, 5972, '\P{^Script=_-BUHID}', "");
Error('\p{Sc=/a/_ buhd}');
Error('\P{Sc=/a/_ buhd}');
Expect(1, 5971, '\p{Sc=buhd}', "");
Expect(0, 5971, '\p{^Sc=buhd}', "");
Expect(0, 5971, '\P{Sc=buhd}', "");
Expect(1, 5971, '\P{^Sc=buhd}', "");
Expect(0, 5972, '\p{Sc=buhd}', "");
Expect(1, 5972, '\p{^Sc=buhd}', "");
Expect(1, 5972, '\P{Sc=buhd}', "");
Expect(0, 5972, '\P{^Sc=buhd}', "");
Expect(1, 5971, '\p{Sc=		Buhd}', "");
Expect(0, 5971, '\p{^Sc=		Buhd}', "");
Expect(0, 5971, '\P{Sc=		Buhd}', "");
Expect(1, 5971, '\P{^Sc=		Buhd}', "");
Expect(0, 5972, '\p{Sc=		Buhd}', "");
Expect(1, 5972, '\p{^Sc=		Buhd}', "");
Expect(1, 5972, '\P{Sc=		Buhd}', "");
Expect(0, 5972, '\P{^Sc=		Buhd}', "");
Error('\p{Is_Script=:= -Buhid}');
Error('\P{Is_Script=:= -Buhid}');
Expect(1, 5971, '\p{Is_Script=buhid}', "");
Expect(0, 5971, '\p{^Is_Script=buhid}', "");
Expect(0, 5971, '\P{Is_Script=buhid}', "");
Expect(1, 5971, '\P{^Is_Script=buhid}', "");
Expect(0, 5972, '\p{Is_Script=buhid}', "");
Expect(1, 5972, '\p{^Is_Script=buhid}', "");
Expect(1, 5972, '\P{Is_Script=buhid}', "");
Expect(0, 5972, '\P{^Is_Script=buhid}', "");
Expect(1, 5971, '\p{Is_Script=-	Buhid}', "");
Expect(0, 5971, '\p{^Is_Script=-	Buhid}', "");
Expect(0, 5971, '\P{Is_Script=-	Buhid}', "");
Expect(1, 5971, '\P{^Is_Script=-	Buhid}', "");
Expect(0, 5972, '\p{Is_Script=-	Buhid}', "");
Expect(1, 5972, '\p{^Is_Script=-	Buhid}', "");
Expect(1, 5972, '\P{Is_Script=-	Buhid}', "");
Expect(0, 5972, '\P{^Is_Script=-	Buhid}', "");
Error('\p{Is_Sc=  Buhd:=}');
Error('\P{Is_Sc=  Buhd:=}');
Expect(1, 5971, '\p{Is_Sc=buhd}', "");
Expect(0, 5971, '\p{^Is_Sc=buhd}', "");
Expect(0, 5971, '\P{Is_Sc=buhd}', "");
Expect(1, 5971, '\P{^Is_Sc=buhd}', "");
Expect(0, 5972, '\p{Is_Sc=buhd}', "");
Expect(1, 5972, '\p{^Is_Sc=buhd}', "");
Expect(1, 5972, '\P{Is_Sc=buhd}', "");
Expect(0, 5972, '\P{^Is_Sc=buhd}', "");
Expect(1, 5971, '\p{Is_Sc=-BUHD}', "");
Expect(0, 5971, '\p{^Is_Sc=-BUHD}', "");
Expect(0, 5971, '\P{Is_Sc=-BUHD}', "");
Expect(1, 5971, '\P{^Is_Sc=-BUHD}', "");
Expect(0, 5972, '\p{Is_Sc=-BUHD}', "");
Expect(1, 5972, '\p{^Is_Sc=-BUHD}', "");
Expect(1, 5972, '\P{Is_Sc=-BUHD}', "");
Expect(0, 5972, '\P{^Is_Sc=-BUHD}', "");
Error('\p{Script=/a/-_CHAKMA}');
Error('\P{Script=/a/-_CHAKMA}');
Expect(1, 69955, '\p{Script=chakma}', "");
Expect(0, 69955, '\p{^Script=chakma}', "");
Expect(0, 69955, '\P{Script=chakma}', "");
Expect(1, 69955, '\P{^Script=chakma}', "");
Expect(0, 69956, '\p{Script=chakma}', "");
Expect(1, 69956, '\p{^Script=chakma}', "");
Expect(1, 69956, '\P{Script=chakma}', "");
Expect(0, 69956, '\P{^Script=chakma}', "");
Expect(1, 69955, '\p{Script=	 CHAKMA}', "");
Expect(0, 69955, '\p{^Script=	 CHAKMA}', "");
Expect(0, 69955, '\P{Script=	 CHAKMA}', "");
Expect(1, 69955, '\P{^Script=	 CHAKMA}', "");
Expect(0, 69956, '\p{Script=	 CHAKMA}', "");
Expect(1, 69956, '\p{^Script=	 CHAKMA}', "");
Expect(1, 69956, '\P{Script=	 CHAKMA}', "");
Expect(0, 69956, '\P{^Script=	 CHAKMA}', "");
Error('\p{Sc=:=__CAKM}');
Error('\P{Sc=:=__CAKM}');
Expect(1, 69955, '\p{Sc:   cakm}', "");
Expect(0, 69955, '\p{^Sc:   cakm}', "");
Expect(0, 69955, '\P{Sc:   cakm}', "");
Expect(1, 69955, '\P{^Sc:   cakm}', "");
Expect(0, 69956, '\p{Sc:   cakm}', "");
Expect(1, 69956, '\p{^Sc:   cakm}', "");
Expect(1, 69956, '\P{Sc:   cakm}', "");
Expect(0, 69956, '\P{^Sc:   cakm}', "");
Expect(1, 69955, '\p{Sc=-Cakm}', "");
Expect(0, 69955, '\p{^Sc=-Cakm}', "");
Expect(0, 69955, '\P{Sc=-Cakm}', "");
Expect(1, 69955, '\P{^Sc=-Cakm}', "");
Expect(0, 69956, '\p{Sc=-Cakm}', "");
Expect(1, 69956, '\p{^Sc=-Cakm}', "");
Expect(1, 69956, '\P{Sc=-Cakm}', "");
Expect(0, 69956, '\P{^Sc=-Cakm}', "");
Error('\p{Is_Script=_	CHAKMA/a/}');
Error('\P{Is_Script=_	CHAKMA/a/}');
Expect(1, 69955, '\p{Is_Script=chakma}', "");
Expect(0, 69955, '\p{^Is_Script=chakma}', "");
Expect(0, 69955, '\P{Is_Script=chakma}', "");
Expect(1, 69955, '\P{^Is_Script=chakma}', "");
Expect(0, 69956, '\p{Is_Script=chakma}', "");
Expect(1, 69956, '\p{^Is_Script=chakma}', "");
Expect(1, 69956, '\P{Is_Script=chakma}', "");
Expect(0, 69956, '\P{^Is_Script=chakma}', "");
Expect(1, 69955, '\p{Is_Script=_	CHAKMA}', "");
Expect(0, 69955, '\p{^Is_Script=_	CHAKMA}', "");
Expect(0, 69955, '\P{Is_Script=_	CHAKMA}', "");
Expect(1, 69955, '\P{^Is_Script=_	CHAKMA}', "");
Expect(0, 69956, '\p{Is_Script=_	CHAKMA}', "");
Expect(1, 69956, '\p{^Is_Script=_	CHAKMA}', "");
Expect(1, 69956, '\P{Is_Script=_	CHAKMA}', "");
Expect(0, 69956, '\P{^Is_Script=_	CHAKMA}', "");
Error('\p{Is_Sc=/a/ 	cakm}');
Error('\P{Is_Sc=/a/ 	cakm}');
Expect(1, 69955, '\p{Is_Sc=cakm}', "");
Expect(0, 69955, '\p{^Is_Sc=cakm}', "");
Expect(0, 69955, '\P{Is_Sc=cakm}', "");
Expect(1, 69955, '\P{^Is_Sc=cakm}', "");
Expect(0, 69956, '\p{Is_Sc=cakm}', "");
Expect(1, 69956, '\p{^Is_Sc=cakm}', "");
Expect(1, 69956, '\P{Is_Sc=cakm}', "");
Expect(0, 69956, '\P{^Is_Sc=cakm}', "");
Expect(1, 69955, '\p{Is_Sc=-_Cakm}', "");
Expect(0, 69955, '\p{^Is_Sc=-_Cakm}', "");
Expect(0, 69955, '\P{Is_Sc=-_Cakm}', "");
Expect(1, 69955, '\P{^Is_Sc=-_Cakm}', "");
Expect(0, 69956, '\p{Is_Sc=-_Cakm}', "");
Expect(1, 69956, '\p{^Is_Sc=-_Cakm}', "");
Expect(1, 69956, '\P{Is_Sc=-_Cakm}', "");
Expect(0, 69956, '\P{^Is_Sc=-_Cakm}', "");
Error('\p{Script=	:=Canadian_ABORIGINAL}');
Error('\P{Script=	:=Canadian_ABORIGINAL}');
Expect(1, 6389, '\p{Script=canadianaboriginal}', "");
Expect(0, 6389, '\p{^Script=canadianaboriginal}', "");
Expect(0, 6389, '\P{Script=canadianaboriginal}', "");
Expect(1, 6389, '\P{^Script=canadianaboriginal}', "");
Expect(0, 6390, '\p{Script=canadianaboriginal}', "");
Expect(1, 6390, '\p{^Script=canadianaboriginal}', "");
Expect(1, 6390, '\P{Script=canadianaboriginal}', "");
Expect(0, 6390, '\P{^Script=canadianaboriginal}', "");
Expect(1, 6389, '\p{Script=_-Canadian_ABORIGINAL}', "");
Expect(0, 6389, '\p{^Script=_-Canadian_ABORIGINAL}', "");
Expect(0, 6389, '\P{Script=_-Canadian_ABORIGINAL}', "");
Expect(1, 6389, '\P{^Script=_-Canadian_ABORIGINAL}', "");
Expect(0, 6390, '\p{Script=_-Canadian_ABORIGINAL}', "");
Expect(1, 6390, '\p{^Script=_-Canadian_ABORIGINAL}', "");
Expect(1, 6390, '\P{Script=_-Canadian_ABORIGINAL}', "");
Expect(0, 6390, '\P{^Script=_-Canadian_ABORIGINAL}', "");
Error('\p{Sc=/a/-	cans}');
Error('\P{Sc=/a/-	cans}');
Expect(1, 6389, '\p{Sc=cans}', "");
Expect(0, 6389, '\p{^Sc=cans}', "");
Expect(0, 6389, '\P{Sc=cans}', "");
Expect(1, 6389, '\P{^Sc=cans}', "");
Expect(0, 6390, '\p{Sc=cans}', "");
Expect(1, 6390, '\p{^Sc=cans}', "");
Expect(1, 6390, '\P{Sc=cans}', "");
Expect(0, 6390, '\P{^Sc=cans}', "");
Expect(1, 6389, '\p{Sc=_ cans}', "");
Expect(0, 6389, '\p{^Sc=_ cans}', "");
Expect(0, 6389, '\P{Sc=_ cans}', "");
Expect(1, 6389, '\P{^Sc=_ cans}', "");
Expect(0, 6390, '\p{Sc=_ cans}', "");
Expect(1, 6390, '\p{^Sc=_ cans}', "");
Expect(1, 6390, '\P{Sc=_ cans}', "");
Expect(0, 6390, '\P{^Sc=_ cans}', "");
Error('\p{Is_Script=/a/	-CANADIAN_Aboriginal}');
Error('\P{Is_Script=/a/	-CANADIAN_Aboriginal}');
Expect(1, 6389, '\p{Is_Script=canadianaboriginal}', "");
Expect(0, 6389, '\p{^Is_Script=canadianaboriginal}', "");
Expect(0, 6389, '\P{Is_Script=canadianaboriginal}', "");
Expect(1, 6389, '\P{^Is_Script=canadianaboriginal}', "");
Expect(0, 6390, '\p{Is_Script=canadianaboriginal}', "");
Expect(1, 6390, '\p{^Is_Script=canadianaboriginal}', "");
Expect(1, 6390, '\P{Is_Script=canadianaboriginal}', "");
Expect(0, 6390, '\P{^Is_Script=canadianaboriginal}', "");
Expect(1, 6389, '\p{Is_Script=-_Canadian_Aboriginal}', "");
Expect(0, 6389, '\p{^Is_Script=-_Canadian_Aboriginal}', "");
Expect(0, 6389, '\P{Is_Script=-_Canadian_Aboriginal}', "");
Expect(1, 6389, '\P{^Is_Script=-_Canadian_Aboriginal}', "");
Expect(0, 6390, '\p{Is_Script=-_Canadian_Aboriginal}', "");
Expect(1, 6390, '\p{^Is_Script=-_Canadian_Aboriginal}', "");
Expect(1, 6390, '\P{Is_Script=-_Canadian_Aboriginal}', "");
Expect(0, 6390, '\P{^Is_Script=-_Canadian_Aboriginal}', "");
Error('\p{Is_Sc=_/a/Cans}');
Error('\P{Is_Sc=_/a/Cans}');
Expect(1, 6389, '\p{Is_Sc=cans}', "");
Expect(0, 6389, '\p{^Is_Sc=cans}', "");
Expect(0, 6389, '\P{Is_Sc=cans}', "");
Expect(1, 6389, '\P{^Is_Sc=cans}', "");
Expect(0, 6390, '\p{Is_Sc=cans}', "");
Expect(1, 6390, '\p{^Is_Sc=cans}', "");
Expect(1, 6390, '\P{Is_Sc=cans}', "");
Expect(0, 6390, '\P{^Is_Sc=cans}', "");
Expect(1, 6389, '\p{Is_Sc=_Cans}', "");
Expect(0, 6389, '\p{^Is_Sc=_Cans}', "");
Expect(0, 6389, '\P{Is_Sc=_Cans}', "");
Expect(1, 6389, '\P{^Is_Sc=_Cans}', "");
Expect(0, 6390, '\p{Is_Sc=_Cans}', "");
Expect(1, 6390, '\p{^Is_Sc=_Cans}', "");
Expect(1, 6390, '\P{Is_Sc=_Cans}', "");
Expect(0, 6390, '\P{^Is_Sc=_Cans}', "");
Error('\p{Script=_/a/Carian}');
Error('\P{Script=_/a/Carian}');
Expect(1, 66256, '\p{Script=carian}', "");
Expect(0, 66256, '\p{^Script=carian}', "");
Expect(0, 66256, '\P{Script=carian}', "");
Expect(1, 66256, '\P{^Script=carian}', "");
Expect(0, 66257, '\p{Script=carian}', "");
Expect(1, 66257, '\p{^Script=carian}', "");
Expect(1, 66257, '\P{Script=carian}', "");
Expect(0, 66257, '\P{^Script=carian}', "");
Expect(1, 66256, '\p{Script:Carian}', "");
Expect(0, 66256, '\p{^Script:Carian}', "");
Expect(0, 66256, '\P{Script:Carian}', "");
Expect(1, 66256, '\P{^Script:Carian}', "");
Expect(0, 66257, '\p{Script:Carian}', "");
Expect(1, 66257, '\p{^Script:Carian}', "");
Expect(1, 66257, '\P{Script:Carian}', "");
Expect(0, 66257, '\P{^Script:Carian}', "");
Error('\p{Sc=/a/Cari}');
Error('\P{Sc=/a/Cari}');
Expect(1, 66256, '\p{Sc=cari}', "");
Expect(0, 66256, '\p{^Sc=cari}', "");
Expect(0, 66256, '\P{Sc=cari}', "");
Expect(1, 66256, '\P{^Sc=cari}', "");
Expect(0, 66257, '\p{Sc=cari}', "");
Expect(1, 66257, '\p{^Sc=cari}', "");
Expect(1, 66257, '\P{Sc=cari}', "");
Expect(0, 66257, '\P{^Sc=cari}', "");
Expect(1, 66256, '\p{Sc= Cari}', "");
Expect(0, 66256, '\p{^Sc= Cari}', "");
Expect(0, 66256, '\P{Sc= Cari}', "");
Expect(1, 66256, '\P{^Sc= Cari}', "");
Expect(0, 66257, '\p{Sc= Cari}', "");
Expect(1, 66257, '\p{^Sc= Cari}', "");
Expect(1, 66257, '\P{Sc= Cari}', "");
Expect(0, 66257, '\P{^Sc= Cari}', "");
Error('\p{Is_Script=:= _Carian}');
Error('\P{Is_Script=:= _Carian}');
Expect(1, 66256, '\p{Is_Script=carian}', "");
Expect(0, 66256, '\p{^Is_Script=carian}', "");
Expect(0, 66256, '\P{Is_Script=carian}', "");
Expect(1, 66256, '\P{^Is_Script=carian}', "");
Expect(0, 66257, '\p{Is_Script=carian}', "");
Expect(1, 66257, '\p{^Is_Script=carian}', "");
Expect(1, 66257, '\P{Is_Script=carian}', "");
Expect(0, 66257, '\P{^Is_Script=carian}', "");
Expect(1, 66256, '\p{Is_Script=_CARIAN}', "");
Expect(0, 66256, '\p{^Is_Script=_CARIAN}', "");
Expect(0, 66256, '\P{Is_Script=_CARIAN}', "");
Expect(1, 66256, '\P{^Is_Script=_CARIAN}', "");
Expect(0, 66257, '\p{Is_Script=_CARIAN}', "");
Expect(1, 66257, '\p{^Is_Script=_CARIAN}', "");
Expect(1, 66257, '\P{Is_Script=_CARIAN}', "");
Expect(0, 66257, '\P{^Is_Script=_CARIAN}', "");
Error('\p{Is_Sc=_-Cari/a/}');
Error('\P{Is_Sc=_-Cari/a/}');
Expect(1, 66256, '\p{Is_Sc=cari}', "");
Expect(0, 66256, '\p{^Is_Sc=cari}', "");
Expect(0, 66256, '\P{Is_Sc=cari}', "");
Expect(1, 66256, '\P{^Is_Sc=cari}', "");
Expect(0, 66257, '\p{Is_Sc=cari}', "");
Expect(1, 66257, '\p{^Is_Sc=cari}', "");
Expect(1, 66257, '\P{Is_Sc=cari}', "");
Expect(0, 66257, '\P{^Is_Sc=cari}', "");
Expect(1, 66256, '\p{Is_Sc=_-Cari}', "");
Expect(0, 66256, '\p{^Is_Sc=_-Cari}', "");
Expect(0, 66256, '\P{Is_Sc=_-Cari}', "");
Expect(1, 66256, '\P{^Is_Sc=_-Cari}', "");
Expect(0, 66257, '\p{Is_Sc=_-Cari}', "");
Expect(1, 66257, '\p{^Is_Sc=_-Cari}', "");
Expect(1, 66257, '\P{Is_Sc=_-Cari}', "");
Expect(0, 66257, '\P{^Is_Sc=_-Cari}', "");
Error('\p{Script=-:=cham}');
Error('\P{Script=-:=cham}');
Expect(1, 43615, '\p{Script=cham}', "");
Expect(0, 43615, '\p{^Script=cham}', "");
Expect(0, 43615, '\P{Script=cham}', "");
Expect(1, 43615, '\P{^Script=cham}', "");
Expect(0, 43616, '\p{Script=cham}', "");
Expect(1, 43616, '\p{^Script=cham}', "");
Expect(1, 43616, '\P{Script=cham}', "");
Expect(0, 43616, '\P{^Script=cham}', "");
Expect(1, 43615, '\p{Script= _cham}', "");
Expect(0, 43615, '\p{^Script= _cham}', "");
Expect(0, 43615, '\P{Script= _cham}', "");
Expect(1, 43615, '\P{^Script= _cham}', "");
Expect(0, 43616, '\p{Script= _cham}', "");
Expect(1, 43616, '\p{^Script= _cham}', "");
Expect(1, 43616, '\P{Script= _cham}', "");
Expect(0, 43616, '\P{^Script= _cham}', "");
Error('\p{Sc:  :=cham}');
Error('\P{Sc:  :=cham}');
Expect(1, 43615, '\p{Sc:cham}', "");
Expect(0, 43615, '\p{^Sc:cham}', "");
Expect(0, 43615, '\P{Sc:cham}', "");
Expect(1, 43615, '\P{^Sc:cham}', "");
Expect(0, 43616, '\p{Sc:cham}', "");
Expect(1, 43616, '\p{^Sc:cham}', "");
Expect(1, 43616, '\P{Sc:cham}', "");
Expect(0, 43616, '\P{^Sc:cham}', "");
Expect(1, 43615, '\p{Sc=_-CHAM}', "");
Expect(0, 43615, '\p{^Sc=_-CHAM}', "");
Expect(0, 43615, '\P{Sc=_-CHAM}', "");
Expect(1, 43615, '\P{^Sc=_-CHAM}', "");
Expect(0, 43616, '\p{Sc=_-CHAM}', "");
Expect(1, 43616, '\p{^Sc=_-CHAM}', "");
Expect(1, 43616, '\P{Sc=_-CHAM}', "");
Expect(0, 43616, '\P{^Sc=_-CHAM}', "");
Error('\p{Is_Script=:= CHAM}');
Error('\P{Is_Script=:= CHAM}');
Expect(1, 43615, '\p{Is_Script:   cham}', "");
Expect(0, 43615, '\p{^Is_Script:   cham}', "");
Expect(0, 43615, '\P{Is_Script:   cham}', "");
Expect(1, 43615, '\P{^Is_Script:   cham}', "");
Expect(0, 43616, '\p{Is_Script:   cham}', "");
Expect(1, 43616, '\p{^Is_Script:   cham}', "");
Expect(1, 43616, '\P{Is_Script:   cham}', "");
Expect(0, 43616, '\P{^Is_Script:   cham}', "");
Expect(1, 43615, '\p{Is_Script= -cham}', "");
Expect(0, 43615, '\p{^Is_Script= -cham}', "");
Expect(0, 43615, '\P{Is_Script= -cham}', "");
Expect(1, 43615, '\P{^Is_Script= -cham}', "");
Expect(0, 43616, '\p{Is_Script= -cham}', "");
Expect(1, 43616, '\p{^Is_Script= -cham}', "");
Expect(1, 43616, '\P{Is_Script= -cham}', "");
Expect(0, 43616, '\P{^Is_Script= -cham}', "");
Error('\p{Is_Sc=	_cham/a/}');
Error('\P{Is_Sc=	_cham/a/}');
Expect(1, 43615, '\p{Is_Sc=cham}', "");
Expect(0, 43615, '\p{^Is_Sc=cham}', "");
Expect(0, 43615, '\P{Is_Sc=cham}', "");
Expect(1, 43615, '\P{^Is_Sc=cham}', "");
Expect(0, 43616, '\p{Is_Sc=cham}', "");
Expect(1, 43616, '\p{^Is_Sc=cham}', "");
Expect(1, 43616, '\P{Is_Sc=cham}', "");
Expect(0, 43616, '\P{^Is_Sc=cham}', "");
Expect(1, 43615, '\p{Is_Sc=-_CHAM}', "");
Expect(0, 43615, '\p{^Is_Sc=-_CHAM}', "");
Expect(0, 43615, '\P{Is_Sc=-_CHAM}', "");
Expect(1, 43615, '\P{^Is_Sc=-_CHAM}', "");
Expect(0, 43616, '\p{Is_Sc=-_CHAM}', "");
Expect(1, 43616, '\p{^Is_Sc=-_CHAM}', "");
Expect(1, 43616, '\P{Is_Sc=-_CHAM}', "");
Expect(0, 43616, '\P{^Is_Sc=-_CHAM}', "");
Error('\p{Script=	cherokee:=}');
Error('\P{Script=	cherokee:=}');
Expect(1, 5108, '\p{Script=cherokee}', "");
Expect(0, 5108, '\p{^Script=cherokee}', "");
Expect(0, 5108, '\P{Script=cherokee}', "");
Expect(1, 5108, '\P{^Script=cherokee}', "");
Expect(0, 5109, '\p{Script=cherokee}', "");
Expect(1, 5109, '\p{^Script=cherokee}', "");
Expect(1, 5109, '\P{Script=cherokee}', "");
Expect(0, 5109, '\P{^Script=cherokee}', "");
Expect(1, 5108, '\p{Script=-Cherokee}', "");
Expect(0, 5108, '\p{^Script=-Cherokee}', "");
Expect(0, 5108, '\P{Script=-Cherokee}', "");
Expect(1, 5108, '\P{^Script=-Cherokee}', "");
Expect(0, 5109, '\p{Script=-Cherokee}', "");
Expect(1, 5109, '\p{^Script=-Cherokee}', "");
Expect(1, 5109, '\P{Script=-Cherokee}', "");
Expect(0, 5109, '\P{^Script=-Cherokee}', "");
Error('\p{Sc=/a/-Cher}');
Error('\P{Sc=/a/-Cher}');
Expect(1, 5108, '\p{Sc=cher}', "");
Expect(0, 5108, '\p{^Sc=cher}', "");
Expect(0, 5108, '\P{Sc=cher}', "");
Expect(1, 5108, '\P{^Sc=cher}', "");
Expect(0, 5109, '\p{Sc=cher}', "");
Expect(1, 5109, '\p{^Sc=cher}', "");
Expect(1, 5109, '\P{Sc=cher}', "");
Expect(0, 5109, '\P{^Sc=cher}', "");
Expect(1, 5108, '\p{Sc:	  cher}', "");
Expect(0, 5108, '\p{^Sc:	  cher}', "");
Expect(0, 5108, '\P{Sc:	  cher}', "");
Expect(1, 5108, '\P{^Sc:	  cher}', "");
Expect(0, 5109, '\p{Sc:	  cher}', "");
Expect(1, 5109, '\p{^Sc:	  cher}', "");
Expect(1, 5109, '\P{Sc:	  cher}', "");
Expect(0, 5109, '\P{^Sc:	  cher}', "");
Error('\p{Is_Script= 	CHEROKEE:=}');
Error('\P{Is_Script= 	CHEROKEE:=}');
Expect(1, 5108, '\p{Is_Script=cherokee}', "");
Expect(0, 5108, '\p{^Is_Script=cherokee}', "");
Expect(0, 5108, '\P{Is_Script=cherokee}', "");
Expect(1, 5108, '\P{^Is_Script=cherokee}', "");
Expect(0, 5109, '\p{Is_Script=cherokee}', "");
Expect(1, 5109, '\p{^Is_Script=cherokee}', "");
Expect(1, 5109, '\P{Is_Script=cherokee}', "");
Expect(0, 5109, '\P{^Is_Script=cherokee}', "");
Expect(1, 5108, '\p{Is_Script: -Cherokee}', "");
Expect(0, 5108, '\p{^Is_Script: -Cherokee}', "");
Expect(0, 5108, '\P{Is_Script: -Cherokee}', "");
Expect(1, 5108, '\P{^Is_Script: -Cherokee}', "");
Expect(0, 5109, '\p{Is_Script: -Cherokee}', "");
Expect(1, 5109, '\p{^Is_Script: -Cherokee}', "");
Expect(1, 5109, '\P{Is_Script: -Cherokee}', "");
Expect(0, 5109, '\P{^Is_Script: -Cherokee}', "");
Error('\p{Is_Sc=_	cher:=}');
Error('\P{Is_Sc=_	cher:=}');
Expect(1, 5108, '\p{Is_Sc=cher}', "");
Expect(0, 5108, '\p{^Is_Sc=cher}', "");
Expect(0, 5108, '\P{Is_Sc=cher}', "");
Expect(1, 5108, '\P{^Is_Sc=cher}', "");
Expect(0, 5109, '\p{Is_Sc=cher}', "");
Expect(1, 5109, '\p{^Is_Sc=cher}', "");
Expect(1, 5109, '\P{Is_Sc=cher}', "");
Expect(0, 5109, '\P{^Is_Sc=cher}', "");
Expect(1, 5108, '\p{Is_Sc=_cher}', "");
Expect(0, 5108, '\p{^Is_Sc=_cher}', "");
Expect(0, 5108, '\P{Is_Sc=_cher}', "");
Expect(1, 5108, '\P{^Is_Sc=_cher}', "");
Expect(0, 5109, '\p{Is_Sc=_cher}', "");
Expect(1, 5109, '\p{^Is_Sc=_cher}', "");
Expect(1, 5109, '\P{Is_Sc=_cher}', "");
Expect(0, 5109, '\P{^Is_Sc=_cher}', "");
Error('\p{Script=:= coptic}');
Error('\P{Script=:= coptic}');
Expect(1, 11519, '\p{Script=coptic}', "");
Expect(0, 11519, '\p{^Script=coptic}', "");
Expect(0, 11519, '\P{Script=coptic}', "");
Expect(1, 11519, '\P{^Script=coptic}', "");
Expect(0, 11520, '\p{Script=coptic}', "");
Expect(1, 11520, '\p{^Script=coptic}', "");
Expect(1, 11520, '\P{Script=coptic}', "");
Expect(0, 11520, '\P{^Script=coptic}', "");
Expect(1, 11519, '\p{Script=_-Coptic}', "");
Expect(0, 11519, '\p{^Script=_-Coptic}', "");
Expect(0, 11519, '\P{Script=_-Coptic}', "");
Expect(1, 11519, '\P{^Script=_-Coptic}', "");
Expect(0, 11520, '\p{Script=_-Coptic}', "");
Expect(1, 11520, '\p{^Script=_-Coptic}', "");
Expect(1, 11520, '\P{Script=_-Coptic}', "");
Expect(0, 11520, '\P{^Script=_-Coptic}', "");
Error('\p{Sc=:=	COPT}');
Error('\P{Sc=:=	COPT}');
Expect(1, 11519, '\p{Sc:   copt}', "");
Expect(0, 11519, '\p{^Sc:   copt}', "");
Expect(0, 11519, '\P{Sc:   copt}', "");
Expect(1, 11519, '\P{^Sc:   copt}', "");
Expect(0, 11520, '\p{Sc:   copt}', "");
Expect(1, 11520, '\p{^Sc:   copt}', "");
Expect(1, 11520, '\P{Sc:   copt}', "");
Expect(0, 11520, '\P{^Sc:   copt}', "");
Expect(1, 11519, '\p{Sc=--Copt}', "");
Expect(0, 11519, '\p{^Sc=--Copt}', "");
Expect(0, 11519, '\P{Sc=--Copt}', "");
Expect(1, 11519, '\P{^Sc=--Copt}', "");
Expect(0, 11520, '\p{Sc=--Copt}', "");
Expect(1, 11520, '\p{^Sc=--Copt}', "");
Expect(1, 11520, '\P{Sc=--Copt}', "");
Expect(0, 11520, '\P{^Sc=--Copt}', "");
Error('\p{Is_Script=/a/ _Qaac}');
Error('\P{Is_Script=/a/ _Qaac}');
Expect(1, 11519, '\p{Is_Script:   qaac}', "");
Expect(0, 11519, '\p{^Is_Script:   qaac}', "");
Expect(0, 11519, '\P{Is_Script:   qaac}', "");
Expect(1, 11519, '\P{^Is_Script:   qaac}', "");
Expect(0, 11520, '\p{Is_Script:   qaac}', "");
Expect(1, 11520, '\p{^Is_Script:   qaac}', "");
Expect(1, 11520, '\P{Is_Script:   qaac}', "");
Expect(0, 11520, '\P{^Is_Script:   qaac}', "");
Expect(1, 11519, '\p{Is_Script:  QAAC}', "");
Expect(0, 11519, '\p{^Is_Script:  QAAC}', "");
Expect(0, 11519, '\P{Is_Script:  QAAC}', "");
Expect(1, 11519, '\P{^Is_Script:  QAAC}', "");
Expect(0, 11520, '\p{Is_Script:  QAAC}', "");
Expect(1, 11520, '\p{^Is_Script:  QAAC}', "");
Expect(1, 11520, '\P{Is_Script:  QAAC}', "");
Expect(0, 11520, '\P{^Is_Script:  QAAC}', "");
Error('\p{Is_Sc=/a/	Coptic}');
Error('\P{Is_Sc=/a/	Coptic}');
Expect(1, 11519, '\p{Is_Sc=coptic}', "");
Expect(0, 11519, '\p{^Is_Sc=coptic}', "");
Expect(0, 11519, '\P{Is_Sc=coptic}', "");
Expect(1, 11519, '\P{^Is_Sc=coptic}', "");
Expect(0, 11520, '\p{Is_Sc=coptic}', "");
Expect(1, 11520, '\p{^Is_Sc=coptic}', "");
Expect(1, 11520, '\P{Is_Sc=coptic}', "");
Expect(0, 11520, '\P{^Is_Sc=coptic}', "");
Expect(1, 11519, '\p{Is_Sc=--Coptic}', "");
Expect(0, 11519, '\p{^Is_Sc=--Coptic}', "");
Expect(0, 11519, '\P{Is_Sc=--Coptic}', "");
Expect(1, 11519, '\P{^Is_Sc=--Coptic}', "");
Expect(0, 11520, '\p{Is_Sc=--Coptic}', "");
Expect(1, 11520, '\p{^Is_Sc=--Coptic}', "");
Expect(1, 11520, '\P{Is_Sc=--Coptic}', "");
Expect(0, 11520, '\P{^Is_Sc=--Coptic}', "");
Error('\p{Script:	Cypriot/a/}');
Error('\P{Script:	Cypriot/a/}');
Expect(1, 67647, '\p{Script=cypriot}', "");
Expect(0, 67647, '\p{^Script=cypriot}', "");
Expect(0, 67647, '\P{Script=cypriot}', "");
Expect(1, 67647, '\P{^Script=cypriot}', "");
Expect(0, 67648, '\p{Script=cypriot}', "");
Expect(1, 67648, '\p{^Script=cypriot}', "");
Expect(1, 67648, '\P{Script=cypriot}', "");
Expect(0, 67648, '\P{^Script=cypriot}', "");
Expect(1, 67647, '\p{Script=-cypriot}', "");
Expect(0, 67647, '\p{^Script=-cypriot}', "");
Expect(0, 67647, '\P{Script=-cypriot}', "");
Expect(1, 67647, '\P{^Script=-cypriot}', "");
Expect(0, 67648, '\p{Script=-cypriot}', "");
Expect(1, 67648, '\p{^Script=-cypriot}', "");
Expect(1, 67648, '\P{Script=-cypriot}', "");
Expect(0, 67648, '\P{^Script=-cypriot}', "");
Error('\p{Sc=-	Cprt:=}');
Error('\P{Sc=-	Cprt:=}');
Expect(1, 67647, '\p{Sc=cprt}', "");
Expect(0, 67647, '\p{^Sc=cprt}', "");
Expect(0, 67647, '\P{Sc=cprt}', "");
Expect(1, 67647, '\P{^Sc=cprt}', "");
Expect(0, 67648, '\p{Sc=cprt}', "");
Expect(1, 67648, '\p{^Sc=cprt}', "");
Expect(1, 67648, '\P{Sc=cprt}', "");
Expect(0, 67648, '\P{^Sc=cprt}', "");
Expect(1, 67647, '\p{Sc=_-Cprt}', "");
Expect(0, 67647, '\p{^Sc=_-Cprt}', "");
Expect(0, 67647, '\P{Sc=_-Cprt}', "");
Expect(1, 67647, '\P{^Sc=_-Cprt}', "");
Expect(0, 67648, '\p{Sc=_-Cprt}', "");
Expect(1, 67648, '\p{^Sc=_-Cprt}', "");
Expect(1, 67648, '\P{Sc=_-Cprt}', "");
Expect(0, 67648, '\P{^Sc=_-Cprt}', "");
Error('\p{Is_Script::=	Cypriot}');
Error('\P{Is_Script::=	Cypriot}');
Expect(1, 67647, '\p{Is_Script=cypriot}', "");
Expect(0, 67647, '\p{^Is_Script=cypriot}', "");
Expect(0, 67647, '\P{Is_Script=cypriot}', "");
Expect(1, 67647, '\P{^Is_Script=cypriot}', "");
Expect(0, 67648, '\p{Is_Script=cypriot}', "");
Expect(1, 67648, '\p{^Is_Script=cypriot}', "");
Expect(1, 67648, '\P{Is_Script=cypriot}', "");
Expect(0, 67648, '\P{^Is_Script=cypriot}', "");
Expect(1, 67647, '\p{Is_Script=-_Cypriot}', "");
Expect(0, 67647, '\p{^Is_Script=-_Cypriot}', "");
Expect(0, 67647, '\P{Is_Script=-_Cypriot}', "");
Expect(1, 67647, '\P{^Is_Script=-_Cypriot}', "");
Expect(0, 67648, '\p{Is_Script=-_Cypriot}', "");
Expect(1, 67648, '\p{^Is_Script=-_Cypriot}', "");
Expect(1, 67648, '\P{Is_Script=-_Cypriot}', "");
Expect(0, 67648, '\P{^Is_Script=-_Cypriot}', "");
Error('\p{Is_Sc=-_Cprt/a/}');
Error('\P{Is_Sc=-_Cprt/a/}');
Expect(1, 67647, '\p{Is_Sc=cprt}', "");
Expect(0, 67647, '\p{^Is_Sc=cprt}', "");
Expect(0, 67647, '\P{Is_Sc=cprt}', "");
Expect(1, 67647, '\P{^Is_Sc=cprt}', "");
Expect(0, 67648, '\p{Is_Sc=cprt}', "");
Expect(1, 67648, '\p{^Is_Sc=cprt}', "");
Expect(1, 67648, '\P{Is_Sc=cprt}', "");
Expect(0, 67648, '\P{^Is_Sc=cprt}', "");
Expect(1, 67647, '\p{Is_Sc=  Cprt}', "");
Expect(0, 67647, '\p{^Is_Sc=  Cprt}', "");
Expect(0, 67647, '\P{Is_Sc=  Cprt}', "");
Expect(1, 67647, '\P{^Is_Sc=  Cprt}', "");
Expect(0, 67648, '\p{Is_Sc=  Cprt}', "");
Expect(1, 67648, '\p{^Is_Sc=  Cprt}', "");
Expect(1, 67648, '\P{Is_Sc=  Cprt}', "");
Expect(0, 67648, '\P{^Is_Sc=  Cprt}', "");
Error('\p{Script=	Cyrillic:=}');
Error('\P{Script=	Cyrillic:=}');
Expect(1, 42655, '\p{Script=cyrillic}', "");
Expect(0, 42655, '\p{^Script=cyrillic}', "");
Expect(0, 42655, '\P{Script=cyrillic}', "");
Expect(1, 42655, '\P{^Script=cyrillic}', "");
Expect(0, 42656, '\p{Script=cyrillic}', "");
Expect(1, 42656, '\p{^Script=cyrillic}', "");
Expect(1, 42656, '\P{Script=cyrillic}', "");
Expect(0, 42656, '\P{^Script=cyrillic}', "");
Expect(1, 42655, '\p{Script=	 CYRILLIC}', "");
Expect(0, 42655, '\p{^Script=	 CYRILLIC}', "");
Expect(0, 42655, '\P{Script=	 CYRILLIC}', "");
Expect(1, 42655, '\P{^Script=	 CYRILLIC}', "");
Expect(0, 42656, '\p{Script=	 CYRILLIC}', "");
Expect(1, 42656, '\p{^Script=	 CYRILLIC}', "");
Expect(1, 42656, '\P{Script=	 CYRILLIC}', "");
Expect(0, 42656, '\P{^Script=	 CYRILLIC}', "");
Error('\p{Sc=/a/		Cyrl}');
Error('\P{Sc=/a/		Cyrl}');
Expect(1, 42655, '\p{Sc=cyrl}', "");
Expect(0, 42655, '\p{^Sc=cyrl}', "");
Expect(0, 42655, '\P{Sc=cyrl}', "");
Expect(1, 42655, '\P{^Sc=cyrl}', "");
Expect(0, 42656, '\p{Sc=cyrl}', "");
Expect(1, 42656, '\p{^Sc=cyrl}', "");
Expect(1, 42656, '\P{Sc=cyrl}', "");
Expect(0, 42656, '\P{^Sc=cyrl}', "");
Expect(1, 42655, '\p{Sc=	-CYRL}', "");
Expect(0, 42655, '\p{^Sc=	-CYRL}', "");
Expect(0, 42655, '\P{Sc=	-CYRL}', "");
Expect(1, 42655, '\P{^Sc=	-CYRL}', "");
Expect(0, 42656, '\p{Sc=	-CYRL}', "");
Expect(1, 42656, '\p{^Sc=	-CYRL}', "");
Expect(1, 42656, '\P{Sc=	-CYRL}', "");
Expect(0, 42656, '\P{^Sc=	-CYRL}', "");
Error('\p{Is_Script=-/a/Cyrillic}');
Error('\P{Is_Script=-/a/Cyrillic}');
Expect(1, 42655, '\p{Is_Script=cyrillic}', "");
Expect(0, 42655, '\p{^Is_Script=cyrillic}', "");
Expect(0, 42655, '\P{Is_Script=cyrillic}', "");
Expect(1, 42655, '\P{^Is_Script=cyrillic}', "");
Expect(0, 42656, '\p{Is_Script=cyrillic}', "");
Expect(1, 42656, '\p{^Is_Script=cyrillic}', "");
Expect(1, 42656, '\P{Is_Script=cyrillic}', "");
Expect(0, 42656, '\P{^Is_Script=cyrillic}', "");
Expect(1, 42655, '\p{Is_Script=	 cyrillic}', "");
Expect(0, 42655, '\p{^Is_Script=	 cyrillic}', "");
Expect(0, 42655, '\P{Is_Script=	 cyrillic}', "");
Expect(1, 42655, '\P{^Is_Script=	 cyrillic}', "");
Expect(0, 42656, '\p{Is_Script=	 cyrillic}', "");
Expect(1, 42656, '\p{^Is_Script=	 cyrillic}', "");
Expect(1, 42656, '\P{Is_Script=	 cyrillic}', "");
Expect(0, 42656, '\P{^Is_Script=	 cyrillic}', "");
Error('\p{Is_Sc= :=CYRL}');
Error('\P{Is_Sc= :=CYRL}');
Expect(1, 42655, '\p{Is_Sc=cyrl}', "");
Expect(0, 42655, '\p{^Is_Sc=cyrl}', "");
Expect(0, 42655, '\P{Is_Sc=cyrl}', "");
Expect(1, 42655, '\P{^Is_Sc=cyrl}', "");
Expect(0, 42656, '\p{Is_Sc=cyrl}', "");
Expect(1, 42656, '\p{^Is_Sc=cyrl}', "");
Expect(1, 42656, '\P{Is_Sc=cyrl}', "");
Expect(0, 42656, '\P{^Is_Sc=cyrl}', "");
Expect(1, 42655, '\p{Is_Sc=__Cyrl}', "");
Expect(0, 42655, '\p{^Is_Sc=__Cyrl}', "");
Expect(0, 42655, '\P{Is_Sc=__Cyrl}', "");
Expect(1, 42655, '\P{^Is_Sc=__Cyrl}', "");
Expect(0, 42656, '\p{Is_Sc=__Cyrl}', "");
Expect(1, 42656, '\p{^Is_Sc=__Cyrl}', "");
Expect(1, 42656, '\P{Is_Sc=__Cyrl}', "");
Expect(0, 42656, '\P{^Is_Sc=__Cyrl}', "");
Error('\p{Script=/a/_Devanagari}');
Error('\P{Script=/a/_Devanagari}');
Expect(1, 43259, '\p{Script=devanagari}', "");
Expect(0, 43259, '\p{^Script=devanagari}', "");
Expect(0, 43259, '\P{Script=devanagari}', "");
Expect(1, 43259, '\P{^Script=devanagari}', "");
Expect(0, 43260, '\p{Script=devanagari}', "");
Expect(1, 43260, '\p{^Script=devanagari}', "");
Expect(1, 43260, '\P{Script=devanagari}', "");
Expect(0, 43260, '\P{^Script=devanagari}', "");
Expect(1, 43259, '\p{Script=	-DEVANAGARI}', "");
Expect(0, 43259, '\p{^Script=	-DEVANAGARI}', "");
Expect(0, 43259, '\P{Script=	-DEVANAGARI}', "");
Expect(1, 43259, '\P{^Script=	-DEVANAGARI}', "");
Expect(0, 43260, '\p{Script=	-DEVANAGARI}', "");
Expect(1, 43260, '\p{^Script=	-DEVANAGARI}', "");
Expect(1, 43260, '\P{Script=	-DEVANAGARI}', "");
Expect(0, 43260, '\P{^Script=	-DEVANAGARI}', "");
Error('\p{Sc= DEVA:=}');
Error('\P{Sc= DEVA:=}');
Expect(1, 43259, '\p{Sc=deva}', "");
Expect(0, 43259, '\p{^Sc=deva}', "");
Expect(0, 43259, '\P{Sc=deva}', "");
Expect(1, 43259, '\P{^Sc=deva}', "");
Expect(0, 43260, '\p{Sc=deva}', "");
Expect(1, 43260, '\p{^Sc=deva}', "");
Expect(1, 43260, '\P{Sc=deva}', "");
Expect(0, 43260, '\P{^Sc=deva}', "");
Expect(1, 43259, '\p{Sc=	-Deva}', "");
Expect(0, 43259, '\p{^Sc=	-Deva}', "");
Expect(0, 43259, '\P{Sc=	-Deva}', "");
Expect(1, 43259, '\P{^Sc=	-Deva}', "");
Expect(0, 43260, '\p{Sc=	-Deva}', "");
Expect(1, 43260, '\p{^Sc=	-Deva}', "");
Expect(1, 43260, '\P{Sc=	-Deva}', "");
Expect(0, 43260, '\P{^Sc=	-Deva}', "");
Error('\p{Is_Script=_ Devanagari/a/}');
Error('\P{Is_Script=_ Devanagari/a/}');
Expect(1, 43259, '\p{Is_Script=devanagari}', "");
Expect(0, 43259, '\p{^Is_Script=devanagari}', "");
Expect(0, 43259, '\P{Is_Script=devanagari}', "");
Expect(1, 43259, '\P{^Is_Script=devanagari}', "");
Expect(0, 43260, '\p{Is_Script=devanagari}', "");
Expect(1, 43260, '\p{^Is_Script=devanagari}', "");
Expect(1, 43260, '\P{Is_Script=devanagari}', "");
Expect(0, 43260, '\P{^Is_Script=devanagari}', "");
Expect(1, 43259, '\p{Is_Script=		Devanagari}', "");
Expect(0, 43259, '\p{^Is_Script=		Devanagari}', "");
Expect(0, 43259, '\P{Is_Script=		Devanagari}', "");
Expect(1, 43259, '\P{^Is_Script=		Devanagari}', "");
Expect(0, 43260, '\p{Is_Script=		Devanagari}', "");
Expect(1, 43260, '\p{^Is_Script=		Devanagari}', "");
Expect(1, 43260, '\P{Is_Script=		Devanagari}', "");
Expect(0, 43260, '\P{^Is_Script=		Devanagari}', "");
Error('\p{Is_Sc=_/a/DEVA}');
Error('\P{Is_Sc=_/a/DEVA}');
Expect(1, 43259, '\p{Is_Sc=deva}', "");
Expect(0, 43259, '\p{^Is_Sc=deva}', "");
Expect(0, 43259, '\P{Is_Sc=deva}', "");
Expect(1, 43259, '\P{^Is_Sc=deva}', "");
Expect(0, 43260, '\p{Is_Sc=deva}', "");
Expect(1, 43260, '\p{^Is_Sc=deva}', "");
Expect(1, 43260, '\P{Is_Sc=deva}', "");
Expect(0, 43260, '\P{^Is_Sc=deva}', "");
Expect(1, 43259, '\p{Is_Sc=__DEVA}', "");
Expect(0, 43259, '\p{^Is_Sc=__DEVA}', "");
Expect(0, 43259, '\P{Is_Sc=__DEVA}', "");
Expect(1, 43259, '\P{^Is_Sc=__DEVA}', "");
Expect(0, 43260, '\p{Is_Sc=__DEVA}', "");
Expect(1, 43260, '\p{^Is_Sc=__DEVA}', "");
Expect(1, 43260, '\P{Is_Sc=__DEVA}', "");
Expect(0, 43260, '\P{^Is_Sc=__DEVA}', "");
Error('\p{Script=	/a/Deseret}');
Error('\P{Script=	/a/Deseret}');
Expect(1, 66639, '\p{Script=deseret}', "");
Expect(0, 66639, '\p{^Script=deseret}', "");
Expect(0, 66639, '\P{Script=deseret}', "");
Expect(1, 66639, '\P{^Script=deseret}', "");
Expect(0, 66640, '\p{Script=deseret}', "");
Expect(1, 66640, '\p{^Script=deseret}', "");
Expect(1, 66640, '\P{Script=deseret}', "");
Expect(0, 66640, '\P{^Script=deseret}', "");
Expect(1, 66639, '\p{Script=-deseret}', "");
Expect(0, 66639, '\p{^Script=-deseret}', "");
Expect(0, 66639, '\P{Script=-deseret}', "");
Expect(1, 66639, '\P{^Script=-deseret}', "");
Expect(0, 66640, '\p{Script=-deseret}', "");
Expect(1, 66640, '\p{^Script=-deseret}', "");
Expect(1, 66640, '\P{Script=-deseret}', "");
Expect(0, 66640, '\P{^Script=-deseret}', "");
Error('\p{Sc= -Dsrt:=}');
Error('\P{Sc= -Dsrt:=}');
Expect(1, 66639, '\p{Sc:   dsrt}', "");
Expect(0, 66639, '\p{^Sc:   dsrt}', "");
Expect(0, 66639, '\P{Sc:   dsrt}', "");
Expect(1, 66639, '\P{^Sc:   dsrt}', "");
Expect(0, 66640, '\p{Sc:   dsrt}', "");
Expect(1, 66640, '\p{^Sc:   dsrt}', "");
Expect(1, 66640, '\P{Sc:   dsrt}', "");
Expect(0, 66640, '\P{^Sc:   dsrt}', "");
Expect(1, 66639, '\p{Sc= _Dsrt}', "");
Expect(0, 66639, '\p{^Sc= _Dsrt}', "");
Expect(0, 66639, '\P{Sc= _Dsrt}', "");
Expect(1, 66639, '\P{^Sc= _Dsrt}', "");
Expect(0, 66640, '\p{Sc= _Dsrt}', "");
Expect(1, 66640, '\p{^Sc= _Dsrt}', "");
Expect(1, 66640, '\P{Sc= _Dsrt}', "");
Expect(0, 66640, '\P{^Sc= _Dsrt}', "");
Error('\p{Is_Script=:=Deseret}');
Error('\P{Is_Script=:=Deseret}');
Expect(1, 66639, '\p{Is_Script=deseret}', "");
Expect(0, 66639, '\p{^Is_Script=deseret}', "");
Expect(0, 66639, '\P{Is_Script=deseret}', "");
Expect(1, 66639, '\P{^Is_Script=deseret}', "");
Expect(0, 66640, '\p{Is_Script=deseret}', "");
Expect(1, 66640, '\p{^Is_Script=deseret}', "");
Expect(1, 66640, '\P{Is_Script=deseret}', "");
Expect(0, 66640, '\P{^Is_Script=deseret}', "");
Expect(1, 66639, '\p{Is_Script=_-Deseret}', "");
Expect(0, 66639, '\p{^Is_Script=_-Deseret}', "");
Expect(0, 66639, '\P{Is_Script=_-Deseret}', "");
Expect(1, 66639, '\P{^Is_Script=_-Deseret}', "");
Expect(0, 66640, '\p{Is_Script=_-Deseret}', "");
Expect(1, 66640, '\p{^Is_Script=_-Deseret}', "");
Expect(1, 66640, '\P{Is_Script=_-Deseret}', "");
Expect(0, 66640, '\P{^Is_Script=_-Deseret}', "");
Error('\p{Is_Sc= :=DSRT}');
Error('\P{Is_Sc= :=DSRT}');
Expect(1, 66639, '\p{Is_Sc=dsrt}', "");
Expect(0, 66639, '\p{^Is_Sc=dsrt}', "");
Expect(0, 66639, '\P{Is_Sc=dsrt}', "");
Expect(1, 66639, '\P{^Is_Sc=dsrt}', "");
Expect(0, 66640, '\p{Is_Sc=dsrt}', "");
Expect(1, 66640, '\p{^Is_Sc=dsrt}', "");
Expect(1, 66640, '\P{Is_Sc=dsrt}', "");
Expect(0, 66640, '\P{^Is_Sc=dsrt}', "");
Expect(1, 66639, '\p{Is_Sc= 	DSRT}', "");
Expect(0, 66639, '\p{^Is_Sc= 	DSRT}', "");
Expect(0, 66639, '\P{Is_Sc= 	DSRT}', "");
Expect(1, 66639, '\P{^Is_Sc= 	DSRT}', "");
Expect(0, 66640, '\p{Is_Sc= 	DSRT}', "");
Expect(1, 66640, '\p{^Is_Sc= 	DSRT}', "");
Expect(1, 66640, '\P{Is_Sc= 	DSRT}', "");
Expect(0, 66640, '\P{^Is_Sc= 	DSRT}', "");
Error('\p{Script=--Egyptian_Hieroglyphs:=}');
Error('\P{Script=--Egyptian_Hieroglyphs:=}');
Expect(1, 78894, '\p{Script=egyptianhieroglyphs}', "");
Expect(0, 78894, '\p{^Script=egyptianhieroglyphs}', "");
Expect(0, 78894, '\P{Script=egyptianhieroglyphs}', "");
Expect(1, 78894, '\P{^Script=egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{Script=egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{^Script=egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{Script=egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{^Script=egyptianhieroglyphs}', "");
Expect(1, 78894, '\p{Script=-_EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78894, '\p{^Script=-_EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78894, '\P{Script=-_EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78894, '\P{^Script=-_EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78895, '\p{Script=-_EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78895, '\p{^Script=-_EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78895, '\P{Script=-_EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78895, '\P{^Script=-_EGYPTIAN_Hieroglyphs}', "");
Error('\p{Sc=/a/--egyp}');
Error('\P{Sc=/a/--egyp}');
Expect(1, 78894, '\p{Sc=egyp}', "");
Expect(0, 78894, '\p{^Sc=egyp}', "");
Expect(0, 78894, '\P{Sc=egyp}', "");
Expect(1, 78894, '\P{^Sc=egyp}', "");
Expect(0, 78895, '\p{Sc=egyp}', "");
Expect(1, 78895, '\p{^Sc=egyp}', "");
Expect(1, 78895, '\P{Sc=egyp}', "");
Expect(0, 78895, '\P{^Sc=egyp}', "");
Expect(1, 78894, '\p{Sc=	EGYP}', "");
Expect(0, 78894, '\p{^Sc=	EGYP}', "");
Expect(0, 78894, '\P{Sc=	EGYP}', "");
Expect(1, 78894, '\P{^Sc=	EGYP}', "");
Expect(0, 78895, '\p{Sc=	EGYP}', "");
Expect(1, 78895, '\p{^Sc=	EGYP}', "");
Expect(1, 78895, '\P{Sc=	EGYP}', "");
Expect(0, 78895, '\P{^Sc=	EGYP}', "");
Error('\p{Is_Script=	/a/Egyptian_hieroglyphs}');
Error('\P{Is_Script=	/a/Egyptian_hieroglyphs}');
Expect(1, 78894, '\p{Is_Script: egyptianhieroglyphs}', "");
Expect(0, 78894, '\p{^Is_Script: egyptianhieroglyphs}', "");
Expect(0, 78894, '\P{Is_Script: egyptianhieroglyphs}', "");
Expect(1, 78894, '\P{^Is_Script: egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{Is_Script: egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{^Is_Script: egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{Is_Script: egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{^Is_Script: egyptianhieroglyphs}', "");
Expect(1, 78894, '\p{Is_Script=_	Egyptian_hieroglyphs}', "");
Expect(0, 78894, '\p{^Is_Script=_	Egyptian_hieroglyphs}', "");
Expect(0, 78894, '\P{Is_Script=_	Egyptian_hieroglyphs}', "");
Expect(1, 78894, '\P{^Is_Script=_	Egyptian_hieroglyphs}', "");
Expect(0, 78895, '\p{Is_Script=_	Egyptian_hieroglyphs}', "");
Expect(1, 78895, '\p{^Is_Script=_	Egyptian_hieroglyphs}', "");
Expect(1, 78895, '\P{Is_Script=_	Egyptian_hieroglyphs}', "");
Expect(0, 78895, '\P{^Is_Script=_	Egyptian_hieroglyphs}', "");
Error('\p{Is_Sc=:=  egyp}');
Error('\P{Is_Sc=:=  egyp}');
Expect(1, 78894, '\p{Is_Sc=egyp}', "");
Expect(0, 78894, '\p{^Is_Sc=egyp}', "");
Expect(0, 78894, '\P{Is_Sc=egyp}', "");
Expect(1, 78894, '\P{^Is_Sc=egyp}', "");
Expect(0, 78895, '\p{Is_Sc=egyp}', "");
Expect(1, 78895, '\p{^Is_Sc=egyp}', "");
Expect(1, 78895, '\P{Is_Sc=egyp}', "");
Expect(0, 78895, '\P{^Is_Sc=egyp}', "");
Expect(1, 78894, '\p{Is_Sc=_-Egyp}', "");
Expect(0, 78894, '\p{^Is_Sc=_-Egyp}', "");
Expect(0, 78894, '\P{Is_Sc=_-Egyp}', "");
Expect(1, 78894, '\P{^Is_Sc=_-Egyp}', "");
Expect(0, 78895, '\p{Is_Sc=_-Egyp}', "");
Expect(1, 78895, '\p{^Is_Sc=_-Egyp}', "");
Expect(1, 78895, '\P{Is_Sc=_-Egyp}', "");
Expect(0, 78895, '\P{^Is_Sc=_-Egyp}', "");
Error('\p{Script=_ethiopic/a/}');
Error('\P{Script=_ethiopic/a/}');
Expect(1, 43822, '\p{Script=ethiopic}', "");
Expect(0, 43822, '\p{^Script=ethiopic}', "");
Expect(0, 43822, '\P{Script=ethiopic}', "");
Expect(1, 43822, '\P{^Script=ethiopic}', "");
Expect(0, 43823, '\p{Script=ethiopic}', "");
Expect(1, 43823, '\p{^Script=ethiopic}', "");
Expect(1, 43823, '\P{Script=ethiopic}', "");
Expect(0, 43823, '\P{^Script=ethiopic}', "");
Expect(1, 43822, '\p{Script= Ethiopic}', "");
Expect(0, 43822, '\p{^Script= Ethiopic}', "");
Expect(0, 43822, '\P{Script= Ethiopic}', "");
Expect(1, 43822, '\P{^Script= Ethiopic}', "");
Expect(0, 43823, '\p{Script= Ethiopic}', "");
Expect(1, 43823, '\p{^Script= Ethiopic}', "");
Expect(1, 43823, '\P{Script= Ethiopic}', "");
Expect(0, 43823, '\P{^Script= Ethiopic}', "");
Error('\p{Sc=:=_-ethi}');
Error('\P{Sc=:=_-ethi}');
Expect(1, 43822, '\p{Sc=ethi}', "");
Expect(0, 43822, '\p{^Sc=ethi}', "");
Expect(0, 43822, '\P{Sc=ethi}', "");
Expect(1, 43822, '\P{^Sc=ethi}', "");
Expect(0, 43823, '\p{Sc=ethi}', "");
Expect(1, 43823, '\p{^Sc=ethi}', "");
Expect(1, 43823, '\P{Sc=ethi}', "");
Expect(0, 43823, '\P{^Sc=ethi}', "");
Expect(1, 43822, '\p{Sc= _ethi}', "");
Expect(0, 43822, '\p{^Sc= _ethi}', "");
Expect(0, 43822, '\P{Sc= _ethi}', "");
Expect(1, 43822, '\P{^Sc= _ethi}', "");
Expect(0, 43823, '\p{Sc= _ethi}', "");
Expect(1, 43823, '\p{^Sc= _ethi}', "");
Expect(1, 43823, '\P{Sc= _ethi}', "");
Expect(0, 43823, '\P{^Sc= _ethi}', "");
Error('\p{Is_Script=_:=Ethiopic}');
Error('\P{Is_Script=_:=Ethiopic}');
Expect(1, 43822, '\p{Is_Script=ethiopic}', "");
Expect(0, 43822, '\p{^Is_Script=ethiopic}', "");
Expect(0, 43822, '\P{Is_Script=ethiopic}', "");
Expect(1, 43822, '\P{^Is_Script=ethiopic}', "");
Expect(0, 43823, '\p{Is_Script=ethiopic}', "");
Expect(1, 43823, '\p{^Is_Script=ethiopic}', "");
Expect(1, 43823, '\P{Is_Script=ethiopic}', "");
Expect(0, 43823, '\P{^Is_Script=ethiopic}', "");
Expect(1, 43822, '\p{Is_Script=-_Ethiopic}', "");
Expect(0, 43822, '\p{^Is_Script=-_Ethiopic}', "");
Expect(0, 43822, '\P{Is_Script=-_Ethiopic}', "");
Expect(1, 43822, '\P{^Is_Script=-_Ethiopic}', "");
Expect(0, 43823, '\p{Is_Script=-_Ethiopic}', "");
Expect(1, 43823, '\p{^Is_Script=-_Ethiopic}', "");
Expect(1, 43823, '\P{Is_Script=-_Ethiopic}', "");
Expect(0, 43823, '\P{^Is_Script=-_Ethiopic}', "");
Error('\p{Is_Sc=-/a/Ethi}');
Error('\P{Is_Sc=-/a/Ethi}');
Expect(1, 43822, '\p{Is_Sc=ethi}', "");
Expect(0, 43822, '\p{^Is_Sc=ethi}', "");
Expect(0, 43822, '\P{Is_Sc=ethi}', "");
Expect(1, 43822, '\P{^Is_Sc=ethi}', "");
Expect(0, 43823, '\p{Is_Sc=ethi}', "");
Expect(1, 43823, '\p{^Is_Sc=ethi}', "");
Expect(1, 43823, '\P{Is_Sc=ethi}', "");
Expect(0, 43823, '\P{^Is_Sc=ethi}', "");
Expect(1, 43822, '\p{Is_Sc=_	ETHI}', "");
Expect(0, 43822, '\p{^Is_Sc=_	ETHI}', "");
Expect(0, 43822, '\P{Is_Sc=_	ETHI}', "");
Expect(1, 43822, '\P{^Is_Sc=_	ETHI}', "");
Expect(0, 43823, '\p{Is_Sc=_	ETHI}', "");
Expect(1, 43823, '\p{^Is_Sc=_	ETHI}', "");
Expect(1, 43823, '\P{Is_Sc=_	ETHI}', "");
Expect(0, 43823, '\P{^Is_Sc=_	ETHI}', "");
Error('\p{Script= georgian:=}');
Error('\P{Script= georgian:=}');
Expect(1, 11565, '\p{Script: georgian}', "");
Expect(0, 11565, '\p{^Script: georgian}', "");
Expect(0, 11565, '\P{Script: georgian}', "");
Expect(1, 11565, '\P{^Script: georgian}', "");
Expect(0, 11566, '\p{Script: georgian}', "");
Expect(1, 11566, '\p{^Script: georgian}', "");
Expect(1, 11566, '\P{Script: georgian}', "");
Expect(0, 11566, '\P{^Script: georgian}', "");
Expect(1, 11565, '\p{Script=_	GEORGIAN}', "");
Expect(0, 11565, '\p{^Script=_	GEORGIAN}', "");
Expect(0, 11565, '\P{Script=_	GEORGIAN}', "");
Expect(1, 11565, '\P{^Script=_	GEORGIAN}', "");
Expect(0, 11566, '\p{Script=_	GEORGIAN}', "");
Expect(1, 11566, '\p{^Script=_	GEORGIAN}', "");
Expect(1, 11566, '\P{Script=_	GEORGIAN}', "");
Expect(0, 11566, '\P{^Script=_	GEORGIAN}', "");
Error('\p{Sc=geor/a/}');
Error('\P{Sc=geor/a/}');
Expect(1, 11565, '\p{Sc=geor}', "");
Expect(0, 11565, '\p{^Sc=geor}', "");
Expect(0, 11565, '\P{Sc=geor}', "");
Expect(1, 11565, '\P{^Sc=geor}', "");
Expect(0, 11566, '\p{Sc=geor}', "");
Expect(1, 11566, '\p{^Sc=geor}', "");
Expect(1, 11566, '\P{Sc=geor}', "");
Expect(0, 11566, '\P{^Sc=geor}', "");
Expect(1, 11565, '\p{Sc= 	geor}', "");
Expect(0, 11565, '\p{^Sc= 	geor}', "");
Expect(0, 11565, '\P{Sc= 	geor}', "");
Expect(1, 11565, '\P{^Sc= 	geor}', "");
Expect(0, 11566, '\p{Sc= 	geor}', "");
Expect(1, 11566, '\p{^Sc= 	geor}', "");
Expect(1, 11566, '\P{Sc= 	geor}', "");
Expect(0, 11566, '\P{^Sc= 	geor}', "");
Error('\p{Is_Script=:=- GEORGIAN}');
Error('\P{Is_Script=:=- GEORGIAN}');
Expect(1, 11565, '\p{Is_Script=georgian}', "");
Expect(0, 11565, '\p{^Is_Script=georgian}', "");
Expect(0, 11565, '\P{Is_Script=georgian}', "");
Expect(1, 11565, '\P{^Is_Script=georgian}', "");
Expect(0, 11566, '\p{Is_Script=georgian}', "");
Expect(1, 11566, '\p{^Is_Script=georgian}', "");
Expect(1, 11566, '\P{Is_Script=georgian}', "");
Expect(0, 11566, '\P{^Is_Script=georgian}', "");
Expect(1, 11565, '\p{Is_Script=_Georgian}', "");
Expect(0, 11565, '\p{^Is_Script=_Georgian}', "");
Expect(0, 11565, '\P{Is_Script=_Georgian}', "");
Expect(1, 11565, '\P{^Is_Script=_Georgian}', "");
Expect(0, 11566, '\p{Is_Script=_Georgian}', "");
Expect(1, 11566, '\p{^Is_Script=_Georgian}', "");
Expect(1, 11566, '\P{Is_Script=_Georgian}', "");
Expect(0, 11566, '\P{^Is_Script=_Georgian}', "");
Error('\p{Is_Sc= :=GEOR}');
Error('\P{Is_Sc= :=GEOR}');
Expect(1, 11565, '\p{Is_Sc=geor}', "");
Expect(0, 11565, '\p{^Is_Sc=geor}', "");
Expect(0, 11565, '\P{Is_Sc=geor}', "");
Expect(1, 11565, '\P{^Is_Sc=geor}', "");
Expect(0, 11566, '\p{Is_Sc=geor}', "");
Expect(1, 11566, '\p{^Is_Sc=geor}', "");
Expect(1, 11566, '\P{Is_Sc=geor}', "");
Expect(0, 11566, '\P{^Is_Sc=geor}', "");
Expect(1, 11565, '\p{Is_Sc=- Geor}', "");
Expect(0, 11565, '\p{^Is_Sc=- Geor}', "");
Expect(0, 11565, '\P{Is_Sc=- Geor}', "");
Expect(1, 11565, '\P{^Is_Sc=- Geor}', "");
Expect(0, 11566, '\p{Is_Sc=- Geor}', "");
Expect(1, 11566, '\p{^Is_Sc=- Geor}', "");
Expect(1, 11566, '\P{Is_Sc=- Geor}', "");
Expect(0, 11566, '\P{^Is_Sc=- Geor}', "");
Error('\p{Script=/a/	 GLAGOLITIC}');
Error('\P{Script=/a/	 GLAGOLITIC}');
Expect(1, 11358, '\p{Script=glagolitic}', "");
Expect(0, 11358, '\p{^Script=glagolitic}', "");
Expect(0, 11358, '\P{Script=glagolitic}', "");
Expect(1, 11358, '\P{^Script=glagolitic}', "");
Expect(0, 11359, '\p{Script=glagolitic}', "");
Expect(1, 11359, '\p{^Script=glagolitic}', "");
Expect(1, 11359, '\P{Script=glagolitic}', "");
Expect(0, 11359, '\P{^Script=glagolitic}', "");
Expect(1, 11358, '\p{Script= _Glagolitic}', "");
Expect(0, 11358, '\p{^Script= _Glagolitic}', "");
Expect(0, 11358, '\P{Script= _Glagolitic}', "");
Expect(1, 11358, '\P{^Script= _Glagolitic}', "");
Expect(0, 11359, '\p{Script= _Glagolitic}', "");
Expect(1, 11359, '\p{^Script= _Glagolitic}', "");
Expect(1, 11359, '\P{Script= _Glagolitic}', "");
Expect(0, 11359, '\P{^Script= _Glagolitic}', "");
Error('\p{Sc=/a/--glag}');
Error('\P{Sc=/a/--glag}');
Expect(1, 11358, '\p{Sc=glag}', "");
Expect(0, 11358, '\p{^Sc=glag}', "");
Expect(0, 11358, '\P{Sc=glag}', "");
Expect(1, 11358, '\P{^Sc=glag}', "");
Expect(0, 11359, '\p{Sc=glag}', "");
Expect(1, 11359, '\p{^Sc=glag}', "");
Expect(1, 11359, '\P{Sc=glag}', "");
Expect(0, 11359, '\P{^Sc=glag}', "");
Expect(1, 11358, '\p{Sc= _Glag}', "");
Expect(0, 11358, '\p{^Sc= _Glag}', "");
Expect(0, 11358, '\P{Sc= _Glag}', "");
Expect(1, 11358, '\P{^Sc= _Glag}', "");
Expect(0, 11359, '\p{Sc= _Glag}', "");
Expect(1, 11359, '\p{^Sc= _Glag}', "");
Expect(1, 11359, '\P{Sc= _Glag}', "");
Expect(0, 11359, '\P{^Sc= _Glag}', "");
Error('\p{Is_Script=  GLAGOLITIC:=}');
Error('\P{Is_Script=  GLAGOLITIC:=}');
Expect(1, 11358, '\p{Is_Script=glagolitic}', "");
Expect(0, 11358, '\p{^Is_Script=glagolitic}', "");
Expect(0, 11358, '\P{Is_Script=glagolitic}', "");
Expect(1, 11358, '\P{^Is_Script=glagolitic}', "");
Expect(0, 11359, '\p{Is_Script=glagolitic}', "");
Expect(1, 11359, '\p{^Is_Script=glagolitic}', "");
Expect(1, 11359, '\P{Is_Script=glagolitic}', "");
Expect(0, 11359, '\P{^Is_Script=glagolitic}', "");
Expect(1, 11358, '\p{Is_Script= 	GLAGOLITIC}', "");
Expect(0, 11358, '\p{^Is_Script= 	GLAGOLITIC}', "");
Expect(0, 11358, '\P{Is_Script= 	GLAGOLITIC}', "");
Expect(1, 11358, '\P{^Is_Script= 	GLAGOLITIC}', "");
Expect(0, 11359, '\p{Is_Script= 	GLAGOLITIC}', "");
Expect(1, 11359, '\p{^Is_Script= 	GLAGOLITIC}', "");
Expect(1, 11359, '\P{Is_Script= 	GLAGOLITIC}', "");
Expect(0, 11359, '\P{^Is_Script= 	GLAGOLITIC}', "");
Error('\p{Is_Sc=-/a/Glag}');
Error('\P{Is_Sc=-/a/Glag}');
Expect(1, 11358, '\p{Is_Sc=glag}', "");
Expect(0, 11358, '\p{^Is_Sc=glag}', "");
Expect(0, 11358, '\P{Is_Sc=glag}', "");
Expect(1, 11358, '\P{^Is_Sc=glag}', "");
Expect(0, 11359, '\p{Is_Sc=glag}', "");
Expect(1, 11359, '\p{^Is_Sc=glag}', "");
Expect(1, 11359, '\P{Is_Sc=glag}', "");
Expect(0, 11359, '\P{^Is_Sc=glag}', "");
Expect(1, 11358, '\p{Is_Sc=	 Glag}', "");
Expect(0, 11358, '\p{^Is_Sc=	 Glag}', "");
Expect(0, 11358, '\P{Is_Sc=	 Glag}', "");
Expect(1, 11358, '\P{^Is_Sc=	 Glag}', "");
Expect(0, 11359, '\p{Is_Sc=	 Glag}', "");
Expect(1, 11359, '\p{^Is_Sc=	 Glag}', "");
Expect(1, 11359, '\P{Is_Sc=	 Glag}', "");
Expect(0, 11359, '\P{^Is_Sc=	 Glag}', "");
Error('\p{Script=/a/-_GOTHIC}');
Error('\P{Script=/a/-_GOTHIC}');
Expect(1, 66378, '\p{Script:   gothic}', "");
Expect(0, 66378, '\p{^Script:   gothic}', "");
Expect(0, 66378, '\P{Script:   gothic}', "");
Expect(1, 66378, '\P{^Script:   gothic}', "");
Expect(0, 66379, '\p{Script:   gothic}', "");
Expect(1, 66379, '\p{^Script:   gothic}', "");
Expect(1, 66379, '\P{Script:   gothic}', "");
Expect(0, 66379, '\P{^Script:   gothic}', "");
Expect(1, 66378, '\p{Script= 	Gothic}', "");
Expect(0, 66378, '\p{^Script= 	Gothic}', "");
Expect(0, 66378, '\P{Script= 	Gothic}', "");
Expect(1, 66378, '\P{^Script= 	Gothic}', "");
Expect(0, 66379, '\p{Script= 	Gothic}', "");
Expect(1, 66379, '\p{^Script= 	Gothic}', "");
Expect(1, 66379, '\P{Script= 	Gothic}', "");
Expect(0, 66379, '\P{^Script= 	Gothic}', "");
Error('\p{Sc=	 Goth/a/}');
Error('\P{Sc=	 Goth/a/}');
Expect(1, 66378, '\p{Sc=goth}', "");
Expect(0, 66378, '\p{^Sc=goth}', "");
Expect(0, 66378, '\P{Sc=goth}', "");
Expect(1, 66378, '\P{^Sc=goth}', "");
Expect(0, 66379, '\p{Sc=goth}', "");
Expect(1, 66379, '\p{^Sc=goth}', "");
Expect(1, 66379, '\P{Sc=goth}', "");
Expect(0, 66379, '\P{^Sc=goth}', "");
Expect(1, 66378, '\p{Sc: _Goth}', "");
Expect(0, 66378, '\p{^Sc: _Goth}', "");
Expect(0, 66378, '\P{Sc: _Goth}', "");
Expect(1, 66378, '\P{^Sc: _Goth}', "");
Expect(0, 66379, '\p{Sc: _Goth}', "");
Expect(1, 66379, '\p{^Sc: _Goth}', "");
Expect(1, 66379, '\P{Sc: _Goth}', "");
Expect(0, 66379, '\P{^Sc: _Goth}', "");
Error('\p{Is_Script=:=-Gothic}');
Error('\P{Is_Script=:=-Gothic}');
Expect(1, 66378, '\p{Is_Script=gothic}', "");
Expect(0, 66378, '\p{^Is_Script=gothic}', "");
Expect(0, 66378, '\P{Is_Script=gothic}', "");
Expect(1, 66378, '\P{^Is_Script=gothic}', "");
Expect(0, 66379, '\p{Is_Script=gothic}', "");
Expect(1, 66379, '\p{^Is_Script=gothic}', "");
Expect(1, 66379, '\P{Is_Script=gothic}', "");
Expect(0, 66379, '\P{^Is_Script=gothic}', "");
Expect(1, 66378, '\p{Is_Script=__GOTHIC}', "");
Expect(0, 66378, '\p{^Is_Script=__GOTHIC}', "");
Expect(0, 66378, '\P{Is_Script=__GOTHIC}', "");
Expect(1, 66378, '\P{^Is_Script=__GOTHIC}', "");
Expect(0, 66379, '\p{Is_Script=__GOTHIC}', "");
Expect(1, 66379, '\p{^Is_Script=__GOTHIC}', "");
Expect(1, 66379, '\P{Is_Script=__GOTHIC}', "");
Expect(0, 66379, '\P{^Is_Script=__GOTHIC}', "");
Error('\p{Is_Sc=/a/_	goth}');
Error('\P{Is_Sc=/a/_	goth}');
Expect(1, 66378, '\p{Is_Sc=goth}', "");
Expect(0, 66378, '\p{^Is_Sc=goth}', "");
Expect(0, 66378, '\P{Is_Sc=goth}', "");
Expect(1, 66378, '\P{^Is_Sc=goth}', "");
Expect(0, 66379, '\p{Is_Sc=goth}', "");
Expect(1, 66379, '\p{^Is_Sc=goth}', "");
Expect(1, 66379, '\P{Is_Sc=goth}', "");
Expect(0, 66379, '\P{^Is_Sc=goth}', "");
Expect(1, 66378, '\p{Is_Sc=- Goth}', "");
Expect(0, 66378, '\p{^Is_Sc=- Goth}', "");
Expect(0, 66378, '\P{Is_Sc=- Goth}', "");
Expect(1, 66378, '\P{^Is_Sc=- Goth}', "");
Expect(0, 66379, '\p{Is_Sc=- Goth}', "");
Expect(1, 66379, '\p{^Is_Sc=- Goth}', "");
Expect(1, 66379, '\P{Is_Sc=- Goth}', "");
Expect(0, 66379, '\P{^Is_Sc=- Goth}', "");
Error('\p{Script=:=		GREEK}');
Error('\P{Script=:=		GREEK}');
Expect(1, 119365, '\p{Script=greek}', "");
Expect(0, 119365, '\p{^Script=greek}', "");
Expect(0, 119365, '\P{Script=greek}', "");
Expect(1, 119365, '\P{^Script=greek}', "");
Expect(0, 119366, '\p{Script=greek}', "");
Expect(1, 119366, '\p{^Script=greek}', "");
Expect(1, 119366, '\P{Script=greek}', "");
Expect(0, 119366, '\P{^Script=greek}', "");
Expect(1, 119365, '\p{Script=  greek}', "");
Expect(0, 119365, '\p{^Script=  greek}', "");
Expect(0, 119365, '\P{Script=  greek}', "");
Expect(1, 119365, '\P{^Script=  greek}', "");
Expect(0, 119366, '\p{Script=  greek}', "");
Expect(1, 119366, '\p{^Script=  greek}', "");
Expect(1, 119366, '\P{Script=  greek}', "");
Expect(0, 119366, '\P{^Script=  greek}', "");
Error('\p{Sc= /a/Grek}');
Error('\P{Sc= /a/Grek}');
Expect(1, 119365, '\p{Sc: grek}', "");
Expect(0, 119365, '\p{^Sc: grek}', "");
Expect(0, 119365, '\P{Sc: grek}', "");
Expect(1, 119365, '\P{^Sc: grek}', "");
Expect(0, 119366, '\p{Sc: grek}', "");
Expect(1, 119366, '\p{^Sc: grek}', "");
Expect(1, 119366, '\P{Sc: grek}', "");
Expect(0, 119366, '\P{^Sc: grek}', "");
Expect(1, 119365, '\p{Sc=-Grek}', "");
Expect(0, 119365, '\p{^Sc=-Grek}', "");
Expect(0, 119365, '\P{Sc=-Grek}', "");
Expect(1, 119365, '\P{^Sc=-Grek}', "");
Expect(0, 119366, '\p{Sc=-Grek}', "");
Expect(1, 119366, '\p{^Sc=-Grek}', "");
Expect(1, 119366, '\P{Sc=-Grek}', "");
Expect(0, 119366, '\P{^Sc=-Grek}', "");
Error('\p{Is_Script=--Greek:=}');
Error('\P{Is_Script=--Greek:=}');
Expect(1, 119365, '\p{Is_Script=greek}', "");
Expect(0, 119365, '\p{^Is_Script=greek}', "");
Expect(0, 119365, '\P{Is_Script=greek}', "");
Expect(1, 119365, '\P{^Is_Script=greek}', "");
Expect(0, 119366, '\p{Is_Script=greek}', "");
Expect(1, 119366, '\p{^Is_Script=greek}', "");
Expect(1, 119366, '\P{Is_Script=greek}', "");
Expect(0, 119366, '\P{^Is_Script=greek}', "");
Expect(1, 119365, '\p{Is_Script= _GREEK}', "");
Expect(0, 119365, '\p{^Is_Script= _GREEK}', "");
Expect(0, 119365, '\P{Is_Script= _GREEK}', "");
Expect(1, 119365, '\P{^Is_Script= _GREEK}', "");
Expect(0, 119366, '\p{Is_Script= _GREEK}', "");
Expect(1, 119366, '\p{^Is_Script= _GREEK}', "");
Expect(1, 119366, '\P{Is_Script= _GREEK}', "");
Expect(0, 119366, '\P{^Is_Script= _GREEK}', "");
Error('\p{Is_Sc=/a/	GREK}');
Error('\P{Is_Sc=/a/	GREK}');
Expect(1, 119365, '\p{Is_Sc=grek}', "");
Expect(0, 119365, '\p{^Is_Sc=grek}', "");
Expect(0, 119365, '\P{Is_Sc=grek}', "");
Expect(1, 119365, '\P{^Is_Sc=grek}', "");
Expect(0, 119366, '\p{Is_Sc=grek}', "");
Expect(1, 119366, '\p{^Is_Sc=grek}', "");
Expect(1, 119366, '\P{Is_Sc=grek}', "");
Expect(0, 119366, '\P{^Is_Sc=grek}', "");
Expect(1, 119365, '\p{Is_Sc=GREK}', "");
Expect(0, 119365, '\p{^Is_Sc=GREK}', "");
Expect(0, 119365, '\P{Is_Sc=GREK}', "");
Expect(1, 119365, '\P{^Is_Sc=GREK}', "");
Expect(0, 119366, '\p{Is_Sc=GREK}', "");
Expect(1, 119366, '\p{^Is_Sc=GREK}', "");
Expect(1, 119366, '\P{Is_Sc=GREK}', "");
Expect(0, 119366, '\P{^Is_Sc=GREK}', "");
Error('\p{Script=/a/__gujarati}');
Error('\P{Script=/a/__gujarati}');
Expect(1, 2801, '\p{Script: gujarati}', "");
Expect(0, 2801, '\p{^Script: gujarati}', "");
Expect(0, 2801, '\P{Script: gujarati}', "");
Expect(1, 2801, '\P{^Script: gujarati}', "");
Expect(0, 2802, '\p{Script: gujarati}', "");
Expect(1, 2802, '\p{^Script: gujarati}', "");
Expect(1, 2802, '\P{Script: gujarati}', "");
Expect(0, 2802, '\P{^Script: gujarati}', "");
Expect(1, 2801, '\p{Script:   _	gujarati}', "");
Expect(0, 2801, '\p{^Script:   _	gujarati}', "");
Expect(0, 2801, '\P{Script:   _	gujarati}', "");
Expect(1, 2801, '\P{^Script:   _	gujarati}', "");
Expect(0, 2802, '\p{Script:   _	gujarati}', "");
Expect(1, 2802, '\p{^Script:   _	gujarati}', "");
Expect(1, 2802, '\P{Script:   _	gujarati}', "");
Expect(0, 2802, '\P{^Script:   _	gujarati}', "");
Error('\p{Sc= -Gujr/a/}');
Error('\P{Sc= -Gujr/a/}');
Expect(1, 2801, '\p{Sc=gujr}', "");
Expect(0, 2801, '\p{^Sc=gujr}', "");
Expect(0, 2801, '\P{Sc=gujr}', "");
Expect(1, 2801, '\P{^Sc=gujr}', "");
Expect(0, 2802, '\p{Sc=gujr}', "");
Expect(1, 2802, '\p{^Sc=gujr}', "");
Expect(1, 2802, '\P{Sc=gujr}', "");
Expect(0, 2802, '\P{^Sc=gujr}', "");
Expect(1, 2801, '\p{Sc=_ GUJR}', "");
Expect(0, 2801, '\p{^Sc=_ GUJR}', "");
Expect(0, 2801, '\P{Sc=_ GUJR}', "");
Expect(1, 2801, '\P{^Sc=_ GUJR}', "");
Expect(0, 2802, '\p{Sc=_ GUJR}', "");
Expect(1, 2802, '\p{^Sc=_ GUJR}', "");
Expect(1, 2802, '\P{Sc=_ GUJR}', "");
Expect(0, 2802, '\P{^Sc=_ GUJR}', "");
Error('\p{Is_Script=_	GUJARATI/a/}');
Error('\P{Is_Script=_	GUJARATI/a/}');
Expect(1, 2801, '\p{Is_Script=gujarati}', "");
Expect(0, 2801, '\p{^Is_Script=gujarati}', "");
Expect(0, 2801, '\P{Is_Script=gujarati}', "");
Expect(1, 2801, '\P{^Is_Script=gujarati}', "");
Expect(0, 2802, '\p{Is_Script=gujarati}', "");
Expect(1, 2802, '\p{^Is_Script=gujarati}', "");
Expect(1, 2802, '\P{Is_Script=gujarati}', "");
Expect(0, 2802, '\P{^Is_Script=gujarati}', "");
Expect(1, 2801, '\p{Is_Script=	-Gujarati}', "");
Expect(0, 2801, '\p{^Is_Script=	-Gujarati}', "");
Expect(0, 2801, '\P{Is_Script=	-Gujarati}', "");
Expect(1, 2801, '\P{^Is_Script=	-Gujarati}', "");
Expect(0, 2802, '\p{Is_Script=	-Gujarati}', "");
Expect(1, 2802, '\p{^Is_Script=	-Gujarati}', "");
Expect(1, 2802, '\P{Is_Script=	-Gujarati}', "");
Expect(0, 2802, '\P{^Is_Script=	-Gujarati}', "");
Error('\p{Is_Sc= :=gujr}');
Error('\P{Is_Sc= :=gujr}');
Expect(1, 2801, '\p{Is_Sc=gujr}', "");
Expect(0, 2801, '\p{^Is_Sc=gujr}', "");
Expect(0, 2801, '\P{Is_Sc=gujr}', "");
Expect(1, 2801, '\P{^Is_Sc=gujr}', "");
Expect(0, 2802, '\p{Is_Sc=gujr}', "");
Expect(1, 2802, '\p{^Is_Sc=gujr}', "");
Expect(1, 2802, '\P{Is_Sc=gujr}', "");
Expect(0, 2802, '\P{^Is_Sc=gujr}', "");
Expect(1, 2801, '\p{Is_Sc=	_GUJR}', "");
Expect(0, 2801, '\p{^Is_Sc=	_GUJR}', "");
Expect(0, 2801, '\P{Is_Sc=	_GUJR}', "");
Expect(1, 2801, '\P{^Is_Sc=	_GUJR}', "");
Expect(0, 2802, '\p{Is_Sc=	_GUJR}', "");
Expect(1, 2802, '\p{^Is_Sc=	_GUJR}', "");
Expect(1, 2802, '\P{Is_Sc=	_GUJR}', "");
Expect(0, 2802, '\P{^Is_Sc=	_GUJR}', "");
Error('\p{Script=/a/	 Gurmukhi}');
Error('\P{Script=/a/	 Gurmukhi}');
Expect(1, 2677, '\p{Script: gurmukhi}', "");
Expect(0, 2677, '\p{^Script: gurmukhi}', "");
Expect(0, 2677, '\P{Script: gurmukhi}', "");
Expect(1, 2677, '\P{^Script: gurmukhi}', "");
Expect(0, 2678, '\p{Script: gurmukhi}', "");
Expect(1, 2678, '\p{^Script: gurmukhi}', "");
Expect(1, 2678, '\P{Script: gurmukhi}', "");
Expect(0, 2678, '\P{^Script: gurmukhi}', "");
Expect(1, 2677, '\p{Script=  gurmukhi}', "");
Expect(0, 2677, '\p{^Script=  gurmukhi}', "");
Expect(0, 2677, '\P{Script=  gurmukhi}', "");
Expect(1, 2677, '\P{^Script=  gurmukhi}', "");
Expect(0, 2678, '\p{Script=  gurmukhi}', "");
Expect(1, 2678, '\p{^Script=  gurmukhi}', "");
Expect(1, 2678, '\P{Script=  gurmukhi}', "");
Expect(0, 2678, '\P{^Script=  gurmukhi}', "");
Error('\p{Sc=:=_	GURU}');
Error('\P{Sc=:=_	GURU}');
Expect(1, 2677, '\p{Sc=guru}', "");
Expect(0, 2677, '\p{^Sc=guru}', "");
Expect(0, 2677, '\P{Sc=guru}', "");
Expect(1, 2677, '\P{^Sc=guru}', "");
Expect(0, 2678, '\p{Sc=guru}', "");
Expect(1, 2678, '\p{^Sc=guru}', "");
Expect(1, 2678, '\P{Sc=guru}', "");
Expect(0, 2678, '\P{^Sc=guru}', "");
Expect(1, 2677, '\p{Sc=-	GURU}', "");
Expect(0, 2677, '\p{^Sc=-	GURU}', "");
Expect(0, 2677, '\P{Sc=-	GURU}', "");
Expect(1, 2677, '\P{^Sc=-	GURU}', "");
Expect(0, 2678, '\p{Sc=-	GURU}', "");
Expect(1, 2678, '\p{^Sc=-	GURU}', "");
Expect(1, 2678, '\P{Sc=-	GURU}', "");
Expect(0, 2678, '\P{^Sc=-	GURU}', "");
Error('\p{Is_Script= :=Gurmukhi}');
Error('\P{Is_Script= :=Gurmukhi}');
Expect(1, 2677, '\p{Is_Script=gurmukhi}', "");
Expect(0, 2677, '\p{^Is_Script=gurmukhi}', "");
Expect(0, 2677, '\P{Is_Script=gurmukhi}', "");
Expect(1, 2677, '\P{^Is_Script=gurmukhi}', "");
Expect(0, 2678, '\p{Is_Script=gurmukhi}', "");
Expect(1, 2678, '\p{^Is_Script=gurmukhi}', "");
Expect(1, 2678, '\P{Is_Script=gurmukhi}', "");
Expect(0, 2678, '\P{^Is_Script=gurmukhi}', "");
Expect(1, 2677, '\p{Is_Script=	-gurmukhi}', "");
Expect(0, 2677, '\p{^Is_Script=	-gurmukhi}', "");
Expect(0, 2677, '\P{Is_Script=	-gurmukhi}', "");
Expect(1, 2677, '\P{^Is_Script=	-gurmukhi}', "");
Expect(0, 2678, '\p{Is_Script=	-gurmukhi}', "");
Expect(1, 2678, '\p{^Is_Script=	-gurmukhi}', "");
Expect(1, 2678, '\P{Is_Script=	-gurmukhi}', "");
Expect(0, 2678, '\P{^Is_Script=	-gurmukhi}', "");
Error('\p{Is_Sc=/a/--guru}');
Error('\P{Is_Sc=/a/--guru}');
Expect(1, 2677, '\p{Is_Sc=guru}', "");
Expect(0, 2677, '\p{^Is_Sc=guru}', "");
Expect(0, 2677, '\P{Is_Sc=guru}', "");
Expect(1, 2677, '\P{^Is_Sc=guru}', "");
Expect(0, 2678, '\p{Is_Sc=guru}', "");
Expect(1, 2678, '\p{^Is_Sc=guru}', "");
Expect(1, 2678, '\P{Is_Sc=guru}', "");
Expect(0, 2678, '\P{^Is_Sc=guru}', "");
Expect(1, 2677, '\p{Is_Sc= Guru}', "");
Expect(0, 2677, '\p{^Is_Sc= Guru}', "");
Expect(0, 2677, '\P{Is_Sc= Guru}', "");
Expect(1, 2677, '\P{^Is_Sc= Guru}', "");
Expect(0, 2678, '\p{Is_Sc= Guru}', "");
Expect(1, 2678, '\p{^Is_Sc= Guru}', "");
Expect(1, 2678, '\P{Is_Sc= Guru}', "");
Expect(0, 2678, '\P{^Is_Sc= Guru}', "");
Error('\p{Script=	:=Hangul}');
Error('\P{Script=	:=Hangul}');
Expect(1, 65500, '\p{Script: hangul}', "");
Expect(0, 65500, '\p{^Script: hangul}', "");
Expect(0, 65500, '\P{Script: hangul}', "");
Expect(1, 65500, '\P{^Script: hangul}', "");
Expect(0, 65501, '\p{Script: hangul}', "");
Expect(1, 65501, '\p{^Script: hangul}', "");
Expect(1, 65501, '\P{Script: hangul}', "");
Expect(0, 65501, '\P{^Script: hangul}', "");
Expect(1, 65500, '\p{Script=	hangul}', "");
Expect(0, 65500, '\p{^Script=	hangul}', "");
Expect(0, 65500, '\P{Script=	hangul}', "");
Expect(1, 65500, '\P{^Script=	hangul}', "");
Expect(0, 65501, '\p{Script=	hangul}', "");
Expect(1, 65501, '\p{^Script=	hangul}', "");
Expect(1, 65501, '\P{Script=	hangul}', "");
Expect(0, 65501, '\P{^Script=	hangul}', "");
Error('\p{Sc=-HANG:=}');
Error('\P{Sc=-HANG:=}');
Expect(1, 65500, '\p{Sc=hang}', "");
Expect(0, 65500, '\p{^Sc=hang}', "");
Expect(0, 65500, '\P{Sc=hang}', "");
Expect(1, 65500, '\P{^Sc=hang}', "");
Expect(0, 65501, '\p{Sc=hang}', "");
Expect(1, 65501, '\p{^Sc=hang}', "");
Expect(1, 65501, '\P{Sc=hang}', "");
Expect(0, 65501, '\P{^Sc=hang}', "");
Expect(1, 65500, '\p{Sc=_-HANG}', "");
Expect(0, 65500, '\p{^Sc=_-HANG}', "");
Expect(0, 65500, '\P{Sc=_-HANG}', "");
Expect(1, 65500, '\P{^Sc=_-HANG}', "");
Expect(0, 65501, '\p{Sc=_-HANG}', "");
Expect(1, 65501, '\p{^Sc=_-HANG}', "");
Expect(1, 65501, '\P{Sc=_-HANG}', "");
Expect(0, 65501, '\P{^Sc=_-HANG}', "");
Error('\p{Is_Script=-HANGUL:=}');
Error('\P{Is_Script=-HANGUL:=}');
Expect(1, 65500, '\p{Is_Script=hangul}', "");
Expect(0, 65500, '\p{^Is_Script=hangul}', "");
Expect(0, 65500, '\P{Is_Script=hangul}', "");
Expect(1, 65500, '\P{^Is_Script=hangul}', "");
Expect(0, 65501, '\p{Is_Script=hangul}', "");
Expect(1, 65501, '\p{^Is_Script=hangul}', "");
Expect(1, 65501, '\P{Is_Script=hangul}', "");
Expect(0, 65501, '\P{^Is_Script=hangul}', "");
Expect(1, 65500, '\p{Is_Script=-HANGUL}', "");
Expect(0, 65500, '\p{^Is_Script=-HANGUL}', "");
Expect(0, 65500, '\P{Is_Script=-HANGUL}', "");
Expect(1, 65500, '\P{^Is_Script=-HANGUL}', "");
Expect(0, 65501, '\p{Is_Script=-HANGUL}', "");
Expect(1, 65501, '\p{^Is_Script=-HANGUL}', "");
Expect(1, 65501, '\P{Is_Script=-HANGUL}', "");
Expect(0, 65501, '\P{^Is_Script=-HANGUL}', "");
Error('\p{Is_Sc=	/a/hang}');
Error('\P{Is_Sc=	/a/hang}');
Expect(1, 65500, '\p{Is_Sc=hang}', "");
Expect(0, 65500, '\p{^Is_Sc=hang}', "");
Expect(0, 65500, '\P{Is_Sc=hang}', "");
Expect(1, 65500, '\P{^Is_Sc=hang}', "");
Expect(0, 65501, '\p{Is_Sc=hang}', "");
Expect(1, 65501, '\p{^Is_Sc=hang}', "");
Expect(1, 65501, '\P{Is_Sc=hang}', "");
Expect(0, 65501, '\P{^Is_Sc=hang}', "");
Expect(1, 65500, '\p{Is_Sc=_	hang}', "");
Expect(0, 65500, '\p{^Is_Sc=_	hang}', "");
Expect(0, 65500, '\P{Is_Sc=_	hang}', "");
Expect(1, 65500, '\P{^Is_Sc=_	hang}', "");
Expect(0, 65501, '\p{Is_Sc=_	hang}', "");
Expect(1, 65501, '\p{^Is_Sc=_	hang}', "");
Expect(1, 65501, '\P{Is_Sc=_	hang}', "");
Expect(0, 65501, '\P{^Is_Sc=_	hang}', "");
Error('\p{Script=:= _Han}');
Error('\P{Script=:= _Han}');
Expect(1, 195101, '\p{Script=han}', "");
Expect(0, 195101, '\p{^Script=han}', "");
Expect(0, 195101, '\P{Script=han}', "");
Expect(1, 195101, '\P{^Script=han}', "");
Expect(0, 195102, '\p{Script=han}', "");
Expect(1, 195102, '\p{^Script=han}', "");
Expect(1, 195102, '\P{Script=han}', "");
Expect(0, 195102, '\P{^Script=han}', "");
Expect(1, 195101, '\p{Script= -Han}', "");
Expect(0, 195101, '\p{^Script= -Han}', "");
Expect(0, 195101, '\P{Script= -Han}', "");
Expect(1, 195101, '\P{^Script= -Han}', "");
Expect(0, 195102, '\p{Script= -Han}', "");
Expect(1, 195102, '\p{^Script= -Han}', "");
Expect(1, 195102, '\P{Script= -Han}', "");
Expect(0, 195102, '\P{^Script= -Han}', "");
Error('\p{Sc=/a/HANI}');
Error('\P{Sc=/a/HANI}');
Expect(1, 195101, '\p{Sc=hani}', "");
Expect(0, 195101, '\p{^Sc=hani}', "");
Expect(0, 195101, '\P{Sc=hani}', "");
Expect(1, 195101, '\P{^Sc=hani}', "");
Expect(0, 195102, '\p{Sc=hani}', "");
Expect(1, 195102, '\p{^Sc=hani}', "");
Expect(1, 195102, '\P{Sc=hani}', "");
Expect(0, 195102, '\P{^Sc=hani}', "");
Expect(1, 195101, '\p{Sc=  Hani}', "");
Expect(0, 195101, '\p{^Sc=  Hani}', "");
Expect(0, 195101, '\P{Sc=  Hani}', "");
Expect(1, 195101, '\P{^Sc=  Hani}', "");
Expect(0, 195102, '\p{Sc=  Hani}', "");
Expect(1, 195102, '\p{^Sc=  Hani}', "");
Expect(1, 195102, '\P{Sc=  Hani}', "");
Expect(0, 195102, '\P{^Sc=  Hani}', "");
Error('\p{Is_Script=-Han:=}');
Error('\P{Is_Script=-Han:=}');
Expect(1, 195101, '\p{Is_Script=han}', "");
Expect(0, 195101, '\p{^Is_Script=han}', "");
Expect(0, 195101, '\P{Is_Script=han}', "");
Expect(1, 195101, '\P{^Is_Script=han}', "");
Expect(0, 195102, '\p{Is_Script=han}', "");
Expect(1, 195102, '\p{^Is_Script=han}', "");
Expect(1, 195102, '\P{Is_Script=han}', "");
Expect(0, 195102, '\P{^Is_Script=han}', "");
Expect(1, 195101, '\p{Is_Script=- han}', "");
Expect(0, 195101, '\p{^Is_Script=- han}', "");
Expect(0, 195101, '\P{Is_Script=- han}', "");
Expect(1, 195101, '\P{^Is_Script=- han}', "");
Expect(0, 195102, '\p{Is_Script=- han}', "");
Expect(1, 195102, '\p{^Is_Script=- han}', "");
Expect(1, 195102, '\P{Is_Script=- han}', "");
Expect(0, 195102, '\P{^Is_Script=- han}', "");
Error('\p{Is_Sc:_ Hani:=}');
Error('\P{Is_Sc:_ Hani:=}');
Expect(1, 195101, '\p{Is_Sc=hani}', "");
Expect(0, 195101, '\p{^Is_Sc=hani}', "");
Expect(0, 195101, '\P{Is_Sc=hani}', "");
Expect(1, 195101, '\P{^Is_Sc=hani}', "");
Expect(0, 195102, '\p{Is_Sc=hani}', "");
Expect(1, 195102, '\p{^Is_Sc=hani}', "");
Expect(1, 195102, '\P{Is_Sc=hani}', "");
Expect(0, 195102, '\P{^Is_Sc=hani}', "");
Expect(1, 195101, '\p{Is_Sc= _Hani}', "");
Expect(0, 195101, '\p{^Is_Sc= _Hani}', "");
Expect(0, 195101, '\P{Is_Sc= _Hani}', "");
Expect(1, 195101, '\P{^Is_Sc= _Hani}', "");
Expect(0, 195102, '\p{Is_Sc= _Hani}', "");
Expect(1, 195102, '\p{^Is_Sc= _Hani}', "");
Expect(1, 195102, '\P{Is_Sc= _Hani}', "");
Expect(0, 195102, '\P{^Is_Sc= _Hani}', "");
Error('\p{Script=Hanunoo/a/}');
Error('\P{Script=Hanunoo/a/}');
Expect(1, 5940, '\p{Script=hanunoo}', "");
Expect(0, 5940, '\p{^Script=hanunoo}', "");
Expect(0, 5940, '\P{Script=hanunoo}', "");
Expect(1, 5940, '\P{^Script=hanunoo}', "");
Expect(0, 5941, '\p{Script=hanunoo}', "");
Expect(1, 5941, '\p{^Script=hanunoo}', "");
Expect(1, 5941, '\P{Script=hanunoo}', "");
Expect(0, 5941, '\P{^Script=hanunoo}', "");
Expect(1, 5940, '\p{Script=		Hanunoo}', "");
Expect(0, 5940, '\p{^Script=		Hanunoo}', "");
Expect(0, 5940, '\P{Script=		Hanunoo}', "");
Expect(1, 5940, '\P{^Script=		Hanunoo}', "");
Expect(0, 5941, '\p{Script=		Hanunoo}', "");
Expect(1, 5941, '\p{^Script=		Hanunoo}', "");
Expect(1, 5941, '\P{Script=		Hanunoo}', "");
Expect(0, 5941, '\P{^Script=		Hanunoo}', "");
Error('\p{Sc=_/a/hano}');
Error('\P{Sc=_/a/hano}');
Expect(1, 5940, '\p{Sc=hano}', "");
Expect(0, 5940, '\p{^Sc=hano}', "");
Expect(0, 5940, '\P{Sc=hano}', "");
Expect(1, 5940, '\P{^Sc=hano}', "");
Expect(0, 5941, '\p{Sc=hano}', "");
Expect(1, 5941, '\p{^Sc=hano}', "");
Expect(1, 5941, '\P{Sc=hano}', "");
Expect(0, 5941, '\P{^Sc=hano}', "");
Expect(1, 5940, '\p{Sc=--HANO}', "");
Expect(0, 5940, '\p{^Sc=--HANO}', "");
Expect(0, 5940, '\P{Sc=--HANO}', "");
Expect(1, 5940, '\P{^Sc=--HANO}', "");
Expect(0, 5941, '\p{Sc=--HANO}', "");
Expect(1, 5941, '\p{^Sc=--HANO}', "");
Expect(1, 5941, '\P{Sc=--HANO}', "");
Expect(0, 5941, '\P{^Sc=--HANO}', "");
Error('\p{Is_Script= _hanunoo:=}');
Error('\P{Is_Script= _hanunoo:=}');
Expect(1, 5940, '\p{Is_Script=hanunoo}', "");
Expect(0, 5940, '\p{^Is_Script=hanunoo}', "");
Expect(0, 5940, '\P{Is_Script=hanunoo}', "");
Expect(1, 5940, '\P{^Is_Script=hanunoo}', "");
Expect(0, 5941, '\p{Is_Script=hanunoo}', "");
Expect(1, 5941, '\p{^Is_Script=hanunoo}', "");
Expect(1, 5941, '\P{Is_Script=hanunoo}', "");
Expect(0, 5941, '\P{^Is_Script=hanunoo}', "");
Expect(1, 5940, '\p{Is_Script=_Hanunoo}', "");
Expect(0, 5940, '\p{^Is_Script=_Hanunoo}', "");
Expect(0, 5940, '\P{Is_Script=_Hanunoo}', "");
Expect(1, 5940, '\P{^Is_Script=_Hanunoo}', "");
Expect(0, 5941, '\p{Is_Script=_Hanunoo}', "");
Expect(1, 5941, '\p{^Is_Script=_Hanunoo}', "");
Expect(1, 5941, '\P{Is_Script=_Hanunoo}', "");
Expect(0, 5941, '\P{^Is_Script=_Hanunoo}', "");
Error('\p{Is_Sc=_Hano:=}');
Error('\P{Is_Sc=_Hano:=}');
Expect(1, 5940, '\p{Is_Sc=hano}', "");
Expect(0, 5940, '\p{^Is_Sc=hano}', "");
Expect(0, 5940, '\P{Is_Sc=hano}', "");
Expect(1, 5940, '\P{^Is_Sc=hano}', "");
Expect(0, 5941, '\p{Is_Sc=hano}', "");
Expect(1, 5941, '\p{^Is_Sc=hano}', "");
Expect(1, 5941, '\P{Is_Sc=hano}', "");
Expect(0, 5941, '\P{^Is_Sc=hano}', "");
Expect(1, 5940, '\p{Is_Sc:	 _HANO}', "");
Expect(0, 5940, '\p{^Is_Sc:	 _HANO}', "");
Expect(0, 5940, '\P{Is_Sc:	 _HANO}', "");
Expect(1, 5940, '\P{^Is_Sc:	 _HANO}', "");
Expect(0, 5941, '\p{Is_Sc:	 _HANO}', "");
Expect(1, 5941, '\p{^Is_Sc:	 _HANO}', "");
Expect(1, 5941, '\P{Is_Sc:	 _HANO}', "");
Expect(0, 5941, '\P{^Is_Sc:	 _HANO}', "");
Error('\p{Script=/a/Hebrew}');
Error('\P{Script=/a/Hebrew}');
Expect(1, 64335, '\p{Script=hebrew}', "");
Expect(0, 64335, '\p{^Script=hebrew}', "");
Expect(0, 64335, '\P{Script=hebrew}', "");
Expect(1, 64335, '\P{^Script=hebrew}', "");
Expect(0, 64336, '\p{Script=hebrew}', "");
Expect(1, 64336, '\p{^Script=hebrew}', "");
Expect(1, 64336, '\P{Script=hebrew}', "");
Expect(0, 64336, '\P{^Script=hebrew}', "");
Expect(1, 64335, '\p{Script=_	HEBREW}', "");
Expect(0, 64335, '\p{^Script=_	HEBREW}', "");
Expect(0, 64335, '\P{Script=_	HEBREW}', "");
Expect(1, 64335, '\P{^Script=_	HEBREW}', "");
Expect(0, 64336, '\p{Script=_	HEBREW}', "");
Expect(1, 64336, '\p{^Script=_	HEBREW}', "");
Expect(1, 64336, '\P{Script=_	HEBREW}', "");
Expect(0, 64336, '\P{^Script=_	HEBREW}', "");
Error('\p{Sc=	 Hebr/a/}');
Error('\P{Sc=	 Hebr/a/}');
Expect(1, 64335, '\p{Sc=hebr}', "");
Expect(0, 64335, '\p{^Sc=hebr}', "");
Expect(0, 64335, '\P{Sc=hebr}', "");
Expect(1, 64335, '\P{^Sc=hebr}', "");
Expect(0, 64336, '\p{Sc=hebr}', "");
Expect(1, 64336, '\p{^Sc=hebr}', "");
Expect(1, 64336, '\P{Sc=hebr}', "");
Expect(0, 64336, '\P{^Sc=hebr}', "");
Expect(1, 64335, '\p{Sc=		Hebr}', "");
Expect(0, 64335, '\p{^Sc=		Hebr}', "");
Expect(0, 64335, '\P{Sc=		Hebr}', "");
Expect(1, 64335, '\P{^Sc=		Hebr}', "");
Expect(0, 64336, '\p{Sc=		Hebr}', "");
Expect(1, 64336, '\p{^Sc=		Hebr}', "");
Expect(1, 64336, '\P{Sc=		Hebr}', "");
Expect(0, 64336, '\P{^Sc=		Hebr}', "");
Error('\p{Is_Script=/a/_	hebrew}');
Error('\P{Is_Script=/a/_	hebrew}');
Expect(1, 64335, '\p{Is_Script=hebrew}', "");
Expect(0, 64335, '\p{^Is_Script=hebrew}', "");
Expect(0, 64335, '\P{Is_Script=hebrew}', "");
Expect(1, 64335, '\P{^Is_Script=hebrew}', "");
Expect(0, 64336, '\p{Is_Script=hebrew}', "");
Expect(1, 64336, '\p{^Is_Script=hebrew}', "");
Expect(1, 64336, '\P{Is_Script=hebrew}', "");
Expect(0, 64336, '\P{^Is_Script=hebrew}', "");
Expect(1, 64335, '\p{Is_Script=_	Hebrew}', "");
Expect(0, 64335, '\p{^Is_Script=_	Hebrew}', "");
Expect(0, 64335, '\P{Is_Script=_	Hebrew}', "");
Expect(1, 64335, '\P{^Is_Script=_	Hebrew}', "");
Expect(0, 64336, '\p{Is_Script=_	Hebrew}', "");
Expect(1, 64336, '\p{^Is_Script=_	Hebrew}', "");
Expect(1, 64336, '\P{Is_Script=_	Hebrew}', "");
Expect(0, 64336, '\P{^Is_Script=_	Hebrew}', "");
Error('\p{Is_Sc= :=Hebr}');
Error('\P{Is_Sc= :=Hebr}');
Expect(1, 64335, '\p{Is_Sc=hebr}', "");
Expect(0, 64335, '\p{^Is_Sc=hebr}', "");
Expect(0, 64335, '\P{Is_Sc=hebr}', "");
Expect(1, 64335, '\P{^Is_Sc=hebr}', "");
Expect(0, 64336, '\p{Is_Sc=hebr}', "");
Expect(1, 64336, '\p{^Is_Sc=hebr}', "");
Expect(1, 64336, '\P{Is_Sc=hebr}', "");
Expect(0, 64336, '\P{^Is_Sc=hebr}', "");
Expect(1, 64335, '\p{Is_Sc=	HEBR}', "");
Expect(0, 64335, '\p{^Is_Sc=	HEBR}', "");
Expect(0, 64335, '\P{Is_Sc=	HEBR}', "");
Expect(1, 64335, '\P{^Is_Sc=	HEBR}', "");
Expect(0, 64336, '\p{Is_Sc=	HEBR}', "");
Expect(1, 64336, '\p{^Is_Sc=	HEBR}', "");
Expect(1, 64336, '\P{Is_Sc=	HEBR}', "");
Expect(0, 64336, '\P{^Is_Sc=	HEBR}', "");
Error('\p{Script=/a/	-hiragana}');
Error('\P{Script=/a/	-hiragana}');
Expect(1, 127488, '\p{Script:hiragana}', "");
Expect(0, 127488, '\p{^Script:hiragana}', "");
Expect(0, 127488, '\P{Script:hiragana}', "");
Expect(1, 127488, '\P{^Script:hiragana}', "");
Expect(0, 127489, '\p{Script:hiragana}', "");
Expect(1, 127489, '\p{^Script:hiragana}', "");
Expect(1, 127489, '\P{Script:hiragana}', "");
Expect(0, 127489, '\P{^Script:hiragana}', "");
Expect(1, 127488, '\p{Script=-hiragana}', "");
Expect(0, 127488, '\p{^Script=-hiragana}', "");
Expect(0, 127488, '\P{Script=-hiragana}', "");
Expect(1, 127488, '\P{^Script=-hiragana}', "");
Expect(0, 127489, '\p{Script=-hiragana}', "");
Expect(1, 127489, '\p{^Script=-hiragana}', "");
Expect(1, 127489, '\P{Script=-hiragana}', "");
Expect(0, 127489, '\P{^Script=-hiragana}', "");
Error('\p{Sc=:=_-hira}');
Error('\P{Sc=:=_-hira}');
Expect(1, 127488, '\p{Sc=hira}', "");
Expect(0, 127488, '\p{^Sc=hira}', "");
Expect(0, 127488, '\P{Sc=hira}', "");
Expect(1, 127488, '\P{^Sc=hira}', "");
Expect(0, 127489, '\p{Sc=hira}', "");
Expect(1, 127489, '\p{^Sc=hira}', "");
Expect(1, 127489, '\P{Sc=hira}', "");
Expect(0, 127489, '\P{^Sc=hira}', "");
Expect(1, 127488, '\p{Sc=		Hira}', "");
Expect(0, 127488, '\p{^Sc=		Hira}', "");
Expect(0, 127488, '\P{Sc=		Hira}', "");
Expect(1, 127488, '\P{^Sc=		Hira}', "");
Expect(0, 127489, '\p{Sc=		Hira}', "");
Expect(1, 127489, '\p{^Sc=		Hira}', "");
Expect(1, 127489, '\P{Sc=		Hira}', "");
Expect(0, 127489, '\P{^Sc=		Hira}', "");
Error('\p{Is_Script=HIRAGANA/a/}');
Error('\P{Is_Script=HIRAGANA/a/}');
Expect(1, 127488, '\p{Is_Script=hiragana}', "");
Expect(0, 127488, '\p{^Is_Script=hiragana}', "");
Expect(0, 127488, '\P{Is_Script=hiragana}', "");
Expect(1, 127488, '\P{^Is_Script=hiragana}', "");
Expect(0, 127489, '\p{Is_Script=hiragana}', "");
Expect(1, 127489, '\p{^Is_Script=hiragana}', "");
Expect(1, 127489, '\P{Is_Script=hiragana}', "");
Expect(0, 127489, '\P{^Is_Script=hiragana}', "");
Expect(1, 127488, '\p{Is_Script=_Hiragana}', "");
Expect(0, 127488, '\p{^Is_Script=_Hiragana}', "");
Expect(0, 127488, '\P{Is_Script=_Hiragana}', "");
Expect(1, 127488, '\P{^Is_Script=_Hiragana}', "");
Expect(0, 127489, '\p{Is_Script=_Hiragana}', "");
Expect(1, 127489, '\p{^Is_Script=_Hiragana}', "");
Expect(1, 127489, '\P{Is_Script=_Hiragana}', "");
Expect(0, 127489, '\P{^Is_Script=_Hiragana}', "");
Error('\p{Is_Sc= Hira/a/}');
Error('\P{Is_Sc= Hira/a/}');
Expect(1, 127488, '\p{Is_Sc=hira}', "");
Expect(0, 127488, '\p{^Is_Sc=hira}', "");
Expect(0, 127488, '\P{Is_Sc=hira}', "");
Expect(1, 127488, '\P{^Is_Sc=hira}', "");
Expect(0, 127489, '\p{Is_Sc=hira}', "");
Expect(1, 127489, '\p{^Is_Sc=hira}', "");
Expect(1, 127489, '\P{Is_Sc=hira}', "");
Expect(0, 127489, '\P{^Is_Sc=hira}', "");
Expect(1, 127488, '\p{Is_Sc=__HIRA}', "");
Expect(0, 127488, '\p{^Is_Sc=__HIRA}', "");
Expect(0, 127488, '\P{Is_Sc=__HIRA}', "");
Expect(1, 127488, '\P{^Is_Sc=__HIRA}', "");
Expect(0, 127489, '\p{Is_Sc=__HIRA}', "");
Expect(1, 127489, '\p{^Is_Sc=__HIRA}', "");
Expect(1, 127489, '\P{Is_Sc=__HIRA}', "");
Expect(0, 127489, '\P{^Is_Sc=__HIRA}', "");
Error('\p{Script=Katakana_Or_Hiragana}');
Error('\P{Script=Katakana_Or_Hiragana}');
Error('\p{Sc=Hrkt}');
Error('\P{Sc=Hrkt}');
Error('\p{Is_Script=Katakana_Or_Hiragana}');
Error('\P{Is_Script=Katakana_Or_Hiragana}');
Error('\p{Is_Sc:	Hrkt}');
Error('\P{Is_Sc:	Hrkt}');
Error('\p{Script=-	old_Italic:=}');
Error('\P{Script=-	old_Italic:=}');
Expect(1, 66339, '\p{Script:olditalic}', "");
Expect(0, 66339, '\p{^Script:olditalic}', "");
Expect(0, 66339, '\P{Script:olditalic}', "");
Expect(1, 66339, '\P{^Script:olditalic}', "");
Expect(0, 66340, '\p{Script:olditalic}', "");
Expect(1, 66340, '\p{^Script:olditalic}', "");
Expect(1, 66340, '\P{Script:olditalic}', "");
Expect(0, 66340, '\P{^Script:olditalic}', "");
Expect(1, 66339, '\p{Script=--old_italic}', "");
Expect(0, 66339, '\p{^Script=--old_italic}', "");
Expect(0, 66339, '\P{Script=--old_italic}', "");
Expect(1, 66339, '\P{^Script=--old_italic}', "");
Expect(0, 66340, '\p{Script=--old_italic}', "");
Expect(1, 66340, '\p{^Script=--old_italic}', "");
Expect(1, 66340, '\P{Script=--old_italic}', "");
Expect(0, 66340, '\P{^Script=--old_italic}', "");
Error('\p{Sc=_:=Ital}');
Error('\P{Sc=_:=Ital}');
Expect(1, 66339, '\p{Sc=ital}', "");
Expect(0, 66339, '\p{^Sc=ital}', "");
Expect(0, 66339, '\P{Sc=ital}', "");
Expect(1, 66339, '\P{^Sc=ital}', "");
Expect(0, 66340, '\p{Sc=ital}', "");
Expect(1, 66340, '\p{^Sc=ital}', "");
Expect(1, 66340, '\P{Sc=ital}', "");
Expect(0, 66340, '\P{^Sc=ital}', "");
Expect(1, 66339, '\p{Sc=--Ital}', "");
Expect(0, 66339, '\p{^Sc=--Ital}', "");
Expect(0, 66339, '\P{Sc=--Ital}', "");
Expect(1, 66339, '\P{^Sc=--Ital}', "");
Expect(0, 66340, '\p{Sc=--Ital}', "");
Expect(1, 66340, '\p{^Sc=--Ital}', "");
Expect(1, 66340, '\P{Sc=--Ital}', "");
Expect(0, 66340, '\P{^Sc=--Ital}', "");
Error('\p{Is_Script=	_Old_ITALIC/a/}');
Error('\P{Is_Script=	_Old_ITALIC/a/}');
Expect(1, 66339, '\p{Is_Script=olditalic}', "");
Expect(0, 66339, '\p{^Is_Script=olditalic}', "");
Expect(0, 66339, '\P{Is_Script=olditalic}', "");
Expect(1, 66339, '\P{^Is_Script=olditalic}', "");
Expect(0, 66340, '\p{Is_Script=olditalic}', "");
Expect(1, 66340, '\p{^Is_Script=olditalic}', "");
Expect(1, 66340, '\P{Is_Script=olditalic}', "");
Expect(0, 66340, '\P{^Is_Script=olditalic}', "");
Expect(1, 66339, '\p{Is_Script=--OLD_Italic}', "");
Expect(0, 66339, '\p{^Is_Script=--OLD_Italic}', "");
Expect(0, 66339, '\P{Is_Script=--OLD_Italic}', "");
Expect(1, 66339, '\P{^Is_Script=--OLD_Italic}', "");
Expect(0, 66340, '\p{Is_Script=--OLD_Italic}', "");
Expect(1, 66340, '\p{^Is_Script=--OLD_Italic}', "");
Expect(1, 66340, '\P{Is_Script=--OLD_Italic}', "");
Expect(0, 66340, '\P{^Is_Script=--OLD_Italic}', "");
Error('\p{Is_Sc=/a/__Ital}');
Error('\P{Is_Sc=/a/__Ital}');
Expect(1, 66339, '\p{Is_Sc=ital}', "");
Expect(0, 66339, '\p{^Is_Sc=ital}', "");
Expect(0, 66339, '\P{Is_Sc=ital}', "");
Expect(1, 66339, '\P{^Is_Sc=ital}', "");
Expect(0, 66340, '\p{Is_Sc=ital}', "");
Expect(1, 66340, '\p{^Is_Sc=ital}', "");
Expect(1, 66340, '\P{Is_Sc=ital}', "");
Expect(0, 66340, '\P{^Is_Sc=ital}', "");
Expect(1, 66339, '\p{Is_Sc= -Ital}', "");
Expect(0, 66339, '\p{^Is_Sc= -Ital}', "");
Expect(0, 66339, '\P{Is_Sc= -Ital}', "");
Expect(1, 66339, '\P{^Is_Sc= -Ital}', "");
Expect(0, 66340, '\p{Is_Sc= -Ital}', "");
Expect(1, 66340, '\p{^Is_Sc= -Ital}', "");
Expect(1, 66340, '\P{Is_Sc= -Ital}', "");
Expect(0, 66340, '\P{^Is_Sc= -Ital}', "");
Error('\p{Script=_:=javanese}');
Error('\P{Script=_:=javanese}');
Expect(1, 43487, '\p{Script=javanese}', "");
Expect(0, 43487, '\p{^Script=javanese}', "");
Expect(0, 43487, '\P{Script=javanese}', "");
Expect(1, 43487, '\P{^Script=javanese}', "");
Expect(0, 43488, '\p{Script=javanese}', "");
Expect(1, 43488, '\p{^Script=javanese}', "");
Expect(1, 43488, '\P{Script=javanese}', "");
Expect(0, 43488, '\P{^Script=javanese}', "");
Expect(1, 43487, '\p{Script=_ JAVANESE}', "");
Expect(0, 43487, '\p{^Script=_ JAVANESE}', "");
Expect(0, 43487, '\P{Script=_ JAVANESE}', "");
Expect(1, 43487, '\P{^Script=_ JAVANESE}', "");
Expect(0, 43488, '\p{Script=_ JAVANESE}', "");
Expect(1, 43488, '\p{^Script=_ JAVANESE}', "");
Expect(1, 43488, '\P{Script=_ JAVANESE}', "");
Expect(0, 43488, '\P{^Script=_ JAVANESE}', "");
Error('\p{Sc=/a/java}');
Error('\P{Sc=/a/java}');
Expect(1, 43487, '\p{Sc=java}', "");
Expect(0, 43487, '\p{^Sc=java}', "");
Expect(0, 43487, '\P{Sc=java}', "");
Expect(1, 43487, '\P{^Sc=java}', "");
Expect(0, 43488, '\p{Sc=java}', "");
Expect(1, 43488, '\p{^Sc=java}', "");
Expect(1, 43488, '\P{Sc=java}', "");
Expect(0, 43488, '\P{^Sc=java}', "");
Expect(1, 43487, '\p{Sc=	JAVA}', "");
Expect(0, 43487, '\p{^Sc=	JAVA}', "");
Expect(0, 43487, '\P{Sc=	JAVA}', "");
Expect(1, 43487, '\P{^Sc=	JAVA}', "");
Expect(0, 43488, '\p{Sc=	JAVA}', "");
Expect(1, 43488, '\p{^Sc=	JAVA}', "");
Expect(1, 43488, '\P{Sc=	JAVA}', "");
Expect(0, 43488, '\P{^Sc=	JAVA}', "");
Error('\p{Is_Script=-Javanese:=}');
Error('\P{Is_Script=-Javanese:=}');
Expect(1, 43487, '\p{Is_Script=javanese}', "");
Expect(0, 43487, '\p{^Is_Script=javanese}', "");
Expect(0, 43487, '\P{Is_Script=javanese}', "");
Expect(1, 43487, '\P{^Is_Script=javanese}', "");
Expect(0, 43488, '\p{Is_Script=javanese}', "");
Expect(1, 43488, '\p{^Is_Script=javanese}', "");
Expect(1, 43488, '\P{Is_Script=javanese}', "");
Expect(0, 43488, '\P{^Is_Script=javanese}', "");
Expect(1, 43487, '\p{Is_Script=--javanese}', "");
Expect(0, 43487, '\p{^Is_Script=--javanese}', "");
Expect(0, 43487, '\P{Is_Script=--javanese}', "");
Expect(1, 43487, '\P{^Is_Script=--javanese}', "");
Expect(0, 43488, '\p{Is_Script=--javanese}', "");
Expect(1, 43488, '\p{^Is_Script=--javanese}', "");
Expect(1, 43488, '\P{Is_Script=--javanese}', "");
Expect(0, 43488, '\P{^Is_Script=--javanese}', "");
Error('\p{Is_Sc=/a/_Java}');
Error('\P{Is_Sc=/a/_Java}');
Expect(1, 43487, '\p{Is_Sc=java}', "");
Expect(0, 43487, '\p{^Is_Sc=java}', "");
Expect(0, 43487, '\P{Is_Sc=java}', "");
Expect(1, 43487, '\P{^Is_Sc=java}', "");
Expect(0, 43488, '\p{Is_Sc=java}', "");
Expect(1, 43488, '\p{^Is_Sc=java}', "");
Expect(1, 43488, '\P{Is_Sc=java}', "");
Expect(0, 43488, '\P{^Is_Sc=java}', "");
Expect(1, 43487, '\p{Is_Sc=-_java}', "");
Expect(0, 43487, '\p{^Is_Sc=-_java}', "");
Expect(0, 43487, '\P{Is_Sc=-_java}', "");
Expect(1, 43487, '\P{^Is_Sc=-_java}', "");
Expect(0, 43488, '\p{Is_Sc=-_java}', "");
Expect(1, 43488, '\p{^Is_Sc=-_java}', "");
Expect(1, 43488, '\P{Is_Sc=-_java}', "");
Expect(0, 43488, '\P{^Is_Sc=-_java}', "");
Error('\p{Script=:=_Kayah_Li}');
Error('\P{Script=:=_Kayah_Li}');
Expect(1, 43311, '\p{Script:kayahli}', "");
Expect(0, 43311, '\p{^Script:kayahli}', "");
Expect(0, 43311, '\P{Script:kayahli}', "");
Expect(1, 43311, '\P{^Script:kayahli}', "");
Expect(0, 43312, '\p{Script:kayahli}', "");
Expect(1, 43312, '\p{^Script:kayahli}', "");
Expect(1, 43312, '\P{Script:kayahli}', "");
Expect(0, 43312, '\P{^Script:kayahli}', "");
Expect(1, 43311, '\p{Script=	 kayah_li}', "");
Expect(0, 43311, '\p{^Script=	 kayah_li}', "");
Expect(0, 43311, '\P{Script=	 kayah_li}', "");
Expect(1, 43311, '\P{^Script=	 kayah_li}', "");
Expect(0, 43312, '\p{Script=	 kayah_li}', "");
Expect(1, 43312, '\p{^Script=	 kayah_li}', "");
Expect(1, 43312, '\P{Script=	 kayah_li}', "");
Expect(0, 43312, '\P{^Script=	 kayah_li}', "");
Error('\p{Sc:   		kali:=}');
Error('\P{Sc:   		kali:=}');
Expect(1, 43311, '\p{Sc=kali}', "");
Expect(0, 43311, '\p{^Sc=kali}', "");
Expect(0, 43311, '\P{Sc=kali}', "");
Expect(1, 43311, '\P{^Sc=kali}', "");
Expect(0, 43312, '\p{Sc=kali}', "");
Expect(1, 43312, '\p{^Sc=kali}', "");
Expect(1, 43312, '\P{Sc=kali}', "");
Expect(0, 43312, '\P{^Sc=kali}', "");
Expect(1, 43311, '\p{Sc=	_kali}', "");
Expect(0, 43311, '\p{^Sc=	_kali}', "");
Expect(0, 43311, '\P{Sc=	_kali}', "");
Expect(1, 43311, '\P{^Sc=	_kali}', "");
Expect(0, 43312, '\p{Sc=	_kali}', "");
Expect(1, 43312, '\p{^Sc=	_kali}', "");
Expect(1, 43312, '\P{Sc=	_kali}', "");
Expect(0, 43312, '\P{^Sc=	_kali}', "");
Error('\p{Is_Script=:=	 kayah_li}');
Error('\P{Is_Script=:=	 kayah_li}');
Expect(1, 43311, '\p{Is_Script: kayahli}', "");
Expect(0, 43311, '\p{^Is_Script: kayahli}', "");
Expect(0, 43311, '\P{Is_Script: kayahli}', "");
Expect(1, 43311, '\P{^Is_Script: kayahli}', "");
Expect(0, 43312, '\p{Is_Script: kayahli}', "");
Expect(1, 43312, '\p{^Is_Script: kayahli}', "");
Expect(1, 43312, '\P{Is_Script: kayahli}', "");
Expect(0, 43312, '\P{^Is_Script: kayahli}', "");
Expect(1, 43311, '\p{Is_Script=- kayah_LI}', "");
Expect(0, 43311, '\p{^Is_Script=- kayah_LI}', "");
Expect(0, 43311, '\P{Is_Script=- kayah_LI}', "");
Expect(1, 43311, '\P{^Is_Script=- kayah_LI}', "");
Expect(0, 43312, '\p{Is_Script=- kayah_LI}', "");
Expect(1, 43312, '\p{^Is_Script=- kayah_LI}', "");
Expect(1, 43312, '\P{Is_Script=- kayah_LI}', "");
Expect(0, 43312, '\P{^Is_Script=- kayah_LI}', "");
Error('\p{Is_Sc=:=Kali}');
Error('\P{Is_Sc=:=Kali}');
Expect(1, 43311, '\p{Is_Sc=kali}', "");
Expect(0, 43311, '\p{^Is_Sc=kali}', "");
Expect(0, 43311, '\P{Is_Sc=kali}', "");
Expect(1, 43311, '\P{^Is_Sc=kali}', "");
Expect(0, 43312, '\p{Is_Sc=kali}', "");
Expect(1, 43312, '\p{^Is_Sc=kali}', "");
Expect(1, 43312, '\P{Is_Sc=kali}', "");
Expect(0, 43312, '\P{^Is_Sc=kali}', "");
Expect(1, 43311, '\p{Is_Sc= kali}', "");
Expect(0, 43311, '\p{^Is_Sc= kali}', "");
Expect(0, 43311, '\P{Is_Sc= kali}', "");
Expect(1, 43311, '\P{^Is_Sc= kali}', "");
Expect(0, 43312, '\p{Is_Sc= kali}', "");
Expect(1, 43312, '\p{^Is_Sc= kali}', "");
Expect(1, 43312, '\P{Is_Sc= kali}', "");
Expect(0, 43312, '\P{^Is_Sc= kali}', "");
Error('\p{Script=		katakana:=}');
Error('\P{Script=		katakana:=}');
Expect(1, 110592, '\p{Script:   katakana}', "");
Expect(0, 110592, '\p{^Script:   katakana}', "");
Expect(0, 110592, '\P{Script:   katakana}', "");
Expect(1, 110592, '\P{^Script:   katakana}', "");
Expect(0, 110593, '\p{Script:   katakana}', "");
Expect(1, 110593, '\p{^Script:   katakana}', "");
Expect(1, 110593, '\P{Script:   katakana}', "");
Expect(0, 110593, '\P{^Script:   katakana}', "");
Expect(1, 110592, '\p{Script=-katakana}', "");
Expect(0, 110592, '\p{^Script=-katakana}', "");
Expect(0, 110592, '\P{Script=-katakana}', "");
Expect(1, 110592, '\P{^Script=-katakana}', "");
Expect(0, 110593, '\p{Script=-katakana}', "");
Expect(1, 110593, '\p{^Script=-katakana}', "");
Expect(1, 110593, '\P{Script=-katakana}', "");
Expect(0, 110593, '\P{^Script=-katakana}', "");
Error('\p{Sc=-KANA:=}');
Error('\P{Sc=-KANA:=}');
Expect(1, 110592, '\p{Sc:   kana}', "");
Expect(0, 110592, '\p{^Sc:   kana}', "");
Expect(0, 110592, '\P{Sc:   kana}', "");
Expect(1, 110592, '\P{^Sc:   kana}', "");
Expect(0, 110593, '\p{Sc:   kana}', "");
Expect(1, 110593, '\p{^Sc:   kana}', "");
Expect(1, 110593, '\P{Sc:   kana}', "");
Expect(0, 110593, '\P{^Sc:   kana}', "");
Expect(1, 110592, '\p{Sc=__kana}', "");
Expect(0, 110592, '\p{^Sc=__kana}', "");
Expect(0, 110592, '\P{Sc=__kana}', "");
Expect(1, 110592, '\P{^Sc=__kana}', "");
Expect(0, 110593, '\p{Sc=__kana}', "");
Expect(1, 110593, '\p{^Sc=__kana}', "");
Expect(1, 110593, '\P{Sc=__kana}', "");
Expect(0, 110593, '\P{^Sc=__kana}', "");
Error('\p{Is_Script:/a/_-Katakana}');
Error('\P{Is_Script:/a/_-Katakana}');
Expect(1, 110592, '\p{Is_Script=katakana}', "");
Expect(0, 110592, '\p{^Is_Script=katakana}', "");
Expect(0, 110592, '\P{Is_Script=katakana}', "");
Expect(1, 110592, '\P{^Is_Script=katakana}', "");
Expect(0, 110593, '\p{Is_Script=katakana}', "");
Expect(1, 110593, '\p{^Is_Script=katakana}', "");
Expect(1, 110593, '\P{Is_Script=katakana}', "");
Expect(0, 110593, '\P{^Is_Script=katakana}', "");
Expect(1, 110592, '\p{Is_Script=-_katakana}', "");
Expect(0, 110592, '\p{^Is_Script=-_katakana}', "");
Expect(0, 110592, '\P{Is_Script=-_katakana}', "");
Expect(1, 110592, '\P{^Is_Script=-_katakana}', "");
Expect(0, 110593, '\p{Is_Script=-_katakana}', "");
Expect(1, 110593, '\p{^Is_Script=-_katakana}', "");
Expect(1, 110593, '\P{Is_Script=-_katakana}', "");
Expect(0, 110593, '\P{^Is_Script=-_katakana}', "");
Error('\p{Is_Sc=/a/	 KANA}');
Error('\P{Is_Sc=/a/	 KANA}');
Expect(1, 110592, '\p{Is_Sc=kana}', "");
Expect(0, 110592, '\p{^Is_Sc=kana}', "");
Expect(0, 110592, '\P{Is_Sc=kana}', "");
Expect(1, 110592, '\P{^Is_Sc=kana}', "");
Expect(0, 110593, '\p{Is_Sc=kana}', "");
Expect(1, 110593, '\p{^Is_Sc=kana}', "");
Expect(1, 110593, '\P{Is_Sc=kana}', "");
Expect(0, 110593, '\P{^Is_Sc=kana}', "");
Expect(1, 110592, '\p{Is_Sc: _ Kana}', "");
Expect(0, 110592, '\p{^Is_Sc: _ Kana}', "");
Expect(0, 110592, '\P{Is_Sc: _ Kana}', "");
Expect(1, 110592, '\P{^Is_Sc: _ Kana}', "");
Expect(0, 110593, '\p{Is_Sc: _ Kana}', "");
Expect(1, 110593, '\p{^Is_Sc: _ Kana}', "");
Expect(1, 110593, '\P{Is_Sc: _ Kana}', "");
Expect(0, 110593, '\P{^Is_Sc: _ Kana}', "");
Error('\p{Script= /a/KHAROSHTHI}');
Error('\P{Script= /a/KHAROSHTHI}');
Expect(1, 68184, '\p{Script=kharoshthi}', "");
Expect(0, 68184, '\p{^Script=kharoshthi}', "");
Expect(0, 68184, '\P{Script=kharoshthi}', "");
Expect(1, 68184, '\P{^Script=kharoshthi}', "");
Expect(0, 68185, '\p{Script=kharoshthi}', "");
Expect(1, 68185, '\p{^Script=kharoshthi}', "");
Expect(1, 68185, '\P{Script=kharoshthi}', "");
Expect(0, 68185, '\P{^Script=kharoshthi}', "");
Expect(1, 68184, '\p{Script=	-KHAROSHTHI}', "");
Expect(0, 68184, '\p{^Script=	-KHAROSHTHI}', "");
Expect(0, 68184, '\P{Script=	-KHAROSHTHI}', "");
Expect(1, 68184, '\P{^Script=	-KHAROSHTHI}', "");
Expect(0, 68185, '\p{Script=	-KHAROSHTHI}', "");
Expect(1, 68185, '\p{^Script=	-KHAROSHTHI}', "");
Expect(1, 68185, '\P{Script=	-KHAROSHTHI}', "");
Expect(0, 68185, '\P{^Script=	-KHAROSHTHI}', "");
Error('\p{Sc=:=_-Khar}');
Error('\P{Sc=:=_-Khar}');
Expect(1, 68184, '\p{Sc=khar}', "");
Expect(0, 68184, '\p{^Sc=khar}', "");
Expect(0, 68184, '\P{Sc=khar}', "");
Expect(1, 68184, '\P{^Sc=khar}', "");
Expect(0, 68185, '\p{Sc=khar}', "");
Expect(1, 68185, '\p{^Sc=khar}', "");
Expect(1, 68185, '\P{Sc=khar}', "");
Expect(0, 68185, '\P{^Sc=khar}', "");
Expect(1, 68184, '\p{Sc:	_Khar}', "");
Expect(0, 68184, '\p{^Sc:	_Khar}', "");
Expect(0, 68184, '\P{Sc:	_Khar}', "");
Expect(1, 68184, '\P{^Sc:	_Khar}', "");
Expect(0, 68185, '\p{Sc:	_Khar}', "");
Expect(1, 68185, '\p{^Sc:	_Khar}', "");
Expect(1, 68185, '\P{Sc:	_Khar}', "");
Expect(0, 68185, '\P{^Sc:	_Khar}', "");
Error('\p{Is_Script:	_:=kharoshthi}');
Error('\P{Is_Script:	_:=kharoshthi}');
Expect(1, 68184, '\p{Is_Script=kharoshthi}', "");
Expect(0, 68184, '\p{^Is_Script=kharoshthi}', "");
Expect(0, 68184, '\P{Is_Script=kharoshthi}', "");
Expect(1, 68184, '\P{^Is_Script=kharoshthi}', "");
Expect(0, 68185, '\p{Is_Script=kharoshthi}', "");
Expect(1, 68185, '\p{^Is_Script=kharoshthi}', "");
Expect(1, 68185, '\P{Is_Script=kharoshthi}', "");
Expect(0, 68185, '\P{^Is_Script=kharoshthi}', "");
Expect(1, 68184, '\p{Is_Script=		Kharoshthi}', "");
Expect(0, 68184, '\p{^Is_Script=		Kharoshthi}', "");
Expect(0, 68184, '\P{Is_Script=		Kharoshthi}', "");
Expect(1, 68184, '\P{^Is_Script=		Kharoshthi}', "");
Expect(0, 68185, '\p{Is_Script=		Kharoshthi}', "");
Expect(1, 68185, '\p{^Is_Script=		Kharoshthi}', "");
Expect(1, 68185, '\P{Is_Script=		Kharoshthi}', "");
Expect(0, 68185, '\P{^Is_Script=		Kharoshthi}', "");
Error('\p{Is_Sc=/a/Khar}');
Error('\P{Is_Sc=/a/Khar}');
Expect(1, 68184, '\p{Is_Sc=khar}', "");
Expect(0, 68184, '\p{^Is_Sc=khar}', "");
Expect(0, 68184, '\P{Is_Sc=khar}', "");
Expect(1, 68184, '\P{^Is_Sc=khar}', "");
Expect(0, 68185, '\p{Is_Sc=khar}', "");
Expect(1, 68185, '\p{^Is_Sc=khar}', "");
Expect(1, 68185, '\P{Is_Sc=khar}', "");
Expect(0, 68185, '\P{^Is_Sc=khar}', "");
Expect(1, 68184, '\p{Is_Sc=- Khar}', "");
Expect(0, 68184, '\p{^Is_Sc=- Khar}', "");
Expect(0, 68184, '\P{Is_Sc=- Khar}', "");
Expect(1, 68184, '\P{^Is_Sc=- Khar}', "");
Expect(0, 68185, '\p{Is_Sc=- Khar}', "");
Expect(1, 68185, '\p{^Is_Sc=- Khar}', "");
Expect(1, 68185, '\P{Is_Sc=- Khar}', "");
Expect(0, 68185, '\P{^Is_Sc=- Khar}', "");
Error('\p{Script=_/a/khmer}');
Error('\P{Script=_/a/khmer}');
Expect(1, 6655, '\p{Script=khmer}', "");
Expect(0, 6655, '\p{^Script=khmer}', "");
Expect(0, 6655, '\P{Script=khmer}', "");
Expect(1, 6655, '\P{^Script=khmer}', "");
Expect(0, 6656, '\p{Script=khmer}', "");
Expect(1, 6656, '\p{^Script=khmer}', "");
Expect(1, 6656, '\P{Script=khmer}', "");
Expect(0, 6656, '\P{^Script=khmer}', "");
Expect(1, 6655, '\p{Script:     KHMER}', "");
Expect(0, 6655, '\p{^Script:     KHMER}', "");
Expect(0, 6655, '\P{Script:     KHMER}', "");
Expect(1, 6655, '\P{^Script:     KHMER}', "");
Expect(0, 6656, '\p{Script:     KHMER}', "");
Expect(1, 6656, '\p{^Script:     KHMER}', "");
Expect(1, 6656, '\P{Script:     KHMER}', "");
Expect(0, 6656, '\P{^Script:     KHMER}', "");
Error('\p{Sc=/a/ khmr}');
Error('\P{Sc=/a/ khmr}');
Expect(1, 6655, '\p{Sc=khmr}', "");
Expect(0, 6655, '\p{^Sc=khmr}', "");
Expect(0, 6655, '\P{Sc=khmr}', "");
Expect(1, 6655, '\P{^Sc=khmr}', "");
Expect(0, 6656, '\p{Sc=khmr}', "");
Expect(1, 6656, '\p{^Sc=khmr}', "");
Expect(1, 6656, '\P{Sc=khmr}', "");
Expect(0, 6656, '\P{^Sc=khmr}', "");
Expect(1, 6655, '\p{Sc:	-	Khmr}', "");
Expect(0, 6655, '\p{^Sc:	-	Khmr}', "");
Expect(0, 6655, '\P{Sc:	-	Khmr}', "");
Expect(1, 6655, '\P{^Sc:	-	Khmr}', "");
Expect(0, 6656, '\p{Sc:	-	Khmr}', "");
Expect(1, 6656, '\p{^Sc:	-	Khmr}', "");
Expect(1, 6656, '\P{Sc:	-	Khmr}', "");
Expect(0, 6656, '\P{^Sc:	-	Khmr}', "");
Error('\p{Is_Script=:=Khmer}');
Error('\P{Is_Script=:=Khmer}');
Expect(1, 6655, '\p{Is_Script=khmer}', "");
Expect(0, 6655, '\p{^Is_Script=khmer}', "");
Expect(0, 6655, '\P{Is_Script=khmer}', "");
Expect(1, 6655, '\P{^Is_Script=khmer}', "");
Expect(0, 6656, '\p{Is_Script=khmer}', "");
Expect(1, 6656, '\p{^Is_Script=khmer}', "");
Expect(1, 6656, '\P{Is_Script=khmer}', "");
Expect(0, 6656, '\P{^Is_Script=khmer}', "");
Expect(1, 6655, '\p{Is_Script:	KHMER}', "");
Expect(0, 6655, '\p{^Is_Script:	KHMER}', "");
Expect(0, 6655, '\P{Is_Script:	KHMER}', "");
Expect(1, 6655, '\P{^Is_Script:	KHMER}', "");
Expect(0, 6656, '\p{Is_Script:	KHMER}', "");
Expect(1, 6656, '\p{^Is_Script:	KHMER}', "");
Expect(1, 6656, '\P{Is_Script:	KHMER}', "");
Expect(0, 6656, '\P{^Is_Script:	KHMER}', "");
Error('\p{Is_Sc=		Khmr:=}');
Error('\P{Is_Sc=		Khmr:=}');
Expect(1, 6655, '\p{Is_Sc=khmr}', "");
Expect(0, 6655, '\p{^Is_Sc=khmr}', "");
Expect(0, 6655, '\P{Is_Sc=khmr}', "");
Expect(1, 6655, '\P{^Is_Sc=khmr}', "");
Expect(0, 6656, '\p{Is_Sc=khmr}', "");
Expect(1, 6656, '\p{^Is_Sc=khmr}', "");
Expect(1, 6656, '\P{Is_Sc=khmr}', "");
Expect(0, 6656, '\P{^Is_Sc=khmr}', "");
Expect(1, 6655, '\p{Is_Sc=	_Khmr}', "");
Expect(0, 6655, '\p{^Is_Sc=	_Khmr}', "");
Expect(0, 6655, '\P{Is_Sc=	_Khmr}', "");
Expect(1, 6655, '\P{^Is_Sc=	_Khmr}', "");
Expect(0, 6656, '\p{Is_Sc=	_Khmr}', "");
Expect(1, 6656, '\p{^Is_Sc=	_Khmr}', "");
Expect(1, 6656, '\P{Is_Sc=	_Khmr}', "");
Expect(0, 6656, '\P{^Is_Sc=	_Khmr}', "");
Error('\p{Script=:=__KANNADA}');
Error('\P{Script=:=__KANNADA}');
Expect(1, 3314, '\p{Script=kannada}', "");
Expect(0, 3314, '\p{^Script=kannada}', "");
Expect(0, 3314, '\P{Script=kannada}', "");
Expect(1, 3314, '\P{^Script=kannada}', "");
Expect(0, 3315, '\p{Script=kannada}', "");
Expect(1, 3315, '\p{^Script=kannada}', "");
Expect(1, 3315, '\P{Script=kannada}', "");
Expect(0, 3315, '\P{^Script=kannada}', "");
Expect(1, 3314, '\p{Script=- Kannada}', "");
Expect(0, 3314, '\p{^Script=- Kannada}', "");
Expect(0, 3314, '\P{Script=- Kannada}', "");
Expect(1, 3314, '\P{^Script=- Kannada}', "");
Expect(0, 3315, '\p{Script=- Kannada}', "");
Expect(1, 3315, '\p{^Script=- Kannada}', "");
Expect(1, 3315, '\P{Script=- Kannada}', "");
Expect(0, 3315, '\P{^Script=- Kannada}', "");
Error('\p{Sc= 	KNDA:=}');
Error('\P{Sc= 	KNDA:=}');
Expect(1, 3314, '\p{Sc=knda}', "");
Expect(0, 3314, '\p{^Sc=knda}', "");
Expect(0, 3314, '\P{Sc=knda}', "");
Expect(1, 3314, '\P{^Sc=knda}', "");
Expect(0, 3315, '\p{Sc=knda}', "");
Expect(1, 3315, '\p{^Sc=knda}', "");
Expect(1, 3315, '\P{Sc=knda}', "");
Expect(0, 3315, '\P{^Sc=knda}', "");
Expect(1, 3314, '\p{Sc=	-Knda}', "");
Expect(0, 3314, '\p{^Sc=	-Knda}', "");
Expect(0, 3314, '\P{Sc=	-Knda}', "");
Expect(1, 3314, '\P{^Sc=	-Knda}', "");
Expect(0, 3315, '\p{Sc=	-Knda}', "");
Expect(1, 3315, '\p{^Sc=	-Knda}', "");
Expect(1, 3315, '\P{Sc=	-Knda}', "");
Expect(0, 3315, '\P{^Sc=	-Knda}', "");
Error('\p{Is_Script=/a/Kannada}');
Error('\P{Is_Script=/a/Kannada}');
Expect(1, 3314, '\p{Is_Script=kannada}', "");
Expect(0, 3314, '\p{^Is_Script=kannada}', "");
Expect(0, 3314, '\P{Is_Script=kannada}', "");
Expect(1, 3314, '\P{^Is_Script=kannada}', "");
Expect(0, 3315, '\p{Is_Script=kannada}', "");
Expect(1, 3315, '\p{^Is_Script=kannada}', "");
Expect(1, 3315, '\P{Is_Script=kannada}', "");
Expect(0, 3315, '\P{^Is_Script=kannada}', "");
Expect(1, 3314, '\p{Is_Script= _Kannada}', "");
Expect(0, 3314, '\p{^Is_Script= _Kannada}', "");
Expect(0, 3314, '\P{Is_Script= _Kannada}', "");
Expect(1, 3314, '\P{^Is_Script= _Kannada}', "");
Expect(0, 3315, '\p{Is_Script= _Kannada}', "");
Expect(1, 3315, '\p{^Is_Script= _Kannada}', "");
Expect(1, 3315, '\P{Is_Script= _Kannada}', "");
Expect(0, 3315, '\P{^Is_Script= _Kannada}', "");
Error('\p{Is_Sc=:=		knda}');
Error('\P{Is_Sc=:=		knda}');
Expect(1, 3314, '\p{Is_Sc: knda}', "");
Expect(0, 3314, '\p{^Is_Sc: knda}', "");
Expect(0, 3314, '\P{Is_Sc: knda}', "");
Expect(1, 3314, '\P{^Is_Sc: knda}', "");
Expect(0, 3315, '\p{Is_Sc: knda}', "");
Expect(1, 3315, '\p{^Is_Sc: knda}', "");
Expect(1, 3315, '\P{Is_Sc: knda}', "");
Expect(0, 3315, '\P{^Is_Sc: knda}', "");
Expect(1, 3314, '\p{Is_Sc=	_KNDA}', "");
Expect(0, 3314, '\p{^Is_Sc=	_KNDA}', "");
Expect(0, 3314, '\P{Is_Sc=	_KNDA}', "");
Expect(1, 3314, '\P{^Is_Sc=	_KNDA}', "");
Expect(0, 3315, '\p{Is_Sc=	_KNDA}', "");
Expect(1, 3315, '\p{^Is_Sc=	_KNDA}', "");
Expect(1, 3315, '\P{Is_Sc=	_KNDA}', "");
Expect(0, 3315, '\P{^Is_Sc=	_KNDA}', "");
Error('\p{Script=-Kaithi:=}');
Error('\P{Script=-Kaithi:=}');
Expect(1, 69825, '\p{Script=kaithi}', "");
Expect(0, 69825, '\p{^Script=kaithi}', "");
Expect(0, 69825, '\P{Script=kaithi}', "");
Expect(1, 69825, '\P{^Script=kaithi}', "");
Expect(0, 69826, '\p{Script=kaithi}', "");
Expect(1, 69826, '\p{^Script=kaithi}', "");
Expect(1, 69826, '\P{Script=kaithi}', "");
Expect(0, 69826, '\P{^Script=kaithi}', "");
Expect(1, 69825, '\p{Script= Kaithi}', "");
Expect(0, 69825, '\p{^Script= Kaithi}', "");
Expect(0, 69825, '\P{Script= Kaithi}', "");
Expect(1, 69825, '\P{^Script= Kaithi}', "");
Expect(0, 69826, '\p{Script= Kaithi}', "");
Expect(1, 69826, '\p{^Script= Kaithi}', "");
Expect(1, 69826, '\P{Script= Kaithi}', "");
Expect(0, 69826, '\P{^Script= Kaithi}', "");
Error('\p{Sc=	Kthi/a/}');
Error('\P{Sc=	Kthi/a/}');
Expect(1, 69825, '\p{Sc:	kthi}', "");
Expect(0, 69825, '\p{^Sc:	kthi}', "");
Expect(0, 69825, '\P{Sc:	kthi}', "");
Expect(1, 69825, '\P{^Sc:	kthi}', "");
Expect(0, 69826, '\p{Sc:	kthi}', "");
Expect(1, 69826, '\p{^Sc:	kthi}', "");
Expect(1, 69826, '\P{Sc:	kthi}', "");
Expect(0, 69826, '\P{^Sc:	kthi}', "");
Expect(1, 69825, '\p{Sc= _Kthi}', "");
Expect(0, 69825, '\p{^Sc= _Kthi}', "");
Expect(0, 69825, '\P{Sc= _Kthi}', "");
Expect(1, 69825, '\P{^Sc= _Kthi}', "");
Expect(0, 69826, '\p{Sc= _Kthi}', "");
Expect(1, 69826, '\p{^Sc= _Kthi}', "");
Expect(1, 69826, '\P{Sc= _Kthi}', "");
Expect(0, 69826, '\P{^Sc= _Kthi}', "");
Error('\p{Is_Script=:=	-Kaithi}');
Error('\P{Is_Script=:=	-Kaithi}');
Expect(1, 69825, '\p{Is_Script: kaithi}', "");
Expect(0, 69825, '\p{^Is_Script: kaithi}', "");
Expect(0, 69825, '\P{Is_Script: kaithi}', "");
Expect(1, 69825, '\P{^Is_Script: kaithi}', "");
Expect(0, 69826, '\p{Is_Script: kaithi}', "");
Expect(1, 69826, '\p{^Is_Script: kaithi}', "");
Expect(1, 69826, '\P{Is_Script: kaithi}', "");
Expect(0, 69826, '\P{^Is_Script: kaithi}', "");
Expect(1, 69825, '\p{Is_Script=- KAITHI}', "");
Expect(0, 69825, '\p{^Is_Script=- KAITHI}', "");
Expect(0, 69825, '\P{Is_Script=- KAITHI}', "");
Expect(1, 69825, '\P{^Is_Script=- KAITHI}', "");
Expect(0, 69826, '\p{Is_Script=- KAITHI}', "");
Expect(1, 69826, '\p{^Is_Script=- KAITHI}', "");
Expect(1, 69826, '\P{Is_Script=- KAITHI}', "");
Expect(0, 69826, '\P{^Is_Script=- KAITHI}', "");
Error('\p{Is_Sc=/a/kthi}');
Error('\P{Is_Sc=/a/kthi}');
Expect(1, 69825, '\p{Is_Sc: kthi}', "");
Expect(0, 69825, '\p{^Is_Sc: kthi}', "");
Expect(0, 69825, '\P{Is_Sc: kthi}', "");
Expect(1, 69825, '\P{^Is_Sc: kthi}', "");
Expect(0, 69826, '\p{Is_Sc: kthi}', "");
Expect(1, 69826, '\p{^Is_Sc: kthi}', "");
Expect(1, 69826, '\P{Is_Sc: kthi}', "");
Expect(0, 69826, '\P{^Is_Sc: kthi}', "");
Expect(1, 69825, '\p{Is_Sc=	Kthi}', "");
Expect(0, 69825, '\p{^Is_Sc=	Kthi}', "");
Expect(0, 69825, '\P{Is_Sc=	Kthi}', "");
Expect(1, 69825, '\P{^Is_Sc=	Kthi}', "");
Expect(0, 69826, '\p{Is_Sc=	Kthi}', "");
Expect(1, 69826, '\p{^Is_Sc=	Kthi}', "");
Expect(1, 69826, '\P{Is_Sc=	Kthi}', "");
Expect(0, 69826, '\P{^Is_Sc=	Kthi}', "");
Error('\p{Script=_/a/TAI_tham}');
Error('\P{Script=_/a/TAI_tham}');
Expect(1, 6829, '\p{Script=taitham}', "");
Expect(0, 6829, '\p{^Script=taitham}', "");
Expect(0, 6829, '\P{Script=taitham}', "");
Expect(1, 6829, '\P{^Script=taitham}', "");
Expect(0, 6830, '\p{Script=taitham}', "");
Expect(1, 6830, '\p{^Script=taitham}', "");
Expect(1, 6830, '\P{Script=taitham}', "");
Expect(0, 6830, '\P{^Script=taitham}', "");
Expect(1, 6829, '\p{Script= Tai_THAM}', "");
Expect(0, 6829, '\p{^Script= Tai_THAM}', "");
Expect(0, 6829, '\P{Script= Tai_THAM}', "");
Expect(1, 6829, '\P{^Script= Tai_THAM}', "");
Expect(0, 6830, '\p{Script= Tai_THAM}', "");
Expect(1, 6830, '\p{^Script= Tai_THAM}', "");
Expect(1, 6830, '\P{Script= Tai_THAM}', "");
Expect(0, 6830, '\P{^Script= Tai_THAM}', "");
Error('\p{Sc=/a/Lana}');
Error('\P{Sc=/a/Lana}');
Expect(1, 6829, '\p{Sc=lana}', "");
Expect(0, 6829, '\p{^Sc=lana}', "");
Expect(0, 6829, '\P{Sc=lana}', "");
Expect(1, 6829, '\P{^Sc=lana}', "");
Expect(0, 6830, '\p{Sc=lana}', "");
Expect(1, 6830, '\p{^Sc=lana}', "");
Expect(1, 6830, '\P{Sc=lana}', "");
Expect(0, 6830, '\P{^Sc=lana}', "");
Expect(1, 6829, '\p{Sc=_ LANA}', "");
Expect(0, 6829, '\p{^Sc=_ LANA}', "");
Expect(0, 6829, '\P{Sc=_ LANA}', "");
Expect(1, 6829, '\P{^Sc=_ LANA}', "");
Expect(0, 6830, '\p{Sc=_ LANA}', "");
Expect(1, 6830, '\p{^Sc=_ LANA}', "");
Expect(1, 6830, '\P{Sc=_ LANA}', "");
Expect(0, 6830, '\P{^Sc=_ LANA}', "");
Error('\p{Is_Script=/a/-	Tai_THAM}');
Error('\P{Is_Script=/a/-	Tai_THAM}');
Expect(1, 6829, '\p{Is_Script:   taitham}', "");
Expect(0, 6829, '\p{^Is_Script:   taitham}', "");
Expect(0, 6829, '\P{Is_Script:   taitham}', "");
Expect(1, 6829, '\P{^Is_Script:   taitham}', "");
Expect(0, 6830, '\p{Is_Script:   taitham}', "");
Expect(1, 6830, '\p{^Is_Script:   taitham}', "");
Expect(1, 6830, '\P{Is_Script:   taitham}', "");
Expect(0, 6830, '\P{^Is_Script:   taitham}', "");
Expect(1, 6829, '\p{Is_Script=-Tai_tham}', "");
Expect(0, 6829, '\p{^Is_Script=-Tai_tham}', "");
Expect(0, 6829, '\P{Is_Script=-Tai_tham}', "");
Expect(1, 6829, '\P{^Is_Script=-Tai_tham}', "");
Expect(0, 6830, '\p{Is_Script=-Tai_tham}', "");
Expect(1, 6830, '\p{^Is_Script=-Tai_tham}', "");
Expect(1, 6830, '\P{Is_Script=-Tai_tham}', "");
Expect(0, 6830, '\P{^Is_Script=-Tai_tham}', "");
Error('\p{Is_Sc= 	Lana:=}');
Error('\P{Is_Sc= 	Lana:=}');
Expect(1, 6829, '\p{Is_Sc=lana}', "");
Expect(0, 6829, '\p{^Is_Sc=lana}', "");
Expect(0, 6829, '\P{Is_Sc=lana}', "");
Expect(1, 6829, '\P{^Is_Sc=lana}', "");
Expect(0, 6830, '\p{Is_Sc=lana}', "");
Expect(1, 6830, '\p{^Is_Sc=lana}', "");
Expect(1, 6830, '\P{Is_Sc=lana}', "");
Expect(0, 6830, '\P{^Is_Sc=lana}', "");
Expect(1, 6829, '\p{Is_Sc: _LANA}', "");
Expect(0, 6829, '\p{^Is_Sc: _LANA}', "");
Expect(0, 6829, '\P{Is_Sc: _LANA}', "");
Expect(1, 6829, '\P{^Is_Sc: _LANA}', "");
Expect(0, 6830, '\p{Is_Sc: _LANA}', "");
Expect(1, 6830, '\p{^Is_Sc: _LANA}', "");
Expect(1, 6830, '\P{Is_Sc: _LANA}', "");
Expect(0, 6830, '\P{^Is_Sc: _LANA}', "");
Error('\p{Script=:=	 lao}');
Error('\P{Script=:=	 lao}');
Expect(1, 3807, '\p{Script=lao}', "");
Expect(0, 3807, '\p{^Script=lao}', "");
Expect(0, 3807, '\P{Script=lao}', "");
Expect(1, 3807, '\P{^Script=lao}', "");
Expect(0, 3808, '\p{Script=lao}', "");
Expect(1, 3808, '\p{^Script=lao}', "");
Expect(1, 3808, '\P{Script=lao}', "");
Expect(0, 3808, '\P{^Script=lao}', "");
Expect(1, 3807, '\p{Script=	 LAO}', "");
Expect(0, 3807, '\p{^Script=	 LAO}', "");
Expect(0, 3807, '\P{Script=	 LAO}', "");
Expect(1, 3807, '\P{^Script=	 LAO}', "");
Expect(0, 3808, '\p{Script=	 LAO}', "");
Expect(1, 3808, '\p{^Script=	 LAO}', "");
Expect(1, 3808, '\P{Script=	 LAO}', "");
Expect(0, 3808, '\P{^Script=	 LAO}', "");
Error('\p{Sc= :=laoo}');
Error('\P{Sc= :=laoo}');
Expect(1, 3807, '\p{Sc=laoo}', "");
Expect(0, 3807, '\p{^Sc=laoo}', "");
Expect(0, 3807, '\P{Sc=laoo}', "");
Expect(1, 3807, '\P{^Sc=laoo}', "");
Expect(0, 3808, '\p{Sc=laoo}', "");
Expect(1, 3808, '\p{^Sc=laoo}', "");
Expect(1, 3808, '\P{Sc=laoo}', "");
Expect(0, 3808, '\P{^Sc=laoo}', "");
Expect(1, 3807, '\p{Sc=	_laoo}', "");
Expect(0, 3807, '\p{^Sc=	_laoo}', "");
Expect(0, 3807, '\P{Sc=	_laoo}', "");
Expect(1, 3807, '\P{^Sc=	_laoo}', "");
Expect(0, 3808, '\p{Sc=	_laoo}', "");
Expect(1, 3808, '\p{^Sc=	_laoo}', "");
Expect(1, 3808, '\P{Sc=	_laoo}', "");
Expect(0, 3808, '\P{^Sc=	_laoo}', "");
Error('\p{Is_Script=_:=LAO}');
Error('\P{Is_Script=_:=LAO}');
Expect(1, 3807, '\p{Is_Script=lao}', "");
Expect(0, 3807, '\p{^Is_Script=lao}', "");
Expect(0, 3807, '\P{Is_Script=lao}', "");
Expect(1, 3807, '\P{^Is_Script=lao}', "");
Expect(0, 3808, '\p{Is_Script=lao}', "");
Expect(1, 3808, '\p{^Is_Script=lao}', "");
Expect(1, 3808, '\P{Is_Script=lao}', "");
Expect(0, 3808, '\P{^Is_Script=lao}', "");
Expect(1, 3807, '\p{Is_Script=	-LAO}', "");
Expect(0, 3807, '\p{^Is_Script=	-LAO}', "");
Expect(0, 3807, '\P{Is_Script=	-LAO}', "");
Expect(1, 3807, '\P{^Is_Script=	-LAO}', "");
Expect(0, 3808, '\p{Is_Script=	-LAO}', "");
Expect(1, 3808, '\p{^Is_Script=	-LAO}', "");
Expect(1, 3808, '\P{Is_Script=	-LAO}', "");
Expect(0, 3808, '\P{^Is_Script=	-LAO}', "");
Error('\p{Is_Sc=Laoo:=}');
Error('\P{Is_Sc=Laoo:=}');
Expect(1, 3807, '\p{Is_Sc=laoo}', "");
Expect(0, 3807, '\p{^Is_Sc=laoo}', "");
Expect(0, 3807, '\P{Is_Sc=laoo}', "");
Expect(1, 3807, '\P{^Is_Sc=laoo}', "");
Expect(0, 3808, '\p{Is_Sc=laoo}', "");
Expect(1, 3808, '\p{^Is_Sc=laoo}', "");
Expect(1, 3808, '\P{Is_Sc=laoo}', "");
Expect(0, 3808, '\P{^Is_Sc=laoo}', "");
Expect(1, 3807, '\p{Is_Sc=		Laoo}', "");
Expect(0, 3807, '\p{^Is_Sc=		Laoo}', "");
Expect(0, 3807, '\P{Is_Sc=		Laoo}', "");
Expect(1, 3807, '\P{^Is_Sc=		Laoo}', "");
Expect(0, 3808, '\p{Is_Sc=		Laoo}', "");
Expect(1, 3808, '\p{^Is_Sc=		Laoo}', "");
Expect(1, 3808, '\P{Is_Sc=		Laoo}', "");
Expect(0, 3808, '\P{^Is_Sc=		Laoo}', "");
Error('\p{Script: :=--Latin}');
Error('\P{Script: :=--Latin}');
Expect(1, 65370, '\p{Script=latin}', "");
Expect(0, 65370, '\p{^Script=latin}', "");
Expect(0, 65370, '\P{Script=latin}', "");
Expect(1, 65370, '\P{^Script=latin}', "");
Expect(0, 65371, '\p{Script=latin}', "");
Expect(1, 65371, '\p{^Script=latin}', "");
Expect(1, 65371, '\P{Script=latin}', "");
Expect(0, 65371, '\P{^Script=latin}', "");
Expect(1, 65370, '\p{Script=	Latin}', "");
Expect(0, 65370, '\p{^Script=	Latin}', "");
Expect(0, 65370, '\P{Script=	Latin}', "");
Expect(1, 65370, '\P{^Script=	Latin}', "");
Expect(0, 65371, '\p{Script=	Latin}', "");
Expect(1, 65371, '\p{^Script=	Latin}', "");
Expect(1, 65371, '\P{Script=	Latin}', "");
Expect(0, 65371, '\P{^Script=	Latin}', "");
Error('\p{Sc=-Latn/a/}');
Error('\P{Sc=-Latn/a/}');
Expect(1, 65370, '\p{Sc=latn}', "");
Expect(0, 65370, '\p{^Sc=latn}', "");
Expect(0, 65370, '\P{Sc=latn}', "");
Expect(1, 65370, '\P{^Sc=latn}', "");
Expect(0, 65371, '\p{Sc=latn}', "");
Expect(1, 65371, '\p{^Sc=latn}', "");
Expect(1, 65371, '\P{Sc=latn}', "");
Expect(0, 65371, '\P{^Sc=latn}', "");
Expect(1, 65370, '\p{Sc=LATN}', "");
Expect(0, 65370, '\p{^Sc=LATN}', "");
Expect(0, 65370, '\P{Sc=LATN}', "");
Expect(1, 65370, '\P{^Sc=LATN}', "");
Expect(0, 65371, '\p{Sc=LATN}', "");
Expect(1, 65371, '\p{^Sc=LATN}', "");
Expect(1, 65371, '\P{Sc=LATN}', "");
Expect(0, 65371, '\P{^Sc=LATN}', "");
Error('\p{Is_Script=_LATIN:=}');
Error('\P{Is_Script=_LATIN:=}');
Expect(1, 65370, '\p{Is_Script: latin}', "");
Expect(0, 65370, '\p{^Is_Script: latin}', "");
Expect(0, 65370, '\P{Is_Script: latin}', "");
Expect(1, 65370, '\P{^Is_Script: latin}', "");
Expect(0, 65371, '\p{Is_Script: latin}', "");
Expect(1, 65371, '\p{^Is_Script: latin}', "");
Expect(1, 65371, '\P{Is_Script: latin}', "");
Expect(0, 65371, '\P{^Is_Script: latin}', "");
Expect(1, 65370, '\p{Is_Script:   - Latin}', "");
Expect(0, 65370, '\p{^Is_Script:   - Latin}', "");
Expect(0, 65370, '\P{Is_Script:   - Latin}', "");
Expect(1, 65370, '\P{^Is_Script:   - Latin}', "");
Expect(0, 65371, '\p{Is_Script:   - Latin}', "");
Expect(1, 65371, '\p{^Is_Script:   - Latin}', "");
Expect(1, 65371, '\P{Is_Script:   - Latin}', "");
Expect(0, 65371, '\P{^Is_Script:   - Latin}', "");
Error('\p{Is_Sc=	Latn:=}');
Error('\P{Is_Sc=	Latn:=}');
Expect(1, 65370, '\p{Is_Sc=latn}', "");
Expect(0, 65370, '\p{^Is_Sc=latn}', "");
Expect(0, 65370, '\P{Is_Sc=latn}', "");
Expect(1, 65370, '\P{^Is_Sc=latn}', "");
Expect(0, 65371, '\p{Is_Sc=latn}', "");
Expect(1, 65371, '\p{^Is_Sc=latn}', "");
Expect(1, 65371, '\P{Is_Sc=latn}', "");
Expect(0, 65371, '\P{^Is_Sc=latn}', "");
Expect(1, 65370, '\p{Is_Sc=-	Latn}', "");
Expect(0, 65370, '\p{^Is_Sc=-	Latn}', "");
Expect(0, 65370, '\P{Is_Sc=-	Latn}', "");
Expect(1, 65370, '\P{^Is_Sc=-	Latn}', "");
Expect(0, 65371, '\p{Is_Sc=-	Latn}', "");
Expect(1, 65371, '\p{^Is_Sc=-	Latn}', "");
Expect(1, 65371, '\P{Is_Sc=-	Latn}', "");
Expect(0, 65371, '\P{^Is_Sc=-	Latn}', "");
Error('\p{Script=Lepcha/a/}');
Error('\P{Script=Lepcha/a/}');
Expect(1, 7247, '\p{Script=lepcha}', "");
Expect(0, 7247, '\p{^Script=lepcha}', "");
Expect(0, 7247, '\P{Script=lepcha}', "");
Expect(1, 7247, '\P{^Script=lepcha}', "");
Expect(0, 7248, '\p{Script=lepcha}', "");
Expect(1, 7248, '\p{^Script=lepcha}', "");
Expect(1, 7248, '\P{Script=lepcha}', "");
Expect(0, 7248, '\P{^Script=lepcha}', "");
Expect(1, 7247, '\p{Script=	_Lepcha}', "");
Expect(0, 7247, '\p{^Script=	_Lepcha}', "");
Expect(0, 7247, '\P{Script=	_Lepcha}', "");
Expect(1, 7247, '\P{^Script=	_Lepcha}', "");
Expect(0, 7248, '\p{Script=	_Lepcha}', "");
Expect(1, 7248, '\p{^Script=	_Lepcha}', "");
Expect(1, 7248, '\P{Script=	_Lepcha}', "");
Expect(0, 7248, '\P{^Script=	_Lepcha}', "");
Error('\p{Sc=  lepc/a/}');
Error('\P{Sc=  lepc/a/}');
Expect(1, 7247, '\p{Sc=lepc}', "");
Expect(0, 7247, '\p{^Sc=lepc}', "");
Expect(0, 7247, '\P{Sc=lepc}', "");
Expect(1, 7247, '\P{^Sc=lepc}', "");
Expect(0, 7248, '\p{Sc=lepc}', "");
Expect(1, 7248, '\p{^Sc=lepc}', "");
Expect(1, 7248, '\P{Sc=lepc}', "");
Expect(0, 7248, '\P{^Sc=lepc}', "");
Expect(1, 7247, '\p{Sc=		LEPC}', "");
Expect(0, 7247, '\p{^Sc=		LEPC}', "");
Expect(0, 7247, '\P{Sc=		LEPC}', "");
Expect(1, 7247, '\P{^Sc=		LEPC}', "");
Expect(0, 7248, '\p{Sc=		LEPC}', "");
Expect(1, 7248, '\p{^Sc=		LEPC}', "");
Expect(1, 7248, '\P{Sc=		LEPC}', "");
Expect(0, 7248, '\P{^Sc=		LEPC}', "");
Error('\p{Is_Script= _Lepcha/a/}');
Error('\P{Is_Script= _Lepcha/a/}');
Expect(1, 7247, '\p{Is_Script=lepcha}', "");
Expect(0, 7247, '\p{^Is_Script=lepcha}', "");
Expect(0, 7247, '\P{Is_Script=lepcha}', "");
Expect(1, 7247, '\P{^Is_Script=lepcha}', "");
Expect(0, 7248, '\p{Is_Script=lepcha}', "");
Expect(1, 7248, '\p{^Is_Script=lepcha}', "");
Expect(1, 7248, '\P{Is_Script=lepcha}', "");
Expect(0, 7248, '\P{^Is_Script=lepcha}', "");
Expect(1, 7247, '\p{Is_Script:_Lepcha}', "");
Expect(0, 7247, '\p{^Is_Script:_Lepcha}', "");
Expect(0, 7247, '\P{Is_Script:_Lepcha}', "");
Expect(1, 7247, '\P{^Is_Script:_Lepcha}', "");
Expect(0, 7248, '\p{Is_Script:_Lepcha}', "");
Expect(1, 7248, '\p{^Is_Script:_Lepcha}', "");
Expect(1, 7248, '\P{Is_Script:_Lepcha}', "");
Expect(0, 7248, '\P{^Is_Script:_Lepcha}', "");
Error('\p{Is_Sc= -Lepc:=}');
Error('\P{Is_Sc= -Lepc:=}');
Expect(1, 7247, '\p{Is_Sc:lepc}', "");
Expect(0, 7247, '\p{^Is_Sc:lepc}', "");
Expect(0, 7247, '\P{Is_Sc:lepc}', "");
Expect(1, 7247, '\P{^Is_Sc:lepc}', "");
Expect(0, 7248, '\p{Is_Sc:lepc}', "");
Expect(1, 7248, '\p{^Is_Sc:lepc}', "");
Expect(1, 7248, '\P{Is_Sc:lepc}', "");
Expect(0, 7248, '\P{^Is_Sc:lepc}', "");
Expect(1, 7247, '\p{Is_Sc=	Lepc}', "");
Expect(0, 7247, '\p{^Is_Sc=	Lepc}', "");
Expect(0, 7247, '\P{Is_Sc=	Lepc}', "");
Expect(1, 7247, '\P{^Is_Sc=	Lepc}', "");
Expect(0, 7248, '\p{Is_Sc=	Lepc}', "");
Expect(1, 7248, '\p{^Is_Sc=	Lepc}', "");
Expect(1, 7248, '\P{Is_Sc=	Lepc}', "");
Expect(0, 7248, '\P{^Is_Sc=	Lepc}', "");
Error('\p{Script=:=	-Limbu}');
Error('\P{Script=:=	-Limbu}');
Expect(1, 6479, '\p{Script=limbu}', "");
Expect(0, 6479, '\p{^Script=limbu}', "");
Expect(0, 6479, '\P{Script=limbu}', "");
Expect(1, 6479, '\P{^Script=limbu}', "");
Expect(0, 6480, '\p{Script=limbu}', "");
Expect(1, 6480, '\p{^Script=limbu}', "");
Expect(1, 6480, '\P{Script=limbu}', "");
Expect(0, 6480, '\P{^Script=limbu}', "");
Expect(1, 6479, '\p{Script=- limbu}', "");
Expect(0, 6479, '\p{^Script=- limbu}', "");
Expect(0, 6479, '\P{Script=- limbu}', "");
Expect(1, 6479, '\P{^Script=- limbu}', "");
Expect(0, 6480, '\p{Script=- limbu}', "");
Expect(1, 6480, '\p{^Script=- limbu}', "");
Expect(1, 6480, '\P{Script=- limbu}', "");
Expect(0, 6480, '\P{^Script=- limbu}', "");
Error('\p{Sc=/a/-	limb}');
Error('\P{Sc=/a/-	limb}');
Expect(1, 6479, '\p{Sc=limb}', "");
Expect(0, 6479, '\p{^Sc=limb}', "");
Expect(0, 6479, '\P{Sc=limb}', "");
Expect(1, 6479, '\P{^Sc=limb}', "");
Expect(0, 6480, '\p{Sc=limb}', "");
Expect(1, 6480, '\p{^Sc=limb}', "");
Expect(1, 6480, '\P{Sc=limb}', "");
Expect(0, 6480, '\P{^Sc=limb}', "");
Expect(1, 6479, '\p{Sc= _limb}', "");
Expect(0, 6479, '\p{^Sc= _limb}', "");
Expect(0, 6479, '\P{Sc= _limb}', "");
Expect(1, 6479, '\P{^Sc= _limb}', "");
Expect(0, 6480, '\p{Sc= _limb}', "");
Expect(1, 6480, '\p{^Sc= _limb}', "");
Expect(1, 6480, '\P{Sc= _limb}', "");
Expect(0, 6480, '\P{^Sc= _limb}', "");
Error('\p{Is_Script= :=Limbu}');
Error('\P{Is_Script= :=Limbu}');
Expect(1, 6479, '\p{Is_Script=limbu}', "");
Expect(0, 6479, '\p{^Is_Script=limbu}', "");
Expect(0, 6479, '\P{Is_Script=limbu}', "");
Expect(1, 6479, '\P{^Is_Script=limbu}', "");
Expect(0, 6480, '\p{Is_Script=limbu}', "");
Expect(1, 6480, '\p{^Is_Script=limbu}', "");
Expect(1, 6480, '\P{Is_Script=limbu}', "");
Expect(0, 6480, '\P{^Is_Script=limbu}', "");
Expect(1, 6479, '\p{Is_Script=		LIMBU}', "");
Expect(0, 6479, '\p{^Is_Script=		LIMBU}', "");
Expect(0, 6479, '\P{Is_Script=		LIMBU}', "");
Expect(1, 6479, '\P{^Is_Script=		LIMBU}', "");
Expect(0, 6480, '\p{Is_Script=		LIMBU}', "");
Expect(1, 6480, '\p{^Is_Script=		LIMBU}', "");
Expect(1, 6480, '\P{Is_Script=		LIMBU}', "");
Expect(0, 6480, '\P{^Is_Script=		LIMBU}', "");
Error('\p{Is_Sc=	 Limb:=}');
Error('\P{Is_Sc=	 Limb:=}');
Expect(1, 6479, '\p{Is_Sc=limb}', "");
Expect(0, 6479, '\p{^Is_Sc=limb}', "");
Expect(0, 6479, '\P{Is_Sc=limb}', "");
Expect(1, 6479, '\P{^Is_Sc=limb}', "");
Expect(0, 6480, '\p{Is_Sc=limb}', "");
Expect(1, 6480, '\p{^Is_Sc=limb}', "");
Expect(1, 6480, '\P{Is_Sc=limb}', "");
Expect(0, 6480, '\P{^Is_Sc=limb}', "");
Expect(1, 6479, '\p{Is_Sc=__Limb}', "");
Expect(0, 6479, '\p{^Is_Sc=__Limb}', "");
Expect(0, 6479, '\P{Is_Sc=__Limb}', "");
Expect(1, 6479, '\P{^Is_Sc=__Limb}', "");
Expect(0, 6480, '\p{Is_Sc=__Limb}', "");
Expect(1, 6480, '\p{^Is_Sc=__Limb}', "");
Expect(1, 6480, '\P{Is_Sc=__Limb}', "");
Expect(0, 6480, '\P{^Is_Sc=__Limb}', "");
Error('\p{Script=:=	_Linear_B}');
Error('\P{Script=:=	_Linear_B}');
Expect(1, 65786, '\p{Script=linearb}', "");
Expect(0, 65786, '\p{^Script=linearb}', "");
Expect(0, 65786, '\P{Script=linearb}', "");
Expect(1, 65786, '\P{^Script=linearb}', "");
Expect(0, 65787, '\p{Script=linearb}', "");
Expect(1, 65787, '\p{^Script=linearb}', "");
Expect(1, 65787, '\P{Script=linearb}', "");
Expect(0, 65787, '\P{^Script=linearb}', "");
Expect(1, 65786, '\p{Script=_	LINEAR_B}', "");
Expect(0, 65786, '\p{^Script=_	LINEAR_B}', "");
Expect(0, 65786, '\P{Script=_	LINEAR_B}', "");
Expect(1, 65786, '\P{^Script=_	LINEAR_B}', "");
Expect(0, 65787, '\p{Script=_	LINEAR_B}', "");
Expect(1, 65787, '\p{^Script=_	LINEAR_B}', "");
Expect(1, 65787, '\P{Script=_	LINEAR_B}', "");
Expect(0, 65787, '\P{^Script=_	LINEAR_B}', "");
Error('\p{Sc=/a/Linb}');
Error('\P{Sc=/a/Linb}');
Expect(1, 65786, '\p{Sc:	linb}', "");
Expect(0, 65786, '\p{^Sc:	linb}', "");
Expect(0, 65786, '\P{Sc:	linb}', "");
Expect(1, 65786, '\P{^Sc:	linb}', "");
Expect(0, 65787, '\p{Sc:	linb}', "");
Expect(1, 65787, '\p{^Sc:	linb}', "");
Expect(1, 65787, '\P{Sc:	linb}', "");
Expect(0, 65787, '\P{^Sc:	linb}', "");
Expect(1, 65786, '\p{Sc= Linb}', "");
Expect(0, 65786, '\p{^Sc= Linb}', "");
Expect(0, 65786, '\P{Sc= Linb}', "");
Expect(1, 65786, '\P{^Sc= Linb}', "");
Expect(0, 65787, '\p{Sc= Linb}', "");
Expect(1, 65787, '\p{^Sc= Linb}', "");
Expect(1, 65787, '\P{Sc= Linb}', "");
Expect(0, 65787, '\P{^Sc= Linb}', "");
Error('\p{Is_Script=:= Linear_B}');
Error('\P{Is_Script=:= Linear_B}');
Expect(1, 65786, '\p{Is_Script=linearb}', "");
Expect(0, 65786, '\p{^Is_Script=linearb}', "");
Expect(0, 65786, '\P{Is_Script=linearb}', "");
Expect(1, 65786, '\P{^Is_Script=linearb}', "");
Expect(0, 65787, '\p{Is_Script=linearb}', "");
Expect(1, 65787, '\p{^Is_Script=linearb}', "");
Expect(1, 65787, '\P{Is_Script=linearb}', "");
Expect(0, 65787, '\P{^Is_Script=linearb}', "");
Expect(1, 65786, '\p{Is_Script=-Linear_B}', "");
Expect(0, 65786, '\p{^Is_Script=-Linear_B}', "");
Expect(0, 65786, '\P{Is_Script=-Linear_B}', "");
Expect(1, 65786, '\P{^Is_Script=-Linear_B}', "");
Expect(0, 65787, '\p{Is_Script=-Linear_B}', "");
Expect(1, 65787, '\p{^Is_Script=-Linear_B}', "");
Expect(1, 65787, '\P{Is_Script=-Linear_B}', "");
Expect(0, 65787, '\P{^Is_Script=-Linear_B}', "");
Error('\p{Is_Sc= Linb:=}');
Error('\P{Is_Sc= Linb:=}');
Expect(1, 65786, '\p{Is_Sc=linb}', "");
Expect(0, 65786, '\p{^Is_Sc=linb}', "");
Expect(0, 65786, '\P{Is_Sc=linb}', "");
Expect(1, 65786, '\P{^Is_Sc=linb}', "");
Expect(0, 65787, '\p{Is_Sc=linb}', "");
Expect(1, 65787, '\p{^Is_Sc=linb}', "");
Expect(1, 65787, '\P{Is_Sc=linb}', "");
Expect(0, 65787, '\P{^Is_Sc=linb}', "");
Expect(1, 65786, '\p{Is_Sc=--LINB}', "");
Expect(0, 65786, '\p{^Is_Sc=--LINB}', "");
Expect(0, 65786, '\P{Is_Sc=--LINB}', "");
Expect(1, 65786, '\P{^Is_Sc=--LINB}', "");
Expect(0, 65787, '\p{Is_Sc=--LINB}', "");
Expect(1, 65787, '\p{^Is_Sc=--LINB}', "");
Expect(1, 65787, '\P{Is_Sc=--LINB}', "");
Expect(0, 65787, '\P{^Is_Sc=--LINB}', "");
Error('\p{Script=:=	lisu}');
Error('\P{Script=:=	lisu}');
Expect(1, 42239, '\p{Script=lisu}', "");
Expect(0, 42239, '\p{^Script=lisu}', "");
Expect(0, 42239, '\P{Script=lisu}', "");
Expect(1, 42239, '\P{^Script=lisu}', "");
Expect(0, 42240, '\p{Script=lisu}', "");
Expect(1, 42240, '\p{^Script=lisu}', "");
Expect(1, 42240, '\P{Script=lisu}', "");
Expect(0, 42240, '\P{^Script=lisu}', "");
Expect(1, 42239, '\p{Script=-_Lisu}', "");
Expect(0, 42239, '\p{^Script=-_Lisu}', "");
Expect(0, 42239, '\P{Script=-_Lisu}', "");
Expect(1, 42239, '\P{^Script=-_Lisu}', "");
Expect(0, 42240, '\p{Script=-_Lisu}', "");
Expect(1, 42240, '\p{^Script=-_Lisu}', "");
Expect(1, 42240, '\P{Script=-_Lisu}', "");
Expect(0, 42240, '\P{^Script=-_Lisu}', "");
Error('\p{Sc=	:=LISU}');
Error('\P{Sc=	:=LISU}');
Expect(1, 42239, '\p{Sc: lisu}', "");
Expect(0, 42239, '\p{^Sc: lisu}', "");
Expect(0, 42239, '\P{Sc: lisu}', "");
Expect(1, 42239, '\P{^Sc: lisu}', "");
Expect(0, 42240, '\p{Sc: lisu}', "");
Expect(1, 42240, '\p{^Sc: lisu}', "");
Expect(1, 42240, '\P{Sc: lisu}', "");
Expect(0, 42240, '\P{^Sc: lisu}', "");
Expect(1, 42239, '\p{Sc: 	lisu}', "");
Expect(0, 42239, '\p{^Sc: 	lisu}', "");
Expect(0, 42239, '\P{Sc: 	lisu}', "");
Expect(1, 42239, '\P{^Sc: 	lisu}', "");
Expect(0, 42240, '\p{Sc: 	lisu}', "");
Expect(1, 42240, '\p{^Sc: 	lisu}', "");
Expect(1, 42240, '\P{Sc: 	lisu}', "");
Expect(0, 42240, '\P{^Sc: 	lisu}', "");
Error('\p{Is_Script=-/a/LISU}');
Error('\P{Is_Script=-/a/LISU}');
Expect(1, 42239, '\p{Is_Script=lisu}', "");
Expect(0, 42239, '\p{^Is_Script=lisu}', "");
Expect(0, 42239, '\P{Is_Script=lisu}', "");
Expect(1, 42239, '\P{^Is_Script=lisu}', "");
Expect(0, 42240, '\p{Is_Script=lisu}', "");
Expect(1, 42240, '\p{^Is_Script=lisu}', "");
Expect(1, 42240, '\P{Is_Script=lisu}', "");
Expect(0, 42240, '\P{^Is_Script=lisu}', "");
Expect(1, 42239, '\p{Is_Script=_ LISU}', "");
Expect(0, 42239, '\p{^Is_Script=_ LISU}', "");
Expect(0, 42239, '\P{Is_Script=_ LISU}', "");
Expect(1, 42239, '\P{^Is_Script=_ LISU}', "");
Expect(0, 42240, '\p{Is_Script=_ LISU}', "");
Expect(1, 42240, '\p{^Is_Script=_ LISU}', "");
Expect(1, 42240, '\P{Is_Script=_ LISU}', "");
Expect(0, 42240, '\P{^Is_Script=_ LISU}', "");
Error('\p{Is_Sc: - LISU:=}');
Error('\P{Is_Sc: - LISU:=}');
Expect(1, 42239, '\p{Is_Sc=lisu}', "");
Expect(0, 42239, '\p{^Is_Sc=lisu}', "");
Expect(0, 42239, '\P{Is_Sc=lisu}', "");
Expect(1, 42239, '\P{^Is_Sc=lisu}', "");
Expect(0, 42240, '\p{Is_Sc=lisu}', "");
Expect(1, 42240, '\p{^Is_Sc=lisu}', "");
Expect(1, 42240, '\P{Is_Sc=lisu}', "");
Expect(0, 42240, '\P{^Is_Sc=lisu}', "");
Expect(1, 42239, '\p{Is_Sc= _lisu}', "");
Expect(0, 42239, '\p{^Is_Sc= _lisu}', "");
Expect(0, 42239, '\P{Is_Sc= _lisu}', "");
Expect(1, 42239, '\P{^Is_Sc= _lisu}', "");
Expect(0, 42240, '\p{Is_Sc= _lisu}', "");
Expect(1, 42240, '\p{^Is_Sc= _lisu}', "");
Expect(1, 42240, '\P{Is_Sc= _lisu}', "");
Expect(0, 42240, '\P{^Is_Sc= _lisu}', "");
Error('\p{Script=-_LYCIAN/a/}');
Error('\P{Script=-_LYCIAN/a/}');
Expect(1, 66204, '\p{Script=lycian}', "");
Expect(0, 66204, '\p{^Script=lycian}', "");
Expect(0, 66204, '\P{Script=lycian}', "");
Expect(1, 66204, '\P{^Script=lycian}', "");
Expect(0, 66205, '\p{Script=lycian}', "");
Expect(1, 66205, '\p{^Script=lycian}', "");
Expect(1, 66205, '\P{Script=lycian}', "");
Expect(0, 66205, '\P{^Script=lycian}', "");
Expect(1, 66204, '\p{Script=	LYCIAN}', "");
Expect(0, 66204, '\p{^Script=	LYCIAN}', "");
Expect(0, 66204, '\P{Script=	LYCIAN}', "");
Expect(1, 66204, '\P{^Script=	LYCIAN}', "");
Expect(0, 66205, '\p{Script=	LYCIAN}', "");
Expect(1, 66205, '\p{^Script=	LYCIAN}', "");
Expect(1, 66205, '\P{Script=	LYCIAN}', "");
Expect(0, 66205, '\P{^Script=	LYCIAN}', "");
Error('\p{Sc=:=	-lyci}');
Error('\P{Sc=:=	-lyci}');
Expect(1, 66204, '\p{Sc=lyci}', "");
Expect(0, 66204, '\p{^Sc=lyci}', "");
Expect(0, 66204, '\P{Sc=lyci}', "");
Expect(1, 66204, '\P{^Sc=lyci}', "");
Expect(0, 66205, '\p{Sc=lyci}', "");
Expect(1, 66205, '\p{^Sc=lyci}', "");
Expect(1, 66205, '\P{Sc=lyci}', "");
Expect(0, 66205, '\P{^Sc=lyci}', "");
Expect(1, 66204, '\p{Sc=-lyci}', "");
Expect(0, 66204, '\p{^Sc=-lyci}', "");
Expect(0, 66204, '\P{Sc=-lyci}', "");
Expect(1, 66204, '\P{^Sc=-lyci}', "");
Expect(0, 66205, '\p{Sc=-lyci}', "");
Expect(1, 66205, '\p{^Sc=-lyci}', "");
Expect(1, 66205, '\P{Sc=-lyci}', "");
Expect(0, 66205, '\P{^Sc=-lyci}', "");
Error('\p{Is_Script=	/a/LYCIAN}');
Error('\P{Is_Script=	/a/LYCIAN}');
Expect(1, 66204, '\p{Is_Script:	lycian}', "");
Expect(0, 66204, '\p{^Is_Script:	lycian}', "");
Expect(0, 66204, '\P{Is_Script:	lycian}', "");
Expect(1, 66204, '\P{^Is_Script:	lycian}', "");
Expect(0, 66205, '\p{Is_Script:	lycian}', "");
Expect(1, 66205, '\p{^Is_Script:	lycian}', "");
Expect(1, 66205, '\P{Is_Script:	lycian}', "");
Expect(0, 66205, '\P{^Is_Script:	lycian}', "");
Expect(1, 66204, '\p{Is_Script= Lycian}', "");
Expect(0, 66204, '\p{^Is_Script= Lycian}', "");
Expect(0, 66204, '\P{Is_Script= Lycian}', "");
Expect(1, 66204, '\P{^Is_Script= Lycian}', "");
Expect(0, 66205, '\p{Is_Script= Lycian}', "");
Expect(1, 66205, '\p{^Is_Script= Lycian}', "");
Expect(1, 66205, '\P{Is_Script= Lycian}', "");
Expect(0, 66205, '\P{^Is_Script= Lycian}', "");
Error('\p{Is_Sc=		Lyci/a/}');
Error('\P{Is_Sc=		Lyci/a/}');
Expect(1, 66204, '\p{Is_Sc=lyci}', "");
Expect(0, 66204, '\p{^Is_Sc=lyci}', "");
Expect(0, 66204, '\P{Is_Sc=lyci}', "");
Expect(1, 66204, '\P{^Is_Sc=lyci}', "");
Expect(0, 66205, '\p{Is_Sc=lyci}', "");
Expect(1, 66205, '\p{^Is_Sc=lyci}', "");
Expect(1, 66205, '\P{Is_Sc=lyci}', "");
Expect(0, 66205, '\P{^Is_Sc=lyci}', "");
Expect(1, 66204, '\p{Is_Sc= Lyci}', "");
Expect(0, 66204, '\p{^Is_Sc= Lyci}', "");
Expect(0, 66204, '\P{Is_Sc= Lyci}', "");
Expect(1, 66204, '\P{^Is_Sc= Lyci}', "");
Expect(0, 66205, '\p{Is_Sc= Lyci}', "");
Expect(1, 66205, '\p{^Is_Sc= Lyci}', "");
Expect(1, 66205, '\P{Is_Sc= Lyci}', "");
Expect(0, 66205, '\P{^Is_Sc= Lyci}', "");
Error('\p{Script=/a/LYDIAN}');
Error('\P{Script=/a/LYDIAN}');
Expect(1, 67903, '\p{Script=lydian}', "");
Expect(0, 67903, '\p{^Script=lydian}', "");
Expect(0, 67903, '\P{Script=lydian}', "");
Expect(1, 67903, '\P{^Script=lydian}', "");
Expect(0, 67904, '\p{Script=lydian}', "");
Expect(1, 67904, '\p{^Script=lydian}', "");
Expect(1, 67904, '\P{Script=lydian}', "");
Expect(0, 67904, '\P{^Script=lydian}', "");
Expect(1, 67903, '\p{Script=		Lydian}', "");
Expect(0, 67903, '\p{^Script=		Lydian}', "");
Expect(0, 67903, '\P{Script=		Lydian}', "");
Expect(1, 67903, '\P{^Script=		Lydian}', "");
Expect(0, 67904, '\p{Script=		Lydian}', "");
Expect(1, 67904, '\p{^Script=		Lydian}', "");
Expect(1, 67904, '\P{Script=		Lydian}', "");
Expect(0, 67904, '\P{^Script=		Lydian}', "");
Error('\p{Sc= 	Lydi/a/}');
Error('\P{Sc= 	Lydi/a/}');
Expect(1, 67903, '\p{Sc=lydi}', "");
Expect(0, 67903, '\p{^Sc=lydi}', "");
Expect(0, 67903, '\P{Sc=lydi}', "");
Expect(1, 67903, '\P{^Sc=lydi}', "");
Expect(0, 67904, '\p{Sc=lydi}', "");
Expect(1, 67904, '\p{^Sc=lydi}', "");
Expect(1, 67904, '\P{Sc=lydi}', "");
Expect(0, 67904, '\P{^Sc=lydi}', "");
Expect(1, 67903, '\p{Sc=--LYDI}', "");
Expect(0, 67903, '\p{^Sc=--LYDI}', "");
Expect(0, 67903, '\P{Sc=--LYDI}', "");
Expect(1, 67903, '\P{^Sc=--LYDI}', "");
Expect(0, 67904, '\p{Sc=--LYDI}', "");
Expect(1, 67904, '\p{^Sc=--LYDI}', "");
Expect(1, 67904, '\P{Sc=--LYDI}', "");
Expect(0, 67904, '\P{^Sc=--LYDI}', "");
Error('\p{Is_Script=_:=Lydian}');
Error('\P{Is_Script=_:=Lydian}');
Expect(1, 67903, '\p{Is_Script:	lydian}', "");
Expect(0, 67903, '\p{^Is_Script:	lydian}', "");
Expect(0, 67903, '\P{Is_Script:	lydian}', "");
Expect(1, 67903, '\P{^Is_Script:	lydian}', "");
Expect(0, 67904, '\p{Is_Script:	lydian}', "");
Expect(1, 67904, '\p{^Is_Script:	lydian}', "");
Expect(1, 67904, '\P{Is_Script:	lydian}', "");
Expect(0, 67904, '\P{^Is_Script:	lydian}', "");
Expect(1, 67903, '\p{Is_Script= 	Lydian}', "");
Expect(0, 67903, '\p{^Is_Script= 	Lydian}', "");
Expect(0, 67903, '\P{Is_Script= 	Lydian}', "");
Expect(1, 67903, '\P{^Is_Script= 	Lydian}', "");
Expect(0, 67904, '\p{Is_Script= 	Lydian}', "");
Expect(1, 67904, '\p{^Is_Script= 	Lydian}', "");
Expect(1, 67904, '\P{Is_Script= 	Lydian}', "");
Expect(0, 67904, '\P{^Is_Script= 	Lydian}', "");
Error('\p{Is_Sc=/a/_ lydi}');
Error('\P{Is_Sc=/a/_ lydi}');
Expect(1, 67903, '\p{Is_Sc=lydi}', "");
Expect(0, 67903, '\p{^Is_Sc=lydi}', "");
Expect(0, 67903, '\P{Is_Sc=lydi}', "");
Expect(1, 67903, '\P{^Is_Sc=lydi}', "");
Expect(0, 67904, '\p{Is_Sc=lydi}', "");
Expect(1, 67904, '\p{^Is_Sc=lydi}', "");
Expect(1, 67904, '\P{Is_Sc=lydi}', "");
Expect(0, 67904, '\P{^Is_Sc=lydi}', "");
Expect(1, 67903, '\p{Is_Sc:   	Lydi}', "");
Expect(0, 67903, '\p{^Is_Sc:   	Lydi}', "");
Expect(0, 67903, '\P{Is_Sc:   	Lydi}', "");
Expect(1, 67903, '\P{^Is_Sc:   	Lydi}', "");
Expect(0, 67904, '\p{Is_Sc:   	Lydi}', "");
Expect(1, 67904, '\p{^Is_Sc:   	Lydi}', "");
Expect(1, 67904, '\P{Is_Sc:   	Lydi}', "");
Expect(0, 67904, '\P{^Is_Sc:   	Lydi}', "");
Error('\p{Script= /a/mandaic}');
Error('\P{Script= /a/mandaic}');
Expect(1, 2142, '\p{Script=mandaic}', "");
Expect(0, 2142, '\p{^Script=mandaic}', "");
Expect(0, 2142, '\P{Script=mandaic}', "");
Expect(1, 2142, '\P{^Script=mandaic}', "");
Expect(0, 2143, '\p{Script=mandaic}', "");
Expect(1, 2143, '\p{^Script=mandaic}', "");
Expect(1, 2143, '\P{Script=mandaic}', "");
Expect(0, 2143, '\P{^Script=mandaic}', "");
Expect(1, 2142, '\p{Script=_-MANDAIC}', "");
Expect(0, 2142, '\p{^Script=_-MANDAIC}', "");
Expect(0, 2142, '\P{Script=_-MANDAIC}', "");
Expect(1, 2142, '\P{^Script=_-MANDAIC}', "");
Expect(0, 2143, '\p{Script=_-MANDAIC}', "");
Expect(1, 2143, '\p{^Script=_-MANDAIC}', "");
Expect(1, 2143, '\P{Script=_-MANDAIC}', "");
Expect(0, 2143, '\P{^Script=_-MANDAIC}', "");
Error('\p{Sc= :=Mand}');
Error('\P{Sc= :=Mand}');
Expect(1, 2142, '\p{Sc=mand}', "");
Expect(0, 2142, '\p{^Sc=mand}', "");
Expect(0, 2142, '\P{Sc=mand}', "");
Expect(1, 2142, '\P{^Sc=mand}', "");
Expect(0, 2143, '\p{Sc=mand}', "");
Expect(1, 2143, '\p{^Sc=mand}', "");
Expect(1, 2143, '\P{Sc=mand}', "");
Expect(0, 2143, '\P{^Sc=mand}', "");
Expect(1, 2142, '\p{Sc=_Mand}', "");
Expect(0, 2142, '\p{^Sc=_Mand}', "");
Expect(0, 2142, '\P{Sc=_Mand}', "");
Expect(1, 2142, '\P{^Sc=_Mand}', "");
Expect(0, 2143, '\p{Sc=_Mand}', "");
Expect(1, 2143, '\p{^Sc=_Mand}', "");
Expect(1, 2143, '\P{Sc=_Mand}', "");
Expect(0, 2143, '\P{^Sc=_Mand}', "");
Error('\p{Is_Script=/a/--MANDAIC}');
Error('\P{Is_Script=/a/--MANDAIC}');
Expect(1, 2142, '\p{Is_Script=mandaic}', "");
Expect(0, 2142, '\p{^Is_Script=mandaic}', "");
Expect(0, 2142, '\P{Is_Script=mandaic}', "");
Expect(1, 2142, '\P{^Is_Script=mandaic}', "");
Expect(0, 2143, '\p{Is_Script=mandaic}', "");
Expect(1, 2143, '\p{^Is_Script=mandaic}', "");
Expect(1, 2143, '\P{Is_Script=mandaic}', "");
Expect(0, 2143, '\P{^Is_Script=mandaic}', "");
Expect(1, 2142, '\p{Is_Script=-_Mandaic}', "");
Expect(0, 2142, '\p{^Is_Script=-_Mandaic}', "");
Expect(0, 2142, '\P{Is_Script=-_Mandaic}', "");
Expect(1, 2142, '\P{^Is_Script=-_Mandaic}', "");
Expect(0, 2143, '\p{Is_Script=-_Mandaic}', "");
Expect(1, 2143, '\p{^Is_Script=-_Mandaic}', "");
Expect(1, 2143, '\P{Is_Script=-_Mandaic}', "");
Expect(0, 2143, '\P{^Is_Script=-_Mandaic}', "");
Error('\p{Is_Sc= /a/mand}');
Error('\P{Is_Sc= /a/mand}');
Expect(1, 2142, '\p{Is_Sc=mand}', "");
Expect(0, 2142, '\p{^Is_Sc=mand}', "");
Expect(0, 2142, '\P{Is_Sc=mand}', "");
Expect(1, 2142, '\P{^Is_Sc=mand}', "");
Expect(0, 2143, '\p{Is_Sc=mand}', "");
Expect(1, 2143, '\p{^Is_Sc=mand}', "");
Expect(1, 2143, '\P{Is_Sc=mand}', "");
Expect(0, 2143, '\P{^Is_Sc=mand}', "");
Expect(1, 2142, '\p{Is_Sc= _MAND}', "");
Expect(0, 2142, '\p{^Is_Sc= _MAND}', "");
Expect(0, 2142, '\P{Is_Sc= _MAND}', "");
Expect(1, 2142, '\P{^Is_Sc= _MAND}', "");
Expect(0, 2143, '\p{Is_Sc= _MAND}', "");
Expect(1, 2143, '\p{^Is_Sc= _MAND}', "");
Expect(1, 2143, '\P{Is_Sc= _MAND}', "");
Expect(0, 2143, '\P{^Is_Sc= _MAND}', "");
Error('\p{Script:   /a/Meroitic_Cursive}');
Error('\P{Script:   /a/Meroitic_Cursive}');
Expect(1, 68031, '\p{Script=meroiticcursive}', "");
Expect(0, 68031, '\p{^Script=meroiticcursive}', "");
Expect(0, 68031, '\P{Script=meroiticcursive}', "");
Expect(1, 68031, '\P{^Script=meroiticcursive}', "");
Expect(0, 68032, '\p{Script=meroiticcursive}', "");
Expect(1, 68032, '\p{^Script=meroiticcursive}', "");
Expect(1, 68032, '\P{Script=meroiticcursive}', "");
Expect(0, 68032, '\P{^Script=meroiticcursive}', "");
Expect(1, 68031, '\p{Script=	 MEROITIC_Cursive}', "");
Expect(0, 68031, '\p{^Script=	 MEROITIC_Cursive}', "");
Expect(0, 68031, '\P{Script=	 MEROITIC_Cursive}', "");
Expect(1, 68031, '\P{^Script=	 MEROITIC_Cursive}', "");
Expect(0, 68032, '\p{Script=	 MEROITIC_Cursive}', "");
Expect(1, 68032, '\p{^Script=	 MEROITIC_Cursive}', "");
Expect(1, 68032, '\P{Script=	 MEROITIC_Cursive}', "");
Expect(0, 68032, '\P{^Script=	 MEROITIC_Cursive}', "");
Error('\p{Sc=-_MERC/a/}');
Error('\P{Sc=-_MERC/a/}');
Expect(1, 68031, '\p{Sc=merc}', "");
Expect(0, 68031, '\p{^Sc=merc}', "");
Expect(0, 68031, '\P{Sc=merc}', "");
Expect(1, 68031, '\P{^Sc=merc}', "");
Expect(0, 68032, '\p{Sc=merc}', "");
Expect(1, 68032, '\p{^Sc=merc}', "");
Expect(1, 68032, '\P{Sc=merc}', "");
Expect(0, 68032, '\P{^Sc=merc}', "");
Expect(1, 68031, '\p{Sc=- Merc}', "");
Expect(0, 68031, '\p{^Sc=- Merc}', "");
Expect(0, 68031, '\P{Sc=- Merc}', "");
Expect(1, 68031, '\P{^Sc=- Merc}', "");
Expect(0, 68032, '\p{Sc=- Merc}', "");
Expect(1, 68032, '\p{^Sc=- Merc}', "");
Expect(1, 68032, '\P{Sc=- Merc}', "");
Expect(0, 68032, '\P{^Sc=- Merc}', "");
Error('\p{Is_Script=/a/ meroitic_Cursive}');
Error('\P{Is_Script=/a/ meroitic_Cursive}');
Expect(1, 68031, '\p{Is_Script=meroiticcursive}', "");
Expect(0, 68031, '\p{^Is_Script=meroiticcursive}', "");
Expect(0, 68031, '\P{Is_Script=meroiticcursive}', "");
Expect(1, 68031, '\P{^Is_Script=meroiticcursive}', "");
Expect(0, 68032, '\p{Is_Script=meroiticcursive}', "");
Expect(1, 68032, '\p{^Is_Script=meroiticcursive}', "");
Expect(1, 68032, '\P{Is_Script=meroiticcursive}', "");
Expect(0, 68032, '\P{^Is_Script=meroiticcursive}', "");
Expect(1, 68031, '\p{Is_Script:   - meroitic_cursive}', "");
Expect(0, 68031, '\p{^Is_Script:   - meroitic_cursive}', "");
Expect(0, 68031, '\P{Is_Script:   - meroitic_cursive}', "");
Expect(1, 68031, '\P{^Is_Script:   - meroitic_cursive}', "");
Expect(0, 68032, '\p{Is_Script:   - meroitic_cursive}', "");
Expect(1, 68032, '\p{^Is_Script:   - meroitic_cursive}', "");
Expect(1, 68032, '\P{Is_Script:   - meroitic_cursive}', "");
Expect(0, 68032, '\P{^Is_Script:   - meroitic_cursive}', "");
Error('\p{Is_Sc=	:=MERC}');
Error('\P{Is_Sc=	:=MERC}');
Expect(1, 68031, '\p{Is_Sc=merc}', "");
Expect(0, 68031, '\p{^Is_Sc=merc}', "");
Expect(0, 68031, '\P{Is_Sc=merc}', "");
Expect(1, 68031, '\P{^Is_Sc=merc}', "");
Expect(0, 68032, '\p{Is_Sc=merc}', "");
Expect(1, 68032, '\p{^Is_Sc=merc}', "");
Expect(1, 68032, '\P{Is_Sc=merc}', "");
Expect(0, 68032, '\P{^Is_Sc=merc}', "");
Expect(1, 68031, '\p{Is_Sc=_-MERC}', "");
Expect(0, 68031, '\p{^Is_Sc=_-MERC}', "");
Expect(0, 68031, '\P{Is_Sc=_-MERC}', "");
Expect(1, 68031, '\P{^Is_Sc=_-MERC}', "");
Expect(0, 68032, '\p{Is_Sc=_-MERC}', "");
Expect(1, 68032, '\p{^Is_Sc=_-MERC}', "");
Expect(1, 68032, '\P{Is_Sc=_-MERC}', "");
Expect(0, 68032, '\P{^Is_Sc=_-MERC}', "");
Error('\p{Script=:=--Meroitic_Hieroglyphs}');
Error('\P{Script=:=--Meroitic_Hieroglyphs}');
Expect(1, 67999, '\p{Script=meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^Script=meroitichieroglyphs}', "");
Expect(0, 67999, '\P{Script=meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^Script=meroitichieroglyphs}', "");
Expect(0, 68000, '\p{Script=meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^Script=meroitichieroglyphs}', "");
Expect(1, 68000, '\P{Script=meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^Script=meroitichieroglyphs}', "");
Expect(1, 67999, '\p{Script=	 Meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\p{^Script=	 Meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\P{Script=	 Meroitic_Hieroglyphs}', "");
Expect(1, 67999, '\P{^Script=	 Meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\p{Script=	 Meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\p{^Script=	 Meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\P{Script=	 Meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\P{^Script=	 Meroitic_Hieroglyphs}', "");
Error('\p{Sc=:=_mero}');
Error('\P{Sc=:=_mero}');
Expect(1, 67999, '\p{Sc=mero}', "");
Expect(0, 67999, '\p{^Sc=mero}', "");
Expect(0, 67999, '\P{Sc=mero}', "");
Expect(1, 67999, '\P{^Sc=mero}', "");
Expect(0, 68000, '\p{Sc=mero}', "");
Expect(1, 68000, '\p{^Sc=mero}', "");
Expect(1, 68000, '\P{Sc=mero}', "");
Expect(0, 68000, '\P{^Sc=mero}', "");
Expect(1, 67999, '\p{Sc:  _Mero}', "");
Expect(0, 67999, '\p{^Sc:  _Mero}', "");
Expect(0, 67999, '\P{Sc:  _Mero}', "");
Expect(1, 67999, '\P{^Sc:  _Mero}', "");
Expect(0, 68000, '\p{Sc:  _Mero}', "");
Expect(1, 68000, '\p{^Sc:  _Mero}', "");
Expect(1, 68000, '\P{Sc:  _Mero}', "");
Expect(0, 68000, '\P{^Sc:  _Mero}', "");
Error('\p{Is_Script= :=meroitic_HIEROGLYPHS}');
Error('\P{Is_Script= :=meroitic_HIEROGLYPHS}');
Expect(1, 67999, '\p{Is_Script: meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^Is_Script: meroitichieroglyphs}', "");
Expect(0, 67999, '\P{Is_Script: meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^Is_Script: meroitichieroglyphs}', "");
Expect(0, 68000, '\p{Is_Script: meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^Is_Script: meroitichieroglyphs}', "");
Expect(1, 68000, '\P{Is_Script: meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^Is_Script: meroitichieroglyphs}', "");
Expect(1, 67999, '\p{Is_Script=__meroitic_HIEROGLYPHS}', "");
Expect(0, 67999, '\p{^Is_Script=__meroitic_HIEROGLYPHS}', "");
Expect(0, 67999, '\P{Is_Script=__meroitic_HIEROGLYPHS}', "");
Expect(1, 67999, '\P{^Is_Script=__meroitic_HIEROGLYPHS}', "");
Expect(0, 68000, '\p{Is_Script=__meroitic_HIEROGLYPHS}', "");
Expect(1, 68000, '\p{^Is_Script=__meroitic_HIEROGLYPHS}', "");
Expect(1, 68000, '\P{Is_Script=__meroitic_HIEROGLYPHS}', "");
Expect(0, 68000, '\P{^Is_Script=__meroitic_HIEROGLYPHS}', "");
Error('\p{Is_Sc=/a/_-mero}');
Error('\P{Is_Sc=/a/_-mero}');
Expect(1, 67999, '\p{Is_Sc=mero}', "");
Expect(0, 67999, '\p{^Is_Sc=mero}', "");
Expect(0, 67999, '\P{Is_Sc=mero}', "");
Expect(1, 67999, '\P{^Is_Sc=mero}', "");
Expect(0, 68000, '\p{Is_Sc=mero}', "");
Expect(1, 68000, '\p{^Is_Sc=mero}', "");
Expect(1, 68000, '\P{Is_Sc=mero}', "");
Expect(0, 68000, '\P{^Is_Sc=mero}', "");
Expect(1, 67999, '\p{Is_Sc=	-Mero}', "");
Expect(0, 67999, '\p{^Is_Sc=	-Mero}', "");
Expect(0, 67999, '\P{Is_Sc=	-Mero}', "");
Expect(1, 67999, '\P{^Is_Sc=	-Mero}', "");
Expect(0, 68000, '\p{Is_Sc=	-Mero}', "");
Expect(1, 68000, '\p{^Is_Sc=	-Mero}', "");
Expect(1, 68000, '\P{Is_Sc=	-Mero}', "");
Expect(0, 68000, '\P{^Is_Sc=	-Mero}', "");
Error('\p{Script:   _Malayalam:=}');
Error('\P{Script:   _Malayalam:=}');
Expect(1, 3455, '\p{Script=malayalam}', "");
Expect(0, 3455, '\p{^Script=malayalam}', "");
Expect(0, 3455, '\P{Script=malayalam}', "");
Expect(1, 3455, '\P{^Script=malayalam}', "");
Expect(0, 3456, '\p{Script=malayalam}', "");
Expect(1, 3456, '\p{^Script=malayalam}', "");
Expect(1, 3456, '\P{Script=malayalam}', "");
Expect(0, 3456, '\P{^Script=malayalam}', "");
Expect(1, 3455, '\p{Script=	MALAYALAM}', "");
Expect(0, 3455, '\p{^Script=	MALAYALAM}', "");
Expect(0, 3455, '\P{Script=	MALAYALAM}', "");
Expect(1, 3455, '\P{^Script=	MALAYALAM}', "");
Expect(0, 3456, '\p{Script=	MALAYALAM}', "");
Expect(1, 3456, '\p{^Script=	MALAYALAM}', "");
Expect(1, 3456, '\P{Script=	MALAYALAM}', "");
Expect(0, 3456, '\P{^Script=	MALAYALAM}', "");
Error('\p{Sc=:=	 Mlym}');
Error('\P{Sc=:=	 Mlym}');
Expect(1, 3455, '\p{Sc=mlym}', "");
Expect(0, 3455, '\p{^Sc=mlym}', "");
Expect(0, 3455, '\P{Sc=mlym}', "");
Expect(1, 3455, '\P{^Sc=mlym}', "");
Expect(0, 3456, '\p{Sc=mlym}', "");
Expect(1, 3456, '\p{^Sc=mlym}', "");
Expect(1, 3456, '\P{Sc=mlym}', "");
Expect(0, 3456, '\P{^Sc=mlym}', "");
Expect(1, 3455, '\p{Sc=-_Mlym}', "");
Expect(0, 3455, '\p{^Sc=-_Mlym}', "");
Expect(0, 3455, '\P{Sc=-_Mlym}', "");
Expect(1, 3455, '\P{^Sc=-_Mlym}', "");
Expect(0, 3456, '\p{Sc=-_Mlym}', "");
Expect(1, 3456, '\p{^Sc=-_Mlym}', "");
Expect(1, 3456, '\P{Sc=-_Mlym}', "");
Expect(0, 3456, '\P{^Sc=-_Mlym}', "");
Error('\p{Is_Script=- Malayalam/a/}');
Error('\P{Is_Script=- Malayalam/a/}');
Expect(1, 3455, '\p{Is_Script:   malayalam}', "");
Expect(0, 3455, '\p{^Is_Script:   malayalam}', "");
Expect(0, 3455, '\P{Is_Script:   malayalam}', "");
Expect(1, 3455, '\P{^Is_Script:   malayalam}', "");
Expect(0, 3456, '\p{Is_Script:   malayalam}', "");
Expect(1, 3456, '\p{^Is_Script:   malayalam}', "");
Expect(1, 3456, '\P{Is_Script:   malayalam}', "");
Expect(0, 3456, '\P{^Is_Script:   malayalam}', "");
Expect(1, 3455, '\p{Is_Script= 	Malayalam}', "");
Expect(0, 3455, '\p{^Is_Script= 	Malayalam}', "");
Expect(0, 3455, '\P{Is_Script= 	Malayalam}', "");
Expect(1, 3455, '\P{^Is_Script= 	Malayalam}', "");
Expect(0, 3456, '\p{Is_Script= 	Malayalam}', "");
Expect(1, 3456, '\p{^Is_Script= 	Malayalam}', "");
Expect(1, 3456, '\P{Is_Script= 	Malayalam}', "");
Expect(0, 3456, '\P{^Is_Script= 	Malayalam}', "");
Error('\p{Is_Sc:   _	Mlym/a/}');
Error('\P{Is_Sc:   _	Mlym/a/}');
Expect(1, 3455, '\p{Is_Sc=mlym}', "");
Expect(0, 3455, '\p{^Is_Sc=mlym}', "");
Expect(0, 3455, '\P{Is_Sc=mlym}', "");
Expect(1, 3455, '\P{^Is_Sc=mlym}', "");
Expect(0, 3456, '\p{Is_Sc=mlym}', "");
Expect(1, 3456, '\p{^Is_Sc=mlym}', "");
Expect(1, 3456, '\P{Is_Sc=mlym}', "");
Expect(0, 3456, '\P{^Is_Sc=mlym}', "");
Expect(1, 3455, '\p{Is_Sc=_Mlym}', "");
Expect(0, 3455, '\p{^Is_Sc=_Mlym}', "");
Expect(0, 3455, '\P{Is_Sc=_Mlym}', "");
Expect(1, 3455, '\P{^Is_Sc=_Mlym}', "");
Expect(0, 3456, '\p{Is_Sc=_Mlym}', "");
Expect(1, 3456, '\p{^Is_Sc=_Mlym}', "");
Expect(1, 3456, '\P{Is_Sc=_Mlym}', "");
Expect(0, 3456, '\P{^Is_Sc=_Mlym}', "");
Error('\p{Script=/a/_	Mongolian}');
Error('\P{Script=/a/_	Mongolian}');
Expect(1, 6314, '\p{Script=mongolian}', "");
Expect(0, 6314, '\p{^Script=mongolian}', "");
Expect(0, 6314, '\P{Script=mongolian}', "");
Expect(1, 6314, '\P{^Script=mongolian}', "");
Expect(0, 6315, '\p{Script=mongolian}', "");
Expect(1, 6315, '\p{^Script=mongolian}', "");
Expect(1, 6315, '\P{Script=mongolian}', "");
Expect(0, 6315, '\P{^Script=mongolian}', "");
Expect(1, 6314, '\p{Script=	_mongolian}', "");
Expect(0, 6314, '\p{^Script=	_mongolian}', "");
Expect(0, 6314, '\P{Script=	_mongolian}', "");
Expect(1, 6314, '\P{^Script=	_mongolian}', "");
Expect(0, 6315, '\p{Script=	_mongolian}', "");
Expect(1, 6315, '\p{^Script=	_mongolian}', "");
Expect(1, 6315, '\P{Script=	_mongolian}', "");
Expect(0, 6315, '\P{^Script=	_mongolian}', "");
Error('\p{Sc=	MONG:=}');
Error('\P{Sc=	MONG:=}');
Expect(1, 6314, '\p{Sc=mong}', "");
Expect(0, 6314, '\p{^Sc=mong}', "");
Expect(0, 6314, '\P{Sc=mong}', "");
Expect(1, 6314, '\P{^Sc=mong}', "");
Expect(0, 6315, '\p{Sc=mong}', "");
Expect(1, 6315, '\p{^Sc=mong}', "");
Expect(1, 6315, '\P{Sc=mong}', "");
Expect(0, 6315, '\P{^Sc=mong}', "");
Expect(1, 6314, '\p{Sc: 	Mong}', "");
Expect(0, 6314, '\p{^Sc: 	Mong}', "");
Expect(0, 6314, '\P{Sc: 	Mong}', "");
Expect(1, 6314, '\P{^Sc: 	Mong}', "");
Expect(0, 6315, '\p{Sc: 	Mong}', "");
Expect(1, 6315, '\p{^Sc: 	Mong}', "");
Expect(1, 6315, '\P{Sc: 	Mong}', "");
Expect(0, 6315, '\P{^Sc: 	Mong}', "");
Error('\p{Is_Script=:= 	Mongolian}');
Error('\P{Is_Script=:= 	Mongolian}');
Expect(1, 6314, '\p{Is_Script=mongolian}', "");
Expect(0, 6314, '\p{^Is_Script=mongolian}', "");
Expect(0, 6314, '\P{Is_Script=mongolian}', "");
Expect(1, 6314, '\P{^Is_Script=mongolian}', "");
Expect(0, 6315, '\p{Is_Script=mongolian}', "");
Expect(1, 6315, '\p{^Is_Script=mongolian}', "");
Expect(1, 6315, '\P{Is_Script=mongolian}', "");
Expect(0, 6315, '\P{^Is_Script=mongolian}', "");
Expect(1, 6314, '\p{Is_Script= -Mongolian}', "");
Expect(0, 6314, '\p{^Is_Script= -Mongolian}', "");
Expect(0, 6314, '\P{Is_Script= -Mongolian}', "");
Expect(1, 6314, '\P{^Is_Script= -Mongolian}', "");
Expect(0, 6315, '\p{Is_Script= -Mongolian}', "");
Expect(1, 6315, '\p{^Is_Script= -Mongolian}', "");
Expect(1, 6315, '\P{Is_Script= -Mongolian}', "");
Expect(0, 6315, '\P{^Is_Script= -Mongolian}', "");
Error('\p{Is_Sc: -Mong:=}');
Error('\P{Is_Sc: -Mong:=}');
Expect(1, 6314, '\p{Is_Sc=mong}', "");
Expect(0, 6314, '\p{^Is_Sc=mong}', "");
Expect(0, 6314, '\P{Is_Sc=mong}', "");
Expect(1, 6314, '\P{^Is_Sc=mong}', "");
Expect(0, 6315, '\p{Is_Sc=mong}', "");
Expect(1, 6315, '\p{^Is_Sc=mong}', "");
Expect(1, 6315, '\P{Is_Sc=mong}', "");
Expect(0, 6315, '\P{^Is_Sc=mong}', "");
Expect(1, 6314, '\p{Is_Sc=	Mong}', "");
Expect(0, 6314, '\p{^Is_Sc=	Mong}', "");
Expect(0, 6314, '\P{Is_Sc=	Mong}', "");
Expect(1, 6314, '\P{^Is_Sc=	Mong}', "");
Expect(0, 6315, '\p{Is_Sc=	Mong}', "");
Expect(1, 6315, '\p{^Is_Sc=	Mong}', "");
Expect(1, 6315, '\P{Is_Sc=	Mong}', "");
Expect(0, 6315, '\P{^Is_Sc=	Mong}', "");
Error('\p{Script=	/a/Meetei_mayek}');
Error('\P{Script=	/a/Meetei_mayek}');
Expect(1, 44025, '\p{Script=meeteimayek}', "");
Expect(0, 44025, '\p{^Script=meeteimayek}', "");
Expect(0, 44025, '\P{Script=meeteimayek}', "");
Expect(1, 44025, '\P{^Script=meeteimayek}', "");
Expect(0, 44026, '\p{Script=meeteimayek}', "");
Expect(1, 44026, '\p{^Script=meeteimayek}', "");
Expect(1, 44026, '\P{Script=meeteimayek}', "");
Expect(0, 44026, '\P{^Script=meeteimayek}', "");
Expect(1, 44025, '\p{Script=-	MEETEI_mayek}', "");
Expect(0, 44025, '\p{^Script=-	MEETEI_mayek}', "");
Expect(0, 44025, '\P{Script=-	MEETEI_mayek}', "");
Expect(1, 44025, '\P{^Script=-	MEETEI_mayek}', "");
Expect(0, 44026, '\p{Script=-	MEETEI_mayek}', "");
Expect(1, 44026, '\p{^Script=-	MEETEI_mayek}', "");
Expect(1, 44026, '\P{Script=-	MEETEI_mayek}', "");
Expect(0, 44026, '\P{^Script=-	MEETEI_mayek}', "");
Error('\p{Sc=:=_	MTEI}');
Error('\P{Sc=:=_	MTEI}');
Expect(1, 44025, '\p{Sc=mtei}', "");
Expect(0, 44025, '\p{^Sc=mtei}', "");
Expect(0, 44025, '\P{Sc=mtei}', "");
Expect(1, 44025, '\P{^Sc=mtei}', "");
Expect(0, 44026, '\p{Sc=mtei}', "");
Expect(1, 44026, '\p{^Sc=mtei}', "");
Expect(1, 44026, '\P{Sc=mtei}', "");
Expect(0, 44026, '\P{^Sc=mtei}', "");
Expect(1, 44025, '\p{Sc=	 Mtei}', "");
Expect(0, 44025, '\p{^Sc=	 Mtei}', "");
Expect(0, 44025, '\P{Sc=	 Mtei}', "");
Expect(1, 44025, '\P{^Sc=	 Mtei}', "");
Expect(0, 44026, '\p{Sc=	 Mtei}', "");
Expect(1, 44026, '\p{^Sc=	 Mtei}', "");
Expect(1, 44026, '\P{Sc=	 Mtei}', "");
Expect(0, 44026, '\P{^Sc=	 Mtei}', "");
Error('\p{Is_Script=	:=meetei_MAYEK}');
Error('\P{Is_Script=	:=meetei_MAYEK}');
Expect(1, 44025, '\p{Is_Script=meeteimayek}', "");
Expect(0, 44025, '\p{^Is_Script=meeteimayek}', "");
Expect(0, 44025, '\P{Is_Script=meeteimayek}', "");
Expect(1, 44025, '\P{^Is_Script=meeteimayek}', "");
Expect(0, 44026, '\p{Is_Script=meeteimayek}', "");
Expect(1, 44026, '\p{^Is_Script=meeteimayek}', "");
Expect(1, 44026, '\P{Is_Script=meeteimayek}', "");
Expect(0, 44026, '\P{^Is_Script=meeteimayek}', "");
Expect(1, 44025, '\p{Is_Script=	 Meetei_Mayek}', "");
Expect(0, 44025, '\p{^Is_Script=	 Meetei_Mayek}', "");
Expect(0, 44025, '\P{Is_Script=	 Meetei_Mayek}', "");
Expect(1, 44025, '\P{^Is_Script=	 Meetei_Mayek}', "");
Expect(0, 44026, '\p{Is_Script=	 Meetei_Mayek}', "");
Expect(1, 44026, '\p{^Is_Script=	 Meetei_Mayek}', "");
Expect(1, 44026, '\P{Is_Script=	 Meetei_Mayek}', "");
Expect(0, 44026, '\P{^Is_Script=	 Meetei_Mayek}', "");
Error('\p{Is_Sc=:=-mtei}');
Error('\P{Is_Sc=:=-mtei}');
Expect(1, 44025, '\p{Is_Sc=mtei}', "");
Expect(0, 44025, '\p{^Is_Sc=mtei}', "");
Expect(0, 44025, '\P{Is_Sc=mtei}', "");
Expect(1, 44025, '\P{^Is_Sc=mtei}', "");
Expect(0, 44026, '\p{Is_Sc=mtei}', "");
Expect(1, 44026, '\p{^Is_Sc=mtei}', "");
Expect(1, 44026, '\P{Is_Sc=mtei}', "");
Expect(0, 44026, '\P{^Is_Sc=mtei}', "");
Expect(1, 44025, '\p{Is_Sc=__Mtei}', "");
Expect(0, 44025, '\p{^Is_Sc=__Mtei}', "");
Expect(0, 44025, '\P{Is_Sc=__Mtei}', "");
Expect(1, 44025, '\P{^Is_Sc=__Mtei}', "");
Expect(0, 44026, '\p{Is_Sc=__Mtei}', "");
Expect(1, 44026, '\p{^Is_Sc=__Mtei}', "");
Expect(1, 44026, '\P{Is_Sc=__Mtei}', "");
Expect(0, 44026, '\P{^Is_Sc=__Mtei}', "");
Error('\p{Script=_/a/Myanmar}');
Error('\P{Script=_/a/Myanmar}');
Expect(1, 43643, '\p{Script=myanmar}', "");
Expect(0, 43643, '\p{^Script=myanmar}', "");
Expect(0, 43643, '\P{Script=myanmar}', "");
Expect(1, 43643, '\P{^Script=myanmar}', "");
Expect(0, 43644, '\p{Script=myanmar}', "");
Expect(1, 43644, '\p{^Script=myanmar}', "");
Expect(1, 43644, '\P{Script=myanmar}', "");
Expect(0, 43644, '\P{^Script=myanmar}', "");
Expect(1, 43643, '\p{Script=  myanmar}', "");
Expect(0, 43643, '\p{^Script=  myanmar}', "");
Expect(0, 43643, '\P{Script=  myanmar}', "");
Expect(1, 43643, '\P{^Script=  myanmar}', "");
Expect(0, 43644, '\p{Script=  myanmar}', "");
Expect(1, 43644, '\p{^Script=  myanmar}', "");
Expect(1, 43644, '\P{Script=  myanmar}', "");
Expect(0, 43644, '\P{^Script=  myanmar}', "");
Error('\p{Sc=/a/_mymr}');
Error('\P{Sc=/a/_mymr}');
Expect(1, 43643, '\p{Sc=mymr}', "");
Expect(0, 43643, '\p{^Sc=mymr}', "");
Expect(0, 43643, '\P{Sc=mymr}', "");
Expect(1, 43643, '\P{^Sc=mymr}', "");
Expect(0, 43644, '\p{Sc=mymr}', "");
Expect(1, 43644, '\p{^Sc=mymr}', "");
Expect(1, 43644, '\P{Sc=mymr}', "");
Expect(0, 43644, '\P{^Sc=mymr}', "");
Expect(1, 43643, '\p{Sc=	Mymr}', "");
Expect(0, 43643, '\p{^Sc=	Mymr}', "");
Expect(0, 43643, '\P{Sc=	Mymr}', "");
Expect(1, 43643, '\P{^Sc=	Mymr}', "");
Expect(0, 43644, '\p{Sc=	Mymr}', "");
Expect(1, 43644, '\p{^Sc=	Mymr}', "");
Expect(1, 43644, '\P{Sc=	Mymr}', "");
Expect(0, 43644, '\P{^Sc=	Mymr}', "");
Error('\p{Is_Script=	myanmar:=}');
Error('\P{Is_Script=	myanmar:=}');
Expect(1, 43643, '\p{Is_Script=myanmar}', "");
Expect(0, 43643, '\p{^Is_Script=myanmar}', "");
Expect(0, 43643, '\P{Is_Script=myanmar}', "");
Expect(1, 43643, '\P{^Is_Script=myanmar}', "");
Expect(0, 43644, '\p{Is_Script=myanmar}', "");
Expect(1, 43644, '\p{^Is_Script=myanmar}', "");
Expect(1, 43644, '\P{Is_Script=myanmar}', "");
Expect(0, 43644, '\P{^Is_Script=myanmar}', "");
Expect(1, 43643, '\p{Is_Script=_MYANMAR}', "");
Expect(0, 43643, '\p{^Is_Script=_MYANMAR}', "");
Expect(0, 43643, '\P{Is_Script=_MYANMAR}', "");
Expect(1, 43643, '\P{^Is_Script=_MYANMAR}', "");
Expect(0, 43644, '\p{Is_Script=_MYANMAR}', "");
Expect(1, 43644, '\p{^Is_Script=_MYANMAR}', "");
Expect(1, 43644, '\P{Is_Script=_MYANMAR}', "");
Expect(0, 43644, '\P{^Is_Script=_MYANMAR}', "");
Error('\p{Is_Sc=/a/__mymr}');
Error('\P{Is_Sc=/a/__mymr}');
Expect(1, 43643, '\p{Is_Sc=mymr}', "");
Expect(0, 43643, '\p{^Is_Sc=mymr}', "");
Expect(0, 43643, '\P{Is_Sc=mymr}', "");
Expect(1, 43643, '\P{^Is_Sc=mymr}', "");
Expect(0, 43644, '\p{Is_Sc=mymr}', "");
Expect(1, 43644, '\p{^Is_Sc=mymr}', "");
Expect(1, 43644, '\P{Is_Sc=mymr}', "");
Expect(0, 43644, '\P{^Is_Sc=mymr}', "");
Expect(1, 43643, '\p{Is_Sc=	-Mymr}', "");
Expect(0, 43643, '\p{^Is_Sc=	-Mymr}', "");
Expect(0, 43643, '\P{Is_Sc=	-Mymr}', "");
Expect(1, 43643, '\P{^Is_Sc=	-Mymr}', "");
Expect(0, 43644, '\p{Is_Sc=	-Mymr}', "");
Expect(1, 43644, '\p{^Is_Sc=	-Mymr}', "");
Expect(1, 43644, '\P{Is_Sc=	-Mymr}', "");
Expect(0, 43644, '\P{^Is_Sc=	-Mymr}', "");
Error('\p{Script:     Nko:=}');
Error('\P{Script:     Nko:=}');
Expect(1, 2042, '\p{Script=nko}', "");
Expect(0, 2042, '\p{^Script=nko}', "");
Expect(0, 2042, '\P{Script=nko}', "");
Expect(1, 2042, '\P{^Script=nko}', "");
Expect(0, 2043, '\p{Script=nko}', "");
Expect(1, 2043, '\p{^Script=nko}', "");
Expect(1, 2043, '\P{Script=nko}', "");
Expect(0, 2043, '\P{^Script=nko}', "");
Expect(1, 2042, '\p{Script= 	nko}', "");
Expect(0, 2042, '\p{^Script= 	nko}', "");
Expect(0, 2042, '\P{Script= 	nko}', "");
Expect(1, 2042, '\P{^Script= 	nko}', "");
Expect(0, 2043, '\p{Script= 	nko}', "");
Expect(1, 2043, '\p{^Script= 	nko}', "");
Expect(1, 2043, '\P{Script= 	nko}', "");
Expect(0, 2043, '\P{^Script= 	nko}', "");
Error('\p{Sc=-	NKOO:=}');
Error('\P{Sc=-	NKOO:=}');
Expect(1, 2042, '\p{Sc=nkoo}', "");
Expect(0, 2042, '\p{^Sc=nkoo}', "");
Expect(0, 2042, '\P{Sc=nkoo}', "");
Expect(1, 2042, '\P{^Sc=nkoo}', "");
Expect(0, 2043, '\p{Sc=nkoo}', "");
Expect(1, 2043, '\p{^Sc=nkoo}', "");
Expect(1, 2043, '\P{Sc=nkoo}', "");
Expect(0, 2043, '\P{^Sc=nkoo}', "");
Expect(1, 2042, '\p{Sc: 		Nkoo}', "");
Expect(0, 2042, '\p{^Sc: 		Nkoo}', "");
Expect(0, 2042, '\P{Sc: 		Nkoo}', "");
Expect(1, 2042, '\P{^Sc: 		Nkoo}', "");
Expect(0, 2043, '\p{Sc: 		Nkoo}', "");
Expect(1, 2043, '\p{^Sc: 		Nkoo}', "");
Expect(1, 2043, '\P{Sc: 		Nkoo}', "");
Expect(0, 2043, '\P{^Sc: 		Nkoo}', "");
Error('\p{Is_Script=/a/ _nko}');
Error('\P{Is_Script=/a/ _nko}');
Expect(1, 2042, '\p{Is_Script=nko}', "");
Expect(0, 2042, '\p{^Is_Script=nko}', "");
Expect(0, 2042, '\P{Is_Script=nko}', "");
Expect(1, 2042, '\P{^Is_Script=nko}', "");
Expect(0, 2043, '\p{Is_Script=nko}', "");
Expect(1, 2043, '\p{^Is_Script=nko}', "");
Expect(1, 2043, '\P{Is_Script=nko}', "");
Expect(0, 2043, '\P{^Is_Script=nko}', "");
Expect(1, 2042, '\p{Is_Script= -nko}', "");
Expect(0, 2042, '\p{^Is_Script= -nko}', "");
Expect(0, 2042, '\P{Is_Script= -nko}', "");
Expect(1, 2042, '\P{^Is_Script= -nko}', "");
Expect(0, 2043, '\p{Is_Script= -nko}', "");
Expect(1, 2043, '\p{^Is_Script= -nko}', "");
Expect(1, 2043, '\P{Is_Script= -nko}', "");
Expect(0, 2043, '\P{^Is_Script= -nko}', "");
Error('\p{Is_Sc=:=Nkoo}');
Error('\P{Is_Sc=:=Nkoo}');
Expect(1, 2042, '\p{Is_Sc=nkoo}', "");
Expect(0, 2042, '\p{^Is_Sc=nkoo}', "");
Expect(0, 2042, '\P{Is_Sc=nkoo}', "");
Expect(1, 2042, '\P{^Is_Sc=nkoo}', "");
Expect(0, 2043, '\p{Is_Sc=nkoo}', "");
Expect(1, 2043, '\p{^Is_Sc=nkoo}', "");
Expect(1, 2043, '\P{Is_Sc=nkoo}', "");
Expect(0, 2043, '\P{^Is_Sc=nkoo}', "");
Expect(1, 2042, '\p{Is_Sc=_NKOO}', "");
Expect(0, 2042, '\p{^Is_Sc=_NKOO}', "");
Expect(0, 2042, '\P{Is_Sc=_NKOO}', "");
Expect(1, 2042, '\P{^Is_Sc=_NKOO}', "");
Expect(0, 2043, '\p{Is_Sc=_NKOO}', "");
Expect(1, 2043, '\p{^Is_Sc=_NKOO}', "");
Expect(1, 2043, '\P{Is_Sc=_NKOO}', "");
Expect(0, 2043, '\P{^Is_Sc=_NKOO}', "");
Error('\p{Script=-:=OGHAM}');
Error('\P{Script=-:=OGHAM}');
Expect(1, 5788, '\p{Script=ogham}', "");
Expect(0, 5788, '\p{^Script=ogham}', "");
Expect(0, 5788, '\P{Script=ogham}', "");
Expect(1, 5788, '\P{^Script=ogham}', "");
Expect(0, 5789, '\p{Script=ogham}', "");
Expect(1, 5789, '\p{^Script=ogham}', "");
Expect(1, 5789, '\P{Script=ogham}', "");
Expect(0, 5789, '\P{^Script=ogham}', "");
Expect(1, 5788, '\p{Script= OGHAM}', "");
Expect(0, 5788, '\p{^Script= OGHAM}', "");
Expect(0, 5788, '\P{Script= OGHAM}', "");
Expect(1, 5788, '\P{^Script= OGHAM}', "");
Expect(0, 5789, '\p{Script= OGHAM}', "");
Expect(1, 5789, '\p{^Script= OGHAM}', "");
Expect(1, 5789, '\P{Script= OGHAM}', "");
Expect(0, 5789, '\P{^Script= OGHAM}', "");
Error('\p{Sc=:= -ogam}');
Error('\P{Sc=:= -ogam}');
Expect(1, 5788, '\p{Sc:ogam}', "");
Expect(0, 5788, '\p{^Sc:ogam}', "");
Expect(0, 5788, '\P{Sc:ogam}', "");
Expect(1, 5788, '\P{^Sc:ogam}', "");
Expect(0, 5789, '\p{Sc:ogam}', "");
Expect(1, 5789, '\p{^Sc:ogam}', "");
Expect(1, 5789, '\P{Sc:ogam}', "");
Expect(0, 5789, '\P{^Sc:ogam}', "");
Expect(1, 5788, '\p{Sc=--Ogam}', "");
Expect(0, 5788, '\p{^Sc=--Ogam}', "");
Expect(0, 5788, '\P{Sc=--Ogam}', "");
Expect(1, 5788, '\P{^Sc=--Ogam}', "");
Expect(0, 5789, '\p{Sc=--Ogam}', "");
Expect(1, 5789, '\p{^Sc=--Ogam}', "");
Expect(1, 5789, '\P{Sc=--Ogam}', "");
Expect(0, 5789, '\P{^Sc=--Ogam}', "");
Error('\p{Is_Script= 	Ogham/a/}');
Error('\P{Is_Script= 	Ogham/a/}');
Expect(1, 5788, '\p{Is_Script=ogham}', "");
Expect(0, 5788, '\p{^Is_Script=ogham}', "");
Expect(0, 5788, '\P{Is_Script=ogham}', "");
Expect(1, 5788, '\P{^Is_Script=ogham}', "");
Expect(0, 5789, '\p{Is_Script=ogham}', "");
Expect(1, 5789, '\p{^Is_Script=ogham}', "");
Expect(1, 5789, '\P{Is_Script=ogham}', "");
Expect(0, 5789, '\P{^Is_Script=ogham}', "");
Expect(1, 5788, '\p{Is_Script=	 Ogham}', "");
Expect(0, 5788, '\p{^Is_Script=	 Ogham}', "");
Expect(0, 5788, '\P{Is_Script=	 Ogham}', "");
Expect(1, 5788, '\P{^Is_Script=	 Ogham}', "");
Expect(0, 5789, '\p{Is_Script=	 Ogham}', "");
Expect(1, 5789, '\p{^Is_Script=	 Ogham}', "");
Expect(1, 5789, '\P{Is_Script=	 Ogham}', "");
Expect(0, 5789, '\P{^Is_Script=	 Ogham}', "");
Error('\p{Is_Sc=_ogam/a/}');
Error('\P{Is_Sc=_ogam/a/}');
Expect(1, 5788, '\p{Is_Sc:ogam}', "");
Expect(0, 5788, '\p{^Is_Sc:ogam}', "");
Expect(0, 5788, '\P{Is_Sc:ogam}', "");
Expect(1, 5788, '\P{^Is_Sc:ogam}', "");
Expect(0, 5789, '\p{Is_Sc:ogam}', "");
Expect(1, 5789, '\p{^Is_Sc:ogam}', "");
Expect(1, 5789, '\P{Is_Sc:ogam}', "");
Expect(0, 5789, '\P{^Is_Sc:ogam}', "");
Expect(1, 5788, '\p{Is_Sc=	OGAM}', "");
Expect(0, 5788, '\p{^Is_Sc=	OGAM}', "");
Expect(0, 5788, '\P{Is_Sc=	OGAM}', "");
Expect(1, 5788, '\P{^Is_Sc=	OGAM}', "");
Expect(0, 5789, '\p{Is_Sc=	OGAM}', "");
Expect(1, 5789, '\p{^Is_Sc=	OGAM}', "");
Expect(1, 5789, '\P{Is_Sc=	OGAM}', "");
Expect(0, 5789, '\P{^Is_Sc=	OGAM}', "");
Error('\p{Script= /a/ol_Chiki}');
Error('\P{Script= /a/ol_Chiki}');
Expect(1, 7295, '\p{Script: olchiki}', "");
Expect(0, 7295, '\p{^Script: olchiki}', "");
Expect(0, 7295, '\P{Script: olchiki}', "");
Expect(1, 7295, '\P{^Script: olchiki}', "");
Expect(0, 7296, '\p{Script: olchiki}', "");
Expect(1, 7296, '\p{^Script: olchiki}', "");
Expect(1, 7296, '\P{Script: olchiki}', "");
Expect(0, 7296, '\P{^Script: olchiki}', "");
Expect(1, 7295, '\p{Script:- Ol_Chiki}', "");
Expect(0, 7295, '\p{^Script:- Ol_Chiki}', "");
Expect(0, 7295, '\P{Script:- Ol_Chiki}', "");
Expect(1, 7295, '\P{^Script:- Ol_Chiki}', "");
Expect(0, 7296, '\p{Script:- Ol_Chiki}', "");
Expect(1, 7296, '\p{^Script:- Ol_Chiki}', "");
Expect(1, 7296, '\P{Script:- Ol_Chiki}', "");
Expect(0, 7296, '\P{^Script:- Ol_Chiki}', "");
Error('\p{Sc=/a/_	olck}');
Error('\P{Sc=/a/_	olck}');
Expect(1, 7295, '\p{Sc=olck}', "");
Expect(0, 7295, '\p{^Sc=olck}', "");
Expect(0, 7295, '\P{Sc=olck}', "");
Expect(1, 7295, '\P{^Sc=olck}', "");
Expect(0, 7296, '\p{Sc=olck}', "");
Expect(1, 7296, '\p{^Sc=olck}', "");
Expect(1, 7296, '\P{Sc=olck}', "");
Expect(0, 7296, '\P{^Sc=olck}', "");
Expect(1, 7295, '\p{Sc= 	olck}', "");
Expect(0, 7295, '\p{^Sc= 	olck}', "");
Expect(0, 7295, '\P{Sc= 	olck}', "");
Expect(1, 7295, '\P{^Sc= 	olck}', "");
Expect(0, 7296, '\p{Sc= 	olck}', "");
Expect(1, 7296, '\p{^Sc= 	olck}', "");
Expect(1, 7296, '\P{Sc= 	olck}', "");
Expect(0, 7296, '\P{^Sc= 	olck}', "");
Error('\p{Is_Script=:= -Ol_chiki}');
Error('\P{Is_Script=:= -Ol_chiki}');
Expect(1, 7295, '\p{Is_Script=olchiki}', "");
Expect(0, 7295, '\p{^Is_Script=olchiki}', "");
Expect(0, 7295, '\P{Is_Script=olchiki}', "");
Expect(1, 7295, '\P{^Is_Script=olchiki}', "");
Expect(0, 7296, '\p{Is_Script=olchiki}', "");
Expect(1, 7296, '\p{^Is_Script=olchiki}', "");
Expect(1, 7296, '\P{Is_Script=olchiki}', "");
Expect(0, 7296, '\P{^Is_Script=olchiki}', "");
Expect(1, 7295, '\p{Is_Script=	OL_chiki}', "");
Expect(0, 7295, '\p{^Is_Script=	OL_chiki}', "");
Expect(0, 7295, '\P{Is_Script=	OL_chiki}', "");
Expect(1, 7295, '\P{^Is_Script=	OL_chiki}', "");
Expect(0, 7296, '\p{Is_Script=	OL_chiki}', "");
Expect(1, 7296, '\p{^Is_Script=	OL_chiki}', "");
Expect(1, 7296, '\P{Is_Script=	OL_chiki}', "");
Expect(0, 7296, '\P{^Is_Script=	OL_chiki}', "");
Error('\p{Is_Sc=		olck:=}');
Error('\P{Is_Sc=		olck:=}');
Expect(1, 7295, '\p{Is_Sc=olck}', "");
Expect(0, 7295, '\p{^Is_Sc=olck}', "");
Expect(0, 7295, '\P{Is_Sc=olck}', "");
Expect(1, 7295, '\P{^Is_Sc=olck}', "");
Expect(0, 7296, '\p{Is_Sc=olck}', "");
Expect(1, 7296, '\p{^Is_Sc=olck}', "");
Expect(1, 7296, '\P{Is_Sc=olck}', "");
Expect(0, 7296, '\P{^Is_Sc=olck}', "");
Expect(1, 7295, '\p{Is_Sc=__Olck}', "");
Expect(0, 7295, '\p{^Is_Sc=__Olck}', "");
Expect(0, 7295, '\P{Is_Sc=__Olck}', "");
Expect(1, 7295, '\P{^Is_Sc=__Olck}', "");
Expect(0, 7296, '\p{Is_Sc=__Olck}', "");
Expect(1, 7296, '\p{^Is_Sc=__Olck}', "");
Expect(1, 7296, '\P{Is_Sc=__Olck}', "");
Expect(0, 7296, '\P{^Is_Sc=__Olck}', "");
Error('\p{Script=	:=OLD_TURKIC}');
Error('\P{Script=	:=OLD_TURKIC}');
Expect(1, 68680, '\p{Script=oldturkic}', "");
Expect(0, 68680, '\p{^Script=oldturkic}', "");
Expect(0, 68680, '\P{Script=oldturkic}', "");
Expect(1, 68680, '\P{^Script=oldturkic}', "");
Expect(0, 68681, '\p{Script=oldturkic}', "");
Expect(1, 68681, '\p{^Script=oldturkic}', "");
Expect(1, 68681, '\P{Script=oldturkic}', "");
Expect(0, 68681, '\P{^Script=oldturkic}', "");
Expect(1, 68680, '\p{Script=	Old_Turkic}', "");
Expect(0, 68680, '\p{^Script=	Old_Turkic}', "");
Expect(0, 68680, '\P{Script=	Old_Turkic}', "");
Expect(1, 68680, '\P{^Script=	Old_Turkic}', "");
Expect(0, 68681, '\p{Script=	Old_Turkic}', "");
Expect(1, 68681, '\p{^Script=	Old_Turkic}', "");
Expect(1, 68681, '\P{Script=	Old_Turkic}', "");
Expect(0, 68681, '\P{^Script=	Old_Turkic}', "");
Error('\p{Sc= -orkh:=}');
Error('\P{Sc= -orkh:=}');
Expect(1, 68680, '\p{Sc=orkh}', "");
Expect(0, 68680, '\p{^Sc=orkh}', "");
Expect(0, 68680, '\P{Sc=orkh}', "");
Expect(1, 68680, '\P{^Sc=orkh}', "");
Expect(0, 68681, '\p{Sc=orkh}', "");
Expect(1, 68681, '\p{^Sc=orkh}', "");
Expect(1, 68681, '\P{Sc=orkh}', "");
Expect(0, 68681, '\P{^Sc=orkh}', "");
Expect(1, 68680, '\p{Sc= 	orkh}', "");
Expect(0, 68680, '\p{^Sc= 	orkh}', "");
Expect(0, 68680, '\P{Sc= 	orkh}', "");
Expect(1, 68680, '\P{^Sc= 	orkh}', "");
Expect(0, 68681, '\p{Sc= 	orkh}', "");
Expect(1, 68681, '\p{^Sc= 	orkh}', "");
Expect(1, 68681, '\P{Sc= 	orkh}', "");
Expect(0, 68681, '\P{^Sc= 	orkh}', "");
Error('\p{Is_Script:   :=old_Turkic}');
Error('\P{Is_Script:   :=old_Turkic}');
Expect(1, 68680, '\p{Is_Script=oldturkic}', "");
Expect(0, 68680, '\p{^Is_Script=oldturkic}', "");
Expect(0, 68680, '\P{Is_Script=oldturkic}', "");
Expect(1, 68680, '\P{^Is_Script=oldturkic}', "");
Expect(0, 68681, '\p{Is_Script=oldturkic}', "");
Expect(1, 68681, '\p{^Is_Script=oldturkic}', "");
Expect(1, 68681, '\P{Is_Script=oldturkic}', "");
Expect(0, 68681, '\P{^Is_Script=oldturkic}', "");
Expect(1, 68680, '\p{Is_Script=_old_turkic}', "");
Expect(0, 68680, '\p{^Is_Script=_old_turkic}', "");
Expect(0, 68680, '\P{Is_Script=_old_turkic}', "");
Expect(1, 68680, '\P{^Is_Script=_old_turkic}', "");
Expect(0, 68681, '\p{Is_Script=_old_turkic}', "");
Expect(1, 68681, '\p{^Is_Script=_old_turkic}', "");
Expect(1, 68681, '\P{Is_Script=_old_turkic}', "");
Expect(0, 68681, '\P{^Is_Script=_old_turkic}', "");
Error('\p{Is_Sc=/a/ orkh}');
Error('\P{Is_Sc=/a/ orkh}');
Expect(1, 68680, '\p{Is_Sc=orkh}', "");
Expect(0, 68680, '\p{^Is_Sc=orkh}', "");
Expect(0, 68680, '\P{Is_Sc=orkh}', "");
Expect(1, 68680, '\P{^Is_Sc=orkh}', "");
Expect(0, 68681, '\p{Is_Sc=orkh}', "");
Expect(1, 68681, '\p{^Is_Sc=orkh}', "");
Expect(1, 68681, '\P{Is_Sc=orkh}', "");
Expect(0, 68681, '\P{^Is_Sc=orkh}', "");
Expect(1, 68680, '\p{Is_Sc=-	Orkh}', "");
Expect(0, 68680, '\p{^Is_Sc=-	Orkh}', "");
Expect(0, 68680, '\P{Is_Sc=-	Orkh}', "");
Expect(1, 68680, '\P{^Is_Sc=-	Orkh}', "");
Expect(0, 68681, '\p{Is_Sc=-	Orkh}', "");
Expect(1, 68681, '\p{^Is_Sc=-	Orkh}', "");
Expect(1, 68681, '\P{Is_Sc=-	Orkh}', "");
Expect(0, 68681, '\P{^Is_Sc=-	Orkh}', "");
Error('\p{Script=- oriya:=}');
Error('\P{Script=- oriya:=}');
Expect(1, 2935, '\p{Script:	oriya}', "");
Expect(0, 2935, '\p{^Script:	oriya}', "");
Expect(0, 2935, '\P{Script:	oriya}', "");
Expect(1, 2935, '\P{^Script:	oriya}', "");
Expect(0, 2936, '\p{Script:	oriya}', "");
Expect(1, 2936, '\p{^Script:	oriya}', "");
Expect(1, 2936, '\P{Script:	oriya}', "");
Expect(0, 2936, '\P{^Script:	oriya}', "");
Expect(1, 2935, '\p{Script:		Oriya}', "");
Expect(0, 2935, '\p{^Script:		Oriya}', "");
Expect(0, 2935, '\P{Script:		Oriya}', "");
Expect(1, 2935, '\P{^Script:		Oriya}', "");
Expect(0, 2936, '\p{Script:		Oriya}', "");
Expect(1, 2936, '\p{^Script:		Oriya}', "");
Expect(1, 2936, '\P{Script:		Oriya}', "");
Expect(0, 2936, '\P{^Script:		Oriya}', "");
Error('\p{Sc=:=	ORYA}');
Error('\P{Sc=:=	ORYA}');
Expect(1, 2935, '\p{Sc=orya}', "");
Expect(0, 2935, '\p{^Sc=orya}', "");
Expect(0, 2935, '\P{Sc=orya}', "");
Expect(1, 2935, '\P{^Sc=orya}', "");
Expect(0, 2936, '\p{Sc=orya}', "");
Expect(1, 2936, '\p{^Sc=orya}', "");
Expect(1, 2936, '\P{Sc=orya}', "");
Expect(0, 2936, '\P{^Sc=orya}', "");
Expect(1, 2935, '\p{Sc=-	Orya}', "");
Expect(0, 2935, '\p{^Sc=-	Orya}', "");
Expect(0, 2935, '\P{Sc=-	Orya}', "");
Expect(1, 2935, '\P{^Sc=-	Orya}', "");
Expect(0, 2936, '\p{Sc=-	Orya}', "");
Expect(1, 2936, '\p{^Sc=-	Orya}', "");
Expect(1, 2936, '\P{Sc=-	Orya}', "");
Expect(0, 2936, '\P{^Sc=-	Orya}', "");
Error('\p{Is_Script: /a/	 oriya}');
Error('\P{Is_Script: /a/	 oriya}');
Expect(1, 2935, '\p{Is_Script=oriya}', "");
Expect(0, 2935, '\p{^Is_Script=oriya}', "");
Expect(0, 2935, '\P{Is_Script=oriya}', "");
Expect(1, 2935, '\P{^Is_Script=oriya}', "");
Expect(0, 2936, '\p{Is_Script=oriya}', "");
Expect(1, 2936, '\p{^Is_Script=oriya}', "");
Expect(1, 2936, '\P{Is_Script=oriya}', "");
Expect(0, 2936, '\P{^Is_Script=oriya}', "");
Expect(1, 2935, '\p{Is_Script= Oriya}', "");
Expect(0, 2935, '\p{^Is_Script= Oriya}', "");
Expect(0, 2935, '\P{Is_Script= Oriya}', "");
Expect(1, 2935, '\P{^Is_Script= Oriya}', "");
Expect(0, 2936, '\p{Is_Script= Oriya}', "");
Expect(1, 2936, '\p{^Is_Script= Oriya}', "");
Expect(1, 2936, '\P{Is_Script= Oriya}', "");
Expect(0, 2936, '\P{^Is_Script= Oriya}', "");
Error('\p{Is_Sc=  Orya:=}');
Error('\P{Is_Sc=  Orya:=}');
Expect(1, 2935, '\p{Is_Sc=orya}', "");
Expect(0, 2935, '\p{^Is_Sc=orya}', "");
Expect(0, 2935, '\P{Is_Sc=orya}', "");
Expect(1, 2935, '\P{^Is_Sc=orya}', "");
Expect(0, 2936, '\p{Is_Sc=orya}', "");
Expect(1, 2936, '\p{^Is_Sc=orya}', "");
Expect(1, 2936, '\P{Is_Sc=orya}', "");
Expect(0, 2936, '\P{^Is_Sc=orya}', "");
Expect(1, 2935, '\p{Is_Sc=	_ORYA}', "");
Expect(0, 2935, '\p{^Is_Sc=	_ORYA}', "");
Expect(0, 2935, '\P{Is_Sc=	_ORYA}', "");
Expect(1, 2935, '\P{^Is_Sc=	_ORYA}', "");
Expect(0, 2936, '\p{Is_Sc=	_ORYA}', "");
Expect(1, 2936, '\p{^Is_Sc=	_ORYA}', "");
Expect(1, 2936, '\P{Is_Sc=	_ORYA}', "");
Expect(0, 2936, '\P{^Is_Sc=	_ORYA}', "");
Error('\p{Script=:= -Osmanya}');
Error('\P{Script=:= -Osmanya}');
Expect(1, 66729, '\p{Script=osmanya}', "");
Expect(0, 66729, '\p{^Script=osmanya}', "");
Expect(0, 66729, '\P{Script=osmanya}', "");
Expect(1, 66729, '\P{^Script=osmanya}', "");
Expect(0, 66730, '\p{Script=osmanya}', "");
Expect(1, 66730, '\p{^Script=osmanya}', "");
Expect(1, 66730, '\P{Script=osmanya}', "");
Expect(0, 66730, '\P{^Script=osmanya}', "");
Expect(1, 66729, '\p{Script=__OSMANYA}', "");
Expect(0, 66729, '\p{^Script=__OSMANYA}', "");
Expect(0, 66729, '\P{Script=__OSMANYA}', "");
Expect(1, 66729, '\P{^Script=__OSMANYA}', "");
Expect(0, 66730, '\p{Script=__OSMANYA}', "");
Expect(1, 66730, '\p{^Script=__OSMANYA}', "");
Expect(1, 66730, '\P{Script=__OSMANYA}', "");
Expect(0, 66730, '\P{^Script=__OSMANYA}', "");
Error('\p{Sc: __Osma/a/}');
Error('\P{Sc: __Osma/a/}');
Expect(1, 66729, '\p{Sc=osma}', "");
Expect(0, 66729, '\p{^Sc=osma}', "");
Expect(0, 66729, '\P{Sc=osma}', "");
Expect(1, 66729, '\P{^Sc=osma}', "");
Expect(0, 66730, '\p{Sc=osma}', "");
Expect(1, 66730, '\p{^Sc=osma}', "");
Expect(1, 66730, '\P{Sc=osma}', "");
Expect(0, 66730, '\P{^Sc=osma}', "");
Expect(1, 66729, '\p{Sc=  Osma}', "");
Expect(0, 66729, '\p{^Sc=  Osma}', "");
Expect(0, 66729, '\P{Sc=  Osma}', "");
Expect(1, 66729, '\P{^Sc=  Osma}', "");
Expect(0, 66730, '\p{Sc=  Osma}', "");
Expect(1, 66730, '\p{^Sc=  Osma}', "");
Expect(1, 66730, '\P{Sc=  Osma}', "");
Expect(0, 66730, '\P{^Sc=  Osma}', "");
Error('\p{Is_Script=	osmanya/a/}');
Error('\P{Is_Script=	osmanya/a/}');
Expect(1, 66729, '\p{Is_Script: osmanya}', "");
Expect(0, 66729, '\p{^Is_Script: osmanya}', "");
Expect(0, 66729, '\P{Is_Script: osmanya}', "");
Expect(1, 66729, '\P{^Is_Script: osmanya}', "");
Expect(0, 66730, '\p{Is_Script: osmanya}', "");
Expect(1, 66730, '\p{^Is_Script: osmanya}', "");
Expect(1, 66730, '\P{Is_Script: osmanya}', "");
Expect(0, 66730, '\P{^Is_Script: osmanya}', "");
Expect(1, 66729, '\p{Is_Script=- Osmanya}', "");
Expect(0, 66729, '\p{^Is_Script=- Osmanya}', "");
Expect(0, 66729, '\P{Is_Script=- Osmanya}', "");
Expect(1, 66729, '\P{^Is_Script=- Osmanya}', "");
Expect(0, 66730, '\p{Is_Script=- Osmanya}', "");
Expect(1, 66730, '\p{^Is_Script=- Osmanya}', "");
Expect(1, 66730, '\P{Is_Script=- Osmanya}', "");
Expect(0, 66730, '\P{^Is_Script=- Osmanya}', "");
Error('\p{Is_Sc=:=	Osma}');
Error('\P{Is_Sc=:=	Osma}');
Expect(1, 66729, '\p{Is_Sc: osma}', "");
Expect(0, 66729, '\p{^Is_Sc: osma}', "");
Expect(0, 66729, '\P{Is_Sc: osma}', "");
Expect(1, 66729, '\P{^Is_Sc: osma}', "");
Expect(0, 66730, '\p{Is_Sc: osma}', "");
Expect(1, 66730, '\p{^Is_Sc: osma}', "");
Expect(1, 66730, '\P{Is_Sc: osma}', "");
Expect(0, 66730, '\P{^Is_Sc: osma}', "");
Expect(1, 66729, '\p{Is_Sc= 	OSMA}', "");
Expect(0, 66729, '\p{^Is_Sc= 	OSMA}', "");
Expect(0, 66729, '\P{Is_Sc= 	OSMA}', "");
Expect(1, 66729, '\P{^Is_Sc= 	OSMA}', "");
Expect(0, 66730, '\p{Is_Sc= 	OSMA}', "");
Expect(1, 66730, '\p{^Is_Sc= 	OSMA}', "");
Expect(1, 66730, '\P{Is_Sc= 	OSMA}', "");
Expect(0, 66730, '\P{^Is_Sc= 	OSMA}', "");
Error('\p{Script=:=-phags_PA}');
Error('\P{Script=:=-phags_PA}');
Expect(1, 43127, '\p{Script=phagspa}', "");
Expect(0, 43127, '\p{^Script=phagspa}', "");
Expect(0, 43127, '\P{Script=phagspa}', "");
Expect(1, 43127, '\P{^Script=phagspa}', "");
Expect(0, 43128, '\p{Script=phagspa}', "");
Expect(1, 43128, '\p{^Script=phagspa}', "");
Expect(1, 43128, '\P{Script=phagspa}', "");
Expect(0, 43128, '\P{^Script=phagspa}', "");
Expect(1, 43127, '\p{Script:	Phags_Pa}', "");
Expect(0, 43127, '\p{^Script:	Phags_Pa}', "");
Expect(0, 43127, '\P{Script:	Phags_Pa}', "");
Expect(1, 43127, '\P{^Script:	Phags_Pa}', "");
Expect(0, 43128, '\p{Script:	Phags_Pa}', "");
Expect(1, 43128, '\p{^Script:	Phags_Pa}', "");
Expect(1, 43128, '\P{Script:	Phags_Pa}', "");
Expect(0, 43128, '\P{^Script:	Phags_Pa}', "");
Error('\p{Sc=_phag:=}');
Error('\P{Sc=_phag:=}');
Expect(1, 43127, '\p{Sc=phag}', "");
Expect(0, 43127, '\p{^Sc=phag}', "");
Expect(0, 43127, '\P{Sc=phag}', "");
Expect(1, 43127, '\P{^Sc=phag}', "");
Expect(0, 43128, '\p{Sc=phag}', "");
Expect(1, 43128, '\p{^Sc=phag}', "");
Expect(1, 43128, '\P{Sc=phag}', "");
Expect(0, 43128, '\P{^Sc=phag}', "");
Expect(1, 43127, '\p{Sc:	 PHAG}', "");
Expect(0, 43127, '\p{^Sc:	 PHAG}', "");
Expect(0, 43127, '\P{Sc:	 PHAG}', "");
Expect(1, 43127, '\P{^Sc:	 PHAG}', "");
Expect(0, 43128, '\p{Sc:	 PHAG}', "");
Expect(1, 43128, '\p{^Sc:	 PHAG}', "");
Expect(1, 43128, '\P{Sc:	 PHAG}', "");
Expect(0, 43128, '\P{^Sc:	 PHAG}', "");
Error('\p{Is_Script=_/a/Phags_PA}');
Error('\P{Is_Script=_/a/Phags_PA}');
Expect(1, 43127, '\p{Is_Script=phagspa}', "");
Expect(0, 43127, '\p{^Is_Script=phagspa}', "");
Expect(0, 43127, '\P{Is_Script=phagspa}', "");
Expect(1, 43127, '\P{^Is_Script=phagspa}', "");
Expect(0, 43128, '\p{Is_Script=phagspa}', "");
Expect(1, 43128, '\p{^Is_Script=phagspa}', "");
Expect(1, 43128, '\P{Is_Script=phagspa}', "");
Expect(0, 43128, '\P{^Is_Script=phagspa}', "");
Expect(1, 43127, '\p{Is_Script=-Phags_Pa}', "");
Expect(0, 43127, '\p{^Is_Script=-Phags_Pa}', "");
Expect(0, 43127, '\P{Is_Script=-Phags_Pa}', "");
Expect(1, 43127, '\P{^Is_Script=-Phags_Pa}', "");
Expect(0, 43128, '\p{Is_Script=-Phags_Pa}', "");
Expect(1, 43128, '\p{^Is_Script=-Phags_Pa}', "");
Expect(1, 43128, '\P{Is_Script=-Phags_Pa}', "");
Expect(0, 43128, '\P{^Is_Script=-Phags_Pa}', "");
Error('\p{Is_Sc=	-PHAG:=}');
Error('\P{Is_Sc=	-PHAG:=}');
Expect(1, 43127, '\p{Is_Sc=phag}', "");
Expect(0, 43127, '\p{^Is_Sc=phag}', "");
Expect(0, 43127, '\P{Is_Sc=phag}', "");
Expect(1, 43127, '\P{^Is_Sc=phag}', "");
Expect(0, 43128, '\p{Is_Sc=phag}', "");
Expect(1, 43128, '\p{^Is_Sc=phag}', "");
Expect(1, 43128, '\P{Is_Sc=phag}', "");
Expect(0, 43128, '\P{^Is_Sc=phag}', "");
Expect(1, 43127, '\p{Is_Sc=	PHAG}', "");
Expect(0, 43127, '\p{^Is_Sc=	PHAG}', "");
Expect(0, 43127, '\P{Is_Sc=	PHAG}', "");
Expect(1, 43127, '\P{^Is_Sc=	PHAG}', "");
Expect(0, 43128, '\p{Is_Sc=	PHAG}', "");
Expect(1, 43128, '\p{^Is_Sc=	PHAG}', "");
Expect(1, 43128, '\P{Is_Sc=	PHAG}', "");
Expect(0, 43128, '\P{^Is_Sc=	PHAG}', "");
Error('\p{Script=/a/_ inscriptional_Pahlavi}');
Error('\P{Script=/a/_ inscriptional_Pahlavi}');
Expect(1, 68479, '\p{Script=inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^Script=inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{Script=inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^Script=inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{Script=inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^Script=inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{Script=inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^Script=inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{Script: -	inscriptional_PAHLAVI}', "");
Expect(0, 68479, '\p{^Script: -	inscriptional_PAHLAVI}', "");
Expect(0, 68479, '\P{Script: -	inscriptional_PAHLAVI}', "");
Expect(1, 68479, '\P{^Script: -	inscriptional_PAHLAVI}', "");
Expect(0, 68480, '\p{Script: -	inscriptional_PAHLAVI}', "");
Expect(1, 68480, '\p{^Script: -	inscriptional_PAHLAVI}', "");
Expect(1, 68480, '\P{Script: -	inscriptional_PAHLAVI}', "");
Expect(0, 68480, '\P{^Script: -	inscriptional_PAHLAVI}', "");
Error('\p{Sc: -phli:=}');
Error('\P{Sc: -phli:=}');
Expect(1, 68479, '\p{Sc=phli}', "");
Expect(0, 68479, '\p{^Sc=phli}', "");
Expect(0, 68479, '\P{Sc=phli}', "");
Expect(1, 68479, '\P{^Sc=phli}', "");
Expect(0, 68480, '\p{Sc=phli}', "");
Expect(1, 68480, '\p{^Sc=phli}', "");
Expect(1, 68480, '\P{Sc=phli}', "");
Expect(0, 68480, '\P{^Sc=phli}', "");
Expect(1, 68479, '\p{Sc= -phli}', "");
Expect(0, 68479, '\p{^Sc= -phli}', "");
Expect(0, 68479, '\P{Sc= -phli}', "");
Expect(1, 68479, '\P{^Sc= -phli}', "");
Expect(0, 68480, '\p{Sc= -phli}', "");
Expect(1, 68480, '\p{^Sc= -phli}', "");
Expect(1, 68480, '\P{Sc= -phli}', "");
Expect(0, 68480, '\P{^Sc= -phli}', "");
Error('\p{Is_Script=	:=Inscriptional_Pahlavi}');
Error('\P{Is_Script=	:=Inscriptional_Pahlavi}');
Expect(1, 68479, '\p{Is_Script=inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^Is_Script=inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{Is_Script=inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^Is_Script=inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{Is_Script=inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^Is_Script=inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{Is_Script=inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^Is_Script=inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{Is_Script=_Inscriptional_Pahlavi}', "");
Expect(0, 68479, '\p{^Is_Script=_Inscriptional_Pahlavi}', "");
Expect(0, 68479, '\P{Is_Script=_Inscriptional_Pahlavi}', "");
Expect(1, 68479, '\P{^Is_Script=_Inscriptional_Pahlavi}', "");
Expect(0, 68480, '\p{Is_Script=_Inscriptional_Pahlavi}', "");
Expect(1, 68480, '\p{^Is_Script=_Inscriptional_Pahlavi}', "");
Expect(1, 68480, '\P{Is_Script=_Inscriptional_Pahlavi}', "");
Expect(0, 68480, '\P{^Is_Script=_Inscriptional_Pahlavi}', "");
Error('\p{Is_Sc= -phli:=}');
Error('\P{Is_Sc= -phli:=}');
Expect(1, 68479, '\p{Is_Sc=phli}', "");
Expect(0, 68479, '\p{^Is_Sc=phli}', "");
Expect(0, 68479, '\P{Is_Sc=phli}', "");
Expect(1, 68479, '\P{^Is_Sc=phli}', "");
Expect(0, 68480, '\p{Is_Sc=phli}', "");
Expect(1, 68480, '\p{^Is_Sc=phli}', "");
Expect(1, 68480, '\P{Is_Sc=phli}', "");
Expect(0, 68480, '\P{^Is_Sc=phli}', "");
Expect(1, 68479, '\p{Is_Sc=_-phli}', "");
Expect(0, 68479, '\p{^Is_Sc=_-phli}', "");
Expect(0, 68479, '\P{Is_Sc=_-phli}', "");
Expect(1, 68479, '\P{^Is_Sc=_-phli}', "");
Expect(0, 68480, '\p{Is_Sc=_-phli}', "");
Expect(1, 68480, '\p{^Is_Sc=_-phli}', "");
Expect(1, 68480, '\P{Is_Sc=_-phli}', "");
Expect(0, 68480, '\P{^Is_Sc=_-phli}', "");
Error('\p{Script=/a/Phoenician}');
Error('\P{Script=/a/Phoenician}');
Expect(1, 67871, '\p{Script=phoenician}', "");
Expect(0, 67871, '\p{^Script=phoenician}', "");
Expect(0, 67871, '\P{Script=phoenician}', "");
Expect(1, 67871, '\P{^Script=phoenician}', "");
Expect(0, 67872, '\p{Script=phoenician}', "");
Expect(1, 67872, '\p{^Script=phoenician}', "");
Expect(1, 67872, '\P{Script=phoenician}', "");
Expect(0, 67872, '\P{^Script=phoenician}', "");
Expect(1, 67871, '\p{Script=__PHOENICIAN}', "");
Expect(0, 67871, '\p{^Script=__PHOENICIAN}', "");
Expect(0, 67871, '\P{Script=__PHOENICIAN}', "");
Expect(1, 67871, '\P{^Script=__PHOENICIAN}', "");
Expect(0, 67872, '\p{Script=__PHOENICIAN}', "");
Expect(1, 67872, '\p{^Script=__PHOENICIAN}', "");
Expect(1, 67872, '\P{Script=__PHOENICIAN}', "");
Expect(0, 67872, '\P{^Script=__PHOENICIAN}', "");
Error('\p{Sc=__PHNX/a/}');
Error('\P{Sc=__PHNX/a/}');
Expect(1, 67871, '\p{Sc=phnx}', "");
Expect(0, 67871, '\p{^Sc=phnx}', "");
Expect(0, 67871, '\P{Sc=phnx}', "");
Expect(1, 67871, '\P{^Sc=phnx}', "");
Expect(0, 67872, '\p{Sc=phnx}', "");
Expect(1, 67872, '\p{^Sc=phnx}', "");
Expect(1, 67872, '\P{Sc=phnx}', "");
Expect(0, 67872, '\P{^Sc=phnx}', "");
Expect(1, 67871, '\p{Sc= 	PHNX}', "");
Expect(0, 67871, '\p{^Sc= 	PHNX}', "");
Expect(0, 67871, '\P{Sc= 	PHNX}', "");
Expect(1, 67871, '\P{^Sc= 	PHNX}', "");
Expect(0, 67872, '\p{Sc= 	PHNX}', "");
Expect(1, 67872, '\p{^Sc= 	PHNX}', "");
Expect(1, 67872, '\P{Sc= 	PHNX}', "");
Expect(0, 67872, '\P{^Sc= 	PHNX}', "");
Error('\p{Is_Script=:=		Phoenician}');
Error('\P{Is_Script=:=		Phoenician}');
Expect(1, 67871, '\p{Is_Script=phoenician}', "");
Expect(0, 67871, '\p{^Is_Script=phoenician}', "");
Expect(0, 67871, '\P{Is_Script=phoenician}', "");
Expect(1, 67871, '\P{^Is_Script=phoenician}', "");
Expect(0, 67872, '\p{Is_Script=phoenician}', "");
Expect(1, 67872, '\p{^Is_Script=phoenician}', "");
Expect(1, 67872, '\P{Is_Script=phoenician}', "");
Expect(0, 67872, '\P{^Is_Script=phoenician}', "");
Expect(1, 67871, '\p{Is_Script=	-phoenician}', "");
Expect(0, 67871, '\p{^Is_Script=	-phoenician}', "");
Expect(0, 67871, '\P{Is_Script=	-phoenician}', "");
Expect(1, 67871, '\P{^Is_Script=	-phoenician}', "");
Expect(0, 67872, '\p{Is_Script=	-phoenician}', "");
Expect(1, 67872, '\p{^Is_Script=	-phoenician}', "");
Expect(1, 67872, '\P{Is_Script=	-phoenician}', "");
Expect(0, 67872, '\P{^Is_Script=	-phoenician}', "");
Error('\p{Is_Sc= :=Phnx}');
Error('\P{Is_Sc= :=Phnx}');
Expect(1, 67871, '\p{Is_Sc=phnx}', "");
Expect(0, 67871, '\p{^Is_Sc=phnx}', "");
Expect(0, 67871, '\P{Is_Sc=phnx}', "");
Expect(1, 67871, '\P{^Is_Sc=phnx}', "");
Expect(0, 67872, '\p{Is_Sc=phnx}', "");
Expect(1, 67872, '\p{^Is_Sc=phnx}', "");
Expect(1, 67872, '\P{Is_Sc=phnx}', "");
Expect(0, 67872, '\P{^Is_Sc=phnx}', "");
Expect(1, 67871, '\p{Is_Sc=-PHNX}', "");
Expect(0, 67871, '\p{^Is_Sc=-PHNX}', "");
Expect(0, 67871, '\P{Is_Sc=-PHNX}', "");
Expect(1, 67871, '\P{^Is_Sc=-PHNX}', "");
Expect(0, 67872, '\p{Is_Sc=-PHNX}', "");
Expect(1, 67872, '\p{^Is_Sc=-PHNX}', "");
Expect(1, 67872, '\P{Is_Sc=-PHNX}', "");
Expect(0, 67872, '\P{^Is_Sc=-PHNX}', "");
Error('\p{Script=_Miao/a/}');
Error('\P{Script=_Miao/a/}');
Expect(1, 94111, '\p{Script=miao}', "");
Expect(0, 94111, '\p{^Script=miao}', "");
Expect(0, 94111, '\P{Script=miao}', "");
Expect(1, 94111, '\P{^Script=miao}', "");
Expect(0, 94112, '\p{Script=miao}', "");
Expect(1, 94112, '\p{^Script=miao}', "");
Expect(1, 94112, '\P{Script=miao}', "");
Expect(0, 94112, '\P{^Script=miao}', "");
Expect(1, 94111, '\p{Script=_Miao}', "");
Expect(0, 94111, '\p{^Script=_Miao}', "");
Expect(0, 94111, '\P{Script=_Miao}', "");
Expect(1, 94111, '\P{^Script=_Miao}', "");
Expect(0, 94112, '\p{Script=_Miao}', "");
Expect(1, 94112, '\p{^Script=_Miao}', "");
Expect(1, 94112, '\P{Script=_Miao}', "");
Expect(0, 94112, '\P{^Script=_Miao}', "");
Error('\p{Sc=_:=Plrd}');
Error('\P{Sc=_:=Plrd}');
Expect(1, 94111, '\p{Sc=plrd}', "");
Expect(0, 94111, '\p{^Sc=plrd}', "");
Expect(0, 94111, '\P{Sc=plrd}', "");
Expect(1, 94111, '\P{^Sc=plrd}', "");
Expect(0, 94112, '\p{Sc=plrd}', "");
Expect(1, 94112, '\p{^Sc=plrd}', "");
Expect(1, 94112, '\P{Sc=plrd}', "");
Expect(0, 94112, '\P{^Sc=plrd}', "");
Expect(1, 94111, '\p{Sc: -_plrd}', "");
Expect(0, 94111, '\p{^Sc: -_plrd}', "");
Expect(0, 94111, '\P{Sc: -_plrd}', "");
Expect(1, 94111, '\P{^Sc: -_plrd}', "");
Expect(0, 94112, '\p{Sc: -_plrd}', "");
Expect(1, 94112, '\p{^Sc: -_plrd}', "");
Expect(1, 94112, '\P{Sc: -_plrd}', "");
Expect(0, 94112, '\P{^Sc: -_plrd}', "");
Error('\p{Is_Script=	:=Miao}');
Error('\P{Is_Script=	:=Miao}');
Expect(1, 94111, '\p{Is_Script=miao}', "");
Expect(0, 94111, '\p{^Is_Script=miao}', "");
Expect(0, 94111, '\P{Is_Script=miao}', "");
Expect(1, 94111, '\P{^Is_Script=miao}', "");
Expect(0, 94112, '\p{Is_Script=miao}', "");
Expect(1, 94112, '\p{^Is_Script=miao}', "");
Expect(1, 94112, '\P{Is_Script=miao}', "");
Expect(0, 94112, '\P{^Is_Script=miao}', "");
Expect(1, 94111, '\p{Is_Script=		Miao}', "");
Expect(0, 94111, '\p{^Is_Script=		Miao}', "");
Expect(0, 94111, '\P{Is_Script=		Miao}', "");
Expect(1, 94111, '\P{^Is_Script=		Miao}', "");
Expect(0, 94112, '\p{Is_Script=		Miao}', "");
Expect(1, 94112, '\p{^Is_Script=		Miao}', "");
Expect(1, 94112, '\P{Is_Script=		Miao}', "");
Expect(0, 94112, '\P{^Is_Script=		Miao}', "");
Error('\p{Is_Sc= -plrd/a/}');
Error('\P{Is_Sc= -plrd/a/}');
Expect(1, 94111, '\p{Is_Sc=plrd}', "");
Expect(0, 94111, '\p{^Is_Sc=plrd}', "");
Expect(0, 94111, '\P{Is_Sc=plrd}', "");
Expect(1, 94111, '\P{^Is_Sc=plrd}', "");
Expect(0, 94112, '\p{Is_Sc=plrd}', "");
Expect(1, 94112, '\p{^Is_Sc=plrd}', "");
Expect(1, 94112, '\P{Is_Sc=plrd}', "");
Expect(0, 94112, '\P{^Is_Sc=plrd}', "");
Expect(1, 94111, '\p{Is_Sc:   --Plrd}', "");
Expect(0, 94111, '\p{^Is_Sc:   --Plrd}', "");
Expect(0, 94111, '\P{Is_Sc:   --Plrd}', "");
Expect(1, 94111, '\P{^Is_Sc:   --Plrd}', "");
Expect(0, 94112, '\p{Is_Sc:   --Plrd}', "");
Expect(1, 94112, '\p{^Is_Sc:   --Plrd}', "");
Expect(1, 94112, '\P{Is_Sc:   --Plrd}', "");
Expect(0, 94112, '\P{^Is_Sc:   --Plrd}', "");
Error('\p{Script=:=inscriptional_PARTHIAN}');
Error('\P{Script=:=inscriptional_PARTHIAN}');
Expect(1, 68447, '\p{Script=inscriptionalparthian}', "");
Expect(0, 68447, '\p{^Script=inscriptionalparthian}', "");
Expect(0, 68447, '\P{Script=inscriptionalparthian}', "");
Expect(1, 68447, '\P{^Script=inscriptionalparthian}', "");
Expect(0, 68448, '\p{Script=inscriptionalparthian}', "");
Expect(1, 68448, '\p{^Script=inscriptionalparthian}', "");
Expect(1, 68448, '\P{Script=inscriptionalparthian}', "");
Expect(0, 68448, '\P{^Script=inscriptionalparthian}', "");
Expect(1, 68447, '\p{Script= INSCRIPTIONAL_Parthian}', "");
Expect(0, 68447, '\p{^Script= INSCRIPTIONAL_Parthian}', "");
Expect(0, 68447, '\P{Script= INSCRIPTIONAL_Parthian}', "");
Expect(1, 68447, '\P{^Script= INSCRIPTIONAL_Parthian}', "");
Expect(0, 68448, '\p{Script= INSCRIPTIONAL_Parthian}', "");
Expect(1, 68448, '\p{^Script= INSCRIPTIONAL_Parthian}', "");
Expect(1, 68448, '\P{Script= INSCRIPTIONAL_Parthian}', "");
Expect(0, 68448, '\P{^Script= INSCRIPTIONAL_Parthian}', "");
Error('\p{Sc:/a/ Prti}');
Error('\P{Sc:/a/ Prti}');
Expect(1, 68447, '\p{Sc=prti}', "");
Expect(0, 68447, '\p{^Sc=prti}', "");
Expect(0, 68447, '\P{Sc=prti}', "");
Expect(1, 68447, '\P{^Sc=prti}', "");
Expect(0, 68448, '\p{Sc=prti}', "");
Expect(1, 68448, '\p{^Sc=prti}', "");
Expect(1, 68448, '\P{Sc=prti}', "");
Expect(0, 68448, '\P{^Sc=prti}', "");
Expect(1, 68447, '\p{Sc=- PRTI}', "");
Expect(0, 68447, '\p{^Sc=- PRTI}', "");
Expect(0, 68447, '\P{Sc=- PRTI}', "");
Expect(1, 68447, '\P{^Sc=- PRTI}', "");
Expect(0, 68448, '\p{Sc=- PRTI}', "");
Expect(1, 68448, '\p{^Sc=- PRTI}', "");
Expect(1, 68448, '\P{Sc=- PRTI}', "");
Expect(0, 68448, '\P{^Sc=- PRTI}', "");
Error('\p{Is_Script=		Inscriptional_parthian:=}');
Error('\P{Is_Script=		Inscriptional_parthian:=}');
Expect(1, 68447, '\p{Is_Script=inscriptionalparthian}', "");
Expect(0, 68447, '\p{^Is_Script=inscriptionalparthian}', "");
Expect(0, 68447, '\P{Is_Script=inscriptionalparthian}', "");
Expect(1, 68447, '\P{^Is_Script=inscriptionalparthian}', "");
Expect(0, 68448, '\p{Is_Script=inscriptionalparthian}', "");
Expect(1, 68448, '\p{^Is_Script=inscriptionalparthian}', "");
Expect(1, 68448, '\P{Is_Script=inscriptionalparthian}', "");
Expect(0, 68448, '\P{^Is_Script=inscriptionalparthian}', "");
Expect(1, 68447, '\p{Is_Script= _inscriptional_Parthian}', "");
Expect(0, 68447, '\p{^Is_Script= _inscriptional_Parthian}', "");
Expect(0, 68447, '\P{Is_Script= _inscriptional_Parthian}', "");
Expect(1, 68447, '\P{^Is_Script= _inscriptional_Parthian}', "");
Expect(0, 68448, '\p{Is_Script= _inscriptional_Parthian}', "");
Expect(1, 68448, '\p{^Is_Script= _inscriptional_Parthian}', "");
Expect(1, 68448, '\P{Is_Script= _inscriptional_Parthian}', "");
Expect(0, 68448, '\P{^Is_Script= _inscriptional_Parthian}', "");
Error('\p{Is_Sc:	/a/Prti}');
Error('\P{Is_Sc:	/a/Prti}');
Expect(1, 68447, '\p{Is_Sc=prti}', "");
Expect(0, 68447, '\p{^Is_Sc=prti}', "");
Expect(0, 68447, '\P{Is_Sc=prti}', "");
Expect(1, 68447, '\P{^Is_Sc=prti}', "");
Expect(0, 68448, '\p{Is_Sc=prti}', "");
Expect(1, 68448, '\p{^Is_Sc=prti}', "");
Expect(1, 68448, '\P{Is_Sc=prti}', "");
Expect(0, 68448, '\P{^Is_Sc=prti}', "");
Expect(1, 68447, '\p{Is_Sc= -Prti}', "");
Expect(0, 68447, '\p{^Is_Sc= -Prti}', "");
Expect(0, 68447, '\P{Is_Sc= -Prti}', "");
Expect(1, 68447, '\P{^Is_Sc= -Prti}', "");
Expect(0, 68448, '\p{Is_Sc= -Prti}', "");
Expect(1, 68448, '\p{^Is_Sc= -Prti}', "");
Expect(1, 68448, '\P{Is_Sc= -Prti}', "");
Expect(0, 68448, '\P{^Is_Sc= -Prti}', "");
Error('\p{Script=/a/_ REJANG}');
Error('\P{Script=/a/_ REJANG}');
Expect(1, 43359, '\p{Script=rejang}', "");
Expect(0, 43359, '\p{^Script=rejang}', "");
Expect(0, 43359, '\P{Script=rejang}', "");
Expect(1, 43359, '\P{^Script=rejang}', "");
Expect(0, 43360, '\p{Script=rejang}', "");
Expect(1, 43360, '\p{^Script=rejang}', "");
Expect(1, 43360, '\P{Script=rejang}', "");
Expect(0, 43360, '\P{^Script=rejang}', "");
Expect(1, 43359, '\p{Script=-REJANG}', "");
Expect(0, 43359, '\p{^Script=-REJANG}', "");
Expect(0, 43359, '\P{Script=-REJANG}', "");
Expect(1, 43359, '\P{^Script=-REJANG}', "");
Expect(0, 43360, '\p{Script=-REJANG}', "");
Expect(1, 43360, '\p{^Script=-REJANG}', "");
Expect(1, 43360, '\P{Script=-REJANG}', "");
Expect(0, 43360, '\P{^Script=-REJANG}', "");
Error('\p{Sc=	_Rjng:=}');
Error('\P{Sc=	_Rjng:=}');
Expect(1, 43359, '\p{Sc=rjng}', "");
Expect(0, 43359, '\p{^Sc=rjng}', "");
Expect(0, 43359, '\P{Sc=rjng}', "");
Expect(1, 43359, '\P{^Sc=rjng}', "");
Expect(0, 43360, '\p{Sc=rjng}', "");
Expect(1, 43360, '\p{^Sc=rjng}', "");
Expect(1, 43360, '\P{Sc=rjng}', "");
Expect(0, 43360, '\P{^Sc=rjng}', "");
Expect(1, 43359, '\p{Sc=	-rjng}', "");
Expect(0, 43359, '\p{^Sc=	-rjng}', "");
Expect(0, 43359, '\P{Sc=	-rjng}', "");
Expect(1, 43359, '\P{^Sc=	-rjng}', "");
Expect(0, 43360, '\p{Sc=	-rjng}', "");
Expect(1, 43360, '\p{^Sc=	-rjng}', "");
Expect(1, 43360, '\P{Sc=	-rjng}', "");
Expect(0, 43360, '\P{^Sc=	-rjng}', "");
Error('\p{Is_Script=/a/_Rejang}');
Error('\P{Is_Script=/a/_Rejang}');
Expect(1, 43359, '\p{Is_Script=rejang}', "");
Expect(0, 43359, '\p{^Is_Script=rejang}', "");
Expect(0, 43359, '\P{Is_Script=rejang}', "");
Expect(1, 43359, '\P{^Is_Script=rejang}', "");
Expect(0, 43360, '\p{Is_Script=rejang}', "");
Expect(1, 43360, '\p{^Is_Script=rejang}', "");
Expect(1, 43360, '\P{Is_Script=rejang}', "");
Expect(0, 43360, '\P{^Is_Script=rejang}', "");
Expect(1, 43359, '\p{Is_Script:	- Rejang}', "");
Expect(0, 43359, '\p{^Is_Script:	- Rejang}', "");
Expect(0, 43359, '\P{Is_Script:	- Rejang}', "");
Expect(1, 43359, '\P{^Is_Script:	- Rejang}', "");
Expect(0, 43360, '\p{Is_Script:	- Rejang}', "");
Expect(1, 43360, '\p{^Is_Script:	- Rejang}', "");
Expect(1, 43360, '\P{Is_Script:	- Rejang}', "");
Expect(0, 43360, '\P{^Is_Script:	- Rejang}', "");
Error('\p{Is_Sc=-Rjng:=}');
Error('\P{Is_Sc=-Rjng:=}');
Expect(1, 43359, '\p{Is_Sc: rjng}', "");
Expect(0, 43359, '\p{^Is_Sc: rjng}', "");
Expect(0, 43359, '\P{Is_Sc: rjng}', "");
Expect(1, 43359, '\P{^Is_Sc: rjng}', "");
Expect(0, 43360, '\p{Is_Sc: rjng}', "");
Expect(1, 43360, '\p{^Is_Sc: rjng}', "");
Expect(1, 43360, '\P{Is_Sc: rjng}', "");
Expect(0, 43360, '\P{^Is_Sc: rjng}', "");
Expect(1, 43359, '\p{Is_Sc=_ rjng}', "");
Expect(0, 43359, '\p{^Is_Sc=_ rjng}', "");
Expect(0, 43359, '\P{Is_Sc=_ rjng}', "");
Expect(1, 43359, '\P{^Is_Sc=_ rjng}', "");
Expect(0, 43360, '\p{Is_Sc=_ rjng}', "");
Expect(1, 43360, '\p{^Is_Sc=_ rjng}', "");
Expect(1, 43360, '\P{Is_Sc=_ rjng}', "");
Expect(0, 43360, '\P{^Is_Sc=_ rjng}', "");
Error('\p{Script=/a/-RUNIC}');
Error('\P{Script=/a/-RUNIC}');
Expect(1, 5872, '\p{Script=runic}', "");
Expect(0, 5872, '\p{^Script=runic}', "");
Expect(0, 5872, '\P{Script=runic}', "");
Expect(1, 5872, '\P{^Script=runic}', "");
Expect(0, 5873, '\p{Script=runic}', "");
Expect(1, 5873, '\p{^Script=runic}', "");
Expect(1, 5873, '\P{Script=runic}', "");
Expect(0, 5873, '\P{^Script=runic}', "");
Expect(1, 5872, '\p{Script=_Runic}', "");
Expect(0, 5872, '\p{^Script=_Runic}', "");
Expect(0, 5872, '\P{Script=_Runic}', "");
Expect(1, 5872, '\P{^Script=_Runic}', "");
Expect(0, 5873, '\p{Script=_Runic}', "");
Expect(1, 5873, '\p{^Script=_Runic}', "");
Expect(1, 5873, '\P{Script=_Runic}', "");
Expect(0, 5873, '\P{^Script=_Runic}', "");
Error('\p{Sc=__Runr/a/}');
Error('\P{Sc=__Runr/a/}');
Expect(1, 5872, '\p{Sc=runr}', "");
Expect(0, 5872, '\p{^Sc=runr}', "");
Expect(0, 5872, '\P{Sc=runr}', "");
Expect(1, 5872, '\P{^Sc=runr}', "");
Expect(0, 5873, '\p{Sc=runr}', "");
Expect(1, 5873, '\p{^Sc=runr}', "");
Expect(1, 5873, '\P{Sc=runr}', "");
Expect(0, 5873, '\P{^Sc=runr}', "");
Expect(1, 5872, '\p{Sc=__Runr}', "");
Expect(0, 5872, '\p{^Sc=__Runr}', "");
Expect(0, 5872, '\P{Sc=__Runr}', "");
Expect(1, 5872, '\P{^Sc=__Runr}', "");
Expect(0, 5873, '\p{Sc=__Runr}', "");
Expect(1, 5873, '\p{^Sc=__Runr}', "");
Expect(1, 5873, '\P{Sc=__Runr}', "");
Expect(0, 5873, '\P{^Sc=__Runr}', "");
Error('\p{Is_Script:		Runic/a/}');
Error('\P{Is_Script:		Runic/a/}');
Expect(1, 5872, '\p{Is_Script:	runic}', "");
Expect(0, 5872, '\p{^Is_Script:	runic}', "");
Expect(0, 5872, '\P{Is_Script:	runic}', "");
Expect(1, 5872, '\P{^Is_Script:	runic}', "");
Expect(0, 5873, '\p{Is_Script:	runic}', "");
Expect(1, 5873, '\p{^Is_Script:	runic}', "");
Expect(1, 5873, '\P{Is_Script:	runic}', "");
Expect(0, 5873, '\P{^Is_Script:	runic}', "");
Expect(1, 5872, '\p{Is_Script=-_RUNIC}', "");
Expect(0, 5872, '\p{^Is_Script=-_RUNIC}', "");
Expect(0, 5872, '\P{Is_Script=-_RUNIC}', "");
Expect(1, 5872, '\P{^Is_Script=-_RUNIC}', "");
Expect(0, 5873, '\p{Is_Script=-_RUNIC}', "");
Expect(1, 5873, '\p{^Is_Script=-_RUNIC}', "");
Expect(1, 5873, '\P{Is_Script=-_RUNIC}', "");
Expect(0, 5873, '\P{^Is_Script=-_RUNIC}', "");
Error('\p{Is_Sc=		RUNR:=}');
Error('\P{Is_Sc=		RUNR:=}');
Expect(1, 5872, '\p{Is_Sc: runr}', "");
Expect(0, 5872, '\p{^Is_Sc: runr}', "");
Expect(0, 5872, '\P{Is_Sc: runr}', "");
Expect(1, 5872, '\P{^Is_Sc: runr}', "");
Expect(0, 5873, '\p{Is_Sc: runr}', "");
Expect(1, 5873, '\p{^Is_Sc: runr}', "");
Expect(1, 5873, '\P{Is_Sc: runr}', "");
Expect(0, 5873, '\P{^Is_Sc: runr}', "");
Expect(1, 5872, '\p{Is_Sc:	__runr}', "");
Expect(0, 5872, '\p{^Is_Sc:	__runr}', "");
Expect(0, 5872, '\P{Is_Sc:	__runr}', "");
Expect(1, 5872, '\P{^Is_Sc:	__runr}', "");
Expect(0, 5873, '\p{Is_Sc:	__runr}', "");
Expect(1, 5873, '\p{^Is_Sc:	__runr}', "");
Expect(1, 5873, '\P{Is_Sc:	__runr}', "");
Expect(0, 5873, '\P{^Is_Sc:	__runr}', "");
Error('\p{Script=/a/ 	samaritan}');
Error('\P{Script=/a/ 	samaritan}');
Expect(1, 2110, '\p{Script=samaritan}', "");
Expect(0, 2110, '\p{^Script=samaritan}', "");
Expect(0, 2110, '\P{Script=samaritan}', "");
Expect(1, 2110, '\P{^Script=samaritan}', "");
Expect(0, 2111, '\p{Script=samaritan}', "");
Expect(1, 2111, '\p{^Script=samaritan}', "");
Expect(1, 2111, '\P{Script=samaritan}', "");
Expect(0, 2111, '\P{^Script=samaritan}', "");
Expect(1, 2110, '\p{Script: -Samaritan}', "");
Expect(0, 2110, '\p{^Script: -Samaritan}', "");
Expect(0, 2110, '\P{Script: -Samaritan}', "");
Expect(1, 2110, '\P{^Script: -Samaritan}', "");
Expect(0, 2111, '\p{Script: -Samaritan}', "");
Expect(1, 2111, '\p{^Script: -Samaritan}', "");
Expect(1, 2111, '\P{Script: -Samaritan}', "");
Expect(0, 2111, '\P{^Script: -Samaritan}', "");
Error('\p{Sc=	_SAMR/a/}');
Error('\P{Sc=	_SAMR/a/}');
Expect(1, 2110, '\p{Sc=samr}', "");
Expect(0, 2110, '\p{^Sc=samr}', "");
Expect(0, 2110, '\P{Sc=samr}', "");
Expect(1, 2110, '\P{^Sc=samr}', "");
Expect(0, 2111, '\p{Sc=samr}', "");
Expect(1, 2111, '\p{^Sc=samr}', "");
Expect(1, 2111, '\P{Sc=samr}', "");
Expect(0, 2111, '\P{^Sc=samr}', "");
Expect(1, 2110, '\p{Sc=-Samr}', "");
Expect(0, 2110, '\p{^Sc=-Samr}', "");
Expect(0, 2110, '\P{Sc=-Samr}', "");
Expect(1, 2110, '\P{^Sc=-Samr}', "");
Expect(0, 2111, '\p{Sc=-Samr}', "");
Expect(1, 2111, '\p{^Sc=-Samr}', "");
Expect(1, 2111, '\P{Sc=-Samr}', "");
Expect(0, 2111, '\P{^Sc=-Samr}', "");
Error('\p{Is_Script=_samaritan/a/}');
Error('\P{Is_Script=_samaritan/a/}');
Expect(1, 2110, '\p{Is_Script=samaritan}', "");
Expect(0, 2110, '\p{^Is_Script=samaritan}', "");
Expect(0, 2110, '\P{Is_Script=samaritan}', "");
Expect(1, 2110, '\P{^Is_Script=samaritan}', "");
Expect(0, 2111, '\p{Is_Script=samaritan}', "");
Expect(1, 2111, '\p{^Is_Script=samaritan}', "");
Expect(1, 2111, '\P{Is_Script=samaritan}', "");
Expect(0, 2111, '\P{^Is_Script=samaritan}', "");
Expect(1, 2110, '\p{Is_Script= 	samaritan}', "");
Expect(0, 2110, '\p{^Is_Script= 	samaritan}', "");
Expect(0, 2110, '\P{Is_Script= 	samaritan}', "");
Expect(1, 2110, '\P{^Is_Script= 	samaritan}', "");
Expect(0, 2111, '\p{Is_Script= 	samaritan}', "");
Expect(1, 2111, '\p{^Is_Script= 	samaritan}', "");
Expect(1, 2111, '\P{Is_Script= 	samaritan}', "");
Expect(0, 2111, '\P{^Is_Script= 	samaritan}', "");
Error('\p{Is_Sc=:=	samr}');
Error('\P{Is_Sc=:=	samr}');
Expect(1, 2110, '\p{Is_Sc=samr}', "");
Expect(0, 2110, '\p{^Is_Sc=samr}', "");
Expect(0, 2110, '\P{Is_Sc=samr}', "");
Expect(1, 2110, '\P{^Is_Sc=samr}', "");
Expect(0, 2111, '\p{Is_Sc=samr}', "");
Expect(1, 2111, '\p{^Is_Sc=samr}', "");
Expect(1, 2111, '\P{Is_Sc=samr}', "");
Expect(0, 2111, '\P{^Is_Sc=samr}', "");
Expect(1, 2110, '\p{Is_Sc=__SAMR}', "");
Expect(0, 2110, '\p{^Is_Sc=__SAMR}', "");
Expect(0, 2110, '\P{Is_Sc=__SAMR}', "");
Expect(1, 2110, '\P{^Is_Sc=__SAMR}', "");
Expect(0, 2111, '\p{Is_Sc=__SAMR}', "");
Expect(1, 2111, '\p{^Is_Sc=__SAMR}', "");
Expect(1, 2111, '\P{Is_Sc=__SAMR}', "");
Expect(0, 2111, '\P{^Is_Sc=__SAMR}', "");
Error('\p{Script=- Old_SOUTH_arabian:=}');
Error('\P{Script=- Old_SOUTH_arabian:=}');
Expect(1, 68223, '\p{Script=oldsoutharabian}', "");
Expect(0, 68223, '\p{^Script=oldsoutharabian}', "");
Expect(0, 68223, '\P{Script=oldsoutharabian}', "");
Expect(1, 68223, '\P{^Script=oldsoutharabian}', "");
Expect(0, 68224, '\p{Script=oldsoutharabian}', "");
Expect(1, 68224, '\p{^Script=oldsoutharabian}', "");
Expect(1, 68224, '\P{Script=oldsoutharabian}', "");
Expect(0, 68224, '\P{^Script=oldsoutharabian}', "");
Expect(1, 68223, '\p{Script=old_SOUTH_ARABIAN}', "");
Expect(0, 68223, '\p{^Script=old_SOUTH_ARABIAN}', "");
Expect(0, 68223, '\P{Script=old_SOUTH_ARABIAN}', "");
Expect(1, 68223, '\P{^Script=old_SOUTH_ARABIAN}', "");
Expect(0, 68224, '\p{Script=old_SOUTH_ARABIAN}', "");
Expect(1, 68224, '\p{^Script=old_SOUTH_ARABIAN}', "");
Expect(1, 68224, '\P{Script=old_SOUTH_ARABIAN}', "");
Expect(0, 68224, '\P{^Script=old_SOUTH_ARABIAN}', "");
Error('\p{Sc=	:=Sarb}');
Error('\P{Sc=	:=Sarb}');
Expect(1, 68223, '\p{Sc=sarb}', "");
Expect(0, 68223, '\p{^Sc=sarb}', "");
Expect(0, 68223, '\P{Sc=sarb}', "");
Expect(1, 68223, '\P{^Sc=sarb}', "");
Expect(0, 68224, '\p{Sc=sarb}', "");
Expect(1, 68224, '\p{^Sc=sarb}', "");
Expect(1, 68224, '\P{Sc=sarb}', "");
Expect(0, 68224, '\P{^Sc=sarb}', "");
Expect(1, 68223, '\p{Sc=-Sarb}', "");
Expect(0, 68223, '\p{^Sc=-Sarb}', "");
Expect(0, 68223, '\P{Sc=-Sarb}', "");
Expect(1, 68223, '\P{^Sc=-Sarb}', "");
Expect(0, 68224, '\p{Sc=-Sarb}', "");
Expect(1, 68224, '\p{^Sc=-Sarb}', "");
Expect(1, 68224, '\P{Sc=-Sarb}', "");
Expect(0, 68224, '\P{^Sc=-Sarb}', "");
Error('\p{Is_Script=/a/		OLD_south_Arabian}');
Error('\P{Is_Script=/a/		OLD_south_Arabian}');
Expect(1, 68223, '\p{Is_Script=oldsoutharabian}', "");
Expect(0, 68223, '\p{^Is_Script=oldsoutharabian}', "");
Expect(0, 68223, '\P{Is_Script=oldsoutharabian}', "");
Expect(1, 68223, '\P{^Is_Script=oldsoutharabian}', "");
Expect(0, 68224, '\p{Is_Script=oldsoutharabian}', "");
Expect(1, 68224, '\p{^Is_Script=oldsoutharabian}', "");
Expect(1, 68224, '\P{Is_Script=oldsoutharabian}', "");
Expect(0, 68224, '\P{^Is_Script=oldsoutharabian}', "");
Expect(1, 68223, '\p{Is_Script=  Old_South_Arabian}', "");
Expect(0, 68223, '\p{^Is_Script=  Old_South_Arabian}', "");
Expect(0, 68223, '\P{Is_Script=  Old_South_Arabian}', "");
Expect(1, 68223, '\P{^Is_Script=  Old_South_Arabian}', "");
Expect(0, 68224, '\p{Is_Script=  Old_South_Arabian}', "");
Expect(1, 68224, '\p{^Is_Script=  Old_South_Arabian}', "");
Expect(1, 68224, '\P{Is_Script=  Old_South_Arabian}', "");
Expect(0, 68224, '\P{^Is_Script=  Old_South_Arabian}', "");
Error('\p{Is_Sc=:=	SARB}');
Error('\P{Is_Sc=:=	SARB}');
Expect(1, 68223, '\p{Is_Sc=sarb}', "");
Expect(0, 68223, '\p{^Is_Sc=sarb}', "");
Expect(0, 68223, '\P{Is_Sc=sarb}', "");
Expect(1, 68223, '\P{^Is_Sc=sarb}', "");
Expect(0, 68224, '\p{Is_Sc=sarb}', "");
Expect(1, 68224, '\p{^Is_Sc=sarb}', "");
Expect(1, 68224, '\P{Is_Sc=sarb}', "");
Expect(0, 68224, '\P{^Is_Sc=sarb}', "");
Expect(1, 68223, '\p{Is_Sc=-Sarb}', "");
Expect(0, 68223, '\p{^Is_Sc=-Sarb}', "");
Expect(0, 68223, '\P{Is_Sc=-Sarb}', "");
Expect(1, 68223, '\P{^Is_Sc=-Sarb}', "");
Expect(0, 68224, '\p{Is_Sc=-Sarb}', "");
Expect(1, 68224, '\p{^Is_Sc=-Sarb}', "");
Expect(1, 68224, '\P{Is_Sc=-Sarb}', "");
Expect(0, 68224, '\P{^Is_Sc=-Sarb}', "");
Error('\p{Script=  Saurashtra:=}');
Error('\P{Script=  Saurashtra:=}');
Expect(1, 43225, '\p{Script=saurashtra}', "");
Expect(0, 43225, '\p{^Script=saurashtra}', "");
Expect(0, 43225, '\P{Script=saurashtra}', "");
Expect(1, 43225, '\P{^Script=saurashtra}', "");
Expect(0, 43226, '\p{Script=saurashtra}', "");
Expect(1, 43226, '\p{^Script=saurashtra}', "");
Expect(1, 43226, '\P{Script=saurashtra}', "");
Expect(0, 43226, '\P{^Script=saurashtra}', "");
Expect(1, 43225, '\p{Script=--saurashtra}', "");
Expect(0, 43225, '\p{^Script=--saurashtra}', "");
Expect(0, 43225, '\P{Script=--saurashtra}', "");
Expect(1, 43225, '\P{^Script=--saurashtra}', "");
Expect(0, 43226, '\p{Script=--saurashtra}', "");
Expect(1, 43226, '\p{^Script=--saurashtra}', "");
Expect(1, 43226, '\P{Script=--saurashtra}', "");
Expect(0, 43226, '\P{^Script=--saurashtra}', "");
Error('\p{Sc= Saur/a/}');
Error('\P{Sc= Saur/a/}');
Expect(1, 43225, '\p{Sc=saur}', "");
Expect(0, 43225, '\p{^Sc=saur}', "");
Expect(0, 43225, '\P{Sc=saur}', "");
Expect(1, 43225, '\P{^Sc=saur}', "");
Expect(0, 43226, '\p{Sc=saur}', "");
Expect(1, 43226, '\p{^Sc=saur}', "");
Expect(1, 43226, '\P{Sc=saur}', "");
Expect(0, 43226, '\P{^Sc=saur}', "");
Expect(1, 43225, '\p{Sc=	saur}', "");
Expect(0, 43225, '\p{^Sc=	saur}', "");
Expect(0, 43225, '\P{Sc=	saur}', "");
Expect(1, 43225, '\P{^Sc=	saur}', "");
Expect(0, 43226, '\p{Sc=	saur}', "");
Expect(1, 43226, '\p{^Sc=	saur}', "");
Expect(1, 43226, '\P{Sc=	saur}', "");
Expect(0, 43226, '\P{^Sc=	saur}', "");
Error('\p{Is_Script=- Saurashtra/a/}');
Error('\P{Is_Script=- Saurashtra/a/}');
Expect(1, 43225, '\p{Is_Script=saurashtra}', "");
Expect(0, 43225, '\p{^Is_Script=saurashtra}', "");
Expect(0, 43225, '\P{Is_Script=saurashtra}', "");
Expect(1, 43225, '\P{^Is_Script=saurashtra}', "");
Expect(0, 43226, '\p{Is_Script=saurashtra}', "");
Expect(1, 43226, '\p{^Is_Script=saurashtra}', "");
Expect(1, 43226, '\P{Is_Script=saurashtra}', "");
Expect(0, 43226, '\P{^Is_Script=saurashtra}', "");
Expect(1, 43225, '\p{Is_Script=_SAURASHTRA}', "");
Expect(0, 43225, '\p{^Is_Script=_SAURASHTRA}', "");
Expect(0, 43225, '\P{Is_Script=_SAURASHTRA}', "");
Expect(1, 43225, '\P{^Is_Script=_SAURASHTRA}', "");
Expect(0, 43226, '\p{Is_Script=_SAURASHTRA}', "");
Expect(1, 43226, '\p{^Is_Script=_SAURASHTRA}', "");
Expect(1, 43226, '\P{Is_Script=_SAURASHTRA}', "");
Expect(0, 43226, '\P{^Is_Script=_SAURASHTRA}', "");
Error('\p{Is_Sc=:=  SAUR}');
Error('\P{Is_Sc=:=  SAUR}');
Expect(1, 43225, '\p{Is_Sc:	saur}', "");
Expect(0, 43225, '\p{^Is_Sc:	saur}', "");
Expect(0, 43225, '\P{Is_Sc:	saur}', "");
Expect(1, 43225, '\P{^Is_Sc:	saur}', "");
Expect(0, 43226, '\p{Is_Sc:	saur}', "");
Expect(1, 43226, '\p{^Is_Sc:	saur}', "");
Expect(1, 43226, '\P{Is_Sc:	saur}', "");
Expect(0, 43226, '\P{^Is_Sc:	saur}', "");
Expect(1, 43225, '\p{Is_Sc= 	SAUR}', "");
Expect(0, 43225, '\p{^Is_Sc= 	SAUR}', "");
Expect(0, 43225, '\P{Is_Sc= 	SAUR}', "");
Expect(1, 43225, '\P{^Is_Sc= 	SAUR}', "");
Expect(0, 43226, '\p{Is_Sc= 	SAUR}', "");
Expect(1, 43226, '\p{^Is_Sc= 	SAUR}', "");
Expect(1, 43226, '\P{Is_Sc= 	SAUR}', "");
Expect(0, 43226, '\P{^Is_Sc= 	SAUR}', "");
Error('\p{Script=_/a/Shavian}');
Error('\P{Script=_/a/Shavian}');
Expect(1, 66687, '\p{Script:shavian}', "");
Expect(0, 66687, '\p{^Script:shavian}', "");
Expect(0, 66687, '\P{Script:shavian}', "");
Expect(1, 66687, '\P{^Script:shavian}', "");
Expect(0, 66688, '\p{Script:shavian}', "");
Expect(1, 66688, '\p{^Script:shavian}', "");
Expect(1, 66688, '\P{Script:shavian}', "");
Expect(0, 66688, '\P{^Script:shavian}', "");
Expect(1, 66687, '\p{Script=	-SHAVIAN}', "");
Expect(0, 66687, '\p{^Script=	-SHAVIAN}', "");
Expect(0, 66687, '\P{Script=	-SHAVIAN}', "");
Expect(1, 66687, '\P{^Script=	-SHAVIAN}', "");
Expect(0, 66688, '\p{Script=	-SHAVIAN}', "");
Expect(1, 66688, '\p{^Script=	-SHAVIAN}', "");
Expect(1, 66688, '\P{Script=	-SHAVIAN}', "");
Expect(0, 66688, '\P{^Script=	-SHAVIAN}', "");
Error('\p{Sc=:= _SHAW}');
Error('\P{Sc=:= _SHAW}');
Expect(1, 66687, '\p{Sc=shaw}', "");
Expect(0, 66687, '\p{^Sc=shaw}', "");
Expect(0, 66687, '\P{Sc=shaw}', "");
Expect(1, 66687, '\P{^Sc=shaw}', "");
Expect(0, 66688, '\p{Sc=shaw}', "");
Expect(1, 66688, '\p{^Sc=shaw}', "");
Expect(1, 66688, '\P{Sc=shaw}', "");
Expect(0, 66688, '\P{^Sc=shaw}', "");
Expect(1, 66687, '\p{Sc:   _ Shaw}', "");
Expect(0, 66687, '\p{^Sc:   _ Shaw}', "");
Expect(0, 66687, '\P{Sc:   _ Shaw}', "");
Expect(1, 66687, '\P{^Sc:   _ Shaw}', "");
Expect(0, 66688, '\p{Sc:   _ Shaw}', "");
Expect(1, 66688, '\p{^Sc:   _ Shaw}', "");
Expect(1, 66688, '\P{Sc:   _ Shaw}', "");
Expect(0, 66688, '\P{^Sc:   _ Shaw}', "");
Error('\p{Is_Script=	:=SHAVIAN}');
Error('\P{Is_Script=	:=SHAVIAN}');
Expect(1, 66687, '\p{Is_Script=shavian}', "");
Expect(0, 66687, '\p{^Is_Script=shavian}', "");
Expect(0, 66687, '\P{Is_Script=shavian}', "");
Expect(1, 66687, '\P{^Is_Script=shavian}', "");
Expect(0, 66688, '\p{Is_Script=shavian}', "");
Expect(1, 66688, '\p{^Is_Script=shavian}', "");
Expect(1, 66688, '\P{Is_Script=shavian}', "");
Expect(0, 66688, '\P{^Is_Script=shavian}', "");
Expect(1, 66687, '\p{Is_Script=		shavian}', "");
Expect(0, 66687, '\p{^Is_Script=		shavian}', "");
Expect(0, 66687, '\P{Is_Script=		shavian}', "");
Expect(1, 66687, '\P{^Is_Script=		shavian}', "");
Expect(0, 66688, '\p{Is_Script=		shavian}', "");
Expect(1, 66688, '\p{^Is_Script=		shavian}', "");
Expect(1, 66688, '\P{Is_Script=		shavian}', "");
Expect(0, 66688, '\P{^Is_Script=		shavian}', "");
Error('\p{Is_Sc=	:=shaw}');
Error('\P{Is_Sc=	:=shaw}');
Expect(1, 66687, '\p{Is_Sc=shaw}', "");
Expect(0, 66687, '\p{^Is_Sc=shaw}', "");
Expect(0, 66687, '\P{Is_Sc=shaw}', "");
Expect(1, 66687, '\P{^Is_Sc=shaw}', "");
Expect(0, 66688, '\p{Is_Sc=shaw}', "");
Expect(1, 66688, '\p{^Is_Sc=shaw}', "");
Expect(1, 66688, '\P{Is_Sc=shaw}', "");
Expect(0, 66688, '\P{^Is_Sc=shaw}', "");
Expect(1, 66687, '\p{Is_Sc=_SHAW}', "");
Expect(0, 66687, '\p{^Is_Sc=_SHAW}', "");
Expect(0, 66687, '\P{Is_Sc=_SHAW}', "");
Expect(1, 66687, '\P{^Is_Sc=_SHAW}', "");
Expect(0, 66688, '\p{Is_Sc=_SHAW}', "");
Expect(1, 66688, '\p{^Is_Sc=_SHAW}', "");
Expect(1, 66688, '\P{Is_Sc=_SHAW}', "");
Expect(0, 66688, '\P{^Is_Sc=_SHAW}', "");
Error('\p{Script:		Sharada/a/}');
Error('\P{Script:		Sharada/a/}');
Expect(1, 70105, '\p{Script=sharada}', "");
Expect(0, 70105, '\p{^Script=sharada}', "");
Expect(0, 70105, '\P{Script=sharada}', "");
Expect(1, 70105, '\P{^Script=sharada}', "");
Expect(0, 70106, '\p{Script=sharada}', "");
Expect(1, 70106, '\p{^Script=sharada}', "");
Expect(1, 70106, '\P{Script=sharada}', "");
Expect(0, 70106, '\P{^Script=sharada}', "");
Expect(1, 70105, '\p{Script:	 Sharada}', "");
Expect(0, 70105, '\p{^Script:	 Sharada}', "");
Expect(0, 70105, '\P{Script:	 Sharada}', "");
Expect(1, 70105, '\P{^Script:	 Sharada}', "");
Expect(0, 70106, '\p{Script:	 Sharada}', "");
Expect(1, 70106, '\p{^Script:	 Sharada}', "");
Expect(1, 70106, '\P{Script:	 Sharada}', "");
Expect(0, 70106, '\P{^Script:	 Sharada}', "");
Error('\p{Sc=-:=shrd}');
Error('\P{Sc=-:=shrd}');
Expect(1, 70105, '\p{Sc=shrd}', "");
Expect(0, 70105, '\p{^Sc=shrd}', "");
Expect(0, 70105, '\P{Sc=shrd}', "");
Expect(1, 70105, '\P{^Sc=shrd}', "");
Expect(0, 70106, '\p{Sc=shrd}', "");
Expect(1, 70106, '\p{^Sc=shrd}', "");
Expect(1, 70106, '\P{Sc=shrd}', "");
Expect(0, 70106, '\P{^Sc=shrd}', "");
Expect(1, 70105, '\p{Sc= -SHRD}', "");
Expect(0, 70105, '\p{^Sc= -SHRD}', "");
Expect(0, 70105, '\P{Sc= -SHRD}', "");
Expect(1, 70105, '\P{^Sc= -SHRD}', "");
Expect(0, 70106, '\p{Sc= -SHRD}', "");
Expect(1, 70106, '\p{^Sc= -SHRD}', "");
Expect(1, 70106, '\P{Sc= -SHRD}', "");
Expect(0, 70106, '\P{^Sc= -SHRD}', "");
Error('\p{Is_Script=-/a/Sharada}');
Error('\P{Is_Script=-/a/Sharada}');
Expect(1, 70105, '\p{Is_Script=sharada}', "");
Expect(0, 70105, '\p{^Is_Script=sharada}', "");
Expect(0, 70105, '\P{Is_Script=sharada}', "");
Expect(1, 70105, '\P{^Is_Script=sharada}', "");
Expect(0, 70106, '\p{Is_Script=sharada}', "");
Expect(1, 70106, '\p{^Is_Script=sharada}', "");
Expect(1, 70106, '\P{Is_Script=sharada}', "");
Expect(0, 70106, '\P{^Is_Script=sharada}', "");
Expect(1, 70105, '\p{Is_Script=	Sharada}', "");
Expect(0, 70105, '\p{^Is_Script=	Sharada}', "");
Expect(0, 70105, '\P{Is_Script=	Sharada}', "");
Expect(1, 70105, '\P{^Is_Script=	Sharada}', "");
Expect(0, 70106, '\p{Is_Script=	Sharada}', "");
Expect(1, 70106, '\p{^Is_Script=	Sharada}', "");
Expect(1, 70106, '\P{Is_Script=	Sharada}', "");
Expect(0, 70106, '\P{^Is_Script=	Sharada}', "");
Error('\p{Is_Sc=_/a/Shrd}');
Error('\P{Is_Sc=_/a/Shrd}');
Expect(1, 70105, '\p{Is_Sc=shrd}', "");
Expect(0, 70105, '\p{^Is_Sc=shrd}', "");
Expect(0, 70105, '\P{Is_Sc=shrd}', "");
Expect(1, 70105, '\P{^Is_Sc=shrd}', "");
Expect(0, 70106, '\p{Is_Sc=shrd}', "");
Expect(1, 70106, '\p{^Is_Sc=shrd}', "");
Expect(1, 70106, '\P{Is_Sc=shrd}', "");
Expect(0, 70106, '\P{^Is_Sc=shrd}', "");
Expect(1, 70105, '\p{Is_Sc=	shrd}', "");
Expect(0, 70105, '\p{^Is_Sc=	shrd}', "");
Expect(0, 70105, '\P{Is_Sc=	shrd}', "");
Expect(1, 70105, '\P{^Is_Sc=	shrd}', "");
Expect(0, 70106, '\p{Is_Sc=	shrd}', "");
Expect(1, 70106, '\p{^Is_Sc=	shrd}', "");
Expect(1, 70106, '\P{Is_Sc=	shrd}', "");
Expect(0, 70106, '\P{^Is_Sc=	shrd}', "");
Error('\p{Script=Sinhala/a/}');
Error('\P{Script=Sinhala/a/}');
Expect(1, 3572, '\p{Script=sinhala}', "");
Expect(0, 3572, '\p{^Script=sinhala}', "");
Expect(0, 3572, '\P{Script=sinhala}', "");
Expect(1, 3572, '\P{^Script=sinhala}', "");
Expect(0, 3573, '\p{Script=sinhala}', "");
Expect(1, 3573, '\p{^Script=sinhala}', "");
Expect(1, 3573, '\P{Script=sinhala}', "");
Expect(0, 3573, '\P{^Script=sinhala}', "");
Expect(1, 3572, '\p{Script:	sinhala}', "");
Expect(0, 3572, '\p{^Script:	sinhala}', "");
Expect(0, 3572, '\P{Script:	sinhala}', "");
Expect(1, 3572, '\P{^Script:	sinhala}', "");
Expect(0, 3573, '\p{Script:	sinhala}', "");
Expect(1, 3573, '\p{^Script:	sinhala}', "");
Expect(1, 3573, '\P{Script:	sinhala}', "");
Expect(0, 3573, '\P{^Script:	sinhala}', "");
Error('\p{Sc=-/a/Sinh}');
Error('\P{Sc=-/a/Sinh}');
Expect(1, 3572, '\p{Sc=sinh}', "");
Expect(0, 3572, '\p{^Sc=sinh}', "");
Expect(0, 3572, '\P{Sc=sinh}', "");
Expect(1, 3572, '\P{^Sc=sinh}', "");
Expect(0, 3573, '\p{Sc=sinh}', "");
Expect(1, 3573, '\p{^Sc=sinh}', "");
Expect(1, 3573, '\P{Sc=sinh}', "");
Expect(0, 3573, '\P{^Sc=sinh}', "");
Expect(1, 3572, '\p{Sc=-SINH}', "");
Expect(0, 3572, '\p{^Sc=-SINH}', "");
Expect(0, 3572, '\P{Sc=-SINH}', "");
Expect(1, 3572, '\P{^Sc=-SINH}', "");
Expect(0, 3573, '\p{Sc=-SINH}', "");
Expect(1, 3573, '\p{^Sc=-SINH}', "");
Expect(1, 3573, '\P{Sc=-SINH}', "");
Expect(0, 3573, '\P{^Sc=-SINH}', "");
Error('\p{Is_Script=/a/ Sinhala}');
Error('\P{Is_Script=/a/ Sinhala}');
Expect(1, 3572, '\p{Is_Script=sinhala}', "");
Expect(0, 3572, '\p{^Is_Script=sinhala}', "");
Expect(0, 3572, '\P{Is_Script=sinhala}', "");
Expect(1, 3572, '\P{^Is_Script=sinhala}', "");
Expect(0, 3573, '\p{Is_Script=sinhala}', "");
Expect(1, 3573, '\p{^Is_Script=sinhala}', "");
Expect(1, 3573, '\P{Is_Script=sinhala}', "");
Expect(0, 3573, '\P{^Is_Script=sinhala}', "");
Expect(1, 3572, '\p{Is_Script=__SINHALA}', "");
Expect(0, 3572, '\p{^Is_Script=__SINHALA}', "");
Expect(0, 3572, '\P{Is_Script=__SINHALA}', "");
Expect(1, 3572, '\P{^Is_Script=__SINHALA}', "");
Expect(0, 3573, '\p{Is_Script=__SINHALA}', "");
Expect(1, 3573, '\p{^Is_Script=__SINHALA}', "");
Expect(1, 3573, '\P{Is_Script=__SINHALA}', "");
Expect(0, 3573, '\P{^Is_Script=__SINHALA}', "");
Error('\p{Is_Sc=_/a/sinh}');
Error('\P{Is_Sc=_/a/sinh}');
Expect(1, 3572, '\p{Is_Sc=sinh}', "");
Expect(0, 3572, '\p{^Is_Sc=sinh}', "");
Expect(0, 3572, '\P{Is_Sc=sinh}', "");
Expect(1, 3572, '\P{^Is_Sc=sinh}', "");
Expect(0, 3573, '\p{Is_Sc=sinh}', "");
Expect(1, 3573, '\p{^Is_Sc=sinh}', "");
Expect(1, 3573, '\P{Is_Sc=sinh}', "");
Expect(0, 3573, '\P{^Is_Sc=sinh}', "");
Expect(1, 3572, '\p{Is_Sc:_Sinh}', "");
Expect(0, 3572, '\p{^Is_Sc:_Sinh}', "");
Expect(0, 3572, '\P{Is_Sc:_Sinh}', "");
Expect(1, 3572, '\P{^Is_Sc:_Sinh}', "");
Expect(0, 3573, '\p{Is_Sc:_Sinh}', "");
Expect(1, 3573, '\p{^Is_Sc:_Sinh}', "");
Expect(1, 3573, '\P{Is_Sc:_Sinh}', "");
Expect(0, 3573, '\P{^Is_Sc:_Sinh}', "");
Error('\p{Script=-	sora_Sompeng/a/}');
Error('\P{Script=-	sora_Sompeng/a/}');
Expect(1, 69881, '\p{Script=sorasompeng}', "");
Expect(0, 69881, '\p{^Script=sorasompeng}', "");
Expect(0, 69881, '\P{Script=sorasompeng}', "");
Expect(1, 69881, '\P{^Script=sorasompeng}', "");
Expect(0, 69882, '\p{Script=sorasompeng}', "");
Expect(1, 69882, '\p{^Script=sorasompeng}', "");
Expect(1, 69882, '\P{Script=sorasompeng}', "");
Expect(0, 69882, '\P{^Script=sorasompeng}', "");
Expect(1, 69881, '\p{Script= Sora_SOMPENG}', "");
Expect(0, 69881, '\p{^Script= Sora_SOMPENG}', "");
Expect(0, 69881, '\P{Script= Sora_SOMPENG}', "");
Expect(1, 69881, '\P{^Script= Sora_SOMPENG}', "");
Expect(0, 69882, '\p{Script= Sora_SOMPENG}', "");
Expect(1, 69882, '\p{^Script= Sora_SOMPENG}', "");
Expect(1, 69882, '\P{Script= Sora_SOMPENG}', "");
Expect(0, 69882, '\P{^Script= Sora_SOMPENG}', "");
Error('\p{Sc=/a/ _sora}');
Error('\P{Sc=/a/ _sora}');
Expect(1, 69881, '\p{Sc=sora}', "");
Expect(0, 69881, '\p{^Sc=sora}', "");
Expect(0, 69881, '\P{Sc=sora}', "");
Expect(1, 69881, '\P{^Sc=sora}', "");
Expect(0, 69882, '\p{Sc=sora}', "");
Expect(1, 69882, '\p{^Sc=sora}', "");
Expect(1, 69882, '\P{Sc=sora}', "");
Expect(0, 69882, '\P{^Sc=sora}', "");
Expect(1, 69881, '\p{Sc=		Sora}', "");
Expect(0, 69881, '\p{^Sc=		Sora}', "");
Expect(0, 69881, '\P{Sc=		Sora}', "");
Expect(1, 69881, '\P{^Sc=		Sora}', "");
Expect(0, 69882, '\p{Sc=		Sora}', "");
Expect(1, 69882, '\p{^Sc=		Sora}', "");
Expect(1, 69882, '\P{Sc=		Sora}', "");
Expect(0, 69882, '\P{^Sc=		Sora}', "");
Error('\p{Is_Script=-:=Sora_Sompeng}');
Error('\P{Is_Script=-:=Sora_Sompeng}');
Expect(1, 69881, '\p{Is_Script:sorasompeng}', "");
Expect(0, 69881, '\p{^Is_Script:sorasompeng}', "");
Expect(0, 69881, '\P{Is_Script:sorasompeng}', "");
Expect(1, 69881, '\P{^Is_Script:sorasompeng}', "");
Expect(0, 69882, '\p{Is_Script:sorasompeng}', "");
Expect(1, 69882, '\p{^Is_Script:sorasompeng}', "");
Expect(1, 69882, '\P{Is_Script:sorasompeng}', "");
Expect(0, 69882, '\P{^Is_Script:sorasompeng}', "");
Expect(1, 69881, '\p{Is_Script=-	Sora_SOMPENG}', "");
Expect(0, 69881, '\p{^Is_Script=-	Sora_SOMPENG}', "");
Expect(0, 69881, '\P{Is_Script=-	Sora_SOMPENG}', "");
Expect(1, 69881, '\P{^Is_Script=-	Sora_SOMPENG}', "");
Expect(0, 69882, '\p{Is_Script=-	Sora_SOMPENG}', "");
Expect(1, 69882, '\p{^Is_Script=-	Sora_SOMPENG}', "");
Expect(1, 69882, '\P{Is_Script=-	Sora_SOMPENG}', "");
Expect(0, 69882, '\P{^Is_Script=-	Sora_SOMPENG}', "");
Error('\p{Is_Sc=:=_-sora}');
Error('\P{Is_Sc=:=_-sora}');
Expect(1, 69881, '\p{Is_Sc=sora}', "");
Expect(0, 69881, '\p{^Is_Sc=sora}', "");
Expect(0, 69881, '\P{Is_Sc=sora}', "");
Expect(1, 69881, '\P{^Is_Sc=sora}', "");
Expect(0, 69882, '\p{Is_Sc=sora}', "");
Expect(1, 69882, '\p{^Is_Sc=sora}', "");
Expect(1, 69882, '\P{Is_Sc=sora}', "");
Expect(0, 69882, '\P{^Is_Sc=sora}', "");
Expect(1, 69881, '\p{Is_Sc: -_Sora}', "");
Expect(0, 69881, '\p{^Is_Sc: -_Sora}', "");
Expect(0, 69881, '\P{Is_Sc: -_Sora}', "");
Expect(1, 69881, '\P{^Is_Sc: -_Sora}', "");
Expect(0, 69882, '\p{Is_Sc: -_Sora}', "");
Expect(1, 69882, '\p{^Is_Sc: -_Sora}', "");
Expect(1, 69882, '\P{Is_Sc: -_Sora}', "");
Expect(0, 69882, '\P{^Is_Sc: -_Sora}', "");
Error('\p{Script=:=Sundanese}');
Error('\P{Script=:=Sundanese}');
Expect(1, 7367, '\p{Script=sundanese}', "");
Expect(0, 7367, '\p{^Script=sundanese}', "");
Expect(0, 7367, '\P{Script=sundanese}', "");
Expect(1, 7367, '\P{^Script=sundanese}', "");
Expect(0, 7368, '\p{Script=sundanese}', "");
Expect(1, 7368, '\p{^Script=sundanese}', "");
Expect(1, 7368, '\P{Script=sundanese}', "");
Expect(0, 7368, '\P{^Script=sundanese}', "");
Expect(1, 7367, '\p{Script=_SUNDANESE}', "");
Expect(0, 7367, '\p{^Script=_SUNDANESE}', "");
Expect(0, 7367, '\P{Script=_SUNDANESE}', "");
Expect(1, 7367, '\P{^Script=_SUNDANESE}', "");
Expect(0, 7368, '\p{Script=_SUNDANESE}', "");
Expect(1, 7368, '\p{^Script=_SUNDANESE}', "");
Expect(1, 7368, '\P{Script=_SUNDANESE}', "");
Expect(0, 7368, '\P{^Script=_SUNDANESE}', "");
Error('\p{Sc= :=sund}');
Error('\P{Sc= :=sund}');
Expect(1, 7367, '\p{Sc=sund}', "");
Expect(0, 7367, '\p{^Sc=sund}', "");
Expect(0, 7367, '\P{Sc=sund}', "");
Expect(1, 7367, '\P{^Sc=sund}', "");
Expect(0, 7368, '\p{Sc=sund}', "");
Expect(1, 7368, '\p{^Sc=sund}', "");
Expect(1, 7368, '\P{Sc=sund}', "");
Expect(0, 7368, '\P{^Sc=sund}', "");
Expect(1, 7367, '\p{Sc=- Sund}', "");
Expect(0, 7367, '\p{^Sc=- Sund}', "");
Expect(0, 7367, '\P{Sc=- Sund}', "");
Expect(1, 7367, '\P{^Sc=- Sund}', "");
Expect(0, 7368, '\p{Sc=- Sund}', "");
Expect(1, 7368, '\p{^Sc=- Sund}', "");
Expect(1, 7368, '\P{Sc=- Sund}', "");
Expect(0, 7368, '\P{^Sc=- Sund}', "");
Error('\p{Is_Script=sundanese:=}');
Error('\P{Is_Script=sundanese:=}');
Expect(1, 7367, '\p{Is_Script=sundanese}', "");
Expect(0, 7367, '\p{^Is_Script=sundanese}', "");
Expect(0, 7367, '\P{Is_Script=sundanese}', "");
Expect(1, 7367, '\P{^Is_Script=sundanese}', "");
Expect(0, 7368, '\p{Is_Script=sundanese}', "");
Expect(1, 7368, '\p{^Is_Script=sundanese}', "");
Expect(1, 7368, '\P{Is_Script=sundanese}', "");
Expect(0, 7368, '\P{^Is_Script=sundanese}', "");
Expect(1, 7367, '\p{Is_Script:  _sundanese}', "");
Expect(0, 7367, '\p{^Is_Script:  _sundanese}', "");
Expect(0, 7367, '\P{Is_Script:  _sundanese}', "");
Expect(1, 7367, '\P{^Is_Script:  _sundanese}', "");
Expect(0, 7368, '\p{Is_Script:  _sundanese}', "");
Expect(1, 7368, '\p{^Is_Script:  _sundanese}', "");
Expect(1, 7368, '\P{Is_Script:  _sundanese}', "");
Expect(0, 7368, '\P{^Is_Script:  _sundanese}', "");
Error('\p{Is_Sc=:=sund}');
Error('\P{Is_Sc=:=sund}');
Expect(1, 7367, '\p{Is_Sc:sund}', "");
Expect(0, 7367, '\p{^Is_Sc:sund}', "");
Expect(0, 7367, '\P{Is_Sc:sund}', "");
Expect(1, 7367, '\P{^Is_Sc:sund}', "");
Expect(0, 7368, '\p{Is_Sc:sund}', "");
Expect(1, 7368, '\p{^Is_Sc:sund}', "");
Expect(1, 7368, '\P{Is_Sc:sund}', "");
Expect(0, 7368, '\P{^Is_Sc:sund}', "");
Expect(1, 7367, '\p{Is_Sc= sund}', "");
Expect(0, 7367, '\p{^Is_Sc= sund}', "");
Expect(0, 7367, '\P{Is_Sc= sund}', "");
Expect(1, 7367, '\P{^Is_Sc= sund}', "");
Expect(0, 7368, '\p{Is_Sc= sund}', "");
Expect(1, 7368, '\p{^Is_Sc= sund}', "");
Expect(1, 7368, '\P{Is_Sc= sund}', "");
Expect(0, 7368, '\P{^Is_Sc= sund}', "");
Error('\p{Script=  Syloti_NAGRI/a/}');
Error('\P{Script=  Syloti_NAGRI/a/}');
Expect(1, 43051, '\p{Script=sylotinagri}', "");
Expect(0, 43051, '\p{^Script=sylotinagri}', "");
Expect(0, 43051, '\P{Script=sylotinagri}', "");
Expect(1, 43051, '\P{^Script=sylotinagri}', "");
Expect(0, 43052, '\p{Script=sylotinagri}', "");
Expect(1, 43052, '\p{^Script=sylotinagri}', "");
Expect(1, 43052, '\P{Script=sylotinagri}', "");
Expect(0, 43052, '\P{^Script=sylotinagri}', "");
Expect(1, 43051, '\p{Script:		Syloti_nagri}', "");
Expect(0, 43051, '\p{^Script:		Syloti_nagri}', "");
Expect(0, 43051, '\P{Script:		Syloti_nagri}', "");
Expect(1, 43051, '\P{^Script:		Syloti_nagri}', "");
Expect(0, 43052, '\p{Script:		Syloti_nagri}', "");
Expect(1, 43052, '\p{^Script:		Syloti_nagri}', "");
Expect(1, 43052, '\P{Script:		Syloti_nagri}', "");
Expect(0, 43052, '\P{^Script:		Syloti_nagri}', "");
Error('\p{Sc=	:=sylo}');
Error('\P{Sc=	:=sylo}');
Expect(1, 43051, '\p{Sc=sylo}', "");
Expect(0, 43051, '\p{^Sc=sylo}', "");
Expect(0, 43051, '\P{Sc=sylo}', "");
Expect(1, 43051, '\P{^Sc=sylo}', "");
Expect(0, 43052, '\p{Sc=sylo}', "");
Expect(1, 43052, '\p{^Sc=sylo}', "");
Expect(1, 43052, '\P{Sc=sylo}', "");
Expect(0, 43052, '\P{^Sc=sylo}', "");
Expect(1, 43051, '\p{Sc=-	Sylo}', "");
Expect(0, 43051, '\p{^Sc=-	Sylo}', "");
Expect(0, 43051, '\P{Sc=-	Sylo}', "");
Expect(1, 43051, '\P{^Sc=-	Sylo}', "");
Expect(0, 43052, '\p{Sc=-	Sylo}', "");
Expect(1, 43052, '\p{^Sc=-	Sylo}', "");
Expect(1, 43052, '\P{Sc=-	Sylo}', "");
Expect(0, 43052, '\P{^Sc=-	Sylo}', "");
Error('\p{Is_Script=-syloti_nagri:=}');
Error('\P{Is_Script=-syloti_nagri:=}');
Expect(1, 43051, '\p{Is_Script=sylotinagri}', "");
Expect(0, 43051, '\p{^Is_Script=sylotinagri}', "");
Expect(0, 43051, '\P{Is_Script=sylotinagri}', "");
Expect(1, 43051, '\P{^Is_Script=sylotinagri}', "");
Expect(0, 43052, '\p{Is_Script=sylotinagri}', "");
Expect(1, 43052, '\p{^Is_Script=sylotinagri}', "");
Expect(1, 43052, '\P{Is_Script=sylotinagri}', "");
Expect(0, 43052, '\P{^Is_Script=sylotinagri}', "");
Expect(1, 43051, '\p{Is_Script= _Syloti_NAGRI}', "");
Expect(0, 43051, '\p{^Is_Script= _Syloti_NAGRI}', "");
Expect(0, 43051, '\P{Is_Script= _Syloti_NAGRI}', "");
Expect(1, 43051, '\P{^Is_Script= _Syloti_NAGRI}', "");
Expect(0, 43052, '\p{Is_Script= _Syloti_NAGRI}', "");
Expect(1, 43052, '\p{^Is_Script= _Syloti_NAGRI}', "");
Expect(1, 43052, '\P{Is_Script= _Syloti_NAGRI}', "");
Expect(0, 43052, '\P{^Is_Script= _Syloti_NAGRI}', "");
Error('\p{Is_Sc=	/a/Sylo}');
Error('\P{Is_Sc=	/a/Sylo}');
Expect(1, 43051, '\p{Is_Sc=sylo}', "");
Expect(0, 43051, '\p{^Is_Sc=sylo}', "");
Expect(0, 43051, '\P{Is_Sc=sylo}', "");
Expect(1, 43051, '\P{^Is_Sc=sylo}', "");
Expect(0, 43052, '\p{Is_Sc=sylo}', "");
Expect(1, 43052, '\p{^Is_Sc=sylo}', "");
Expect(1, 43052, '\P{Is_Sc=sylo}', "");
Expect(0, 43052, '\P{^Is_Sc=sylo}', "");
Expect(1, 43051, '\p{Is_Sc:     SYLO}', "");
Expect(0, 43051, '\p{^Is_Sc:     SYLO}', "");
Expect(0, 43051, '\P{Is_Sc:     SYLO}', "");
Expect(1, 43051, '\P{^Is_Sc:     SYLO}', "");
Expect(0, 43052, '\p{Is_Sc:     SYLO}', "");
Expect(1, 43052, '\p{^Is_Sc:     SYLO}', "");
Expect(1, 43052, '\P{Is_Sc:     SYLO}', "");
Expect(0, 43052, '\P{^Is_Sc:     SYLO}', "");
Error('\p{Script=SYRIAC:=}');
Error('\P{Script=SYRIAC:=}');
Expect(1, 1871, '\p{Script=syriac}', "");
Expect(0, 1871, '\p{^Script=syriac}', "");
Expect(0, 1871, '\P{Script=syriac}', "");
Expect(1, 1871, '\P{^Script=syriac}', "");
Expect(0, 1872, '\p{Script=syriac}', "");
Expect(1, 1872, '\p{^Script=syriac}', "");
Expect(1, 1872, '\P{Script=syriac}', "");
Expect(0, 1872, '\P{^Script=syriac}', "");
Expect(1, 1871, '\p{Script:   -	Syriac}', "");
Expect(0, 1871, '\p{^Script:   -	Syriac}', "");
Expect(0, 1871, '\P{Script:   -	Syriac}', "");
Expect(1, 1871, '\P{^Script:   -	Syriac}', "");
Expect(0, 1872, '\p{Script:   -	Syriac}', "");
Expect(1, 1872, '\p{^Script:   -	Syriac}', "");
Expect(1, 1872, '\P{Script:   -	Syriac}', "");
Expect(0, 1872, '\P{^Script:   -	Syriac}', "");
Error('\p{Sc=/a/ SYRC}');
Error('\P{Sc=/a/ SYRC}');
Expect(1, 1871, '\p{Sc:syrc}', "");
Expect(0, 1871, '\p{^Sc:syrc}', "");
Expect(0, 1871, '\P{Sc:syrc}', "");
Expect(1, 1871, '\P{^Sc:syrc}', "");
Expect(0, 1872, '\p{Sc:syrc}', "");
Expect(1, 1872, '\p{^Sc:syrc}', "");
Expect(1, 1872, '\P{Sc:syrc}', "");
Expect(0, 1872, '\P{^Sc:syrc}', "");
Expect(1, 1871, '\p{Sc=	_SYRC}', "");
Expect(0, 1871, '\p{^Sc=	_SYRC}', "");
Expect(0, 1871, '\P{Sc=	_SYRC}', "");
Expect(1, 1871, '\P{^Sc=	_SYRC}', "");
Expect(0, 1872, '\p{Sc=	_SYRC}', "");
Expect(1, 1872, '\p{^Sc=	_SYRC}', "");
Expect(1, 1872, '\P{Sc=	_SYRC}', "");
Expect(0, 1872, '\P{^Sc=	_SYRC}', "");
Error('\p{Is_Script=_/a/syriac}');
Error('\P{Is_Script=_/a/syriac}');
Expect(1, 1871, '\p{Is_Script=syriac}', "");
Expect(0, 1871, '\p{^Is_Script=syriac}', "");
Expect(0, 1871, '\P{Is_Script=syriac}', "");
Expect(1, 1871, '\P{^Is_Script=syriac}', "");
Expect(0, 1872, '\p{Is_Script=syriac}', "");
Expect(1, 1872, '\p{^Is_Script=syriac}', "");
Expect(1, 1872, '\P{Is_Script=syriac}', "");
Expect(0, 1872, '\P{^Is_Script=syriac}', "");
Expect(1, 1871, '\p{Is_Script=		Syriac}', "");
Expect(0, 1871, '\p{^Is_Script=		Syriac}', "");
Expect(0, 1871, '\P{Is_Script=		Syriac}', "");
Expect(1, 1871, '\P{^Is_Script=		Syriac}', "");
Expect(0, 1872, '\p{Is_Script=		Syriac}', "");
Expect(1, 1872, '\p{^Is_Script=		Syriac}', "");
Expect(1, 1872, '\P{Is_Script=		Syriac}', "");
Expect(0, 1872, '\P{^Is_Script=		Syriac}', "");
Error('\p{Is_Sc=-/a/Syrc}');
Error('\P{Is_Sc=-/a/Syrc}');
Expect(1, 1871, '\p{Is_Sc=syrc}', "");
Expect(0, 1871, '\p{^Is_Sc=syrc}', "");
Expect(0, 1871, '\P{Is_Sc=syrc}', "");
Expect(1, 1871, '\P{^Is_Sc=syrc}', "");
Expect(0, 1872, '\p{Is_Sc=syrc}', "");
Expect(1, 1872, '\p{^Is_Sc=syrc}', "");
Expect(1, 1872, '\P{Is_Sc=syrc}', "");
Expect(0, 1872, '\P{^Is_Sc=syrc}', "");
Expect(1, 1871, '\p{Is_Sc=-Syrc}', "");
Expect(0, 1871, '\p{^Is_Sc=-Syrc}', "");
Expect(0, 1871, '\P{Is_Sc=-Syrc}', "");
Expect(1, 1871, '\P{^Is_Sc=-Syrc}', "");
Expect(0, 1872, '\p{Is_Sc=-Syrc}', "");
Expect(1, 1872, '\p{^Is_Sc=-Syrc}', "");
Expect(1, 1872, '\P{Is_Sc=-Syrc}', "");
Expect(0, 1872, '\P{^Is_Sc=-Syrc}', "");
Error('\p{Script=  Tagbanwa:=}');
Error('\P{Script=  Tagbanwa:=}');
Expect(1, 6003, '\p{Script=tagbanwa}', "");
Expect(0, 6003, '\p{^Script=tagbanwa}', "");
Expect(0, 6003, '\P{Script=tagbanwa}', "");
Expect(1, 6003, '\P{^Script=tagbanwa}', "");
Expect(0, 6004, '\p{Script=tagbanwa}', "");
Expect(1, 6004, '\p{^Script=tagbanwa}', "");
Expect(1, 6004, '\P{Script=tagbanwa}', "");
Expect(0, 6004, '\P{^Script=tagbanwa}', "");
Expect(1, 6003, '\p{Script= 	TAGBANWA}', "");
Expect(0, 6003, '\p{^Script= 	TAGBANWA}', "");
Expect(0, 6003, '\P{Script= 	TAGBANWA}', "");
Expect(1, 6003, '\P{^Script= 	TAGBANWA}', "");
Expect(0, 6004, '\p{Script= 	TAGBANWA}', "");
Expect(1, 6004, '\p{^Script= 	TAGBANWA}', "");
Expect(1, 6004, '\P{Script= 	TAGBANWA}', "");
Expect(0, 6004, '\P{^Script= 	TAGBANWA}', "");
Error('\p{Sc=:=TAGB}');
Error('\P{Sc=:=TAGB}');
Expect(1, 6003, '\p{Sc=tagb}', "");
Expect(0, 6003, '\p{^Sc=tagb}', "");
Expect(0, 6003, '\P{Sc=tagb}', "");
Expect(1, 6003, '\P{^Sc=tagb}', "");
Expect(0, 6004, '\p{Sc=tagb}', "");
Expect(1, 6004, '\p{^Sc=tagb}', "");
Expect(1, 6004, '\P{Sc=tagb}', "");
Expect(0, 6004, '\P{^Sc=tagb}', "");
Expect(1, 6003, '\p{Sc= -tagb}', "");
Expect(0, 6003, '\p{^Sc= -tagb}', "");
Expect(0, 6003, '\P{Sc= -tagb}', "");
Expect(1, 6003, '\P{^Sc= -tagb}', "");
Expect(0, 6004, '\p{Sc= -tagb}', "");
Expect(1, 6004, '\p{^Sc= -tagb}', "");
Expect(1, 6004, '\P{Sc= -tagb}', "");
Expect(0, 6004, '\P{^Sc= -tagb}', "");
Error('\p{Is_Script:	_Tagbanwa:=}');
Error('\P{Is_Script:	_Tagbanwa:=}');
Expect(1, 6003, '\p{Is_Script:   tagbanwa}', "");
Expect(0, 6003, '\p{^Is_Script:   tagbanwa}', "");
Expect(0, 6003, '\P{Is_Script:   tagbanwa}', "");
Expect(1, 6003, '\P{^Is_Script:   tagbanwa}', "");
Expect(0, 6004, '\p{Is_Script:   tagbanwa}', "");
Expect(1, 6004, '\p{^Is_Script:   tagbanwa}', "");
Expect(1, 6004, '\P{Is_Script:   tagbanwa}', "");
Expect(0, 6004, '\P{^Is_Script:   tagbanwa}', "");
Expect(1, 6003, '\p{Is_Script:   - tagbanwa}', "");
Expect(0, 6003, '\p{^Is_Script:   - tagbanwa}', "");
Expect(0, 6003, '\P{Is_Script:   - tagbanwa}', "");
Expect(1, 6003, '\P{^Is_Script:   - tagbanwa}', "");
Expect(0, 6004, '\p{Is_Script:   - tagbanwa}', "");
Expect(1, 6004, '\p{^Is_Script:   - tagbanwa}', "");
Expect(1, 6004, '\P{Is_Script:   - tagbanwa}', "");
Expect(0, 6004, '\P{^Is_Script:   - tagbanwa}', "");
Error('\p{Is_Sc=/a/ Tagb}');
Error('\P{Is_Sc=/a/ Tagb}');
Expect(1, 6003, '\p{Is_Sc=tagb}', "");
Expect(0, 6003, '\p{^Is_Sc=tagb}', "");
Expect(0, 6003, '\P{Is_Sc=tagb}', "");
Expect(1, 6003, '\P{^Is_Sc=tagb}', "");
Expect(0, 6004, '\p{Is_Sc=tagb}', "");
Expect(1, 6004, '\p{^Is_Sc=tagb}', "");
Expect(1, 6004, '\P{Is_Sc=tagb}', "");
Expect(0, 6004, '\P{^Is_Sc=tagb}', "");
Expect(1, 6003, '\p{Is_Sc=	tagb}', "");
Expect(0, 6003, '\p{^Is_Sc=	tagb}', "");
Expect(0, 6003, '\P{Is_Sc=	tagb}', "");
Expect(1, 6003, '\P{^Is_Sc=	tagb}', "");
Expect(0, 6004, '\p{Is_Sc=	tagb}', "");
Expect(1, 6004, '\p{^Is_Sc=	tagb}', "");
Expect(1, 6004, '\P{Is_Sc=	tagb}', "");
Expect(0, 6004, '\P{^Is_Sc=	tagb}', "");
Error('\p{Script:   	/a/TAKRI}');
Error('\P{Script:   	/a/TAKRI}');
Expect(1, 71369, '\p{Script=takri}', "");
Expect(0, 71369, '\p{^Script=takri}', "");
Expect(0, 71369, '\P{Script=takri}', "");
Expect(1, 71369, '\P{^Script=takri}', "");
Expect(0, 71370, '\p{Script=takri}', "");
Expect(1, 71370, '\p{^Script=takri}', "");
Expect(1, 71370, '\P{Script=takri}', "");
Expect(0, 71370, '\P{^Script=takri}', "");
Expect(1, 71369, '\p{Script:   - TAKRI}', "");
Expect(0, 71369, '\p{^Script:   - TAKRI}', "");
Expect(0, 71369, '\P{Script:   - TAKRI}', "");
Expect(1, 71369, '\P{^Script:   - TAKRI}', "");
Expect(0, 71370, '\p{Script:   - TAKRI}', "");
Expect(1, 71370, '\p{^Script:   - TAKRI}', "");
Expect(1, 71370, '\P{Script:   - TAKRI}', "");
Expect(0, 71370, '\P{^Script:   - TAKRI}', "");
Error('\p{Sc=-Takr:=}');
Error('\P{Sc=-Takr:=}');
Expect(1, 71369, '\p{Sc=takr}', "");
Expect(0, 71369, '\p{^Sc=takr}', "");
Expect(0, 71369, '\P{Sc=takr}', "");
Expect(1, 71369, '\P{^Sc=takr}', "");
Expect(0, 71370, '\p{Sc=takr}', "");
Expect(1, 71370, '\p{^Sc=takr}', "");
Expect(1, 71370, '\P{Sc=takr}', "");
Expect(0, 71370, '\P{^Sc=takr}', "");
Expect(1, 71369, '\p{Sc=_Takr}', "");
Expect(0, 71369, '\p{^Sc=_Takr}', "");
Expect(0, 71369, '\P{Sc=_Takr}', "");
Expect(1, 71369, '\P{^Sc=_Takr}', "");
Expect(0, 71370, '\p{Sc=_Takr}', "");
Expect(1, 71370, '\p{^Sc=_Takr}', "");
Expect(1, 71370, '\P{Sc=_Takr}', "");
Expect(0, 71370, '\P{^Sc=_Takr}', "");
Error('\p{Is_Script=:=- takri}');
Error('\P{Is_Script=:=- takri}');
Expect(1, 71369, '\p{Is_Script:   takri}', "");
Expect(0, 71369, '\p{^Is_Script:   takri}', "");
Expect(0, 71369, '\P{Is_Script:   takri}', "");
Expect(1, 71369, '\P{^Is_Script:   takri}', "");
Expect(0, 71370, '\p{Is_Script:   takri}', "");
Expect(1, 71370, '\p{^Is_Script:   takri}', "");
Expect(1, 71370, '\P{Is_Script:   takri}', "");
Expect(0, 71370, '\P{^Is_Script:   takri}', "");
Expect(1, 71369, '\p{Is_Script=_	Takri}', "");
Expect(0, 71369, '\p{^Is_Script=_	Takri}', "");
Expect(0, 71369, '\P{Is_Script=_	Takri}', "");
Expect(1, 71369, '\P{^Is_Script=_	Takri}', "");
Expect(0, 71370, '\p{Is_Script=_	Takri}', "");
Expect(1, 71370, '\p{^Is_Script=_	Takri}', "");
Expect(1, 71370, '\P{Is_Script=_	Takri}', "");
Expect(0, 71370, '\P{^Is_Script=_	Takri}', "");
Error('\p{Is_Sc=-:=Takr}');
Error('\P{Is_Sc=-:=Takr}');
Expect(1, 71369, '\p{Is_Sc=takr}', "");
Expect(0, 71369, '\p{^Is_Sc=takr}', "");
Expect(0, 71369, '\P{Is_Sc=takr}', "");
Expect(1, 71369, '\P{^Is_Sc=takr}', "");
Expect(0, 71370, '\p{Is_Sc=takr}', "");
Expect(1, 71370, '\p{^Is_Sc=takr}', "");
Expect(1, 71370, '\P{Is_Sc=takr}', "");
Expect(0, 71370, '\P{^Is_Sc=takr}', "");
Expect(1, 71369, '\p{Is_Sc= _takr}', "");
Expect(0, 71369, '\p{^Is_Sc= _takr}', "");
Expect(0, 71369, '\P{Is_Sc= _takr}', "");
Expect(1, 71369, '\P{^Is_Sc= _takr}', "");
Expect(0, 71370, '\p{Is_Sc= _takr}', "");
Expect(1, 71370, '\p{^Is_Sc= _takr}', "");
Expect(1, 71370, '\P{Is_Sc= _takr}', "");
Expect(0, 71370, '\P{^Is_Sc= _takr}', "");
Error('\p{Script=-/a/tai_LE}');
Error('\P{Script=-/a/tai_LE}');
Expect(1, 6516, '\p{Script=taile}', "");
Expect(0, 6516, '\p{^Script=taile}', "");
Expect(0, 6516, '\P{Script=taile}', "");
Expect(1, 6516, '\P{^Script=taile}', "");
Expect(0, 6517, '\p{Script=taile}', "");
Expect(1, 6517, '\p{^Script=taile}', "");
Expect(1, 6517, '\P{Script=taile}', "");
Expect(0, 6517, '\P{^Script=taile}', "");
Expect(1, 6516, '\p{Script=		Tai_Le}', "");
Expect(0, 6516, '\p{^Script=		Tai_Le}', "");
Expect(0, 6516, '\P{Script=		Tai_Le}', "");
Expect(1, 6516, '\P{^Script=		Tai_Le}', "");
Expect(0, 6517, '\p{Script=		Tai_Le}', "");
Expect(1, 6517, '\p{^Script=		Tai_Le}', "");
Expect(1, 6517, '\P{Script=		Tai_Le}', "");
Expect(0, 6517, '\P{^Script=		Tai_Le}', "");
Error('\p{Sc=_	TALE:=}');
Error('\P{Sc=_	TALE:=}');
Expect(1, 6516, '\p{Sc=tale}', "");
Expect(0, 6516, '\p{^Sc=tale}', "");
Expect(0, 6516, '\P{Sc=tale}', "");
Expect(1, 6516, '\P{^Sc=tale}', "");
Expect(0, 6517, '\p{Sc=tale}', "");
Expect(1, 6517, '\p{^Sc=tale}', "");
Expect(1, 6517, '\P{Sc=tale}', "");
Expect(0, 6517, '\P{^Sc=tale}', "");
Expect(1, 6516, '\p{Sc:   	_Tale}', "");
Expect(0, 6516, '\p{^Sc:   	_Tale}', "");
Expect(0, 6516, '\P{Sc:   	_Tale}', "");
Expect(1, 6516, '\P{^Sc:   	_Tale}', "");
Expect(0, 6517, '\p{Sc:   	_Tale}', "");
Expect(1, 6517, '\p{^Sc:   	_Tale}', "");
Expect(1, 6517, '\P{Sc:   	_Tale}', "");
Expect(0, 6517, '\P{^Sc:   	_Tale}', "");
Error('\p{Is_Script=		Tai_Le:=}');
Error('\P{Is_Script=		Tai_Le:=}');
Expect(1, 6516, '\p{Is_Script:   taile}', "");
Expect(0, 6516, '\p{^Is_Script:   taile}', "");
Expect(0, 6516, '\P{Is_Script:   taile}', "");
Expect(1, 6516, '\P{^Is_Script:   taile}', "");
Expect(0, 6517, '\p{Is_Script:   taile}', "");
Expect(1, 6517, '\p{^Is_Script:   taile}', "");
Expect(1, 6517, '\P{Is_Script:   taile}', "");
Expect(0, 6517, '\P{^Is_Script:   taile}', "");
Expect(1, 6516, '\p{Is_Script=--tai_LE}', "");
Expect(0, 6516, '\p{^Is_Script=--tai_LE}', "");
Expect(0, 6516, '\P{Is_Script=--tai_LE}', "");
Expect(1, 6516, '\P{^Is_Script=--tai_LE}', "");
Expect(0, 6517, '\p{Is_Script=--tai_LE}', "");
Expect(1, 6517, '\p{^Is_Script=--tai_LE}', "");
Expect(1, 6517, '\P{Is_Script=--tai_LE}', "");
Expect(0, 6517, '\P{^Is_Script=--tai_LE}', "");
Error('\p{Is_Sc=/a/-_Tale}');
Error('\P{Is_Sc=/a/-_Tale}');
Expect(1, 6516, '\p{Is_Sc=tale}', "");
Expect(0, 6516, '\p{^Is_Sc=tale}', "");
Expect(0, 6516, '\P{Is_Sc=tale}', "");
Expect(1, 6516, '\P{^Is_Sc=tale}', "");
Expect(0, 6517, '\p{Is_Sc=tale}', "");
Expect(1, 6517, '\p{^Is_Sc=tale}', "");
Expect(1, 6517, '\P{Is_Sc=tale}', "");
Expect(0, 6517, '\P{^Is_Sc=tale}', "");
Expect(1, 6516, '\p{Is_Sc= -Tale}', "");
Expect(0, 6516, '\p{^Is_Sc= -Tale}', "");
Expect(0, 6516, '\P{Is_Sc= -Tale}', "");
Expect(1, 6516, '\P{^Is_Sc= -Tale}', "");
Expect(0, 6517, '\p{Is_Sc= -Tale}', "");
Expect(1, 6517, '\p{^Is_Sc= -Tale}', "");
Expect(1, 6517, '\P{Is_Sc= -Tale}', "");
Expect(0, 6517, '\P{^Is_Sc= -Tale}', "");
Error('\p{Script=_:=NEW_Tai_LUE}');
Error('\P{Script=_:=NEW_Tai_LUE}');
Expect(1, 6623, '\p{Script=newtailue}', "");
Expect(0, 6623, '\p{^Script=newtailue}', "");
Expect(0, 6623, '\P{Script=newtailue}', "");
Expect(1, 6623, '\P{^Script=newtailue}', "");
Expect(0, 6624, '\p{Script=newtailue}', "");
Expect(1, 6624, '\p{^Script=newtailue}', "");
Expect(1, 6624, '\P{Script=newtailue}', "");
Expect(0, 6624, '\P{^Script=newtailue}', "");
Expect(1, 6623, '\p{Script=- NEW_TAI_lue}', "");
Expect(0, 6623, '\p{^Script=- NEW_TAI_lue}', "");
Expect(0, 6623, '\P{Script=- NEW_TAI_lue}', "");
Expect(1, 6623, '\P{^Script=- NEW_TAI_lue}', "");
Expect(0, 6624, '\p{Script=- NEW_TAI_lue}', "");
Expect(1, 6624, '\p{^Script=- NEW_TAI_lue}', "");
Expect(1, 6624, '\P{Script=- NEW_TAI_lue}', "");
Expect(0, 6624, '\P{^Script=- NEW_TAI_lue}', "");
Error('\p{Sc=_ TALU/a/}');
Error('\P{Sc=_ TALU/a/}');
Expect(1, 6623, '\p{Sc=talu}', "");
Expect(0, 6623, '\p{^Sc=talu}', "");
Expect(0, 6623, '\P{Sc=talu}', "");
Expect(1, 6623, '\P{^Sc=talu}', "");
Expect(0, 6624, '\p{Sc=talu}', "");
Expect(1, 6624, '\p{^Sc=talu}', "");
Expect(1, 6624, '\P{Sc=talu}', "");
Expect(0, 6624, '\P{^Sc=talu}', "");
Expect(1, 6623, '\p{Sc= _talu}', "");
Expect(0, 6623, '\p{^Sc= _talu}', "");
Expect(0, 6623, '\P{Sc= _talu}', "");
Expect(1, 6623, '\P{^Sc= _talu}', "");
Expect(0, 6624, '\p{Sc= _talu}', "");
Expect(1, 6624, '\p{^Sc= _talu}', "");
Expect(1, 6624, '\P{Sc= _talu}', "");
Expect(0, 6624, '\P{^Sc= _talu}', "");
Error('\p{Is_Script=:=  NEW_Tai_LUE}');
Error('\P{Is_Script=:=  NEW_Tai_LUE}');
Expect(1, 6623, '\p{Is_Script=newtailue}', "");
Expect(0, 6623, '\p{^Is_Script=newtailue}', "");
Expect(0, 6623, '\P{Is_Script=newtailue}', "");
Expect(1, 6623, '\P{^Is_Script=newtailue}', "");
Expect(0, 6624, '\p{Is_Script=newtailue}', "");
Expect(1, 6624, '\p{^Is_Script=newtailue}', "");
Expect(1, 6624, '\P{Is_Script=newtailue}', "");
Expect(0, 6624, '\P{^Is_Script=newtailue}', "");
Expect(1, 6623, '\p{Is_Script=_	NEW_Tai_Lue}', "");
Expect(0, 6623, '\p{^Is_Script=_	NEW_Tai_Lue}', "");
Expect(0, 6623, '\P{Is_Script=_	NEW_Tai_Lue}', "");
Expect(1, 6623, '\P{^Is_Script=_	NEW_Tai_Lue}', "");
Expect(0, 6624, '\p{Is_Script=_	NEW_Tai_Lue}', "");
Expect(1, 6624, '\p{^Is_Script=_	NEW_Tai_Lue}', "");
Expect(1, 6624, '\P{Is_Script=_	NEW_Tai_Lue}', "");
Expect(0, 6624, '\P{^Is_Script=_	NEW_Tai_Lue}', "");
Error('\p{Is_Sc=:= TALU}');
Error('\P{Is_Sc=:= TALU}');
Expect(1, 6623, '\p{Is_Sc=talu}', "");
Expect(0, 6623, '\p{^Is_Sc=talu}', "");
Expect(0, 6623, '\P{Is_Sc=talu}', "");
Expect(1, 6623, '\P{^Is_Sc=talu}', "");
Expect(0, 6624, '\p{Is_Sc=talu}', "");
Expect(1, 6624, '\p{^Is_Sc=talu}', "");
Expect(1, 6624, '\P{Is_Sc=talu}', "");
Expect(0, 6624, '\P{^Is_Sc=talu}', "");
Expect(1, 6623, '\p{Is_Sc=		TALU}', "");
Expect(0, 6623, '\p{^Is_Sc=		TALU}', "");
Expect(0, 6623, '\P{Is_Sc=		TALU}', "");
Expect(1, 6623, '\P{^Is_Sc=		TALU}', "");
Expect(0, 6624, '\p{Is_Sc=		TALU}', "");
Expect(1, 6624, '\p{^Is_Sc=		TALU}', "");
Expect(1, 6624, '\P{Is_Sc=		TALU}', "");
Expect(0, 6624, '\P{^Is_Sc=		TALU}', "");
Error('\p{Script:   :=	 tamil}');
Error('\P{Script:   :=	 tamil}');
Expect(1, 3066, '\p{Script=tamil}', "");
Expect(0, 3066, '\p{^Script=tamil}', "");
Expect(0, 3066, '\P{Script=tamil}', "");
Expect(1, 3066, '\P{^Script=tamil}', "");
Expect(0, 3067, '\p{Script=tamil}', "");
Expect(1, 3067, '\p{^Script=tamil}', "");
Expect(1, 3067, '\P{Script=tamil}', "");
Expect(0, 3067, '\P{^Script=tamil}', "");
Expect(1, 3066, '\p{Script= _tamil}', "");
Expect(0, 3066, '\p{^Script= _tamil}', "");
Expect(0, 3066, '\P{Script= _tamil}', "");
Expect(1, 3066, '\P{^Script= _tamil}', "");
Expect(0, 3067, '\p{Script= _tamil}', "");
Expect(1, 3067, '\p{^Script= _tamil}', "");
Expect(1, 3067, '\P{Script= _tamil}', "");
Expect(0, 3067, '\P{^Script= _tamil}', "");
Error('\p{Sc=__TAML:=}');
Error('\P{Sc=__TAML:=}');
Expect(1, 3066, '\p{Sc=taml}', "");
Expect(0, 3066, '\p{^Sc=taml}', "");
Expect(0, 3066, '\P{Sc=taml}', "");
Expect(1, 3066, '\P{^Sc=taml}', "");
Expect(0, 3067, '\p{Sc=taml}', "");
Expect(1, 3067, '\p{^Sc=taml}', "");
Expect(1, 3067, '\P{Sc=taml}', "");
Expect(0, 3067, '\P{^Sc=taml}', "");
Expect(1, 3066, '\p{Sc=Taml}', "");
Expect(0, 3066, '\p{^Sc=Taml}', "");
Expect(0, 3066, '\P{Sc=Taml}', "");
Expect(1, 3066, '\P{^Sc=Taml}', "");
Expect(0, 3067, '\p{Sc=Taml}', "");
Expect(1, 3067, '\p{^Sc=Taml}', "");
Expect(1, 3067, '\P{Sc=Taml}', "");
Expect(0, 3067, '\P{^Sc=Taml}', "");
Error('\p{Is_Script=/a/--TAMIL}');
Error('\P{Is_Script=/a/--TAMIL}');
Expect(1, 3066, '\p{Is_Script=tamil}', "");
Expect(0, 3066, '\p{^Is_Script=tamil}', "");
Expect(0, 3066, '\P{Is_Script=tamil}', "");
Expect(1, 3066, '\P{^Is_Script=tamil}', "");
Expect(0, 3067, '\p{Is_Script=tamil}', "");
Expect(1, 3067, '\p{^Is_Script=tamil}', "");
Expect(1, 3067, '\P{Is_Script=tamil}', "");
Expect(0, 3067, '\P{^Is_Script=tamil}', "");
Expect(1, 3066, '\p{Is_Script=-_Tamil}', "");
Expect(0, 3066, '\p{^Is_Script=-_Tamil}', "");
Expect(0, 3066, '\P{Is_Script=-_Tamil}', "");
Expect(1, 3066, '\P{^Is_Script=-_Tamil}', "");
Expect(0, 3067, '\p{Is_Script=-_Tamil}', "");
Expect(1, 3067, '\p{^Is_Script=-_Tamil}', "");
Expect(1, 3067, '\P{Is_Script=-_Tamil}', "");
Expect(0, 3067, '\P{^Is_Script=-_Tamil}', "");
Error('\p{Is_Sc:-	Taml:=}');
Error('\P{Is_Sc:-	Taml:=}');
Expect(1, 3066, '\p{Is_Sc=taml}', "");
Expect(0, 3066, '\p{^Is_Sc=taml}', "");
Expect(0, 3066, '\P{Is_Sc=taml}', "");
Expect(1, 3066, '\P{^Is_Sc=taml}', "");
Expect(0, 3067, '\p{Is_Sc=taml}', "");
Expect(1, 3067, '\p{^Is_Sc=taml}', "");
Expect(1, 3067, '\P{Is_Sc=taml}', "");
Expect(0, 3067, '\P{^Is_Sc=taml}', "");
Expect(1, 3066, '\p{Is_Sc:	 _Taml}', "");
Expect(0, 3066, '\p{^Is_Sc:	 _Taml}', "");
Expect(0, 3066, '\P{Is_Sc:	 _Taml}', "");
Expect(1, 3066, '\P{^Is_Sc:	 _Taml}', "");
Expect(0, 3067, '\p{Is_Sc:	 _Taml}', "");
Expect(1, 3067, '\p{^Is_Sc:	 _Taml}', "");
Expect(1, 3067, '\P{Is_Sc:	 _Taml}', "");
Expect(0, 3067, '\P{^Is_Sc:	 _Taml}', "");
Error('\p{Script= :=Tai_viet}');
Error('\P{Script= :=Tai_viet}');
Expect(1, 43743, '\p{Script=taiviet}', "");
Expect(0, 43743, '\p{^Script=taiviet}', "");
Expect(0, 43743, '\P{Script=taiviet}', "");
Expect(1, 43743, '\P{^Script=taiviet}', "");
Expect(0, 43744, '\p{Script=taiviet}', "");
Expect(1, 43744, '\p{^Script=taiviet}', "");
Expect(1, 43744, '\P{Script=taiviet}', "");
Expect(0, 43744, '\P{^Script=taiviet}', "");
Expect(1, 43743, '\p{Script= Tai_Viet}', "");
Expect(0, 43743, '\p{^Script= Tai_Viet}', "");
Expect(0, 43743, '\P{Script= Tai_Viet}', "");
Expect(1, 43743, '\P{^Script= Tai_Viet}', "");
Expect(0, 43744, '\p{Script= Tai_Viet}', "");
Expect(1, 43744, '\p{^Script= Tai_Viet}', "");
Expect(1, 43744, '\P{Script= Tai_Viet}', "");
Expect(0, 43744, '\P{^Script= Tai_Viet}', "");
Error('\p{Sc:	:=-	Tavt}');
Error('\P{Sc:	:=-	Tavt}');
Expect(1, 43743, '\p{Sc=tavt}', "");
Expect(0, 43743, '\p{^Sc=tavt}', "");
Expect(0, 43743, '\P{Sc=tavt}', "");
Expect(1, 43743, '\P{^Sc=tavt}', "");
Expect(0, 43744, '\p{Sc=tavt}', "");
Expect(1, 43744, '\p{^Sc=tavt}', "");
Expect(1, 43744, '\P{Sc=tavt}', "");
Expect(0, 43744, '\P{^Sc=tavt}', "");
Expect(1, 43743, '\p{Sc:-Tavt}', "");
Expect(0, 43743, '\p{^Sc:-Tavt}', "");
Expect(0, 43743, '\P{Sc:-Tavt}', "");
Expect(1, 43743, '\P{^Sc:-Tavt}', "");
Expect(0, 43744, '\p{Sc:-Tavt}', "");
Expect(1, 43744, '\p{^Sc:-Tavt}', "");
Expect(1, 43744, '\P{Sc:-Tavt}', "");
Expect(0, 43744, '\P{^Sc:-Tavt}', "");
Error('\p{Is_Script=-:=TAI_Viet}');
Error('\P{Is_Script=-:=TAI_Viet}');
Expect(1, 43743, '\p{Is_Script=taiviet}', "");
Expect(0, 43743, '\p{^Is_Script=taiviet}', "");
Expect(0, 43743, '\P{Is_Script=taiviet}', "");
Expect(1, 43743, '\P{^Is_Script=taiviet}', "");
Expect(0, 43744, '\p{Is_Script=taiviet}', "");
Expect(1, 43744, '\p{^Is_Script=taiviet}', "");
Expect(1, 43744, '\P{Is_Script=taiviet}', "");
Expect(0, 43744, '\P{^Is_Script=taiviet}', "");
Expect(1, 43743, '\p{Is_Script=	 Tai_Viet}', "");
Expect(0, 43743, '\p{^Is_Script=	 Tai_Viet}', "");
Expect(0, 43743, '\P{Is_Script=	 Tai_Viet}', "");
Expect(1, 43743, '\P{^Is_Script=	 Tai_Viet}', "");
Expect(0, 43744, '\p{Is_Script=	 Tai_Viet}', "");
Expect(1, 43744, '\p{^Is_Script=	 Tai_Viet}', "");
Expect(1, 43744, '\P{Is_Script=	 Tai_Viet}', "");
Expect(0, 43744, '\P{^Is_Script=	 Tai_Viet}', "");
Error('\p{Is_Sc=:=-Tavt}');
Error('\P{Is_Sc=:=-Tavt}');
Expect(1, 43743, '\p{Is_Sc=tavt}', "");
Expect(0, 43743, '\p{^Is_Sc=tavt}', "");
Expect(0, 43743, '\P{Is_Sc=tavt}', "");
Expect(1, 43743, '\P{^Is_Sc=tavt}', "");
Expect(0, 43744, '\p{Is_Sc=tavt}', "");
Expect(1, 43744, '\p{^Is_Sc=tavt}', "");
Expect(1, 43744, '\P{Is_Sc=tavt}', "");
Expect(0, 43744, '\P{^Is_Sc=tavt}', "");
Expect(1, 43743, '\p{Is_Sc=	Tavt}', "");
Expect(0, 43743, '\p{^Is_Sc=	Tavt}', "");
Expect(0, 43743, '\P{Is_Sc=	Tavt}', "");
Expect(1, 43743, '\P{^Is_Sc=	Tavt}', "");
Expect(0, 43744, '\p{Is_Sc=	Tavt}', "");
Expect(1, 43744, '\p{^Is_Sc=	Tavt}', "");
Expect(1, 43744, '\P{Is_Sc=	Tavt}', "");
Expect(0, 43744, '\P{^Is_Sc=	Tavt}', "");
Error('\p{Script=/a/ telugu}');
Error('\P{Script=/a/ telugu}');
Expect(1, 3199, '\p{Script=telugu}', "");
Expect(0, 3199, '\p{^Script=telugu}', "");
Expect(0, 3199, '\P{Script=telugu}', "");
Expect(1, 3199, '\P{^Script=telugu}', "");
Expect(0, 3200, '\p{Script=telugu}', "");
Expect(1, 3200, '\p{^Script=telugu}', "");
Expect(1, 3200, '\P{Script=telugu}', "");
Expect(0, 3200, '\P{^Script=telugu}', "");
Expect(1, 3199, '\p{Script=__telugu}', "");
Expect(0, 3199, '\p{^Script=__telugu}', "");
Expect(0, 3199, '\P{Script=__telugu}', "");
Expect(1, 3199, '\P{^Script=__telugu}', "");
Expect(0, 3200, '\p{Script=__telugu}', "");
Expect(1, 3200, '\p{^Script=__telugu}', "");
Expect(1, 3200, '\P{Script=__telugu}', "");
Expect(0, 3200, '\P{^Script=__telugu}', "");
Error('\p{Sc=/a/--Telu}');
Error('\P{Sc=/a/--Telu}');
Expect(1, 3199, '\p{Sc=telu}', "");
Expect(0, 3199, '\p{^Sc=telu}', "");
Expect(0, 3199, '\P{Sc=telu}', "");
Expect(1, 3199, '\P{^Sc=telu}', "");
Expect(0, 3200, '\p{Sc=telu}', "");
Expect(1, 3200, '\p{^Sc=telu}', "");
Expect(1, 3200, '\P{Sc=telu}', "");
Expect(0, 3200, '\P{^Sc=telu}', "");
Expect(1, 3199, '\p{Sc=_telu}', "");
Expect(0, 3199, '\p{^Sc=_telu}', "");
Expect(0, 3199, '\P{Sc=_telu}', "");
Expect(1, 3199, '\P{^Sc=_telu}', "");
Expect(0, 3200, '\p{Sc=_telu}', "");
Expect(1, 3200, '\p{^Sc=_telu}', "");
Expect(1, 3200, '\P{Sc=_telu}', "");
Expect(0, 3200, '\P{^Sc=_telu}', "");
Error('\p{Is_Script=	:=TELUGU}');
Error('\P{Is_Script=	:=TELUGU}');
Expect(1, 3199, '\p{Is_Script=telugu}', "");
Expect(0, 3199, '\p{^Is_Script=telugu}', "");
Expect(0, 3199, '\P{Is_Script=telugu}', "");
Expect(1, 3199, '\P{^Is_Script=telugu}', "");
Expect(0, 3200, '\p{Is_Script=telugu}', "");
Expect(1, 3200, '\p{^Is_Script=telugu}', "");
Expect(1, 3200, '\P{Is_Script=telugu}', "");
Expect(0, 3200, '\P{^Is_Script=telugu}', "");
Expect(1, 3199, '\p{Is_Script= -Telugu}', "");
Expect(0, 3199, '\p{^Is_Script= -Telugu}', "");
Expect(0, 3199, '\P{Is_Script= -Telugu}', "");
Expect(1, 3199, '\P{^Is_Script= -Telugu}', "");
Expect(0, 3200, '\p{Is_Script= -Telugu}', "");
Expect(1, 3200, '\p{^Is_Script= -Telugu}', "");
Expect(1, 3200, '\P{Is_Script= -Telugu}', "");
Expect(0, 3200, '\P{^Is_Script= -Telugu}', "");
Error('\p{Is_Sc= Telu/a/}');
Error('\P{Is_Sc= Telu/a/}');
Expect(1, 3199, '\p{Is_Sc=telu}', "");
Expect(0, 3199, '\p{^Is_Sc=telu}', "");
Expect(0, 3199, '\P{Is_Sc=telu}', "");
Expect(1, 3199, '\P{^Is_Sc=telu}', "");
Expect(0, 3200, '\p{Is_Sc=telu}', "");
Expect(1, 3200, '\p{^Is_Sc=telu}', "");
Expect(1, 3200, '\P{Is_Sc=telu}', "");
Expect(0, 3200, '\P{^Is_Sc=telu}', "");
Expect(1, 3199, '\p{Is_Sc=-TELU}', "");
Expect(0, 3199, '\p{^Is_Sc=-TELU}', "");
Expect(0, 3199, '\P{Is_Sc=-TELU}', "");
Expect(1, 3199, '\P{^Is_Sc=-TELU}', "");
Expect(0, 3200, '\p{Is_Sc=-TELU}', "");
Expect(1, 3200, '\p{^Is_Sc=-TELU}', "");
Expect(1, 3200, '\P{Is_Sc=-TELU}', "");
Expect(0, 3200, '\P{^Is_Sc=-TELU}', "");
Error('\p{Script= 	Tifinagh/a/}');
Error('\P{Script= 	Tifinagh/a/}');
Expect(1, 11647, '\p{Script:   tifinagh}', "");
Expect(0, 11647, '\p{^Script:   tifinagh}', "");
Expect(0, 11647, '\P{Script:   tifinagh}', "");
Expect(1, 11647, '\P{^Script:   tifinagh}', "");
Expect(0, 11648, '\p{Script:   tifinagh}', "");
Expect(1, 11648, '\p{^Script:   tifinagh}', "");
Expect(1, 11648, '\P{Script:   tifinagh}', "");
Expect(0, 11648, '\P{^Script:   tifinagh}', "");
Expect(1, 11647, '\p{Script:   _	Tifinagh}', "");
Expect(0, 11647, '\p{^Script:   _	Tifinagh}', "");
Expect(0, 11647, '\P{Script:   _	Tifinagh}', "");
Expect(1, 11647, '\P{^Script:   _	Tifinagh}', "");
Expect(0, 11648, '\p{Script:   _	Tifinagh}', "");
Expect(1, 11648, '\p{^Script:   _	Tifinagh}', "");
Expect(1, 11648, '\P{Script:   _	Tifinagh}', "");
Expect(0, 11648, '\P{^Script:   _	Tifinagh}', "");
Error('\p{Sc= /a/tfng}');
Error('\P{Sc= /a/tfng}');
Expect(1, 11647, '\p{Sc=tfng}', "");
Expect(0, 11647, '\p{^Sc=tfng}', "");
Expect(0, 11647, '\P{Sc=tfng}', "");
Expect(1, 11647, '\P{^Sc=tfng}', "");
Expect(0, 11648, '\p{Sc=tfng}', "");
Expect(1, 11648, '\p{^Sc=tfng}', "");
Expect(1, 11648, '\P{Sc=tfng}', "");
Expect(0, 11648, '\P{^Sc=tfng}', "");
Expect(1, 11647, '\p{Sc=	_TFNG}', "");
Expect(0, 11647, '\p{^Sc=	_TFNG}', "");
Expect(0, 11647, '\P{Sc=	_TFNG}', "");
Expect(1, 11647, '\P{^Sc=	_TFNG}', "");
Expect(0, 11648, '\p{Sc=	_TFNG}', "");
Expect(1, 11648, '\p{^Sc=	_TFNG}', "");
Expect(1, 11648, '\P{Sc=	_TFNG}', "");
Expect(0, 11648, '\P{^Sc=	_TFNG}', "");
Error('\p{Is_Script=:= -TIFINAGH}');
Error('\P{Is_Script=:= -TIFINAGH}');
Expect(1, 11647, '\p{Is_Script=tifinagh}', "");
Expect(0, 11647, '\p{^Is_Script=tifinagh}', "");
Expect(0, 11647, '\P{Is_Script=tifinagh}', "");
Expect(1, 11647, '\P{^Is_Script=tifinagh}', "");
Expect(0, 11648, '\p{Is_Script=tifinagh}', "");
Expect(1, 11648, '\p{^Is_Script=tifinagh}', "");
Expect(1, 11648, '\P{Is_Script=tifinagh}', "");
Expect(0, 11648, '\P{^Is_Script=tifinagh}', "");
Expect(1, 11647, '\p{Is_Script=--tifinagh}', "");
Expect(0, 11647, '\p{^Is_Script=--tifinagh}', "");
Expect(0, 11647, '\P{Is_Script=--tifinagh}', "");
Expect(1, 11647, '\P{^Is_Script=--tifinagh}', "");
Expect(0, 11648, '\p{Is_Script=--tifinagh}', "");
Expect(1, 11648, '\p{^Is_Script=--tifinagh}', "");
Expect(1, 11648, '\P{Is_Script=--tifinagh}', "");
Expect(0, 11648, '\P{^Is_Script=--tifinagh}', "");
Error('\p{Is_Sc=_/a/tfng}');
Error('\P{Is_Sc=_/a/tfng}');
Expect(1, 11647, '\p{Is_Sc=tfng}', "");
Expect(0, 11647, '\p{^Is_Sc=tfng}', "");
Expect(0, 11647, '\P{Is_Sc=tfng}', "");
Expect(1, 11647, '\P{^Is_Sc=tfng}', "");
Expect(0, 11648, '\p{Is_Sc=tfng}', "");
Expect(1, 11648, '\p{^Is_Sc=tfng}', "");
Expect(1, 11648, '\P{Is_Sc=tfng}', "");
Expect(0, 11648, '\P{^Is_Sc=tfng}', "");
Expect(1, 11647, '\p{Is_Sc: 	 TFNG}', "");
Expect(0, 11647, '\p{^Is_Sc: 	 TFNG}', "");
Expect(0, 11647, '\P{Is_Sc: 	 TFNG}', "");
Expect(1, 11647, '\P{^Is_Sc: 	 TFNG}', "");
Expect(0, 11648, '\p{Is_Sc: 	 TFNG}', "");
Expect(1, 11648, '\p{^Is_Sc: 	 TFNG}', "");
Expect(1, 11648, '\P{Is_Sc: 	 TFNG}', "");
Expect(0, 11648, '\P{^Is_Sc: 	 TFNG}', "");
Error('\p{Script=/a/-tagalog}');
Error('\P{Script=/a/-tagalog}');
Expect(1, 5908, '\p{Script=tagalog}', "");
Expect(0, 5908, '\p{^Script=tagalog}', "");
Expect(0, 5908, '\P{Script=tagalog}', "");
Expect(1, 5908, '\P{^Script=tagalog}', "");
Expect(0, 5909, '\p{Script=tagalog}', "");
Expect(1, 5909, '\p{^Script=tagalog}', "");
Expect(1, 5909, '\P{Script=tagalog}', "");
Expect(0, 5909, '\P{^Script=tagalog}', "");
Expect(1, 5908, '\p{Script=	-Tagalog}', "");
Expect(0, 5908, '\p{^Script=	-Tagalog}', "");
Expect(0, 5908, '\P{Script=	-Tagalog}', "");
Expect(1, 5908, '\P{^Script=	-Tagalog}', "");
Expect(0, 5909, '\p{Script=	-Tagalog}', "");
Expect(1, 5909, '\p{^Script=	-Tagalog}', "");
Expect(1, 5909, '\P{Script=	-Tagalog}', "");
Expect(0, 5909, '\P{^Script=	-Tagalog}', "");
Error('\p{Sc=/a/-_Tglg}');
Error('\P{Sc=/a/-_Tglg}');
Expect(1, 5908, '\p{Sc=tglg}', "");
Expect(0, 5908, '\p{^Sc=tglg}', "");
Expect(0, 5908, '\P{Sc=tglg}', "");
Expect(1, 5908, '\P{^Sc=tglg}', "");
Expect(0, 5909, '\p{Sc=tglg}', "");
Expect(1, 5909, '\p{^Sc=tglg}', "");
Expect(1, 5909, '\P{Sc=tglg}', "");
Expect(0, 5909, '\P{^Sc=tglg}', "");
Expect(1, 5908, '\p{Sc:	_tglg}', "");
Expect(0, 5908, '\p{^Sc:	_tglg}', "");
Expect(0, 5908, '\P{Sc:	_tglg}', "");
Expect(1, 5908, '\P{^Sc:	_tglg}', "");
Expect(0, 5909, '\p{Sc:	_tglg}', "");
Expect(1, 5909, '\p{^Sc:	_tglg}', "");
Expect(1, 5909, '\P{Sc:	_tglg}', "");
Expect(0, 5909, '\P{^Sc:	_tglg}', "");
Error('\p{Is_Script:	-:=tagalog}');
Error('\P{Is_Script:	-:=tagalog}');
Expect(1, 5908, '\p{Is_Script=tagalog}', "");
Expect(0, 5908, '\p{^Is_Script=tagalog}', "");
Expect(0, 5908, '\P{Is_Script=tagalog}', "");
Expect(1, 5908, '\P{^Is_Script=tagalog}', "");
Expect(0, 5909, '\p{Is_Script=tagalog}', "");
Expect(1, 5909, '\p{^Is_Script=tagalog}', "");
Expect(1, 5909, '\P{Is_Script=tagalog}', "");
Expect(0, 5909, '\P{^Is_Script=tagalog}', "");
Expect(1, 5908, '\p{Is_Script: 	_Tagalog}', "");
Expect(0, 5908, '\p{^Is_Script: 	_Tagalog}', "");
Expect(0, 5908, '\P{Is_Script: 	_Tagalog}', "");
Expect(1, 5908, '\P{^Is_Script: 	_Tagalog}', "");
Expect(0, 5909, '\p{Is_Script: 	_Tagalog}', "");
Expect(1, 5909, '\p{^Is_Script: 	_Tagalog}', "");
Expect(1, 5909, '\P{Is_Script: 	_Tagalog}', "");
Expect(0, 5909, '\P{^Is_Script: 	_Tagalog}', "");
Error('\p{Is_Sc=	/a/tglg}');
Error('\P{Is_Sc=	/a/tglg}');
Expect(1, 5908, '\p{Is_Sc=tglg}', "");
Expect(0, 5908, '\p{^Is_Sc=tglg}', "");
Expect(0, 5908, '\P{Is_Sc=tglg}', "");
Expect(1, 5908, '\P{^Is_Sc=tglg}', "");
Expect(0, 5909, '\p{Is_Sc=tglg}', "");
Expect(1, 5909, '\p{^Is_Sc=tglg}', "");
Expect(1, 5909, '\P{Is_Sc=tglg}', "");
Expect(0, 5909, '\P{^Is_Sc=tglg}', "");
Expect(1, 5908, '\p{Is_Sc= _TGLG}', "");
Expect(0, 5908, '\p{^Is_Sc= _TGLG}', "");
Expect(0, 5908, '\P{Is_Sc= _TGLG}', "");
Expect(1, 5908, '\P{^Is_Sc= _TGLG}', "");
Expect(0, 5909, '\p{Is_Sc= _TGLG}', "");
Expect(1, 5909, '\p{^Is_Sc= _TGLG}', "");
Expect(1, 5909, '\P{Is_Sc= _TGLG}', "");
Expect(0, 5909, '\P{^Is_Sc= _TGLG}', "");
Error('\p{Script=-THAANA:=}');
Error('\P{Script=-THAANA:=}');
Expect(1, 1969, '\p{Script=thaana}', "");
Expect(0, 1969, '\p{^Script=thaana}', "");
Expect(0, 1969, '\P{Script=thaana}', "");
Expect(1, 1969, '\P{^Script=thaana}', "");
Expect(0, 1970, '\p{Script=thaana}', "");
Expect(1, 1970, '\p{^Script=thaana}', "");
Expect(1, 1970, '\P{Script=thaana}', "");
Expect(0, 1970, '\P{^Script=thaana}', "");
Expect(1, 1969, '\p{Script=	 THAANA}', "");
Expect(0, 1969, '\p{^Script=	 THAANA}', "");
Expect(0, 1969, '\P{Script=	 THAANA}', "");
Expect(1, 1969, '\P{^Script=	 THAANA}', "");
Expect(0, 1970, '\p{Script=	 THAANA}', "");
Expect(1, 1970, '\p{^Script=	 THAANA}', "");
Expect(1, 1970, '\P{Script=	 THAANA}', "");
Expect(0, 1970, '\P{^Script=	 THAANA}', "");
Error('\p{Sc= /a/thaa}');
Error('\P{Sc= /a/thaa}');
Expect(1, 1969, '\p{Sc=thaa}', "");
Expect(0, 1969, '\p{^Sc=thaa}', "");
Expect(0, 1969, '\P{Sc=thaa}', "");
Expect(1, 1969, '\P{^Sc=thaa}', "");
Expect(0, 1970, '\p{Sc=thaa}', "");
Expect(1, 1970, '\p{^Sc=thaa}', "");
Expect(1, 1970, '\P{Sc=thaa}', "");
Expect(0, 1970, '\P{^Sc=thaa}', "");
Expect(1, 1969, '\p{Sc=_-Thaa}', "");
Expect(0, 1969, '\p{^Sc=_-Thaa}', "");
Expect(0, 1969, '\P{Sc=_-Thaa}', "");
Expect(1, 1969, '\P{^Sc=_-Thaa}', "");
Expect(0, 1970, '\p{Sc=_-Thaa}', "");
Expect(1, 1970, '\p{^Sc=_-Thaa}', "");
Expect(1, 1970, '\P{Sc=_-Thaa}', "");
Expect(0, 1970, '\P{^Sc=_-Thaa}', "");
Error('\p{Is_Script=	:=Thaana}');
Error('\P{Is_Script=	:=Thaana}');
Expect(1, 1969, '\p{Is_Script=thaana}', "");
Expect(0, 1969, '\p{^Is_Script=thaana}', "");
Expect(0, 1969, '\P{Is_Script=thaana}', "");
Expect(1, 1969, '\P{^Is_Script=thaana}', "");
Expect(0, 1970, '\p{Is_Script=thaana}', "");
Expect(1, 1970, '\p{^Is_Script=thaana}', "");
Expect(1, 1970, '\P{Is_Script=thaana}', "");
Expect(0, 1970, '\P{^Is_Script=thaana}', "");
Expect(1, 1969, '\p{Is_Script=_-thaana}', "");
Expect(0, 1969, '\p{^Is_Script=_-thaana}', "");
Expect(0, 1969, '\P{Is_Script=_-thaana}', "");
Expect(1, 1969, '\P{^Is_Script=_-thaana}', "");
Expect(0, 1970, '\p{Is_Script=_-thaana}', "");
Expect(1, 1970, '\p{^Is_Script=_-thaana}', "");
Expect(1, 1970, '\P{Is_Script=_-thaana}', "");
Expect(0, 1970, '\P{^Is_Script=_-thaana}', "");
Error('\p{Is_Sc=	Thaa:=}');
Error('\P{Is_Sc=	Thaa:=}');
Expect(1, 1969, '\p{Is_Sc=thaa}', "");
Expect(0, 1969, '\p{^Is_Sc=thaa}', "");
Expect(0, 1969, '\P{Is_Sc=thaa}', "");
Expect(1, 1969, '\P{^Is_Sc=thaa}', "");
Expect(0, 1970, '\p{Is_Sc=thaa}', "");
Expect(1, 1970, '\p{^Is_Sc=thaa}', "");
Expect(1, 1970, '\P{Is_Sc=thaa}', "");
Expect(0, 1970, '\P{^Is_Sc=thaa}', "");
Expect(1, 1969, '\p{Is_Sc=__Thaa}', "");
Expect(0, 1969, '\p{^Is_Sc=__Thaa}', "");
Expect(0, 1969, '\P{Is_Sc=__Thaa}', "");
Expect(1, 1969, '\P{^Is_Sc=__Thaa}', "");
Expect(0, 1970, '\p{Is_Sc=__Thaa}', "");
Expect(1, 1970, '\p{^Is_Sc=__Thaa}', "");
Expect(1, 1970, '\P{Is_Sc=__Thaa}', "");
Expect(0, 1970, '\P{^Is_Sc=__Thaa}', "");
Error('\p{Script=/a/ 	thai}');
Error('\P{Script=/a/ 	thai}');
Expect(1, 3675, '\p{Script=thai}', "");
Expect(0, 3675, '\p{^Script=thai}', "");
Expect(0, 3675, '\P{Script=thai}', "");
Expect(1, 3675, '\P{^Script=thai}', "");
Expect(0, 3676, '\p{Script=thai}', "");
Expect(1, 3676, '\p{^Script=thai}', "");
Expect(1, 3676, '\P{Script=thai}', "");
Expect(0, 3676, '\P{^Script=thai}', "");
Expect(1, 3675, '\p{Script=	Thai}', "");
Expect(0, 3675, '\p{^Script=	Thai}', "");
Expect(0, 3675, '\P{Script=	Thai}', "");
Expect(1, 3675, '\P{^Script=	Thai}', "");
Expect(0, 3676, '\p{Script=	Thai}', "");
Expect(1, 3676, '\p{^Script=	Thai}', "");
Expect(1, 3676, '\P{Script=	Thai}', "");
Expect(0, 3676, '\P{^Script=	Thai}', "");
Error('\p{Sc= THAI/a/}');
Error('\P{Sc= THAI/a/}');
Expect(1, 3675, '\p{Sc=thai}', "");
Expect(0, 3675, '\p{^Sc=thai}', "");
Expect(0, 3675, '\P{Sc=thai}', "");
Expect(1, 3675, '\P{^Sc=thai}', "");
Expect(0, 3676, '\p{Sc=thai}', "");
Expect(1, 3676, '\p{^Sc=thai}', "");
Expect(1, 3676, '\P{Sc=thai}', "");
Expect(0, 3676, '\P{^Sc=thai}', "");
Expect(1, 3675, '\p{Sc=_ Thai}', "");
Expect(0, 3675, '\p{^Sc=_ Thai}', "");
Expect(0, 3675, '\P{Sc=_ Thai}', "");
Expect(1, 3675, '\P{^Sc=_ Thai}', "");
Expect(0, 3676, '\p{Sc=_ Thai}', "");
Expect(1, 3676, '\p{^Sc=_ Thai}', "");
Expect(1, 3676, '\P{Sc=_ Thai}', "");
Expect(0, 3676, '\P{^Sc=_ Thai}', "");
Error('\p{Is_Script=/a/--thai}');
Error('\P{Is_Script=/a/--thai}');
Expect(1, 3675, '\p{Is_Script=thai}', "");
Expect(0, 3675, '\p{^Is_Script=thai}', "");
Expect(0, 3675, '\P{Is_Script=thai}', "");
Expect(1, 3675, '\P{^Is_Script=thai}', "");
Expect(0, 3676, '\p{Is_Script=thai}', "");
Expect(1, 3676, '\p{^Is_Script=thai}', "");
Expect(1, 3676, '\P{Is_Script=thai}', "");
Expect(0, 3676, '\P{^Is_Script=thai}', "");
Expect(1, 3675, '\p{Is_Script=_-THAI}', "");
Expect(0, 3675, '\p{^Is_Script=_-THAI}', "");
Expect(0, 3675, '\P{Is_Script=_-THAI}', "");
Expect(1, 3675, '\P{^Is_Script=_-THAI}', "");
Expect(0, 3676, '\p{Is_Script=_-THAI}', "");
Expect(1, 3676, '\p{^Is_Script=_-THAI}', "");
Expect(1, 3676, '\P{Is_Script=_-THAI}', "");
Expect(0, 3676, '\P{^Is_Script=_-THAI}', "");
Error('\p{Is_Sc=__Thai/a/}');
Error('\P{Is_Sc=__Thai/a/}');
Expect(1, 3675, '\p{Is_Sc=thai}', "");
Expect(0, 3675, '\p{^Is_Sc=thai}', "");
Expect(0, 3675, '\P{Is_Sc=thai}', "");
Expect(1, 3675, '\P{^Is_Sc=thai}', "");
Expect(0, 3676, '\p{Is_Sc=thai}', "");
Expect(1, 3676, '\p{^Is_Sc=thai}', "");
Expect(1, 3676, '\P{Is_Sc=thai}', "");
Expect(0, 3676, '\P{^Is_Sc=thai}', "");
Expect(1, 3675, '\p{Is_Sc= 	Thai}', "");
Expect(0, 3675, '\p{^Is_Sc= 	Thai}', "");
Expect(0, 3675, '\P{Is_Sc= 	Thai}', "");
Expect(1, 3675, '\P{^Is_Sc= 	Thai}', "");
Expect(0, 3676, '\p{Is_Sc= 	Thai}', "");
Expect(1, 3676, '\p{^Is_Sc= 	Thai}', "");
Expect(1, 3676, '\P{Is_Sc= 	Thai}', "");
Expect(0, 3676, '\P{^Is_Sc= 	Thai}', "");
Error('\p{Script=/a/	TIBETAN}');
Error('\P{Script=/a/	TIBETAN}');
Expect(1, 4058, '\p{Script=tibetan}', "");
Expect(0, 4058, '\p{^Script=tibetan}', "");
Expect(0, 4058, '\P{Script=tibetan}', "");
Expect(1, 4058, '\P{^Script=tibetan}', "");
Expect(0, 4059, '\p{Script=tibetan}', "");
Expect(1, 4059, '\p{^Script=tibetan}', "");
Expect(1, 4059, '\P{Script=tibetan}', "");
Expect(0, 4059, '\P{^Script=tibetan}', "");
Expect(1, 4058, '\p{Script=__tibetan}', "");
Expect(0, 4058, '\p{^Script=__tibetan}', "");
Expect(0, 4058, '\P{Script=__tibetan}', "");
Expect(1, 4058, '\P{^Script=__tibetan}', "");
Expect(0, 4059, '\p{Script=__tibetan}', "");
Expect(1, 4059, '\p{^Script=__tibetan}', "");
Expect(1, 4059, '\P{Script=__tibetan}', "");
Expect(0, 4059, '\P{^Script=__tibetan}', "");
Error('\p{Sc=	_TIBT:=}');
Error('\P{Sc=	_TIBT:=}');
Expect(1, 4058, '\p{Sc=tibt}', "");
Expect(0, 4058, '\p{^Sc=tibt}', "");
Expect(0, 4058, '\P{Sc=tibt}', "");
Expect(1, 4058, '\P{^Sc=tibt}', "");
Expect(0, 4059, '\p{Sc=tibt}', "");
Expect(1, 4059, '\p{^Sc=tibt}', "");
Expect(1, 4059, '\P{Sc=tibt}', "");
Expect(0, 4059, '\P{^Sc=tibt}', "");
Expect(1, 4058, '\p{Sc=--Tibt}', "");
Expect(0, 4058, '\p{^Sc=--Tibt}', "");
Expect(0, 4058, '\P{Sc=--Tibt}', "");
Expect(1, 4058, '\P{^Sc=--Tibt}', "");
Expect(0, 4059, '\p{Sc=--Tibt}', "");
Expect(1, 4059, '\p{^Sc=--Tibt}', "");
Expect(1, 4059, '\P{Sc=--Tibt}', "");
Expect(0, 4059, '\P{^Sc=--Tibt}', "");
Error('\p{Is_Script=/a/-TIBETAN}');
Error('\P{Is_Script=/a/-TIBETAN}');
Expect(1, 4058, '\p{Is_Script=tibetan}', "");
Expect(0, 4058, '\p{^Is_Script=tibetan}', "");
Expect(0, 4058, '\P{Is_Script=tibetan}', "");
Expect(1, 4058, '\P{^Is_Script=tibetan}', "");
Expect(0, 4059, '\p{Is_Script=tibetan}', "");
Expect(1, 4059, '\p{^Is_Script=tibetan}', "");
Expect(1, 4059, '\P{Is_Script=tibetan}', "");
Expect(0, 4059, '\P{^Is_Script=tibetan}', "");
Expect(1, 4058, '\p{Is_Script=-_tibetan}', "");
Expect(0, 4058, '\p{^Is_Script=-_tibetan}', "");
Expect(0, 4058, '\P{Is_Script=-_tibetan}', "");
Expect(1, 4058, '\P{^Is_Script=-_tibetan}', "");
Expect(0, 4059, '\p{Is_Script=-_tibetan}', "");
Expect(1, 4059, '\p{^Is_Script=-_tibetan}', "");
Expect(1, 4059, '\P{Is_Script=-_tibetan}', "");
Expect(0, 4059, '\P{^Is_Script=-_tibetan}', "");
Error('\p{Is_Sc=	:=TIBT}');
Error('\P{Is_Sc=	:=TIBT}');
Expect(1, 4058, '\p{Is_Sc=tibt}', "");
Expect(0, 4058, '\p{^Is_Sc=tibt}', "");
Expect(0, 4058, '\P{Is_Sc=tibt}', "");
Expect(1, 4058, '\P{^Is_Sc=tibt}', "");
Expect(0, 4059, '\p{Is_Sc=tibt}', "");
Expect(1, 4059, '\p{^Is_Sc=tibt}', "");
Expect(1, 4059, '\P{Is_Sc=tibt}', "");
Expect(0, 4059, '\P{^Is_Sc=tibt}', "");
Expect(1, 4058, '\p{Is_Sc=_Tibt}', "");
Expect(0, 4058, '\p{^Is_Sc=_Tibt}', "");
Expect(0, 4058, '\P{Is_Sc=_Tibt}', "");
Expect(1, 4058, '\P{^Is_Sc=_Tibt}', "");
Expect(0, 4059, '\p{Is_Sc=_Tibt}', "");
Expect(1, 4059, '\p{^Is_Sc=_Tibt}', "");
Expect(1, 4059, '\P{Is_Sc=_Tibt}', "");
Expect(0, 4059, '\P{^Is_Sc=_Tibt}', "");
Error('\p{Script= Ugaritic/a/}');
Error('\P{Script= Ugaritic/a/}');
Expect(1, 66463, '\p{Script=ugaritic}', "");
Expect(0, 66463, '\p{^Script=ugaritic}', "");
Expect(0, 66463, '\P{Script=ugaritic}', "");
Expect(1, 66463, '\P{^Script=ugaritic}', "");
Expect(0, 66464, '\p{Script=ugaritic}', "");
Expect(1, 66464, '\p{^Script=ugaritic}', "");
Expect(1, 66464, '\P{Script=ugaritic}', "");
Expect(0, 66464, '\P{^Script=ugaritic}', "");
Expect(1, 66463, '\p{Script=	_Ugaritic}', "");
Expect(0, 66463, '\p{^Script=	_Ugaritic}', "");
Expect(0, 66463, '\P{Script=	_Ugaritic}', "");
Expect(1, 66463, '\P{^Script=	_Ugaritic}', "");
Expect(0, 66464, '\p{Script=	_Ugaritic}', "");
Expect(1, 66464, '\p{^Script=	_Ugaritic}', "");
Expect(1, 66464, '\P{Script=	_Ugaritic}', "");
Expect(0, 66464, '\P{^Script=	_Ugaritic}', "");
Error('\p{Sc=-_UGAR:=}');
Error('\P{Sc=-_UGAR:=}');
Expect(1, 66463, '\p{Sc=ugar}', "");
Expect(0, 66463, '\p{^Sc=ugar}', "");
Expect(0, 66463, '\P{Sc=ugar}', "");
Expect(1, 66463, '\P{^Sc=ugar}', "");
Expect(0, 66464, '\p{Sc=ugar}', "");
Expect(1, 66464, '\p{^Sc=ugar}', "");
Expect(1, 66464, '\P{Sc=ugar}', "");
Expect(0, 66464, '\P{^Sc=ugar}', "");
Expect(1, 66463, '\p{Sc=-Ugar}', "");
Expect(0, 66463, '\p{^Sc=-Ugar}', "");
Expect(0, 66463, '\P{Sc=-Ugar}', "");
Expect(1, 66463, '\P{^Sc=-Ugar}', "");
Expect(0, 66464, '\p{Sc=-Ugar}', "");
Expect(1, 66464, '\p{^Sc=-Ugar}', "");
Expect(1, 66464, '\P{Sc=-Ugar}', "");
Expect(0, 66464, '\P{^Sc=-Ugar}', "");
Error('\p{Is_Script=-Ugaritic/a/}');
Error('\P{Is_Script=-Ugaritic/a/}');
Expect(1, 66463, '\p{Is_Script=ugaritic}', "");
Expect(0, 66463, '\p{^Is_Script=ugaritic}', "");
Expect(0, 66463, '\P{Is_Script=ugaritic}', "");
Expect(1, 66463, '\P{^Is_Script=ugaritic}', "");
Expect(0, 66464, '\p{Is_Script=ugaritic}', "");
Expect(1, 66464, '\p{^Is_Script=ugaritic}', "");
Expect(1, 66464, '\P{Is_Script=ugaritic}', "");
Expect(0, 66464, '\P{^Is_Script=ugaritic}', "");
Expect(1, 66463, '\p{Is_Script=  Ugaritic}', "");
Expect(0, 66463, '\p{^Is_Script=  Ugaritic}', "");
Expect(0, 66463, '\P{Is_Script=  Ugaritic}', "");
Expect(1, 66463, '\P{^Is_Script=  Ugaritic}', "");
Expect(0, 66464, '\p{Is_Script=  Ugaritic}', "");
Expect(1, 66464, '\p{^Is_Script=  Ugaritic}', "");
Expect(1, 66464, '\P{Is_Script=  Ugaritic}', "");
Expect(0, 66464, '\P{^Is_Script=  Ugaritic}', "");
Error('\p{Is_Sc=_/a/Ugar}');
Error('\P{Is_Sc=_/a/Ugar}');
Expect(1, 66463, '\p{Is_Sc:ugar}', "");
Expect(0, 66463, '\p{^Is_Sc:ugar}', "");
Expect(0, 66463, '\P{Is_Sc:ugar}', "");
Expect(1, 66463, '\P{^Is_Sc:ugar}', "");
Expect(0, 66464, '\p{Is_Sc:ugar}', "");
Expect(1, 66464, '\p{^Is_Sc:ugar}', "");
Expect(1, 66464, '\P{Is_Sc:ugar}', "");
Expect(0, 66464, '\P{^Is_Sc:ugar}', "");
Expect(1, 66463, '\p{Is_Sc=--Ugar}', "");
Expect(0, 66463, '\p{^Is_Sc=--Ugar}', "");
Expect(0, 66463, '\P{Is_Sc=--Ugar}', "");
Expect(1, 66463, '\P{^Is_Sc=--Ugar}', "");
Expect(0, 66464, '\p{Is_Sc=--Ugar}', "");
Expect(1, 66464, '\p{^Is_Sc=--Ugar}', "");
Expect(1, 66464, '\P{Is_Sc=--Ugar}', "");
Expect(0, 66464, '\P{^Is_Sc=--Ugar}', "");
Error('\p{Script=		vai:=}');
Error('\P{Script=		vai:=}');
Expect(1, 42539, '\p{Script=vai}', "");
Expect(0, 42539, '\p{^Script=vai}', "");
Expect(0, 42539, '\P{Script=vai}', "");
Expect(1, 42539, '\P{^Script=vai}', "");
Expect(0, 42540, '\p{Script=vai}', "");
Expect(1, 42540, '\p{^Script=vai}', "");
Expect(1, 42540, '\P{Script=vai}', "");
Expect(0, 42540, '\P{^Script=vai}', "");
Expect(1, 42539, '\p{Script=-	vai}', "");
Expect(0, 42539, '\p{^Script=-	vai}', "");
Expect(0, 42539, '\P{Script=-	vai}', "");
Expect(1, 42539, '\P{^Script=-	vai}', "");
Expect(0, 42540, '\p{Script=-	vai}', "");
Expect(1, 42540, '\p{^Script=-	vai}', "");
Expect(1, 42540, '\P{Script=-	vai}', "");
Expect(0, 42540, '\P{^Script=-	vai}', "");
Error('\p{Sc=_-Vaii/a/}');
Error('\P{Sc=_-Vaii/a/}');
Expect(1, 42539, '\p{Sc=vaii}', "");
Expect(0, 42539, '\p{^Sc=vaii}', "");
Expect(0, 42539, '\P{Sc=vaii}', "");
Expect(1, 42539, '\P{^Sc=vaii}', "");
Expect(0, 42540, '\p{Sc=vaii}', "");
Expect(1, 42540, '\p{^Sc=vaii}', "");
Expect(1, 42540, '\P{Sc=vaii}', "");
Expect(0, 42540, '\P{^Sc=vaii}', "");
Expect(1, 42539, '\p{Sc=	Vaii}', "");
Expect(0, 42539, '\p{^Sc=	Vaii}', "");
Expect(0, 42539, '\P{Sc=	Vaii}', "");
Expect(1, 42539, '\P{^Sc=	Vaii}', "");
Expect(0, 42540, '\p{Sc=	Vaii}', "");
Expect(1, 42540, '\p{^Sc=	Vaii}', "");
Expect(1, 42540, '\P{Sc=	Vaii}', "");
Expect(0, 42540, '\P{^Sc=	Vaii}', "");
Error('\p{Is_Script= _VAI:=}');
Error('\P{Is_Script= _VAI:=}');
Expect(1, 42539, '\p{Is_Script=vai}', "");
Expect(0, 42539, '\p{^Is_Script=vai}', "");
Expect(0, 42539, '\P{Is_Script=vai}', "");
Expect(1, 42539, '\P{^Is_Script=vai}', "");
Expect(0, 42540, '\p{Is_Script=vai}', "");
Expect(1, 42540, '\p{^Is_Script=vai}', "");
Expect(1, 42540, '\P{Is_Script=vai}', "");
Expect(0, 42540, '\P{^Is_Script=vai}', "");
Expect(1, 42539, '\p{Is_Script:    	Vai}', "");
Expect(0, 42539, '\p{^Is_Script:    	Vai}', "");
Expect(0, 42539, '\P{Is_Script:    	Vai}', "");
Expect(1, 42539, '\P{^Is_Script:    	Vai}', "");
Expect(0, 42540, '\p{Is_Script:    	Vai}', "");
Expect(1, 42540, '\p{^Is_Script:    	Vai}', "");
Expect(1, 42540, '\P{Is_Script:    	Vai}', "");
Expect(0, 42540, '\P{^Is_Script:    	Vai}', "");
Error('\p{Is_Sc=/a/		Vaii}');
Error('\P{Is_Sc=/a/		Vaii}');
Expect(1, 42539, '\p{Is_Sc=vaii}', "");
Expect(0, 42539, '\p{^Is_Sc=vaii}', "");
Expect(0, 42539, '\P{Is_Sc=vaii}', "");
Expect(1, 42539, '\P{^Is_Sc=vaii}', "");
Expect(0, 42540, '\p{Is_Sc=vaii}', "");
Expect(1, 42540, '\p{^Is_Sc=vaii}', "");
Expect(1, 42540, '\P{Is_Sc=vaii}', "");
Expect(0, 42540, '\P{^Is_Sc=vaii}', "");
Expect(1, 42539, '\p{Is_Sc=_Vaii}', "");
Expect(0, 42539, '\p{^Is_Sc=_Vaii}', "");
Expect(0, 42539, '\P{Is_Sc=_Vaii}', "");
Expect(1, 42539, '\P{^Is_Sc=_Vaii}', "");
Expect(0, 42540, '\p{Is_Sc=_Vaii}', "");
Expect(1, 42540, '\p{^Is_Sc=_Vaii}', "");
Expect(1, 42540, '\P{Is_Sc=_Vaii}', "");
Expect(0, 42540, '\P{^Is_Sc=_Vaii}', "");
Error('\p{Script=_:=OLD_Persian}');
Error('\P{Script=_:=OLD_Persian}');
Expect(1, 66517, '\p{Script=oldpersian}', "");
Expect(0, 66517, '\p{^Script=oldpersian}', "");
Expect(0, 66517, '\P{Script=oldpersian}', "");
Expect(1, 66517, '\P{^Script=oldpersian}', "");
Expect(0, 66518, '\p{Script=oldpersian}', "");
Expect(1, 66518, '\p{^Script=oldpersian}', "");
Expect(1, 66518, '\P{Script=oldpersian}', "");
Expect(0, 66518, '\P{^Script=oldpersian}', "");
Expect(1, 66517, '\p{Script=_Old_PERSIAN}', "");
Expect(0, 66517, '\p{^Script=_Old_PERSIAN}', "");
Expect(0, 66517, '\P{Script=_Old_PERSIAN}', "");
Expect(1, 66517, '\P{^Script=_Old_PERSIAN}', "");
Expect(0, 66518, '\p{Script=_Old_PERSIAN}', "");
Expect(1, 66518, '\p{^Script=_Old_PERSIAN}', "");
Expect(1, 66518, '\P{Script=_Old_PERSIAN}', "");
Expect(0, 66518, '\P{^Script=_Old_PERSIAN}', "");
Error('\p{Sc=:=-Xpeo}');
Error('\P{Sc=:=-Xpeo}');
Expect(1, 66517, '\p{Sc=xpeo}', "");
Expect(0, 66517, '\p{^Sc=xpeo}', "");
Expect(0, 66517, '\P{Sc=xpeo}', "");
Expect(1, 66517, '\P{^Sc=xpeo}', "");
Expect(0, 66518, '\p{Sc=xpeo}', "");
Expect(1, 66518, '\p{^Sc=xpeo}', "");
Expect(1, 66518, '\P{Sc=xpeo}', "");
Expect(0, 66518, '\P{^Sc=xpeo}', "");
Expect(1, 66517, '\p{Sc=_	Xpeo}', "");
Expect(0, 66517, '\p{^Sc=_	Xpeo}', "");
Expect(0, 66517, '\P{Sc=_	Xpeo}', "");
Expect(1, 66517, '\P{^Sc=_	Xpeo}', "");
Expect(0, 66518, '\p{Sc=_	Xpeo}', "");
Expect(1, 66518, '\p{^Sc=_	Xpeo}', "");
Expect(1, 66518, '\P{Sc=_	Xpeo}', "");
Expect(0, 66518, '\P{^Sc=_	Xpeo}', "");
Error('\p{Is_Script=:=-Old_Persian}');
Error('\P{Is_Script=:=-Old_Persian}');
Expect(1, 66517, '\p{Is_Script=oldpersian}', "");
Expect(0, 66517, '\p{^Is_Script=oldpersian}', "");
Expect(0, 66517, '\P{Is_Script=oldpersian}', "");
Expect(1, 66517, '\P{^Is_Script=oldpersian}', "");
Expect(0, 66518, '\p{Is_Script=oldpersian}', "");
Expect(1, 66518, '\p{^Is_Script=oldpersian}', "");
Expect(1, 66518, '\P{Is_Script=oldpersian}', "");
Expect(0, 66518, '\P{^Is_Script=oldpersian}', "");
Expect(1, 66517, '\p{Is_Script= 	Old_Persian}', "");
Expect(0, 66517, '\p{^Is_Script= 	Old_Persian}', "");
Expect(0, 66517, '\P{Is_Script= 	Old_Persian}', "");
Expect(1, 66517, '\P{^Is_Script= 	Old_Persian}', "");
Expect(0, 66518, '\p{Is_Script= 	Old_Persian}', "");
Expect(1, 66518, '\p{^Is_Script= 	Old_Persian}', "");
Expect(1, 66518, '\P{Is_Script= 	Old_Persian}', "");
Expect(0, 66518, '\P{^Is_Script= 	Old_Persian}', "");
Error('\p{Is_Sc=_/a/XPEO}');
Error('\P{Is_Sc=_/a/XPEO}');
Expect(1, 66517, '\p{Is_Sc=xpeo}', "");
Expect(0, 66517, '\p{^Is_Sc=xpeo}', "");
Expect(0, 66517, '\P{Is_Sc=xpeo}', "");
Expect(1, 66517, '\P{^Is_Sc=xpeo}', "");
Expect(0, 66518, '\p{Is_Sc=xpeo}', "");
Expect(1, 66518, '\p{^Is_Sc=xpeo}', "");
Expect(1, 66518, '\P{Is_Sc=xpeo}', "");
Expect(0, 66518, '\P{^Is_Sc=xpeo}', "");
Expect(1, 66517, '\p{Is_Sc=-_xpeo}', "");
Expect(0, 66517, '\p{^Is_Sc=-_xpeo}', "");
Expect(0, 66517, '\P{Is_Sc=-_xpeo}', "");
Expect(1, 66517, '\P{^Is_Sc=-_xpeo}', "");
Expect(0, 66518, '\p{Is_Sc=-_xpeo}', "");
Expect(1, 66518, '\p{^Is_Sc=-_xpeo}', "");
Expect(1, 66518, '\P{Is_Sc=-_xpeo}', "");
Expect(0, 66518, '\P{^Is_Sc=-_xpeo}', "");
Error('\p{Script:    /a/cuneiform}');
Error('\P{Script:    /a/cuneiform}');
Expect(1, 74867, '\p{Script=cuneiform}', "");
Expect(0, 74867, '\p{^Script=cuneiform}', "");
Expect(0, 74867, '\P{Script=cuneiform}', "");
Expect(1, 74867, '\P{^Script=cuneiform}', "");
Expect(0, 74868, '\p{Script=cuneiform}', "");
Expect(1, 74868, '\p{^Script=cuneiform}', "");
Expect(1, 74868, '\P{Script=cuneiform}', "");
Expect(0, 74868, '\P{^Script=cuneiform}', "");
Expect(1, 74867, '\p{Script:   -_CUNEIFORM}', "");
Expect(0, 74867, '\p{^Script:   -_CUNEIFORM}', "");
Expect(0, 74867, '\P{Script:   -_CUNEIFORM}', "");
Expect(1, 74867, '\P{^Script:   -_CUNEIFORM}', "");
Expect(0, 74868, '\p{Script:   -_CUNEIFORM}', "");
Expect(1, 74868, '\p{^Script:   -_CUNEIFORM}', "");
Expect(1, 74868, '\P{Script:   -_CUNEIFORM}', "");
Expect(0, 74868, '\P{^Script:   -_CUNEIFORM}', "");
Error('\p{Sc=:=xsux}');
Error('\P{Sc=:=xsux}');
Expect(1, 74867, '\p{Sc=xsux}', "");
Expect(0, 74867, '\p{^Sc=xsux}', "");
Expect(0, 74867, '\P{Sc=xsux}', "");
Expect(1, 74867, '\P{^Sc=xsux}', "");
Expect(0, 74868, '\p{Sc=xsux}', "");
Expect(1, 74868, '\p{^Sc=xsux}', "");
Expect(1, 74868, '\P{Sc=xsux}', "");
Expect(0, 74868, '\P{^Sc=xsux}', "");
Expect(1, 74867, '\p{Sc=- XSUX}', "");
Expect(0, 74867, '\p{^Sc=- XSUX}', "");
Expect(0, 74867, '\P{Sc=- XSUX}', "");
Expect(1, 74867, '\P{^Sc=- XSUX}', "");
Expect(0, 74868, '\p{Sc=- XSUX}', "");
Expect(1, 74868, '\p{^Sc=- XSUX}', "");
Expect(1, 74868, '\P{Sc=- XSUX}', "");
Expect(0, 74868, '\P{^Sc=- XSUX}', "");
Error('\p{Is_Script=:=	-Cuneiform}');
Error('\P{Is_Script=:=	-Cuneiform}');
Expect(1, 74867, '\p{Is_Script=cuneiform}', "");
Expect(0, 74867, '\p{^Is_Script=cuneiform}', "");
Expect(0, 74867, '\P{Is_Script=cuneiform}', "");
Expect(1, 74867, '\P{^Is_Script=cuneiform}', "");
Expect(0, 74868, '\p{Is_Script=cuneiform}', "");
Expect(1, 74868, '\p{^Is_Script=cuneiform}', "");
Expect(1, 74868, '\P{Is_Script=cuneiform}', "");
Expect(0, 74868, '\P{^Is_Script=cuneiform}', "");
Expect(1, 74867, '\p{Is_Script=	 CUNEIFORM}', "");
Expect(0, 74867, '\p{^Is_Script=	 CUNEIFORM}', "");
Expect(0, 74867, '\P{Is_Script=	 CUNEIFORM}', "");
Expect(1, 74867, '\P{^Is_Script=	 CUNEIFORM}', "");
Expect(0, 74868, '\p{Is_Script=	 CUNEIFORM}', "");
Expect(1, 74868, '\p{^Is_Script=	 CUNEIFORM}', "");
Expect(1, 74868, '\P{Is_Script=	 CUNEIFORM}', "");
Expect(0, 74868, '\P{^Is_Script=	 CUNEIFORM}', "");
Error('\p{Is_Sc=	/a/Xsux}');
Error('\P{Is_Sc=	/a/Xsux}');
Expect(1, 74867, '\p{Is_Sc=xsux}', "");
Expect(0, 74867, '\p{^Is_Sc=xsux}', "");
Expect(0, 74867, '\P{Is_Sc=xsux}', "");
Expect(1, 74867, '\P{^Is_Sc=xsux}', "");
Expect(0, 74868, '\p{Is_Sc=xsux}', "");
Expect(1, 74868, '\p{^Is_Sc=xsux}', "");
Expect(1, 74868, '\P{Is_Sc=xsux}', "");
Expect(0, 74868, '\P{^Is_Sc=xsux}', "");
Expect(1, 74867, '\p{Is_Sc=		Xsux}', "");
Expect(0, 74867, '\p{^Is_Sc=		Xsux}', "");
Expect(0, 74867, '\P{Is_Sc=		Xsux}', "");
Expect(1, 74867, '\P{^Is_Sc=		Xsux}', "");
Expect(0, 74868, '\p{Is_Sc=		Xsux}', "");
Expect(1, 74868, '\p{^Is_Sc=		Xsux}', "");
Expect(1, 74868, '\P{Is_Sc=		Xsux}', "");
Expect(0, 74868, '\P{^Is_Sc=		Xsux}', "");
Error('\p{Script:    	Yi/a/}');
Error('\P{Script:    	Yi/a/}');
Expect(1, 42182, '\p{Script=yi}', "");
Expect(0, 42182, '\p{^Script=yi}', "");
Expect(0, 42182, '\P{Script=yi}', "");
Expect(1, 42182, '\P{^Script=yi}', "");
Expect(0, 42183, '\p{Script=yi}', "");
Expect(1, 42183, '\p{^Script=yi}', "");
Expect(1, 42183, '\P{Script=yi}', "");
Expect(0, 42183, '\P{^Script=yi}', "");
Expect(1, 42182, '\p{Script=-Yi}', "");
Expect(0, 42182, '\p{^Script=-Yi}', "");
Expect(0, 42182, '\P{Script=-Yi}', "");
Expect(1, 42182, '\P{^Script=-Yi}', "");
Expect(0, 42183, '\p{Script=-Yi}', "");
Expect(1, 42183, '\p{^Script=-Yi}', "");
Expect(1, 42183, '\P{Script=-Yi}', "");
Expect(0, 42183, '\P{^Script=-Yi}', "");
Error('\p{Sc=_Yiii/a/}');
Error('\P{Sc=_Yiii/a/}');
Expect(1, 42182, '\p{Sc=yiii}', "");
Expect(0, 42182, '\p{^Sc=yiii}', "");
Expect(0, 42182, '\P{Sc=yiii}', "");
Expect(1, 42182, '\P{^Sc=yiii}', "");
Expect(0, 42183, '\p{Sc=yiii}', "");
Expect(1, 42183, '\p{^Sc=yiii}', "");
Expect(1, 42183, '\P{Sc=yiii}', "");
Expect(0, 42183, '\P{^Sc=yiii}', "");
Expect(1, 42182, '\p{Sc=  Yiii}', "");
Expect(0, 42182, '\p{^Sc=  Yiii}', "");
Expect(0, 42182, '\P{Sc=  Yiii}', "");
Expect(1, 42182, '\P{^Sc=  Yiii}', "");
Expect(0, 42183, '\p{Sc=  Yiii}', "");
Expect(1, 42183, '\p{^Sc=  Yiii}', "");
Expect(1, 42183, '\P{Sc=  Yiii}', "");
Expect(0, 42183, '\P{^Sc=  Yiii}', "");
Error('\p{Is_Script=  yi:=}');
Error('\P{Is_Script=  yi:=}');
Expect(1, 42182, '\p{Is_Script=yi}', "");
Expect(0, 42182, '\p{^Is_Script=yi}', "");
Expect(0, 42182, '\P{Is_Script=yi}', "");
Expect(1, 42182, '\P{^Is_Script=yi}', "");
Expect(0, 42183, '\p{Is_Script=yi}', "");
Expect(1, 42183, '\p{^Is_Script=yi}', "");
Expect(1, 42183, '\P{Is_Script=yi}', "");
Expect(0, 42183, '\P{^Is_Script=yi}', "");
Expect(1, 42182, '\p{Is_Script=	Yi}', "");
Expect(0, 42182, '\p{^Is_Script=	Yi}', "");
Expect(0, 42182, '\P{Is_Script=	Yi}', "");
Expect(1, 42182, '\P{^Is_Script=	Yi}', "");
Expect(0, 42183, '\p{Is_Script=	Yi}', "");
Expect(1, 42183, '\p{^Is_Script=	Yi}', "");
Expect(1, 42183, '\P{Is_Script=	Yi}', "");
Expect(0, 42183, '\P{^Is_Script=	Yi}', "");
Error('\p{Is_Sc=-:=yiii}');
Error('\P{Is_Sc=-:=yiii}');
Expect(1, 42182, '\p{Is_Sc=yiii}', "");
Expect(0, 42182, '\p{^Is_Sc=yiii}', "");
Expect(0, 42182, '\P{Is_Sc=yiii}', "");
Expect(1, 42182, '\P{^Is_Sc=yiii}', "");
Expect(0, 42183, '\p{Is_Sc=yiii}', "");
Expect(1, 42183, '\p{^Is_Sc=yiii}', "");
Expect(1, 42183, '\P{Is_Sc=yiii}', "");
Expect(0, 42183, '\P{^Is_Sc=yiii}', "");
Expect(1, 42182, '\p{Is_Sc= yiii}', "");
Expect(0, 42182, '\p{^Is_Sc= yiii}', "");
Expect(0, 42182, '\P{Is_Sc= yiii}', "");
Expect(1, 42182, '\P{^Is_Sc= yiii}', "");
Expect(0, 42183, '\p{Is_Sc= yiii}', "");
Expect(1, 42183, '\p{^Is_Sc= yiii}', "");
Expect(1, 42183, '\P{Is_Sc= yiii}', "");
Expect(0, 42183, '\P{^Is_Sc= yiii}', "");
Error('\p{Script=	-inherited/a/}');
Error('\P{Script=	-inherited/a/}');
Expect(1, 917999, '\p{Script:   inherited}', "");
Expect(0, 917999, '\p{^Script:   inherited}', "");
Expect(0, 917999, '\P{Script:   inherited}', "");
Expect(1, 917999, '\P{^Script:   inherited}', "");
Expect(0, 918000, '\p{Script:   inherited}', "");
Expect(1, 918000, '\p{^Script:   inherited}', "");
Expect(1, 918000, '\P{Script:   inherited}', "");
Expect(0, 918000, '\P{^Script:   inherited}', "");
Expect(1, 917999, '\p{Script=-inherited}', "");
Expect(0, 917999, '\p{^Script=-inherited}', "");
Expect(0, 917999, '\P{Script=-inherited}', "");
Expect(1, 917999, '\P{^Script=-inherited}', "");
Expect(0, 918000, '\p{Script=-inherited}', "");
Expect(1, 918000, '\p{^Script=-inherited}', "");
Expect(1, 918000, '\P{Script=-inherited}', "");
Expect(0, 918000, '\P{^Script=-inherited}', "");
Error('\p{Sc=/a/	Zinh}');
Error('\P{Sc=/a/	Zinh}');
Expect(1, 917999, '\p{Sc=zinh}', "");
Expect(0, 917999, '\p{^Sc=zinh}', "");
Expect(0, 917999, '\P{Sc=zinh}', "");
Expect(1, 917999, '\P{^Sc=zinh}', "");
Expect(0, 918000, '\p{Sc=zinh}', "");
Expect(1, 918000, '\p{^Sc=zinh}', "");
Expect(1, 918000, '\P{Sc=zinh}', "");
Expect(0, 918000, '\P{^Sc=zinh}', "");
Expect(1, 917999, '\p{Sc= -Zinh}', "");
Expect(0, 917999, '\p{^Sc= -Zinh}', "");
Expect(0, 917999, '\P{Sc= -Zinh}', "");
Expect(1, 917999, '\P{^Sc= -Zinh}', "");
Expect(0, 918000, '\p{Sc= -Zinh}', "");
Expect(1, 918000, '\p{^Sc= -Zinh}', "");
Expect(1, 918000, '\P{Sc= -Zinh}', "");
Expect(0, 918000, '\P{^Sc= -Zinh}', "");
Error('\p{Is_Script=_/a/QAAI}');
Error('\P{Is_Script=_/a/QAAI}');
Expect(1, 917999, '\p{Is_Script=qaai}', "");
Expect(0, 917999, '\p{^Is_Script=qaai}', "");
Expect(0, 917999, '\P{Is_Script=qaai}', "");
Expect(1, 917999, '\P{^Is_Script=qaai}', "");
Expect(0, 918000, '\p{Is_Script=qaai}', "");
Expect(1, 918000, '\p{^Is_Script=qaai}', "");
Expect(1, 918000, '\P{Is_Script=qaai}', "");
Expect(0, 918000, '\P{^Is_Script=qaai}', "");
Expect(1, 917999, '\p{Is_Script=  qaai}', "");
Expect(0, 917999, '\p{^Is_Script=  qaai}', "");
Expect(0, 917999, '\P{Is_Script=  qaai}', "");
Expect(1, 917999, '\P{^Is_Script=  qaai}', "");
Expect(0, 918000, '\p{Is_Script=  qaai}', "");
Expect(1, 918000, '\p{^Is_Script=  qaai}', "");
Expect(1, 918000, '\P{Is_Script=  qaai}', "");
Expect(0, 918000, '\P{^Is_Script=  qaai}', "");
Error('\p{Is_Sc:    -INHERITED:=}');
Error('\P{Is_Sc:    -INHERITED:=}');
Expect(1, 917999, '\p{Is_Sc=inherited}', "");
Expect(0, 917999, '\p{^Is_Sc=inherited}', "");
Expect(0, 917999, '\P{Is_Sc=inherited}', "");
Expect(1, 917999, '\P{^Is_Sc=inherited}', "");
Expect(0, 918000, '\p{Is_Sc=inherited}', "");
Expect(1, 918000, '\p{^Is_Sc=inherited}', "");
Expect(1, 918000, '\P{Is_Sc=inherited}', "");
Expect(0, 918000, '\P{^Is_Sc=inherited}', "");
Expect(1, 917999, '\p{Is_Sc=_-Inherited}', "");
Expect(0, 917999, '\p{^Is_Sc=_-Inherited}', "");
Expect(0, 917999, '\P{Is_Sc=_-Inherited}', "");
Expect(1, 917999, '\P{^Is_Sc=_-Inherited}', "");
Expect(0, 918000, '\p{Is_Sc=_-Inherited}', "");
Expect(1, 918000, '\p{^Is_Sc=_-Inherited}', "");
Expect(1, 918000, '\P{Is_Sc=_-Inherited}', "");
Expect(0, 918000, '\P{^Is_Sc=_-Inherited}', "");
Error('\p{Script=/a/ -COMMON}');
Error('\P{Script=/a/ -COMMON}');
Expect(1, 917631, '\p{Script=common}', "");
Expect(0, 917631, '\p{^Script=common}', "");
Expect(0, 917631, '\P{Script=common}', "");
Expect(1, 917631, '\P{^Script=common}', "");
Expect(0, 917632, '\p{Script=common}', "");
Expect(1, 917632, '\p{^Script=common}', "");
Expect(1, 917632, '\P{Script=common}', "");
Expect(0, 917632, '\P{^Script=common}', "");
Expect(1, 917631, '\p{Script:    	common}', "");
Expect(0, 917631, '\p{^Script:    	common}', "");
Expect(0, 917631, '\P{Script:    	common}', "");
Expect(1, 917631, '\P{^Script:    	common}', "");
Expect(0, 917632, '\p{Script:    	common}', "");
Expect(1, 917632, '\p{^Script:    	common}', "");
Expect(1, 917632, '\P{Script:    	common}', "");
Expect(0, 917632, '\P{^Script:    	common}', "");
Error('\p{Sc=_ Zyyy:=}');
Error('\P{Sc=_ Zyyy:=}');
Expect(1, 917631, '\p{Sc=zyyy}', "");
Expect(0, 917631, '\p{^Sc=zyyy}', "");
Expect(0, 917631, '\P{Sc=zyyy}', "");
Expect(1, 917631, '\P{^Sc=zyyy}', "");
Expect(0, 917632, '\p{Sc=zyyy}', "");
Expect(1, 917632, '\p{^Sc=zyyy}', "");
Expect(1, 917632, '\P{Sc=zyyy}', "");
Expect(0, 917632, '\P{^Sc=zyyy}', "");
Expect(1, 917631, '\p{Sc= _zyyy}', "");
Expect(0, 917631, '\p{^Sc= _zyyy}', "");
Expect(0, 917631, '\P{Sc= _zyyy}', "");
Expect(1, 917631, '\P{^Sc= _zyyy}', "");
Expect(0, 917632, '\p{Sc= _zyyy}', "");
Expect(1, 917632, '\p{^Sc= _zyyy}', "");
Expect(1, 917632, '\P{Sc= _zyyy}', "");
Expect(0, 917632, '\P{^Sc= _zyyy}', "");
Error('\p{Is_Script=	COMMON/a/}');
Error('\P{Is_Script=	COMMON/a/}');
Expect(1, 917631, '\p{Is_Script=common}', "");
Expect(0, 917631, '\p{^Is_Script=common}', "");
Expect(0, 917631, '\P{Is_Script=common}', "");
Expect(1, 917631, '\P{^Is_Script=common}', "");
Expect(0, 917632, '\p{Is_Script=common}', "");
Expect(1, 917632, '\p{^Is_Script=common}', "");
Expect(1, 917632, '\P{Is_Script=common}', "");
Expect(0, 917632, '\P{^Is_Script=common}', "");
Expect(1, 917631, '\p{Is_Script=_-COMMON}', "");
Expect(0, 917631, '\p{^Is_Script=_-COMMON}', "");
Expect(0, 917631, '\P{Is_Script=_-COMMON}', "");
Expect(1, 917631, '\P{^Is_Script=_-COMMON}', "");
Expect(0, 917632, '\p{Is_Script=_-COMMON}', "");
Expect(1, 917632, '\p{^Is_Script=_-COMMON}', "");
Expect(1, 917632, '\P{Is_Script=_-COMMON}', "");
Expect(0, 917632, '\P{^Is_Script=_-COMMON}', "");
Error('\p{Is_Sc= 	Zyyy/a/}');
Error('\P{Is_Sc= 	Zyyy/a/}');
Expect(1, 917631, '\p{Is_Sc=zyyy}', "");
Expect(0, 917631, '\p{^Is_Sc=zyyy}', "");
Expect(0, 917631, '\P{Is_Sc=zyyy}', "");
Expect(1, 917631, '\P{^Is_Sc=zyyy}', "");
Expect(0, 917632, '\p{Is_Sc=zyyy}', "");
Expect(1, 917632, '\p{^Is_Sc=zyyy}', "");
Expect(1, 917632, '\P{Is_Sc=zyyy}', "");
Expect(0, 917632, '\P{^Is_Sc=zyyy}', "");
Expect(1, 917631, '\p{Is_Sc:		Zyyy}', "");
Expect(0, 917631, '\p{^Is_Sc:		Zyyy}', "");
Expect(0, 917631, '\P{Is_Sc:		Zyyy}', "");
Expect(1, 917631, '\P{^Is_Sc:		Zyyy}', "");
Expect(0, 917632, '\p{Is_Sc:		Zyyy}', "");
Expect(1, 917632, '\p{^Is_Sc:		Zyyy}', "");
Expect(1, 917632, '\P{Is_Sc:		Zyyy}', "");
Expect(0, 917632, '\P{^Is_Sc:		Zyyy}', "");
Error('\p{Script= _Unknown:=}');
Error('\P{Script= _Unknown:=}');
Expect(1, 918000, '\p{Script=unknown}', "");
Expect(0, 918000, '\p{^Script=unknown}', "");
Expect(0, 918000, '\P{Script=unknown}', "");
Expect(1, 918000, '\P{^Script=unknown}', "");
Expect(0, 917999, '\p{Script=unknown}', "");
Expect(1, 917999, '\p{^Script=unknown}', "");
Expect(1, 917999, '\P{Script=unknown}', "");
Expect(0, 917999, '\P{^Script=unknown}', "");
Expect(1, 918000, '\p{Script= unknown}', "");
Expect(0, 918000, '\p{^Script= unknown}', "");
Expect(0, 918000, '\P{Script= unknown}', "");
Expect(1, 918000, '\P{^Script= unknown}', "");
Expect(0, 917999, '\p{Script= unknown}', "");
Expect(1, 917999, '\p{^Script= unknown}', "");
Expect(1, 917999, '\P{Script= unknown}', "");
Expect(0, 917999, '\P{^Script= unknown}', "");
Error('\p{Sc=	/a/Zzzz}');
Error('\P{Sc=	/a/Zzzz}');
Expect(1, 918000, '\p{Sc=zzzz}', "");
Expect(0, 918000, '\p{^Sc=zzzz}', "");
Expect(0, 918000, '\P{Sc=zzzz}', "");
Expect(1, 918000, '\P{^Sc=zzzz}', "");
Expect(0, 917999, '\p{Sc=zzzz}', "");
Expect(1, 917999, '\p{^Sc=zzzz}', "");
Expect(1, 917999, '\P{Sc=zzzz}', "");
Expect(0, 917999, '\P{^Sc=zzzz}', "");
Expect(1, 918000, '\p{Sc=_-Zzzz}', "");
Expect(0, 918000, '\p{^Sc=_-Zzzz}', "");
Expect(0, 918000, '\P{Sc=_-Zzzz}', "");
Expect(1, 918000, '\P{^Sc=_-Zzzz}', "");
Expect(0, 917999, '\p{Sc=_-Zzzz}', "");
Expect(1, 917999, '\p{^Sc=_-Zzzz}', "");
Expect(1, 917999, '\P{Sc=_-Zzzz}', "");
Expect(0, 917999, '\P{^Sc=_-Zzzz}', "");
Error('\p{Is_Script=-/a/Unknown}');
Error('\P{Is_Script=-/a/Unknown}');
Expect(1, 918000, '\p{Is_Script=unknown}', "");
Expect(0, 918000, '\p{^Is_Script=unknown}', "");
Expect(0, 918000, '\P{Is_Script=unknown}', "");
Expect(1, 918000, '\P{^Is_Script=unknown}', "");
Expect(0, 917999, '\p{Is_Script=unknown}', "");
Expect(1, 917999, '\p{^Is_Script=unknown}', "");
Expect(1, 917999, '\P{Is_Script=unknown}', "");
Expect(0, 917999, '\P{^Is_Script=unknown}', "");
Expect(1, 918000, '\p{Is_Script=-_Unknown}', "");
Expect(0, 918000, '\p{^Is_Script=-_Unknown}', "");
Expect(0, 918000, '\P{Is_Script=-_Unknown}', "");
Expect(1, 918000, '\P{^Is_Script=-_Unknown}', "");
Expect(0, 917999, '\p{Is_Script=-_Unknown}', "");
Expect(1, 917999, '\p{^Is_Script=-_Unknown}', "");
Expect(1, 917999, '\P{Is_Script=-_Unknown}', "");
Expect(0, 917999, '\P{^Is_Script=-_Unknown}', "");
Error('\p{Is_Sc=	Zzzz:=}');
Error('\P{Is_Sc=	Zzzz:=}');
Expect(1, 918000, '\p{Is_Sc=zzzz}', "");
Expect(0, 918000, '\p{^Is_Sc=zzzz}', "");
Expect(0, 918000, '\P{Is_Sc=zzzz}', "");
Expect(1, 918000, '\P{^Is_Sc=zzzz}', "");
Expect(0, 917999, '\p{Is_Sc=zzzz}', "");
Expect(1, 917999, '\p{^Is_Sc=zzzz}', "");
Expect(1, 917999, '\P{Is_Sc=zzzz}', "");
Expect(0, 917999, '\P{^Is_Sc=zzzz}', "");
Expect(1, 918000, '\p{Is_Sc=-_zzzz}', "");
Expect(0, 918000, '\p{^Is_Sc=-_zzzz}', "");
Expect(0, 918000, '\P{Is_Sc=-_zzzz}', "");
Expect(1, 918000, '\P{^Is_Sc=-_zzzz}', "");
Expect(0, 917999, '\p{Is_Sc=-_zzzz}', "");
Expect(1, 917999, '\p{^Is_Sc=-_zzzz}', "");
Expect(1, 917999, '\P{Is_Sc=-_zzzz}', "");
Expect(0, 917999, '\P{^Is_Sc=-_zzzz}', "");
Error('\p{Script_Extensions:   	:=Arabic}');
Error('\P{Script_Extensions:   	:=Arabic}');
Expect(1, 126705, '\p{Script_Extensions=arabic}', "");
Expect(0, 126705, '\p{^Script_Extensions=arabic}', "");
Expect(0, 126705, '\P{Script_Extensions=arabic}', "");
Expect(1, 126705, '\P{^Script_Extensions=arabic}', "");
Expect(0, 126706, '\p{Script_Extensions=arabic}', "");
Expect(1, 126706, '\p{^Script_Extensions=arabic}', "");
Expect(1, 126706, '\P{Script_Extensions=arabic}', "");
Expect(0, 126706, '\P{^Script_Extensions=arabic}', "");
Expect(1, 126705, '\p{Script_Extensions=	-Arabic}', "");
Expect(0, 126705, '\p{^Script_Extensions=	-Arabic}', "");
Expect(0, 126705, '\P{Script_Extensions=	-Arabic}', "");
Expect(1, 126705, '\P{^Script_Extensions=	-Arabic}', "");
Expect(0, 126706, '\p{Script_Extensions=	-Arabic}', "");
Expect(1, 126706, '\p{^Script_Extensions=	-Arabic}', "");
Expect(1, 126706, '\P{Script_Extensions=	-Arabic}', "");
Expect(0, 126706, '\P{^Script_Extensions=	-Arabic}', "");
Error('\p{Scx:	_ Arab:=}');
Error('\P{Scx:	_ Arab:=}');
Expect(1, 126705, '\p{Scx=arab}', "");
Expect(0, 126705, '\p{^Scx=arab}', "");
Expect(0, 126705, '\P{Scx=arab}', "");
Expect(1, 126705, '\P{^Scx=arab}', "");
Expect(0, 126706, '\p{Scx=arab}', "");
Expect(1, 126706, '\p{^Scx=arab}', "");
Expect(1, 126706, '\P{Scx=arab}', "");
Expect(0, 126706, '\P{^Scx=arab}', "");
Expect(1, 126705, '\p{Scx:   -	Arab}', "");
Expect(0, 126705, '\p{^Scx:   -	Arab}', "");
Expect(0, 126705, '\P{Scx:   -	Arab}', "");
Expect(1, 126705, '\P{^Scx:   -	Arab}', "");
Expect(0, 126706, '\p{Scx:   -	Arab}', "");
Expect(1, 126706, '\p{^Scx:   -	Arab}', "");
Expect(1, 126706, '\P{Scx:   -	Arab}', "");
Expect(0, 126706, '\P{^Scx:   -	Arab}', "");
Error('\p{Is_Script_Extensions=:=-_Arabic}');
Error('\P{Is_Script_Extensions=:=-_Arabic}');
Expect(1, 126705, '\p{Is_Script_Extensions=arabic}', "");
Expect(0, 126705, '\p{^Is_Script_Extensions=arabic}', "");
Expect(0, 126705, '\P{Is_Script_Extensions=arabic}', "");
Expect(1, 126705, '\P{^Is_Script_Extensions=arabic}', "");
Expect(0, 126706, '\p{Is_Script_Extensions=arabic}', "");
Expect(1, 126706, '\p{^Is_Script_Extensions=arabic}', "");
Expect(1, 126706, '\P{Is_Script_Extensions=arabic}', "");
Expect(0, 126706, '\P{^Is_Script_Extensions=arabic}', "");
Expect(1, 126705, '\p{Is_Script_Extensions:   	 Arabic}', "");
Expect(0, 126705, '\p{^Is_Script_Extensions:   	 Arabic}', "");
Expect(0, 126705, '\P{Is_Script_Extensions:   	 Arabic}', "");
Expect(1, 126705, '\P{^Is_Script_Extensions:   	 Arabic}', "");
Expect(0, 126706, '\p{Is_Script_Extensions:   	 Arabic}', "");
Expect(1, 126706, '\p{^Is_Script_Extensions:   	 Arabic}', "");
Expect(1, 126706, '\P{Is_Script_Extensions:   	 Arabic}', "");
Expect(0, 126706, '\P{^Is_Script_Extensions:   	 Arabic}', "");
Error('\p{Is_Scx=/a/-arab}');
Error('\P{Is_Scx=/a/-arab}');
Expect(1, 126705, '\p{Is_Scx=arab}', "");
Expect(0, 126705, '\p{^Is_Scx=arab}', "");
Expect(0, 126705, '\P{Is_Scx=arab}', "");
Expect(1, 126705, '\P{^Is_Scx=arab}', "");
Expect(0, 126706, '\p{Is_Scx=arab}', "");
Expect(1, 126706, '\p{^Is_Scx=arab}', "");
Expect(1, 126706, '\P{Is_Scx=arab}', "");
Expect(0, 126706, '\P{^Is_Scx=arab}', "");
Expect(1, 126705, '\p{Is_Scx=-_Arab}', "");
Expect(0, 126705, '\p{^Is_Scx=-_Arab}', "");
Expect(0, 126705, '\P{Is_Scx=-_Arab}', "");
Expect(1, 126705, '\P{^Is_Scx=-_Arab}', "");
Expect(0, 126706, '\p{Is_Scx=-_Arab}', "");
Expect(1, 126706, '\p{^Is_Scx=-_Arab}', "");
Expect(1, 126706, '\P{Is_Scx=-_Arab}', "");
Expect(0, 126706, '\P{^Is_Scx=-_Arab}', "");
Error('\p{Script_Extensions=-	imperial_Aramaic/a/}');
Error('\P{Script_Extensions=-	imperial_Aramaic/a/}');
Expect(1, 67679, '\p{Script_Extensions=imperialaramaic}', "");
Expect(0, 67679, '\p{^Script_Extensions=imperialaramaic}', "");
Expect(0, 67679, '\P{Script_Extensions=imperialaramaic}', "");
Expect(1, 67679, '\P{^Script_Extensions=imperialaramaic}', "");
Expect(0, 67680, '\p{Script_Extensions=imperialaramaic}', "");
Expect(1, 67680, '\p{^Script_Extensions=imperialaramaic}', "");
Expect(1, 67680, '\P{Script_Extensions=imperialaramaic}', "");
Expect(0, 67680, '\P{^Script_Extensions=imperialaramaic}', "");
Expect(1, 67679, '\p{Script_Extensions=	_imperial_aramaic}', "");
Expect(0, 67679, '\p{^Script_Extensions=	_imperial_aramaic}', "");
Expect(0, 67679, '\P{Script_Extensions=	_imperial_aramaic}', "");
Expect(1, 67679, '\P{^Script_Extensions=	_imperial_aramaic}', "");
Expect(0, 67680, '\p{Script_Extensions=	_imperial_aramaic}', "");
Expect(1, 67680, '\p{^Script_Extensions=	_imperial_aramaic}', "");
Expect(1, 67680, '\P{Script_Extensions=	_imperial_aramaic}', "");
Expect(0, 67680, '\P{^Script_Extensions=	_imperial_aramaic}', "");
Error('\p{Scx=:=-_armi}');
Error('\P{Scx=:=-_armi}');
Expect(1, 67679, '\p{Scx=armi}', "");
Expect(0, 67679, '\p{^Scx=armi}', "");
Expect(0, 67679, '\P{Scx=armi}', "");
Expect(1, 67679, '\P{^Scx=armi}', "");
Expect(0, 67680, '\p{Scx=armi}', "");
Expect(1, 67680, '\p{^Scx=armi}', "");
Expect(1, 67680, '\P{Scx=armi}', "");
Expect(0, 67680, '\P{^Scx=armi}', "");
Expect(1, 67679, '\p{Scx=-Armi}', "");
Expect(0, 67679, '\p{^Scx=-Armi}', "");
Expect(0, 67679, '\P{Scx=-Armi}', "");
Expect(1, 67679, '\P{^Scx=-Armi}', "");
Expect(0, 67680, '\p{Scx=-Armi}', "");
Expect(1, 67680, '\p{^Scx=-Armi}', "");
Expect(1, 67680, '\P{Scx=-Armi}', "");
Expect(0, 67680, '\P{^Scx=-Armi}', "");
Error('\p{Is_Script_Extensions=:=_Imperial_Aramaic}');
Error('\P{Is_Script_Extensions=:=_Imperial_Aramaic}');
Expect(1, 67679, '\p{Is_Script_Extensions=imperialaramaic}', "");
Expect(0, 67679, '\p{^Is_Script_Extensions=imperialaramaic}', "");
Expect(0, 67679, '\P{Is_Script_Extensions=imperialaramaic}', "");
Expect(1, 67679, '\P{^Is_Script_Extensions=imperialaramaic}', "");
Expect(0, 67680, '\p{Is_Script_Extensions=imperialaramaic}', "");
Expect(1, 67680, '\p{^Is_Script_Extensions=imperialaramaic}', "");
Expect(1, 67680, '\P{Is_Script_Extensions=imperialaramaic}', "");
Expect(0, 67680, '\P{^Is_Script_Extensions=imperialaramaic}', "");
Expect(1, 67679, '\p{Is_Script_Extensions= -Imperial_Aramaic}', "");
Expect(0, 67679, '\p{^Is_Script_Extensions= -Imperial_Aramaic}', "");
Expect(0, 67679, '\P{Is_Script_Extensions= -Imperial_Aramaic}', "");
Expect(1, 67679, '\P{^Is_Script_Extensions= -Imperial_Aramaic}', "");
Expect(0, 67680, '\p{Is_Script_Extensions= -Imperial_Aramaic}', "");
Expect(1, 67680, '\p{^Is_Script_Extensions= -Imperial_Aramaic}', "");
Expect(1, 67680, '\P{Is_Script_Extensions= -Imperial_Aramaic}', "");
Expect(0, 67680, '\P{^Is_Script_Extensions= -Imperial_Aramaic}', "");
Error('\p{Is_Scx=/a/-Armi}');
Error('\P{Is_Scx=/a/-Armi}');
Expect(1, 67679, '\p{Is_Scx=armi}', "");
Expect(0, 67679, '\p{^Is_Scx=armi}', "");
Expect(0, 67679, '\P{Is_Scx=armi}', "");
Expect(1, 67679, '\P{^Is_Scx=armi}', "");
Expect(0, 67680, '\p{Is_Scx=armi}', "");
Expect(1, 67680, '\p{^Is_Scx=armi}', "");
Expect(1, 67680, '\P{Is_Scx=armi}', "");
Expect(0, 67680, '\P{^Is_Scx=armi}', "");
Expect(1, 67679, '\p{Is_Scx= armi}', "");
Expect(0, 67679, '\p{^Is_Scx= armi}', "");
Expect(0, 67679, '\P{Is_Scx= armi}', "");
Expect(1, 67679, '\P{^Is_Scx= armi}', "");
Expect(0, 67680, '\p{Is_Scx= armi}', "");
Expect(1, 67680, '\p{^Is_Scx= armi}', "");
Expect(1, 67680, '\P{Is_Scx= armi}', "");
Expect(0, 67680, '\P{^Is_Scx= armi}', "");
Error('\p{Script_Extensions=/a/-Armenian}');
Error('\P{Script_Extensions=/a/-Armenian}');
Expect(1, 64279, '\p{Script_Extensions=armenian}', "");
Expect(0, 64279, '\p{^Script_Extensions=armenian}', "");
Expect(0, 64279, '\P{Script_Extensions=armenian}', "");
Expect(1, 64279, '\P{^Script_Extensions=armenian}', "");
Expect(0, 64280, '\p{Script_Extensions=armenian}', "");
Expect(1, 64280, '\p{^Script_Extensions=armenian}', "");
Expect(1, 64280, '\P{Script_Extensions=armenian}', "");
Expect(0, 64280, '\P{^Script_Extensions=armenian}', "");
Expect(1, 64279, '\p{Script_Extensions=	armenian}', "");
Expect(0, 64279, '\p{^Script_Extensions=	armenian}', "");
Expect(0, 64279, '\P{Script_Extensions=	armenian}', "");
Expect(1, 64279, '\P{^Script_Extensions=	armenian}', "");
Expect(0, 64280, '\p{Script_Extensions=	armenian}', "");
Expect(1, 64280, '\p{^Script_Extensions=	armenian}', "");
Expect(1, 64280, '\P{Script_Extensions=	armenian}', "");
Expect(0, 64280, '\P{^Script_Extensions=	armenian}', "");
Error('\p{Scx=/a/Armn}');
Error('\P{Scx=/a/Armn}');
Expect(1, 64279, '\p{Scx=armn}', "");
Expect(0, 64279, '\p{^Scx=armn}', "");
Expect(0, 64279, '\P{Scx=armn}', "");
Expect(1, 64279, '\P{^Scx=armn}', "");
Expect(0, 64280, '\p{Scx=armn}', "");
Expect(1, 64280, '\p{^Scx=armn}', "");
Expect(1, 64280, '\P{Scx=armn}', "");
Expect(0, 64280, '\P{^Scx=armn}', "");
Expect(1, 64279, '\p{Scx=-Armn}', "");
Expect(0, 64279, '\p{^Scx=-Armn}', "");
Expect(0, 64279, '\P{Scx=-Armn}', "");
Expect(1, 64279, '\P{^Scx=-Armn}', "");
Expect(0, 64280, '\p{Scx=-Armn}', "");
Expect(1, 64280, '\p{^Scx=-Armn}', "");
Expect(1, 64280, '\P{Scx=-Armn}', "");
Expect(0, 64280, '\P{^Scx=-Armn}', "");
Error('\p{Is_Script_Extensions=	/a/armenian}');
Error('\P{Is_Script_Extensions=	/a/armenian}');
Expect(1, 64279, '\p{Is_Script_Extensions:armenian}', "");
Expect(0, 64279, '\p{^Is_Script_Extensions:armenian}', "");
Expect(0, 64279, '\P{Is_Script_Extensions:armenian}', "");
Expect(1, 64279, '\P{^Is_Script_Extensions:armenian}', "");
Expect(0, 64280, '\p{Is_Script_Extensions:armenian}', "");
Expect(1, 64280, '\p{^Is_Script_Extensions:armenian}', "");
Expect(1, 64280, '\P{Is_Script_Extensions:armenian}', "");
Expect(0, 64280, '\P{^Is_Script_Extensions:armenian}', "");
Expect(1, 64279, '\p{Is_Script_Extensions=_	ARMENIAN}', "");
Expect(0, 64279, '\p{^Is_Script_Extensions=_	ARMENIAN}', "");
Expect(0, 64279, '\P{Is_Script_Extensions=_	ARMENIAN}', "");
Expect(1, 64279, '\P{^Is_Script_Extensions=_	ARMENIAN}', "");
Expect(0, 64280, '\p{Is_Script_Extensions=_	ARMENIAN}', "");
Expect(1, 64280, '\p{^Is_Script_Extensions=_	ARMENIAN}', "");
Expect(1, 64280, '\P{Is_Script_Extensions=_	ARMENIAN}', "");
Expect(0, 64280, '\P{^Is_Script_Extensions=_	ARMENIAN}', "");
Error('\p{Is_Scx= Armn/a/}');
Error('\P{Is_Scx= Armn/a/}');
Expect(1, 64279, '\p{Is_Scx=armn}', "");
Expect(0, 64279, '\p{^Is_Scx=armn}', "");
Expect(0, 64279, '\P{Is_Scx=armn}', "");
Expect(1, 64279, '\P{^Is_Scx=armn}', "");
Expect(0, 64280, '\p{Is_Scx=armn}', "");
Expect(1, 64280, '\p{^Is_Scx=armn}', "");
Expect(1, 64280, '\P{Is_Scx=armn}', "");
Expect(0, 64280, '\P{^Is_Scx=armn}', "");
Expect(1, 64279, '\p{Is_Scx=	Armn}', "");
Expect(0, 64279, '\p{^Is_Scx=	Armn}', "");
Expect(0, 64279, '\P{Is_Scx=	Armn}', "");
Expect(1, 64279, '\P{^Is_Scx=	Armn}', "");
Expect(0, 64280, '\p{Is_Scx=	Armn}', "");
Expect(1, 64280, '\p{^Is_Scx=	Armn}', "");
Expect(1, 64280, '\P{Is_Scx=	Armn}', "");
Expect(0, 64280, '\P{^Is_Scx=	Armn}', "");
Error('\p{Script_Extensions=	avestan/a/}');
Error('\P{Script_Extensions=	avestan/a/}');
Expect(1, 68415, '\p{Script_Extensions=avestan}', "");
Expect(0, 68415, '\p{^Script_Extensions=avestan}', "");
Expect(0, 68415, '\P{Script_Extensions=avestan}', "");
Expect(1, 68415, '\P{^Script_Extensions=avestan}', "");
Expect(0, 68416, '\p{Script_Extensions=avestan}', "");
Expect(1, 68416, '\p{^Script_Extensions=avestan}', "");
Expect(1, 68416, '\P{Script_Extensions=avestan}', "");
Expect(0, 68416, '\P{^Script_Extensions=avestan}', "");
Error('\p{Scx:-:=Avst}');
Error('\P{Scx:-:=Avst}');
Expect(1, 68415, '\p{Scx=avst}', "");
Expect(0, 68415, '\p{^Scx=avst}', "");
Expect(0, 68415, '\P{Scx=avst}', "");
Expect(1, 68415, '\P{^Scx=avst}', "");
Expect(0, 68416, '\p{Scx=avst}', "");
Expect(1, 68416, '\p{^Scx=avst}', "");
Expect(1, 68416, '\P{Scx=avst}', "");
Expect(0, 68416, '\P{^Scx=avst}', "");
Expect(1, 68415, '\p{Scx=	 avst}', "");
Expect(0, 68415, '\p{^Scx=	 avst}', "");
Expect(0, 68415, '\P{Scx=	 avst}', "");
Expect(1, 68415, '\P{^Scx=	 avst}', "");
Expect(0, 68416, '\p{Scx=	 avst}', "");
Expect(1, 68416, '\p{^Scx=	 avst}', "");
Expect(1, 68416, '\P{Scx=	 avst}', "");
Expect(0, 68416, '\P{^Scx=	 avst}', "");
Error('\p{Is_Script_Extensions=__Avestan/a/}');
Error('\P{Is_Script_Extensions=__Avestan/a/}');
Expect(1, 68415, '\p{Is_Script_Extensions:avestan}', "");
Expect(0, 68415, '\p{^Is_Script_Extensions:avestan}', "");
Expect(0, 68415, '\P{Is_Script_Extensions:avestan}', "");
Expect(1, 68415, '\P{^Is_Script_Extensions:avestan}', "");
Expect(0, 68416, '\p{Is_Script_Extensions:avestan}', "");
Expect(1, 68416, '\p{^Is_Script_Extensions:avestan}', "");
Expect(1, 68416, '\P{Is_Script_Extensions:avestan}', "");
Expect(0, 68416, '\P{^Is_Script_Extensions:avestan}', "");
Expect(1, 68415, '\p{Is_Script_Extensions=  Avestan}', "");
Expect(0, 68415, '\p{^Is_Script_Extensions=  Avestan}', "");
Expect(0, 68415, '\P{Is_Script_Extensions=  Avestan}', "");
Expect(1, 68415, '\P{^Is_Script_Extensions=  Avestan}', "");
Expect(0, 68416, '\p{Is_Script_Extensions=  Avestan}', "");
Expect(1, 68416, '\p{^Is_Script_Extensions=  Avestan}', "");
Expect(1, 68416, '\P{Is_Script_Extensions=  Avestan}', "");
Expect(0, 68416, '\P{^Is_Script_Extensions=  Avestan}', "");
Error('\p{Is_Scx=- Avst:=}');
Error('\P{Is_Scx=- Avst:=}');
Expect(1, 68415, '\p{Is_Scx=avst}', "");
Expect(0, 68415, '\p{^Is_Scx=avst}', "");
Expect(0, 68415, '\P{Is_Scx=avst}', "");
Expect(1, 68415, '\P{^Is_Scx=avst}', "");
Expect(0, 68416, '\p{Is_Scx=avst}', "");
Expect(1, 68416, '\p{^Is_Scx=avst}', "");
Expect(1, 68416, '\P{Is_Scx=avst}', "");
Expect(0, 68416, '\P{^Is_Scx=avst}', "");
Expect(1, 68415, '\p{Is_Scx=	AVST}', "");
Expect(0, 68415, '\p{^Is_Scx=	AVST}', "");
Expect(0, 68415, '\P{Is_Scx=	AVST}', "");
Expect(1, 68415, '\P{^Is_Scx=	AVST}', "");
Expect(0, 68416, '\p{Is_Scx=	AVST}', "");
Expect(1, 68416, '\p{^Is_Scx=	AVST}', "");
Expect(1, 68416, '\P{Is_Scx=	AVST}', "");
Expect(0, 68416, '\P{^Is_Scx=	AVST}', "");
Error('\p{Script_Extensions=/a/ -Balinese}');
Error('\P{Script_Extensions=/a/ -Balinese}');
Expect(1, 7036, '\p{Script_Extensions=balinese}', "");
Expect(0, 7036, '\p{^Script_Extensions=balinese}', "");
Expect(0, 7036, '\P{Script_Extensions=balinese}', "");
Expect(1, 7036, '\P{^Script_Extensions=balinese}', "");
Expect(0, 7037, '\p{Script_Extensions=balinese}', "");
Expect(1, 7037, '\p{^Script_Extensions=balinese}', "");
Expect(1, 7037, '\P{Script_Extensions=balinese}', "");
Expect(0, 7037, '\P{^Script_Extensions=balinese}', "");
Expect(1, 7036, '\p{Script_Extensions= 	Balinese}', "");
Expect(0, 7036, '\p{^Script_Extensions= 	Balinese}', "");
Expect(0, 7036, '\P{Script_Extensions= 	Balinese}', "");
Expect(1, 7036, '\P{^Script_Extensions= 	Balinese}', "");
Expect(0, 7037, '\p{Script_Extensions= 	Balinese}', "");
Expect(1, 7037, '\p{^Script_Extensions= 	Balinese}', "");
Expect(1, 7037, '\P{Script_Extensions= 	Balinese}', "");
Expect(0, 7037, '\P{^Script_Extensions= 	Balinese}', "");
Error('\p{Scx=	_bali/a/}');
Error('\P{Scx=	_bali/a/}');
Expect(1, 7036, '\p{Scx=bali}', "");
Expect(0, 7036, '\p{^Scx=bali}', "");
Expect(0, 7036, '\P{Scx=bali}', "");
Expect(1, 7036, '\P{^Scx=bali}', "");
Expect(0, 7037, '\p{Scx=bali}', "");
Expect(1, 7037, '\p{^Scx=bali}', "");
Expect(1, 7037, '\P{Scx=bali}', "");
Expect(0, 7037, '\P{^Scx=bali}', "");
Expect(1, 7036, '\p{Scx=  Bali}', "");
Expect(0, 7036, '\p{^Scx=  Bali}', "");
Expect(0, 7036, '\P{Scx=  Bali}', "");
Expect(1, 7036, '\P{^Scx=  Bali}', "");
Expect(0, 7037, '\p{Scx=  Bali}', "");
Expect(1, 7037, '\p{^Scx=  Bali}', "");
Expect(1, 7037, '\P{Scx=  Bali}', "");
Expect(0, 7037, '\P{^Scx=  Bali}', "");
Error('\p{Is_Script_Extensions=:=	_balinese}');
Error('\P{Is_Script_Extensions=:=	_balinese}');
Expect(1, 7036, '\p{Is_Script_Extensions=balinese}', "");
Expect(0, 7036, '\p{^Is_Script_Extensions=balinese}', "");
Expect(0, 7036, '\P{Is_Script_Extensions=balinese}', "");
Expect(1, 7036, '\P{^Is_Script_Extensions=balinese}', "");
Expect(0, 7037, '\p{Is_Script_Extensions=balinese}', "");
Expect(1, 7037, '\p{^Is_Script_Extensions=balinese}', "");
Expect(1, 7037, '\P{Is_Script_Extensions=balinese}', "");
Expect(0, 7037, '\P{^Is_Script_Extensions=balinese}', "");
Expect(1, 7036, '\p{Is_Script_Extensions=	Balinese}', "");
Expect(0, 7036, '\p{^Is_Script_Extensions=	Balinese}', "");
Expect(0, 7036, '\P{Is_Script_Extensions=	Balinese}', "");
Expect(1, 7036, '\P{^Is_Script_Extensions=	Balinese}', "");
Expect(0, 7037, '\p{Is_Script_Extensions=	Balinese}', "");
Expect(1, 7037, '\p{^Is_Script_Extensions=	Balinese}', "");
Expect(1, 7037, '\P{Is_Script_Extensions=	Balinese}', "");
Expect(0, 7037, '\P{^Is_Script_Extensions=	Balinese}', "");
Error('\p{Is_Scx=:=bali}');
Error('\P{Is_Scx=:=bali}');
Expect(1, 7036, '\p{Is_Scx=bali}', "");
Expect(0, 7036, '\p{^Is_Scx=bali}', "");
Expect(0, 7036, '\P{Is_Scx=bali}', "");
Expect(1, 7036, '\P{^Is_Scx=bali}', "");
Expect(0, 7037, '\p{Is_Scx=bali}', "");
Expect(1, 7037, '\p{^Is_Scx=bali}', "");
Expect(1, 7037, '\P{Is_Scx=bali}', "");
Expect(0, 7037, '\P{^Is_Scx=bali}', "");
Expect(1, 7036, '\p{Is_Scx= _bali}', "");
Expect(0, 7036, '\p{^Is_Scx= _bali}', "");
Expect(0, 7036, '\P{Is_Scx= _bali}', "");
Expect(1, 7036, '\P{^Is_Scx= _bali}', "");
Expect(0, 7037, '\p{Is_Scx= _bali}', "");
Expect(1, 7037, '\p{^Is_Scx= _bali}', "");
Expect(1, 7037, '\P{Is_Scx= _bali}', "");
Expect(0, 7037, '\P{^Is_Scx= _bali}', "");
Error('\p{Script_Extensions=_bamum:=}');
Error('\P{Script_Extensions=_bamum:=}');
Expect(1, 92728, '\p{Script_Extensions=bamum}', "");
Expect(0, 92728, '\p{^Script_Extensions=bamum}', "");
Expect(0, 92728, '\P{Script_Extensions=bamum}', "");
Expect(1, 92728, '\P{^Script_Extensions=bamum}', "");
Expect(0, 92729, '\p{Script_Extensions=bamum}', "");
Expect(1, 92729, '\p{^Script_Extensions=bamum}', "");
Expect(1, 92729, '\P{Script_Extensions=bamum}', "");
Expect(0, 92729, '\P{^Script_Extensions=bamum}', "");
Expect(1, 92728, '\p{Script_Extensions=-	Bamum}', "");
Expect(0, 92728, '\p{^Script_Extensions=-	Bamum}', "");
Expect(0, 92728, '\P{Script_Extensions=-	Bamum}', "");
Expect(1, 92728, '\P{^Script_Extensions=-	Bamum}', "");
Expect(0, 92729, '\p{Script_Extensions=-	Bamum}', "");
Expect(1, 92729, '\p{^Script_Extensions=-	Bamum}', "");
Expect(1, 92729, '\P{Script_Extensions=-	Bamum}', "");
Expect(0, 92729, '\P{^Script_Extensions=-	Bamum}', "");
Error('\p{Scx= /a/BAMU}');
Error('\P{Scx= /a/BAMU}');
Expect(1, 92728, '\p{Scx=bamu}', "");
Expect(0, 92728, '\p{^Scx=bamu}', "");
Expect(0, 92728, '\P{Scx=bamu}', "");
Expect(1, 92728, '\P{^Scx=bamu}', "");
Expect(0, 92729, '\p{Scx=bamu}', "");
Expect(1, 92729, '\p{^Scx=bamu}', "");
Expect(1, 92729, '\P{Scx=bamu}', "");
Expect(0, 92729, '\P{^Scx=bamu}', "");
Expect(1, 92728, '\p{Scx=--Bamu}', "");
Expect(0, 92728, '\p{^Scx=--Bamu}', "");
Expect(0, 92728, '\P{Scx=--Bamu}', "");
Expect(1, 92728, '\P{^Scx=--Bamu}', "");
Expect(0, 92729, '\p{Scx=--Bamu}', "");
Expect(1, 92729, '\p{^Scx=--Bamu}', "");
Expect(1, 92729, '\P{Scx=--Bamu}', "");
Expect(0, 92729, '\P{^Scx=--Bamu}', "");
Error('\p{Is_Script_Extensions= 	bamum:=}');
Error('\P{Is_Script_Extensions= 	bamum:=}');
Expect(1, 92728, '\p{Is_Script_Extensions:	bamum}', "");
Expect(0, 92728, '\p{^Is_Script_Extensions:	bamum}', "");
Expect(0, 92728, '\P{Is_Script_Extensions:	bamum}', "");
Expect(1, 92728, '\P{^Is_Script_Extensions:	bamum}', "");
Expect(0, 92729, '\p{Is_Script_Extensions:	bamum}', "");
Expect(1, 92729, '\p{^Is_Script_Extensions:	bamum}', "");
Expect(1, 92729, '\P{Is_Script_Extensions:	bamum}', "");
Expect(0, 92729, '\P{^Is_Script_Extensions:	bamum}', "");
Expect(1, 92728, '\p{Is_Script_Extensions: -Bamum}', "");
Expect(0, 92728, '\p{^Is_Script_Extensions: -Bamum}', "");
Expect(0, 92728, '\P{Is_Script_Extensions: -Bamum}', "");
Expect(1, 92728, '\P{^Is_Script_Extensions: -Bamum}', "");
Expect(0, 92729, '\p{Is_Script_Extensions: -Bamum}', "");
Expect(1, 92729, '\p{^Is_Script_Extensions: -Bamum}', "");
Expect(1, 92729, '\P{Is_Script_Extensions: -Bamum}', "");
Expect(0, 92729, '\P{^Is_Script_Extensions: -Bamum}', "");
Error('\p{Is_Scx=/a/ bamu}');
Error('\P{Is_Scx=/a/ bamu}');
Expect(1, 92728, '\p{Is_Scx=bamu}', "");
Expect(0, 92728, '\p{^Is_Scx=bamu}', "");
Expect(0, 92728, '\P{Is_Scx=bamu}', "");
Expect(1, 92728, '\P{^Is_Scx=bamu}', "");
Expect(0, 92729, '\p{Is_Scx=bamu}', "");
Expect(1, 92729, '\p{^Is_Scx=bamu}', "");
Expect(1, 92729, '\P{Is_Scx=bamu}', "");
Expect(0, 92729, '\P{^Is_Scx=bamu}', "");
Expect(1, 92728, '\p{Is_Scx:		 Bamu}', "");
Expect(0, 92728, '\p{^Is_Scx:		 Bamu}', "");
Expect(0, 92728, '\P{Is_Scx:		 Bamu}', "");
Expect(1, 92728, '\P{^Is_Scx:		 Bamu}', "");
Expect(0, 92729, '\p{Is_Scx:		 Bamu}', "");
Expect(1, 92729, '\p{^Is_Scx:		 Bamu}', "");
Expect(1, 92729, '\P{Is_Scx:		 Bamu}', "");
Expect(0, 92729, '\P{^Is_Scx:		 Bamu}', "");
Error('\p{Script_Extensions=/a/_	Batak}');
Error('\P{Script_Extensions=/a/_	Batak}');
Expect(1, 7167, '\p{Script_Extensions=batak}', "");
Expect(0, 7167, '\p{^Script_Extensions=batak}', "");
Expect(0, 7167, '\P{Script_Extensions=batak}', "");
Expect(1, 7167, '\P{^Script_Extensions=batak}', "");
Expect(0, 7168, '\p{Script_Extensions=batak}', "");
Expect(1, 7168, '\p{^Script_Extensions=batak}', "");
Expect(1, 7168, '\P{Script_Extensions=batak}', "");
Expect(0, 7168, '\P{^Script_Extensions=batak}', "");
Expect(1, 7167, '\p{Script_Extensions: -BATAK}', "");
Expect(0, 7167, '\p{^Script_Extensions: -BATAK}', "");
Expect(0, 7167, '\P{Script_Extensions: -BATAK}', "");
Expect(1, 7167, '\P{^Script_Extensions: -BATAK}', "");
Expect(0, 7168, '\p{Script_Extensions: -BATAK}', "");
Expect(1, 7168, '\p{^Script_Extensions: -BATAK}', "");
Expect(1, 7168, '\P{Script_Extensions: -BATAK}', "");
Expect(0, 7168, '\P{^Script_Extensions: -BATAK}', "");
Error('\p{Scx=/a/--Batk}');
Error('\P{Scx=/a/--Batk}');
Expect(1, 7167, '\p{Scx=batk}', "");
Expect(0, 7167, '\p{^Scx=batk}', "");
Expect(0, 7167, '\P{Scx=batk}', "");
Expect(1, 7167, '\P{^Scx=batk}', "");
Expect(0, 7168, '\p{Scx=batk}', "");
Expect(1, 7168, '\p{^Scx=batk}', "");
Expect(1, 7168, '\P{Scx=batk}', "");
Expect(0, 7168, '\P{^Scx=batk}', "");
Expect(1, 7167, '\p{Scx= BATK}', "");
Expect(0, 7167, '\p{^Scx= BATK}', "");
Expect(0, 7167, '\P{Scx= BATK}', "");
Expect(1, 7167, '\P{^Scx= BATK}', "");
Expect(0, 7168, '\p{Scx= BATK}', "");
Expect(1, 7168, '\p{^Scx= BATK}', "");
Expect(1, 7168, '\P{Scx= BATK}', "");
Expect(0, 7168, '\P{^Scx= BATK}', "");
Error('\p{Is_Script_Extensions=	/a/Batak}');
Error('\P{Is_Script_Extensions=	/a/Batak}');
Expect(1, 7167, '\p{Is_Script_Extensions:batak}', "");
Expect(0, 7167, '\p{^Is_Script_Extensions:batak}', "");
Expect(0, 7167, '\P{Is_Script_Extensions:batak}', "");
Expect(1, 7167, '\P{^Is_Script_Extensions:batak}', "");
Expect(0, 7168, '\p{Is_Script_Extensions:batak}', "");
Expect(1, 7168, '\p{^Is_Script_Extensions:batak}', "");
Expect(1, 7168, '\P{Is_Script_Extensions:batak}', "");
Expect(0, 7168, '\P{^Is_Script_Extensions:batak}', "");
Expect(1, 7167, '\p{Is_Script_Extensions:   -batak}', "");
Expect(0, 7167, '\p{^Is_Script_Extensions:   -batak}', "");
Expect(0, 7167, '\P{Is_Script_Extensions:   -batak}', "");
Expect(1, 7167, '\P{^Is_Script_Extensions:   -batak}', "");
Expect(0, 7168, '\p{Is_Script_Extensions:   -batak}', "");
Expect(1, 7168, '\p{^Is_Script_Extensions:   -batak}', "");
Expect(1, 7168, '\P{Is_Script_Extensions:   -batak}', "");
Expect(0, 7168, '\P{^Is_Script_Extensions:   -batak}', "");
Error('\p{Is_Scx=:= BATK}');
Error('\P{Is_Scx=:= BATK}');
Expect(1, 7167, '\p{Is_Scx=batk}', "");
Expect(0, 7167, '\p{^Is_Scx=batk}', "");
Expect(0, 7167, '\P{Is_Scx=batk}', "");
Expect(1, 7167, '\P{^Is_Scx=batk}', "");
Expect(0, 7168, '\p{Is_Scx=batk}', "");
Expect(1, 7168, '\p{^Is_Scx=batk}', "");
Expect(1, 7168, '\P{Is_Scx=batk}', "");
Expect(0, 7168, '\P{^Is_Scx=batk}', "");
Expect(1, 7167, '\p{Is_Scx=_Batk}', "");
Expect(0, 7167, '\p{^Is_Scx=_Batk}', "");
Expect(0, 7167, '\P{Is_Scx=_Batk}', "");
Expect(1, 7167, '\P{^Is_Scx=_Batk}', "");
Expect(0, 7168, '\p{Is_Scx=_Batk}', "");
Expect(1, 7168, '\p{^Is_Scx=_Batk}', "");
Expect(1, 7168, '\P{Is_Scx=_Batk}', "");
Expect(0, 7168, '\P{^Is_Scx=_Batk}', "");
Error('\p{Script_Extensions=/a/--Bengali}');
Error('\P{Script_Extensions=/a/--Bengali}');
Expect(1, 2555, '\p{Script_Extensions=bengali}', "");
Expect(0, 2555, '\p{^Script_Extensions=bengali}', "");
Expect(0, 2555, '\P{Script_Extensions=bengali}', "");
Expect(1, 2555, '\P{^Script_Extensions=bengali}', "");
Expect(0, 2556, '\p{Script_Extensions=bengali}', "");
Expect(1, 2556, '\p{^Script_Extensions=bengali}', "");
Expect(1, 2556, '\P{Script_Extensions=bengali}', "");
Expect(0, 2556, '\P{^Script_Extensions=bengali}', "");
Expect(1, 2555, '\p{Script_Extensions=	Bengali}', "");
Expect(0, 2555, '\p{^Script_Extensions=	Bengali}', "");
Expect(0, 2555, '\P{Script_Extensions=	Bengali}', "");
Expect(1, 2555, '\P{^Script_Extensions=	Bengali}', "");
Expect(0, 2556, '\p{Script_Extensions=	Bengali}', "");
Expect(1, 2556, '\p{^Script_Extensions=	Bengali}', "");
Expect(1, 2556, '\P{Script_Extensions=	Bengali}', "");
Expect(0, 2556, '\P{^Script_Extensions=	Bengali}', "");
Error('\p{Scx=:=Beng}');
Error('\P{Scx=:=Beng}');
Expect(1, 2555, '\p{Scx=beng}', "");
Expect(0, 2555, '\p{^Scx=beng}', "");
Expect(0, 2555, '\P{Scx=beng}', "");
Expect(1, 2555, '\P{^Scx=beng}', "");
Expect(0, 2556, '\p{Scx=beng}', "");
Expect(1, 2556, '\p{^Scx=beng}', "");
Expect(1, 2556, '\P{Scx=beng}', "");
Expect(0, 2556, '\P{^Scx=beng}', "");
Expect(1, 2555, '\p{Scx= BENG}', "");
Expect(0, 2555, '\p{^Scx= BENG}', "");
Expect(0, 2555, '\P{Scx= BENG}', "");
Expect(1, 2555, '\P{^Scx= BENG}', "");
Expect(0, 2556, '\p{Scx= BENG}', "");
Expect(1, 2556, '\p{^Scx= BENG}', "");
Expect(1, 2556, '\P{Scx= BENG}', "");
Expect(0, 2556, '\P{^Scx= BENG}', "");
Error('\p{Is_Script_Extensions=-bengali/a/}');
Error('\P{Is_Script_Extensions=-bengali/a/}');
Expect(1, 2555, '\p{Is_Script_Extensions=bengali}', "");
Expect(0, 2555, '\p{^Is_Script_Extensions=bengali}', "");
Expect(0, 2555, '\P{Is_Script_Extensions=bengali}', "");
Expect(1, 2555, '\P{^Is_Script_Extensions=bengali}', "");
Expect(0, 2556, '\p{Is_Script_Extensions=bengali}', "");
Expect(1, 2556, '\p{^Is_Script_Extensions=bengali}', "");
Expect(1, 2556, '\P{Is_Script_Extensions=bengali}', "");
Expect(0, 2556, '\P{^Is_Script_Extensions=bengali}', "");
Expect(1, 2555, '\p{Is_Script_Extensions=Bengali}', "");
Expect(0, 2555, '\p{^Is_Script_Extensions=Bengali}', "");
Expect(0, 2555, '\P{Is_Script_Extensions=Bengali}', "");
Expect(1, 2555, '\P{^Is_Script_Extensions=Bengali}', "");
Expect(0, 2556, '\p{Is_Script_Extensions=Bengali}', "");
Expect(1, 2556, '\p{^Is_Script_Extensions=Bengali}', "");
Expect(1, 2556, '\P{Is_Script_Extensions=Bengali}', "");
Expect(0, 2556, '\P{^Is_Script_Extensions=Bengali}', "");
Error('\p{Is_Scx:	/a/_-beng}');
Error('\P{Is_Scx:	/a/_-beng}');
Expect(1, 2555, '\p{Is_Scx=beng}', "");
Expect(0, 2555, '\p{^Is_Scx=beng}', "");
Expect(0, 2555, '\P{Is_Scx=beng}', "");
Expect(1, 2555, '\P{^Is_Scx=beng}', "");
Expect(0, 2556, '\p{Is_Scx=beng}', "");
Expect(1, 2556, '\p{^Is_Scx=beng}', "");
Expect(1, 2556, '\P{Is_Scx=beng}', "");
Expect(0, 2556, '\P{^Is_Scx=beng}', "");
Expect(1, 2555, '\p{Is_Scx=_ Beng}', "");
Expect(0, 2555, '\p{^Is_Scx=_ Beng}', "");
Expect(0, 2555, '\P{Is_Scx=_ Beng}', "");
Expect(1, 2555, '\P{^Is_Scx=_ Beng}', "");
Expect(0, 2556, '\p{Is_Scx=_ Beng}', "");
Expect(1, 2556, '\p{^Is_Scx=_ Beng}', "");
Expect(1, 2556, '\P{Is_Scx=_ Beng}', "");
Expect(0, 2556, '\P{^Is_Scx=_ Beng}', "");
Error('\p{Script_Extensions=-/a/Bopomofo}');
Error('\P{Script_Extensions=-/a/Bopomofo}');
Expect(1, 65381, '\p{Script_Extensions: bopomofo}', "");
Expect(0, 65381, '\p{^Script_Extensions: bopomofo}', "");
Expect(0, 65381, '\P{Script_Extensions: bopomofo}', "");
Expect(1, 65381, '\P{^Script_Extensions: bopomofo}', "");
Expect(0, 65382, '\p{Script_Extensions: bopomofo}', "");
Expect(1, 65382, '\p{^Script_Extensions: bopomofo}', "");
Expect(1, 65382, '\P{Script_Extensions: bopomofo}', "");
Expect(0, 65382, '\P{^Script_Extensions: bopomofo}', "");
Expect(1, 65381, '\p{Script_Extensions=	_bopomofo}', "");
Expect(0, 65381, '\p{^Script_Extensions=	_bopomofo}', "");
Expect(0, 65381, '\P{Script_Extensions=	_bopomofo}', "");
Expect(1, 65381, '\P{^Script_Extensions=	_bopomofo}', "");
Expect(0, 65382, '\p{Script_Extensions=	_bopomofo}', "");
Expect(1, 65382, '\p{^Script_Extensions=	_bopomofo}', "");
Expect(1, 65382, '\P{Script_Extensions=	_bopomofo}', "");
Expect(0, 65382, '\P{^Script_Extensions=	_bopomofo}', "");
Error('\p{Scx= :=Bopo}');
Error('\P{Scx= :=Bopo}');
Expect(1, 65381, '\p{Scx=bopo}', "");
Expect(0, 65381, '\p{^Scx=bopo}', "");
Expect(0, 65381, '\P{Scx=bopo}', "");
Expect(1, 65381, '\P{^Scx=bopo}', "");
Expect(0, 65382, '\p{Scx=bopo}', "");
Expect(1, 65382, '\p{^Scx=bopo}', "");
Expect(1, 65382, '\P{Scx=bopo}', "");
Expect(0, 65382, '\P{^Scx=bopo}', "");
Expect(1, 65381, '\p{Scx=  bopo}', "");
Expect(0, 65381, '\p{^Scx=  bopo}', "");
Expect(0, 65381, '\P{Scx=  bopo}', "");
Expect(1, 65381, '\P{^Scx=  bopo}', "");
Expect(0, 65382, '\p{Scx=  bopo}', "");
Expect(1, 65382, '\p{^Scx=  bopo}', "");
Expect(1, 65382, '\P{Scx=  bopo}', "");
Expect(0, 65382, '\P{^Scx=  bopo}', "");
Error('\p{Is_Script_Extensions=:= bopomofo}');
Error('\P{Is_Script_Extensions=:= bopomofo}');
Expect(1, 65381, '\p{Is_Script_Extensions=bopomofo}', "");
Expect(0, 65381, '\p{^Is_Script_Extensions=bopomofo}', "");
Expect(0, 65381, '\P{Is_Script_Extensions=bopomofo}', "");
Expect(1, 65381, '\P{^Is_Script_Extensions=bopomofo}', "");
Expect(0, 65382, '\p{Is_Script_Extensions=bopomofo}', "");
Expect(1, 65382, '\p{^Is_Script_Extensions=bopomofo}', "");
Expect(1, 65382, '\P{Is_Script_Extensions=bopomofo}', "");
Expect(0, 65382, '\P{^Is_Script_Extensions=bopomofo}', "");
Expect(1, 65381, '\p{Is_Script_Extensions:-BOPOMOFO}', "");
Expect(0, 65381, '\p{^Is_Script_Extensions:-BOPOMOFO}', "");
Expect(0, 65381, '\P{Is_Script_Extensions:-BOPOMOFO}', "");
Expect(1, 65381, '\P{^Is_Script_Extensions:-BOPOMOFO}', "");
Expect(0, 65382, '\p{Is_Script_Extensions:-BOPOMOFO}', "");
Expect(1, 65382, '\p{^Is_Script_Extensions:-BOPOMOFO}', "");
Expect(1, 65382, '\P{Is_Script_Extensions:-BOPOMOFO}', "");
Expect(0, 65382, '\P{^Is_Script_Extensions:-BOPOMOFO}', "");
Error('\p{Is_Scx=-_BOPO:=}');
Error('\P{Is_Scx=-_BOPO:=}');
Expect(1, 65381, '\p{Is_Scx=bopo}', "");
Expect(0, 65381, '\p{^Is_Scx=bopo}', "");
Expect(0, 65381, '\P{Is_Scx=bopo}', "");
Expect(1, 65381, '\P{^Is_Scx=bopo}', "");
Expect(0, 65382, '\p{Is_Scx=bopo}', "");
Expect(1, 65382, '\p{^Is_Scx=bopo}', "");
Expect(1, 65382, '\P{Is_Scx=bopo}', "");
Expect(0, 65382, '\P{^Is_Scx=bopo}', "");
Expect(1, 65381, '\p{Is_Scx= BOPO}', "");
Expect(0, 65381, '\p{^Is_Scx= BOPO}', "");
Expect(0, 65381, '\P{Is_Scx= BOPO}', "");
Expect(1, 65381, '\P{^Is_Scx= BOPO}', "");
Expect(0, 65382, '\p{Is_Scx= BOPO}', "");
Expect(1, 65382, '\p{^Is_Scx= BOPO}', "");
Expect(1, 65382, '\P{Is_Scx= BOPO}', "");
Expect(0, 65382, '\P{^Is_Scx= BOPO}', "");
Error('\p{Script_Extensions=/a/-BRAHMI}');
Error('\P{Script_Extensions=/a/-BRAHMI}');
Expect(1, 69743, '\p{Script_Extensions=brahmi}', "");
Expect(0, 69743, '\p{^Script_Extensions=brahmi}', "");
Expect(0, 69743, '\P{Script_Extensions=brahmi}', "");
Expect(1, 69743, '\P{^Script_Extensions=brahmi}', "");
Expect(0, 69744, '\p{Script_Extensions=brahmi}', "");
Expect(1, 69744, '\p{^Script_Extensions=brahmi}', "");
Expect(1, 69744, '\P{Script_Extensions=brahmi}', "");
Expect(0, 69744, '\P{^Script_Extensions=brahmi}', "");
Error('\p{Scx=:=_	Brah}');
Error('\P{Scx=:=_	Brah}');
Expect(1, 69743, '\p{Scx=brah}', "");
Expect(0, 69743, '\p{^Scx=brah}', "");
Expect(0, 69743, '\P{Scx=brah}', "");
Expect(1, 69743, '\P{^Scx=brah}', "");
Expect(0, 69744, '\p{Scx=brah}', "");
Expect(1, 69744, '\p{^Scx=brah}', "");
Expect(1, 69744, '\P{Scx=brah}', "");
Expect(0, 69744, '\P{^Scx=brah}', "");
Expect(1, 69743, '\p{Scx=--BRAH}', "");
Expect(0, 69743, '\p{^Scx=--BRAH}', "");
Expect(0, 69743, '\P{Scx=--BRAH}', "");
Expect(1, 69743, '\P{^Scx=--BRAH}', "");
Expect(0, 69744, '\p{Scx=--BRAH}', "");
Expect(1, 69744, '\p{^Scx=--BRAH}', "");
Expect(1, 69744, '\P{Scx=--BRAH}', "");
Expect(0, 69744, '\P{^Scx=--BRAH}', "");
Error('\p{Is_Script_Extensions=:=	brahmi}');
Error('\P{Is_Script_Extensions=:=	brahmi}');
Expect(1, 69743, '\p{Is_Script_Extensions=brahmi}', "");
Expect(0, 69743, '\p{^Is_Script_Extensions=brahmi}', "");
Expect(0, 69743, '\P{Is_Script_Extensions=brahmi}', "");
Expect(1, 69743, '\P{^Is_Script_Extensions=brahmi}', "");
Expect(0, 69744, '\p{Is_Script_Extensions=brahmi}', "");
Expect(1, 69744, '\p{^Is_Script_Extensions=brahmi}', "");
Expect(1, 69744, '\P{Is_Script_Extensions=brahmi}', "");
Expect(0, 69744, '\P{^Is_Script_Extensions=brahmi}', "");
Expect(1, 69743, '\p{Is_Script_Extensions=  Brahmi}', "");
Expect(0, 69743, '\p{^Is_Script_Extensions=  Brahmi}', "");
Expect(0, 69743, '\P{Is_Script_Extensions=  Brahmi}', "");
Expect(1, 69743, '\P{^Is_Script_Extensions=  Brahmi}', "");
Expect(0, 69744, '\p{Is_Script_Extensions=  Brahmi}', "");
Expect(1, 69744, '\p{^Is_Script_Extensions=  Brahmi}', "");
Expect(1, 69744, '\P{Is_Script_Extensions=  Brahmi}', "");
Expect(0, 69744, '\P{^Is_Script_Extensions=  Brahmi}', "");
Error('\p{Is_Scx=	/a/brah}');
Error('\P{Is_Scx=	/a/brah}');
Expect(1, 69743, '\p{Is_Scx=brah}', "");
Expect(0, 69743, '\p{^Is_Scx=brah}', "");
Expect(0, 69743, '\P{Is_Scx=brah}', "");
Expect(1, 69743, '\P{^Is_Scx=brah}', "");
Expect(0, 69744, '\p{Is_Scx=brah}', "");
Expect(1, 69744, '\p{^Is_Scx=brah}', "");
Expect(1, 69744, '\P{Is_Scx=brah}', "");
Expect(0, 69744, '\P{^Is_Scx=brah}', "");
Expect(1, 69743, '\p{Is_Scx:		Brah}', "");
Expect(0, 69743, '\p{^Is_Scx:		Brah}', "");
Expect(0, 69743, '\P{Is_Scx:		Brah}', "");
Expect(1, 69743, '\P{^Is_Scx:		Brah}', "");
Expect(0, 69744, '\p{Is_Scx:		Brah}', "");
Expect(1, 69744, '\p{^Is_Scx:		Brah}', "");
Expect(1, 69744, '\P{Is_Scx:		Brah}', "");
Expect(0, 69744, '\P{^Is_Scx:		Brah}', "");
Error('\p{Script_Extensions=:=_-braille}');
Error('\P{Script_Extensions=:=_-braille}');
Expect(1, 10495, '\p{Script_Extensions:braille}', "");
Expect(0, 10495, '\p{^Script_Extensions:braille}', "");
Expect(0, 10495, '\P{Script_Extensions:braille}', "");
Expect(1, 10495, '\P{^Script_Extensions:braille}', "");
Expect(0, 10496, '\p{Script_Extensions:braille}', "");
Expect(1, 10496, '\p{^Script_Extensions:braille}', "");
Expect(1, 10496, '\P{Script_Extensions:braille}', "");
Expect(0, 10496, '\P{^Script_Extensions:braille}', "");
Expect(1, 10495, '\p{Script_Extensions=	 Braille}', "");
Expect(0, 10495, '\p{^Script_Extensions=	 Braille}', "");
Expect(0, 10495, '\P{Script_Extensions=	 Braille}', "");
Expect(1, 10495, '\P{^Script_Extensions=	 Braille}', "");
Expect(0, 10496, '\p{Script_Extensions=	 Braille}', "");
Expect(1, 10496, '\p{^Script_Extensions=	 Braille}', "");
Expect(1, 10496, '\P{Script_Extensions=	 Braille}', "");
Expect(0, 10496, '\P{^Script_Extensions=	 Braille}', "");
Error('\p{Scx=-Brai:=}');
Error('\P{Scx=-Brai:=}');
Expect(1, 10495, '\p{Scx=brai}', "");
Expect(0, 10495, '\p{^Scx=brai}', "");
Expect(0, 10495, '\P{Scx=brai}', "");
Expect(1, 10495, '\P{^Scx=brai}', "");
Expect(0, 10496, '\p{Scx=brai}', "");
Expect(1, 10496, '\p{^Scx=brai}', "");
Expect(1, 10496, '\P{Scx=brai}', "");
Expect(0, 10496, '\P{^Scx=brai}', "");
Expect(1, 10495, '\p{Scx=_Brai}', "");
Expect(0, 10495, '\p{^Scx=_Brai}', "");
Expect(0, 10495, '\P{Scx=_Brai}', "");
Expect(1, 10495, '\P{^Scx=_Brai}', "");
Expect(0, 10496, '\p{Scx=_Brai}', "");
Expect(1, 10496, '\p{^Scx=_Brai}', "");
Expect(1, 10496, '\P{Scx=_Brai}', "");
Expect(0, 10496, '\P{^Scx=_Brai}', "");
Error('\p{Is_Script_Extensions=-:=BRAILLE}');
Error('\P{Is_Script_Extensions=-:=BRAILLE}');
Expect(1, 10495, '\p{Is_Script_Extensions=braille}', "");
Expect(0, 10495, '\p{^Is_Script_Extensions=braille}', "");
Expect(0, 10495, '\P{Is_Script_Extensions=braille}', "");
Expect(1, 10495, '\P{^Is_Script_Extensions=braille}', "");
Expect(0, 10496, '\p{Is_Script_Extensions=braille}', "");
Expect(1, 10496, '\p{^Is_Script_Extensions=braille}', "");
Expect(1, 10496, '\P{Is_Script_Extensions=braille}', "");
Expect(0, 10496, '\P{^Is_Script_Extensions=braille}', "");
Expect(1, 10495, '\p{Is_Script_Extensions=_-Braille}', "");
Expect(0, 10495, '\p{^Is_Script_Extensions=_-Braille}', "");
Expect(0, 10495, '\P{Is_Script_Extensions=_-Braille}', "");
Expect(1, 10495, '\P{^Is_Script_Extensions=_-Braille}', "");
Expect(0, 10496, '\p{Is_Script_Extensions=_-Braille}', "");
Expect(1, 10496, '\p{^Is_Script_Extensions=_-Braille}', "");
Expect(1, 10496, '\P{Is_Script_Extensions=_-Braille}', "");
Expect(0, 10496, '\P{^Is_Script_Extensions=_-Braille}', "");
Error('\p{Is_Scx= /a/Brai}');
Error('\P{Is_Scx= /a/Brai}');
Expect(1, 10495, '\p{Is_Scx:	brai}', "");
Expect(0, 10495, '\p{^Is_Scx:	brai}', "");
Expect(0, 10495, '\P{Is_Scx:	brai}', "");
Expect(1, 10495, '\P{^Is_Scx:	brai}', "");
Expect(0, 10496, '\p{Is_Scx:	brai}', "");
Expect(1, 10496, '\p{^Is_Scx:	brai}', "");
Expect(1, 10496, '\P{Is_Scx:	brai}', "");
Expect(0, 10496, '\P{^Is_Scx:	brai}', "");
Expect(1, 10495, '\p{Is_Scx=		Brai}', "");
Expect(0, 10495, '\p{^Is_Scx=		Brai}', "");
Expect(0, 10495, '\P{Is_Scx=		Brai}', "");
Expect(1, 10495, '\P{^Is_Scx=		Brai}', "");
Expect(0, 10496, '\p{Is_Scx=		Brai}', "");
Expect(1, 10496, '\p{^Is_Scx=		Brai}', "");
Expect(1, 10496, '\P{Is_Scx=		Brai}', "");
Expect(0, 10496, '\P{^Is_Scx=		Brai}', "");
Error('\p{Script_Extensions=/a/buginese}');
Error('\P{Script_Extensions=/a/buginese}');
Expect(1, 43471, '\p{Script_Extensions=buginese}', "");
Expect(0, 43471, '\p{^Script_Extensions=buginese}', "");
Expect(0, 43471, '\P{Script_Extensions=buginese}', "");
Expect(1, 43471, '\P{^Script_Extensions=buginese}', "");
Expect(0, 43472, '\p{Script_Extensions=buginese}', "");
Expect(1, 43472, '\p{^Script_Extensions=buginese}', "");
Expect(1, 43472, '\P{Script_Extensions=buginese}', "");
Expect(0, 43472, '\P{^Script_Extensions=buginese}', "");
Expect(1, 43471, '\p{Script_Extensions=_Buginese}', "");
Expect(0, 43471, '\p{^Script_Extensions=_Buginese}', "");
Expect(0, 43471, '\P{Script_Extensions=_Buginese}', "");
Expect(1, 43471, '\P{^Script_Extensions=_Buginese}', "");
Expect(0, 43472, '\p{Script_Extensions=_Buginese}', "");
Expect(1, 43472, '\p{^Script_Extensions=_Buginese}', "");
Expect(1, 43472, '\P{Script_Extensions=_Buginese}', "");
Expect(0, 43472, '\P{^Script_Extensions=_Buginese}', "");
Error('\p{Scx=-_BUGI/a/}');
Error('\P{Scx=-_BUGI/a/}');
Expect(1, 43471, '\p{Scx=bugi}', "");
Expect(0, 43471, '\p{^Scx=bugi}', "");
Expect(0, 43471, '\P{Scx=bugi}', "");
Expect(1, 43471, '\P{^Scx=bugi}', "");
Expect(0, 43472, '\p{Scx=bugi}', "");
Expect(1, 43472, '\p{^Scx=bugi}', "");
Expect(1, 43472, '\P{Scx=bugi}', "");
Expect(0, 43472, '\P{^Scx=bugi}', "");
Expect(1, 43471, '\p{Scx=_Bugi}', "");
Expect(0, 43471, '\p{^Scx=_Bugi}', "");
Expect(0, 43471, '\P{Scx=_Bugi}', "");
Expect(1, 43471, '\P{^Scx=_Bugi}', "");
Expect(0, 43472, '\p{Scx=_Bugi}', "");
Expect(1, 43472, '\p{^Scx=_Bugi}', "");
Expect(1, 43472, '\P{Scx=_Bugi}', "");
Expect(0, 43472, '\P{^Scx=_Bugi}', "");
Error('\p{Is_Script_Extensions: /a/  Buginese}');
Error('\P{Is_Script_Extensions: /a/  Buginese}');
Expect(1, 43471, '\p{Is_Script_Extensions=buginese}', "");
Expect(0, 43471, '\p{^Is_Script_Extensions=buginese}', "");
Expect(0, 43471, '\P{Is_Script_Extensions=buginese}', "");
Expect(1, 43471, '\P{^Is_Script_Extensions=buginese}', "");
Expect(0, 43472, '\p{Is_Script_Extensions=buginese}', "");
Expect(1, 43472, '\p{^Is_Script_Extensions=buginese}', "");
Expect(1, 43472, '\P{Is_Script_Extensions=buginese}', "");
Expect(0, 43472, '\P{^Is_Script_Extensions=buginese}', "");
Expect(1, 43471, '\p{Is_Script_Extensions=_ Buginese}', "");
Expect(0, 43471, '\p{^Is_Script_Extensions=_ Buginese}', "");
Expect(0, 43471, '\P{Is_Script_Extensions=_ Buginese}', "");
Expect(1, 43471, '\P{^Is_Script_Extensions=_ Buginese}', "");
Expect(0, 43472, '\p{Is_Script_Extensions=_ Buginese}', "");
Expect(1, 43472, '\p{^Is_Script_Extensions=_ Buginese}', "");
Expect(1, 43472, '\P{Is_Script_Extensions=_ Buginese}', "");
Expect(0, 43472, '\P{^Is_Script_Extensions=_ Buginese}', "");
Error('\p{Is_Scx=_Bugi:=}');
Error('\P{Is_Scx=_Bugi:=}');
Expect(1, 43471, '\p{Is_Scx=bugi}', "");
Expect(0, 43471, '\p{^Is_Scx=bugi}', "");
Expect(0, 43471, '\P{Is_Scx=bugi}', "");
Expect(1, 43471, '\P{^Is_Scx=bugi}', "");
Expect(0, 43472, '\p{Is_Scx=bugi}', "");
Expect(1, 43472, '\p{^Is_Scx=bugi}', "");
Expect(1, 43472, '\P{Is_Scx=bugi}', "");
Expect(0, 43472, '\P{^Is_Scx=bugi}', "");
Expect(1, 43471, '\p{Is_Scx=-	Bugi}', "");
Expect(0, 43471, '\p{^Is_Scx=-	Bugi}', "");
Expect(0, 43471, '\P{Is_Scx=-	Bugi}', "");
Expect(1, 43471, '\P{^Is_Scx=-	Bugi}', "");
Expect(0, 43472, '\p{Is_Scx=-	Bugi}', "");
Expect(1, 43472, '\p{^Is_Scx=-	Bugi}', "");
Expect(1, 43472, '\P{Is_Scx=-	Bugi}', "");
Expect(0, 43472, '\P{^Is_Scx=-	Bugi}', "");
Error('\p{Script_Extensions::=-_buhid}');
Error('\P{Script_Extensions::=-_buhid}');
Expect(1, 5971, '\p{Script_Extensions=buhid}', "");
Expect(0, 5971, '\p{^Script_Extensions=buhid}', "");
Expect(0, 5971, '\P{Script_Extensions=buhid}', "");
Expect(1, 5971, '\P{^Script_Extensions=buhid}', "");
Expect(0, 5972, '\p{Script_Extensions=buhid}', "");
Expect(1, 5972, '\p{^Script_Extensions=buhid}', "");
Expect(1, 5972, '\P{Script_Extensions=buhid}', "");
Expect(0, 5972, '\P{^Script_Extensions=buhid}', "");
Expect(1, 5971, '\p{Script_Extensions=__Buhid}', "");
Expect(0, 5971, '\p{^Script_Extensions=__Buhid}', "");
Expect(0, 5971, '\P{Script_Extensions=__Buhid}', "");
Expect(1, 5971, '\P{^Script_Extensions=__Buhid}', "");
Expect(0, 5972, '\p{Script_Extensions=__Buhid}', "");
Expect(1, 5972, '\p{^Script_Extensions=__Buhid}', "");
Expect(1, 5972, '\P{Script_Extensions=__Buhid}', "");
Expect(0, 5972, '\P{^Script_Extensions=__Buhid}', "");
Error('\p{Scx=/a/__buhd}');
Error('\P{Scx=/a/__buhd}');
Expect(1, 5971, '\p{Scx=buhd}', "");
Expect(0, 5971, '\p{^Scx=buhd}', "");
Expect(0, 5971, '\P{Scx=buhd}', "");
Expect(1, 5971, '\P{^Scx=buhd}', "");
Expect(0, 5972, '\p{Scx=buhd}', "");
Expect(1, 5972, '\p{^Scx=buhd}', "");
Expect(1, 5972, '\P{Scx=buhd}', "");
Expect(0, 5972, '\P{^Scx=buhd}', "");
Expect(1, 5971, '\p{Scx= -Buhd}', "");
Expect(0, 5971, '\p{^Scx= -Buhd}', "");
Expect(0, 5971, '\P{Scx= -Buhd}', "");
Expect(1, 5971, '\P{^Scx= -Buhd}', "");
Expect(0, 5972, '\p{Scx= -Buhd}', "");
Expect(1, 5972, '\p{^Scx= -Buhd}', "");
Expect(1, 5972, '\P{Scx= -Buhd}', "");
Expect(0, 5972, '\P{^Scx= -Buhd}', "");
Error('\p{Is_Script_Extensions=- Buhid:=}');
Error('\P{Is_Script_Extensions=- Buhid:=}');
Expect(1, 5971, '\p{Is_Script_Extensions=buhid}', "");
Expect(0, 5971, '\p{^Is_Script_Extensions=buhid}', "");
Expect(0, 5971, '\P{Is_Script_Extensions=buhid}', "");
Expect(1, 5971, '\P{^Is_Script_Extensions=buhid}', "");
Expect(0, 5972, '\p{Is_Script_Extensions=buhid}', "");
Expect(1, 5972, '\p{^Is_Script_Extensions=buhid}', "");
Expect(1, 5972, '\P{Is_Script_Extensions=buhid}', "");
Expect(0, 5972, '\P{^Is_Script_Extensions=buhid}', "");
Expect(1, 5971, '\p{Is_Script_Extensions=-buhid}', "");
Expect(0, 5971, '\p{^Is_Script_Extensions=-buhid}', "");
Expect(0, 5971, '\P{Is_Script_Extensions=-buhid}', "");
Expect(1, 5971, '\P{^Is_Script_Extensions=-buhid}', "");
Expect(0, 5972, '\p{Is_Script_Extensions=-buhid}', "");
Expect(1, 5972, '\p{^Is_Script_Extensions=-buhid}', "");
Expect(1, 5972, '\P{Is_Script_Extensions=-buhid}', "");
Expect(0, 5972, '\P{^Is_Script_Extensions=-buhid}', "");
Error('\p{Is_Scx=:=	Buhd}');
Error('\P{Is_Scx=:=	Buhd}');
Expect(1, 5971, '\p{Is_Scx=buhd}', "");
Expect(0, 5971, '\p{^Is_Scx=buhd}', "");
Expect(0, 5971, '\P{Is_Scx=buhd}', "");
Expect(1, 5971, '\P{^Is_Scx=buhd}', "");
Expect(0, 5972, '\p{Is_Scx=buhd}', "");
Expect(1, 5972, '\p{^Is_Scx=buhd}', "");
Expect(1, 5972, '\P{Is_Scx=buhd}', "");
Expect(0, 5972, '\P{^Is_Scx=buhd}', "");
Expect(1, 5971, '\p{Is_Scx=	Buhd}', "");
Expect(0, 5971, '\p{^Is_Scx=	Buhd}', "");
Expect(0, 5971, '\P{Is_Scx=	Buhd}', "");
Expect(1, 5971, '\P{^Is_Scx=	Buhd}', "");
Expect(0, 5972, '\p{Is_Scx=	Buhd}', "");
Expect(1, 5972, '\p{^Is_Scx=	Buhd}', "");
Expect(1, 5972, '\P{Is_Scx=	Buhd}', "");
Expect(0, 5972, '\P{^Is_Scx=	Buhd}', "");
Error('\p{Script_Extensions=-chakma/a/}');
Error('\P{Script_Extensions=-chakma/a/}');
Expect(1, 69955, '\p{Script_Extensions=chakma}', "");
Expect(0, 69955, '\p{^Script_Extensions=chakma}', "");
Expect(0, 69955, '\P{Script_Extensions=chakma}', "");
Expect(1, 69955, '\P{^Script_Extensions=chakma}', "");
Expect(0, 69956, '\p{Script_Extensions=chakma}', "");
Expect(1, 69956, '\p{^Script_Extensions=chakma}', "");
Expect(1, 69956, '\P{Script_Extensions=chakma}', "");
Expect(0, 69956, '\P{^Script_Extensions=chakma}', "");
Expect(1, 69955, '\p{Script_Extensions=__chakma}', "");
Expect(0, 69955, '\p{^Script_Extensions=__chakma}', "");
Expect(0, 69955, '\P{Script_Extensions=__chakma}', "");
Expect(1, 69955, '\P{^Script_Extensions=__chakma}', "");
Expect(0, 69956, '\p{Script_Extensions=__chakma}', "");
Expect(1, 69956, '\p{^Script_Extensions=__chakma}', "");
Expect(1, 69956, '\P{Script_Extensions=__chakma}', "");
Expect(0, 69956, '\P{^Script_Extensions=__chakma}', "");
Error('\p{Scx=/a/cakm}');
Error('\P{Scx=/a/cakm}');
Expect(1, 69955, '\p{Scx=cakm}', "");
Expect(0, 69955, '\p{^Scx=cakm}', "");
Expect(0, 69955, '\P{Scx=cakm}', "");
Expect(1, 69955, '\P{^Scx=cakm}', "");
Expect(0, 69956, '\p{Scx=cakm}', "");
Expect(1, 69956, '\p{^Scx=cakm}', "");
Expect(1, 69956, '\P{Scx=cakm}', "");
Expect(0, 69956, '\P{^Scx=cakm}', "");
Expect(1, 69955, '\p{Scx=	 CAKM}', "");
Expect(0, 69955, '\p{^Scx=	 CAKM}', "");
Expect(0, 69955, '\P{Scx=	 CAKM}', "");
Expect(1, 69955, '\P{^Scx=	 CAKM}', "");
Expect(0, 69956, '\p{Scx=	 CAKM}', "");
Expect(1, 69956, '\p{^Scx=	 CAKM}', "");
Expect(1, 69956, '\P{Scx=	 CAKM}', "");
Expect(0, 69956, '\P{^Scx=	 CAKM}', "");
Error('\p{Is_Script_Extensions=:=_-chakma}');
Error('\P{Is_Script_Extensions=:=_-chakma}');
Expect(1, 69955, '\p{Is_Script_Extensions=chakma}', "");
Expect(0, 69955, '\p{^Is_Script_Extensions=chakma}', "");
Expect(0, 69955, '\P{Is_Script_Extensions=chakma}', "");
Expect(1, 69955, '\P{^Is_Script_Extensions=chakma}', "");
Expect(0, 69956, '\p{Is_Script_Extensions=chakma}', "");
Expect(1, 69956, '\p{^Is_Script_Extensions=chakma}', "");
Expect(1, 69956, '\P{Is_Script_Extensions=chakma}', "");
Expect(0, 69956, '\P{^Is_Script_Extensions=chakma}', "");
Expect(1, 69955, '\p{Is_Script_Extensions=	_Chakma}', "");
Expect(0, 69955, '\p{^Is_Script_Extensions=	_Chakma}', "");
Expect(0, 69955, '\P{Is_Script_Extensions=	_Chakma}', "");
Expect(1, 69955, '\P{^Is_Script_Extensions=	_Chakma}', "");
Expect(0, 69956, '\p{Is_Script_Extensions=	_Chakma}', "");
Expect(1, 69956, '\p{^Is_Script_Extensions=	_Chakma}', "");
Expect(1, 69956, '\P{Is_Script_Extensions=	_Chakma}', "");
Expect(0, 69956, '\P{^Is_Script_Extensions=	_Chakma}', "");
Error('\p{Is_Scx= :=cakm}');
Error('\P{Is_Scx= :=cakm}');
Expect(1, 69955, '\p{Is_Scx=cakm}', "");
Expect(0, 69955, '\p{^Is_Scx=cakm}', "");
Expect(0, 69955, '\P{Is_Scx=cakm}', "");
Expect(1, 69955, '\P{^Is_Scx=cakm}', "");
Expect(0, 69956, '\p{Is_Scx=cakm}', "");
Expect(1, 69956, '\p{^Is_Scx=cakm}', "");
Expect(1, 69956, '\P{Is_Scx=cakm}', "");
Expect(0, 69956, '\P{^Is_Scx=cakm}', "");
Expect(1, 69955, '\p{Is_Scx=__CAKM}', "");
Expect(0, 69955, '\p{^Is_Scx=__CAKM}', "");
Expect(0, 69955, '\P{Is_Scx=__CAKM}', "");
Expect(1, 69955, '\P{^Is_Scx=__CAKM}', "");
Expect(0, 69956, '\p{Is_Scx=__CAKM}', "");
Expect(1, 69956, '\p{^Is_Scx=__CAKM}', "");
Expect(1, 69956, '\P{Is_Scx=__CAKM}', "");
Expect(0, 69956, '\P{^Is_Scx=__CAKM}', "");
Error('\p{Script_Extensions=	/a/Canadian_Aboriginal}');
Error('\P{Script_Extensions=	/a/Canadian_Aboriginal}');
Expect(1, 6389, '\p{Script_Extensions:   canadianaboriginal}', "");
Expect(0, 6389, '\p{^Script_Extensions:   canadianaboriginal}', "");
Expect(0, 6389, '\P{Script_Extensions:   canadianaboriginal}', "");
Expect(1, 6389, '\P{^Script_Extensions:   canadianaboriginal}', "");
Expect(0, 6390, '\p{Script_Extensions:   canadianaboriginal}', "");
Expect(1, 6390, '\p{^Script_Extensions:   canadianaboriginal}', "");
Expect(1, 6390, '\P{Script_Extensions:   canadianaboriginal}', "");
Expect(0, 6390, '\P{^Script_Extensions:   canadianaboriginal}', "");
Expect(1, 6389, '\p{Script_Extensions=	CANADIAN_ABORIGINAL}', "");
Expect(0, 6389, '\p{^Script_Extensions=	CANADIAN_ABORIGINAL}', "");
Expect(0, 6389, '\P{Script_Extensions=	CANADIAN_ABORIGINAL}', "");
Expect(1, 6389, '\P{^Script_Extensions=	CANADIAN_ABORIGINAL}', "");
Expect(0, 6390, '\p{Script_Extensions=	CANADIAN_ABORIGINAL}', "");
Expect(1, 6390, '\p{^Script_Extensions=	CANADIAN_ABORIGINAL}', "");
Expect(1, 6390, '\P{Script_Extensions=	CANADIAN_ABORIGINAL}', "");
Expect(0, 6390, '\P{^Script_Extensions=	CANADIAN_ABORIGINAL}', "");
Error('\p{Scx=__Cans/a/}');
Error('\P{Scx=__Cans/a/}');
Expect(1, 6389, '\p{Scx=cans}', "");
Expect(0, 6389, '\p{^Scx=cans}', "");
Expect(0, 6389, '\P{Scx=cans}', "");
Expect(1, 6389, '\P{^Scx=cans}', "");
Expect(0, 6390, '\p{Scx=cans}', "");
Expect(1, 6390, '\p{^Scx=cans}', "");
Expect(1, 6390, '\P{Scx=cans}', "");
Expect(0, 6390, '\P{^Scx=cans}', "");
Expect(1, 6389, '\p{Scx= cans}', "");
Expect(0, 6389, '\p{^Scx= cans}', "");
Expect(0, 6389, '\P{Scx= cans}', "");
Expect(1, 6389, '\P{^Scx= cans}', "");
Expect(0, 6390, '\p{Scx= cans}', "");
Expect(1, 6390, '\p{^Scx= cans}', "");
Expect(1, 6390, '\P{Scx= cans}', "");
Expect(0, 6390, '\P{^Scx= cans}', "");
Error('\p{Is_Script_Extensions:    :=CANADIAN_ABORIGINAL}');
Error('\P{Is_Script_Extensions:    :=CANADIAN_ABORIGINAL}');
Expect(1, 6389, '\p{Is_Script_Extensions=canadianaboriginal}', "");
Expect(0, 6389, '\p{^Is_Script_Extensions=canadianaboriginal}', "");
Expect(0, 6389, '\P{Is_Script_Extensions=canadianaboriginal}', "");
Expect(1, 6389, '\P{^Is_Script_Extensions=canadianaboriginal}', "");
Expect(0, 6390, '\p{Is_Script_Extensions=canadianaboriginal}', "");
Expect(1, 6390, '\p{^Is_Script_Extensions=canadianaboriginal}', "");
Expect(1, 6390, '\P{Is_Script_Extensions=canadianaboriginal}', "");
Expect(0, 6390, '\P{^Is_Script_Extensions=canadianaboriginal}', "");
Expect(1, 6389, '\p{Is_Script_Extensions= 	Canadian_Aboriginal}', "");
Expect(0, 6389, '\p{^Is_Script_Extensions= 	Canadian_Aboriginal}', "");
Expect(0, 6389, '\P{Is_Script_Extensions= 	Canadian_Aboriginal}', "");
Expect(1, 6389, '\P{^Is_Script_Extensions= 	Canadian_Aboriginal}', "");
Expect(0, 6390, '\p{Is_Script_Extensions= 	Canadian_Aboriginal}', "");
Expect(1, 6390, '\p{^Is_Script_Extensions= 	Canadian_Aboriginal}', "");
Expect(1, 6390, '\P{Is_Script_Extensions= 	Canadian_Aboriginal}', "");
Expect(0, 6390, '\P{^Is_Script_Extensions= 	Canadian_Aboriginal}', "");
Error('\p{Is_Scx=-CANS/a/}');
Error('\P{Is_Scx=-CANS/a/}');
Expect(1, 6389, '\p{Is_Scx=cans}', "");
Expect(0, 6389, '\p{^Is_Scx=cans}', "");
Expect(0, 6389, '\P{Is_Scx=cans}', "");
Expect(1, 6389, '\P{^Is_Scx=cans}', "");
Expect(0, 6390, '\p{Is_Scx=cans}', "");
Expect(1, 6390, '\p{^Is_Scx=cans}', "");
Expect(1, 6390, '\P{Is_Scx=cans}', "");
Expect(0, 6390, '\P{^Is_Scx=cans}', "");
Expect(1, 6389, '\p{Is_Scx=	 Cans}', "");
Expect(0, 6389, '\p{^Is_Scx=	 Cans}', "");
Expect(0, 6389, '\P{Is_Scx=	 Cans}', "");
Expect(1, 6389, '\P{^Is_Scx=	 Cans}', "");
Expect(0, 6390, '\p{Is_Scx=	 Cans}', "");
Expect(1, 6390, '\p{^Is_Scx=	 Cans}', "");
Expect(1, 6390, '\P{Is_Scx=	 Cans}', "");
Expect(0, 6390, '\P{^Is_Scx=	 Cans}', "");
Error('\p{Script_Extensions= 	Carian/a/}');
Error('\P{Script_Extensions= 	Carian/a/}');
Expect(1, 66256, '\p{Script_Extensions: carian}', "");
Expect(0, 66256, '\p{^Script_Extensions: carian}', "");
Expect(0, 66256, '\P{Script_Extensions: carian}', "");
Expect(1, 66256, '\P{^Script_Extensions: carian}', "");
Expect(0, 66257, '\p{Script_Extensions: carian}', "");
Expect(1, 66257, '\p{^Script_Extensions: carian}', "");
Expect(1, 66257, '\P{Script_Extensions: carian}', "");
Expect(0, 66257, '\P{^Script_Extensions: carian}', "");
Expect(1, 66256, '\p{Script_Extensions:- carian}', "");
Expect(0, 66256, '\p{^Script_Extensions:- carian}', "");
Expect(0, 66256, '\P{Script_Extensions:- carian}', "");
Expect(1, 66256, '\P{^Script_Extensions:- carian}', "");
Expect(0, 66257, '\p{Script_Extensions:- carian}', "");
Expect(1, 66257, '\p{^Script_Extensions:- carian}', "");
Expect(1, 66257, '\P{Script_Extensions:- carian}', "");
Expect(0, 66257, '\P{^Script_Extensions:- carian}', "");
Error('\p{Scx= _CARI:=}');
Error('\P{Scx= _CARI:=}');
Expect(1, 66256, '\p{Scx=cari}', "");
Expect(0, 66256, '\p{^Scx=cari}', "");
Expect(0, 66256, '\P{Scx=cari}', "");
Expect(1, 66256, '\P{^Scx=cari}', "");
Expect(0, 66257, '\p{Scx=cari}', "");
Expect(1, 66257, '\p{^Scx=cari}', "");
Expect(1, 66257, '\P{Scx=cari}', "");
Expect(0, 66257, '\P{^Scx=cari}', "");
Expect(1, 66256, '\p{Scx=_	Cari}', "");
Expect(0, 66256, '\p{^Scx=_	Cari}', "");
Expect(0, 66256, '\P{Scx=_	Cari}', "");
Expect(1, 66256, '\P{^Scx=_	Cari}', "");
Expect(0, 66257, '\p{Scx=_	Cari}', "");
Expect(1, 66257, '\p{^Scx=_	Cari}', "");
Expect(1, 66257, '\P{Scx=_	Cari}', "");
Expect(0, 66257, '\P{^Scx=_	Cari}', "");
Error('\p{Is_Script_Extensions: 	Carian/a/}');
Error('\P{Is_Script_Extensions: 	Carian/a/}');
Expect(1, 66256, '\p{Is_Script_Extensions=carian}', "");
Expect(0, 66256, '\p{^Is_Script_Extensions=carian}', "");
Expect(0, 66256, '\P{Is_Script_Extensions=carian}', "");
Expect(1, 66256, '\P{^Is_Script_Extensions=carian}', "");
Expect(0, 66257, '\p{Is_Script_Extensions=carian}', "");
Expect(1, 66257, '\p{^Is_Script_Extensions=carian}', "");
Expect(1, 66257, '\P{Is_Script_Extensions=carian}', "");
Expect(0, 66257, '\P{^Is_Script_Extensions=carian}', "");
Expect(1, 66256, '\p{Is_Script_Extensions=_Carian}', "");
Expect(0, 66256, '\p{^Is_Script_Extensions=_Carian}', "");
Expect(0, 66256, '\P{Is_Script_Extensions=_Carian}', "");
Expect(1, 66256, '\P{^Is_Script_Extensions=_Carian}', "");
Expect(0, 66257, '\p{Is_Script_Extensions=_Carian}', "");
Expect(1, 66257, '\p{^Is_Script_Extensions=_Carian}', "");
Expect(1, 66257, '\P{Is_Script_Extensions=_Carian}', "");
Expect(0, 66257, '\P{^Is_Script_Extensions=_Carian}', "");
Error('\p{Is_Scx=/a/Cari}');
Error('\P{Is_Scx=/a/Cari}');
Expect(1, 66256, '\p{Is_Scx=cari}', "");
Expect(0, 66256, '\p{^Is_Scx=cari}', "");
Expect(0, 66256, '\P{Is_Scx=cari}', "");
Expect(1, 66256, '\P{^Is_Scx=cari}', "");
Expect(0, 66257, '\p{Is_Scx=cari}', "");
Expect(1, 66257, '\p{^Is_Scx=cari}', "");
Expect(1, 66257, '\P{Is_Scx=cari}', "");
Expect(0, 66257, '\P{^Is_Scx=cari}', "");
Expect(1, 66256, '\p{Is_Scx=_	CARI}', "");
Expect(0, 66256, '\p{^Is_Scx=_	CARI}', "");
Expect(0, 66256, '\P{Is_Scx=_	CARI}', "");
Expect(1, 66256, '\P{^Is_Scx=_	CARI}', "");
Expect(0, 66257, '\p{Is_Scx=_	CARI}', "");
Expect(1, 66257, '\p{^Is_Scx=_	CARI}', "");
Expect(1, 66257, '\P{Is_Scx=_	CARI}', "");
Expect(0, 66257, '\P{^Is_Scx=_	CARI}', "");
Error('\p{Script_Extensions=/a/ _Cham}');
Error('\P{Script_Extensions=/a/ _Cham}');
Expect(1, 43615, '\p{Script_Extensions=cham}', "");
Expect(0, 43615, '\p{^Script_Extensions=cham}', "");
Expect(0, 43615, '\P{Script_Extensions=cham}', "");
Expect(1, 43615, '\P{^Script_Extensions=cham}', "");
Expect(0, 43616, '\p{Script_Extensions=cham}', "");
Expect(1, 43616, '\p{^Script_Extensions=cham}', "");
Expect(1, 43616, '\P{Script_Extensions=cham}', "");
Expect(0, 43616, '\P{^Script_Extensions=cham}', "");
Expect(1, 43615, '\p{Script_Extensions=  Cham}', "");
Expect(0, 43615, '\p{^Script_Extensions=  Cham}', "");
Expect(0, 43615, '\P{Script_Extensions=  Cham}', "");
Expect(1, 43615, '\P{^Script_Extensions=  Cham}', "");
Expect(0, 43616, '\p{Script_Extensions=  Cham}', "");
Expect(1, 43616, '\p{^Script_Extensions=  Cham}', "");
Expect(1, 43616, '\P{Script_Extensions=  Cham}', "");
Expect(0, 43616, '\P{^Script_Extensions=  Cham}', "");
Error('\p{Scx=/a/	-CHAM}');
Error('\P{Scx=/a/	-CHAM}');
Expect(1, 43615, '\p{Scx=cham}', "");
Expect(0, 43615, '\p{^Scx=cham}', "");
Expect(0, 43615, '\P{Scx=cham}', "");
Expect(1, 43615, '\P{^Scx=cham}', "");
Expect(0, 43616, '\p{Scx=cham}', "");
Expect(1, 43616, '\p{^Scx=cham}', "");
Expect(1, 43616, '\P{Scx=cham}', "");
Expect(0, 43616, '\P{^Scx=cham}', "");
Expect(1, 43615, '\p{Scx= CHAM}', "");
Expect(0, 43615, '\p{^Scx= CHAM}', "");
Expect(0, 43615, '\P{Scx= CHAM}', "");
Expect(1, 43615, '\P{^Scx= CHAM}', "");
Expect(0, 43616, '\p{Scx= CHAM}', "");
Expect(1, 43616, '\p{^Scx= CHAM}', "");
Expect(1, 43616, '\P{Scx= CHAM}', "");
Expect(0, 43616, '\P{^Scx= CHAM}', "");
Error('\p{Is_Script_Extensions:   :=-Cham}');
Error('\P{Is_Script_Extensions:   :=-Cham}');
Expect(1, 43615, '\p{Is_Script_Extensions=cham}', "");
Expect(0, 43615, '\p{^Is_Script_Extensions=cham}', "");
Expect(0, 43615, '\P{Is_Script_Extensions=cham}', "");
Expect(1, 43615, '\P{^Is_Script_Extensions=cham}', "");
Expect(0, 43616, '\p{Is_Script_Extensions=cham}', "");
Expect(1, 43616, '\p{^Is_Script_Extensions=cham}', "");
Expect(1, 43616, '\P{Is_Script_Extensions=cham}', "");
Expect(0, 43616, '\P{^Is_Script_Extensions=cham}', "");
Expect(1, 43615, '\p{Is_Script_Extensions=_ Cham}', "");
Expect(0, 43615, '\p{^Is_Script_Extensions=_ Cham}', "");
Expect(0, 43615, '\P{Is_Script_Extensions=_ Cham}', "");
Expect(1, 43615, '\P{^Is_Script_Extensions=_ Cham}', "");
Expect(0, 43616, '\p{Is_Script_Extensions=_ Cham}', "");
Expect(1, 43616, '\p{^Is_Script_Extensions=_ Cham}', "");
Expect(1, 43616, '\P{Is_Script_Extensions=_ Cham}', "");
Expect(0, 43616, '\P{^Is_Script_Extensions=_ Cham}', "");
Error('\p{Is_Scx=	:=Cham}');
Error('\P{Is_Scx=	:=Cham}');
Expect(1, 43615, '\p{Is_Scx=cham}', "");
Expect(0, 43615, '\p{^Is_Scx=cham}', "");
Expect(0, 43615, '\P{Is_Scx=cham}', "");
Expect(1, 43615, '\P{^Is_Scx=cham}', "");
Expect(0, 43616, '\p{Is_Scx=cham}', "");
Expect(1, 43616, '\p{^Is_Scx=cham}', "");
Expect(1, 43616, '\P{Is_Scx=cham}', "");
Expect(0, 43616, '\P{^Is_Scx=cham}', "");
Expect(1, 43615, '\p{Is_Scx:		_Cham}', "");
Expect(0, 43615, '\p{^Is_Scx:		_Cham}', "");
Expect(0, 43615, '\P{Is_Scx:		_Cham}', "");
Expect(1, 43615, '\P{^Is_Scx:		_Cham}', "");
Expect(0, 43616, '\p{Is_Scx:		_Cham}', "");
Expect(1, 43616, '\p{^Is_Scx:		_Cham}', "");
Expect(1, 43616, '\P{Is_Scx:		_Cham}', "");
Expect(0, 43616, '\P{^Is_Scx:		_Cham}', "");
Error('\p{Script_Extensions=/a/ 	CHEROKEE}');
Error('\P{Script_Extensions=/a/ 	CHEROKEE}');
Expect(1, 5108, '\p{Script_Extensions=cherokee}', "");
Expect(0, 5108, '\p{^Script_Extensions=cherokee}', "");
Expect(0, 5108, '\P{Script_Extensions=cherokee}', "");
Expect(1, 5108, '\P{^Script_Extensions=cherokee}', "");
Expect(0, 5109, '\p{Script_Extensions=cherokee}', "");
Expect(1, 5109, '\p{^Script_Extensions=cherokee}', "");
Expect(1, 5109, '\P{Script_Extensions=cherokee}', "");
Expect(0, 5109, '\P{^Script_Extensions=cherokee}', "");
Expect(1, 5108, '\p{Script_Extensions=_-cherokee}', "");
Expect(0, 5108, '\p{^Script_Extensions=_-cherokee}', "");
Expect(0, 5108, '\P{Script_Extensions=_-cherokee}', "");
Expect(1, 5108, '\P{^Script_Extensions=_-cherokee}', "");
Expect(0, 5109, '\p{Script_Extensions=_-cherokee}', "");
Expect(1, 5109, '\p{^Script_Extensions=_-cherokee}', "");
Expect(1, 5109, '\P{Script_Extensions=_-cherokee}', "");
Expect(0, 5109, '\P{^Script_Extensions=_-cherokee}', "");
Error('\p{Scx=:=	_CHER}');
Error('\P{Scx=:=	_CHER}');
Expect(1, 5108, '\p{Scx=cher}', "");
Expect(0, 5108, '\p{^Scx=cher}', "");
Expect(0, 5108, '\P{Scx=cher}', "");
Expect(1, 5108, '\P{^Scx=cher}', "");
Expect(0, 5109, '\p{Scx=cher}', "");
Expect(1, 5109, '\p{^Scx=cher}', "");
Expect(1, 5109, '\P{Scx=cher}', "");
Expect(0, 5109, '\P{^Scx=cher}', "");
Expect(1, 5108, '\p{Scx=-Cher}', "");
Expect(0, 5108, '\p{^Scx=-Cher}', "");
Expect(0, 5108, '\P{Scx=-Cher}', "");
Expect(1, 5108, '\P{^Scx=-Cher}', "");
Expect(0, 5109, '\p{Scx=-Cher}', "");
Expect(1, 5109, '\p{^Scx=-Cher}', "");
Expect(1, 5109, '\P{Scx=-Cher}', "");
Expect(0, 5109, '\P{^Scx=-Cher}', "");
Error('\p{Is_Script_Extensions:   - Cherokee:=}');
Error('\P{Is_Script_Extensions:   - Cherokee:=}');
Expect(1, 5108, '\p{Is_Script_Extensions=cherokee}', "");
Expect(0, 5108, '\p{^Is_Script_Extensions=cherokee}', "");
Expect(0, 5108, '\P{Is_Script_Extensions=cherokee}', "");
Expect(1, 5108, '\P{^Is_Script_Extensions=cherokee}', "");
Expect(0, 5109, '\p{Is_Script_Extensions=cherokee}', "");
Expect(1, 5109, '\p{^Is_Script_Extensions=cherokee}', "");
Expect(1, 5109, '\P{Is_Script_Extensions=cherokee}', "");
Expect(0, 5109, '\P{^Is_Script_Extensions=cherokee}', "");
Expect(1, 5108, '\p{Is_Script_Extensions: Cherokee}', "");
Expect(0, 5108, '\p{^Is_Script_Extensions: Cherokee}', "");
Expect(0, 5108, '\P{Is_Script_Extensions: Cherokee}', "");
Expect(1, 5108, '\P{^Is_Script_Extensions: Cherokee}', "");
Expect(0, 5109, '\p{Is_Script_Extensions: Cherokee}', "");
Expect(1, 5109, '\p{^Is_Script_Extensions: Cherokee}', "");
Expect(1, 5109, '\P{Is_Script_Extensions: Cherokee}', "");
Expect(0, 5109, '\P{^Is_Script_Extensions: Cherokee}', "");
Error('\p{Is_Scx=:=CHER}');
Error('\P{Is_Scx=:=CHER}');
Expect(1, 5108, '\p{Is_Scx=cher}', "");
Expect(0, 5108, '\p{^Is_Scx=cher}', "");
Expect(0, 5108, '\P{Is_Scx=cher}', "");
Expect(1, 5108, '\P{^Is_Scx=cher}', "");
Expect(0, 5109, '\p{Is_Scx=cher}', "");
Expect(1, 5109, '\p{^Is_Scx=cher}', "");
Expect(1, 5109, '\P{Is_Scx=cher}', "");
Expect(0, 5109, '\P{^Is_Scx=cher}', "");
Expect(1, 5108, '\p{Is_Scx= Cher}', "");
Expect(0, 5108, '\p{^Is_Scx= Cher}', "");
Expect(0, 5108, '\P{Is_Scx= Cher}', "");
Expect(1, 5108, '\P{^Is_Scx= Cher}', "");
Expect(0, 5109, '\p{Is_Scx= Cher}', "");
Expect(1, 5109, '\p{^Is_Scx= Cher}', "");
Expect(1, 5109, '\P{Is_Scx= Cher}', "");
Expect(0, 5109, '\P{^Is_Scx= Cher}', "");
Error('\p{Script_Extensions=:= 	coptic}');
Error('\P{Script_Extensions=:= 	coptic}');
Expect(1, 11519, '\p{Script_Extensions=coptic}', "");
Expect(0, 11519, '\p{^Script_Extensions=coptic}', "");
Expect(0, 11519, '\P{Script_Extensions=coptic}', "");
Expect(1, 11519, '\P{^Script_Extensions=coptic}', "");
Expect(0, 11520, '\p{Script_Extensions=coptic}', "");
Expect(1, 11520, '\p{^Script_Extensions=coptic}', "");
Expect(1, 11520, '\P{Script_Extensions=coptic}', "");
Expect(0, 11520, '\P{^Script_Extensions=coptic}', "");
Expect(1, 11519, '\p{Script_Extensions:    -Coptic}', "");
Expect(0, 11519, '\p{^Script_Extensions:    -Coptic}', "");
Expect(0, 11519, '\P{Script_Extensions:    -Coptic}', "");
Expect(1, 11519, '\P{^Script_Extensions:    -Coptic}', "");
Expect(0, 11520, '\p{Script_Extensions:    -Coptic}', "");
Expect(1, 11520, '\p{^Script_Extensions:    -Coptic}', "");
Expect(1, 11520, '\P{Script_Extensions:    -Coptic}', "");
Expect(0, 11520, '\P{^Script_Extensions:    -Coptic}', "");
Error('\p{Scx:   --copt:=}');
Error('\P{Scx:   --copt:=}');
Expect(1, 11519, '\p{Scx=copt}', "");
Expect(0, 11519, '\p{^Scx=copt}', "");
Expect(0, 11519, '\P{Scx=copt}', "");
Expect(1, 11519, '\P{^Scx=copt}', "");
Expect(0, 11520, '\p{Scx=copt}', "");
Expect(1, 11520, '\p{^Scx=copt}', "");
Expect(1, 11520, '\P{Scx=copt}', "");
Expect(0, 11520, '\P{^Scx=copt}', "");
Error('\p{Is_Script_Extensions= 	Qaac:=}');
Error('\P{Is_Script_Extensions= 	Qaac:=}');
Expect(1, 11519, '\p{Is_Script_Extensions=qaac}', "");
Expect(0, 11519, '\p{^Is_Script_Extensions=qaac}', "");
Expect(0, 11519, '\P{Is_Script_Extensions=qaac}', "");
Expect(1, 11519, '\P{^Is_Script_Extensions=qaac}', "");
Expect(0, 11520, '\p{Is_Script_Extensions=qaac}', "");
Expect(1, 11520, '\p{^Is_Script_Extensions=qaac}', "");
Expect(1, 11520, '\P{Is_Script_Extensions=qaac}', "");
Expect(0, 11520, '\P{^Is_Script_Extensions=qaac}', "");
Expect(1, 11519, '\p{Is_Script_Extensions=Qaac}', "");
Expect(0, 11519, '\p{^Is_Script_Extensions=Qaac}', "");
Expect(0, 11519, '\P{Is_Script_Extensions=Qaac}', "");
Expect(1, 11519, '\P{^Is_Script_Extensions=Qaac}', "");
Expect(0, 11520, '\p{Is_Script_Extensions=Qaac}', "");
Expect(1, 11520, '\p{^Is_Script_Extensions=Qaac}', "");
Expect(1, 11520, '\P{Is_Script_Extensions=Qaac}', "");
Expect(0, 11520, '\P{^Is_Script_Extensions=Qaac}', "");
Error('\p{Is_Scx=-:=coptic}');
Error('\P{Is_Scx=-:=coptic}');
Expect(1, 11519, '\p{Is_Scx=coptic}', "");
Expect(0, 11519, '\p{^Is_Scx=coptic}', "");
Expect(0, 11519, '\P{Is_Scx=coptic}', "");
Expect(1, 11519, '\P{^Is_Scx=coptic}', "");
Expect(0, 11520, '\p{Is_Scx=coptic}', "");
Expect(1, 11520, '\p{^Is_Scx=coptic}', "");
Expect(1, 11520, '\P{Is_Scx=coptic}', "");
Expect(0, 11520, '\P{^Is_Scx=coptic}', "");
Expect(1, 11519, '\p{Is_Scx=  coptic}', "");
Expect(0, 11519, '\p{^Is_Scx=  coptic}', "");
Expect(0, 11519, '\P{Is_Scx=  coptic}', "");
Expect(1, 11519, '\P{^Is_Scx=  coptic}', "");
Expect(0, 11520, '\p{Is_Scx=  coptic}', "");
Expect(1, 11520, '\p{^Is_Scx=  coptic}', "");
Expect(1, 11520, '\P{Is_Scx=  coptic}', "");
Expect(0, 11520, '\P{^Is_Scx=  coptic}', "");
Error('\p{Script_Extensions=-/a/Cypriot}');
Error('\P{Script_Extensions=-/a/Cypriot}');
Expect(1, 67647, '\p{Script_Extensions=cypriot}', "");
Expect(0, 67647, '\p{^Script_Extensions=cypriot}', "");
Expect(0, 67647, '\P{Script_Extensions=cypriot}', "");
Expect(1, 67647, '\P{^Script_Extensions=cypriot}', "");
Expect(0, 67648, '\p{Script_Extensions=cypriot}', "");
Expect(1, 67648, '\p{^Script_Extensions=cypriot}', "");
Expect(1, 67648, '\P{Script_Extensions=cypriot}', "");
Expect(0, 67648, '\P{^Script_Extensions=cypriot}', "");
Expect(1, 67647, '\p{Script_Extensions=-_Cypriot}', "");
Expect(0, 67647, '\p{^Script_Extensions=-_Cypriot}', "");
Expect(0, 67647, '\P{Script_Extensions=-_Cypriot}', "");
Expect(1, 67647, '\P{^Script_Extensions=-_Cypriot}', "");
Expect(0, 67648, '\p{Script_Extensions=-_Cypriot}', "");
Expect(1, 67648, '\p{^Script_Extensions=-_Cypriot}', "");
Expect(1, 67648, '\P{Script_Extensions=-_Cypriot}', "");
Expect(0, 67648, '\P{^Script_Extensions=-_Cypriot}', "");
Error('\p{Scx=	Cprt/a/}');
Error('\P{Scx=	Cprt/a/}');
Expect(1, 67647, '\p{Scx=cprt}', "");
Expect(0, 67647, '\p{^Scx=cprt}', "");
Expect(0, 67647, '\P{Scx=cprt}', "");
Expect(1, 67647, '\P{^Scx=cprt}', "");
Expect(0, 67648, '\p{Scx=cprt}', "");
Expect(1, 67648, '\p{^Scx=cprt}', "");
Expect(1, 67648, '\P{Scx=cprt}', "");
Expect(0, 67648, '\P{^Scx=cprt}', "");
Expect(1, 67647, '\p{Scx= Cprt}', "");
Expect(0, 67647, '\p{^Scx= Cprt}', "");
Expect(0, 67647, '\P{Scx= Cprt}', "");
Expect(1, 67647, '\P{^Scx= Cprt}', "");
Expect(0, 67648, '\p{Scx= Cprt}', "");
Expect(1, 67648, '\p{^Scx= Cprt}', "");
Expect(1, 67648, '\P{Scx= Cprt}', "");
Expect(0, 67648, '\P{^Scx= Cprt}', "");
Error('\p{Is_Script_Extensions=:=-CYPRIOT}');
Error('\P{Is_Script_Extensions=:=-CYPRIOT}');
Expect(1, 67647, '\p{Is_Script_Extensions=cypriot}', "");
Expect(0, 67647, '\p{^Is_Script_Extensions=cypriot}', "");
Expect(0, 67647, '\P{Is_Script_Extensions=cypriot}', "");
Expect(1, 67647, '\P{^Is_Script_Extensions=cypriot}', "");
Expect(0, 67648, '\p{Is_Script_Extensions=cypriot}', "");
Expect(1, 67648, '\p{^Is_Script_Extensions=cypriot}', "");
Expect(1, 67648, '\P{Is_Script_Extensions=cypriot}', "");
Expect(0, 67648, '\P{^Is_Script_Extensions=cypriot}', "");
Expect(1, 67647, '\p{Is_Script_Extensions=-Cypriot}', "");
Expect(0, 67647, '\p{^Is_Script_Extensions=-Cypriot}', "");
Expect(0, 67647, '\P{Is_Script_Extensions=-Cypriot}', "");
Expect(1, 67647, '\P{^Is_Script_Extensions=-Cypriot}', "");
Expect(0, 67648, '\p{Is_Script_Extensions=-Cypriot}', "");
Expect(1, 67648, '\p{^Is_Script_Extensions=-Cypriot}', "");
Expect(1, 67648, '\P{Is_Script_Extensions=-Cypriot}', "");
Expect(0, 67648, '\P{^Is_Script_Extensions=-Cypriot}', "");
Error('\p{Is_Scx=		Cprt/a/}');
Error('\P{Is_Scx=		Cprt/a/}');
Expect(1, 67647, '\p{Is_Scx=cprt}', "");
Expect(0, 67647, '\p{^Is_Scx=cprt}', "");
Expect(0, 67647, '\P{Is_Scx=cprt}', "");
Expect(1, 67647, '\P{^Is_Scx=cprt}', "");
Expect(0, 67648, '\p{Is_Scx=cprt}', "");
Expect(1, 67648, '\p{^Is_Scx=cprt}', "");
Expect(1, 67648, '\P{Is_Scx=cprt}', "");
Expect(0, 67648, '\P{^Is_Scx=cprt}', "");
Expect(1, 67647, '\p{Is_Scx=	-CPRT}', "");
Expect(0, 67647, '\p{^Is_Scx=	-CPRT}', "");
Expect(0, 67647, '\P{Is_Scx=	-CPRT}', "");
Expect(1, 67647, '\P{^Is_Scx=	-CPRT}', "");
Expect(0, 67648, '\p{Is_Scx=	-CPRT}', "");
Expect(1, 67648, '\p{^Is_Scx=	-CPRT}', "");
Expect(1, 67648, '\P{Is_Scx=	-CPRT}', "");
Expect(0, 67648, '\P{^Is_Scx=	-CPRT}', "");
Error('\p{Script_Extensions::=	_cyrillic}');
Error('\P{Script_Extensions::=	_cyrillic}');
Expect(1, 42655, '\p{Script_Extensions=cyrillic}', "");
Expect(0, 42655, '\p{^Script_Extensions=cyrillic}', "");
Expect(0, 42655, '\P{Script_Extensions=cyrillic}', "");
Expect(1, 42655, '\P{^Script_Extensions=cyrillic}', "");
Expect(0, 42656, '\p{Script_Extensions=cyrillic}', "");
Expect(1, 42656, '\p{^Script_Extensions=cyrillic}', "");
Expect(1, 42656, '\P{Script_Extensions=cyrillic}', "");
Expect(0, 42656, '\P{^Script_Extensions=cyrillic}', "");
Expect(1, 42655, '\p{Script_Extensions=	CYRILLIC}', "");
Expect(0, 42655, '\p{^Script_Extensions=	CYRILLIC}', "");
Expect(0, 42655, '\P{Script_Extensions=	CYRILLIC}', "");
Expect(1, 42655, '\P{^Script_Extensions=	CYRILLIC}', "");
Expect(0, 42656, '\p{Script_Extensions=	CYRILLIC}', "");
Expect(1, 42656, '\p{^Script_Extensions=	CYRILLIC}', "");
Expect(1, 42656, '\P{Script_Extensions=	CYRILLIC}', "");
Expect(0, 42656, '\P{^Script_Extensions=	CYRILLIC}', "");
Error('\p{Scx=	/a/Cyrl}');
Error('\P{Scx=	/a/Cyrl}');
Expect(1, 42655, '\p{Scx=cyrl}', "");
Expect(0, 42655, '\p{^Scx=cyrl}', "");
Expect(0, 42655, '\P{Scx=cyrl}', "");
Expect(1, 42655, '\P{^Scx=cyrl}', "");
Expect(0, 42656, '\p{Scx=cyrl}', "");
Expect(1, 42656, '\p{^Scx=cyrl}', "");
Expect(1, 42656, '\P{Scx=cyrl}', "");
Expect(0, 42656, '\P{^Scx=cyrl}', "");
Expect(1, 42655, '\p{Scx=	CYRL}', "");
Expect(0, 42655, '\p{^Scx=	CYRL}', "");
Expect(0, 42655, '\P{Scx=	CYRL}', "");
Expect(1, 42655, '\P{^Scx=	CYRL}', "");
Expect(0, 42656, '\p{Scx=	CYRL}', "");
Expect(1, 42656, '\p{^Scx=	CYRL}', "");
Expect(1, 42656, '\P{Scx=	CYRL}', "");
Expect(0, 42656, '\P{^Scx=	CYRL}', "");
Error('\p{Is_Script_Extensions=:= _cyrillic}');
Error('\P{Is_Script_Extensions=:= _cyrillic}');
Expect(1, 42655, '\p{Is_Script_Extensions=cyrillic}', "");
Expect(0, 42655, '\p{^Is_Script_Extensions=cyrillic}', "");
Expect(0, 42655, '\P{Is_Script_Extensions=cyrillic}', "");
Expect(1, 42655, '\P{^Is_Script_Extensions=cyrillic}', "");
Expect(0, 42656, '\p{Is_Script_Extensions=cyrillic}', "");
Expect(1, 42656, '\p{^Is_Script_Extensions=cyrillic}', "");
Expect(1, 42656, '\P{Is_Script_Extensions=cyrillic}', "");
Expect(0, 42656, '\P{^Is_Script_Extensions=cyrillic}', "");
Expect(1, 42655, '\p{Is_Script_Extensions= 	cyrillic}', "");
Expect(0, 42655, '\p{^Is_Script_Extensions= 	cyrillic}', "");
Expect(0, 42655, '\P{Is_Script_Extensions= 	cyrillic}', "");
Expect(1, 42655, '\P{^Is_Script_Extensions= 	cyrillic}', "");
Expect(0, 42656, '\p{Is_Script_Extensions= 	cyrillic}', "");
Expect(1, 42656, '\p{^Is_Script_Extensions= 	cyrillic}', "");
Expect(1, 42656, '\P{Is_Script_Extensions= 	cyrillic}', "");
Expect(0, 42656, '\P{^Is_Script_Extensions= 	cyrillic}', "");
Error('\p{Is_Scx:   :=-	CYRL}');
Error('\P{Is_Scx:   :=-	CYRL}');
Expect(1, 42655, '\p{Is_Scx:	cyrl}', "");
Expect(0, 42655, '\p{^Is_Scx:	cyrl}', "");
Expect(0, 42655, '\P{Is_Scx:	cyrl}', "");
Expect(1, 42655, '\P{^Is_Scx:	cyrl}', "");
Expect(0, 42656, '\p{Is_Scx:	cyrl}', "");
Expect(1, 42656, '\p{^Is_Scx:	cyrl}', "");
Expect(1, 42656, '\P{Is_Scx:	cyrl}', "");
Expect(0, 42656, '\P{^Is_Scx:	cyrl}', "");
Expect(1, 42655, '\p{Is_Scx=	_Cyrl}', "");
Expect(0, 42655, '\p{^Is_Scx=	_Cyrl}', "");
Expect(0, 42655, '\P{Is_Scx=	_Cyrl}', "");
Expect(1, 42655, '\P{^Is_Scx=	_Cyrl}', "");
Expect(0, 42656, '\p{Is_Scx=	_Cyrl}', "");
Expect(1, 42656, '\p{^Is_Scx=	_Cyrl}', "");
Expect(1, 42656, '\P{Is_Scx=	_Cyrl}', "");
Expect(0, 42656, '\P{^Is_Scx=	_Cyrl}', "");
Error('\p{Script_Extensions=-:=Devanagari}');
Error('\P{Script_Extensions=-:=Devanagari}');
Expect(1, 43259, '\p{Script_Extensions: devanagari}', "");
Expect(0, 43259, '\p{^Script_Extensions: devanagari}', "");
Expect(0, 43259, '\P{Script_Extensions: devanagari}', "");
Expect(1, 43259, '\P{^Script_Extensions: devanagari}', "");
Expect(0, 43260, '\p{Script_Extensions: devanagari}', "");
Expect(1, 43260, '\p{^Script_Extensions: devanagari}', "");
Expect(1, 43260, '\P{Script_Extensions: devanagari}', "");
Expect(0, 43260, '\P{^Script_Extensions: devanagari}', "");
Expect(1, 43259, '\p{Script_Extensions=_ DEVANAGARI}', "");
Expect(0, 43259, '\p{^Script_Extensions=_ DEVANAGARI}', "");
Expect(0, 43259, '\P{Script_Extensions=_ DEVANAGARI}', "");
Expect(1, 43259, '\P{^Script_Extensions=_ DEVANAGARI}', "");
Expect(0, 43260, '\p{Script_Extensions=_ DEVANAGARI}', "");
Expect(1, 43260, '\p{^Script_Extensions=_ DEVANAGARI}', "");
Expect(1, 43260, '\P{Script_Extensions=_ DEVANAGARI}', "");
Expect(0, 43260, '\P{^Script_Extensions=_ DEVANAGARI}', "");
Error('\p{Scx=_/a/Deva}');
Error('\P{Scx=_/a/Deva}');
Expect(1, 43259, '\p{Scx=deva}', "");
Expect(0, 43259, '\p{^Scx=deva}', "");
Expect(0, 43259, '\P{Scx=deva}', "");
Expect(1, 43259, '\P{^Scx=deva}', "");
Expect(0, 43260, '\p{Scx=deva}', "");
Expect(1, 43260, '\p{^Scx=deva}', "");
Expect(1, 43260, '\P{Scx=deva}', "");
Expect(0, 43260, '\P{^Scx=deva}', "");
Expect(1, 43259, '\p{Scx=  deva}', "");
Expect(0, 43259, '\p{^Scx=  deva}', "");
Expect(0, 43259, '\P{Scx=  deva}', "");
Expect(1, 43259, '\P{^Scx=  deva}', "");
Expect(0, 43260, '\p{Scx=  deva}', "");
Expect(1, 43260, '\p{^Scx=  deva}', "");
Expect(1, 43260, '\P{Scx=  deva}', "");
Expect(0, 43260, '\P{^Scx=  deva}', "");
Error('\p{Is_Script_Extensions=_	DEVANAGARI:=}');
Error('\P{Is_Script_Extensions=_	DEVANAGARI:=}');
Expect(1, 43259, '\p{Is_Script_Extensions:devanagari}', "");
Expect(0, 43259, '\p{^Is_Script_Extensions:devanagari}', "");
Expect(0, 43259, '\P{Is_Script_Extensions:devanagari}', "");
Expect(1, 43259, '\P{^Is_Script_Extensions:devanagari}', "");
Expect(0, 43260, '\p{Is_Script_Extensions:devanagari}', "");
Expect(1, 43260, '\p{^Is_Script_Extensions:devanagari}', "");
Expect(1, 43260, '\P{Is_Script_Extensions:devanagari}', "");
Expect(0, 43260, '\P{^Is_Script_Extensions:devanagari}', "");
Expect(1, 43259, '\p{Is_Script_Extensions=_	Devanagari}', "");
Expect(0, 43259, '\p{^Is_Script_Extensions=_	Devanagari}', "");
Expect(0, 43259, '\P{Is_Script_Extensions=_	Devanagari}', "");
Expect(1, 43259, '\P{^Is_Script_Extensions=_	Devanagari}', "");
Expect(0, 43260, '\p{Is_Script_Extensions=_	Devanagari}', "");
Expect(1, 43260, '\p{^Is_Script_Extensions=_	Devanagari}', "");
Expect(1, 43260, '\P{Is_Script_Extensions=_	Devanagari}', "");
Expect(0, 43260, '\P{^Is_Script_Extensions=_	Devanagari}', "");
Error('\p{Is_Scx=	:=deva}');
Error('\P{Is_Scx=	:=deva}');
Expect(1, 43259, '\p{Is_Scx=deva}', "");
Expect(0, 43259, '\p{^Is_Scx=deva}', "");
Expect(0, 43259, '\P{Is_Scx=deva}', "");
Expect(1, 43259, '\P{^Is_Scx=deva}', "");
Expect(0, 43260, '\p{Is_Scx=deva}', "");
Expect(1, 43260, '\p{^Is_Scx=deva}', "");
Expect(1, 43260, '\P{Is_Scx=deva}', "");
Expect(0, 43260, '\P{^Is_Scx=deva}', "");
Expect(1, 43259, '\p{Is_Scx=_-DEVA}', "");
Expect(0, 43259, '\p{^Is_Scx=_-DEVA}', "");
Expect(0, 43259, '\P{Is_Scx=_-DEVA}', "");
Expect(1, 43259, '\P{^Is_Scx=_-DEVA}', "");
Expect(0, 43260, '\p{Is_Scx=_-DEVA}', "");
Expect(1, 43260, '\p{^Is_Scx=_-DEVA}', "");
Expect(1, 43260, '\P{Is_Scx=_-DEVA}', "");
Expect(0, 43260, '\P{^Is_Scx=_-DEVA}', "");
Error('\p{Script_Extensions=/a/_Deseret}');
Error('\P{Script_Extensions=/a/_Deseret}');
Expect(1, 66639, '\p{Script_Extensions=deseret}', "");
Expect(0, 66639, '\p{^Script_Extensions=deseret}', "");
Expect(0, 66639, '\P{Script_Extensions=deseret}', "");
Expect(1, 66639, '\P{^Script_Extensions=deseret}', "");
Expect(0, 66640, '\p{Script_Extensions=deseret}', "");
Expect(1, 66640, '\p{^Script_Extensions=deseret}', "");
Expect(1, 66640, '\P{Script_Extensions=deseret}', "");
Expect(0, 66640, '\P{^Script_Extensions=deseret}', "");
Expect(1, 66639, '\p{Script_Extensions=-Deseret}', "");
Expect(0, 66639, '\p{^Script_Extensions=-Deseret}', "");
Expect(0, 66639, '\P{Script_Extensions=-Deseret}', "");
Expect(1, 66639, '\P{^Script_Extensions=-Deseret}', "");
Expect(0, 66640, '\p{Script_Extensions=-Deseret}', "");
Expect(1, 66640, '\p{^Script_Extensions=-Deseret}', "");
Expect(1, 66640, '\P{Script_Extensions=-Deseret}', "");
Expect(0, 66640, '\P{^Script_Extensions=-Deseret}', "");
Error('\p{Scx=		Dsrt:=}');
Error('\P{Scx=		Dsrt:=}');
Expect(1, 66639, '\p{Scx=dsrt}', "");
Expect(0, 66639, '\p{^Scx=dsrt}', "");
Expect(0, 66639, '\P{Scx=dsrt}', "");
Expect(1, 66639, '\P{^Scx=dsrt}', "");
Expect(0, 66640, '\p{Scx=dsrt}', "");
Expect(1, 66640, '\p{^Scx=dsrt}', "");
Expect(1, 66640, '\P{Scx=dsrt}', "");
Expect(0, 66640, '\P{^Scx=dsrt}', "");
Expect(1, 66639, '\p{Scx=_dsrt}', "");
Expect(0, 66639, '\p{^Scx=_dsrt}', "");
Expect(0, 66639, '\P{Scx=_dsrt}', "");
Expect(1, 66639, '\P{^Scx=_dsrt}', "");
Expect(0, 66640, '\p{Scx=_dsrt}', "");
Expect(1, 66640, '\p{^Scx=_dsrt}', "");
Expect(1, 66640, '\P{Scx=_dsrt}', "");
Expect(0, 66640, '\P{^Scx=_dsrt}', "");
Error('\p{Is_Script_Extensions= /a/DESERET}');
Error('\P{Is_Script_Extensions= /a/DESERET}');
Expect(1, 66639, '\p{Is_Script_Extensions=deseret}', "");
Expect(0, 66639, '\p{^Is_Script_Extensions=deseret}', "");
Expect(0, 66639, '\P{Is_Script_Extensions=deseret}', "");
Expect(1, 66639, '\P{^Is_Script_Extensions=deseret}', "");
Expect(0, 66640, '\p{Is_Script_Extensions=deseret}', "");
Expect(1, 66640, '\p{^Is_Script_Extensions=deseret}', "");
Expect(1, 66640, '\P{Is_Script_Extensions=deseret}', "");
Expect(0, 66640, '\P{^Is_Script_Extensions=deseret}', "");
Expect(1, 66639, '\p{Is_Script_Extensions=-	Deseret}', "");
Expect(0, 66639, '\p{^Is_Script_Extensions=-	Deseret}', "");
Expect(0, 66639, '\P{Is_Script_Extensions=-	Deseret}', "");
Expect(1, 66639, '\P{^Is_Script_Extensions=-	Deseret}', "");
Expect(0, 66640, '\p{Is_Script_Extensions=-	Deseret}', "");
Expect(1, 66640, '\p{^Is_Script_Extensions=-	Deseret}', "");
Expect(1, 66640, '\P{Is_Script_Extensions=-	Deseret}', "");
Expect(0, 66640, '\P{^Is_Script_Extensions=-	Deseret}', "");
Error('\p{Is_Scx=/a/Dsrt}');
Error('\P{Is_Scx=/a/Dsrt}');
Expect(1, 66639, '\p{Is_Scx=dsrt}', "");
Expect(0, 66639, '\p{^Is_Scx=dsrt}', "");
Expect(0, 66639, '\P{Is_Scx=dsrt}', "");
Expect(1, 66639, '\P{^Is_Scx=dsrt}', "");
Expect(0, 66640, '\p{Is_Scx=dsrt}', "");
Expect(1, 66640, '\p{^Is_Scx=dsrt}', "");
Expect(1, 66640, '\P{Is_Scx=dsrt}', "");
Expect(0, 66640, '\P{^Is_Scx=dsrt}', "");
Expect(1, 66639, '\p{Is_Scx=		dsrt}', "");
Expect(0, 66639, '\p{^Is_Scx=		dsrt}', "");
Expect(0, 66639, '\P{Is_Scx=		dsrt}', "");
Expect(1, 66639, '\P{^Is_Scx=		dsrt}', "");
Expect(0, 66640, '\p{Is_Scx=		dsrt}', "");
Expect(1, 66640, '\p{^Is_Scx=		dsrt}', "");
Expect(1, 66640, '\P{Is_Scx=		dsrt}', "");
Expect(0, 66640, '\P{^Is_Scx=		dsrt}', "");
Error('\p{Script_Extensions=__EGYPTIAN_Hieroglyphs/a/}');
Error('\P{Script_Extensions=__EGYPTIAN_Hieroglyphs/a/}');
Expect(1, 78894, '\p{Script_Extensions=egyptianhieroglyphs}', "");
Expect(0, 78894, '\p{^Script_Extensions=egyptianhieroglyphs}', "");
Expect(0, 78894, '\P{Script_Extensions=egyptianhieroglyphs}', "");
Expect(1, 78894, '\P{^Script_Extensions=egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{Script_Extensions=egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{^Script_Extensions=egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{Script_Extensions=egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{^Script_Extensions=egyptianhieroglyphs}', "");
Expect(1, 78894, '\p{Script_Extensions= Egyptian_Hieroglyphs}', "");
Expect(0, 78894, '\p{^Script_Extensions= Egyptian_Hieroglyphs}', "");
Expect(0, 78894, '\P{Script_Extensions= Egyptian_Hieroglyphs}', "");
Expect(1, 78894, '\P{^Script_Extensions= Egyptian_Hieroglyphs}', "");
Expect(0, 78895, '\p{Script_Extensions= Egyptian_Hieroglyphs}', "");
Expect(1, 78895, '\p{^Script_Extensions= Egyptian_Hieroglyphs}', "");
Expect(1, 78895, '\P{Script_Extensions= Egyptian_Hieroglyphs}', "");
Expect(0, 78895, '\P{^Script_Extensions= Egyptian_Hieroglyphs}', "");
Error('\p{Scx:   :=		EGYP}');
Error('\P{Scx:   :=		EGYP}');
Expect(1, 78894, '\p{Scx=egyp}', "");
Expect(0, 78894, '\p{^Scx=egyp}', "");
Expect(0, 78894, '\P{Scx=egyp}', "");
Expect(1, 78894, '\P{^Scx=egyp}', "");
Expect(0, 78895, '\p{Scx=egyp}', "");
Expect(1, 78895, '\p{^Scx=egyp}', "");
Expect(1, 78895, '\P{Scx=egyp}', "");
Expect(0, 78895, '\P{^Scx=egyp}', "");
Expect(1, 78894, '\p{Scx=	Egyp}', "");
Expect(0, 78894, '\p{^Scx=	Egyp}', "");
Expect(0, 78894, '\P{Scx=	Egyp}', "");
Expect(1, 78894, '\P{^Scx=	Egyp}', "");
Expect(0, 78895, '\p{Scx=	Egyp}', "");
Expect(1, 78895, '\p{^Scx=	Egyp}', "");
Expect(1, 78895, '\P{Scx=	Egyp}', "");
Expect(0, 78895, '\P{^Scx=	Egyp}', "");
Error('\p{Is_Script_Extensions=/a/	_EGYPTIAN_Hieroglyphs}');
Error('\P{Is_Script_Extensions=/a/	_EGYPTIAN_Hieroglyphs}');
Expect(1, 78894, '\p{Is_Script_Extensions=egyptianhieroglyphs}', "");
Expect(0, 78894, '\p{^Is_Script_Extensions=egyptianhieroglyphs}', "");
Expect(0, 78894, '\P{Is_Script_Extensions=egyptianhieroglyphs}', "");
Expect(1, 78894, '\P{^Is_Script_Extensions=egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{Is_Script_Extensions=egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{^Is_Script_Extensions=egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{Is_Script_Extensions=egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{^Is_Script_Extensions=egyptianhieroglyphs}', "");
Expect(1, 78894, '\p{Is_Script_Extensions= Egyptian_HIEROGLYPHS}', "");
Expect(0, 78894, '\p{^Is_Script_Extensions= Egyptian_HIEROGLYPHS}', "");
Expect(0, 78894, '\P{Is_Script_Extensions= Egyptian_HIEROGLYPHS}', "");
Expect(1, 78894, '\P{^Is_Script_Extensions= Egyptian_HIEROGLYPHS}', "");
Expect(0, 78895, '\p{Is_Script_Extensions= Egyptian_HIEROGLYPHS}', "");
Expect(1, 78895, '\p{^Is_Script_Extensions= Egyptian_HIEROGLYPHS}', "");
Expect(1, 78895, '\P{Is_Script_Extensions= Egyptian_HIEROGLYPHS}', "");
Expect(0, 78895, '\P{^Is_Script_Extensions= Egyptian_HIEROGLYPHS}', "");
Error('\p{Is_Scx= -Egyp:=}');
Error('\P{Is_Scx= -Egyp:=}');
Expect(1, 78894, '\p{Is_Scx=egyp}', "");
Expect(0, 78894, '\p{^Is_Scx=egyp}', "");
Expect(0, 78894, '\P{Is_Scx=egyp}', "");
Expect(1, 78894, '\P{^Is_Scx=egyp}', "");
Expect(0, 78895, '\p{Is_Scx=egyp}', "");
Expect(1, 78895, '\p{^Is_Scx=egyp}', "");
Expect(1, 78895, '\P{Is_Scx=egyp}', "");
Expect(0, 78895, '\P{^Is_Scx=egyp}', "");
Expect(1, 78894, '\p{Is_Scx:   _ Egyp}', "");
Expect(0, 78894, '\p{^Is_Scx:   _ Egyp}', "");
Expect(0, 78894, '\P{Is_Scx:   _ Egyp}', "");
Expect(1, 78894, '\P{^Is_Scx:   _ Egyp}', "");
Expect(0, 78895, '\p{Is_Scx:   _ Egyp}', "");
Expect(1, 78895, '\p{^Is_Scx:   _ Egyp}', "");
Expect(1, 78895, '\P{Is_Scx:   _ Egyp}', "");
Expect(0, 78895, '\P{^Is_Scx:   _ Egyp}', "");
Error('\p{Script_Extensions=:=  Ethiopic}');
Error('\P{Script_Extensions=:=  Ethiopic}');
Expect(1, 43822, '\p{Script_Extensions=ethiopic}', "");
Expect(0, 43822, '\p{^Script_Extensions=ethiopic}', "");
Expect(0, 43822, '\P{Script_Extensions=ethiopic}', "");
Expect(1, 43822, '\P{^Script_Extensions=ethiopic}', "");
Expect(0, 43823, '\p{Script_Extensions=ethiopic}', "");
Expect(1, 43823, '\p{^Script_Extensions=ethiopic}', "");
Expect(1, 43823, '\P{Script_Extensions=ethiopic}', "");
Expect(0, 43823, '\P{^Script_Extensions=ethiopic}', "");
Expect(1, 43822, '\p{Script_Extensions:_-ETHIOPIC}', "");
Expect(0, 43822, '\p{^Script_Extensions:_-ETHIOPIC}', "");
Expect(0, 43822, '\P{Script_Extensions:_-ETHIOPIC}', "");
Expect(1, 43822, '\P{^Script_Extensions:_-ETHIOPIC}', "");
Expect(0, 43823, '\p{Script_Extensions:_-ETHIOPIC}', "");
Expect(1, 43823, '\p{^Script_Extensions:_-ETHIOPIC}', "");
Expect(1, 43823, '\P{Script_Extensions:_-ETHIOPIC}', "");
Expect(0, 43823, '\P{^Script_Extensions:_-ETHIOPIC}', "");
Error('\p{Scx=--Ethi/a/}');
Error('\P{Scx=--Ethi/a/}');
Expect(1, 43822, '\p{Scx=ethi}', "");
Expect(0, 43822, '\p{^Scx=ethi}', "");
Expect(0, 43822, '\P{Scx=ethi}', "");
Expect(1, 43822, '\P{^Scx=ethi}', "");
Expect(0, 43823, '\p{Scx=ethi}', "");
Expect(1, 43823, '\p{^Scx=ethi}', "");
Expect(1, 43823, '\P{Scx=ethi}', "");
Expect(0, 43823, '\P{^Scx=ethi}', "");
Expect(1, 43822, '\p{Scx= _ethi}', "");
Expect(0, 43822, '\p{^Scx= _ethi}', "");
Expect(0, 43822, '\P{Scx= _ethi}', "");
Expect(1, 43822, '\P{^Scx= _ethi}', "");
Expect(0, 43823, '\p{Scx= _ethi}', "");
Expect(1, 43823, '\p{^Scx= _ethi}', "");
Expect(1, 43823, '\P{Scx= _ethi}', "");
Expect(0, 43823, '\P{^Scx= _ethi}', "");
Error('\p{Is_Script_Extensions=-_ETHIOPIC/a/}');
Error('\P{Is_Script_Extensions=-_ETHIOPIC/a/}');
Expect(1, 43822, '\p{Is_Script_Extensions=ethiopic}', "");
Expect(0, 43822, '\p{^Is_Script_Extensions=ethiopic}', "");
Expect(0, 43822, '\P{Is_Script_Extensions=ethiopic}', "");
Expect(1, 43822, '\P{^Is_Script_Extensions=ethiopic}', "");
Expect(0, 43823, '\p{Is_Script_Extensions=ethiopic}', "");
Expect(1, 43823, '\p{^Is_Script_Extensions=ethiopic}', "");
Expect(1, 43823, '\P{Is_Script_Extensions=ethiopic}', "");
Expect(0, 43823, '\P{^Is_Script_Extensions=ethiopic}', "");
Expect(1, 43822, '\p{Is_Script_Extensions:    Ethiopic}', "");
Expect(0, 43822, '\p{^Is_Script_Extensions:    Ethiopic}', "");
Expect(0, 43822, '\P{Is_Script_Extensions:    Ethiopic}', "");
Expect(1, 43822, '\P{^Is_Script_Extensions:    Ethiopic}', "");
Expect(0, 43823, '\p{Is_Script_Extensions:    Ethiopic}', "");
Expect(1, 43823, '\p{^Is_Script_Extensions:    Ethiopic}', "");
Expect(1, 43823, '\P{Is_Script_Extensions:    Ethiopic}', "");
Expect(0, 43823, '\P{^Is_Script_Extensions:    Ethiopic}', "");
Error('\p{Is_Scx=_:=ETHI}');
Error('\P{Is_Scx=_:=ETHI}');
Expect(1, 43822, '\p{Is_Scx=ethi}', "");
Expect(0, 43822, '\p{^Is_Scx=ethi}', "");
Expect(0, 43822, '\P{Is_Scx=ethi}', "");
Expect(1, 43822, '\P{^Is_Scx=ethi}', "");
Expect(0, 43823, '\p{Is_Scx=ethi}', "");
Expect(1, 43823, '\p{^Is_Scx=ethi}', "");
Expect(1, 43823, '\P{Is_Scx=ethi}', "");
Expect(0, 43823, '\P{^Is_Scx=ethi}', "");
Expect(1, 43822, '\p{Is_Scx=_Ethi}', "");
Expect(0, 43822, '\p{^Is_Scx=_Ethi}', "");
Expect(0, 43822, '\P{Is_Scx=_Ethi}', "");
Expect(1, 43822, '\P{^Is_Scx=_Ethi}', "");
Expect(0, 43823, '\p{Is_Scx=_Ethi}', "");
Expect(1, 43823, '\p{^Is_Scx=_Ethi}', "");
Expect(1, 43823, '\P{Is_Scx=_Ethi}', "");
Expect(0, 43823, '\P{^Is_Scx=_Ethi}', "");
Error('\p{Script_Extensions=:=georgian}');
Error('\P{Script_Extensions=:=georgian}');
Expect(1, 11565, '\p{Script_Extensions=georgian}', "");
Expect(0, 11565, '\p{^Script_Extensions=georgian}', "");
Expect(0, 11565, '\P{Script_Extensions=georgian}', "");
Expect(1, 11565, '\P{^Script_Extensions=georgian}', "");
Expect(0, 11566, '\p{Script_Extensions=georgian}', "");
Expect(1, 11566, '\p{^Script_Extensions=georgian}', "");
Expect(1, 11566, '\P{Script_Extensions=georgian}', "");
Expect(0, 11566, '\P{^Script_Extensions=georgian}', "");
Expect(1, 11565, '\p{Script_Extensions=GEORGIAN}', "");
Expect(0, 11565, '\p{^Script_Extensions=GEORGIAN}', "");
Expect(0, 11565, '\P{Script_Extensions=GEORGIAN}', "");
Expect(1, 11565, '\P{^Script_Extensions=GEORGIAN}', "");
Expect(0, 11566, '\p{Script_Extensions=GEORGIAN}', "");
Expect(1, 11566, '\p{^Script_Extensions=GEORGIAN}', "");
Expect(1, 11566, '\P{Script_Extensions=GEORGIAN}', "");
Expect(0, 11566, '\P{^Script_Extensions=GEORGIAN}', "");
Error('\p{Scx=-_geor:=}');
Error('\P{Scx=-_geor:=}');
Expect(1, 11565, '\p{Scx=geor}', "");
Expect(0, 11565, '\p{^Scx=geor}', "");
Expect(0, 11565, '\P{Scx=geor}', "");
Expect(1, 11565, '\P{^Scx=geor}', "");
Expect(0, 11566, '\p{Scx=geor}', "");
Expect(1, 11566, '\p{^Scx=geor}', "");
Expect(1, 11566, '\P{Scx=geor}', "");
Expect(0, 11566, '\P{^Scx=geor}', "");
Expect(1, 11565, '\p{Scx= _GEOR}', "");
Expect(0, 11565, '\p{^Scx= _GEOR}', "");
Expect(0, 11565, '\P{Scx= _GEOR}', "");
Expect(1, 11565, '\P{^Scx= _GEOR}', "");
Expect(0, 11566, '\p{Scx= _GEOR}', "");
Expect(1, 11566, '\p{^Scx= _GEOR}', "");
Expect(1, 11566, '\P{Scx= _GEOR}', "");
Expect(0, 11566, '\P{^Scx= _GEOR}', "");
Error('\p{Is_Script_Extensions=:=-_georgian}');
Error('\P{Is_Script_Extensions=:=-_georgian}');
Expect(1, 11565, '\p{Is_Script_Extensions=georgian}', "");
Expect(0, 11565, '\p{^Is_Script_Extensions=georgian}', "");
Expect(0, 11565, '\P{Is_Script_Extensions=georgian}', "");
Expect(1, 11565, '\P{^Is_Script_Extensions=georgian}', "");
Expect(0, 11566, '\p{Is_Script_Extensions=georgian}', "");
Expect(1, 11566, '\p{^Is_Script_Extensions=georgian}', "");
Expect(1, 11566, '\P{Is_Script_Extensions=georgian}', "");
Expect(0, 11566, '\P{^Is_Script_Extensions=georgian}', "");
Expect(1, 11565, '\p{Is_Script_Extensions= Georgian}', "");
Expect(0, 11565, '\p{^Is_Script_Extensions= Georgian}', "");
Expect(0, 11565, '\P{Is_Script_Extensions= Georgian}', "");
Expect(1, 11565, '\P{^Is_Script_Extensions= Georgian}', "");
Expect(0, 11566, '\p{Is_Script_Extensions= Georgian}', "");
Expect(1, 11566, '\p{^Is_Script_Extensions= Georgian}', "");
Expect(1, 11566, '\P{Is_Script_Extensions= Georgian}', "");
Expect(0, 11566, '\P{^Is_Script_Extensions= Georgian}', "");
Error('\p{Is_Scx=  Geor/a/}');
Error('\P{Is_Scx=  Geor/a/}');
Expect(1, 11565, '\p{Is_Scx:geor}', "");
Expect(0, 11565, '\p{^Is_Scx:geor}', "");
Expect(0, 11565, '\P{Is_Scx:geor}', "");
Expect(1, 11565, '\P{^Is_Scx:geor}', "");
Expect(0, 11566, '\p{Is_Scx:geor}', "");
Expect(1, 11566, '\p{^Is_Scx:geor}', "");
Expect(1, 11566, '\P{Is_Scx:geor}', "");
Expect(0, 11566, '\P{^Is_Scx:geor}', "");
Expect(1, 11565, '\p{Is_Scx= 	GEOR}', "");
Expect(0, 11565, '\p{^Is_Scx= 	GEOR}', "");
Expect(0, 11565, '\P{Is_Scx= 	GEOR}', "");
Expect(1, 11565, '\P{^Is_Scx= 	GEOR}', "");
Expect(0, 11566, '\p{Is_Scx= 	GEOR}', "");
Expect(1, 11566, '\p{^Is_Scx= 	GEOR}', "");
Expect(1, 11566, '\P{Is_Scx= 	GEOR}', "");
Expect(0, 11566, '\P{^Is_Scx= 	GEOR}', "");
Error('\p{Script_Extensions:		glagolitic/a/}');
Error('\P{Script_Extensions:		glagolitic/a/}');
Expect(1, 11358, '\p{Script_Extensions=glagolitic}', "");
Expect(0, 11358, '\p{^Script_Extensions=glagolitic}', "");
Expect(0, 11358, '\P{Script_Extensions=glagolitic}', "");
Expect(1, 11358, '\P{^Script_Extensions=glagolitic}', "");
Expect(0, 11359, '\p{Script_Extensions=glagolitic}', "");
Expect(1, 11359, '\p{^Script_Extensions=glagolitic}', "");
Expect(1, 11359, '\P{Script_Extensions=glagolitic}', "");
Expect(0, 11359, '\P{^Script_Extensions=glagolitic}', "");
Expect(1, 11358, '\p{Script_Extensions=-Glagolitic}', "");
Expect(0, 11358, '\p{^Script_Extensions=-Glagolitic}', "");
Expect(0, 11358, '\P{Script_Extensions=-Glagolitic}', "");
Expect(1, 11358, '\P{^Script_Extensions=-Glagolitic}', "");
Expect(0, 11359, '\p{Script_Extensions=-Glagolitic}', "");
Expect(1, 11359, '\p{^Script_Extensions=-Glagolitic}', "");
Expect(1, 11359, '\P{Script_Extensions=-Glagolitic}', "");
Expect(0, 11359, '\P{^Script_Extensions=-Glagolitic}', "");
Error('\p{Scx=:=		glag}');
Error('\P{Scx=:=		glag}');
Expect(1, 11358, '\p{Scx=glag}', "");
Expect(0, 11358, '\p{^Scx=glag}', "");
Expect(0, 11358, '\P{Scx=glag}', "");
Expect(1, 11358, '\P{^Scx=glag}', "");
Expect(0, 11359, '\p{Scx=glag}', "");
Expect(1, 11359, '\p{^Scx=glag}', "");
Expect(1, 11359, '\P{Scx=glag}', "");
Expect(0, 11359, '\P{^Scx=glag}', "");
Expect(1, 11358, '\p{Scx=_	Glag}', "");
Expect(0, 11358, '\p{^Scx=_	Glag}', "");
Expect(0, 11358, '\P{Scx=_	Glag}', "");
Expect(1, 11358, '\P{^Scx=_	Glag}', "");
Expect(0, 11359, '\p{Scx=_	Glag}', "");
Expect(1, 11359, '\p{^Scx=_	Glag}', "");
Expect(1, 11359, '\P{Scx=_	Glag}', "");
Expect(0, 11359, '\P{^Scx=_	Glag}', "");
Error('\p{Is_Script_Extensions=:=_GLAGOLITIC}');
Error('\P{Is_Script_Extensions=:=_GLAGOLITIC}');
Expect(1, 11358, '\p{Is_Script_Extensions=glagolitic}', "");
Expect(0, 11358, '\p{^Is_Script_Extensions=glagolitic}', "");
Expect(0, 11358, '\P{Is_Script_Extensions=glagolitic}', "");
Expect(1, 11358, '\P{^Is_Script_Extensions=glagolitic}', "");
Expect(0, 11359, '\p{Is_Script_Extensions=glagolitic}', "");
Expect(1, 11359, '\p{^Is_Script_Extensions=glagolitic}', "");
Expect(1, 11359, '\P{Is_Script_Extensions=glagolitic}', "");
Expect(0, 11359, '\P{^Is_Script_Extensions=glagolitic}', "");
Expect(1, 11358, '\p{Is_Script_Extensions= _glagolitic}', "");
Expect(0, 11358, '\p{^Is_Script_Extensions= _glagolitic}', "");
Expect(0, 11358, '\P{Is_Script_Extensions= _glagolitic}', "");
Expect(1, 11358, '\P{^Is_Script_Extensions= _glagolitic}', "");
Expect(0, 11359, '\p{Is_Script_Extensions= _glagolitic}', "");
Expect(1, 11359, '\p{^Is_Script_Extensions= _glagolitic}', "");
Expect(1, 11359, '\P{Is_Script_Extensions= _glagolitic}', "");
Expect(0, 11359, '\P{^Is_Script_Extensions= _glagolitic}', "");
Error('\p{Is_Scx= /a/glag}');
Error('\P{Is_Scx= /a/glag}');
Expect(1, 11358, '\p{Is_Scx=glag}', "");
Expect(0, 11358, '\p{^Is_Scx=glag}', "");
Expect(0, 11358, '\P{Is_Scx=glag}', "");
Expect(1, 11358, '\P{^Is_Scx=glag}', "");
Expect(0, 11359, '\p{Is_Scx=glag}', "");
Expect(1, 11359, '\p{^Is_Scx=glag}', "");
Expect(1, 11359, '\P{Is_Scx=glag}', "");
Expect(0, 11359, '\P{^Is_Scx=glag}', "");
Expect(1, 11358, '\p{Is_Scx=_	Glag}', "");
Expect(0, 11358, '\p{^Is_Scx=_	Glag}', "");
Expect(0, 11358, '\P{Is_Scx=_	Glag}', "");
Expect(1, 11358, '\P{^Is_Scx=_	Glag}', "");
Expect(0, 11359, '\p{Is_Scx=_	Glag}', "");
Expect(1, 11359, '\p{^Is_Scx=_	Glag}', "");
Expect(1, 11359, '\P{Is_Scx=_	Glag}', "");
Expect(0, 11359, '\P{^Is_Scx=_	Glag}', "");
Error('\p{Script_Extensions= gothic/a/}');
Error('\P{Script_Extensions= gothic/a/}');
Expect(1, 66378, '\p{Script_Extensions=gothic}', "");
Expect(0, 66378, '\p{^Script_Extensions=gothic}', "");
Expect(0, 66378, '\P{Script_Extensions=gothic}', "");
Expect(1, 66378, '\P{^Script_Extensions=gothic}', "");
Expect(0, 66379, '\p{Script_Extensions=gothic}', "");
Expect(1, 66379, '\p{^Script_Extensions=gothic}', "");
Expect(1, 66379, '\P{Script_Extensions=gothic}', "");
Expect(0, 66379, '\P{^Script_Extensions=gothic}', "");
Expect(1, 66378, '\p{Script_Extensions=  gothic}', "");
Expect(0, 66378, '\p{^Script_Extensions=  gothic}', "");
Expect(0, 66378, '\P{Script_Extensions=  gothic}', "");
Expect(1, 66378, '\P{^Script_Extensions=  gothic}', "");
Expect(0, 66379, '\p{Script_Extensions=  gothic}', "");
Expect(1, 66379, '\p{^Script_Extensions=  gothic}', "");
Expect(1, 66379, '\P{Script_Extensions=  gothic}', "");
Expect(0, 66379, '\P{^Script_Extensions=  gothic}', "");
Error('\p{Scx=_-Goth:=}');
Error('\P{Scx=_-Goth:=}');
Expect(1, 66378, '\p{Scx=goth}', "");
Expect(0, 66378, '\p{^Scx=goth}', "");
Expect(0, 66378, '\P{Scx=goth}', "");
Expect(1, 66378, '\P{^Scx=goth}', "");
Expect(0, 66379, '\p{Scx=goth}', "");
Expect(1, 66379, '\p{^Scx=goth}', "");
Expect(1, 66379, '\P{Scx=goth}', "");
Expect(0, 66379, '\P{^Scx=goth}', "");
Expect(1, 66378, '\p{Scx=_-Goth}', "");
Expect(0, 66378, '\p{^Scx=_-Goth}', "");
Expect(0, 66378, '\P{Scx=_-Goth}', "");
Expect(1, 66378, '\P{^Scx=_-Goth}', "");
Expect(0, 66379, '\p{Scx=_-Goth}', "");
Expect(1, 66379, '\p{^Scx=_-Goth}', "");
Expect(1, 66379, '\P{Scx=_-Goth}', "");
Expect(0, 66379, '\P{^Scx=_-Goth}', "");
Error('\p{Is_Script_Extensions= :=gothic}');
Error('\P{Is_Script_Extensions= :=gothic}');
Expect(1, 66378, '\p{Is_Script_Extensions=gothic}', "");
Expect(0, 66378, '\p{^Is_Script_Extensions=gothic}', "");
Expect(0, 66378, '\P{Is_Script_Extensions=gothic}', "");
Expect(1, 66378, '\P{^Is_Script_Extensions=gothic}', "");
Expect(0, 66379, '\p{Is_Script_Extensions=gothic}', "");
Expect(1, 66379, '\p{^Is_Script_Extensions=gothic}', "");
Expect(1, 66379, '\P{Is_Script_Extensions=gothic}', "");
Expect(0, 66379, '\P{^Is_Script_Extensions=gothic}', "");
Expect(1, 66378, '\p{Is_Script_Extensions= Gothic}', "");
Expect(0, 66378, '\p{^Is_Script_Extensions= Gothic}', "");
Expect(0, 66378, '\P{Is_Script_Extensions= Gothic}', "");
Expect(1, 66378, '\P{^Is_Script_Extensions= Gothic}', "");
Expect(0, 66379, '\p{Is_Script_Extensions= Gothic}', "");
Expect(1, 66379, '\p{^Is_Script_Extensions= Gothic}', "");
Expect(1, 66379, '\P{Is_Script_Extensions= Gothic}', "");
Expect(0, 66379, '\P{^Is_Script_Extensions= Gothic}', "");
Error('\p{Is_Scx:   --Goth:=}');
Error('\P{Is_Scx:   --Goth:=}');
Expect(1, 66378, '\p{Is_Scx=goth}', "");
Expect(0, 66378, '\p{^Is_Scx=goth}', "");
Expect(0, 66378, '\P{Is_Scx=goth}', "");
Expect(1, 66378, '\P{^Is_Scx=goth}', "");
Expect(0, 66379, '\p{Is_Scx=goth}', "");
Expect(1, 66379, '\p{^Is_Scx=goth}', "");
Expect(1, 66379, '\P{Is_Scx=goth}', "");
Expect(0, 66379, '\P{^Is_Scx=goth}', "");
Expect(1, 66378, '\p{Is_Scx=-Goth}', "");
Expect(0, 66378, '\p{^Is_Scx=-Goth}', "");
Expect(0, 66378, '\P{Is_Scx=-Goth}', "");
Expect(1, 66378, '\P{^Is_Scx=-Goth}', "");
Expect(0, 66379, '\p{Is_Scx=-Goth}', "");
Expect(1, 66379, '\p{^Is_Scx=-Goth}', "");
Expect(1, 66379, '\P{Is_Scx=-Goth}', "");
Expect(0, 66379, '\P{^Is_Scx=-Goth}', "");
Error('\p{Script_Extensions=:= -Greek}');
Error('\P{Script_Extensions=:= -Greek}');
Expect(1, 119365, '\p{Script_Extensions=greek}', "");
Expect(0, 119365, '\p{^Script_Extensions=greek}', "");
Expect(0, 119365, '\P{Script_Extensions=greek}', "");
Expect(1, 119365, '\P{^Script_Extensions=greek}', "");
Expect(0, 119366, '\p{Script_Extensions=greek}', "");
Expect(1, 119366, '\p{^Script_Extensions=greek}', "");
Expect(1, 119366, '\P{Script_Extensions=greek}', "");
Expect(0, 119366, '\P{^Script_Extensions=greek}', "");
Expect(1, 119365, '\p{Script_Extensions=	_GREEK}', "");
Expect(0, 119365, '\p{^Script_Extensions=	_GREEK}', "");
Expect(0, 119365, '\P{Script_Extensions=	_GREEK}', "");
Expect(1, 119365, '\P{^Script_Extensions=	_GREEK}', "");
Expect(0, 119366, '\p{Script_Extensions=	_GREEK}', "");
Expect(1, 119366, '\p{^Script_Extensions=	_GREEK}', "");
Expect(1, 119366, '\P{Script_Extensions=	_GREEK}', "");
Expect(0, 119366, '\P{^Script_Extensions=	_GREEK}', "");
Error('\p{Scx=:=	_Grek}');
Error('\P{Scx=:=	_Grek}');
Expect(1, 119365, '\p{Scx=grek}', "");
Expect(0, 119365, '\p{^Scx=grek}', "");
Expect(0, 119365, '\P{Scx=grek}', "");
Expect(1, 119365, '\P{^Scx=grek}', "");
Expect(0, 119366, '\p{Scx=grek}', "");
Expect(1, 119366, '\p{^Scx=grek}', "");
Expect(1, 119366, '\P{Scx=grek}', "");
Expect(0, 119366, '\P{^Scx=grek}', "");
Expect(1, 119365, '\p{Scx=	-grek}', "");
Expect(0, 119365, '\p{^Scx=	-grek}', "");
Expect(0, 119365, '\P{Scx=	-grek}', "");
Expect(1, 119365, '\P{^Scx=	-grek}', "");
Expect(0, 119366, '\p{Scx=	-grek}', "");
Expect(1, 119366, '\p{^Scx=	-grek}', "");
Expect(1, 119366, '\P{Scx=	-grek}', "");
Expect(0, 119366, '\P{^Scx=	-grek}', "");
Error('\p{Is_Script_Extensions=:=greek}');
Error('\P{Is_Script_Extensions=:=greek}');
Expect(1, 119365, '\p{Is_Script_Extensions=greek}', "");
Expect(0, 119365, '\p{^Is_Script_Extensions=greek}', "");
Expect(0, 119365, '\P{Is_Script_Extensions=greek}', "");
Expect(1, 119365, '\P{^Is_Script_Extensions=greek}', "");
Expect(0, 119366, '\p{Is_Script_Extensions=greek}', "");
Expect(1, 119366, '\p{^Is_Script_Extensions=greek}', "");
Expect(1, 119366, '\P{Is_Script_Extensions=greek}', "");
Expect(0, 119366, '\P{^Is_Script_Extensions=greek}', "");
Expect(1, 119365, '\p{Is_Script_Extensions=-Greek}', "");
Expect(0, 119365, '\p{^Is_Script_Extensions=-Greek}', "");
Expect(0, 119365, '\P{Is_Script_Extensions=-Greek}', "");
Expect(1, 119365, '\P{^Is_Script_Extensions=-Greek}', "");
Expect(0, 119366, '\p{Is_Script_Extensions=-Greek}', "");
Expect(1, 119366, '\p{^Is_Script_Extensions=-Greek}', "");
Expect(1, 119366, '\P{Is_Script_Extensions=-Greek}', "");
Expect(0, 119366, '\P{^Is_Script_Extensions=-Greek}', "");
Error('\p{Is_Scx=- Grek:=}');
Error('\P{Is_Scx=- Grek:=}');
Expect(1, 119365, '\p{Is_Scx=grek}', "");
Expect(0, 119365, '\p{^Is_Scx=grek}', "");
Expect(0, 119365, '\P{Is_Scx=grek}', "");
Expect(1, 119365, '\P{^Is_Scx=grek}', "");
Expect(0, 119366, '\p{Is_Scx=grek}', "");
Expect(1, 119366, '\p{^Is_Scx=grek}', "");
Expect(1, 119366, '\P{Is_Scx=grek}', "");
Expect(0, 119366, '\P{^Is_Scx=grek}', "");
Expect(1, 119365, '\p{Is_Scx=_ Grek}', "");
Expect(0, 119365, '\p{^Is_Scx=_ Grek}', "");
Expect(0, 119365, '\P{Is_Scx=_ Grek}', "");
Expect(1, 119365, '\P{^Is_Scx=_ Grek}', "");
Expect(0, 119366, '\p{Is_Scx=_ Grek}', "");
Expect(1, 119366, '\p{^Is_Scx=_ Grek}', "");
Expect(1, 119366, '\P{Is_Scx=_ Grek}', "");
Expect(0, 119366, '\P{^Is_Scx=_ Grek}', "");
Error('\p{Script_Extensions=	_Gujarati/a/}');
Error('\P{Script_Extensions=	_Gujarati/a/}');
Expect(1, 43065, '\p{Script_Extensions: gujarati}', "");
Expect(0, 43065, '\p{^Script_Extensions: gujarati}', "");
Expect(0, 43065, '\P{Script_Extensions: gujarati}', "");
Expect(1, 43065, '\P{^Script_Extensions: gujarati}', "");
Expect(0, 43066, '\p{Script_Extensions: gujarati}', "");
Expect(1, 43066, '\p{^Script_Extensions: gujarati}', "");
Expect(1, 43066, '\P{Script_Extensions: gujarati}', "");
Expect(0, 43066, '\P{^Script_Extensions: gujarati}', "");
Expect(1, 43065, '\p{Script_Extensions=	_Gujarati}', "");
Expect(0, 43065, '\p{^Script_Extensions=	_Gujarati}', "");
Expect(0, 43065, '\P{Script_Extensions=	_Gujarati}', "");
Expect(1, 43065, '\P{^Script_Extensions=	_Gujarati}', "");
Expect(0, 43066, '\p{Script_Extensions=	_Gujarati}', "");
Expect(1, 43066, '\p{^Script_Extensions=	_Gujarati}', "");
Expect(1, 43066, '\P{Script_Extensions=	_Gujarati}', "");
Expect(0, 43066, '\P{^Script_Extensions=	_Gujarati}', "");
Error('\p{Scx=-	GUJR/a/}');
Error('\P{Scx=-	GUJR/a/}');
Expect(1, 43065, '\p{Scx=gujr}', "");
Expect(0, 43065, '\p{^Scx=gujr}', "");
Expect(0, 43065, '\P{Scx=gujr}', "");
Expect(1, 43065, '\P{^Scx=gujr}', "");
Expect(0, 43066, '\p{Scx=gujr}', "");
Expect(1, 43066, '\p{^Scx=gujr}', "");
Expect(1, 43066, '\P{Scx=gujr}', "");
Expect(0, 43066, '\P{^Scx=gujr}', "");
Expect(1, 43065, '\p{Scx=- Gujr}', "");
Expect(0, 43065, '\p{^Scx=- Gujr}', "");
Expect(0, 43065, '\P{Scx=- Gujr}', "");
Expect(1, 43065, '\P{^Scx=- Gujr}', "");
Expect(0, 43066, '\p{Scx=- Gujr}', "");
Expect(1, 43066, '\p{^Scx=- Gujr}', "");
Expect(1, 43066, '\P{Scx=- Gujr}', "");
Expect(0, 43066, '\P{^Scx=- Gujr}', "");
Error('\p{Is_Script_Extensions=/a/  gujarati}');
Error('\P{Is_Script_Extensions=/a/  gujarati}');
Expect(1, 43065, '\p{Is_Script_Extensions=gujarati}', "");
Expect(0, 43065, '\p{^Is_Script_Extensions=gujarati}', "");
Expect(0, 43065, '\P{Is_Script_Extensions=gujarati}', "");
Expect(1, 43065, '\P{^Is_Script_Extensions=gujarati}', "");
Expect(0, 43066, '\p{Is_Script_Extensions=gujarati}', "");
Expect(1, 43066, '\p{^Is_Script_Extensions=gujarati}', "");
Expect(1, 43066, '\P{Is_Script_Extensions=gujarati}', "");
Expect(0, 43066, '\P{^Is_Script_Extensions=gujarati}', "");
Expect(1, 43065, '\p{Is_Script_Extensions= Gujarati}', "");
Expect(0, 43065, '\p{^Is_Script_Extensions= Gujarati}', "");
Expect(0, 43065, '\P{Is_Script_Extensions= Gujarati}', "");
Expect(1, 43065, '\P{^Is_Script_Extensions= Gujarati}', "");
Expect(0, 43066, '\p{Is_Script_Extensions= Gujarati}', "");
Expect(1, 43066, '\p{^Is_Script_Extensions= Gujarati}', "");
Expect(1, 43066, '\P{Is_Script_Extensions= Gujarati}', "");
Expect(0, 43066, '\P{^Is_Script_Extensions= Gujarati}', "");
Error('\p{Is_Scx=:= -GUJR}');
Error('\P{Is_Scx=:= -GUJR}');
Expect(1, 43065, '\p{Is_Scx: gujr}', "");
Expect(0, 43065, '\p{^Is_Scx: gujr}', "");
Expect(0, 43065, '\P{Is_Scx: gujr}', "");
Expect(1, 43065, '\P{^Is_Scx: gujr}', "");
Expect(0, 43066, '\p{Is_Scx: gujr}', "");
Expect(1, 43066, '\p{^Is_Scx: gujr}', "");
Expect(1, 43066, '\P{Is_Scx: gujr}', "");
Expect(0, 43066, '\P{^Is_Scx: gujr}', "");
Expect(1, 43065, '\p{Is_Scx= gujr}', "");
Expect(0, 43065, '\p{^Is_Scx= gujr}', "");
Expect(0, 43065, '\P{Is_Scx= gujr}', "");
Expect(1, 43065, '\P{^Is_Scx= gujr}', "");
Expect(0, 43066, '\p{Is_Scx= gujr}', "");
Expect(1, 43066, '\p{^Is_Scx= gujr}', "");
Expect(1, 43066, '\P{Is_Scx= gujr}', "");
Expect(0, 43066, '\P{^Is_Scx= gujr}', "");
Error('\p{Script_Extensions:_Gurmukhi:=}');
Error('\P{Script_Extensions:_Gurmukhi:=}');
Expect(1, 43065, '\p{Script_Extensions=gurmukhi}', "");
Expect(0, 43065, '\p{^Script_Extensions=gurmukhi}', "");
Expect(0, 43065, '\P{Script_Extensions=gurmukhi}', "");
Expect(1, 43065, '\P{^Script_Extensions=gurmukhi}', "");
Expect(0, 43066, '\p{Script_Extensions=gurmukhi}', "");
Expect(1, 43066, '\p{^Script_Extensions=gurmukhi}', "");
Expect(1, 43066, '\P{Script_Extensions=gurmukhi}', "");
Expect(0, 43066, '\P{^Script_Extensions=gurmukhi}', "");
Expect(1, 43065, '\p{Script_Extensions:_ Gurmukhi}', "");
Expect(0, 43065, '\p{^Script_Extensions:_ Gurmukhi}', "");
Expect(0, 43065, '\P{Script_Extensions:_ Gurmukhi}', "");
Expect(1, 43065, '\P{^Script_Extensions:_ Gurmukhi}', "");
Expect(0, 43066, '\p{Script_Extensions:_ Gurmukhi}', "");
Expect(1, 43066, '\p{^Script_Extensions:_ Gurmukhi}', "");
Expect(1, 43066, '\P{Script_Extensions:_ Gurmukhi}', "");
Expect(0, 43066, '\P{^Script_Extensions:_ Gurmukhi}', "");
Error('\p{Scx= 	guru:=}');
Error('\P{Scx= 	guru:=}');
Expect(1, 43065, '\p{Scx=guru}', "");
Expect(0, 43065, '\p{^Scx=guru}', "");
Expect(0, 43065, '\P{Scx=guru}', "");
Expect(1, 43065, '\P{^Scx=guru}', "");
Expect(0, 43066, '\p{Scx=guru}', "");
Expect(1, 43066, '\p{^Scx=guru}', "");
Expect(1, 43066, '\P{Scx=guru}', "");
Expect(0, 43066, '\P{^Scx=guru}', "");
Expect(1, 43065, '\p{Scx=- Guru}', "");
Expect(0, 43065, '\p{^Scx=- Guru}', "");
Expect(0, 43065, '\P{Scx=- Guru}', "");
Expect(1, 43065, '\P{^Scx=- Guru}', "");
Expect(0, 43066, '\p{Scx=- Guru}', "");
Expect(1, 43066, '\p{^Scx=- Guru}', "");
Expect(1, 43066, '\P{Scx=- Guru}', "");
Expect(0, 43066, '\P{^Scx=- Guru}', "");
Error('\p{Is_Script_Extensions=_Gurmukhi:=}');
Error('\P{Is_Script_Extensions=_Gurmukhi:=}');
Expect(1, 43065, '\p{Is_Script_Extensions=gurmukhi}', "");
Expect(0, 43065, '\p{^Is_Script_Extensions=gurmukhi}', "");
Expect(0, 43065, '\P{Is_Script_Extensions=gurmukhi}', "");
Expect(1, 43065, '\P{^Is_Script_Extensions=gurmukhi}', "");
Expect(0, 43066, '\p{Is_Script_Extensions=gurmukhi}', "");
Expect(1, 43066, '\p{^Is_Script_Extensions=gurmukhi}', "");
Expect(1, 43066, '\P{Is_Script_Extensions=gurmukhi}', "");
Expect(0, 43066, '\P{^Is_Script_Extensions=gurmukhi}', "");
Expect(1, 43065, '\p{Is_Script_Extensions=_ Gurmukhi}', "");
Expect(0, 43065, '\p{^Is_Script_Extensions=_ Gurmukhi}', "");
Expect(0, 43065, '\P{Is_Script_Extensions=_ Gurmukhi}', "");
Expect(1, 43065, '\P{^Is_Script_Extensions=_ Gurmukhi}', "");
Expect(0, 43066, '\p{Is_Script_Extensions=_ Gurmukhi}', "");
Expect(1, 43066, '\p{^Is_Script_Extensions=_ Gurmukhi}', "");
Expect(1, 43066, '\P{Is_Script_Extensions=_ Gurmukhi}', "");
Expect(0, 43066, '\P{^Is_Script_Extensions=_ Gurmukhi}', "");
Error('\p{Is_Scx=/a/ -GURU}');
Error('\P{Is_Scx=/a/ -GURU}');
Expect(1, 43065, '\p{Is_Scx=guru}', "");
Expect(0, 43065, '\p{^Is_Scx=guru}', "");
Expect(0, 43065, '\P{Is_Scx=guru}', "");
Expect(1, 43065, '\P{^Is_Scx=guru}', "");
Expect(0, 43066, '\p{Is_Scx=guru}', "");
Expect(1, 43066, '\p{^Is_Scx=guru}', "");
Expect(1, 43066, '\P{Is_Scx=guru}', "");
Expect(0, 43066, '\P{^Is_Scx=guru}', "");
Expect(1, 43065, '\p{Is_Scx=  GURU}', "");
Expect(0, 43065, '\p{^Is_Scx=  GURU}', "");
Expect(0, 43065, '\P{Is_Scx=  GURU}', "");
Expect(1, 43065, '\P{^Is_Scx=  GURU}', "");
Expect(0, 43066, '\p{Is_Scx=  GURU}', "");
Expect(1, 43066, '\p{^Is_Scx=  GURU}', "");
Expect(1, 43066, '\P{Is_Scx=  GURU}', "");
Expect(0, 43066, '\P{^Is_Scx=  GURU}', "");
Error('\p{Script_Extensions=/a/	-Hangul}');
Error('\P{Script_Extensions=/a/	-Hangul}');
Expect(1, 65500, '\p{Script_Extensions=hangul}', "");
Expect(0, 65500, '\p{^Script_Extensions=hangul}', "");
Expect(0, 65500, '\P{Script_Extensions=hangul}', "");
Expect(1, 65500, '\P{^Script_Extensions=hangul}', "");
Expect(0, 65501, '\p{Script_Extensions=hangul}', "");
Expect(1, 65501, '\p{^Script_Extensions=hangul}', "");
Expect(1, 65501, '\P{Script_Extensions=hangul}', "");
Expect(0, 65501, '\P{^Script_Extensions=hangul}', "");
Expect(1, 65500, '\p{Script_Extensions:	-	Hangul}', "");
Expect(0, 65500, '\p{^Script_Extensions:	-	Hangul}', "");
Expect(0, 65500, '\P{Script_Extensions:	-	Hangul}', "");
Expect(1, 65500, '\P{^Script_Extensions:	-	Hangul}', "");
Expect(0, 65501, '\p{Script_Extensions:	-	Hangul}', "");
Expect(1, 65501, '\p{^Script_Extensions:	-	Hangul}', "");
Expect(1, 65501, '\P{Script_Extensions:	-	Hangul}', "");
Expect(0, 65501, '\P{^Script_Extensions:	-	Hangul}', "");
Error('\p{Scx=	:=hang}');
Error('\P{Scx=	:=hang}');
Expect(1, 65500, '\p{Scx=hang}', "");
Expect(0, 65500, '\p{^Scx=hang}', "");
Expect(0, 65500, '\P{Scx=hang}', "");
Expect(1, 65500, '\P{^Scx=hang}', "");
Expect(0, 65501, '\p{Scx=hang}', "");
Expect(1, 65501, '\p{^Scx=hang}', "");
Expect(1, 65501, '\P{Scx=hang}', "");
Expect(0, 65501, '\P{^Scx=hang}', "");
Expect(1, 65500, '\p{Scx= _hang}', "");
Expect(0, 65500, '\p{^Scx= _hang}', "");
Expect(0, 65500, '\P{Scx= _hang}', "");
Expect(1, 65500, '\P{^Scx= _hang}', "");
Expect(0, 65501, '\p{Scx= _hang}', "");
Expect(1, 65501, '\p{^Scx= _hang}', "");
Expect(1, 65501, '\P{Scx= _hang}', "");
Expect(0, 65501, '\P{^Scx= _hang}', "");
Error('\p{Is_Script_Extensions=HANGUL/a/}');
Error('\P{Is_Script_Extensions=HANGUL/a/}');
Expect(1, 65500, '\p{Is_Script_Extensions=hangul}', "");
Expect(0, 65500, '\p{^Is_Script_Extensions=hangul}', "");
Expect(0, 65500, '\P{Is_Script_Extensions=hangul}', "");
Expect(1, 65500, '\P{^Is_Script_Extensions=hangul}', "");
Expect(0, 65501, '\p{Is_Script_Extensions=hangul}', "");
Expect(1, 65501, '\p{^Is_Script_Extensions=hangul}', "");
Expect(1, 65501, '\P{Is_Script_Extensions=hangul}', "");
Expect(0, 65501, '\P{^Is_Script_Extensions=hangul}', "");
Expect(1, 65500, '\p{Is_Script_Extensions=	-Hangul}', "");
Expect(0, 65500, '\p{^Is_Script_Extensions=	-Hangul}', "");
Expect(0, 65500, '\P{Is_Script_Extensions=	-Hangul}', "");
Expect(1, 65500, '\P{^Is_Script_Extensions=	-Hangul}', "");
Expect(0, 65501, '\p{Is_Script_Extensions=	-Hangul}', "");
Expect(1, 65501, '\p{^Is_Script_Extensions=	-Hangul}', "");
Expect(1, 65501, '\P{Is_Script_Extensions=	-Hangul}', "");
Expect(0, 65501, '\P{^Is_Script_Extensions=	-Hangul}', "");
Error('\p{Is_Scx=		Hang/a/}');
Error('\P{Is_Scx=		Hang/a/}');
Expect(1, 65500, '\p{Is_Scx:	hang}', "");
Expect(0, 65500, '\p{^Is_Scx:	hang}', "");
Expect(0, 65500, '\P{Is_Scx:	hang}', "");
Expect(1, 65500, '\P{^Is_Scx:	hang}', "");
Expect(0, 65501, '\p{Is_Scx:	hang}', "");
Expect(1, 65501, '\p{^Is_Scx:	hang}', "");
Expect(1, 65501, '\P{Is_Scx:	hang}', "");
Expect(0, 65501, '\P{^Is_Scx:	hang}', "");
Expect(1, 65500, '\p{Is_Scx=	-HANG}', "");
Expect(0, 65500, '\p{^Is_Scx=	-HANG}', "");
Expect(0, 65500, '\P{Is_Scx=	-HANG}', "");
Expect(1, 65500, '\P{^Is_Scx=	-HANG}', "");
Expect(0, 65501, '\p{Is_Scx=	-HANG}', "");
Expect(1, 65501, '\p{^Is_Scx=	-HANG}', "");
Expect(1, 65501, '\P{Is_Scx=	-HANG}', "");
Expect(0, 65501, '\P{^Is_Scx=	-HANG}', "");
Error('\p{Script_Extensions= :=han}');
Error('\P{Script_Extensions= :=han}');
Expect(1, 195101, '\p{Script_Extensions=han}', "");
Expect(0, 195101, '\p{^Script_Extensions=han}', "");
Expect(0, 195101, '\P{Script_Extensions=han}', "");
Expect(1, 195101, '\P{^Script_Extensions=han}', "");
Expect(0, 195102, '\p{Script_Extensions=han}', "");
Expect(1, 195102, '\p{^Script_Extensions=han}', "");
Expect(1, 195102, '\P{Script_Extensions=han}', "");
Expect(0, 195102, '\P{^Script_Extensions=han}', "");
Expect(1, 195101, '\p{Script_Extensions: -han}', "");
Expect(0, 195101, '\p{^Script_Extensions: -han}', "");
Expect(0, 195101, '\P{Script_Extensions: -han}', "");
Expect(1, 195101, '\P{^Script_Extensions: -han}', "");
Expect(0, 195102, '\p{Script_Extensions: -han}', "");
Expect(1, 195102, '\p{^Script_Extensions: -han}', "");
Expect(1, 195102, '\P{Script_Extensions: -han}', "");
Expect(0, 195102, '\P{^Script_Extensions: -han}', "");
Error('\p{Scx=:= 	Hani}');
Error('\P{Scx=:= 	Hani}');
Expect(1, 195101, '\p{Scx=hani}', "");
Expect(0, 195101, '\p{^Scx=hani}', "");
Expect(0, 195101, '\P{Scx=hani}', "");
Expect(1, 195101, '\P{^Scx=hani}', "");
Expect(0, 195102, '\p{Scx=hani}', "");
Expect(1, 195102, '\p{^Scx=hani}', "");
Expect(1, 195102, '\P{Scx=hani}', "");
Expect(0, 195102, '\P{^Scx=hani}', "");
Expect(1, 195101, '\p{Scx=_ Hani}', "");
Expect(0, 195101, '\p{^Scx=_ Hani}', "");
Expect(0, 195101, '\P{Scx=_ Hani}', "");
Expect(1, 195101, '\P{^Scx=_ Hani}', "");
Expect(0, 195102, '\p{Scx=_ Hani}', "");
Expect(1, 195102, '\p{^Scx=_ Hani}', "");
Expect(1, 195102, '\P{Scx=_ Hani}', "");
Expect(0, 195102, '\P{^Scx=_ Hani}', "");
Error('\p{Is_Script_Extensions=-/a/HAN}');
Error('\P{Is_Script_Extensions=-/a/HAN}');
Expect(1, 195101, '\p{Is_Script_Extensions=han}', "");
Expect(0, 195101, '\p{^Is_Script_Extensions=han}', "");
Expect(0, 195101, '\P{Is_Script_Extensions=han}', "");
Expect(1, 195101, '\P{^Is_Script_Extensions=han}', "");
Expect(0, 195102, '\p{Is_Script_Extensions=han}', "");
Expect(1, 195102, '\p{^Is_Script_Extensions=han}', "");
Expect(1, 195102, '\P{Is_Script_Extensions=han}', "");
Expect(0, 195102, '\P{^Is_Script_Extensions=han}', "");
Expect(1, 195101, '\p{Is_Script_Extensions=Han}', "");
Expect(0, 195101, '\p{^Is_Script_Extensions=Han}', "");
Expect(0, 195101, '\P{Is_Script_Extensions=Han}', "");
Expect(1, 195101, '\P{^Is_Script_Extensions=Han}', "");
Expect(0, 195102, '\p{Is_Script_Extensions=Han}', "");
Expect(1, 195102, '\p{^Is_Script_Extensions=Han}', "");
Expect(1, 195102, '\P{Is_Script_Extensions=Han}', "");
Expect(0, 195102, '\P{^Is_Script_Extensions=Han}', "");
Error('\p{Is_Scx= hani/a/}');
Error('\P{Is_Scx= hani/a/}');
Expect(1, 195101, '\p{Is_Scx=hani}', "");
Expect(0, 195101, '\p{^Is_Scx=hani}', "");
Expect(0, 195101, '\P{Is_Scx=hani}', "");
Expect(1, 195101, '\P{^Is_Scx=hani}', "");
Expect(0, 195102, '\p{Is_Scx=hani}', "");
Expect(1, 195102, '\p{^Is_Scx=hani}', "");
Expect(1, 195102, '\P{Is_Scx=hani}', "");
Expect(0, 195102, '\P{^Is_Scx=hani}', "");
Expect(1, 195101, '\p{Is_Scx:    Hani}', "");
Expect(0, 195101, '\p{^Is_Scx:    Hani}', "");
Expect(0, 195101, '\P{Is_Scx:    Hani}', "");
Expect(1, 195101, '\P{^Is_Scx:    Hani}', "");
Expect(0, 195102, '\p{Is_Scx:    Hani}', "");
Expect(1, 195102, '\p{^Is_Scx:    Hani}', "");
Expect(1, 195102, '\P{Is_Scx:    Hani}', "");
Expect(0, 195102, '\P{^Is_Scx:    Hani}', "");
Error('\p{Script_Extensions=-/a/Hanunoo}');
Error('\P{Script_Extensions=-/a/Hanunoo}');
Expect(1, 5942, '\p{Script_Extensions=hanunoo}', "");
Expect(0, 5942, '\p{^Script_Extensions=hanunoo}', "");
Expect(0, 5942, '\P{Script_Extensions=hanunoo}', "");
Expect(1, 5942, '\P{^Script_Extensions=hanunoo}', "");
Expect(0, 5943, '\p{Script_Extensions=hanunoo}', "");
Expect(1, 5943, '\p{^Script_Extensions=hanunoo}', "");
Expect(1, 5943, '\P{Script_Extensions=hanunoo}', "");
Expect(0, 5943, '\P{^Script_Extensions=hanunoo}', "");
Expect(1, 5942, '\p{Script_Extensions=	-Hanunoo}', "");
Expect(0, 5942, '\p{^Script_Extensions=	-Hanunoo}', "");
Expect(0, 5942, '\P{Script_Extensions=	-Hanunoo}', "");
Expect(1, 5942, '\P{^Script_Extensions=	-Hanunoo}', "");
Expect(0, 5943, '\p{Script_Extensions=	-Hanunoo}', "");
Expect(1, 5943, '\p{^Script_Extensions=	-Hanunoo}', "");
Expect(1, 5943, '\P{Script_Extensions=	-Hanunoo}', "");
Expect(0, 5943, '\P{^Script_Extensions=	-Hanunoo}', "");
Error('\p{Scx=- HANO:=}');
Error('\P{Scx=- HANO:=}');
Expect(1, 5942, '\p{Scx=hano}', "");
Expect(0, 5942, '\p{^Scx=hano}', "");
Expect(0, 5942, '\P{Scx=hano}', "");
Expect(1, 5942, '\P{^Scx=hano}', "");
Expect(0, 5943, '\p{Scx=hano}', "");
Expect(1, 5943, '\p{^Scx=hano}', "");
Expect(1, 5943, '\P{Scx=hano}', "");
Expect(0, 5943, '\P{^Scx=hano}', "");
Expect(1, 5942, '\p{Scx= Hano}', "");
Expect(0, 5942, '\p{^Scx= Hano}', "");
Expect(0, 5942, '\P{Scx= Hano}', "");
Expect(1, 5942, '\P{^Scx= Hano}', "");
Expect(0, 5943, '\p{Scx= Hano}', "");
Expect(1, 5943, '\p{^Scx= Hano}', "");
Expect(1, 5943, '\P{Scx= Hano}', "");
Expect(0, 5943, '\P{^Scx= Hano}', "");
Error('\p{Is_Script_Extensions=:=	Hanunoo}');
Error('\P{Is_Script_Extensions=:=	Hanunoo}');
Expect(1, 5942, '\p{Is_Script_Extensions=hanunoo}', "");
Expect(0, 5942, '\p{^Is_Script_Extensions=hanunoo}', "");
Expect(0, 5942, '\P{Is_Script_Extensions=hanunoo}', "");
Expect(1, 5942, '\P{^Is_Script_Extensions=hanunoo}', "");
Expect(0, 5943, '\p{Is_Script_Extensions=hanunoo}', "");
Expect(1, 5943, '\p{^Is_Script_Extensions=hanunoo}', "");
Expect(1, 5943, '\P{Is_Script_Extensions=hanunoo}', "");
Expect(0, 5943, '\P{^Is_Script_Extensions=hanunoo}', "");
Expect(1, 5942, '\p{Is_Script_Extensions=-	Hanunoo}', "");
Expect(0, 5942, '\p{^Is_Script_Extensions=-	Hanunoo}', "");
Expect(0, 5942, '\P{Is_Script_Extensions=-	Hanunoo}', "");
Expect(1, 5942, '\P{^Is_Script_Extensions=-	Hanunoo}', "");
Expect(0, 5943, '\p{Is_Script_Extensions=-	Hanunoo}', "");
Expect(1, 5943, '\p{^Is_Script_Extensions=-	Hanunoo}', "");
Expect(1, 5943, '\P{Is_Script_Extensions=-	Hanunoo}', "");
Expect(0, 5943, '\P{^Is_Script_Extensions=-	Hanunoo}', "");
Error('\p{Is_Scx=/a/HANO}');
Error('\P{Is_Scx=/a/HANO}');
Expect(1, 5942, '\p{Is_Scx=hano}', "");
Expect(0, 5942, '\p{^Is_Scx=hano}', "");
Expect(0, 5942, '\P{Is_Scx=hano}', "");
Expect(1, 5942, '\P{^Is_Scx=hano}', "");
Expect(0, 5943, '\p{Is_Scx=hano}', "");
Expect(1, 5943, '\p{^Is_Scx=hano}', "");
Expect(1, 5943, '\P{Is_Scx=hano}', "");
Expect(0, 5943, '\P{^Is_Scx=hano}', "");
Expect(1, 5942, '\p{Is_Scx:	 	hano}', "");
Expect(0, 5942, '\p{^Is_Scx:	 	hano}', "");
Expect(0, 5942, '\P{Is_Scx:	 	hano}', "");
Expect(1, 5942, '\P{^Is_Scx:	 	hano}', "");
Expect(0, 5943, '\p{Is_Scx:	 	hano}', "");
Expect(1, 5943, '\p{^Is_Scx:	 	hano}', "");
Expect(1, 5943, '\P{Is_Scx:	 	hano}', "");
Expect(0, 5943, '\P{^Is_Scx:	 	hano}', "");
Error('\p{Script_Extensions=:= -hebrew}');
Error('\P{Script_Extensions=:= -hebrew}');
Expect(1, 64335, '\p{Script_Extensions=hebrew}', "");
Expect(0, 64335, '\p{^Script_Extensions=hebrew}', "");
Expect(0, 64335, '\P{Script_Extensions=hebrew}', "");
Expect(1, 64335, '\P{^Script_Extensions=hebrew}', "");
Expect(0, 64336, '\p{Script_Extensions=hebrew}', "");
Expect(1, 64336, '\p{^Script_Extensions=hebrew}', "");
Expect(1, 64336, '\P{Script_Extensions=hebrew}', "");
Expect(0, 64336, '\P{^Script_Extensions=hebrew}', "");
Expect(1, 64335, '\p{Script_Extensions: _Hebrew}', "");
Expect(0, 64335, '\p{^Script_Extensions: _Hebrew}', "");
Expect(0, 64335, '\P{Script_Extensions: _Hebrew}', "");
Expect(1, 64335, '\P{^Script_Extensions: _Hebrew}', "");
Expect(0, 64336, '\p{Script_Extensions: _Hebrew}', "");
Expect(1, 64336, '\p{^Script_Extensions: _Hebrew}', "");
Expect(1, 64336, '\P{Script_Extensions: _Hebrew}', "");
Expect(0, 64336, '\P{^Script_Extensions: _Hebrew}', "");
Error('\p{Scx:	/a/ _hebr}');
Error('\P{Scx:	/a/ _hebr}');
Expect(1, 64335, '\p{Scx=hebr}', "");
Expect(0, 64335, '\p{^Scx=hebr}', "");
Expect(0, 64335, '\P{Scx=hebr}', "");
Expect(1, 64335, '\P{^Scx=hebr}', "");
Expect(0, 64336, '\p{Scx=hebr}', "");
Expect(1, 64336, '\p{^Scx=hebr}', "");
Expect(1, 64336, '\P{Scx=hebr}', "");
Expect(0, 64336, '\P{^Scx=hebr}', "");
Expect(1, 64335, '\p{Scx:   -HEBR}', "");
Expect(0, 64335, '\p{^Scx:   -HEBR}', "");
Expect(0, 64335, '\P{Scx:   -HEBR}', "");
Expect(1, 64335, '\P{^Scx:   -HEBR}', "");
Expect(0, 64336, '\p{Scx:   -HEBR}', "");
Expect(1, 64336, '\p{^Scx:   -HEBR}', "");
Expect(1, 64336, '\P{Scx:   -HEBR}', "");
Expect(0, 64336, '\P{^Scx:   -HEBR}', "");
Error('\p{Is_Script_Extensions=-	Hebrew/a/}');
Error('\P{Is_Script_Extensions=-	Hebrew/a/}');
Expect(1, 64335, '\p{Is_Script_Extensions=hebrew}', "");
Expect(0, 64335, '\p{^Is_Script_Extensions=hebrew}', "");
Expect(0, 64335, '\P{Is_Script_Extensions=hebrew}', "");
Expect(1, 64335, '\P{^Is_Script_Extensions=hebrew}', "");
Expect(0, 64336, '\p{Is_Script_Extensions=hebrew}', "");
Expect(1, 64336, '\p{^Is_Script_Extensions=hebrew}', "");
Expect(1, 64336, '\P{Is_Script_Extensions=hebrew}', "");
Expect(0, 64336, '\P{^Is_Script_Extensions=hebrew}', "");
Expect(1, 64335, '\p{Is_Script_Extensions: 	_HEBREW}', "");
Expect(0, 64335, '\p{^Is_Script_Extensions: 	_HEBREW}', "");
Expect(0, 64335, '\P{Is_Script_Extensions: 	_HEBREW}', "");
Expect(1, 64335, '\P{^Is_Script_Extensions: 	_HEBREW}', "");
Expect(0, 64336, '\p{Is_Script_Extensions: 	_HEBREW}', "");
Expect(1, 64336, '\p{^Is_Script_Extensions: 	_HEBREW}', "");
Expect(1, 64336, '\P{Is_Script_Extensions: 	_HEBREW}', "");
Expect(0, 64336, '\P{^Is_Script_Extensions: 	_HEBREW}', "");
Error('\p{Is_Scx=_	Hebr/a/}');
Error('\P{Is_Scx=_	Hebr/a/}');
Expect(1, 64335, '\p{Is_Scx=hebr}', "");
Expect(0, 64335, '\p{^Is_Scx=hebr}', "");
Expect(0, 64335, '\P{Is_Scx=hebr}', "");
Expect(1, 64335, '\P{^Is_Scx=hebr}', "");
Expect(0, 64336, '\p{Is_Scx=hebr}', "");
Expect(1, 64336, '\p{^Is_Scx=hebr}', "");
Expect(1, 64336, '\P{Is_Scx=hebr}', "");
Expect(0, 64336, '\P{^Is_Scx=hebr}', "");
Expect(1, 64335, '\p{Is_Scx:	Hebr}', "");
Expect(0, 64335, '\p{^Is_Scx:	Hebr}', "");
Expect(0, 64335, '\P{Is_Scx:	Hebr}', "");
Expect(1, 64335, '\P{^Is_Scx:	Hebr}', "");
Expect(0, 64336, '\p{Is_Scx:	Hebr}', "");
Expect(1, 64336, '\p{^Is_Scx:	Hebr}', "");
Expect(1, 64336, '\P{Is_Scx:	Hebr}', "");
Expect(0, 64336, '\P{^Is_Scx:	Hebr}', "");
Error('\p{Script_Extensions=:=_HIRAGANA}');
Error('\P{Script_Extensions=:=_HIRAGANA}');
Expect(1, 127488, '\p{Script_Extensions=hiragana}', "");
Expect(0, 127488, '\p{^Script_Extensions=hiragana}', "");
Expect(0, 127488, '\P{Script_Extensions=hiragana}', "");
Expect(1, 127488, '\P{^Script_Extensions=hiragana}', "");
Expect(0, 127489, '\p{Script_Extensions=hiragana}', "");
Expect(1, 127489, '\p{^Script_Extensions=hiragana}', "");
Expect(1, 127489, '\P{Script_Extensions=hiragana}', "");
Expect(0, 127489, '\P{^Script_Extensions=hiragana}', "");
Expect(1, 127488, '\p{Script_Extensions= hiragana}', "");
Expect(0, 127488, '\p{^Script_Extensions= hiragana}', "");
Expect(0, 127488, '\P{Script_Extensions= hiragana}', "");
Expect(1, 127488, '\P{^Script_Extensions= hiragana}', "");
Expect(0, 127489, '\p{Script_Extensions= hiragana}', "");
Expect(1, 127489, '\p{^Script_Extensions= hiragana}', "");
Expect(1, 127489, '\P{Script_Extensions= hiragana}', "");
Expect(0, 127489, '\P{^Script_Extensions= hiragana}', "");
Error('\p{Scx= /a/HIRA}');
Error('\P{Scx= /a/HIRA}');
Expect(1, 127488, '\p{Scx=hira}', "");
Expect(0, 127488, '\p{^Scx=hira}', "");
Expect(0, 127488, '\P{Scx=hira}', "");
Expect(1, 127488, '\P{^Scx=hira}', "");
Expect(0, 127489, '\p{Scx=hira}', "");
Expect(1, 127489, '\p{^Scx=hira}', "");
Expect(1, 127489, '\P{Scx=hira}', "");
Expect(0, 127489, '\P{^Scx=hira}', "");
Expect(1, 127488, '\p{Scx=HIRA}', "");
Expect(0, 127488, '\p{^Scx=HIRA}', "");
Expect(0, 127488, '\P{Scx=HIRA}', "");
Expect(1, 127488, '\P{^Scx=HIRA}', "");
Expect(0, 127489, '\p{Scx=HIRA}', "");
Expect(1, 127489, '\p{^Scx=HIRA}', "");
Expect(1, 127489, '\P{Scx=HIRA}', "");
Expect(0, 127489, '\P{^Scx=HIRA}', "");
Error('\p{Is_Script_Extensions= 	Hiragana:=}');
Error('\P{Is_Script_Extensions= 	Hiragana:=}');
Expect(1, 127488, '\p{Is_Script_Extensions=hiragana}', "");
Expect(0, 127488, '\p{^Is_Script_Extensions=hiragana}', "");
Expect(0, 127488, '\P{Is_Script_Extensions=hiragana}', "");
Expect(1, 127488, '\P{^Is_Script_Extensions=hiragana}', "");
Expect(0, 127489, '\p{Is_Script_Extensions=hiragana}', "");
Expect(1, 127489, '\p{^Is_Script_Extensions=hiragana}', "");
Expect(1, 127489, '\P{Is_Script_Extensions=hiragana}', "");
Expect(0, 127489, '\P{^Is_Script_Extensions=hiragana}', "");
Expect(1, 127488, '\p{Is_Script_Extensions=-hiragana}', "");
Expect(0, 127488, '\p{^Is_Script_Extensions=-hiragana}', "");
Expect(0, 127488, '\P{Is_Script_Extensions=-hiragana}', "");
Expect(1, 127488, '\P{^Is_Script_Extensions=-hiragana}', "");
Expect(0, 127489, '\p{Is_Script_Extensions=-hiragana}', "");
Expect(1, 127489, '\p{^Is_Script_Extensions=-hiragana}', "");
Expect(1, 127489, '\P{Is_Script_Extensions=-hiragana}', "");
Expect(0, 127489, '\P{^Is_Script_Extensions=-hiragana}', "");
Error('\p{Is_Scx=		Hira/a/}');
Error('\P{Is_Scx=		Hira/a/}');
Expect(1, 127488, '\p{Is_Scx=hira}', "");
Expect(0, 127488, '\p{^Is_Scx=hira}', "");
Expect(0, 127488, '\P{Is_Scx=hira}', "");
Expect(1, 127488, '\P{^Is_Scx=hira}', "");
Expect(0, 127489, '\p{Is_Scx=hira}', "");
Expect(1, 127489, '\p{^Is_Scx=hira}', "");
Expect(1, 127489, '\P{Is_Scx=hira}', "");
Expect(0, 127489, '\P{^Is_Scx=hira}', "");
Expect(1, 127488, '\p{Is_Scx=__Hira}', "");
Expect(0, 127488, '\p{^Is_Scx=__Hira}', "");
Expect(0, 127488, '\P{Is_Scx=__Hira}', "");
Expect(1, 127488, '\P{^Is_Scx=__Hira}', "");
Expect(0, 127489, '\p{Is_Scx=__Hira}', "");
Expect(1, 127489, '\p{^Is_Scx=__Hira}', "");
Expect(1, 127489, '\P{Is_Scx=__Hira}', "");
Expect(0, 127489, '\P{^Is_Scx=__Hira}', "");
Error('\p{Script_Extensions=Katakana_Or_Hiragana}');
Error('\P{Script_Extensions=Katakana_Or_Hiragana}');
Error('\p{Scx=Hrkt}');
Error('\P{Scx=Hrkt}');
Error('\p{Is_Script_Extensions=Katakana_Or_Hiragana}');
Error('\P{Is_Script_Extensions=Katakana_Or_Hiragana}');
Error('\p{Is_Scx=Hrkt}');
Error('\P{Is_Scx=Hrkt}');
Error('\p{Script_Extensions=_OLD_Italic:=}');
Error('\P{Script_Extensions=_OLD_Italic:=}');
Expect(1, 66339, '\p{Script_Extensions=olditalic}', "");
Expect(0, 66339, '\p{^Script_Extensions=olditalic}', "");
Expect(0, 66339, '\P{Script_Extensions=olditalic}', "");
Expect(1, 66339, '\P{^Script_Extensions=olditalic}', "");
Expect(0, 66340, '\p{Script_Extensions=olditalic}', "");
Expect(1, 66340, '\p{^Script_Extensions=olditalic}', "");
Expect(1, 66340, '\P{Script_Extensions=olditalic}', "");
Expect(0, 66340, '\P{^Script_Extensions=olditalic}', "");
Expect(1, 66339, '\p{Script_Extensions= 	Old_Italic}', "");
Expect(0, 66339, '\p{^Script_Extensions= 	Old_Italic}', "");
Expect(0, 66339, '\P{Script_Extensions= 	Old_Italic}', "");
Expect(1, 66339, '\P{^Script_Extensions= 	Old_Italic}', "");
Expect(0, 66340, '\p{Script_Extensions= 	Old_Italic}', "");
Expect(1, 66340, '\p{^Script_Extensions= 	Old_Italic}', "");
Expect(1, 66340, '\P{Script_Extensions= 	Old_Italic}', "");
Expect(0, 66340, '\P{^Script_Extensions= 	Old_Italic}', "");
Error('\p{Scx=/a/--ITAL}');
Error('\P{Scx=/a/--ITAL}');
Expect(1, 66339, '\p{Scx:ital}', "");
Expect(0, 66339, '\p{^Scx:ital}', "");
Expect(0, 66339, '\P{Scx:ital}', "");
Expect(1, 66339, '\P{^Scx:ital}', "");
Expect(0, 66340, '\p{Scx:ital}', "");
Expect(1, 66340, '\p{^Scx:ital}', "");
Expect(1, 66340, '\P{Scx:ital}', "");
Expect(0, 66340, '\P{^Scx:ital}', "");
Expect(1, 66339, '\p{Scx=_Ital}', "");
Expect(0, 66339, '\p{^Scx=_Ital}', "");
Expect(0, 66339, '\P{Scx=_Ital}', "");
Expect(1, 66339, '\P{^Scx=_Ital}', "");
Expect(0, 66340, '\p{Scx=_Ital}', "");
Expect(1, 66340, '\p{^Scx=_Ital}', "");
Expect(1, 66340, '\P{Scx=_Ital}', "");
Expect(0, 66340, '\P{^Scx=_Ital}', "");
Error('\p{Is_Script_Extensions=_ old_Italic/a/}');
Error('\P{Is_Script_Extensions=_ old_Italic/a/}');
Expect(1, 66339, '\p{Is_Script_Extensions=olditalic}', "");
Expect(0, 66339, '\p{^Is_Script_Extensions=olditalic}', "");
Expect(0, 66339, '\P{Is_Script_Extensions=olditalic}', "");
Expect(1, 66339, '\P{^Is_Script_Extensions=olditalic}', "");
Expect(0, 66340, '\p{Is_Script_Extensions=olditalic}', "");
Expect(1, 66340, '\p{^Is_Script_Extensions=olditalic}', "");
Expect(1, 66340, '\P{Is_Script_Extensions=olditalic}', "");
Expect(0, 66340, '\P{^Is_Script_Extensions=olditalic}', "");
Expect(1, 66339, '\p{Is_Script_Extensions= -old_italic}', "");
Expect(0, 66339, '\p{^Is_Script_Extensions= -old_italic}', "");
Expect(0, 66339, '\P{Is_Script_Extensions= -old_italic}', "");
Expect(1, 66339, '\P{^Is_Script_Extensions= -old_italic}', "");
Expect(0, 66340, '\p{Is_Script_Extensions= -old_italic}', "");
Expect(1, 66340, '\p{^Is_Script_Extensions= -old_italic}', "");
Expect(1, 66340, '\P{Is_Script_Extensions= -old_italic}', "");
Expect(0, 66340, '\P{^Is_Script_Extensions= -old_italic}', "");
Error('\p{Is_Scx=-/a/ital}');
Error('\P{Is_Scx=-/a/ital}');
Expect(1, 66339, '\p{Is_Scx=ital}', "");
Expect(0, 66339, '\p{^Is_Scx=ital}', "");
Expect(0, 66339, '\P{Is_Scx=ital}', "");
Expect(1, 66339, '\P{^Is_Scx=ital}', "");
Expect(0, 66340, '\p{Is_Scx=ital}', "");
Expect(1, 66340, '\p{^Is_Scx=ital}', "");
Expect(1, 66340, '\P{Is_Scx=ital}', "");
Expect(0, 66340, '\P{^Is_Scx=ital}', "");
Expect(1, 66339, '\p{Is_Scx=_ital}', "");
Expect(0, 66339, '\p{^Is_Scx=_ital}', "");
Expect(0, 66339, '\P{Is_Scx=_ital}', "");
Expect(1, 66339, '\P{^Is_Scx=_ital}', "");
Expect(0, 66340, '\p{Is_Scx=_ital}', "");
Expect(1, 66340, '\p{^Is_Scx=_ital}', "");
Expect(1, 66340, '\P{Is_Scx=_ital}', "");
Expect(0, 66340, '\P{^Is_Scx=_ital}', "");
Error('\p{Script_Extensions=-_javanese/a/}');
Error('\P{Script_Extensions=-_javanese/a/}');
Expect(1, 43487, '\p{Script_Extensions=javanese}', "");
Expect(0, 43487, '\p{^Script_Extensions=javanese}', "");
Expect(0, 43487, '\P{Script_Extensions=javanese}', "");
Expect(1, 43487, '\P{^Script_Extensions=javanese}', "");
Expect(0, 43488, '\p{Script_Extensions=javanese}', "");
Expect(1, 43488, '\p{^Script_Extensions=javanese}', "");
Expect(1, 43488, '\P{Script_Extensions=javanese}', "");
Expect(0, 43488, '\P{^Script_Extensions=javanese}', "");
Expect(1, 43487, '\p{Script_Extensions=Javanese}', "");
Expect(0, 43487, '\p{^Script_Extensions=Javanese}', "");
Expect(0, 43487, '\P{Script_Extensions=Javanese}', "");
Expect(1, 43487, '\P{^Script_Extensions=Javanese}', "");
Expect(0, 43488, '\p{Script_Extensions=Javanese}', "");
Expect(1, 43488, '\p{^Script_Extensions=Javanese}', "");
Expect(1, 43488, '\P{Script_Extensions=Javanese}', "");
Expect(0, 43488, '\P{^Script_Extensions=Javanese}', "");
Error('\p{Scx: /a/ Java}');
Error('\P{Scx: /a/ Java}');
Expect(1, 43487, '\p{Scx=java}', "");
Expect(0, 43487, '\p{^Scx=java}', "");
Expect(0, 43487, '\P{Scx=java}', "");
Expect(1, 43487, '\P{^Scx=java}', "");
Expect(0, 43488, '\p{Scx=java}', "");
Expect(1, 43488, '\p{^Scx=java}', "");
Expect(1, 43488, '\P{Scx=java}', "");
Expect(0, 43488, '\P{^Scx=java}', "");
Expect(1, 43487, '\p{Scx=_ Java}', "");
Expect(0, 43487, '\p{^Scx=_ Java}', "");
Expect(0, 43487, '\P{Scx=_ Java}', "");
Expect(1, 43487, '\P{^Scx=_ Java}', "");
Expect(0, 43488, '\p{Scx=_ Java}', "");
Expect(1, 43488, '\p{^Scx=_ Java}', "");
Expect(1, 43488, '\P{Scx=_ Java}', "");
Expect(0, 43488, '\P{^Scx=_ Java}', "");
Error('\p{Is_Script_Extensions=/a/	-Javanese}');
Error('\P{Is_Script_Extensions=/a/	-Javanese}');
Expect(1, 43487, '\p{Is_Script_Extensions=javanese}', "");
Expect(0, 43487, '\p{^Is_Script_Extensions=javanese}', "");
Expect(0, 43487, '\P{Is_Script_Extensions=javanese}', "");
Expect(1, 43487, '\P{^Is_Script_Extensions=javanese}', "");
Expect(0, 43488, '\p{Is_Script_Extensions=javanese}', "");
Expect(1, 43488, '\p{^Is_Script_Extensions=javanese}', "");
Expect(1, 43488, '\P{Is_Script_Extensions=javanese}', "");
Expect(0, 43488, '\P{^Is_Script_Extensions=javanese}', "");
Expect(1, 43487, '\p{Is_Script_Extensions= -Javanese}', "");
Expect(0, 43487, '\p{^Is_Script_Extensions= -Javanese}', "");
Expect(0, 43487, '\P{Is_Script_Extensions= -Javanese}', "");
Expect(1, 43487, '\P{^Is_Script_Extensions= -Javanese}', "");
Expect(0, 43488, '\p{Is_Script_Extensions= -Javanese}', "");
Expect(1, 43488, '\p{^Is_Script_Extensions= -Javanese}', "");
Expect(1, 43488, '\P{Is_Script_Extensions= -Javanese}', "");
Expect(0, 43488, '\P{^Is_Script_Extensions= -Javanese}', "");
Error('\p{Is_Scx=:= 	JAVA}');
Error('\P{Is_Scx=:= 	JAVA}');
Expect(1, 43487, '\p{Is_Scx:   java}', "");
Expect(0, 43487, '\p{^Is_Scx:   java}', "");
Expect(0, 43487, '\P{Is_Scx:   java}', "");
Expect(1, 43487, '\P{^Is_Scx:   java}', "");
Expect(0, 43488, '\p{Is_Scx:   java}', "");
Expect(1, 43488, '\p{^Is_Scx:   java}', "");
Expect(1, 43488, '\P{Is_Scx:   java}', "");
Expect(0, 43488, '\P{^Is_Scx:   java}', "");
Expect(1, 43487, '\p{Is_Scx=	_JAVA}', "");
Expect(0, 43487, '\p{^Is_Scx=	_JAVA}', "");
Expect(0, 43487, '\P{Is_Scx=	_JAVA}', "");
Expect(1, 43487, '\P{^Is_Scx=	_JAVA}', "");
Expect(0, 43488, '\p{Is_Scx=	_JAVA}', "");
Expect(1, 43488, '\p{^Is_Scx=	_JAVA}', "");
Expect(1, 43488, '\P{Is_Scx=	_JAVA}', "");
Expect(0, 43488, '\P{^Is_Scx=	_JAVA}', "");
Error('\p{Script_Extensions=	/a/kayah_li}');
Error('\P{Script_Extensions=	/a/kayah_li}');
Expect(1, 43311, '\p{Script_Extensions=kayahli}', "");
Expect(0, 43311, '\p{^Script_Extensions=kayahli}', "");
Expect(0, 43311, '\P{Script_Extensions=kayahli}', "");
Expect(1, 43311, '\P{^Script_Extensions=kayahli}', "");
Expect(0, 43312, '\p{Script_Extensions=kayahli}', "");
Expect(1, 43312, '\p{^Script_Extensions=kayahli}', "");
Expect(1, 43312, '\P{Script_Extensions=kayahli}', "");
Expect(0, 43312, '\P{^Script_Extensions=kayahli}', "");
Expect(1, 43311, '\p{Script_Extensions=	Kayah_li}', "");
Expect(0, 43311, '\p{^Script_Extensions=	Kayah_li}', "");
Expect(0, 43311, '\P{Script_Extensions=	Kayah_li}', "");
Expect(1, 43311, '\P{^Script_Extensions=	Kayah_li}', "");
Expect(0, 43312, '\p{Script_Extensions=	Kayah_li}', "");
Expect(1, 43312, '\p{^Script_Extensions=	Kayah_li}', "");
Expect(1, 43312, '\P{Script_Extensions=	Kayah_li}', "");
Expect(0, 43312, '\P{^Script_Extensions=	Kayah_li}', "");
Error('\p{Scx=-Kali:=}');
Error('\P{Scx=-Kali:=}');
Expect(1, 43311, '\p{Scx=kali}', "");
Expect(0, 43311, '\p{^Scx=kali}', "");
Expect(0, 43311, '\P{Scx=kali}', "");
Expect(1, 43311, '\P{^Scx=kali}', "");
Expect(0, 43312, '\p{Scx=kali}', "");
Expect(1, 43312, '\p{^Scx=kali}', "");
Expect(1, 43312, '\P{Scx=kali}', "");
Expect(0, 43312, '\P{^Scx=kali}', "");
Expect(1, 43311, '\p{Scx= Kali}', "");
Expect(0, 43311, '\p{^Scx= Kali}', "");
Expect(0, 43311, '\P{Scx= Kali}', "");
Expect(1, 43311, '\P{^Scx= Kali}', "");
Expect(0, 43312, '\p{Scx= Kali}', "");
Expect(1, 43312, '\p{^Scx= Kali}', "");
Expect(1, 43312, '\P{Scx= Kali}', "");
Expect(0, 43312, '\P{^Scx= Kali}', "");
Error('\p{Is_Script_Extensions=-Kayah_LI/a/}');
Error('\P{Is_Script_Extensions=-Kayah_LI/a/}');
Expect(1, 43311, '\p{Is_Script_Extensions=kayahli}', "");
Expect(0, 43311, '\p{^Is_Script_Extensions=kayahli}', "");
Expect(0, 43311, '\P{Is_Script_Extensions=kayahli}', "");
Expect(1, 43311, '\P{^Is_Script_Extensions=kayahli}', "");
Expect(0, 43312, '\p{Is_Script_Extensions=kayahli}', "");
Expect(1, 43312, '\p{^Is_Script_Extensions=kayahli}', "");
Expect(1, 43312, '\P{Is_Script_Extensions=kayahli}', "");
Expect(0, 43312, '\P{^Is_Script_Extensions=kayahli}', "");
Expect(1, 43311, '\p{Is_Script_Extensions=	-Kayah_li}', "");
Expect(0, 43311, '\p{^Is_Script_Extensions=	-Kayah_li}', "");
Expect(0, 43311, '\P{Is_Script_Extensions=	-Kayah_li}', "");
Expect(1, 43311, '\P{^Is_Script_Extensions=	-Kayah_li}', "");
Expect(0, 43312, '\p{Is_Script_Extensions=	-Kayah_li}', "");
Expect(1, 43312, '\p{^Is_Script_Extensions=	-Kayah_li}', "");
Expect(1, 43312, '\P{Is_Script_Extensions=	-Kayah_li}', "");
Expect(0, 43312, '\P{^Is_Script_Extensions=	-Kayah_li}', "");
Error('\p{Is_Scx:   /a/_kali}');
Error('\P{Is_Scx:   /a/_kali}');
Expect(1, 43311, '\p{Is_Scx=kali}', "");
Expect(0, 43311, '\p{^Is_Scx=kali}', "");
Expect(0, 43311, '\P{Is_Scx=kali}', "");
Expect(1, 43311, '\P{^Is_Scx=kali}', "");
Expect(0, 43312, '\p{Is_Scx=kali}', "");
Expect(1, 43312, '\p{^Is_Scx=kali}', "");
Expect(1, 43312, '\P{Is_Scx=kali}', "");
Expect(0, 43312, '\P{^Is_Scx=kali}', "");
Expect(1, 43311, '\p{Is_Scx:   -	Kali}', "");
Expect(0, 43311, '\p{^Is_Scx:   -	Kali}', "");
Expect(0, 43311, '\P{Is_Scx:   -	Kali}', "");
Expect(1, 43311, '\P{^Is_Scx:   -	Kali}', "");
Expect(0, 43312, '\p{Is_Scx:   -	Kali}', "");
Expect(1, 43312, '\p{^Is_Scx:   -	Kali}', "");
Expect(1, 43312, '\P{Is_Scx:   -	Kali}', "");
Expect(0, 43312, '\P{^Is_Scx:   -	Kali}', "");
Error('\p{Script_Extensions=	_Katakana/a/}');
Error('\P{Script_Extensions=	_Katakana/a/}');
Expect(1, 110592, '\p{Script_Extensions=katakana}', "");
Expect(0, 110592, '\p{^Script_Extensions=katakana}', "");
Expect(0, 110592, '\P{Script_Extensions=katakana}', "");
Expect(1, 110592, '\P{^Script_Extensions=katakana}', "");
Expect(0, 110593, '\p{Script_Extensions=katakana}', "");
Expect(1, 110593, '\p{^Script_Extensions=katakana}', "");
Expect(1, 110593, '\P{Script_Extensions=katakana}', "");
Expect(0, 110593, '\P{^Script_Extensions=katakana}', "");
Expect(1, 110592, '\p{Script_Extensions=- Katakana}', "");
Expect(0, 110592, '\p{^Script_Extensions=- Katakana}', "");
Expect(0, 110592, '\P{Script_Extensions=- Katakana}', "");
Expect(1, 110592, '\P{^Script_Extensions=- Katakana}', "");
Expect(0, 110593, '\p{Script_Extensions=- Katakana}', "");
Expect(1, 110593, '\p{^Script_Extensions=- Katakana}', "");
Expect(1, 110593, '\P{Script_Extensions=- Katakana}', "");
Expect(0, 110593, '\P{^Script_Extensions=- Katakana}', "");
Error('\p{Scx=/a/  KANA}');
Error('\P{Scx=/a/  KANA}');
Expect(1, 110592, '\p{Scx=kana}', "");
Expect(0, 110592, '\p{^Scx=kana}', "");
Expect(0, 110592, '\P{Scx=kana}', "");
Expect(1, 110592, '\P{^Scx=kana}', "");
Expect(0, 110593, '\p{Scx=kana}', "");
Expect(1, 110593, '\p{^Scx=kana}', "");
Expect(1, 110593, '\P{Scx=kana}', "");
Expect(0, 110593, '\P{^Scx=kana}', "");
Expect(1, 110592, '\p{Scx= -kana}', "");
Expect(0, 110592, '\p{^Scx= -kana}', "");
Expect(0, 110592, '\P{Scx= -kana}', "");
Expect(1, 110592, '\P{^Scx= -kana}', "");
Expect(0, 110593, '\p{Scx= -kana}', "");
Expect(1, 110593, '\p{^Scx= -kana}', "");
Expect(1, 110593, '\P{Scx= -kana}', "");
Expect(0, 110593, '\P{^Scx= -kana}', "");
Error('\p{Is_Script_Extensions:	/a/	Katakana}');
Error('\P{Is_Script_Extensions:	/a/	Katakana}');
Expect(1, 110592, '\p{Is_Script_Extensions=katakana}', "");
Expect(0, 110592, '\p{^Is_Script_Extensions=katakana}', "");
Expect(0, 110592, '\P{Is_Script_Extensions=katakana}', "");
Expect(1, 110592, '\P{^Is_Script_Extensions=katakana}', "");
Expect(0, 110593, '\p{Is_Script_Extensions=katakana}', "");
Expect(1, 110593, '\p{^Is_Script_Extensions=katakana}', "");
Expect(1, 110593, '\P{Is_Script_Extensions=katakana}', "");
Expect(0, 110593, '\P{^Is_Script_Extensions=katakana}', "");
Expect(1, 110592, '\p{Is_Script_Extensions=	 KATAKANA}', "");
Expect(0, 110592, '\p{^Is_Script_Extensions=	 KATAKANA}', "");
Expect(0, 110592, '\P{Is_Script_Extensions=	 KATAKANA}', "");
Expect(1, 110592, '\P{^Is_Script_Extensions=	 KATAKANA}', "");
Expect(0, 110593, '\p{Is_Script_Extensions=	 KATAKANA}', "");
Expect(1, 110593, '\p{^Is_Script_Extensions=	 KATAKANA}', "");
Expect(1, 110593, '\P{Is_Script_Extensions=	 KATAKANA}', "");
Expect(0, 110593, '\P{^Is_Script_Extensions=	 KATAKANA}', "");
Error('\p{Is_Scx=--Kana/a/}');
Error('\P{Is_Scx=--Kana/a/}');
Expect(1, 110592, '\p{Is_Scx=kana}', "");
Expect(0, 110592, '\p{^Is_Scx=kana}', "");
Expect(0, 110592, '\P{Is_Scx=kana}', "");
Expect(1, 110592, '\P{^Is_Scx=kana}', "");
Expect(0, 110593, '\p{Is_Scx=kana}', "");
Expect(1, 110593, '\p{^Is_Scx=kana}', "");
Expect(1, 110593, '\P{Is_Scx=kana}', "");
Expect(0, 110593, '\P{^Is_Scx=kana}', "");
Expect(1, 110592, '\p{Is_Scx=Kana}', "");
Expect(0, 110592, '\p{^Is_Scx=Kana}', "");
Expect(0, 110592, '\P{Is_Scx=Kana}', "");
Expect(1, 110592, '\P{^Is_Scx=Kana}', "");
Expect(0, 110593, '\p{Is_Scx=Kana}', "");
Expect(1, 110593, '\p{^Is_Scx=Kana}', "");
Expect(1, 110593, '\P{Is_Scx=Kana}', "");
Expect(0, 110593, '\P{^Is_Scx=Kana}', "");
Error('\p{Script_Extensions=	_kharoshthi/a/}');
Error('\P{Script_Extensions=	_kharoshthi/a/}');
Expect(1, 68184, '\p{Script_Extensions=kharoshthi}', "");
Expect(0, 68184, '\p{^Script_Extensions=kharoshthi}', "");
Expect(0, 68184, '\P{Script_Extensions=kharoshthi}', "");
Expect(1, 68184, '\P{^Script_Extensions=kharoshthi}', "");
Expect(0, 68185, '\p{Script_Extensions=kharoshthi}', "");
Expect(1, 68185, '\p{^Script_Extensions=kharoshthi}', "");
Expect(1, 68185, '\P{Script_Extensions=kharoshthi}', "");
Expect(0, 68185, '\P{^Script_Extensions=kharoshthi}', "");
Expect(1, 68184, '\p{Script_Extensions= KHAROSHTHI}', "");
Expect(0, 68184, '\p{^Script_Extensions= KHAROSHTHI}', "");
Expect(0, 68184, '\P{Script_Extensions= KHAROSHTHI}', "");
Expect(1, 68184, '\P{^Script_Extensions= KHAROSHTHI}', "");
Expect(0, 68185, '\p{Script_Extensions= KHAROSHTHI}', "");
Expect(1, 68185, '\p{^Script_Extensions= KHAROSHTHI}', "");
Expect(1, 68185, '\P{Script_Extensions= KHAROSHTHI}', "");
Expect(0, 68185, '\P{^Script_Extensions= KHAROSHTHI}', "");
Error('\p{Scx=	:=KHAR}');
Error('\P{Scx=	:=KHAR}');
Expect(1, 68184, '\p{Scx=khar}', "");
Expect(0, 68184, '\p{^Scx=khar}', "");
Expect(0, 68184, '\P{Scx=khar}', "");
Expect(1, 68184, '\P{^Scx=khar}', "");
Expect(0, 68185, '\p{Scx=khar}', "");
Expect(1, 68185, '\p{^Scx=khar}', "");
Expect(1, 68185, '\P{Scx=khar}', "");
Expect(0, 68185, '\P{^Scx=khar}', "");
Expect(1, 68184, '\p{Scx=_	khar}', "");
Expect(0, 68184, '\p{^Scx=_	khar}', "");
Expect(0, 68184, '\P{Scx=_	khar}', "");
Expect(1, 68184, '\P{^Scx=_	khar}', "");
Expect(0, 68185, '\p{Scx=_	khar}', "");
Expect(1, 68185, '\p{^Scx=_	khar}', "");
Expect(1, 68185, '\P{Scx=_	khar}', "");
Expect(0, 68185, '\P{^Scx=_	khar}', "");
Error('\p{Is_Script_Extensions:   	Kharoshthi/a/}');
Error('\P{Is_Script_Extensions:   	Kharoshthi/a/}');
Expect(1, 68184, '\p{Is_Script_Extensions=kharoshthi}', "");
Expect(0, 68184, '\p{^Is_Script_Extensions=kharoshthi}', "");
Expect(0, 68184, '\P{Is_Script_Extensions=kharoshthi}', "");
Expect(1, 68184, '\P{^Is_Script_Extensions=kharoshthi}', "");
Expect(0, 68185, '\p{Is_Script_Extensions=kharoshthi}', "");
Expect(1, 68185, '\p{^Is_Script_Extensions=kharoshthi}', "");
Expect(1, 68185, '\P{Is_Script_Extensions=kharoshthi}', "");
Expect(0, 68185, '\P{^Is_Script_Extensions=kharoshthi}', "");
Expect(1, 68184, '\p{Is_Script_Extensions=	 Kharoshthi}', "");
Expect(0, 68184, '\p{^Is_Script_Extensions=	 Kharoshthi}', "");
Expect(0, 68184, '\P{Is_Script_Extensions=	 Kharoshthi}', "");
Expect(1, 68184, '\P{^Is_Script_Extensions=	 Kharoshthi}', "");
Expect(0, 68185, '\p{Is_Script_Extensions=	 Kharoshthi}', "");
Expect(1, 68185, '\p{^Is_Script_Extensions=	 Kharoshthi}', "");
Expect(1, 68185, '\P{Is_Script_Extensions=	 Kharoshthi}', "");
Expect(0, 68185, '\P{^Is_Script_Extensions=	 Kharoshthi}', "");
Error('\p{Is_Scx=	 Khar:=}');
Error('\P{Is_Scx=	 Khar:=}');
Expect(1, 68184, '\p{Is_Scx=khar}', "");
Expect(0, 68184, '\p{^Is_Scx=khar}', "");
Expect(0, 68184, '\P{Is_Scx=khar}', "");
Expect(1, 68184, '\P{^Is_Scx=khar}', "");
Expect(0, 68185, '\p{Is_Scx=khar}', "");
Expect(1, 68185, '\p{^Is_Scx=khar}', "");
Expect(1, 68185, '\P{Is_Scx=khar}', "");
Expect(0, 68185, '\P{^Is_Scx=khar}', "");
Expect(1, 68184, '\p{Is_Scx=-_Khar}', "");
Expect(0, 68184, '\p{^Is_Scx=-_Khar}', "");
Expect(0, 68184, '\P{Is_Scx=-_Khar}', "");
Expect(1, 68184, '\P{^Is_Scx=-_Khar}', "");
Expect(0, 68185, '\p{Is_Scx=-_Khar}', "");
Expect(1, 68185, '\p{^Is_Scx=-_Khar}', "");
Expect(1, 68185, '\P{Is_Scx=-_Khar}', "");
Expect(0, 68185, '\P{^Is_Scx=-_Khar}', "");
Error('\p{Script_Extensions=:= khmer}');
Error('\P{Script_Extensions=:= khmer}');
Expect(1, 6655, '\p{Script_Extensions=khmer}', "");
Expect(0, 6655, '\p{^Script_Extensions=khmer}', "");
Expect(0, 6655, '\P{Script_Extensions=khmer}', "");
Expect(1, 6655, '\P{^Script_Extensions=khmer}', "");
Expect(0, 6656, '\p{Script_Extensions=khmer}', "");
Expect(1, 6656, '\p{^Script_Extensions=khmer}', "");
Expect(1, 6656, '\P{Script_Extensions=khmer}', "");
Expect(0, 6656, '\P{^Script_Extensions=khmer}', "");
Expect(1, 6655, '\p{Script_Extensions=_-KHMER}', "");
Expect(0, 6655, '\p{^Script_Extensions=_-KHMER}', "");
Expect(0, 6655, '\P{Script_Extensions=_-KHMER}', "");
Expect(1, 6655, '\P{^Script_Extensions=_-KHMER}', "");
Expect(0, 6656, '\p{Script_Extensions=_-KHMER}', "");
Expect(1, 6656, '\p{^Script_Extensions=_-KHMER}', "");
Expect(1, 6656, '\P{Script_Extensions=_-KHMER}', "");
Expect(0, 6656, '\P{^Script_Extensions=_-KHMER}', "");
Error('\p{Scx=/a/- KHMR}');
Error('\P{Scx=/a/- KHMR}');
Expect(1, 6655, '\p{Scx=khmr}', "");
Expect(0, 6655, '\p{^Scx=khmr}', "");
Expect(0, 6655, '\P{Scx=khmr}', "");
Expect(1, 6655, '\P{^Scx=khmr}', "");
Expect(0, 6656, '\p{Scx=khmr}', "");
Expect(1, 6656, '\p{^Scx=khmr}', "");
Expect(1, 6656, '\P{Scx=khmr}', "");
Expect(0, 6656, '\P{^Scx=khmr}', "");
Expect(1, 6655, '\p{Scx=	khmr}', "");
Expect(0, 6655, '\p{^Scx=	khmr}', "");
Expect(0, 6655, '\P{Scx=	khmr}', "");
Expect(1, 6655, '\P{^Scx=	khmr}', "");
Expect(0, 6656, '\p{Scx=	khmr}', "");
Expect(1, 6656, '\p{^Scx=	khmr}', "");
Expect(1, 6656, '\P{Scx=	khmr}', "");
Expect(0, 6656, '\P{^Scx=	khmr}', "");
Error('\p{Is_Script_Extensions:   -_khmer:=}');
Error('\P{Is_Script_Extensions:   -_khmer:=}');
Expect(1, 6655, '\p{Is_Script_Extensions=khmer}', "");
Expect(0, 6655, '\p{^Is_Script_Extensions=khmer}', "");
Expect(0, 6655, '\P{Is_Script_Extensions=khmer}', "");
Expect(1, 6655, '\P{^Is_Script_Extensions=khmer}', "");
Expect(0, 6656, '\p{Is_Script_Extensions=khmer}', "");
Expect(1, 6656, '\p{^Is_Script_Extensions=khmer}', "");
Expect(1, 6656, '\P{Is_Script_Extensions=khmer}', "");
Expect(0, 6656, '\P{^Is_Script_Extensions=khmer}', "");
Expect(1, 6655, '\p{Is_Script_Extensions:   	 Khmer}', "");
Expect(0, 6655, '\p{^Is_Script_Extensions:   	 Khmer}', "");
Expect(0, 6655, '\P{Is_Script_Extensions:   	 Khmer}', "");
Expect(1, 6655, '\P{^Is_Script_Extensions:   	 Khmer}', "");
Expect(0, 6656, '\p{Is_Script_Extensions:   	 Khmer}', "");
Expect(1, 6656, '\p{^Is_Script_Extensions:   	 Khmer}', "");
Expect(1, 6656, '\P{Is_Script_Extensions:   	 Khmer}', "");
Expect(0, 6656, '\P{^Is_Script_Extensions:   	 Khmer}', "");
Error('\p{Is_Scx=:=-Khmr}');
Error('\P{Is_Scx=:=-Khmr}');
Expect(1, 6655, '\p{Is_Scx=khmr}', "");
Expect(0, 6655, '\p{^Is_Scx=khmr}', "");
Expect(0, 6655, '\P{Is_Scx=khmr}', "");
Expect(1, 6655, '\P{^Is_Scx=khmr}', "");
Expect(0, 6656, '\p{Is_Scx=khmr}', "");
Expect(1, 6656, '\p{^Is_Scx=khmr}', "");
Expect(1, 6656, '\P{Is_Scx=khmr}', "");
Expect(0, 6656, '\P{^Is_Scx=khmr}', "");
Expect(1, 6655, '\p{Is_Scx=_KHMR}', "");
Expect(0, 6655, '\p{^Is_Scx=_KHMR}', "");
Expect(0, 6655, '\P{Is_Scx=_KHMR}', "");
Expect(1, 6655, '\P{^Is_Scx=_KHMR}', "");
Expect(0, 6656, '\p{Is_Scx=_KHMR}', "");
Expect(1, 6656, '\p{^Is_Scx=_KHMR}', "");
Expect(1, 6656, '\P{Is_Scx=_KHMR}', "");
Expect(0, 6656, '\P{^Is_Scx=_KHMR}', "");
Error('\p{Script_Extensions:   	:=KANNADA}');
Error('\P{Script_Extensions:   	:=KANNADA}');
Expect(1, 3314, '\p{Script_Extensions=kannada}', "");
Expect(0, 3314, '\p{^Script_Extensions=kannada}', "");
Expect(0, 3314, '\P{Script_Extensions=kannada}', "");
Expect(1, 3314, '\P{^Script_Extensions=kannada}', "");
Expect(0, 3315, '\p{Script_Extensions=kannada}', "");
Expect(1, 3315, '\p{^Script_Extensions=kannada}', "");
Expect(1, 3315, '\P{Script_Extensions=kannada}', "");
Expect(0, 3315, '\P{^Script_Extensions=kannada}', "");
Expect(1, 3314, '\p{Script_Extensions=		KANNADA}', "");
Expect(0, 3314, '\p{^Script_Extensions=		KANNADA}', "");
Expect(0, 3314, '\P{Script_Extensions=		KANNADA}', "");
Expect(1, 3314, '\P{^Script_Extensions=		KANNADA}', "");
Expect(0, 3315, '\p{Script_Extensions=		KANNADA}', "");
Expect(1, 3315, '\p{^Script_Extensions=		KANNADA}', "");
Expect(1, 3315, '\P{Script_Extensions=		KANNADA}', "");
Expect(0, 3315, '\P{^Script_Extensions=		KANNADA}', "");
Error('\p{Scx=	/a/KNDA}');
Error('\P{Scx=	/a/KNDA}');
Expect(1, 3314, '\p{Scx=knda}', "");
Expect(0, 3314, '\p{^Scx=knda}', "");
Expect(0, 3314, '\P{Scx=knda}', "");
Expect(1, 3314, '\P{^Scx=knda}', "");
Expect(0, 3315, '\p{Scx=knda}', "");
Expect(1, 3315, '\p{^Scx=knda}', "");
Expect(1, 3315, '\P{Scx=knda}', "");
Expect(0, 3315, '\P{^Scx=knda}', "");
Expect(1, 3314, '\p{Scx=-knda}', "");
Expect(0, 3314, '\p{^Scx=-knda}', "");
Expect(0, 3314, '\P{Scx=-knda}', "");
Expect(1, 3314, '\P{^Scx=-knda}', "");
Expect(0, 3315, '\p{Scx=-knda}', "");
Expect(1, 3315, '\p{^Scx=-knda}', "");
Expect(1, 3315, '\P{Scx=-knda}', "");
Expect(0, 3315, '\P{^Scx=-knda}', "");
Error('\p{Is_Script_Extensions= :=Kannada}');
Error('\P{Is_Script_Extensions= :=Kannada}');
Expect(1, 3314, '\p{Is_Script_Extensions: kannada}', "");
Expect(0, 3314, '\p{^Is_Script_Extensions: kannada}', "");
Expect(0, 3314, '\P{Is_Script_Extensions: kannada}', "");
Expect(1, 3314, '\P{^Is_Script_Extensions: kannada}', "");
Expect(0, 3315, '\p{Is_Script_Extensions: kannada}', "");
Expect(1, 3315, '\p{^Is_Script_Extensions: kannada}', "");
Expect(1, 3315, '\P{Is_Script_Extensions: kannada}', "");
Expect(0, 3315, '\P{^Is_Script_Extensions: kannada}', "");
Expect(1, 3314, '\p{Is_Script_Extensions=-KANNADA}', "");
Expect(0, 3314, '\p{^Is_Script_Extensions=-KANNADA}', "");
Expect(0, 3314, '\P{Is_Script_Extensions=-KANNADA}', "");
Expect(1, 3314, '\P{^Is_Script_Extensions=-KANNADA}', "");
Expect(0, 3315, '\p{Is_Script_Extensions=-KANNADA}', "");
Expect(1, 3315, '\p{^Is_Script_Extensions=-KANNADA}', "");
Expect(1, 3315, '\P{Is_Script_Extensions=-KANNADA}', "");
Expect(0, 3315, '\P{^Is_Script_Extensions=-KANNADA}', "");
Error('\p{Is_Scx=_:=Knda}');
Error('\P{Is_Scx=_:=Knda}');
Expect(1, 3314, '\p{Is_Scx=knda}', "");
Expect(0, 3314, '\p{^Is_Scx=knda}', "");
Expect(0, 3314, '\P{Is_Scx=knda}', "");
Expect(1, 3314, '\P{^Is_Scx=knda}', "");
Expect(0, 3315, '\p{Is_Scx=knda}', "");
Expect(1, 3315, '\p{^Is_Scx=knda}', "");
Expect(1, 3315, '\P{Is_Scx=knda}', "");
Expect(0, 3315, '\P{^Is_Scx=knda}', "");
Expect(1, 3314, '\p{Is_Scx= Knda}', "");
Expect(0, 3314, '\p{^Is_Scx= Knda}', "");
Expect(0, 3314, '\P{Is_Scx= Knda}', "");
Expect(1, 3314, '\P{^Is_Scx= Knda}', "");
Expect(0, 3315, '\p{Is_Scx= Knda}', "");
Expect(1, 3315, '\p{^Is_Scx= Knda}', "");
Expect(1, 3315, '\P{Is_Scx= Knda}', "");
Expect(0, 3315, '\P{^Is_Scx= Knda}', "");
Error('\p{Script_Extensions=_ Kaithi:=}');
Error('\P{Script_Extensions=_ Kaithi:=}');
Expect(1, 69825, '\p{Script_Extensions=kaithi}', "");
Expect(0, 69825, '\p{^Script_Extensions=kaithi}', "");
Expect(0, 69825, '\P{Script_Extensions=kaithi}', "");
Expect(1, 69825, '\P{^Script_Extensions=kaithi}', "");
Expect(0, 69826, '\p{Script_Extensions=kaithi}', "");
Expect(1, 69826, '\p{^Script_Extensions=kaithi}', "");
Expect(1, 69826, '\P{Script_Extensions=kaithi}', "");
Expect(0, 69826, '\P{^Script_Extensions=kaithi}', "");
Expect(1, 69825, '\p{Script_Extensions:	-	kaithi}', "");
Expect(0, 69825, '\p{^Script_Extensions:	-	kaithi}', "");
Expect(0, 69825, '\P{Script_Extensions:	-	kaithi}', "");
Expect(1, 69825, '\P{^Script_Extensions:	-	kaithi}', "");
Expect(0, 69826, '\p{Script_Extensions:	-	kaithi}', "");
Expect(1, 69826, '\p{^Script_Extensions:	-	kaithi}', "");
Expect(1, 69826, '\P{Script_Extensions:	-	kaithi}', "");
Expect(0, 69826, '\P{^Script_Extensions:	-	kaithi}', "");
Error('\p{Scx=/a/- Kthi}');
Error('\P{Scx=/a/- Kthi}');
Expect(1, 69825, '\p{Scx=kthi}', "");
Expect(0, 69825, '\p{^Scx=kthi}', "");
Expect(0, 69825, '\P{Scx=kthi}', "");
Expect(1, 69825, '\P{^Scx=kthi}', "");
Expect(0, 69826, '\p{Scx=kthi}', "");
Expect(1, 69826, '\p{^Scx=kthi}', "");
Expect(1, 69826, '\P{Scx=kthi}', "");
Expect(0, 69826, '\P{^Scx=kthi}', "");
Expect(1, 69825, '\p{Scx= -KTHI}', "");
Expect(0, 69825, '\p{^Scx= -KTHI}', "");
Expect(0, 69825, '\P{Scx= -KTHI}', "");
Expect(1, 69825, '\P{^Scx= -KTHI}', "");
Expect(0, 69826, '\p{Scx= -KTHI}', "");
Expect(1, 69826, '\p{^Scx= -KTHI}', "");
Expect(1, 69826, '\P{Scx= -KTHI}', "");
Expect(0, 69826, '\P{^Scx= -KTHI}', "");
Error('\p{Is_Script_Extensions=/a/_ kaithi}');
Error('\P{Is_Script_Extensions=/a/_ kaithi}');
Expect(1, 69825, '\p{Is_Script_Extensions=kaithi}', "");
Expect(0, 69825, '\p{^Is_Script_Extensions=kaithi}', "");
Expect(0, 69825, '\P{Is_Script_Extensions=kaithi}', "");
Expect(1, 69825, '\P{^Is_Script_Extensions=kaithi}', "");
Expect(0, 69826, '\p{Is_Script_Extensions=kaithi}', "");
Expect(1, 69826, '\p{^Is_Script_Extensions=kaithi}', "");
Expect(1, 69826, '\P{Is_Script_Extensions=kaithi}', "");
Expect(0, 69826, '\P{^Is_Script_Extensions=kaithi}', "");
Expect(1, 69825, '\p{Is_Script_Extensions=	-KAITHI}', "");
Expect(0, 69825, '\p{^Is_Script_Extensions=	-KAITHI}', "");
Expect(0, 69825, '\P{Is_Script_Extensions=	-KAITHI}', "");
Expect(1, 69825, '\P{^Is_Script_Extensions=	-KAITHI}', "");
Expect(0, 69826, '\p{Is_Script_Extensions=	-KAITHI}', "");
Expect(1, 69826, '\p{^Is_Script_Extensions=	-KAITHI}', "");
Expect(1, 69826, '\P{Is_Script_Extensions=	-KAITHI}', "");
Expect(0, 69826, '\P{^Is_Script_Extensions=	-KAITHI}', "");
Error('\p{Is_Scx=:=_KTHI}');
Error('\P{Is_Scx=:=_KTHI}');
Expect(1, 69825, '\p{Is_Scx:kthi}', "");
Expect(0, 69825, '\p{^Is_Scx:kthi}', "");
Expect(0, 69825, '\P{Is_Scx:kthi}', "");
Expect(1, 69825, '\P{^Is_Scx:kthi}', "");
Expect(0, 69826, '\p{Is_Scx:kthi}', "");
Expect(1, 69826, '\p{^Is_Scx:kthi}', "");
Expect(1, 69826, '\P{Is_Scx:kthi}', "");
Expect(0, 69826, '\P{^Is_Scx:kthi}', "");
Expect(1, 69825, '\p{Is_Scx=_KTHI}', "");
Expect(0, 69825, '\p{^Is_Scx=_KTHI}', "");
Expect(0, 69825, '\P{Is_Scx=_KTHI}', "");
Expect(1, 69825, '\P{^Is_Scx=_KTHI}', "");
Expect(0, 69826, '\p{Is_Scx=_KTHI}', "");
Expect(1, 69826, '\p{^Is_Scx=_KTHI}', "");
Expect(1, 69826, '\P{Is_Scx=_KTHI}', "");
Expect(0, 69826, '\P{^Is_Scx=_KTHI}', "");
Error('\p{Script_Extensions=__TAI_tham:=}');
Error('\P{Script_Extensions=__TAI_tham:=}');
Expect(1, 6829, '\p{Script_Extensions=taitham}', "");
Expect(0, 6829, '\p{^Script_Extensions=taitham}', "");
Expect(0, 6829, '\P{Script_Extensions=taitham}', "");
Expect(1, 6829, '\P{^Script_Extensions=taitham}', "");
Expect(0, 6830, '\p{Script_Extensions=taitham}', "");
Expect(1, 6830, '\p{^Script_Extensions=taitham}', "");
Expect(1, 6830, '\P{Script_Extensions=taitham}', "");
Expect(0, 6830, '\P{^Script_Extensions=taitham}', "");
Expect(1, 6829, '\p{Script_Extensions= Tai_THAM}', "");
Expect(0, 6829, '\p{^Script_Extensions= Tai_THAM}', "");
Expect(0, 6829, '\P{Script_Extensions= Tai_THAM}', "");
Expect(1, 6829, '\P{^Script_Extensions= Tai_THAM}', "");
Expect(0, 6830, '\p{Script_Extensions= Tai_THAM}', "");
Expect(1, 6830, '\p{^Script_Extensions= Tai_THAM}', "");
Expect(1, 6830, '\P{Script_Extensions= Tai_THAM}', "");
Expect(0, 6830, '\P{^Script_Extensions= Tai_THAM}', "");
Error('\p{Scx= /a/LANA}');
Error('\P{Scx= /a/LANA}');
Expect(1, 6829, '\p{Scx=lana}', "");
Expect(0, 6829, '\p{^Scx=lana}', "");
Expect(0, 6829, '\P{Scx=lana}', "");
Expect(1, 6829, '\P{^Scx=lana}', "");
Expect(0, 6830, '\p{Scx=lana}', "");
Expect(1, 6830, '\p{^Scx=lana}', "");
Expect(1, 6830, '\P{Scx=lana}', "");
Expect(0, 6830, '\P{^Scx=lana}', "");
Expect(1, 6829, '\p{Scx=		Lana}', "");
Expect(0, 6829, '\p{^Scx=		Lana}', "");
Expect(0, 6829, '\P{Scx=		Lana}', "");
Expect(1, 6829, '\P{^Scx=		Lana}', "");
Expect(0, 6830, '\p{Scx=		Lana}', "");
Expect(1, 6830, '\p{^Scx=		Lana}', "");
Expect(1, 6830, '\P{Scx=		Lana}', "");
Expect(0, 6830, '\P{^Scx=		Lana}', "");
Error('\p{Is_Script_Extensions:	/a/ -TAI_Tham}');
Error('\P{Is_Script_Extensions:	/a/ -TAI_Tham}');
Expect(1, 6829, '\p{Is_Script_Extensions=taitham}', "");
Expect(0, 6829, '\p{^Is_Script_Extensions=taitham}', "");
Expect(0, 6829, '\P{Is_Script_Extensions=taitham}', "");
Expect(1, 6829, '\P{^Is_Script_Extensions=taitham}', "");
Expect(0, 6830, '\p{Is_Script_Extensions=taitham}', "");
Expect(1, 6830, '\p{^Is_Script_Extensions=taitham}', "");
Expect(1, 6830, '\P{Is_Script_Extensions=taitham}', "");
Expect(0, 6830, '\P{^Is_Script_Extensions=taitham}', "");
Expect(1, 6829, '\p{Is_Script_Extensions=__Tai_Tham}', "");
Expect(0, 6829, '\p{^Is_Script_Extensions=__Tai_Tham}', "");
Expect(0, 6829, '\P{Is_Script_Extensions=__Tai_Tham}', "");
Expect(1, 6829, '\P{^Is_Script_Extensions=__Tai_Tham}', "");
Expect(0, 6830, '\p{Is_Script_Extensions=__Tai_Tham}', "");
Expect(1, 6830, '\p{^Is_Script_Extensions=__Tai_Tham}', "");
Expect(1, 6830, '\P{Is_Script_Extensions=__Tai_Tham}', "");
Expect(0, 6830, '\P{^Is_Script_Extensions=__Tai_Tham}', "");
Error('\p{Is_Scx=_Lana/a/}');
Error('\P{Is_Scx=_Lana/a/}');
Expect(1, 6829, '\p{Is_Scx: lana}', "");
Expect(0, 6829, '\p{^Is_Scx: lana}', "");
Expect(0, 6829, '\P{Is_Scx: lana}', "");
Expect(1, 6829, '\P{^Is_Scx: lana}', "");
Expect(0, 6830, '\p{Is_Scx: lana}', "");
Expect(1, 6830, '\p{^Is_Scx: lana}', "");
Expect(1, 6830, '\P{Is_Scx: lana}', "");
Expect(0, 6830, '\P{^Is_Scx: lana}', "");
Expect(1, 6829, '\p{Is_Scx=	-lana}', "");
Expect(0, 6829, '\p{^Is_Scx=	-lana}', "");
Expect(0, 6829, '\P{Is_Scx=	-lana}', "");
Expect(1, 6829, '\P{^Is_Scx=	-lana}', "");
Expect(0, 6830, '\p{Is_Scx=	-lana}', "");
Expect(1, 6830, '\p{^Is_Scx=	-lana}', "");
Expect(1, 6830, '\P{Is_Scx=	-lana}', "");
Expect(0, 6830, '\P{^Is_Scx=	-lana}', "");
Error('\p{Script_Extensions=_:=Lao}');
Error('\P{Script_Extensions=_:=Lao}');
Expect(1, 3807, '\p{Script_Extensions:lao}', "");
Expect(0, 3807, '\p{^Script_Extensions:lao}', "");
Expect(0, 3807, '\P{Script_Extensions:lao}', "");
Expect(1, 3807, '\P{^Script_Extensions:lao}', "");
Expect(0, 3808, '\p{Script_Extensions:lao}', "");
Expect(1, 3808, '\p{^Script_Extensions:lao}', "");
Expect(1, 3808, '\P{Script_Extensions:lao}', "");
Expect(0, 3808, '\P{^Script_Extensions:lao}', "");
Expect(1, 3807, '\p{Script_Extensions=__Lao}', "");
Expect(0, 3807, '\p{^Script_Extensions=__Lao}', "");
Expect(0, 3807, '\P{Script_Extensions=__Lao}', "");
Expect(1, 3807, '\P{^Script_Extensions=__Lao}', "");
Expect(0, 3808, '\p{Script_Extensions=__Lao}', "");
Expect(1, 3808, '\p{^Script_Extensions=__Lao}', "");
Expect(1, 3808, '\P{Script_Extensions=__Lao}', "");
Expect(0, 3808, '\P{^Script_Extensions=__Lao}', "");
Error('\p{Scx=:=	laoo}');
Error('\P{Scx=:=	laoo}');
Expect(1, 3807, '\p{Scx=laoo}', "");
Expect(0, 3807, '\p{^Scx=laoo}', "");
Expect(0, 3807, '\P{Scx=laoo}', "");
Expect(1, 3807, '\P{^Scx=laoo}', "");
Expect(0, 3808, '\p{Scx=laoo}', "");
Expect(1, 3808, '\p{^Scx=laoo}', "");
Expect(1, 3808, '\P{Scx=laoo}', "");
Expect(0, 3808, '\P{^Scx=laoo}', "");
Expect(1, 3807, '\p{Scx=_	Laoo}', "");
Expect(0, 3807, '\p{^Scx=_	Laoo}', "");
Expect(0, 3807, '\P{Scx=_	Laoo}', "");
Expect(1, 3807, '\P{^Scx=_	Laoo}', "");
Expect(0, 3808, '\p{Scx=_	Laoo}', "");
Expect(1, 3808, '\p{^Scx=_	Laoo}', "");
Expect(1, 3808, '\P{Scx=_	Laoo}', "");
Expect(0, 3808, '\P{^Scx=_	Laoo}', "");
Error('\p{Is_Script_Extensions=	:=lao}');
Error('\P{Is_Script_Extensions=	:=lao}');
Expect(1, 3807, '\p{Is_Script_Extensions=lao}', "");
Expect(0, 3807, '\p{^Is_Script_Extensions=lao}', "");
Expect(0, 3807, '\P{Is_Script_Extensions=lao}', "");
Expect(1, 3807, '\P{^Is_Script_Extensions=lao}', "");
Expect(0, 3808, '\p{Is_Script_Extensions=lao}', "");
Expect(1, 3808, '\p{^Is_Script_Extensions=lao}', "");
Expect(1, 3808, '\P{Is_Script_Extensions=lao}', "");
Expect(0, 3808, '\P{^Is_Script_Extensions=lao}', "");
Expect(1, 3807, '\p{Is_Script_Extensions=_lao}', "");
Expect(0, 3807, '\p{^Is_Script_Extensions=_lao}', "");
Expect(0, 3807, '\P{Is_Script_Extensions=_lao}', "");
Expect(1, 3807, '\P{^Is_Script_Extensions=_lao}', "");
Expect(0, 3808, '\p{Is_Script_Extensions=_lao}', "");
Expect(1, 3808, '\p{^Is_Script_Extensions=_lao}', "");
Expect(1, 3808, '\P{Is_Script_Extensions=_lao}', "");
Expect(0, 3808, '\P{^Is_Script_Extensions=_lao}', "");
Error('\p{Is_Scx=--Laoo/a/}');
Error('\P{Is_Scx=--Laoo/a/}');
Expect(1, 3807, '\p{Is_Scx=laoo}', "");
Expect(0, 3807, '\p{^Is_Scx=laoo}', "");
Expect(0, 3807, '\P{Is_Scx=laoo}', "");
Expect(1, 3807, '\P{^Is_Scx=laoo}', "");
Expect(0, 3808, '\p{Is_Scx=laoo}', "");
Expect(1, 3808, '\p{^Is_Scx=laoo}', "");
Expect(1, 3808, '\P{Is_Scx=laoo}', "");
Expect(0, 3808, '\P{^Is_Scx=laoo}', "");
Expect(1, 3807, '\p{Is_Scx=_	Laoo}', "");
Expect(0, 3807, '\p{^Is_Scx=_	Laoo}', "");
Expect(0, 3807, '\P{Is_Scx=_	Laoo}', "");
Expect(1, 3807, '\P{^Is_Scx=_	Laoo}', "");
Expect(0, 3808, '\p{Is_Scx=_	Laoo}', "");
Expect(1, 3808, '\p{^Is_Scx=_	Laoo}', "");
Expect(1, 3808, '\P{Is_Scx=_	Laoo}', "");
Expect(0, 3808, '\P{^Is_Scx=_	Laoo}', "");
Error('\p{Script_Extensions=/a/	_Latin}');
Error('\P{Script_Extensions=/a/	_Latin}');
Expect(1, 65370, '\p{Script_Extensions=latin}', "");
Expect(0, 65370, '\p{^Script_Extensions=latin}', "");
Expect(0, 65370, '\P{Script_Extensions=latin}', "");
Expect(1, 65370, '\P{^Script_Extensions=latin}', "");
Expect(0, 65371, '\p{Script_Extensions=latin}', "");
Expect(1, 65371, '\p{^Script_Extensions=latin}', "");
Expect(1, 65371, '\P{Script_Extensions=latin}', "");
Expect(0, 65371, '\P{^Script_Extensions=latin}', "");
Expect(1, 65370, '\p{Script_Extensions=__latin}', "");
Expect(0, 65370, '\p{^Script_Extensions=__latin}', "");
Expect(0, 65370, '\P{Script_Extensions=__latin}', "");
Expect(1, 65370, '\P{^Script_Extensions=__latin}', "");
Expect(0, 65371, '\p{Script_Extensions=__latin}', "");
Expect(1, 65371, '\p{^Script_Extensions=__latin}', "");
Expect(1, 65371, '\P{Script_Extensions=__latin}', "");
Expect(0, 65371, '\P{^Script_Extensions=__latin}', "");
Error('\p{Scx=/a/		LATN}');
Error('\P{Scx=/a/		LATN}');
Expect(1, 65370, '\p{Scx=latn}', "");
Expect(0, 65370, '\p{^Scx=latn}', "");
Expect(0, 65370, '\P{Scx=latn}', "");
Expect(1, 65370, '\P{^Scx=latn}', "");
Expect(0, 65371, '\p{Scx=latn}', "");
Expect(1, 65371, '\p{^Scx=latn}', "");
Expect(1, 65371, '\P{Scx=latn}', "");
Expect(0, 65371, '\P{^Scx=latn}', "");
Expect(1, 65370, '\p{Scx=	_Latn}', "");
Expect(0, 65370, '\p{^Scx=	_Latn}', "");
Expect(0, 65370, '\P{Scx=	_Latn}', "");
Expect(1, 65370, '\P{^Scx=	_Latn}', "");
Expect(0, 65371, '\p{Scx=	_Latn}', "");
Expect(1, 65371, '\p{^Scx=	_Latn}', "");
Expect(1, 65371, '\P{Scx=	_Latn}', "");
Expect(0, 65371, '\P{^Scx=	_Latn}', "");
Error('\p{Is_Script_Extensions=	Latin/a/}');
Error('\P{Is_Script_Extensions=	Latin/a/}');
Expect(1, 65370, '\p{Is_Script_Extensions=latin}', "");
Expect(0, 65370, '\p{^Is_Script_Extensions=latin}', "");
Expect(0, 65370, '\P{Is_Script_Extensions=latin}', "");
Expect(1, 65370, '\P{^Is_Script_Extensions=latin}', "");
Expect(0, 65371, '\p{Is_Script_Extensions=latin}', "");
Expect(1, 65371, '\p{^Is_Script_Extensions=latin}', "");
Expect(1, 65371, '\P{Is_Script_Extensions=latin}', "");
Expect(0, 65371, '\P{^Is_Script_Extensions=latin}', "");
Expect(1, 65370, '\p{Is_Script_Extensions=-Latin}', "");
Expect(0, 65370, '\p{^Is_Script_Extensions=-Latin}', "");
Expect(0, 65370, '\P{Is_Script_Extensions=-Latin}', "");
Expect(1, 65370, '\P{^Is_Script_Extensions=-Latin}', "");
Expect(0, 65371, '\p{Is_Script_Extensions=-Latin}', "");
Expect(1, 65371, '\p{^Is_Script_Extensions=-Latin}', "");
Expect(1, 65371, '\P{Is_Script_Extensions=-Latin}', "");
Expect(0, 65371, '\P{^Is_Script_Extensions=-Latin}', "");
Error('\p{Is_Scx=/a/ -latn}');
Error('\P{Is_Scx=/a/ -latn}');
Expect(1, 65370, '\p{Is_Scx=latn}', "");
Expect(0, 65370, '\p{^Is_Scx=latn}', "");
Expect(0, 65370, '\P{Is_Scx=latn}', "");
Expect(1, 65370, '\P{^Is_Scx=latn}', "");
Expect(0, 65371, '\p{Is_Scx=latn}', "");
Expect(1, 65371, '\p{^Is_Scx=latn}', "");
Expect(1, 65371, '\P{Is_Scx=latn}', "");
Expect(0, 65371, '\P{^Is_Scx=latn}', "");
Expect(1, 65370, '\p{Is_Scx=- Latn}', "");
Expect(0, 65370, '\p{^Is_Scx=- Latn}', "");
Expect(0, 65370, '\P{Is_Scx=- Latn}', "");
Expect(1, 65370, '\P{^Is_Scx=- Latn}', "");
Expect(0, 65371, '\p{Is_Scx=- Latn}', "");
Expect(1, 65371, '\p{^Is_Scx=- Latn}', "");
Expect(1, 65371, '\P{Is_Scx=- Latn}', "");
Expect(0, 65371, '\P{^Is_Scx=- Latn}', "");
Error('\p{Script_Extensions= :=Lepcha}');
Error('\P{Script_Extensions= :=Lepcha}');
Expect(1, 7247, '\p{Script_Extensions=lepcha}', "");
Expect(0, 7247, '\p{^Script_Extensions=lepcha}', "");
Expect(0, 7247, '\P{Script_Extensions=lepcha}', "");
Expect(1, 7247, '\P{^Script_Extensions=lepcha}', "");
Expect(0, 7248, '\p{Script_Extensions=lepcha}', "");
Expect(1, 7248, '\p{^Script_Extensions=lepcha}', "");
Expect(1, 7248, '\P{Script_Extensions=lepcha}', "");
Expect(0, 7248, '\P{^Script_Extensions=lepcha}', "");
Expect(1, 7247, '\p{Script_Extensions=_-lepcha}', "");
Expect(0, 7247, '\p{^Script_Extensions=_-lepcha}', "");
Expect(0, 7247, '\P{Script_Extensions=_-lepcha}', "");
Expect(1, 7247, '\P{^Script_Extensions=_-lepcha}', "");
Expect(0, 7248, '\p{Script_Extensions=_-lepcha}', "");
Expect(1, 7248, '\p{^Script_Extensions=_-lepcha}', "");
Expect(1, 7248, '\P{Script_Extensions=_-lepcha}', "");
Expect(0, 7248, '\P{^Script_Extensions=_-lepcha}', "");
Error('\p{Scx= /a/LEPC}');
Error('\P{Scx= /a/LEPC}');
Expect(1, 7247, '\p{Scx=lepc}', "");
Expect(0, 7247, '\p{^Scx=lepc}', "");
Expect(0, 7247, '\P{Scx=lepc}', "");
Expect(1, 7247, '\P{^Scx=lepc}', "");
Expect(0, 7248, '\p{Scx=lepc}', "");
Expect(1, 7248, '\p{^Scx=lepc}', "");
Expect(1, 7248, '\P{Scx=lepc}', "");
Expect(0, 7248, '\P{^Scx=lepc}', "");
Expect(1, 7247, '\p{Scx= 	Lepc}', "");
Expect(0, 7247, '\p{^Scx= 	Lepc}', "");
Expect(0, 7247, '\P{Scx= 	Lepc}', "");
Expect(1, 7247, '\P{^Scx= 	Lepc}', "");
Expect(0, 7248, '\p{Scx= 	Lepc}', "");
Expect(1, 7248, '\p{^Scx= 	Lepc}', "");
Expect(1, 7248, '\P{Scx= 	Lepc}', "");
Expect(0, 7248, '\P{^Scx= 	Lepc}', "");
Error('\p{Is_Script_Extensions=:=Lepcha}');
Error('\P{Is_Script_Extensions=:=Lepcha}');
Expect(1, 7247, '\p{Is_Script_Extensions=lepcha}', "");
Expect(0, 7247, '\p{^Is_Script_Extensions=lepcha}', "");
Expect(0, 7247, '\P{Is_Script_Extensions=lepcha}', "");
Expect(1, 7247, '\P{^Is_Script_Extensions=lepcha}', "");
Expect(0, 7248, '\p{Is_Script_Extensions=lepcha}', "");
Expect(1, 7248, '\p{^Is_Script_Extensions=lepcha}', "");
Expect(1, 7248, '\P{Is_Script_Extensions=lepcha}', "");
Expect(0, 7248, '\P{^Is_Script_Extensions=lepcha}', "");
Expect(1, 7247, '\p{Is_Script_Extensions:	 	Lepcha}', "");
Expect(0, 7247, '\p{^Is_Script_Extensions:	 	Lepcha}', "");
Expect(0, 7247, '\P{Is_Script_Extensions:	 	Lepcha}', "");
Expect(1, 7247, '\P{^Is_Script_Extensions:	 	Lepcha}', "");
Expect(0, 7248, '\p{Is_Script_Extensions:	 	Lepcha}', "");
Expect(1, 7248, '\p{^Is_Script_Extensions:	 	Lepcha}', "");
Expect(1, 7248, '\P{Is_Script_Extensions:	 	Lepcha}', "");
Expect(0, 7248, '\P{^Is_Script_Extensions:	 	Lepcha}', "");
Error('\p{Is_Scx=_:=Lepc}');
Error('\P{Is_Scx=_:=Lepc}');
Expect(1, 7247, '\p{Is_Scx=lepc}', "");
Expect(0, 7247, '\p{^Is_Scx=lepc}', "");
Expect(0, 7247, '\P{Is_Scx=lepc}', "");
Expect(1, 7247, '\P{^Is_Scx=lepc}', "");
Expect(0, 7248, '\p{Is_Scx=lepc}', "");
Expect(1, 7248, '\p{^Is_Scx=lepc}', "");
Expect(1, 7248, '\P{Is_Scx=lepc}', "");
Expect(0, 7248, '\P{^Is_Scx=lepc}', "");
Expect(1, 7247, '\p{Is_Scx=	lepc}', "");
Expect(0, 7247, '\p{^Is_Scx=	lepc}', "");
Expect(0, 7247, '\P{Is_Scx=	lepc}', "");
Expect(1, 7247, '\P{^Is_Scx=	lepc}', "");
Expect(0, 7248, '\p{Is_Scx=	lepc}', "");
Expect(1, 7248, '\p{^Is_Scx=	lepc}', "");
Expect(1, 7248, '\P{Is_Scx=	lepc}', "");
Expect(0, 7248, '\P{^Is_Scx=	lepc}', "");
Error('\p{Script_Extensions=/a/	_limbu}');
Error('\P{Script_Extensions=/a/	_limbu}');
Expect(1, 6479, '\p{Script_Extensions=limbu}', "");
Expect(0, 6479, '\p{^Script_Extensions=limbu}', "");
Expect(0, 6479, '\P{Script_Extensions=limbu}', "");
Expect(1, 6479, '\P{^Script_Extensions=limbu}', "");
Expect(0, 6480, '\p{Script_Extensions=limbu}', "");
Expect(1, 6480, '\p{^Script_Extensions=limbu}', "");
Expect(1, 6480, '\P{Script_Extensions=limbu}', "");
Expect(0, 6480, '\P{^Script_Extensions=limbu}', "");
Expect(1, 6479, '\p{Script_Extensions=LIMBU}', "");
Expect(0, 6479, '\p{^Script_Extensions=LIMBU}', "");
Expect(0, 6479, '\P{Script_Extensions=LIMBU}', "");
Expect(1, 6479, '\P{^Script_Extensions=LIMBU}', "");
Expect(0, 6480, '\p{Script_Extensions=LIMBU}', "");
Expect(1, 6480, '\p{^Script_Extensions=LIMBU}', "");
Expect(1, 6480, '\P{Script_Extensions=LIMBU}', "");
Expect(0, 6480, '\P{^Script_Extensions=LIMBU}', "");
Error('\p{Scx=/a/_ LIMB}');
Error('\P{Scx=/a/_ LIMB}');
Expect(1, 6479, '\p{Scx:   limb}', "");
Expect(0, 6479, '\p{^Scx:   limb}', "");
Expect(0, 6479, '\P{Scx:   limb}', "");
Expect(1, 6479, '\P{^Scx:   limb}', "");
Expect(0, 6480, '\p{Scx:   limb}', "");
Expect(1, 6480, '\p{^Scx:   limb}', "");
Expect(1, 6480, '\P{Scx:   limb}', "");
Expect(0, 6480, '\P{^Scx:   limb}', "");
Expect(1, 6479, '\p{Scx= 	Limb}', "");
Expect(0, 6479, '\p{^Scx= 	Limb}', "");
Expect(0, 6479, '\P{Scx= 	Limb}', "");
Expect(1, 6479, '\P{^Scx= 	Limb}', "");
Expect(0, 6480, '\p{Scx= 	Limb}', "");
Expect(1, 6480, '\p{^Scx= 	Limb}', "");
Expect(1, 6480, '\P{Scx= 	Limb}', "");
Expect(0, 6480, '\P{^Scx= 	Limb}', "");
Error('\p{Is_Script_Extensions:/a/__Limbu}');
Error('\P{Is_Script_Extensions:/a/__Limbu}');
Expect(1, 6479, '\p{Is_Script_Extensions=limbu}', "");
Expect(0, 6479, '\p{^Is_Script_Extensions=limbu}', "");
Expect(0, 6479, '\P{Is_Script_Extensions=limbu}', "");
Expect(1, 6479, '\P{^Is_Script_Extensions=limbu}', "");
Expect(0, 6480, '\p{Is_Script_Extensions=limbu}', "");
Expect(1, 6480, '\p{^Is_Script_Extensions=limbu}', "");
Expect(1, 6480, '\P{Is_Script_Extensions=limbu}', "");
Expect(0, 6480, '\P{^Is_Script_Extensions=limbu}', "");
Expect(1, 6479, '\p{Is_Script_Extensions=-_LIMBU}', "");
Expect(0, 6479, '\p{^Is_Script_Extensions=-_LIMBU}', "");
Expect(0, 6479, '\P{Is_Script_Extensions=-_LIMBU}', "");
Expect(1, 6479, '\P{^Is_Script_Extensions=-_LIMBU}', "");
Expect(0, 6480, '\p{Is_Script_Extensions=-_LIMBU}', "");
Expect(1, 6480, '\p{^Is_Script_Extensions=-_LIMBU}', "");
Expect(1, 6480, '\P{Is_Script_Extensions=-_LIMBU}', "");
Expect(0, 6480, '\P{^Is_Script_Extensions=-_LIMBU}', "");
Error('\p{Is_Scx:   /a/ Limb}');
Error('\P{Is_Scx:   /a/ Limb}');
Expect(1, 6479, '\p{Is_Scx=limb}', "");
Expect(0, 6479, '\p{^Is_Scx=limb}', "");
Expect(0, 6479, '\P{Is_Scx=limb}', "");
Expect(1, 6479, '\P{^Is_Scx=limb}', "");
Expect(0, 6480, '\p{Is_Scx=limb}', "");
Expect(1, 6480, '\p{^Is_Scx=limb}', "");
Expect(1, 6480, '\P{Is_Scx=limb}', "");
Expect(0, 6480, '\P{^Is_Scx=limb}', "");
Expect(1, 6479, '\p{Is_Scx=_LIMB}', "");
Expect(0, 6479, '\p{^Is_Scx=_LIMB}', "");
Expect(0, 6479, '\P{Is_Scx=_LIMB}', "");
Expect(1, 6479, '\P{^Is_Scx=_LIMB}', "");
Expect(0, 6480, '\p{Is_Scx=_LIMB}', "");
Expect(1, 6480, '\p{^Is_Scx=_LIMB}', "");
Expect(1, 6480, '\P{Is_Scx=_LIMB}', "");
Expect(0, 6480, '\P{^Is_Scx=_LIMB}', "");
Error('\p{Script_Extensions=/a/ Linear_B}');
Error('\P{Script_Extensions=/a/ Linear_B}');
Expect(1, 65855, '\p{Script_Extensions=linearb}', "");
Expect(0, 65855, '\p{^Script_Extensions=linearb}', "");
Expect(0, 65855, '\P{Script_Extensions=linearb}', "");
Expect(1, 65855, '\P{^Script_Extensions=linearb}', "");
Expect(0, 65856, '\p{Script_Extensions=linearb}', "");
Expect(1, 65856, '\p{^Script_Extensions=linearb}', "");
Expect(1, 65856, '\P{Script_Extensions=linearb}', "");
Expect(0, 65856, '\P{^Script_Extensions=linearb}', "");
Expect(1, 65855, '\p{Script_Extensions=_	LINEAR_b}', "");
Expect(0, 65855, '\p{^Script_Extensions=_	LINEAR_b}', "");
Expect(0, 65855, '\P{Script_Extensions=_	LINEAR_b}', "");
Expect(1, 65855, '\P{^Script_Extensions=_	LINEAR_b}', "");
Expect(0, 65856, '\p{Script_Extensions=_	LINEAR_b}', "");
Expect(1, 65856, '\p{^Script_Extensions=_	LINEAR_b}', "");
Expect(1, 65856, '\P{Script_Extensions=_	LINEAR_b}', "");
Expect(0, 65856, '\P{^Script_Extensions=_	LINEAR_b}', "");
Error('\p{Scx:   /a/_Linb}');
Error('\P{Scx:   /a/_Linb}');
Expect(1, 65855, '\p{Scx=linb}', "");
Expect(0, 65855, '\p{^Scx=linb}', "");
Expect(0, 65855, '\P{Scx=linb}', "");
Expect(1, 65855, '\P{^Scx=linb}', "");
Expect(0, 65856, '\p{Scx=linb}', "");
Expect(1, 65856, '\p{^Scx=linb}', "");
Expect(1, 65856, '\P{Scx=linb}', "");
Expect(0, 65856, '\P{^Scx=linb}', "");
Expect(1, 65855, '\p{Scx=-_LINB}', "");
Expect(0, 65855, '\p{^Scx=-_LINB}', "");
Expect(0, 65855, '\P{Scx=-_LINB}', "");
Expect(1, 65855, '\P{^Scx=-_LINB}', "");
Expect(0, 65856, '\p{Scx=-_LINB}', "");
Expect(1, 65856, '\p{^Scx=-_LINB}', "");
Expect(1, 65856, '\P{Scx=-_LINB}', "");
Expect(0, 65856, '\P{^Scx=-_LINB}', "");
Error('\p{Is_Script_Extensions=:=_Linear_B}');
Error('\P{Is_Script_Extensions=:=_Linear_B}');
Expect(1, 65855, '\p{Is_Script_Extensions=linearb}', "");
Expect(0, 65855, '\p{^Is_Script_Extensions=linearb}', "");
Expect(0, 65855, '\P{Is_Script_Extensions=linearb}', "");
Expect(1, 65855, '\P{^Is_Script_Extensions=linearb}', "");
Expect(0, 65856, '\p{Is_Script_Extensions=linearb}', "");
Expect(1, 65856, '\p{^Is_Script_Extensions=linearb}', "");
Expect(1, 65856, '\P{Is_Script_Extensions=linearb}', "");
Expect(0, 65856, '\P{^Is_Script_Extensions=linearb}', "");
Expect(1, 65855, '\p{Is_Script_Extensions= _linear_B}', "");
Expect(0, 65855, '\p{^Is_Script_Extensions= _linear_B}', "");
Expect(0, 65855, '\P{Is_Script_Extensions= _linear_B}', "");
Expect(1, 65855, '\P{^Is_Script_Extensions= _linear_B}', "");
Expect(0, 65856, '\p{Is_Script_Extensions= _linear_B}', "");
Expect(1, 65856, '\p{^Is_Script_Extensions= _linear_B}', "");
Expect(1, 65856, '\P{Is_Script_Extensions= _linear_B}', "");
Expect(0, 65856, '\P{^Is_Script_Extensions= _linear_B}', "");
Error('\p{Is_Scx=/a/-linb}');
Error('\P{Is_Scx=/a/-linb}');
Expect(1, 65855, '\p{Is_Scx=linb}', "");
Expect(0, 65855, '\p{^Is_Scx=linb}', "");
Expect(0, 65855, '\P{Is_Scx=linb}', "");
Expect(1, 65855, '\P{^Is_Scx=linb}', "");
Expect(0, 65856, '\p{Is_Scx=linb}', "");
Expect(1, 65856, '\p{^Is_Scx=linb}', "");
Expect(1, 65856, '\P{Is_Scx=linb}', "");
Expect(0, 65856, '\P{^Is_Scx=linb}', "");
Expect(1, 65855, '\p{Is_Scx= _LINB}', "");
Expect(0, 65855, '\p{^Is_Scx= _LINB}', "");
Expect(0, 65855, '\P{Is_Scx= _LINB}', "");
Expect(1, 65855, '\P{^Is_Scx= _LINB}', "");
Expect(0, 65856, '\p{Is_Scx= _LINB}', "");
Expect(1, 65856, '\p{^Is_Scx= _LINB}', "");
Expect(1, 65856, '\P{Is_Scx= _LINB}', "");
Expect(0, 65856, '\P{^Is_Scx= _LINB}', "");
Error('\p{Script_Extensions=-_LISU/a/}');
Error('\P{Script_Extensions=-_LISU/a/}');
Expect(1, 42239, '\p{Script_Extensions=lisu}', "");
Expect(0, 42239, '\p{^Script_Extensions=lisu}', "");
Expect(0, 42239, '\P{Script_Extensions=lisu}', "");
Expect(1, 42239, '\P{^Script_Extensions=lisu}', "");
Expect(0, 42240, '\p{Script_Extensions=lisu}', "");
Expect(1, 42240, '\p{^Script_Extensions=lisu}', "");
Expect(1, 42240, '\P{Script_Extensions=lisu}', "");
Expect(0, 42240, '\P{^Script_Extensions=lisu}', "");
Expect(1, 42239, '\p{Script_Extensions= 	Lisu}', "");
Expect(0, 42239, '\p{^Script_Extensions= 	Lisu}', "");
Expect(0, 42239, '\P{Script_Extensions= 	Lisu}', "");
Expect(1, 42239, '\P{^Script_Extensions= 	Lisu}', "");
Expect(0, 42240, '\p{Script_Extensions= 	Lisu}', "");
Expect(1, 42240, '\p{^Script_Extensions= 	Lisu}', "");
Expect(1, 42240, '\P{Script_Extensions= 	Lisu}', "");
Expect(0, 42240, '\P{^Script_Extensions= 	Lisu}', "");
Error('\p{Scx=:=_lisu}');
Error('\P{Scx=:=_lisu}');
Expect(1, 42239, '\p{Scx=lisu}', "");
Expect(0, 42239, '\p{^Scx=lisu}', "");
Expect(0, 42239, '\P{Scx=lisu}', "");
Expect(1, 42239, '\P{^Scx=lisu}', "");
Expect(0, 42240, '\p{Scx=lisu}', "");
Expect(1, 42240, '\p{^Scx=lisu}', "");
Expect(1, 42240, '\P{Scx=lisu}', "");
Expect(0, 42240, '\P{^Scx=lisu}', "");
Expect(1, 42239, '\p{Scx=	Lisu}', "");
Expect(0, 42239, '\p{^Scx=	Lisu}', "");
Expect(0, 42239, '\P{Scx=	Lisu}', "");
Expect(1, 42239, '\P{^Scx=	Lisu}', "");
Expect(0, 42240, '\p{Scx=	Lisu}', "");
Expect(1, 42240, '\p{^Scx=	Lisu}', "");
Expect(1, 42240, '\P{Scx=	Lisu}', "");
Expect(0, 42240, '\P{^Scx=	Lisu}', "");
Error('\p{Is_Script_Extensions=_:=Lisu}');
Error('\P{Is_Script_Extensions=_:=Lisu}');
Expect(1, 42239, '\p{Is_Script_Extensions=lisu}', "");
Expect(0, 42239, '\p{^Is_Script_Extensions=lisu}', "");
Expect(0, 42239, '\P{Is_Script_Extensions=lisu}', "");
Expect(1, 42239, '\P{^Is_Script_Extensions=lisu}', "");
Expect(0, 42240, '\p{Is_Script_Extensions=lisu}', "");
Expect(1, 42240, '\p{^Is_Script_Extensions=lisu}', "");
Expect(1, 42240, '\P{Is_Script_Extensions=lisu}', "");
Expect(0, 42240, '\P{^Is_Script_Extensions=lisu}', "");
Expect(1, 42239, '\p{Is_Script_Extensions= Lisu}', "");
Expect(0, 42239, '\p{^Is_Script_Extensions= Lisu}', "");
Expect(0, 42239, '\P{Is_Script_Extensions= Lisu}', "");
Expect(1, 42239, '\P{^Is_Script_Extensions= Lisu}', "");
Expect(0, 42240, '\p{Is_Script_Extensions= Lisu}', "");
Expect(1, 42240, '\p{^Is_Script_Extensions= Lisu}', "");
Expect(1, 42240, '\P{Is_Script_Extensions= Lisu}', "");
Expect(0, 42240, '\P{^Is_Script_Extensions= Lisu}', "");
Error('\p{Is_Scx:	:=	_lisu}');
Error('\P{Is_Scx:	:=	_lisu}');
Expect(1, 42239, '\p{Is_Scx=lisu}', "");
Expect(0, 42239, '\p{^Is_Scx=lisu}', "");
Expect(0, 42239, '\P{Is_Scx=lisu}', "");
Expect(1, 42239, '\P{^Is_Scx=lisu}', "");
Expect(0, 42240, '\p{Is_Scx=lisu}', "");
Expect(1, 42240, '\p{^Is_Scx=lisu}', "");
Expect(1, 42240, '\P{Is_Scx=lisu}', "");
Expect(0, 42240, '\P{^Is_Scx=lisu}', "");
Expect(1, 42239, '\p{Is_Scx=_Lisu}', "");
Expect(0, 42239, '\p{^Is_Scx=_Lisu}', "");
Expect(0, 42239, '\P{Is_Scx=_Lisu}', "");
Expect(1, 42239, '\P{^Is_Scx=_Lisu}', "");
Expect(0, 42240, '\p{Is_Scx=_Lisu}', "");
Expect(1, 42240, '\p{^Is_Scx=_Lisu}', "");
Expect(1, 42240, '\P{Is_Scx=_Lisu}', "");
Expect(0, 42240, '\P{^Is_Scx=_Lisu}', "");
Error('\p{Script_Extensions=_ Lycian/a/}');
Error('\P{Script_Extensions=_ Lycian/a/}');
Expect(1, 66204, '\p{Script_Extensions=lycian}', "");
Expect(0, 66204, '\p{^Script_Extensions=lycian}', "");
Expect(0, 66204, '\P{Script_Extensions=lycian}', "");
Expect(1, 66204, '\P{^Script_Extensions=lycian}', "");
Expect(0, 66205, '\p{Script_Extensions=lycian}', "");
Expect(1, 66205, '\p{^Script_Extensions=lycian}', "");
Expect(1, 66205, '\P{Script_Extensions=lycian}', "");
Expect(0, 66205, '\P{^Script_Extensions=lycian}', "");
Expect(1, 66204, '\p{Script_Extensions=_	LYCIAN}', "");
Expect(0, 66204, '\p{^Script_Extensions=_	LYCIAN}', "");
Expect(0, 66204, '\P{Script_Extensions=_	LYCIAN}', "");
Expect(1, 66204, '\P{^Script_Extensions=_	LYCIAN}', "");
Expect(0, 66205, '\p{Script_Extensions=_	LYCIAN}', "");
Expect(1, 66205, '\p{^Script_Extensions=_	LYCIAN}', "");
Expect(1, 66205, '\P{Script_Extensions=_	LYCIAN}', "");
Expect(0, 66205, '\P{^Script_Extensions=_	LYCIAN}', "");
Error('\p{Scx=		Lyci/a/}');
Error('\P{Scx=		Lyci/a/}');
Expect(1, 66204, '\p{Scx: lyci}', "");
Expect(0, 66204, '\p{^Scx: lyci}', "");
Expect(0, 66204, '\P{Scx: lyci}', "");
Expect(1, 66204, '\P{^Scx: lyci}', "");
Expect(0, 66205, '\p{Scx: lyci}', "");
Expect(1, 66205, '\p{^Scx: lyci}', "");
Expect(1, 66205, '\P{Scx: lyci}', "");
Expect(0, 66205, '\P{^Scx: lyci}', "");
Expect(1, 66204, '\p{Scx=	lyci}', "");
Expect(0, 66204, '\p{^Scx=	lyci}', "");
Expect(0, 66204, '\P{Scx=	lyci}', "");
Expect(1, 66204, '\P{^Scx=	lyci}', "");
Expect(0, 66205, '\p{Scx=	lyci}', "");
Expect(1, 66205, '\p{^Scx=	lyci}', "");
Expect(1, 66205, '\P{Scx=	lyci}', "");
Expect(0, 66205, '\P{^Scx=	lyci}', "");
Error('\p{Is_Script_Extensions:    :=Lycian}');
Error('\P{Is_Script_Extensions:    :=Lycian}');
Expect(1, 66204, '\p{Is_Script_Extensions=lycian}', "");
Expect(0, 66204, '\p{^Is_Script_Extensions=lycian}', "");
Expect(0, 66204, '\P{Is_Script_Extensions=lycian}', "");
Expect(1, 66204, '\P{^Is_Script_Extensions=lycian}', "");
Expect(0, 66205, '\p{Is_Script_Extensions=lycian}', "");
Expect(1, 66205, '\p{^Is_Script_Extensions=lycian}', "");
Expect(1, 66205, '\P{Is_Script_Extensions=lycian}', "");
Expect(0, 66205, '\P{^Is_Script_Extensions=lycian}', "");
Expect(1, 66204, '\p{Is_Script_Extensions=  Lycian}', "");
Expect(0, 66204, '\p{^Is_Script_Extensions=  Lycian}', "");
Expect(0, 66204, '\P{Is_Script_Extensions=  Lycian}', "");
Expect(1, 66204, '\P{^Is_Script_Extensions=  Lycian}', "");
Expect(0, 66205, '\p{Is_Script_Extensions=  Lycian}', "");
Expect(1, 66205, '\p{^Is_Script_Extensions=  Lycian}', "");
Expect(1, 66205, '\P{Is_Script_Extensions=  Lycian}', "");
Expect(0, 66205, '\P{^Is_Script_Extensions=  Lycian}', "");
Error('\p{Is_Scx=:=_Lyci}');
Error('\P{Is_Scx=:=_Lyci}');
Expect(1, 66204, '\p{Is_Scx=lyci}', "");
Expect(0, 66204, '\p{^Is_Scx=lyci}', "");
Expect(0, 66204, '\P{Is_Scx=lyci}', "");
Expect(1, 66204, '\P{^Is_Scx=lyci}', "");
Expect(0, 66205, '\p{Is_Scx=lyci}', "");
Expect(1, 66205, '\p{^Is_Scx=lyci}', "");
Expect(1, 66205, '\P{Is_Scx=lyci}', "");
Expect(0, 66205, '\P{^Is_Scx=lyci}', "");
Expect(1, 66204, '\p{Is_Scx= LYCI}', "");
Expect(0, 66204, '\p{^Is_Scx= LYCI}', "");
Expect(0, 66204, '\P{Is_Scx= LYCI}', "");
Expect(1, 66204, '\P{^Is_Scx= LYCI}', "");
Expect(0, 66205, '\p{Is_Scx= LYCI}', "");
Expect(1, 66205, '\p{^Is_Scx= LYCI}', "");
Expect(1, 66205, '\P{Is_Scx= LYCI}', "");
Expect(0, 66205, '\P{^Is_Scx= LYCI}', "");
Error('\p{Script_Extensions: -/a/lydian}');
Error('\P{Script_Extensions: -/a/lydian}');
Expect(1, 67903, '\p{Script_Extensions=lydian}', "");
Expect(0, 67903, '\p{^Script_Extensions=lydian}', "");
Expect(0, 67903, '\P{Script_Extensions=lydian}', "");
Expect(1, 67903, '\P{^Script_Extensions=lydian}', "");
Expect(0, 67904, '\p{Script_Extensions=lydian}', "");
Expect(1, 67904, '\p{^Script_Extensions=lydian}', "");
Expect(1, 67904, '\P{Script_Extensions=lydian}', "");
Expect(0, 67904, '\P{^Script_Extensions=lydian}', "");
Expect(1, 67903, '\p{Script_Extensions=_lydian}', "");
Expect(0, 67903, '\p{^Script_Extensions=_lydian}', "");
Expect(0, 67903, '\P{Script_Extensions=_lydian}', "");
Expect(1, 67903, '\P{^Script_Extensions=_lydian}', "");
Expect(0, 67904, '\p{Script_Extensions=_lydian}', "");
Expect(1, 67904, '\p{^Script_Extensions=_lydian}', "");
Expect(1, 67904, '\P{Script_Extensions=_lydian}', "");
Expect(0, 67904, '\P{^Script_Extensions=_lydian}', "");
Error('\p{Scx=--LYDI:=}');
Error('\P{Scx=--LYDI:=}');
Expect(1, 67903, '\p{Scx=lydi}', "");
Expect(0, 67903, '\p{^Scx=lydi}', "");
Expect(0, 67903, '\P{Scx=lydi}', "");
Expect(1, 67903, '\P{^Scx=lydi}', "");
Expect(0, 67904, '\p{Scx=lydi}', "");
Expect(1, 67904, '\p{^Scx=lydi}', "");
Expect(1, 67904, '\P{Scx=lydi}', "");
Expect(0, 67904, '\P{^Scx=lydi}', "");
Expect(1, 67903, '\p{Scx=Lydi}', "");
Expect(0, 67903, '\p{^Scx=Lydi}', "");
Expect(0, 67903, '\P{Scx=Lydi}', "");
Expect(1, 67903, '\P{^Scx=Lydi}', "");
Expect(0, 67904, '\p{Scx=Lydi}', "");
Expect(1, 67904, '\p{^Scx=Lydi}', "");
Expect(1, 67904, '\P{Scx=Lydi}', "");
Expect(0, 67904, '\P{^Scx=Lydi}', "");
Error('\p{Is_Script_Extensions=__lydian/a/}');
Error('\P{Is_Script_Extensions=__lydian/a/}');
Expect(1, 67903, '\p{Is_Script_Extensions=lydian}', "");
Expect(0, 67903, '\p{^Is_Script_Extensions=lydian}', "");
Expect(0, 67903, '\P{Is_Script_Extensions=lydian}', "");
Expect(1, 67903, '\P{^Is_Script_Extensions=lydian}', "");
Expect(0, 67904, '\p{Is_Script_Extensions=lydian}', "");
Expect(1, 67904, '\p{^Is_Script_Extensions=lydian}', "");
Expect(1, 67904, '\P{Is_Script_Extensions=lydian}', "");
Expect(0, 67904, '\P{^Is_Script_Extensions=lydian}', "");
Expect(1, 67903, '\p{Is_Script_Extensions=_	Lydian}', "");
Expect(0, 67903, '\p{^Is_Script_Extensions=_	Lydian}', "");
Expect(0, 67903, '\P{Is_Script_Extensions=_	Lydian}', "");
Expect(1, 67903, '\P{^Is_Script_Extensions=_	Lydian}', "");
Expect(0, 67904, '\p{Is_Script_Extensions=_	Lydian}', "");
Expect(1, 67904, '\p{^Is_Script_Extensions=_	Lydian}', "");
Expect(1, 67904, '\P{Is_Script_Extensions=_	Lydian}', "");
Expect(0, 67904, '\P{^Is_Script_Extensions=_	Lydian}', "");
Error('\p{Is_Scx:   _LYDI/a/}');
Error('\P{Is_Scx:   _LYDI/a/}');
Expect(1, 67903, '\p{Is_Scx=lydi}', "");
Expect(0, 67903, '\p{^Is_Scx=lydi}', "");
Expect(0, 67903, '\P{Is_Scx=lydi}', "");
Expect(1, 67903, '\P{^Is_Scx=lydi}', "");
Expect(0, 67904, '\p{Is_Scx=lydi}', "");
Expect(1, 67904, '\p{^Is_Scx=lydi}', "");
Expect(1, 67904, '\P{Is_Scx=lydi}', "");
Expect(0, 67904, '\P{^Is_Scx=lydi}', "");
Expect(1, 67903, '\p{Is_Scx=-Lydi}', "");
Expect(0, 67903, '\p{^Is_Scx=-Lydi}', "");
Expect(0, 67903, '\P{Is_Scx=-Lydi}', "");
Expect(1, 67903, '\P{^Is_Scx=-Lydi}', "");
Expect(0, 67904, '\p{Is_Scx=-Lydi}', "");
Expect(1, 67904, '\p{^Is_Scx=-Lydi}', "");
Expect(1, 67904, '\P{Is_Scx=-Lydi}', "");
Expect(0, 67904, '\P{^Is_Scx=-Lydi}', "");
Error('\p{Script_Extensions=:= _mandaic}');
Error('\P{Script_Extensions=:= _mandaic}');
Expect(1, 2142, '\p{Script_Extensions=mandaic}', "");
Expect(0, 2142, '\p{^Script_Extensions=mandaic}', "");
Expect(0, 2142, '\P{Script_Extensions=mandaic}', "");
Expect(1, 2142, '\P{^Script_Extensions=mandaic}', "");
Expect(0, 2143, '\p{Script_Extensions=mandaic}', "");
Expect(1, 2143, '\p{^Script_Extensions=mandaic}', "");
Expect(1, 2143, '\P{Script_Extensions=mandaic}', "");
Expect(0, 2143, '\P{^Script_Extensions=mandaic}', "");
Expect(1, 2142, '\p{Script_Extensions=Mandaic}', "");
Expect(0, 2142, '\p{^Script_Extensions=Mandaic}', "");
Expect(0, 2142, '\P{Script_Extensions=Mandaic}', "");
Expect(1, 2142, '\P{^Script_Extensions=Mandaic}', "");
Expect(0, 2143, '\p{Script_Extensions=Mandaic}', "");
Expect(1, 2143, '\p{^Script_Extensions=Mandaic}', "");
Expect(1, 2143, '\P{Script_Extensions=Mandaic}', "");
Expect(0, 2143, '\P{^Script_Extensions=Mandaic}', "");
Error('\p{Scx=	:=MAND}');
Error('\P{Scx=	:=MAND}');
Expect(1, 2142, '\p{Scx:mand}', "");
Expect(0, 2142, '\p{^Scx:mand}', "");
Expect(0, 2142, '\P{Scx:mand}', "");
Expect(1, 2142, '\P{^Scx:mand}', "");
Expect(0, 2143, '\p{Scx:mand}', "");
Expect(1, 2143, '\p{^Scx:mand}', "");
Expect(1, 2143, '\P{Scx:mand}', "");
Expect(0, 2143, '\P{^Scx:mand}', "");
Expect(1, 2142, '\p{Scx=  Mand}', "");
Expect(0, 2142, '\p{^Scx=  Mand}', "");
Expect(0, 2142, '\P{Scx=  Mand}', "");
Expect(1, 2142, '\P{^Scx=  Mand}', "");
Expect(0, 2143, '\p{Scx=  Mand}', "");
Expect(1, 2143, '\p{^Scx=  Mand}', "");
Expect(1, 2143, '\P{Scx=  Mand}', "");
Expect(0, 2143, '\P{^Scx=  Mand}', "");
Error('\p{Is_Script_Extensions=_:=Mandaic}');
Error('\P{Is_Script_Extensions=_:=Mandaic}');
Expect(1, 2142, '\p{Is_Script_Extensions=mandaic}', "");
Expect(0, 2142, '\p{^Is_Script_Extensions=mandaic}', "");
Expect(0, 2142, '\P{Is_Script_Extensions=mandaic}', "");
Expect(1, 2142, '\P{^Is_Script_Extensions=mandaic}', "");
Expect(0, 2143, '\p{Is_Script_Extensions=mandaic}', "");
Expect(1, 2143, '\p{^Is_Script_Extensions=mandaic}', "");
Expect(1, 2143, '\P{Is_Script_Extensions=mandaic}', "");
Expect(0, 2143, '\P{^Is_Script_Extensions=mandaic}', "");
Expect(1, 2142, '\p{Is_Script_Extensions=-	Mandaic}', "");
Expect(0, 2142, '\p{^Is_Script_Extensions=-	Mandaic}', "");
Expect(0, 2142, '\P{Is_Script_Extensions=-	Mandaic}', "");
Expect(1, 2142, '\P{^Is_Script_Extensions=-	Mandaic}', "");
Expect(0, 2143, '\p{Is_Script_Extensions=-	Mandaic}', "");
Expect(1, 2143, '\p{^Is_Script_Extensions=-	Mandaic}', "");
Expect(1, 2143, '\P{Is_Script_Extensions=-	Mandaic}', "");
Expect(0, 2143, '\P{^Is_Script_Extensions=-	Mandaic}', "");
Error('\p{Is_Scx=_mand/a/}');
Error('\P{Is_Scx=_mand/a/}');
Expect(1, 2142, '\p{Is_Scx=mand}', "");
Expect(0, 2142, '\p{^Is_Scx=mand}', "");
Expect(0, 2142, '\P{Is_Scx=mand}', "");
Expect(1, 2142, '\P{^Is_Scx=mand}', "");
Expect(0, 2143, '\p{Is_Scx=mand}', "");
Expect(1, 2143, '\p{^Is_Scx=mand}', "");
Expect(1, 2143, '\P{Is_Scx=mand}', "");
Expect(0, 2143, '\P{^Is_Scx=mand}', "");
Expect(1, 2142, '\p{Is_Scx=--Mand}', "");
Expect(0, 2142, '\p{^Is_Scx=--Mand}', "");
Expect(0, 2142, '\P{Is_Scx=--Mand}', "");
Expect(1, 2142, '\P{^Is_Scx=--Mand}', "");
Expect(0, 2143, '\p{Is_Scx=--Mand}', "");
Expect(1, 2143, '\p{^Is_Scx=--Mand}', "");
Expect(1, 2143, '\P{Is_Scx=--Mand}', "");
Expect(0, 2143, '\P{^Is_Scx=--Mand}', "");
Error('\p{Script_Extensions= _Meroitic_Cursive:=}');
Error('\P{Script_Extensions= _Meroitic_Cursive:=}');
Expect(1, 68031, '\p{Script_Extensions=meroiticcursive}', "");
Expect(0, 68031, '\p{^Script_Extensions=meroiticcursive}', "");
Expect(0, 68031, '\P{Script_Extensions=meroiticcursive}', "");
Expect(1, 68031, '\P{^Script_Extensions=meroiticcursive}', "");
Expect(0, 68032, '\p{Script_Extensions=meroiticcursive}', "");
Expect(1, 68032, '\p{^Script_Extensions=meroiticcursive}', "");
Expect(1, 68032, '\P{Script_Extensions=meroiticcursive}', "");
Expect(0, 68032, '\P{^Script_Extensions=meroiticcursive}', "");
Expect(1, 68031, '\p{Script_Extensions: -_Meroitic_Cursive}', "");
Expect(0, 68031, '\p{^Script_Extensions: -_Meroitic_Cursive}', "");
Expect(0, 68031, '\P{Script_Extensions: -_Meroitic_Cursive}', "");
Expect(1, 68031, '\P{^Script_Extensions: -_Meroitic_Cursive}', "");
Expect(0, 68032, '\p{Script_Extensions: -_Meroitic_Cursive}', "");
Expect(1, 68032, '\p{^Script_Extensions: -_Meroitic_Cursive}', "");
Expect(1, 68032, '\P{Script_Extensions: -_Meroitic_Cursive}', "");
Expect(0, 68032, '\P{^Script_Extensions: -_Meroitic_Cursive}', "");
Error('\p{Scx: -:=MERC}');
Error('\P{Scx: -:=MERC}');
Expect(1, 68031, '\p{Scx=merc}', "");
Expect(0, 68031, '\p{^Scx=merc}', "");
Expect(0, 68031, '\P{Scx=merc}', "");
Expect(1, 68031, '\P{^Scx=merc}', "");
Expect(0, 68032, '\p{Scx=merc}', "");
Expect(1, 68032, '\p{^Scx=merc}', "");
Expect(1, 68032, '\P{Scx=merc}', "");
Expect(0, 68032, '\P{^Scx=merc}', "");
Expect(1, 68031, '\p{Scx=-Merc}', "");
Expect(0, 68031, '\p{^Scx=-Merc}', "");
Expect(0, 68031, '\P{Scx=-Merc}', "");
Expect(1, 68031, '\P{^Scx=-Merc}', "");
Expect(0, 68032, '\p{Scx=-Merc}', "");
Expect(1, 68032, '\p{^Scx=-Merc}', "");
Expect(1, 68032, '\P{Scx=-Merc}', "");
Expect(0, 68032, '\P{^Scx=-Merc}', "");
Error('\p{Is_Script_Extensions:   		meroitic_CURSIVE/a/}');
Error('\P{Is_Script_Extensions:   		meroitic_CURSIVE/a/}');
Expect(1, 68031, '\p{Is_Script_Extensions=meroiticcursive}', "");
Expect(0, 68031, '\p{^Is_Script_Extensions=meroiticcursive}', "");
Expect(0, 68031, '\P{Is_Script_Extensions=meroiticcursive}', "");
Expect(1, 68031, '\P{^Is_Script_Extensions=meroiticcursive}', "");
Expect(0, 68032, '\p{Is_Script_Extensions=meroiticcursive}', "");
Expect(1, 68032, '\p{^Is_Script_Extensions=meroiticcursive}', "");
Expect(1, 68032, '\P{Is_Script_Extensions=meroiticcursive}', "");
Expect(0, 68032, '\P{^Is_Script_Extensions=meroiticcursive}', "");
Expect(1, 68031, '\p{Is_Script_Extensions=	Meroitic_cursive}', "");
Expect(0, 68031, '\p{^Is_Script_Extensions=	Meroitic_cursive}', "");
Expect(0, 68031, '\P{Is_Script_Extensions=	Meroitic_cursive}', "");
Expect(1, 68031, '\P{^Is_Script_Extensions=	Meroitic_cursive}', "");
Expect(0, 68032, '\p{Is_Script_Extensions=	Meroitic_cursive}', "");
Expect(1, 68032, '\p{^Is_Script_Extensions=	Meroitic_cursive}', "");
Expect(1, 68032, '\P{Is_Script_Extensions=	Meroitic_cursive}', "");
Expect(0, 68032, '\P{^Is_Script_Extensions=	Meroitic_cursive}', "");
Error('\p{Is_Scx=		Merc:=}');
Error('\P{Is_Scx=		Merc:=}');
Expect(1, 68031, '\p{Is_Scx=merc}', "");
Expect(0, 68031, '\p{^Is_Scx=merc}', "");
Expect(0, 68031, '\P{Is_Scx=merc}', "");
Expect(1, 68031, '\P{^Is_Scx=merc}', "");
Expect(0, 68032, '\p{Is_Scx=merc}', "");
Expect(1, 68032, '\p{^Is_Scx=merc}', "");
Expect(1, 68032, '\P{Is_Scx=merc}', "");
Expect(0, 68032, '\P{^Is_Scx=merc}', "");
Expect(1, 68031, '\p{Is_Scx= -merc}', "");
Expect(0, 68031, '\p{^Is_Scx= -merc}', "");
Expect(0, 68031, '\P{Is_Scx= -merc}', "");
Expect(1, 68031, '\P{^Is_Scx= -merc}', "");
Expect(0, 68032, '\p{Is_Scx= -merc}', "");
Expect(1, 68032, '\p{^Is_Scx= -merc}', "");
Expect(1, 68032, '\P{Is_Scx= -merc}', "");
Expect(0, 68032, '\P{^Is_Scx= -merc}', "");
Error('\p{Script_Extensions=	:=Meroitic_HIEROGLYPHS}');
Error('\P{Script_Extensions=	:=Meroitic_HIEROGLYPHS}');
Expect(1, 67999, '\p{Script_Extensions=meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^Script_Extensions=meroitichieroglyphs}', "");
Expect(0, 67999, '\P{Script_Extensions=meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^Script_Extensions=meroitichieroglyphs}', "");
Expect(0, 68000, '\p{Script_Extensions=meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^Script_Extensions=meroitichieroglyphs}', "");
Expect(1, 68000, '\P{Script_Extensions=meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^Script_Extensions=meroitichieroglyphs}', "");
Expect(1, 67999, '\p{Script_Extensions=--MEROITIC_Hieroglyphs}', "");
Expect(0, 67999, '\p{^Script_Extensions=--MEROITIC_Hieroglyphs}', "");
Expect(0, 67999, '\P{Script_Extensions=--MEROITIC_Hieroglyphs}', "");
Expect(1, 67999, '\P{^Script_Extensions=--MEROITIC_Hieroglyphs}', "");
Expect(0, 68000, '\p{Script_Extensions=--MEROITIC_Hieroglyphs}', "");
Expect(1, 68000, '\p{^Script_Extensions=--MEROITIC_Hieroglyphs}', "");
Expect(1, 68000, '\P{Script_Extensions=--MEROITIC_Hieroglyphs}', "");
Expect(0, 68000, '\P{^Script_Extensions=--MEROITIC_Hieroglyphs}', "");
Error('\p{Scx:	- Mero/a/}');
Error('\P{Scx:	- Mero/a/}');
Expect(1, 67999, '\p{Scx=mero}', "");
Expect(0, 67999, '\p{^Scx=mero}', "");
Expect(0, 67999, '\P{Scx=mero}', "");
Expect(1, 67999, '\P{^Scx=mero}', "");
Expect(0, 68000, '\p{Scx=mero}', "");
Expect(1, 68000, '\p{^Scx=mero}', "");
Expect(1, 68000, '\P{Scx=mero}', "");
Expect(0, 68000, '\P{^Scx=mero}', "");
Expect(1, 67999, '\p{Scx=_	Mero}', "");
Expect(0, 67999, '\p{^Scx=_	Mero}', "");
Expect(0, 67999, '\P{Scx=_	Mero}', "");
Expect(1, 67999, '\P{^Scx=_	Mero}', "");
Expect(0, 68000, '\p{Scx=_	Mero}', "");
Expect(1, 68000, '\p{^Scx=_	Mero}', "");
Expect(1, 68000, '\P{Scx=_	Mero}', "");
Expect(0, 68000, '\P{^Scx=_	Mero}', "");
Error('\p{Is_Script_Extensions=:=Meroitic_hieroglyphs}');
Error('\P{Is_Script_Extensions=:=Meroitic_hieroglyphs}');
Expect(1, 67999, '\p{Is_Script_Extensions=meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^Is_Script_Extensions=meroitichieroglyphs}', "");
Expect(0, 67999, '\P{Is_Script_Extensions=meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^Is_Script_Extensions=meroitichieroglyphs}', "");
Expect(0, 68000, '\p{Is_Script_Extensions=meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^Is_Script_Extensions=meroitichieroglyphs}', "");
Expect(1, 68000, '\P{Is_Script_Extensions=meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^Is_Script_Extensions=meroitichieroglyphs}', "");
Expect(1, 67999, '\p{Is_Script_Extensions=	-Meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\p{^Is_Script_Extensions=	-Meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\P{Is_Script_Extensions=	-Meroitic_Hieroglyphs}', "");
Expect(1, 67999, '\P{^Is_Script_Extensions=	-Meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\p{Is_Script_Extensions=	-Meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\p{^Is_Script_Extensions=	-Meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\P{Is_Script_Extensions=	-Meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\P{^Is_Script_Extensions=	-Meroitic_Hieroglyphs}', "");
Error('\p{Is_Scx= /a/Mero}');
Error('\P{Is_Scx= /a/Mero}');
Expect(1, 67999, '\p{Is_Scx=mero}', "");
Expect(0, 67999, '\p{^Is_Scx=mero}', "");
Expect(0, 67999, '\P{Is_Scx=mero}', "");
Expect(1, 67999, '\P{^Is_Scx=mero}', "");
Expect(0, 68000, '\p{Is_Scx=mero}', "");
Expect(1, 68000, '\p{^Is_Scx=mero}', "");
Expect(1, 68000, '\P{Is_Scx=mero}', "");
Expect(0, 68000, '\P{^Is_Scx=mero}', "");
Expect(1, 67999, '\p{Is_Scx= -mero}', "");
Expect(0, 67999, '\p{^Is_Scx= -mero}', "");
Expect(0, 67999, '\P{Is_Scx= -mero}', "");
Expect(1, 67999, '\P{^Is_Scx= -mero}', "");
Expect(0, 68000, '\p{Is_Scx= -mero}', "");
Expect(1, 68000, '\p{^Is_Scx= -mero}', "");
Expect(1, 68000, '\P{Is_Scx= -mero}', "");
Expect(0, 68000, '\P{^Is_Scx= -mero}', "");
Error('\p{Script_Extensions:	/a/_	MALAYALAM}');
Error('\P{Script_Extensions:	/a/_	MALAYALAM}');
Expect(1, 3455, '\p{Script_Extensions: malayalam}', "");
Expect(0, 3455, '\p{^Script_Extensions: malayalam}', "");
Expect(0, 3455, '\P{Script_Extensions: malayalam}', "");
Expect(1, 3455, '\P{^Script_Extensions: malayalam}', "");
Expect(0, 3456, '\p{Script_Extensions: malayalam}', "");
Expect(1, 3456, '\p{^Script_Extensions: malayalam}', "");
Expect(1, 3456, '\P{Script_Extensions: malayalam}', "");
Expect(0, 3456, '\P{^Script_Extensions: malayalam}', "");
Expect(1, 3455, '\p{Script_Extensions:   	_malayalam}', "");
Expect(0, 3455, '\p{^Script_Extensions:   	_malayalam}', "");
Expect(0, 3455, '\P{Script_Extensions:   	_malayalam}', "");
Expect(1, 3455, '\P{^Script_Extensions:   	_malayalam}', "");
Expect(0, 3456, '\p{Script_Extensions:   	_malayalam}', "");
Expect(1, 3456, '\p{^Script_Extensions:   	_malayalam}', "");
Expect(1, 3456, '\P{Script_Extensions:   	_malayalam}', "");
Expect(0, 3456, '\P{^Script_Extensions:   	_malayalam}', "");
Error('\p{Scx=/a/	Mlym}');
Error('\P{Scx=/a/	Mlym}');
Expect(1, 3455, '\p{Scx=mlym}', "");
Expect(0, 3455, '\p{^Scx=mlym}', "");
Expect(0, 3455, '\P{Scx=mlym}', "");
Expect(1, 3455, '\P{^Scx=mlym}', "");
Expect(0, 3456, '\p{Scx=mlym}', "");
Expect(1, 3456, '\p{^Scx=mlym}', "");
Expect(1, 3456, '\P{Scx=mlym}', "");
Expect(0, 3456, '\P{^Scx=mlym}', "");
Expect(1, 3455, '\p{Scx=-_MLYM}', "");
Expect(0, 3455, '\p{^Scx=-_MLYM}', "");
Expect(0, 3455, '\P{Scx=-_MLYM}', "");
Expect(1, 3455, '\P{^Scx=-_MLYM}', "");
Expect(0, 3456, '\p{Scx=-_MLYM}', "");
Expect(1, 3456, '\p{^Scx=-_MLYM}', "");
Expect(1, 3456, '\P{Scx=-_MLYM}', "");
Expect(0, 3456, '\P{^Scx=-_MLYM}', "");
Error('\p{Is_Script_Extensions= /a/Malayalam}');
Error('\P{Is_Script_Extensions= /a/Malayalam}');
Expect(1, 3455, '\p{Is_Script_Extensions=malayalam}', "");
Expect(0, 3455, '\p{^Is_Script_Extensions=malayalam}', "");
Expect(0, 3455, '\P{Is_Script_Extensions=malayalam}', "");
Expect(1, 3455, '\P{^Is_Script_Extensions=malayalam}', "");
Expect(0, 3456, '\p{Is_Script_Extensions=malayalam}', "");
Expect(1, 3456, '\p{^Is_Script_Extensions=malayalam}', "");
Expect(1, 3456, '\P{Is_Script_Extensions=malayalam}', "");
Expect(0, 3456, '\P{^Is_Script_Extensions=malayalam}', "");
Expect(1, 3455, '\p{Is_Script_Extensions=	malayalam}', "");
Expect(0, 3455, '\p{^Is_Script_Extensions=	malayalam}', "");
Expect(0, 3455, '\P{Is_Script_Extensions=	malayalam}', "");
Expect(1, 3455, '\P{^Is_Script_Extensions=	malayalam}', "");
Expect(0, 3456, '\p{Is_Script_Extensions=	malayalam}', "");
Expect(1, 3456, '\p{^Is_Script_Extensions=	malayalam}', "");
Expect(1, 3456, '\P{Is_Script_Extensions=	malayalam}', "");
Expect(0, 3456, '\P{^Is_Script_Extensions=	malayalam}', "");
Error('\p{Is_Scx=-Mlym/a/}');
Error('\P{Is_Scx=-Mlym/a/}');
Expect(1, 3455, '\p{Is_Scx=mlym}', "");
Expect(0, 3455, '\p{^Is_Scx=mlym}', "");
Expect(0, 3455, '\P{Is_Scx=mlym}', "");
Expect(1, 3455, '\P{^Is_Scx=mlym}', "");
Expect(0, 3456, '\p{Is_Scx=mlym}', "");
Expect(1, 3456, '\p{^Is_Scx=mlym}', "");
Expect(1, 3456, '\P{Is_Scx=mlym}', "");
Expect(0, 3456, '\P{^Is_Scx=mlym}', "");
Expect(1, 3455, '\p{Is_Scx=_	Mlym}', "");
Expect(0, 3455, '\p{^Is_Scx=_	Mlym}', "");
Expect(0, 3455, '\P{Is_Scx=_	Mlym}', "");
Expect(1, 3455, '\P{^Is_Scx=_	Mlym}', "");
Expect(0, 3456, '\p{Is_Scx=_	Mlym}', "");
Expect(1, 3456, '\p{^Is_Scx=_	Mlym}', "");
Expect(1, 3456, '\P{Is_Scx=_	Mlym}', "");
Expect(0, 3456, '\P{^Is_Scx=_	Mlym}', "");
Error('\p{Script_Extensions: mongolian/a/}');
Error('\P{Script_Extensions: mongolian/a/}');
Expect(1, 6314, '\p{Script_Extensions=mongolian}', "");
Expect(0, 6314, '\p{^Script_Extensions=mongolian}', "");
Expect(0, 6314, '\P{Script_Extensions=mongolian}', "");
Expect(1, 6314, '\P{^Script_Extensions=mongolian}', "");
Expect(0, 6315, '\p{Script_Extensions=mongolian}', "");
Expect(1, 6315, '\p{^Script_Extensions=mongolian}', "");
Expect(1, 6315, '\P{Script_Extensions=mongolian}', "");
Expect(0, 6315, '\P{^Script_Extensions=mongolian}', "");
Expect(1, 6314, '\p{Script_Extensions=-Mongolian}', "");
Expect(0, 6314, '\p{^Script_Extensions=-Mongolian}', "");
Expect(0, 6314, '\P{Script_Extensions=-Mongolian}', "");
Expect(1, 6314, '\P{^Script_Extensions=-Mongolian}', "");
Expect(0, 6315, '\p{Script_Extensions=-Mongolian}', "");
Expect(1, 6315, '\p{^Script_Extensions=-Mongolian}', "");
Expect(1, 6315, '\P{Script_Extensions=-Mongolian}', "");
Expect(0, 6315, '\P{^Script_Extensions=-Mongolian}', "");
Error('\p{Scx=:=		mong}');
Error('\P{Scx=:=		mong}');
Expect(1, 6314, '\p{Scx=mong}', "");
Expect(0, 6314, '\p{^Scx=mong}', "");
Expect(0, 6314, '\P{Scx=mong}', "");
Expect(1, 6314, '\P{^Scx=mong}', "");
Expect(0, 6315, '\p{Scx=mong}', "");
Expect(1, 6315, '\p{^Scx=mong}', "");
Expect(1, 6315, '\P{Scx=mong}', "");
Expect(0, 6315, '\P{^Scx=mong}', "");
Expect(1, 6314, '\p{Scx: 		Mong}', "");
Expect(0, 6314, '\p{^Scx: 		Mong}', "");
Expect(0, 6314, '\P{Scx: 		Mong}', "");
Expect(1, 6314, '\P{^Scx: 		Mong}', "");
Expect(0, 6315, '\p{Scx: 		Mong}', "");
Expect(1, 6315, '\p{^Scx: 		Mong}', "");
Expect(1, 6315, '\P{Scx: 		Mong}', "");
Expect(0, 6315, '\P{^Scx: 		Mong}', "");
Error('\p{Is_Script_Extensions=_:=mongolian}');
Error('\P{Is_Script_Extensions=_:=mongolian}');
Expect(1, 6314, '\p{Is_Script_Extensions=mongolian}', "");
Expect(0, 6314, '\p{^Is_Script_Extensions=mongolian}', "");
Expect(0, 6314, '\P{Is_Script_Extensions=mongolian}', "");
Expect(1, 6314, '\P{^Is_Script_Extensions=mongolian}', "");
Expect(0, 6315, '\p{Is_Script_Extensions=mongolian}', "");
Expect(1, 6315, '\p{^Is_Script_Extensions=mongolian}', "");
Expect(1, 6315, '\P{Is_Script_Extensions=mongolian}', "");
Expect(0, 6315, '\P{^Is_Script_Extensions=mongolian}', "");
Expect(1, 6314, '\p{Is_Script_Extensions=	_mongolian}', "");
Expect(0, 6314, '\p{^Is_Script_Extensions=	_mongolian}', "");
Expect(0, 6314, '\P{Is_Script_Extensions=	_mongolian}', "");
Expect(1, 6314, '\P{^Is_Script_Extensions=	_mongolian}', "");
Expect(0, 6315, '\p{Is_Script_Extensions=	_mongolian}', "");
Expect(1, 6315, '\p{^Is_Script_Extensions=	_mongolian}', "");
Expect(1, 6315, '\P{Is_Script_Extensions=	_mongolian}', "");
Expect(0, 6315, '\P{^Is_Script_Extensions=	_mongolian}', "");
Error('\p{Is_Scx=/a/ MONG}');
Error('\P{Is_Scx=/a/ MONG}');
Expect(1, 6314, '\p{Is_Scx=mong}', "");
Expect(0, 6314, '\p{^Is_Scx=mong}', "");
Expect(0, 6314, '\P{Is_Scx=mong}', "");
Expect(1, 6314, '\P{^Is_Scx=mong}', "");
Expect(0, 6315, '\p{Is_Scx=mong}', "");
Expect(1, 6315, '\p{^Is_Scx=mong}', "");
Expect(1, 6315, '\P{Is_Scx=mong}', "");
Expect(0, 6315, '\P{^Is_Scx=mong}', "");
Expect(1, 6314, '\p{Is_Scx=_-Mong}', "");
Expect(0, 6314, '\p{^Is_Scx=_-Mong}', "");
Expect(0, 6314, '\P{Is_Scx=_-Mong}', "");
Expect(1, 6314, '\P{^Is_Scx=_-Mong}', "");
Expect(0, 6315, '\p{Is_Scx=_-Mong}', "");
Expect(1, 6315, '\p{^Is_Scx=_-Mong}', "");
Expect(1, 6315, '\P{Is_Scx=_-Mong}', "");
Expect(0, 6315, '\P{^Is_Scx=_-Mong}', "");
Error('\p{Script_Extensions=	:=Meetei_MAYEK}');
Error('\P{Script_Extensions=	:=Meetei_MAYEK}');
Expect(1, 44025, '\p{Script_Extensions=meeteimayek}', "");
Expect(0, 44025, '\p{^Script_Extensions=meeteimayek}', "");
Expect(0, 44025, '\P{Script_Extensions=meeteimayek}', "");
Expect(1, 44025, '\P{^Script_Extensions=meeteimayek}', "");
Expect(0, 44026, '\p{Script_Extensions=meeteimayek}', "");
Expect(1, 44026, '\p{^Script_Extensions=meeteimayek}', "");
Expect(1, 44026, '\P{Script_Extensions=meeteimayek}', "");
Expect(0, 44026, '\P{^Script_Extensions=meeteimayek}', "");
Expect(1, 44025, '\p{Script_Extensions=_Meetei_Mayek}', "");
Expect(0, 44025, '\p{^Script_Extensions=_Meetei_Mayek}', "");
Expect(0, 44025, '\P{Script_Extensions=_Meetei_Mayek}', "");
Expect(1, 44025, '\P{^Script_Extensions=_Meetei_Mayek}', "");
Expect(0, 44026, '\p{Script_Extensions=_Meetei_Mayek}', "");
Expect(1, 44026, '\p{^Script_Extensions=_Meetei_Mayek}', "");
Expect(1, 44026, '\P{Script_Extensions=_Meetei_Mayek}', "");
Expect(0, 44026, '\P{^Script_Extensions=_Meetei_Mayek}', "");
Error('\p{Scx=:=_	Mtei}');
Error('\P{Scx=:=_	Mtei}');
Expect(1, 44025, '\p{Scx=mtei}', "");
Expect(0, 44025, '\p{^Scx=mtei}', "");
Expect(0, 44025, '\P{Scx=mtei}', "");
Expect(1, 44025, '\P{^Scx=mtei}', "");
Expect(0, 44026, '\p{Scx=mtei}', "");
Expect(1, 44026, '\p{^Scx=mtei}', "");
Expect(1, 44026, '\P{Scx=mtei}', "");
Expect(0, 44026, '\P{^Scx=mtei}', "");
Expect(1, 44025, '\p{Scx=MTEI}', "");
Expect(0, 44025, '\p{^Scx=MTEI}', "");
Expect(0, 44025, '\P{Scx=MTEI}', "");
Expect(1, 44025, '\P{^Scx=MTEI}', "");
Expect(0, 44026, '\p{Scx=MTEI}', "");
Expect(1, 44026, '\p{^Scx=MTEI}', "");
Expect(1, 44026, '\P{Scx=MTEI}', "");
Expect(0, 44026, '\P{^Scx=MTEI}', "");
Error('\p{Is_Script_Extensions=/a/	 Meetei_MAYEK}');
Error('\P{Is_Script_Extensions=/a/	 Meetei_MAYEK}');
Expect(1, 44025, '\p{Is_Script_Extensions=meeteimayek}', "");
Expect(0, 44025, '\p{^Is_Script_Extensions=meeteimayek}', "");
Expect(0, 44025, '\P{Is_Script_Extensions=meeteimayek}', "");
Expect(1, 44025, '\P{^Is_Script_Extensions=meeteimayek}', "");
Expect(0, 44026, '\p{Is_Script_Extensions=meeteimayek}', "");
Expect(1, 44026, '\p{^Is_Script_Extensions=meeteimayek}', "");
Expect(1, 44026, '\P{Is_Script_Extensions=meeteimayek}', "");
Expect(0, 44026, '\P{^Is_Script_Extensions=meeteimayek}', "");
Expect(1, 44025, '\p{Is_Script_Extensions=  Meetei_Mayek}', "");
Expect(0, 44025, '\p{^Is_Script_Extensions=  Meetei_Mayek}', "");
Expect(0, 44025, '\P{Is_Script_Extensions=  Meetei_Mayek}', "");
Expect(1, 44025, '\P{^Is_Script_Extensions=  Meetei_Mayek}', "");
Expect(0, 44026, '\p{Is_Script_Extensions=  Meetei_Mayek}', "");
Expect(1, 44026, '\p{^Is_Script_Extensions=  Meetei_Mayek}', "");
Expect(1, 44026, '\P{Is_Script_Extensions=  Meetei_Mayek}', "");
Expect(0, 44026, '\P{^Is_Script_Extensions=  Meetei_Mayek}', "");
Error('\p{Is_Scx=- mtei/a/}');
Error('\P{Is_Scx=- mtei/a/}');
Expect(1, 44025, '\p{Is_Scx=mtei}', "");
Expect(0, 44025, '\p{^Is_Scx=mtei}', "");
Expect(0, 44025, '\P{Is_Scx=mtei}', "");
Expect(1, 44025, '\P{^Is_Scx=mtei}', "");
Expect(0, 44026, '\p{Is_Scx=mtei}', "");
Expect(1, 44026, '\p{^Is_Scx=mtei}', "");
Expect(1, 44026, '\P{Is_Scx=mtei}', "");
Expect(0, 44026, '\P{^Is_Scx=mtei}', "");
Expect(1, 44025, '\p{Is_Scx=-Mtei}', "");
Expect(0, 44025, '\p{^Is_Scx=-Mtei}', "");
Expect(0, 44025, '\P{Is_Scx=-Mtei}', "");
Expect(1, 44025, '\P{^Is_Scx=-Mtei}', "");
Expect(0, 44026, '\p{Is_Scx=-Mtei}', "");
Expect(1, 44026, '\p{^Is_Scx=-Mtei}', "");
Expect(1, 44026, '\P{Is_Scx=-Mtei}', "");
Expect(0, 44026, '\P{^Is_Scx=-Mtei}', "");
Error('\p{Script_Extensions:   /a/_	Myanmar}');
Error('\P{Script_Extensions:   /a/_	Myanmar}');
Expect(1, 43643, '\p{Script_Extensions:   myanmar}', "");
Expect(0, 43643, '\p{^Script_Extensions:   myanmar}', "");
Expect(0, 43643, '\P{Script_Extensions:   myanmar}', "");
Expect(1, 43643, '\P{^Script_Extensions:   myanmar}', "");
Expect(0, 43644, '\p{Script_Extensions:   myanmar}', "");
Expect(1, 43644, '\p{^Script_Extensions:   myanmar}', "");
Expect(1, 43644, '\P{Script_Extensions:   myanmar}', "");
Expect(0, 43644, '\P{^Script_Extensions:   myanmar}', "");
Expect(1, 43643, '\p{Script_Extensions=  myanmar}', "");
Expect(0, 43643, '\p{^Script_Extensions=  myanmar}', "");
Expect(0, 43643, '\P{Script_Extensions=  myanmar}', "");
Expect(1, 43643, '\P{^Script_Extensions=  myanmar}', "");
Expect(0, 43644, '\p{Script_Extensions=  myanmar}', "");
Expect(1, 43644, '\p{^Script_Extensions=  myanmar}', "");
Expect(1, 43644, '\P{Script_Extensions=  myanmar}', "");
Expect(0, 43644, '\P{^Script_Extensions=  myanmar}', "");
Error('\p{Scx= _mymr:=}');
Error('\P{Scx= _mymr:=}');
Expect(1, 43643, '\p{Scx=mymr}', "");
Expect(0, 43643, '\p{^Scx=mymr}', "");
Expect(0, 43643, '\P{Scx=mymr}', "");
Expect(1, 43643, '\P{^Scx=mymr}', "");
Expect(0, 43644, '\p{Scx=mymr}', "");
Expect(1, 43644, '\p{^Scx=mymr}', "");
Expect(1, 43644, '\P{Scx=mymr}', "");
Expect(0, 43644, '\P{^Scx=mymr}', "");
Expect(1, 43643, '\p{Scx=  Mymr}', "");
Expect(0, 43643, '\p{^Scx=  Mymr}', "");
Expect(0, 43643, '\P{Scx=  Mymr}', "");
Expect(1, 43643, '\P{^Scx=  Mymr}', "");
Expect(0, 43644, '\p{Scx=  Mymr}', "");
Expect(1, 43644, '\p{^Scx=  Mymr}', "");
Expect(1, 43644, '\P{Scx=  Mymr}', "");
Expect(0, 43644, '\P{^Scx=  Mymr}', "");
Error('\p{Is_Script_Extensions=/a/	myanmar}');
Error('\P{Is_Script_Extensions=/a/	myanmar}');
Expect(1, 43643, '\p{Is_Script_Extensions=myanmar}', "");
Expect(0, 43643, '\p{^Is_Script_Extensions=myanmar}', "");
Expect(0, 43643, '\P{Is_Script_Extensions=myanmar}', "");
Expect(1, 43643, '\P{^Is_Script_Extensions=myanmar}', "");
Expect(0, 43644, '\p{Is_Script_Extensions=myanmar}', "");
Expect(1, 43644, '\p{^Is_Script_Extensions=myanmar}', "");
Expect(1, 43644, '\P{Is_Script_Extensions=myanmar}', "");
Expect(0, 43644, '\P{^Is_Script_Extensions=myanmar}', "");
Expect(1, 43643, '\p{Is_Script_Extensions=_-myanmar}', "");
Expect(0, 43643, '\p{^Is_Script_Extensions=_-myanmar}', "");
Expect(0, 43643, '\P{Is_Script_Extensions=_-myanmar}', "");
Expect(1, 43643, '\P{^Is_Script_Extensions=_-myanmar}', "");
Expect(0, 43644, '\p{Is_Script_Extensions=_-myanmar}', "");
Expect(1, 43644, '\p{^Is_Script_Extensions=_-myanmar}', "");
Expect(1, 43644, '\P{Is_Script_Extensions=_-myanmar}', "");
Expect(0, 43644, '\P{^Is_Script_Extensions=_-myanmar}', "");
Error('\p{Is_Scx=:=_mymr}');
Error('\P{Is_Scx=:=_mymr}');
Expect(1, 43643, '\p{Is_Scx=mymr}', "");
Expect(0, 43643, '\p{^Is_Scx=mymr}', "");
Expect(0, 43643, '\P{Is_Scx=mymr}', "");
Expect(1, 43643, '\P{^Is_Scx=mymr}', "");
Expect(0, 43644, '\p{Is_Scx=mymr}', "");
Expect(1, 43644, '\p{^Is_Scx=mymr}', "");
Expect(1, 43644, '\P{Is_Scx=mymr}', "");
Expect(0, 43644, '\P{^Is_Scx=mymr}', "");
Expect(1, 43643, '\p{Is_Scx=- MYMR}', "");
Expect(0, 43643, '\p{^Is_Scx=- MYMR}', "");
Expect(0, 43643, '\P{Is_Scx=- MYMR}', "");
Expect(1, 43643, '\P{^Is_Scx=- MYMR}', "");
Expect(0, 43644, '\p{Is_Scx=- MYMR}', "");
Expect(1, 43644, '\p{^Is_Scx=- MYMR}', "");
Expect(1, 43644, '\P{Is_Scx=- MYMR}', "");
Expect(0, 43644, '\P{^Is_Scx=- MYMR}', "");
Error('\p{Script_Extensions=/a/_Nko}');
Error('\P{Script_Extensions=/a/_Nko}');
Expect(1, 2042, '\p{Script_Extensions=nko}', "");
Expect(0, 2042, '\p{^Script_Extensions=nko}', "");
Expect(0, 2042, '\P{Script_Extensions=nko}', "");
Expect(1, 2042, '\P{^Script_Extensions=nko}', "");
Expect(0, 2043, '\p{Script_Extensions=nko}', "");
Expect(1, 2043, '\p{^Script_Extensions=nko}', "");
Expect(1, 2043, '\P{Script_Extensions=nko}', "");
Expect(0, 2043, '\P{^Script_Extensions=nko}', "");
Expect(1, 2042, '\p{Script_Extensions=	_Nko}', "");
Expect(0, 2042, '\p{^Script_Extensions=	_Nko}', "");
Expect(0, 2042, '\P{Script_Extensions=	_Nko}', "");
Expect(1, 2042, '\P{^Script_Extensions=	_Nko}', "");
Expect(0, 2043, '\p{Script_Extensions=	_Nko}', "");
Expect(1, 2043, '\p{^Script_Extensions=	_Nko}', "");
Expect(1, 2043, '\P{Script_Extensions=	_Nko}', "");
Expect(0, 2043, '\P{^Script_Extensions=	_Nko}', "");
Error('\p{Scx=_	Nkoo/a/}');
Error('\P{Scx=_	Nkoo/a/}');
Expect(1, 2042, '\p{Scx=nkoo}', "");
Expect(0, 2042, '\p{^Scx=nkoo}', "");
Expect(0, 2042, '\P{Scx=nkoo}', "");
Expect(1, 2042, '\P{^Scx=nkoo}', "");
Expect(0, 2043, '\p{Scx=nkoo}', "");
Expect(1, 2043, '\p{^Scx=nkoo}', "");
Expect(1, 2043, '\P{Scx=nkoo}', "");
Expect(0, 2043, '\P{^Scx=nkoo}', "");
Expect(1, 2042, '\p{Scx=	 Nkoo}', "");
Expect(0, 2042, '\p{^Scx=	 Nkoo}', "");
Expect(0, 2042, '\P{Scx=	 Nkoo}', "");
Expect(1, 2042, '\P{^Scx=	 Nkoo}', "");
Expect(0, 2043, '\p{Scx=	 Nkoo}', "");
Expect(1, 2043, '\p{^Scx=	 Nkoo}', "");
Expect(1, 2043, '\P{Scx=	 Nkoo}', "");
Expect(0, 2043, '\P{^Scx=	 Nkoo}', "");
Error('\p{Is_Script_Extensions=	/a/Nko}');
Error('\P{Is_Script_Extensions=	/a/Nko}');
Expect(1, 2042, '\p{Is_Script_Extensions=nko}', "");
Expect(0, 2042, '\p{^Is_Script_Extensions=nko}', "");
Expect(0, 2042, '\P{Is_Script_Extensions=nko}', "");
Expect(1, 2042, '\P{^Is_Script_Extensions=nko}', "");
Expect(0, 2043, '\p{Is_Script_Extensions=nko}', "");
Expect(1, 2043, '\p{^Is_Script_Extensions=nko}', "");
Expect(1, 2043, '\P{Is_Script_Extensions=nko}', "");
Expect(0, 2043, '\P{^Is_Script_Extensions=nko}', "");
Expect(1, 2042, '\p{Is_Script_Extensions= Nko}', "");
Expect(0, 2042, '\p{^Is_Script_Extensions= Nko}', "");
Expect(0, 2042, '\P{Is_Script_Extensions= Nko}', "");
Expect(1, 2042, '\P{^Is_Script_Extensions= Nko}', "");
Expect(0, 2043, '\p{Is_Script_Extensions= Nko}', "");
Expect(1, 2043, '\p{^Is_Script_Extensions= Nko}', "");
Expect(1, 2043, '\P{Is_Script_Extensions= Nko}', "");
Expect(0, 2043, '\P{^Is_Script_Extensions= Nko}', "");
Error('\p{Is_Scx=-NKOO:=}');
Error('\P{Is_Scx=-NKOO:=}');
Expect(1, 2042, '\p{Is_Scx=nkoo}', "");
Expect(0, 2042, '\p{^Is_Scx=nkoo}', "");
Expect(0, 2042, '\P{Is_Scx=nkoo}', "");
Expect(1, 2042, '\P{^Is_Scx=nkoo}', "");
Expect(0, 2043, '\p{Is_Scx=nkoo}', "");
Expect(1, 2043, '\p{^Is_Scx=nkoo}', "");
Expect(1, 2043, '\P{Is_Scx=nkoo}', "");
Expect(0, 2043, '\P{^Is_Scx=nkoo}', "");
Expect(1, 2042, '\p{Is_Scx:	Nkoo}', "");
Expect(0, 2042, '\p{^Is_Scx:	Nkoo}', "");
Expect(0, 2042, '\P{Is_Scx:	Nkoo}', "");
Expect(1, 2042, '\P{^Is_Scx:	Nkoo}', "");
Expect(0, 2043, '\p{Is_Scx:	Nkoo}', "");
Expect(1, 2043, '\p{^Is_Scx:	Nkoo}', "");
Expect(1, 2043, '\P{Is_Scx:	Nkoo}', "");
Expect(0, 2043, '\P{^Is_Scx:	Nkoo}', "");
Error('\p{Script_Extensions=-:=ogham}');
Error('\P{Script_Extensions=-:=ogham}');
Expect(1, 5788, '\p{Script_Extensions: ogham}', "");
Expect(0, 5788, '\p{^Script_Extensions: ogham}', "");
Expect(0, 5788, '\P{Script_Extensions: ogham}', "");
Expect(1, 5788, '\P{^Script_Extensions: ogham}', "");
Expect(0, 5789, '\p{Script_Extensions: ogham}', "");
Expect(1, 5789, '\p{^Script_Extensions: ogham}', "");
Expect(1, 5789, '\P{Script_Extensions: ogham}', "");
Expect(0, 5789, '\P{^Script_Extensions: ogham}', "");
Expect(1, 5788, '\p{Script_Extensions=	Ogham}', "");
Expect(0, 5788, '\p{^Script_Extensions=	Ogham}', "");
Expect(0, 5788, '\P{Script_Extensions=	Ogham}', "");
Expect(1, 5788, '\P{^Script_Extensions=	Ogham}', "");
Expect(0, 5789, '\p{Script_Extensions=	Ogham}', "");
Expect(1, 5789, '\p{^Script_Extensions=	Ogham}', "");
Expect(1, 5789, '\P{Script_Extensions=	Ogham}', "");
Expect(0, 5789, '\P{^Script_Extensions=	Ogham}', "");
Error('\p{Scx: 	/a/OGAM}');
Error('\P{Scx: 	/a/OGAM}');
Expect(1, 5788, '\p{Scx=ogam}', "");
Expect(0, 5788, '\p{^Scx=ogam}', "");
Expect(0, 5788, '\P{Scx=ogam}', "");
Expect(1, 5788, '\P{^Scx=ogam}', "");
Expect(0, 5789, '\p{Scx=ogam}', "");
Expect(1, 5789, '\p{^Scx=ogam}', "");
Expect(1, 5789, '\P{Scx=ogam}', "");
Expect(0, 5789, '\P{^Scx=ogam}', "");
Expect(1, 5788, '\p{Scx= -Ogam}', "");
Expect(0, 5788, '\p{^Scx= -Ogam}', "");
Expect(0, 5788, '\P{Scx= -Ogam}', "");
Expect(1, 5788, '\P{^Scx= -Ogam}', "");
Expect(0, 5789, '\p{Scx= -Ogam}', "");
Expect(1, 5789, '\p{^Scx= -Ogam}', "");
Expect(1, 5789, '\P{Scx= -Ogam}', "");
Expect(0, 5789, '\P{^Scx= -Ogam}', "");
Error('\p{Is_Script_Extensions=:=ogham}');
Error('\P{Is_Script_Extensions=:=ogham}');
Expect(1, 5788, '\p{Is_Script_Extensions=ogham}', "");
Expect(0, 5788, '\p{^Is_Script_Extensions=ogham}', "");
Expect(0, 5788, '\P{Is_Script_Extensions=ogham}', "");
Expect(1, 5788, '\P{^Is_Script_Extensions=ogham}', "");
Expect(0, 5789, '\p{Is_Script_Extensions=ogham}', "");
Expect(1, 5789, '\p{^Is_Script_Extensions=ogham}', "");
Expect(1, 5789, '\P{Is_Script_Extensions=ogham}', "");
Expect(0, 5789, '\P{^Is_Script_Extensions=ogham}', "");
Expect(1, 5788, '\p{Is_Script_Extensions=__Ogham}', "");
Expect(0, 5788, '\p{^Is_Script_Extensions=__Ogham}', "");
Expect(0, 5788, '\P{Is_Script_Extensions=__Ogham}', "");
Expect(1, 5788, '\P{^Is_Script_Extensions=__Ogham}', "");
Expect(0, 5789, '\p{Is_Script_Extensions=__Ogham}', "");
Expect(1, 5789, '\p{^Is_Script_Extensions=__Ogham}', "");
Expect(1, 5789, '\P{Is_Script_Extensions=__Ogham}', "");
Expect(0, 5789, '\P{^Is_Script_Extensions=__Ogham}', "");
Error('\p{Is_Scx=	OGAM/a/}');
Error('\P{Is_Scx=	OGAM/a/}');
Expect(1, 5788, '\p{Is_Scx=ogam}', "");
Expect(0, 5788, '\p{^Is_Scx=ogam}', "");
Expect(0, 5788, '\P{Is_Scx=ogam}', "");
Expect(1, 5788, '\P{^Is_Scx=ogam}', "");
Expect(0, 5789, '\p{Is_Scx=ogam}', "");
Expect(1, 5789, '\p{^Is_Scx=ogam}', "");
Expect(1, 5789, '\P{Is_Scx=ogam}', "");
Expect(0, 5789, '\P{^Is_Scx=ogam}', "");
Expect(1, 5788, '\p{Is_Scx=_ogam}', "");
Expect(0, 5788, '\p{^Is_Scx=_ogam}', "");
Expect(0, 5788, '\P{Is_Scx=_ogam}', "");
Expect(1, 5788, '\P{^Is_Scx=_ogam}', "");
Expect(0, 5789, '\p{Is_Scx=_ogam}', "");
Expect(1, 5789, '\p{^Is_Scx=_ogam}', "");
Expect(1, 5789, '\P{Is_Scx=_ogam}', "");
Expect(0, 5789, '\P{^Is_Scx=_ogam}', "");
Error('\p{Script_Extensions=_	OL_chiki/a/}');
Error('\P{Script_Extensions=_	OL_chiki/a/}');
Expect(1, 7295, '\p{Script_Extensions=olchiki}', "");
Expect(0, 7295, '\p{^Script_Extensions=olchiki}', "");
Expect(0, 7295, '\P{Script_Extensions=olchiki}', "");
Expect(1, 7295, '\P{^Script_Extensions=olchiki}', "");
Expect(0, 7296, '\p{Script_Extensions=olchiki}', "");
Expect(1, 7296, '\p{^Script_Extensions=olchiki}', "");
Expect(1, 7296, '\P{Script_Extensions=olchiki}', "");
Expect(0, 7296, '\P{^Script_Extensions=olchiki}', "");
Expect(1, 7295, '\p{Script_Extensions=	 Ol_Chiki}', "");
Expect(0, 7295, '\p{^Script_Extensions=	 Ol_Chiki}', "");
Expect(0, 7295, '\P{Script_Extensions=	 Ol_Chiki}', "");
Expect(1, 7295, '\P{^Script_Extensions=	 Ol_Chiki}', "");
Expect(0, 7296, '\p{Script_Extensions=	 Ol_Chiki}', "");
Expect(1, 7296, '\p{^Script_Extensions=	 Ol_Chiki}', "");
Expect(1, 7296, '\P{Script_Extensions=	 Ol_Chiki}', "");
Expect(0, 7296, '\P{^Script_Extensions=	 Ol_Chiki}', "");
Error('\p{Scx=/a/olck}');
Error('\P{Scx=/a/olck}');
Expect(1, 7295, '\p{Scx=olck}', "");
Expect(0, 7295, '\p{^Scx=olck}', "");
Expect(0, 7295, '\P{Scx=olck}', "");
Expect(1, 7295, '\P{^Scx=olck}', "");
Expect(0, 7296, '\p{Scx=olck}', "");
Expect(1, 7296, '\p{^Scx=olck}', "");
Expect(1, 7296, '\P{Scx=olck}', "");
Expect(0, 7296, '\P{^Scx=olck}', "");
Expect(1, 7295, '\p{Scx=	-OLCK}', "");
Expect(0, 7295, '\p{^Scx=	-OLCK}', "");
Expect(0, 7295, '\P{Scx=	-OLCK}', "");
Expect(1, 7295, '\P{^Scx=	-OLCK}', "");
Expect(0, 7296, '\p{Scx=	-OLCK}', "");
Expect(1, 7296, '\p{^Scx=	-OLCK}', "");
Expect(1, 7296, '\P{Scx=	-OLCK}', "");
Expect(0, 7296, '\P{^Scx=	-OLCK}', "");
Error('\p{Is_Script_Extensions=	_Ol_chiki:=}');
Error('\P{Is_Script_Extensions=	_Ol_chiki:=}');
Expect(1, 7295, '\p{Is_Script_Extensions=olchiki}', "");
Expect(0, 7295, '\p{^Is_Script_Extensions=olchiki}', "");
Expect(0, 7295, '\P{Is_Script_Extensions=olchiki}', "");
Expect(1, 7295, '\P{^Is_Script_Extensions=olchiki}', "");
Expect(0, 7296, '\p{Is_Script_Extensions=olchiki}', "");
Expect(1, 7296, '\p{^Is_Script_Extensions=olchiki}', "");
Expect(1, 7296, '\P{Is_Script_Extensions=olchiki}', "");
Expect(0, 7296, '\P{^Is_Script_Extensions=olchiki}', "");
Expect(1, 7295, '\p{Is_Script_Extensions=__Ol_Chiki}', "");
Expect(0, 7295, '\p{^Is_Script_Extensions=__Ol_Chiki}', "");
Expect(0, 7295, '\P{Is_Script_Extensions=__Ol_Chiki}', "");
Expect(1, 7295, '\P{^Is_Script_Extensions=__Ol_Chiki}', "");
Expect(0, 7296, '\p{Is_Script_Extensions=__Ol_Chiki}', "");
Expect(1, 7296, '\p{^Is_Script_Extensions=__Ol_Chiki}', "");
Expect(1, 7296, '\P{Is_Script_Extensions=__Ol_Chiki}', "");
Expect(0, 7296, '\P{^Is_Script_Extensions=__Ol_Chiki}', "");
Error('\p{Is_Scx=/a/ OLCK}');
Error('\P{Is_Scx=/a/ OLCK}');
Expect(1, 7295, '\p{Is_Scx=olck}', "");
Expect(0, 7295, '\p{^Is_Scx=olck}', "");
Expect(0, 7295, '\P{Is_Scx=olck}', "");
Expect(1, 7295, '\P{^Is_Scx=olck}', "");
Expect(0, 7296, '\p{Is_Scx=olck}', "");
Expect(1, 7296, '\p{^Is_Scx=olck}', "");
Expect(1, 7296, '\P{Is_Scx=olck}', "");
Expect(0, 7296, '\P{^Is_Scx=olck}', "");
Expect(1, 7295, '\p{Is_Scx=__Olck}', "");
Expect(0, 7295, '\p{^Is_Scx=__Olck}', "");
Expect(0, 7295, '\P{Is_Scx=__Olck}', "");
Expect(1, 7295, '\P{^Is_Scx=__Olck}', "");
Expect(0, 7296, '\p{Is_Scx=__Olck}', "");
Expect(1, 7296, '\p{^Is_Scx=__Olck}', "");
Expect(1, 7296, '\P{Is_Scx=__Olck}', "");
Expect(0, 7296, '\P{^Is_Scx=__Olck}', "");
Error('\p{Script_Extensions= 	Old_TURKIC:=}');
Error('\P{Script_Extensions= 	Old_TURKIC:=}');
Expect(1, 68680, '\p{Script_Extensions=oldturkic}', "");
Expect(0, 68680, '\p{^Script_Extensions=oldturkic}', "");
Expect(0, 68680, '\P{Script_Extensions=oldturkic}', "");
Expect(1, 68680, '\P{^Script_Extensions=oldturkic}', "");
Expect(0, 68681, '\p{Script_Extensions=oldturkic}', "");
Expect(1, 68681, '\p{^Script_Extensions=oldturkic}', "");
Expect(1, 68681, '\P{Script_Extensions=oldturkic}', "");
Expect(0, 68681, '\P{^Script_Extensions=oldturkic}', "");
Expect(1, 68680, '\p{Script_Extensions: 	Old_Turkic}', "");
Expect(0, 68680, '\p{^Script_Extensions: 	Old_Turkic}', "");
Expect(0, 68680, '\P{Script_Extensions: 	Old_Turkic}', "");
Expect(1, 68680, '\P{^Script_Extensions: 	Old_Turkic}', "");
Expect(0, 68681, '\p{Script_Extensions: 	Old_Turkic}', "");
Expect(1, 68681, '\p{^Script_Extensions: 	Old_Turkic}', "");
Expect(1, 68681, '\P{Script_Extensions: 	Old_Turkic}', "");
Expect(0, 68681, '\P{^Script_Extensions: 	Old_Turkic}', "");
Error('\p{Scx=:=	_Orkh}');
Error('\P{Scx=:=	_Orkh}');
Expect(1, 68680, '\p{Scx=orkh}', "");
Expect(0, 68680, '\p{^Scx=orkh}', "");
Expect(0, 68680, '\P{Scx=orkh}', "");
Expect(1, 68680, '\P{^Scx=orkh}', "");
Expect(0, 68681, '\p{Scx=orkh}', "");
Expect(1, 68681, '\p{^Scx=orkh}', "");
Expect(1, 68681, '\P{Scx=orkh}', "");
Expect(0, 68681, '\P{^Scx=orkh}', "");
Expect(1, 68680, '\p{Scx=_ Orkh}', "");
Expect(0, 68680, '\p{^Scx=_ Orkh}', "");
Expect(0, 68680, '\P{Scx=_ Orkh}', "");
Expect(1, 68680, '\P{^Scx=_ Orkh}', "");
Expect(0, 68681, '\p{Scx=_ Orkh}', "");
Expect(1, 68681, '\p{^Scx=_ Orkh}', "");
Expect(1, 68681, '\P{Scx=_ Orkh}', "");
Expect(0, 68681, '\P{^Scx=_ Orkh}', "");
Error('\p{Is_Script_Extensions= -Old_turkic/a/}');
Error('\P{Is_Script_Extensions= -Old_turkic/a/}');
Expect(1, 68680, '\p{Is_Script_Extensions=oldturkic}', "");
Expect(0, 68680, '\p{^Is_Script_Extensions=oldturkic}', "");
Expect(0, 68680, '\P{Is_Script_Extensions=oldturkic}', "");
Expect(1, 68680, '\P{^Is_Script_Extensions=oldturkic}', "");
Expect(0, 68681, '\p{Is_Script_Extensions=oldturkic}', "");
Expect(1, 68681, '\p{^Is_Script_Extensions=oldturkic}', "");
Expect(1, 68681, '\P{Is_Script_Extensions=oldturkic}', "");
Expect(0, 68681, '\P{^Is_Script_Extensions=oldturkic}', "");
Expect(1, 68680, '\p{Is_Script_Extensions=__Old_Turkic}', "");
Expect(0, 68680, '\p{^Is_Script_Extensions=__Old_Turkic}', "");
Expect(0, 68680, '\P{Is_Script_Extensions=__Old_Turkic}', "");
Expect(1, 68680, '\P{^Is_Script_Extensions=__Old_Turkic}', "");
Expect(0, 68681, '\p{Is_Script_Extensions=__Old_Turkic}', "");
Expect(1, 68681, '\p{^Is_Script_Extensions=__Old_Turkic}', "");
Expect(1, 68681, '\P{Is_Script_Extensions=__Old_Turkic}', "");
Expect(0, 68681, '\P{^Is_Script_Extensions=__Old_Turkic}', "");
Error('\p{Is_Scx: /a/Orkh}');
Error('\P{Is_Scx: /a/Orkh}');
Expect(1, 68680, '\p{Is_Scx=orkh}', "");
Expect(0, 68680, '\p{^Is_Scx=orkh}', "");
Expect(0, 68680, '\P{Is_Scx=orkh}', "");
Expect(1, 68680, '\P{^Is_Scx=orkh}', "");
Expect(0, 68681, '\p{Is_Scx=orkh}', "");
Expect(1, 68681, '\p{^Is_Scx=orkh}', "");
Expect(1, 68681, '\P{Is_Scx=orkh}', "");
Expect(0, 68681, '\P{^Is_Scx=orkh}', "");
Expect(1, 68680, '\p{Is_Scx=-Orkh}', "");
Expect(0, 68680, '\p{^Is_Scx=-Orkh}', "");
Expect(0, 68680, '\P{Is_Scx=-Orkh}', "");
Expect(1, 68680, '\P{^Is_Scx=-Orkh}', "");
Expect(0, 68681, '\p{Is_Scx=-Orkh}', "");
Expect(1, 68681, '\p{^Is_Scx=-Orkh}', "");
Expect(1, 68681, '\P{Is_Scx=-Orkh}', "");
Expect(0, 68681, '\P{^Is_Scx=-Orkh}', "");
Error('\p{Script_Extensions:    :=oriya}');
Error('\P{Script_Extensions:    :=oriya}');
Expect(1, 2935, '\p{Script_Extensions=oriya}', "");
Expect(0, 2935, '\p{^Script_Extensions=oriya}', "");
Expect(0, 2935, '\P{Script_Extensions=oriya}', "");
Expect(1, 2935, '\P{^Script_Extensions=oriya}', "");
Expect(0, 2936, '\p{Script_Extensions=oriya}', "");
Expect(1, 2936, '\p{^Script_Extensions=oriya}', "");
Expect(1, 2936, '\P{Script_Extensions=oriya}', "");
Expect(0, 2936, '\P{^Script_Extensions=oriya}', "");
Expect(1, 2935, '\p{Script_Extensions=	 ORIYA}', "");
Expect(0, 2935, '\p{^Script_Extensions=	 ORIYA}', "");
Expect(0, 2935, '\P{Script_Extensions=	 ORIYA}', "");
Expect(1, 2935, '\P{^Script_Extensions=	 ORIYA}', "");
Expect(0, 2936, '\p{Script_Extensions=	 ORIYA}', "");
Expect(1, 2936, '\p{^Script_Extensions=	 ORIYA}', "");
Expect(1, 2936, '\P{Script_Extensions=	 ORIYA}', "");
Expect(0, 2936, '\P{^Script_Extensions=	 ORIYA}', "");
Error('\p{Scx=/a/	_Orya}');
Error('\P{Scx=/a/	_Orya}');
Expect(1, 2935, '\p{Scx=orya}', "");
Expect(0, 2935, '\p{^Scx=orya}', "");
Expect(0, 2935, '\P{Scx=orya}', "");
Expect(1, 2935, '\P{^Scx=orya}', "");
Expect(0, 2936, '\p{Scx=orya}', "");
Expect(1, 2936, '\p{^Scx=orya}', "");
Expect(1, 2936, '\P{Scx=orya}', "");
Expect(0, 2936, '\P{^Scx=orya}', "");
Expect(1, 2935, '\p{Scx=_ORYA}', "");
Expect(0, 2935, '\p{^Scx=_ORYA}', "");
Expect(0, 2935, '\P{Scx=_ORYA}', "");
Expect(1, 2935, '\P{^Scx=_ORYA}', "");
Expect(0, 2936, '\p{Scx=_ORYA}', "");
Expect(1, 2936, '\p{^Scx=_ORYA}', "");
Expect(1, 2936, '\P{Scx=_ORYA}', "");
Expect(0, 2936, '\P{^Scx=_ORYA}', "");
Error('\p{Is_Script_Extensions:   	/a/Oriya}');
Error('\P{Is_Script_Extensions:   	/a/Oriya}');
Expect(1, 2935, '\p{Is_Script_Extensions=oriya}', "");
Expect(0, 2935, '\p{^Is_Script_Extensions=oriya}', "");
Expect(0, 2935, '\P{Is_Script_Extensions=oriya}', "");
Expect(1, 2935, '\P{^Is_Script_Extensions=oriya}', "");
Expect(0, 2936, '\p{Is_Script_Extensions=oriya}', "");
Expect(1, 2936, '\p{^Is_Script_Extensions=oriya}', "");
Expect(1, 2936, '\P{Is_Script_Extensions=oriya}', "");
Expect(0, 2936, '\P{^Is_Script_Extensions=oriya}', "");
Expect(1, 2935, '\p{Is_Script_Extensions:	Oriya}', "");
Expect(0, 2935, '\p{^Is_Script_Extensions:	Oriya}', "");
Expect(0, 2935, '\P{Is_Script_Extensions:	Oriya}', "");
Expect(1, 2935, '\P{^Is_Script_Extensions:	Oriya}', "");
Expect(0, 2936, '\p{Is_Script_Extensions:	Oriya}', "");
Expect(1, 2936, '\p{^Is_Script_Extensions:	Oriya}', "");
Expect(1, 2936, '\P{Is_Script_Extensions:	Oriya}', "");
Expect(0, 2936, '\P{^Is_Script_Extensions:	Oriya}', "");
Error('\p{Is_Scx=-ORYA:=}');
Error('\P{Is_Scx=-ORYA:=}');
Expect(1, 2935, '\p{Is_Scx:orya}', "");
Expect(0, 2935, '\p{^Is_Scx:orya}', "");
Expect(0, 2935, '\P{Is_Scx:orya}', "");
Expect(1, 2935, '\P{^Is_Scx:orya}', "");
Expect(0, 2936, '\p{Is_Scx:orya}', "");
Expect(1, 2936, '\p{^Is_Scx:orya}', "");
Expect(1, 2936, '\P{Is_Scx:orya}', "");
Expect(0, 2936, '\P{^Is_Scx:orya}', "");
Expect(1, 2935, '\p{Is_Scx= 	Orya}', "");
Expect(0, 2935, '\p{^Is_Scx= 	Orya}', "");
Expect(0, 2935, '\P{Is_Scx= 	Orya}', "");
Expect(1, 2935, '\P{^Is_Scx= 	Orya}', "");
Expect(0, 2936, '\p{Is_Scx= 	Orya}', "");
Expect(1, 2936, '\p{^Is_Scx= 	Orya}', "");
Expect(1, 2936, '\P{Is_Scx= 	Orya}', "");
Expect(0, 2936, '\P{^Is_Scx= 	Orya}', "");
Error('\p{Script_Extensions:		Osmanya:=}');
Error('\P{Script_Extensions:		Osmanya:=}');
Expect(1, 66729, '\p{Script_Extensions=osmanya}', "");
Expect(0, 66729, '\p{^Script_Extensions=osmanya}', "");
Expect(0, 66729, '\P{Script_Extensions=osmanya}', "");
Expect(1, 66729, '\P{^Script_Extensions=osmanya}', "");
Expect(0, 66730, '\p{Script_Extensions=osmanya}', "");
Expect(1, 66730, '\p{^Script_Extensions=osmanya}', "");
Expect(1, 66730, '\P{Script_Extensions=osmanya}', "");
Expect(0, 66730, '\P{^Script_Extensions=osmanya}', "");
Expect(1, 66729, '\p{Script_Extensions=	Osmanya}', "");
Expect(0, 66729, '\p{^Script_Extensions=	Osmanya}', "");
Expect(0, 66729, '\P{Script_Extensions=	Osmanya}', "");
Expect(1, 66729, '\P{^Script_Extensions=	Osmanya}', "");
Expect(0, 66730, '\p{Script_Extensions=	Osmanya}', "");
Expect(1, 66730, '\p{^Script_Extensions=	Osmanya}', "");
Expect(1, 66730, '\P{Script_Extensions=	Osmanya}', "");
Expect(0, 66730, '\P{^Script_Extensions=	Osmanya}', "");
Error('\p{Scx=:=Osma}');
Error('\P{Scx=:=Osma}');
Expect(1, 66729, '\p{Scx=osma}', "");
Expect(0, 66729, '\p{^Scx=osma}', "");
Expect(0, 66729, '\P{Scx=osma}', "");
Expect(1, 66729, '\P{^Scx=osma}', "");
Expect(0, 66730, '\p{Scx=osma}', "");
Expect(1, 66730, '\p{^Scx=osma}', "");
Expect(1, 66730, '\P{Scx=osma}', "");
Expect(0, 66730, '\P{^Scx=osma}', "");
Expect(1, 66729, '\p{Scx= -Osma}', "");
Expect(0, 66729, '\p{^Scx= -Osma}', "");
Expect(0, 66729, '\P{Scx= -Osma}', "");
Expect(1, 66729, '\P{^Scx= -Osma}', "");
Expect(0, 66730, '\p{Scx= -Osma}', "");
Expect(1, 66730, '\p{^Scx= -Osma}', "");
Expect(1, 66730, '\P{Scx= -Osma}', "");
Expect(0, 66730, '\P{^Scx= -Osma}', "");
Error('\p{Is_Script_Extensions=:=-_OSMANYA}');
Error('\P{Is_Script_Extensions=:=-_OSMANYA}');
Expect(1, 66729, '\p{Is_Script_Extensions=osmanya}', "");
Expect(0, 66729, '\p{^Is_Script_Extensions=osmanya}', "");
Expect(0, 66729, '\P{Is_Script_Extensions=osmanya}', "");
Expect(1, 66729, '\P{^Is_Script_Extensions=osmanya}', "");
Expect(0, 66730, '\p{Is_Script_Extensions=osmanya}', "");
Expect(1, 66730, '\p{^Is_Script_Extensions=osmanya}', "");
Expect(1, 66730, '\P{Is_Script_Extensions=osmanya}', "");
Expect(0, 66730, '\P{^Is_Script_Extensions=osmanya}', "");
Expect(1, 66729, '\p{Is_Script_Extensions=_-Osmanya}', "");
Expect(0, 66729, '\p{^Is_Script_Extensions=_-Osmanya}', "");
Expect(0, 66729, '\P{Is_Script_Extensions=_-Osmanya}', "");
Expect(1, 66729, '\P{^Is_Script_Extensions=_-Osmanya}', "");
Expect(0, 66730, '\p{Is_Script_Extensions=_-Osmanya}', "");
Expect(1, 66730, '\p{^Is_Script_Extensions=_-Osmanya}', "");
Expect(1, 66730, '\P{Is_Script_Extensions=_-Osmanya}', "");
Expect(0, 66730, '\P{^Is_Script_Extensions=_-Osmanya}', "");
Error('\p{Is_Scx= 	osma:=}');
Error('\P{Is_Scx= 	osma:=}');
Expect(1, 66729, '\p{Is_Scx=osma}', "");
Expect(0, 66729, '\p{^Is_Scx=osma}', "");
Expect(0, 66729, '\P{Is_Scx=osma}', "");
Expect(1, 66729, '\P{^Is_Scx=osma}', "");
Expect(0, 66730, '\p{Is_Scx=osma}', "");
Expect(1, 66730, '\p{^Is_Scx=osma}', "");
Expect(1, 66730, '\P{Is_Scx=osma}', "");
Expect(0, 66730, '\P{^Is_Scx=osma}', "");
Expect(1, 66729, '\p{Is_Scx=__OSMA}', "");
Expect(0, 66729, '\p{^Is_Scx=__OSMA}', "");
Expect(0, 66729, '\P{Is_Scx=__OSMA}', "");
Expect(1, 66729, '\P{^Is_Scx=__OSMA}', "");
Expect(0, 66730, '\p{Is_Scx=__OSMA}', "");
Expect(1, 66730, '\p{^Is_Scx=__OSMA}', "");
Expect(1, 66730, '\P{Is_Scx=__OSMA}', "");
Expect(0, 66730, '\P{^Is_Scx=__OSMA}', "");
Error('\p{Script_Extensions=/a/ Phags_Pa}');
Error('\P{Script_Extensions=/a/ Phags_Pa}');
Expect(1, 43127, '\p{Script_Extensions=phagspa}', "");
Expect(0, 43127, '\p{^Script_Extensions=phagspa}', "");
Expect(0, 43127, '\P{Script_Extensions=phagspa}', "");
Expect(1, 43127, '\P{^Script_Extensions=phagspa}', "");
Expect(0, 43128, '\p{Script_Extensions=phagspa}', "");
Expect(1, 43128, '\p{^Script_Extensions=phagspa}', "");
Expect(1, 43128, '\P{Script_Extensions=phagspa}', "");
Expect(0, 43128, '\P{^Script_Extensions=phagspa}', "");
Expect(1, 43127, '\p{Script_Extensions= 	Phags_Pa}', "");
Expect(0, 43127, '\p{^Script_Extensions= 	Phags_Pa}', "");
Expect(0, 43127, '\P{Script_Extensions= 	Phags_Pa}', "");
Expect(1, 43127, '\P{^Script_Extensions= 	Phags_Pa}', "");
Expect(0, 43128, '\p{Script_Extensions= 	Phags_Pa}', "");
Expect(1, 43128, '\p{^Script_Extensions= 	Phags_Pa}', "");
Expect(1, 43128, '\P{Script_Extensions= 	Phags_Pa}', "");
Expect(0, 43128, '\P{^Script_Extensions= 	Phags_Pa}', "");
Error('\p{Scx:		 phag:=}');
Error('\P{Scx:		 phag:=}');
Expect(1, 43127, '\p{Scx=phag}', "");
Expect(0, 43127, '\p{^Scx=phag}', "");
Expect(0, 43127, '\P{Scx=phag}', "");
Expect(1, 43127, '\P{^Scx=phag}', "");
Expect(0, 43128, '\p{Scx=phag}', "");
Expect(1, 43128, '\p{^Scx=phag}', "");
Expect(1, 43128, '\P{Scx=phag}', "");
Expect(0, 43128, '\P{^Scx=phag}', "");
Error('\p{Is_Script_Extensions=-Phags_PA:=}');
Error('\P{Is_Script_Extensions=-Phags_PA:=}');
Expect(1, 43127, '\p{Is_Script_Extensions=phagspa}', "");
Expect(0, 43127, '\p{^Is_Script_Extensions=phagspa}', "");
Expect(0, 43127, '\P{Is_Script_Extensions=phagspa}', "");
Expect(1, 43127, '\P{^Is_Script_Extensions=phagspa}', "");
Expect(0, 43128, '\p{Is_Script_Extensions=phagspa}', "");
Expect(1, 43128, '\p{^Is_Script_Extensions=phagspa}', "");
Expect(1, 43128, '\P{Is_Script_Extensions=phagspa}', "");
Expect(0, 43128, '\P{^Is_Script_Extensions=phagspa}', "");
Expect(1, 43127, '\p{Is_Script_Extensions=_PHAGS_Pa}', "");
Expect(0, 43127, '\p{^Is_Script_Extensions=_PHAGS_Pa}', "");
Expect(0, 43127, '\P{Is_Script_Extensions=_PHAGS_Pa}', "");
Expect(1, 43127, '\P{^Is_Script_Extensions=_PHAGS_Pa}', "");
Expect(0, 43128, '\p{Is_Script_Extensions=_PHAGS_Pa}', "");
Expect(1, 43128, '\p{^Is_Script_Extensions=_PHAGS_Pa}', "");
Expect(1, 43128, '\P{Is_Script_Extensions=_PHAGS_Pa}', "");
Expect(0, 43128, '\P{^Is_Script_Extensions=_PHAGS_Pa}', "");
Error('\p{Is_Scx=	_Phag:=}');
Error('\P{Is_Scx=	_Phag:=}');
Expect(1, 43127, '\p{Is_Scx=phag}', "");
Expect(0, 43127, '\p{^Is_Scx=phag}', "");
Expect(0, 43127, '\P{Is_Scx=phag}', "");
Expect(1, 43127, '\P{^Is_Scx=phag}', "");
Expect(0, 43128, '\p{Is_Scx=phag}', "");
Expect(1, 43128, '\p{^Is_Scx=phag}', "");
Expect(1, 43128, '\P{Is_Scx=phag}', "");
Expect(0, 43128, '\P{^Is_Scx=phag}', "");
Expect(1, 43127, '\p{Is_Scx=-Phag}', "");
Expect(0, 43127, '\p{^Is_Scx=-Phag}', "");
Expect(0, 43127, '\P{Is_Scx=-Phag}', "");
Expect(1, 43127, '\P{^Is_Scx=-Phag}', "");
Expect(0, 43128, '\p{Is_Scx=-Phag}', "");
Expect(1, 43128, '\p{^Is_Scx=-Phag}', "");
Expect(1, 43128, '\P{Is_Scx=-Phag}', "");
Expect(0, 43128, '\P{^Is_Scx=-Phag}', "");
Error('\p{Script_Extensions=_:=Inscriptional_Pahlavi}');
Error('\P{Script_Extensions=_:=Inscriptional_Pahlavi}');
Expect(1, 68479, '\p{Script_Extensions=inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^Script_Extensions=inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{Script_Extensions=inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^Script_Extensions=inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{Script_Extensions=inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^Script_Extensions=inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{Script_Extensions=inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^Script_Extensions=inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{Script_Extensions=__Inscriptional_Pahlavi}', "");
Expect(0, 68479, '\p{^Script_Extensions=__Inscriptional_Pahlavi}', "");
Expect(0, 68479, '\P{Script_Extensions=__Inscriptional_Pahlavi}', "");
Expect(1, 68479, '\P{^Script_Extensions=__Inscriptional_Pahlavi}', "");
Expect(0, 68480, '\p{Script_Extensions=__Inscriptional_Pahlavi}', "");
Expect(1, 68480, '\p{^Script_Extensions=__Inscriptional_Pahlavi}', "");
Expect(1, 68480, '\P{Script_Extensions=__Inscriptional_Pahlavi}', "");
Expect(0, 68480, '\P{^Script_Extensions=__Inscriptional_Pahlavi}', "");
Error('\p{Scx=/a/_	Phli}');
Error('\P{Scx=/a/_	Phli}');
Expect(1, 68479, '\p{Scx=phli}', "");
Expect(0, 68479, '\p{^Scx=phli}', "");
Expect(0, 68479, '\P{Scx=phli}', "");
Expect(1, 68479, '\P{^Scx=phli}', "");
Expect(0, 68480, '\p{Scx=phli}', "");
Expect(1, 68480, '\p{^Scx=phli}', "");
Expect(1, 68480, '\P{Scx=phli}', "");
Expect(0, 68480, '\P{^Scx=phli}', "");
Expect(1, 68479, '\p{Scx=-	Phli}', "");
Expect(0, 68479, '\p{^Scx=-	Phli}', "");
Expect(0, 68479, '\P{Scx=-	Phli}', "");
Expect(1, 68479, '\P{^Scx=-	Phli}', "");
Expect(0, 68480, '\p{Scx=-	Phli}', "");
Expect(1, 68480, '\p{^Scx=-	Phli}', "");
Expect(1, 68480, '\P{Scx=-	Phli}', "");
Expect(0, 68480, '\P{^Scx=-	Phli}', "");
Error('\p{Is_Script_Extensions=inscriptional_pahlavi/a/}');
Error('\P{Is_Script_Extensions=inscriptional_pahlavi/a/}');
Expect(1, 68479, '\p{Is_Script_Extensions=inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^Is_Script_Extensions=inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{Is_Script_Extensions=inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^Is_Script_Extensions=inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{Is_Script_Extensions=inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^Is_Script_Extensions=inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{Is_Script_Extensions=inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^Is_Script_Extensions=inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{Is_Script_Extensions=  INSCRIPTIONAL_PAHLAVI}', "");
Expect(0, 68479, '\p{^Is_Script_Extensions=  INSCRIPTIONAL_PAHLAVI}', "");
Expect(0, 68479, '\P{Is_Script_Extensions=  INSCRIPTIONAL_PAHLAVI}', "");
Expect(1, 68479, '\P{^Is_Script_Extensions=  INSCRIPTIONAL_PAHLAVI}', "");
Expect(0, 68480, '\p{Is_Script_Extensions=  INSCRIPTIONAL_PAHLAVI}', "");
Expect(1, 68480, '\p{^Is_Script_Extensions=  INSCRIPTIONAL_PAHLAVI}', "");
Expect(1, 68480, '\P{Is_Script_Extensions=  INSCRIPTIONAL_PAHLAVI}', "");
Expect(0, 68480, '\P{^Is_Script_Extensions=  INSCRIPTIONAL_PAHLAVI}', "");
Error('\p{Is_Scx=- Phli/a/}');
Error('\P{Is_Scx=- Phli/a/}');
Expect(1, 68479, '\p{Is_Scx=phli}', "");
Expect(0, 68479, '\p{^Is_Scx=phli}', "");
Expect(0, 68479, '\P{Is_Scx=phli}', "");
Expect(1, 68479, '\P{^Is_Scx=phli}', "");
Expect(0, 68480, '\p{Is_Scx=phli}', "");
Expect(1, 68480, '\p{^Is_Scx=phli}', "");
Expect(1, 68480, '\P{Is_Scx=phli}', "");
Expect(0, 68480, '\P{^Is_Scx=phli}', "");
Expect(1, 68479, '\p{Is_Scx:	 PHLI}', "");
Expect(0, 68479, '\p{^Is_Scx:	 PHLI}', "");
Expect(0, 68479, '\P{Is_Scx:	 PHLI}', "");
Expect(1, 68479, '\P{^Is_Scx:	 PHLI}', "");
Expect(0, 68480, '\p{Is_Scx:	 PHLI}', "");
Expect(1, 68480, '\p{^Is_Scx:	 PHLI}', "");
Expect(1, 68480, '\P{Is_Scx:	 PHLI}', "");
Expect(0, 68480, '\P{^Is_Scx:	 PHLI}', "");
Error('\p{Script_Extensions=_/a/phoenician}');
Error('\P{Script_Extensions=_/a/phoenician}');
Expect(1, 67871, '\p{Script_Extensions=phoenician}', "");
Expect(0, 67871, '\p{^Script_Extensions=phoenician}', "");
Expect(0, 67871, '\P{Script_Extensions=phoenician}', "");
Expect(1, 67871, '\P{^Script_Extensions=phoenician}', "");
Expect(0, 67872, '\p{Script_Extensions=phoenician}', "");
Expect(1, 67872, '\p{^Script_Extensions=phoenician}', "");
Expect(1, 67872, '\P{Script_Extensions=phoenician}', "");
Expect(0, 67872, '\P{^Script_Extensions=phoenician}', "");
Expect(1, 67871, '\p{Script_Extensions= -phoenician}', "");
Expect(0, 67871, '\p{^Script_Extensions= -phoenician}', "");
Expect(0, 67871, '\P{Script_Extensions= -phoenician}', "");
Expect(1, 67871, '\P{^Script_Extensions= -phoenician}', "");
Expect(0, 67872, '\p{Script_Extensions= -phoenician}', "");
Expect(1, 67872, '\p{^Script_Extensions= -phoenician}', "");
Expect(1, 67872, '\P{Script_Extensions= -phoenician}', "");
Expect(0, 67872, '\P{^Script_Extensions= -phoenician}', "");
Error('\p{Scx=_:=Phnx}');
Error('\P{Scx=_:=Phnx}');
Expect(1, 67871, '\p{Scx=phnx}', "");
Expect(0, 67871, '\p{^Scx=phnx}', "");
Expect(0, 67871, '\P{Scx=phnx}', "");
Expect(1, 67871, '\P{^Scx=phnx}', "");
Expect(0, 67872, '\p{Scx=phnx}', "");
Expect(1, 67872, '\p{^Scx=phnx}', "");
Expect(1, 67872, '\P{Scx=phnx}', "");
Expect(0, 67872, '\P{^Scx=phnx}', "");
Expect(1, 67871, '\p{Scx=	Phnx}', "");
Expect(0, 67871, '\p{^Scx=	Phnx}', "");
Expect(0, 67871, '\P{Scx=	Phnx}', "");
Expect(1, 67871, '\P{^Scx=	Phnx}', "");
Expect(0, 67872, '\p{Scx=	Phnx}', "");
Expect(1, 67872, '\p{^Scx=	Phnx}', "");
Expect(1, 67872, '\P{Scx=	Phnx}', "");
Expect(0, 67872, '\P{^Scx=	Phnx}', "");
Error('\p{Is_Script_Extensions=  Phoenician/a/}');
Error('\P{Is_Script_Extensions=  Phoenician/a/}');
Expect(1, 67871, '\p{Is_Script_Extensions: phoenician}', "");
Expect(0, 67871, '\p{^Is_Script_Extensions: phoenician}', "");
Expect(0, 67871, '\P{Is_Script_Extensions: phoenician}', "");
Expect(1, 67871, '\P{^Is_Script_Extensions: phoenician}', "");
Expect(0, 67872, '\p{Is_Script_Extensions: phoenician}', "");
Expect(1, 67872, '\p{^Is_Script_Extensions: phoenician}', "");
Expect(1, 67872, '\P{Is_Script_Extensions: phoenician}', "");
Expect(0, 67872, '\P{^Is_Script_Extensions: phoenician}', "");
Expect(1, 67871, '\p{Is_Script_Extensions=-phoenician}', "");
Expect(0, 67871, '\p{^Is_Script_Extensions=-phoenician}', "");
Expect(0, 67871, '\P{Is_Script_Extensions=-phoenician}', "");
Expect(1, 67871, '\P{^Is_Script_Extensions=-phoenician}', "");
Expect(0, 67872, '\p{Is_Script_Extensions=-phoenician}', "");
Expect(1, 67872, '\p{^Is_Script_Extensions=-phoenician}', "");
Expect(1, 67872, '\P{Is_Script_Extensions=-phoenician}', "");
Expect(0, 67872, '\P{^Is_Script_Extensions=-phoenician}', "");
Error('\p{Is_Scx=	:=Phnx}');
Error('\P{Is_Scx=	:=Phnx}');
Expect(1, 67871, '\p{Is_Scx=phnx}', "");
Expect(0, 67871, '\p{^Is_Scx=phnx}', "");
Expect(0, 67871, '\P{Is_Scx=phnx}', "");
Expect(1, 67871, '\P{^Is_Scx=phnx}', "");
Expect(0, 67872, '\p{Is_Scx=phnx}', "");
Expect(1, 67872, '\p{^Is_Scx=phnx}', "");
Expect(1, 67872, '\P{Is_Scx=phnx}', "");
Expect(0, 67872, '\P{^Is_Scx=phnx}', "");
Expect(1, 67871, '\p{Is_Scx=- PHNX}', "");
Expect(0, 67871, '\p{^Is_Scx=- PHNX}', "");
Expect(0, 67871, '\P{Is_Scx=- PHNX}', "");
Expect(1, 67871, '\P{^Is_Scx=- PHNX}', "");
Expect(0, 67872, '\p{Is_Scx=- PHNX}', "");
Expect(1, 67872, '\p{^Is_Scx=- PHNX}', "");
Expect(1, 67872, '\P{Is_Scx=- PHNX}', "");
Expect(0, 67872, '\P{^Is_Scx=- PHNX}', "");
Error('\p{Script_Extensions=:= 	MIAO}');
Error('\P{Script_Extensions=:= 	MIAO}');
Expect(1, 94111, '\p{Script_Extensions=miao}', "");
Expect(0, 94111, '\p{^Script_Extensions=miao}', "");
Expect(0, 94111, '\P{Script_Extensions=miao}', "");
Expect(1, 94111, '\P{^Script_Extensions=miao}', "");
Expect(0, 94112, '\p{Script_Extensions=miao}', "");
Expect(1, 94112, '\p{^Script_Extensions=miao}', "");
Expect(1, 94112, '\P{Script_Extensions=miao}', "");
Expect(0, 94112, '\P{^Script_Extensions=miao}', "");
Expect(1, 94111, '\p{Script_Extensions=-_Miao}', "");
Expect(0, 94111, '\p{^Script_Extensions=-_Miao}', "");
Expect(0, 94111, '\P{Script_Extensions=-_Miao}', "");
Expect(1, 94111, '\P{^Script_Extensions=-_Miao}', "");
Expect(0, 94112, '\p{Script_Extensions=-_Miao}', "");
Expect(1, 94112, '\p{^Script_Extensions=-_Miao}', "");
Expect(1, 94112, '\P{Script_Extensions=-_Miao}', "");
Expect(0, 94112, '\P{^Script_Extensions=-_Miao}', "");
Error('\p{Scx:	Plrd:=}');
Error('\P{Scx:	Plrd:=}');
Expect(1, 94111, '\p{Scx=plrd}', "");
Expect(0, 94111, '\p{^Scx=plrd}', "");
Expect(0, 94111, '\P{Scx=plrd}', "");
Expect(1, 94111, '\P{^Scx=plrd}', "");
Expect(0, 94112, '\p{Scx=plrd}', "");
Expect(1, 94112, '\p{^Scx=plrd}', "");
Expect(1, 94112, '\P{Scx=plrd}', "");
Expect(0, 94112, '\P{^Scx=plrd}', "");
Expect(1, 94111, '\p{Scx=	plrd}', "");
Expect(0, 94111, '\p{^Scx=	plrd}', "");
Expect(0, 94111, '\P{Scx=	plrd}', "");
Expect(1, 94111, '\P{^Scx=	plrd}', "");
Expect(0, 94112, '\p{Scx=	plrd}', "");
Expect(1, 94112, '\p{^Scx=	plrd}', "");
Expect(1, 94112, '\P{Scx=	plrd}', "");
Expect(0, 94112, '\P{^Scx=	plrd}', "");
Error('\p{Is_Script_Extensions=/a/-	miao}');
Error('\P{Is_Script_Extensions=/a/-	miao}');
Expect(1, 94111, '\p{Is_Script_Extensions=miao}', "");
Expect(0, 94111, '\p{^Is_Script_Extensions=miao}', "");
Expect(0, 94111, '\P{Is_Script_Extensions=miao}', "");
Expect(1, 94111, '\P{^Is_Script_Extensions=miao}', "");
Expect(0, 94112, '\p{Is_Script_Extensions=miao}', "");
Expect(1, 94112, '\p{^Is_Script_Extensions=miao}', "");
Expect(1, 94112, '\P{Is_Script_Extensions=miao}', "");
Expect(0, 94112, '\P{^Is_Script_Extensions=miao}', "");
Expect(1, 94111, '\p{Is_Script_Extensions=_Miao}', "");
Expect(0, 94111, '\p{^Is_Script_Extensions=_Miao}', "");
Expect(0, 94111, '\P{Is_Script_Extensions=_Miao}', "");
Expect(1, 94111, '\P{^Is_Script_Extensions=_Miao}', "");
Expect(0, 94112, '\p{Is_Script_Extensions=_Miao}', "");
Expect(1, 94112, '\p{^Is_Script_Extensions=_Miao}', "");
Expect(1, 94112, '\P{Is_Script_Extensions=_Miao}', "");
Expect(0, 94112, '\P{^Is_Script_Extensions=_Miao}', "");
Error('\p{Is_Scx= /a/Plrd}');
Error('\P{Is_Scx= /a/Plrd}');
Expect(1, 94111, '\p{Is_Scx=plrd}', "");
Expect(0, 94111, '\p{^Is_Scx=plrd}', "");
Expect(0, 94111, '\P{Is_Scx=plrd}', "");
Expect(1, 94111, '\P{^Is_Scx=plrd}', "");
Expect(0, 94112, '\p{Is_Scx=plrd}', "");
Expect(1, 94112, '\p{^Is_Scx=plrd}', "");
Expect(1, 94112, '\P{Is_Scx=plrd}', "");
Expect(0, 94112, '\P{^Is_Scx=plrd}', "");
Expect(1, 94111, '\p{Is_Scx=	_plrd}', "");
Expect(0, 94111, '\p{^Is_Scx=	_plrd}', "");
Expect(0, 94111, '\P{Is_Scx=	_plrd}', "");
Expect(1, 94111, '\P{^Is_Scx=	_plrd}', "");
Expect(0, 94112, '\p{Is_Scx=	_plrd}', "");
Expect(1, 94112, '\p{^Is_Scx=	_plrd}', "");
Expect(1, 94112, '\P{Is_Scx=	_plrd}', "");
Expect(0, 94112, '\P{^Is_Scx=	_plrd}', "");
Error('\p{Script_Extensions=/a/ _INSCRIPTIONAL_Parthian}');
Error('\P{Script_Extensions=/a/ _INSCRIPTIONAL_Parthian}');
Expect(1, 68447, '\p{Script_Extensions=inscriptionalparthian}', "");
Expect(0, 68447, '\p{^Script_Extensions=inscriptionalparthian}', "");
Expect(0, 68447, '\P{Script_Extensions=inscriptionalparthian}', "");
Expect(1, 68447, '\P{^Script_Extensions=inscriptionalparthian}', "");
Expect(0, 68448, '\p{Script_Extensions=inscriptionalparthian}', "");
Expect(1, 68448, '\p{^Script_Extensions=inscriptionalparthian}', "");
Expect(1, 68448, '\P{Script_Extensions=inscriptionalparthian}', "");
Expect(0, 68448, '\P{^Script_Extensions=inscriptionalparthian}', "");
Expect(1, 68447, '\p{Script_Extensions= inscriptional_parthian}', "");
Expect(0, 68447, '\p{^Script_Extensions= inscriptional_parthian}', "");
Expect(0, 68447, '\P{Script_Extensions= inscriptional_parthian}', "");
Expect(1, 68447, '\P{^Script_Extensions= inscriptional_parthian}', "");
Expect(0, 68448, '\p{Script_Extensions= inscriptional_parthian}', "");
Expect(1, 68448, '\p{^Script_Extensions= inscriptional_parthian}', "");
Expect(1, 68448, '\P{Script_Extensions= inscriptional_parthian}', "");
Expect(0, 68448, '\P{^Script_Extensions= inscriptional_parthian}', "");
Error('\p{Scx=:= PRTI}');
Error('\P{Scx=:= PRTI}');
Expect(1, 68447, '\p{Scx=prti}', "");
Expect(0, 68447, '\p{^Scx=prti}', "");
Expect(0, 68447, '\P{Scx=prti}', "");
Expect(1, 68447, '\P{^Scx=prti}', "");
Expect(0, 68448, '\p{Scx=prti}', "");
Expect(1, 68448, '\p{^Scx=prti}', "");
Expect(1, 68448, '\P{Scx=prti}', "");
Expect(0, 68448, '\P{^Scx=prti}', "");
Expect(1, 68447, '\p{Scx:   -_Prti}', "");
Expect(0, 68447, '\p{^Scx:   -_Prti}', "");
Expect(0, 68447, '\P{Scx:   -_Prti}', "");
Expect(1, 68447, '\P{^Scx:   -_Prti}', "");
Expect(0, 68448, '\p{Scx:   -_Prti}', "");
Expect(1, 68448, '\p{^Scx:   -_Prti}', "");
Expect(1, 68448, '\P{Scx:   -_Prti}', "");
Expect(0, 68448, '\P{^Scx:   -_Prti}', "");
Error('\p{Is_Script_Extensions=/a/_	INSCRIPTIONAL_Parthian}');
Error('\P{Is_Script_Extensions=/a/_	INSCRIPTIONAL_Parthian}');
Expect(1, 68447, '\p{Is_Script_Extensions=inscriptionalparthian}', "");
Expect(0, 68447, '\p{^Is_Script_Extensions=inscriptionalparthian}', "");
Expect(0, 68447, '\P{Is_Script_Extensions=inscriptionalparthian}', "");
Expect(1, 68447, '\P{^Is_Script_Extensions=inscriptionalparthian}', "");
Expect(0, 68448, '\p{Is_Script_Extensions=inscriptionalparthian}', "");
Expect(1, 68448, '\p{^Is_Script_Extensions=inscriptionalparthian}', "");
Expect(1, 68448, '\P{Is_Script_Extensions=inscriptionalparthian}', "");
Expect(0, 68448, '\P{^Is_Script_Extensions=inscriptionalparthian}', "");
Expect(1, 68447, '\p{Is_Script_Extensions= _Inscriptional_PARTHIAN}', "");
Expect(0, 68447, '\p{^Is_Script_Extensions= _Inscriptional_PARTHIAN}', "");
Expect(0, 68447, '\P{Is_Script_Extensions= _Inscriptional_PARTHIAN}', "");
Expect(1, 68447, '\P{^Is_Script_Extensions= _Inscriptional_PARTHIAN}', "");
Expect(0, 68448, '\p{Is_Script_Extensions= _Inscriptional_PARTHIAN}', "");
Expect(1, 68448, '\p{^Is_Script_Extensions= _Inscriptional_PARTHIAN}', "");
Expect(1, 68448, '\P{Is_Script_Extensions= _Inscriptional_PARTHIAN}', "");
Expect(0, 68448, '\P{^Is_Script_Extensions= _Inscriptional_PARTHIAN}', "");
Error('\p{Is_Scx=_ prti/a/}');
Error('\P{Is_Scx=_ prti/a/}');
Expect(1, 68447, '\p{Is_Scx=prti}', "");
Expect(0, 68447, '\p{^Is_Scx=prti}', "");
Expect(0, 68447, '\P{Is_Scx=prti}', "");
Expect(1, 68447, '\P{^Is_Scx=prti}', "");
Expect(0, 68448, '\p{Is_Scx=prti}', "");
Expect(1, 68448, '\p{^Is_Scx=prti}', "");
Expect(1, 68448, '\P{Is_Scx=prti}', "");
Expect(0, 68448, '\P{^Is_Scx=prti}', "");
Expect(1, 68447, '\p{Is_Scx=-	PRTI}', "");
Expect(0, 68447, '\p{^Is_Scx=-	PRTI}', "");
Expect(0, 68447, '\P{Is_Scx=-	PRTI}', "");
Expect(1, 68447, '\P{^Is_Scx=-	PRTI}', "");
Expect(0, 68448, '\p{Is_Scx=-	PRTI}', "");
Expect(1, 68448, '\p{^Is_Scx=-	PRTI}', "");
Expect(1, 68448, '\P{Is_Scx=-	PRTI}', "");
Expect(0, 68448, '\P{^Is_Scx=-	PRTI}', "");
Error('\p{Script_Extensions=/a/-Rejang}');
Error('\P{Script_Extensions=/a/-Rejang}');
Expect(1, 43359, '\p{Script_Extensions=rejang}', "");
Expect(0, 43359, '\p{^Script_Extensions=rejang}', "");
Expect(0, 43359, '\P{Script_Extensions=rejang}', "");
Expect(1, 43359, '\P{^Script_Extensions=rejang}', "");
Expect(0, 43360, '\p{Script_Extensions=rejang}', "");
Expect(1, 43360, '\p{^Script_Extensions=rejang}', "");
Expect(1, 43360, '\P{Script_Extensions=rejang}', "");
Expect(0, 43360, '\P{^Script_Extensions=rejang}', "");
Expect(1, 43359, '\p{Script_Extensions:	 REJANG}', "");
Expect(0, 43359, '\p{^Script_Extensions:	 REJANG}', "");
Expect(0, 43359, '\P{Script_Extensions:	 REJANG}', "");
Expect(1, 43359, '\P{^Script_Extensions:	 REJANG}', "");
Expect(0, 43360, '\p{Script_Extensions:	 REJANG}', "");
Expect(1, 43360, '\p{^Script_Extensions:	 REJANG}', "");
Expect(1, 43360, '\P{Script_Extensions:	 REJANG}', "");
Expect(0, 43360, '\P{^Script_Extensions:	 REJANG}', "");
Error('\p{Scx:-/a/Rjng}');
Error('\P{Scx:-/a/Rjng}');
Expect(1, 43359, '\p{Scx=rjng}', "");
Expect(0, 43359, '\p{^Scx=rjng}', "");
Expect(0, 43359, '\P{Scx=rjng}', "");
Expect(1, 43359, '\P{^Scx=rjng}', "");
Expect(0, 43360, '\p{Scx=rjng}', "");
Expect(1, 43360, '\p{^Scx=rjng}', "");
Expect(1, 43360, '\P{Scx=rjng}', "");
Expect(0, 43360, '\P{^Scx=rjng}', "");
Expect(1, 43359, '\p{Scx=	_Rjng}', "");
Expect(0, 43359, '\p{^Scx=	_Rjng}', "");
Expect(0, 43359, '\P{Scx=	_Rjng}', "");
Expect(1, 43359, '\P{^Scx=	_Rjng}', "");
Expect(0, 43360, '\p{Scx=	_Rjng}', "");
Expect(1, 43360, '\p{^Scx=	_Rjng}', "");
Expect(1, 43360, '\P{Scx=	_Rjng}', "");
Expect(0, 43360, '\P{^Scx=	_Rjng}', "");
Error('\p{Is_Script_Extensions=-:=Rejang}');
Error('\P{Is_Script_Extensions=-:=Rejang}');
Expect(1, 43359, '\p{Is_Script_Extensions=rejang}', "");
Expect(0, 43359, '\p{^Is_Script_Extensions=rejang}', "");
Expect(0, 43359, '\P{Is_Script_Extensions=rejang}', "");
Expect(1, 43359, '\P{^Is_Script_Extensions=rejang}', "");
Expect(0, 43360, '\p{Is_Script_Extensions=rejang}', "");
Expect(1, 43360, '\p{^Is_Script_Extensions=rejang}', "");
Expect(1, 43360, '\P{Is_Script_Extensions=rejang}', "");
Expect(0, 43360, '\P{^Is_Script_Extensions=rejang}', "");
Expect(1, 43359, '\p{Is_Script_Extensions=- REJANG}', "");
Expect(0, 43359, '\p{^Is_Script_Extensions=- REJANG}', "");
Expect(0, 43359, '\P{Is_Script_Extensions=- REJANG}', "");
Expect(1, 43359, '\P{^Is_Script_Extensions=- REJANG}', "");
Expect(0, 43360, '\p{Is_Script_Extensions=- REJANG}', "");
Expect(1, 43360, '\p{^Is_Script_Extensions=- REJANG}', "");
Expect(1, 43360, '\P{Is_Script_Extensions=- REJANG}', "");
Expect(0, 43360, '\P{^Is_Script_Extensions=- REJANG}', "");
Error('\p{Is_Scx:	-Rjng/a/}');
Error('\P{Is_Scx:	-Rjng/a/}');
Expect(1, 43359, '\p{Is_Scx=rjng}', "");
Expect(0, 43359, '\p{^Is_Scx=rjng}', "");
Expect(0, 43359, '\P{Is_Scx=rjng}', "");
Expect(1, 43359, '\P{^Is_Scx=rjng}', "");
Expect(0, 43360, '\p{Is_Scx=rjng}', "");
Expect(1, 43360, '\p{^Is_Scx=rjng}', "");
Expect(1, 43360, '\P{Is_Scx=rjng}', "");
Expect(0, 43360, '\P{^Is_Scx=rjng}', "");
Expect(1, 43359, '\p{Is_Scx=Rjng}', "");
Expect(0, 43359, '\p{^Is_Scx=Rjng}', "");
Expect(0, 43359, '\P{Is_Scx=Rjng}', "");
Expect(1, 43359, '\P{^Is_Scx=Rjng}', "");
Expect(0, 43360, '\p{Is_Scx=Rjng}', "");
Expect(1, 43360, '\p{^Is_Scx=Rjng}', "");
Expect(1, 43360, '\P{Is_Scx=Rjng}', "");
Expect(0, 43360, '\P{^Is_Scx=Rjng}', "");
Error('\p{Script_Extensions=:=		Runic}');
Error('\P{Script_Extensions=:=		Runic}');
Expect(1, 5872, '\p{Script_Extensions=runic}', "");
Expect(0, 5872, '\p{^Script_Extensions=runic}', "");
Expect(0, 5872, '\P{Script_Extensions=runic}', "");
Expect(1, 5872, '\P{^Script_Extensions=runic}', "");
Expect(0, 5873, '\p{Script_Extensions=runic}', "");
Expect(1, 5873, '\p{^Script_Extensions=runic}', "");
Expect(1, 5873, '\P{Script_Extensions=runic}', "");
Expect(0, 5873, '\P{^Script_Extensions=runic}', "");
Expect(1, 5872, '\p{Script_Extensions=-RUNIC}', "");
Expect(0, 5872, '\p{^Script_Extensions=-RUNIC}', "");
Expect(0, 5872, '\P{Script_Extensions=-RUNIC}', "");
Expect(1, 5872, '\P{^Script_Extensions=-RUNIC}', "");
Expect(0, 5873, '\p{Script_Extensions=-RUNIC}', "");
Expect(1, 5873, '\p{^Script_Extensions=-RUNIC}', "");
Expect(1, 5873, '\P{Script_Extensions=-RUNIC}', "");
Expect(0, 5873, '\P{^Script_Extensions=-RUNIC}', "");
Error('\p{Scx:	-RUNR/a/}');
Error('\P{Scx:	-RUNR/a/}');
Expect(1, 5872, '\p{Scx:	runr}', "");
Expect(0, 5872, '\p{^Scx:	runr}', "");
Expect(0, 5872, '\P{Scx:	runr}', "");
Expect(1, 5872, '\P{^Scx:	runr}', "");
Expect(0, 5873, '\p{Scx:	runr}', "");
Expect(1, 5873, '\p{^Scx:	runr}', "");
Expect(1, 5873, '\P{Scx:	runr}', "");
Expect(0, 5873, '\P{^Scx:	runr}', "");
Expect(1, 5872, '\p{Scx= RUNR}', "");
Expect(0, 5872, '\p{^Scx= RUNR}', "");
Expect(0, 5872, '\P{Scx= RUNR}', "");
Expect(1, 5872, '\P{^Scx= RUNR}', "");
Expect(0, 5873, '\p{Scx= RUNR}', "");
Expect(1, 5873, '\p{^Scx= RUNR}', "");
Expect(1, 5873, '\P{Scx= RUNR}', "");
Expect(0, 5873, '\P{^Scx= RUNR}', "");
Error('\p{Is_Script_Extensions= -Runic/a/}');
Error('\P{Is_Script_Extensions= -Runic/a/}');
Expect(1, 5872, '\p{Is_Script_Extensions=runic}', "");
Expect(0, 5872, '\p{^Is_Script_Extensions=runic}', "");
Expect(0, 5872, '\P{Is_Script_Extensions=runic}', "");
Expect(1, 5872, '\P{^Is_Script_Extensions=runic}', "");
Expect(0, 5873, '\p{Is_Script_Extensions=runic}', "");
Expect(1, 5873, '\p{^Is_Script_Extensions=runic}', "");
Expect(1, 5873, '\P{Is_Script_Extensions=runic}', "");
Expect(0, 5873, '\P{^Is_Script_Extensions=runic}', "");
Expect(1, 5872, '\p{Is_Script_Extensions=--runic}', "");
Expect(0, 5872, '\p{^Is_Script_Extensions=--runic}', "");
Expect(0, 5872, '\P{Is_Script_Extensions=--runic}', "");
Expect(1, 5872, '\P{^Is_Script_Extensions=--runic}', "");
Expect(0, 5873, '\p{Is_Script_Extensions=--runic}', "");
Expect(1, 5873, '\p{^Is_Script_Extensions=--runic}', "");
Expect(1, 5873, '\P{Is_Script_Extensions=--runic}', "");
Expect(0, 5873, '\P{^Is_Script_Extensions=--runic}', "");
Error('\p{Is_Scx=-runr/a/}');
Error('\P{Is_Scx=-runr/a/}');
Expect(1, 5872, '\p{Is_Scx=runr}', "");
Expect(0, 5872, '\p{^Is_Scx=runr}', "");
Expect(0, 5872, '\P{Is_Scx=runr}', "");
Expect(1, 5872, '\P{^Is_Scx=runr}', "");
Expect(0, 5873, '\p{Is_Scx=runr}', "");
Expect(1, 5873, '\p{^Is_Scx=runr}', "");
Expect(1, 5873, '\P{Is_Scx=runr}', "");
Expect(0, 5873, '\P{^Is_Scx=runr}', "");
Expect(1, 5872, '\p{Is_Scx=-	RUNR}', "");
Expect(0, 5872, '\p{^Is_Scx=-	RUNR}', "");
Expect(0, 5872, '\P{Is_Scx=-	RUNR}', "");
Expect(1, 5872, '\P{^Is_Scx=-	RUNR}', "");
Expect(0, 5873, '\p{Is_Scx=-	RUNR}', "");
Expect(1, 5873, '\p{^Is_Scx=-	RUNR}', "");
Expect(1, 5873, '\P{Is_Scx=-	RUNR}', "");
Expect(0, 5873, '\P{^Is_Scx=-	RUNR}', "");
Error('\p{Script_Extensions=:=SAMARITAN}');
Error('\P{Script_Extensions=:=SAMARITAN}');
Expect(1, 2110, '\p{Script_Extensions=samaritan}', "");
Expect(0, 2110, '\p{^Script_Extensions=samaritan}', "");
Expect(0, 2110, '\P{Script_Extensions=samaritan}', "");
Expect(1, 2110, '\P{^Script_Extensions=samaritan}', "");
Expect(0, 2111, '\p{Script_Extensions=samaritan}', "");
Expect(1, 2111, '\p{^Script_Extensions=samaritan}', "");
Expect(1, 2111, '\P{Script_Extensions=samaritan}', "");
Expect(0, 2111, '\P{^Script_Extensions=samaritan}', "");
Expect(1, 2110, '\p{Script_Extensions: 	Samaritan}', "");
Expect(0, 2110, '\p{^Script_Extensions: 	Samaritan}', "");
Expect(0, 2110, '\P{Script_Extensions: 	Samaritan}', "");
Expect(1, 2110, '\P{^Script_Extensions: 	Samaritan}', "");
Expect(0, 2111, '\p{Script_Extensions: 	Samaritan}', "");
Expect(1, 2111, '\p{^Script_Extensions: 	Samaritan}', "");
Expect(1, 2111, '\P{Script_Extensions: 	Samaritan}', "");
Expect(0, 2111, '\P{^Script_Extensions: 	Samaritan}', "");
Error('\p{Scx= -SAMR:=}');
Error('\P{Scx= -SAMR:=}');
Expect(1, 2110, '\p{Scx=samr}', "");
Expect(0, 2110, '\p{^Scx=samr}', "");
Expect(0, 2110, '\P{Scx=samr}', "");
Expect(1, 2110, '\P{^Scx=samr}', "");
Expect(0, 2111, '\p{Scx=samr}', "");
Expect(1, 2111, '\p{^Scx=samr}', "");
Expect(1, 2111, '\P{Scx=samr}', "");
Expect(0, 2111, '\P{^Scx=samr}', "");
Expect(1, 2110, '\p{Scx=_Samr}', "");
Expect(0, 2110, '\p{^Scx=_Samr}', "");
Expect(0, 2110, '\P{Scx=_Samr}', "");
Expect(1, 2110, '\P{^Scx=_Samr}', "");
Expect(0, 2111, '\p{Scx=_Samr}', "");
Expect(1, 2111, '\p{^Scx=_Samr}', "");
Expect(1, 2111, '\P{Scx=_Samr}', "");
Expect(0, 2111, '\P{^Scx=_Samr}', "");
Error('\p{Is_Script_Extensions=__Samaritan:=}');
Error('\P{Is_Script_Extensions=__Samaritan:=}');
Expect(1, 2110, '\p{Is_Script_Extensions=samaritan}', "");
Expect(0, 2110, '\p{^Is_Script_Extensions=samaritan}', "");
Expect(0, 2110, '\P{Is_Script_Extensions=samaritan}', "");
Expect(1, 2110, '\P{^Is_Script_Extensions=samaritan}', "");
Expect(0, 2111, '\p{Is_Script_Extensions=samaritan}', "");
Expect(1, 2111, '\p{^Is_Script_Extensions=samaritan}', "");
Expect(1, 2111, '\P{Is_Script_Extensions=samaritan}', "");
Expect(0, 2111, '\P{^Is_Script_Extensions=samaritan}', "");
Expect(1, 2110, '\p{Is_Script_Extensions=  Samaritan}', "");
Expect(0, 2110, '\p{^Is_Script_Extensions=  Samaritan}', "");
Expect(0, 2110, '\P{Is_Script_Extensions=  Samaritan}', "");
Expect(1, 2110, '\P{^Is_Script_Extensions=  Samaritan}', "");
Expect(0, 2111, '\p{Is_Script_Extensions=  Samaritan}', "");
Expect(1, 2111, '\p{^Is_Script_Extensions=  Samaritan}', "");
Expect(1, 2111, '\P{Is_Script_Extensions=  Samaritan}', "");
Expect(0, 2111, '\P{^Is_Script_Extensions=  Samaritan}', "");
Error('\p{Is_Scx=:= _Samr}');
Error('\P{Is_Scx=:= _Samr}');
Expect(1, 2110, '\p{Is_Scx=samr}', "");
Expect(0, 2110, '\p{^Is_Scx=samr}', "");
Expect(0, 2110, '\P{Is_Scx=samr}', "");
Expect(1, 2110, '\P{^Is_Scx=samr}', "");
Expect(0, 2111, '\p{Is_Scx=samr}', "");
Expect(1, 2111, '\p{^Is_Scx=samr}', "");
Expect(1, 2111, '\P{Is_Scx=samr}', "");
Expect(0, 2111, '\P{^Is_Scx=samr}', "");
Expect(1, 2110, '\p{Is_Scx=	_Samr}', "");
Expect(0, 2110, '\p{^Is_Scx=	_Samr}', "");
Expect(0, 2110, '\P{Is_Scx=	_Samr}', "");
Expect(1, 2110, '\P{^Is_Scx=	_Samr}', "");
Expect(0, 2111, '\p{Is_Scx=	_Samr}', "");
Expect(1, 2111, '\p{^Is_Scx=	_Samr}', "");
Expect(1, 2111, '\P{Is_Scx=	_Samr}', "");
Expect(0, 2111, '\P{^Is_Scx=	_Samr}', "");
Error('\p{Script_Extensions:   		old_South_Arabian:=}');
Error('\P{Script_Extensions:   		old_South_Arabian:=}');
Expect(1, 68223, '\p{Script_Extensions=oldsoutharabian}', "");
Expect(0, 68223, '\p{^Script_Extensions=oldsoutharabian}', "");
Expect(0, 68223, '\P{Script_Extensions=oldsoutharabian}', "");
Expect(1, 68223, '\P{^Script_Extensions=oldsoutharabian}', "");
Expect(0, 68224, '\p{Script_Extensions=oldsoutharabian}', "");
Expect(1, 68224, '\p{^Script_Extensions=oldsoutharabian}', "");
Expect(1, 68224, '\P{Script_Extensions=oldsoutharabian}', "");
Expect(0, 68224, '\P{^Script_Extensions=oldsoutharabian}', "");
Expect(1, 68223, '\p{Script_Extensions=_-Old_SOUTH_Arabian}', "");
Expect(0, 68223, '\p{^Script_Extensions=_-Old_SOUTH_Arabian}', "");
Expect(0, 68223, '\P{Script_Extensions=_-Old_SOUTH_Arabian}', "");
Expect(1, 68223, '\P{^Script_Extensions=_-Old_SOUTH_Arabian}', "");
Expect(0, 68224, '\p{Script_Extensions=_-Old_SOUTH_Arabian}', "");
Expect(1, 68224, '\p{^Script_Extensions=_-Old_SOUTH_Arabian}', "");
Expect(1, 68224, '\P{Script_Extensions=_-Old_SOUTH_Arabian}', "");
Expect(0, 68224, '\P{^Script_Extensions=_-Old_SOUTH_Arabian}', "");
Error('\p{Scx=/a/ SARB}');
Error('\P{Scx=/a/ SARB}');
Expect(1, 68223, '\p{Scx=sarb}', "");
Expect(0, 68223, '\p{^Scx=sarb}', "");
Expect(0, 68223, '\P{Scx=sarb}', "");
Expect(1, 68223, '\P{^Scx=sarb}', "");
Expect(0, 68224, '\p{Scx=sarb}', "");
Expect(1, 68224, '\p{^Scx=sarb}', "");
Expect(1, 68224, '\P{Scx=sarb}', "");
Expect(0, 68224, '\P{^Scx=sarb}', "");
Expect(1, 68223, '\p{Scx=-SARB}', "");
Expect(0, 68223, '\p{^Scx=-SARB}', "");
Expect(0, 68223, '\P{Scx=-SARB}', "");
Expect(1, 68223, '\P{^Scx=-SARB}', "");
Expect(0, 68224, '\p{Scx=-SARB}', "");
Expect(1, 68224, '\p{^Scx=-SARB}', "");
Expect(1, 68224, '\P{Scx=-SARB}', "");
Expect(0, 68224, '\P{^Scx=-SARB}', "");
Error('\p{Is_Script_Extensions=/a/-old_South_Arabian}');
Error('\P{Is_Script_Extensions=/a/-old_South_Arabian}');
Expect(1, 68223, '\p{Is_Script_Extensions=oldsoutharabian}', "");
Expect(0, 68223, '\p{^Is_Script_Extensions=oldsoutharabian}', "");
Expect(0, 68223, '\P{Is_Script_Extensions=oldsoutharabian}', "");
Expect(1, 68223, '\P{^Is_Script_Extensions=oldsoutharabian}', "");
Expect(0, 68224, '\p{Is_Script_Extensions=oldsoutharabian}', "");
Expect(1, 68224, '\p{^Is_Script_Extensions=oldsoutharabian}', "");
Expect(1, 68224, '\P{Is_Script_Extensions=oldsoutharabian}', "");
Expect(0, 68224, '\P{^Is_Script_Extensions=oldsoutharabian}', "");
Expect(1, 68223, '\p{Is_Script_Extensions= old_SOUTH_ARABIAN}', "");
Expect(0, 68223, '\p{^Is_Script_Extensions= old_SOUTH_ARABIAN}', "");
Expect(0, 68223, '\P{Is_Script_Extensions= old_SOUTH_ARABIAN}', "");
Expect(1, 68223, '\P{^Is_Script_Extensions= old_SOUTH_ARABIAN}', "");
Expect(0, 68224, '\p{Is_Script_Extensions= old_SOUTH_ARABIAN}', "");
Expect(1, 68224, '\p{^Is_Script_Extensions= old_SOUTH_ARABIAN}', "");
Expect(1, 68224, '\P{Is_Script_Extensions= old_SOUTH_ARABIAN}', "");
Expect(0, 68224, '\P{^Is_Script_Extensions= old_SOUTH_ARABIAN}', "");
Error('\p{Is_Scx=-	SARB:=}');
Error('\P{Is_Scx=-	SARB:=}');
Expect(1, 68223, '\p{Is_Scx=sarb}', "");
Expect(0, 68223, '\p{^Is_Scx=sarb}', "");
Expect(0, 68223, '\P{Is_Scx=sarb}', "");
Expect(1, 68223, '\P{^Is_Scx=sarb}', "");
Expect(0, 68224, '\p{Is_Scx=sarb}', "");
Expect(1, 68224, '\p{^Is_Scx=sarb}', "");
Expect(1, 68224, '\P{Is_Scx=sarb}', "");
Expect(0, 68224, '\P{^Is_Scx=sarb}', "");
Expect(1, 68223, '\p{Is_Scx= sarb}', "");
Expect(0, 68223, '\p{^Is_Scx= sarb}', "");
Expect(0, 68223, '\P{Is_Scx= sarb}', "");
Expect(1, 68223, '\P{^Is_Scx= sarb}', "");
Expect(0, 68224, '\p{Is_Scx= sarb}', "");
Expect(1, 68224, '\p{^Is_Scx= sarb}', "");
Expect(1, 68224, '\P{Is_Scx= sarb}', "");
Expect(0, 68224, '\P{^Is_Scx= sarb}', "");
Error('\p{Script_Extensions=/a/SAURASHTRA}');
Error('\P{Script_Extensions=/a/SAURASHTRA}');
Expect(1, 43225, '\p{Script_Extensions=saurashtra}', "");
Expect(0, 43225, '\p{^Script_Extensions=saurashtra}', "");
Expect(0, 43225, '\P{Script_Extensions=saurashtra}', "");
Expect(1, 43225, '\P{^Script_Extensions=saurashtra}', "");
Expect(0, 43226, '\p{Script_Extensions=saurashtra}', "");
Expect(1, 43226, '\p{^Script_Extensions=saurashtra}', "");
Expect(1, 43226, '\P{Script_Extensions=saurashtra}', "");
Expect(0, 43226, '\P{^Script_Extensions=saurashtra}', "");
Expect(1, 43225, '\p{Script_Extensions=-	saurashtra}', "");
Expect(0, 43225, '\p{^Script_Extensions=-	saurashtra}', "");
Expect(0, 43225, '\P{Script_Extensions=-	saurashtra}', "");
Expect(1, 43225, '\P{^Script_Extensions=-	saurashtra}', "");
Expect(0, 43226, '\p{Script_Extensions=-	saurashtra}', "");
Expect(1, 43226, '\p{^Script_Extensions=-	saurashtra}', "");
Expect(1, 43226, '\P{Script_Extensions=-	saurashtra}', "");
Expect(0, 43226, '\P{^Script_Extensions=-	saurashtra}', "");
Error('\p{Scx=SAUR:=}');
Error('\P{Scx=SAUR:=}');
Expect(1, 43225, '\p{Scx=saur}', "");
Expect(0, 43225, '\p{^Scx=saur}', "");
Expect(0, 43225, '\P{Scx=saur}', "");
Expect(1, 43225, '\P{^Scx=saur}', "");
Expect(0, 43226, '\p{Scx=saur}', "");
Expect(1, 43226, '\p{^Scx=saur}', "");
Expect(1, 43226, '\P{Scx=saur}', "");
Expect(0, 43226, '\P{^Scx=saur}', "");
Expect(1, 43225, '\p{Scx=-	saur}', "");
Expect(0, 43225, '\p{^Scx=-	saur}', "");
Expect(0, 43225, '\P{Scx=-	saur}', "");
Expect(1, 43225, '\P{^Scx=-	saur}', "");
Expect(0, 43226, '\p{Scx=-	saur}', "");
Expect(1, 43226, '\p{^Scx=-	saur}', "");
Expect(1, 43226, '\P{Scx=-	saur}', "");
Expect(0, 43226, '\P{^Scx=-	saur}', "");
Error('\p{Is_Script_Extensions=-SAURASHTRA/a/}');
Error('\P{Is_Script_Extensions=-SAURASHTRA/a/}');
Expect(1, 43225, '\p{Is_Script_Extensions=saurashtra}', "");
Expect(0, 43225, '\p{^Is_Script_Extensions=saurashtra}', "");
Expect(0, 43225, '\P{Is_Script_Extensions=saurashtra}', "");
Expect(1, 43225, '\P{^Is_Script_Extensions=saurashtra}', "");
Expect(0, 43226, '\p{Is_Script_Extensions=saurashtra}', "");
Expect(1, 43226, '\p{^Is_Script_Extensions=saurashtra}', "");
Expect(1, 43226, '\P{Is_Script_Extensions=saurashtra}', "");
Expect(0, 43226, '\P{^Is_Script_Extensions=saurashtra}', "");
Expect(1, 43225, '\p{Is_Script_Extensions=_	Saurashtra}', "");
Expect(0, 43225, '\p{^Is_Script_Extensions=_	Saurashtra}', "");
Expect(0, 43225, '\P{Is_Script_Extensions=_	Saurashtra}', "");
Expect(1, 43225, '\P{^Is_Script_Extensions=_	Saurashtra}', "");
Expect(0, 43226, '\p{Is_Script_Extensions=_	Saurashtra}', "");
Expect(1, 43226, '\p{^Is_Script_Extensions=_	Saurashtra}', "");
Expect(1, 43226, '\P{Is_Script_Extensions=_	Saurashtra}', "");
Expect(0, 43226, '\P{^Is_Script_Extensions=_	Saurashtra}', "");
Error('\p{Is_Scx=_:=Saur}');
Error('\P{Is_Scx=_:=Saur}');
Expect(1, 43225, '\p{Is_Scx=saur}', "");
Expect(0, 43225, '\p{^Is_Scx=saur}', "");
Expect(0, 43225, '\P{Is_Scx=saur}', "");
Expect(1, 43225, '\P{^Is_Scx=saur}', "");
Expect(0, 43226, '\p{Is_Scx=saur}', "");
Expect(1, 43226, '\p{^Is_Scx=saur}', "");
Expect(1, 43226, '\P{Is_Scx=saur}', "");
Expect(0, 43226, '\P{^Is_Scx=saur}', "");
Expect(1, 43225, '\p{Is_Scx=	Saur}', "");
Expect(0, 43225, '\p{^Is_Scx=	Saur}', "");
Expect(0, 43225, '\P{Is_Scx=	Saur}', "");
Expect(1, 43225, '\P{^Is_Scx=	Saur}', "");
Expect(0, 43226, '\p{Is_Scx=	Saur}', "");
Expect(1, 43226, '\p{^Is_Scx=	Saur}', "");
Expect(1, 43226, '\P{Is_Scx=	Saur}', "");
Expect(0, 43226, '\P{^Is_Scx=	Saur}', "");
Error('\p{Script_Extensions=:=_shavian}');
Error('\P{Script_Extensions=:=_shavian}');
Expect(1, 66687, '\p{Script_Extensions=shavian}', "");
Expect(0, 66687, '\p{^Script_Extensions=shavian}', "");
Expect(0, 66687, '\P{Script_Extensions=shavian}', "");
Expect(1, 66687, '\P{^Script_Extensions=shavian}', "");
Expect(0, 66688, '\p{Script_Extensions=shavian}', "");
Expect(1, 66688, '\p{^Script_Extensions=shavian}', "");
Expect(1, 66688, '\P{Script_Extensions=shavian}', "");
Expect(0, 66688, '\P{^Script_Extensions=shavian}', "");
Expect(1, 66687, '\p{Script_Extensions=_Shavian}', "");
Expect(0, 66687, '\p{^Script_Extensions=_Shavian}', "");
Expect(0, 66687, '\P{Script_Extensions=_Shavian}', "");
Expect(1, 66687, '\P{^Script_Extensions=_Shavian}', "");
Expect(0, 66688, '\p{Script_Extensions=_Shavian}', "");
Expect(1, 66688, '\p{^Script_Extensions=_Shavian}', "");
Expect(1, 66688, '\P{Script_Extensions=_Shavian}', "");
Expect(0, 66688, '\P{^Script_Extensions=_Shavian}', "");
Error('\p{Scx=	/a/Shaw}');
Error('\P{Scx=	/a/Shaw}');
Expect(1, 66687, '\p{Scx=shaw}', "");
Expect(0, 66687, '\p{^Scx=shaw}', "");
Expect(0, 66687, '\P{Scx=shaw}', "");
Expect(1, 66687, '\P{^Scx=shaw}', "");
Expect(0, 66688, '\p{Scx=shaw}', "");
Expect(1, 66688, '\p{^Scx=shaw}', "");
Expect(1, 66688, '\P{Scx=shaw}', "");
Expect(0, 66688, '\P{^Scx=shaw}', "");
Expect(1, 66687, '\p{Scx:-shaw}', "");
Expect(0, 66687, '\p{^Scx:-shaw}', "");
Expect(0, 66687, '\P{Scx:-shaw}', "");
Expect(1, 66687, '\P{^Scx:-shaw}', "");
Expect(0, 66688, '\p{Scx:-shaw}', "");
Expect(1, 66688, '\p{^Scx:-shaw}', "");
Expect(1, 66688, '\P{Scx:-shaw}', "");
Expect(0, 66688, '\P{^Scx:-shaw}', "");
Error('\p{Is_Script_Extensions:   __SHAVIAN/a/}');
Error('\P{Is_Script_Extensions:   __SHAVIAN/a/}');
Expect(1, 66687, '\p{Is_Script_Extensions=shavian}', "");
Expect(0, 66687, '\p{^Is_Script_Extensions=shavian}', "");
Expect(0, 66687, '\P{Is_Script_Extensions=shavian}', "");
Expect(1, 66687, '\P{^Is_Script_Extensions=shavian}', "");
Expect(0, 66688, '\p{Is_Script_Extensions=shavian}', "");
Expect(1, 66688, '\p{^Is_Script_Extensions=shavian}', "");
Expect(1, 66688, '\P{Is_Script_Extensions=shavian}', "");
Expect(0, 66688, '\P{^Is_Script_Extensions=shavian}', "");
Expect(1, 66687, '\p{Is_Script_Extensions=  Shavian}', "");
Expect(0, 66687, '\p{^Is_Script_Extensions=  Shavian}', "");
Expect(0, 66687, '\P{Is_Script_Extensions=  Shavian}', "");
Expect(1, 66687, '\P{^Is_Script_Extensions=  Shavian}', "");
Expect(0, 66688, '\p{Is_Script_Extensions=  Shavian}', "");
Expect(1, 66688, '\p{^Is_Script_Extensions=  Shavian}', "");
Expect(1, 66688, '\P{Is_Script_Extensions=  Shavian}', "");
Expect(0, 66688, '\P{^Is_Script_Extensions=  Shavian}', "");
Error('\p{Is_Scx=/a/		Shaw}');
Error('\P{Is_Scx=/a/		Shaw}');
Expect(1, 66687, '\p{Is_Scx=shaw}', "");
Expect(0, 66687, '\p{^Is_Scx=shaw}', "");
Expect(0, 66687, '\P{Is_Scx=shaw}', "");
Expect(1, 66687, '\P{^Is_Scx=shaw}', "");
Expect(0, 66688, '\p{Is_Scx=shaw}', "");
Expect(1, 66688, '\p{^Is_Scx=shaw}', "");
Expect(1, 66688, '\P{Is_Scx=shaw}', "");
Expect(0, 66688, '\P{^Is_Scx=shaw}', "");
Expect(1, 66687, '\p{Is_Scx=	 Shaw}', "");
Expect(0, 66687, '\p{^Is_Scx=	 Shaw}', "");
Expect(0, 66687, '\P{Is_Scx=	 Shaw}', "");
Expect(1, 66687, '\P{^Is_Scx=	 Shaw}', "");
Expect(0, 66688, '\p{Is_Scx=	 Shaw}', "");
Expect(1, 66688, '\p{^Is_Scx=	 Shaw}', "");
Expect(1, 66688, '\P{Is_Scx=	 Shaw}', "");
Expect(0, 66688, '\P{^Is_Scx=	 Shaw}', "");
Error('\p{Script_Extensions=:=_	sharada}');
Error('\P{Script_Extensions=:=_	sharada}');
Expect(1, 70105, '\p{Script_Extensions=sharada}', "");
Expect(0, 70105, '\p{^Script_Extensions=sharada}', "");
Expect(0, 70105, '\P{Script_Extensions=sharada}', "");
Expect(1, 70105, '\P{^Script_Extensions=sharada}', "");
Expect(0, 70106, '\p{Script_Extensions=sharada}', "");
Expect(1, 70106, '\p{^Script_Extensions=sharada}', "");
Expect(1, 70106, '\P{Script_Extensions=sharada}', "");
Expect(0, 70106, '\P{^Script_Extensions=sharada}', "");
Expect(1, 70105, '\p{Script_Extensions=	Sharada}', "");
Expect(0, 70105, '\p{^Script_Extensions=	Sharada}', "");
Expect(0, 70105, '\P{Script_Extensions=	Sharada}', "");
Expect(1, 70105, '\P{^Script_Extensions=	Sharada}', "");
Expect(0, 70106, '\p{Script_Extensions=	Sharada}', "");
Expect(1, 70106, '\p{^Script_Extensions=	Sharada}', "");
Expect(1, 70106, '\P{Script_Extensions=	Sharada}', "");
Expect(0, 70106, '\P{^Script_Extensions=	Sharada}', "");
Error('\p{Scx=:=	 SHRD}');
Error('\P{Scx=:=	 SHRD}');
Expect(1, 70105, '\p{Scx=shrd}', "");
Expect(0, 70105, '\p{^Scx=shrd}', "");
Expect(0, 70105, '\P{Scx=shrd}', "");
Expect(1, 70105, '\P{^Scx=shrd}', "");
Expect(0, 70106, '\p{Scx=shrd}', "");
Expect(1, 70106, '\p{^Scx=shrd}', "");
Expect(1, 70106, '\P{Scx=shrd}', "");
Expect(0, 70106, '\P{^Scx=shrd}', "");
Expect(1, 70105, '\p{Scx=__Shrd}', "");
Expect(0, 70105, '\p{^Scx=__Shrd}', "");
Expect(0, 70105, '\P{Scx=__Shrd}', "");
Expect(1, 70105, '\P{^Scx=__Shrd}', "");
Expect(0, 70106, '\p{Scx=__Shrd}', "");
Expect(1, 70106, '\p{^Scx=__Shrd}', "");
Expect(1, 70106, '\P{Scx=__Shrd}', "");
Expect(0, 70106, '\P{^Scx=__Shrd}', "");
Error('\p{Is_Script_Extensions=/a/	sharada}');
Error('\P{Is_Script_Extensions=/a/	sharada}');
Expect(1, 70105, '\p{Is_Script_Extensions=sharada}', "");
Expect(0, 70105, '\p{^Is_Script_Extensions=sharada}', "");
Expect(0, 70105, '\P{Is_Script_Extensions=sharada}', "");
Expect(1, 70105, '\P{^Is_Script_Extensions=sharada}', "");
Expect(0, 70106, '\p{Is_Script_Extensions=sharada}', "");
Expect(1, 70106, '\p{^Is_Script_Extensions=sharada}', "");
Expect(1, 70106, '\P{Is_Script_Extensions=sharada}', "");
Expect(0, 70106, '\P{^Is_Script_Extensions=sharada}', "");
Expect(1, 70105, '\p{Is_Script_Extensions=  sharada}', "");
Expect(0, 70105, '\p{^Is_Script_Extensions=  sharada}', "");
Expect(0, 70105, '\P{Is_Script_Extensions=  sharada}', "");
Expect(1, 70105, '\P{^Is_Script_Extensions=  sharada}', "");
Expect(0, 70106, '\p{Is_Script_Extensions=  sharada}', "");
Expect(1, 70106, '\p{^Is_Script_Extensions=  sharada}', "");
Expect(1, 70106, '\P{Is_Script_Extensions=  sharada}', "");
Expect(0, 70106, '\P{^Is_Script_Extensions=  sharada}', "");
Error('\p{Is_Scx=	:=shrd}');
Error('\P{Is_Scx=	:=shrd}');
Expect(1, 70105, '\p{Is_Scx=shrd}', "");
Expect(0, 70105, '\p{^Is_Scx=shrd}', "");
Expect(0, 70105, '\P{Is_Scx=shrd}', "");
Expect(1, 70105, '\P{^Is_Scx=shrd}', "");
Expect(0, 70106, '\p{Is_Scx=shrd}', "");
Expect(1, 70106, '\p{^Is_Scx=shrd}', "");
Expect(1, 70106, '\P{Is_Scx=shrd}', "");
Expect(0, 70106, '\P{^Is_Scx=shrd}', "");
Expect(1, 70105, '\p{Is_Scx=-shrd}', "");
Expect(0, 70105, '\p{^Is_Scx=-shrd}', "");
Expect(0, 70105, '\P{Is_Scx=-shrd}', "");
Expect(1, 70105, '\P{^Is_Scx=-shrd}', "");
Expect(0, 70106, '\p{Is_Scx=-shrd}', "");
Expect(1, 70106, '\p{^Is_Scx=-shrd}', "");
Expect(1, 70106, '\P{Is_Scx=-shrd}', "");
Expect(0, 70106, '\P{^Is_Scx=-shrd}', "");
Error('\p{Script_Extensions=/a/sinhala}');
Error('\P{Script_Extensions=/a/sinhala}');
Expect(1, 3572, '\p{Script_Extensions=sinhala}', "");
Expect(0, 3572, '\p{^Script_Extensions=sinhala}', "");
Expect(0, 3572, '\P{Script_Extensions=sinhala}', "");
Expect(1, 3572, '\P{^Script_Extensions=sinhala}', "");
Expect(0, 3573, '\p{Script_Extensions=sinhala}', "");
Expect(1, 3573, '\p{^Script_Extensions=sinhala}', "");
Expect(1, 3573, '\P{Script_Extensions=sinhala}', "");
Expect(0, 3573, '\P{^Script_Extensions=sinhala}', "");
Expect(1, 3572, '\p{Script_Extensions=_Sinhala}', "");
Expect(0, 3572, '\p{^Script_Extensions=_Sinhala}', "");
Expect(0, 3572, '\P{Script_Extensions=_Sinhala}', "");
Expect(1, 3572, '\P{^Script_Extensions=_Sinhala}', "");
Expect(0, 3573, '\p{Script_Extensions=_Sinhala}', "");
Expect(1, 3573, '\p{^Script_Extensions=_Sinhala}', "");
Expect(1, 3573, '\P{Script_Extensions=_Sinhala}', "");
Expect(0, 3573, '\P{^Script_Extensions=_Sinhala}', "");
Error('\p{Scx:	_ SINH/a/}');
Error('\P{Scx:	_ SINH/a/}');
Expect(1, 3572, '\p{Scx=sinh}', "");
Expect(0, 3572, '\p{^Scx=sinh}', "");
Expect(0, 3572, '\P{Scx=sinh}', "");
Expect(1, 3572, '\P{^Scx=sinh}', "");
Expect(0, 3573, '\p{Scx=sinh}', "");
Expect(1, 3573, '\p{^Scx=sinh}', "");
Expect(1, 3573, '\P{Scx=sinh}', "");
Expect(0, 3573, '\P{^Scx=sinh}', "");
Expect(1, 3572, '\p{Scx=Sinh}', "");
Expect(0, 3572, '\p{^Scx=Sinh}', "");
Expect(0, 3572, '\P{Scx=Sinh}', "");
Expect(1, 3572, '\P{^Scx=Sinh}', "");
Expect(0, 3573, '\p{Scx=Sinh}', "");
Expect(1, 3573, '\p{^Scx=Sinh}', "");
Expect(1, 3573, '\P{Scx=Sinh}', "");
Expect(0, 3573, '\P{^Scx=Sinh}', "");
Error('\p{Is_Script_Extensions=:=-Sinhala}');
Error('\P{Is_Script_Extensions=:=-Sinhala}');
Expect(1, 3572, '\p{Is_Script_Extensions=sinhala}', "");
Expect(0, 3572, '\p{^Is_Script_Extensions=sinhala}', "");
Expect(0, 3572, '\P{Is_Script_Extensions=sinhala}', "");
Expect(1, 3572, '\P{^Is_Script_Extensions=sinhala}', "");
Expect(0, 3573, '\p{Is_Script_Extensions=sinhala}', "");
Expect(1, 3573, '\p{^Is_Script_Extensions=sinhala}', "");
Expect(1, 3573, '\P{Is_Script_Extensions=sinhala}', "");
Expect(0, 3573, '\P{^Is_Script_Extensions=sinhala}', "");
Expect(1, 3572, '\p{Is_Script_Extensions=-Sinhala}', "");
Expect(0, 3572, '\p{^Is_Script_Extensions=-Sinhala}', "");
Expect(0, 3572, '\P{Is_Script_Extensions=-Sinhala}', "");
Expect(1, 3572, '\P{^Is_Script_Extensions=-Sinhala}', "");
Expect(0, 3573, '\p{Is_Script_Extensions=-Sinhala}', "");
Expect(1, 3573, '\p{^Is_Script_Extensions=-Sinhala}', "");
Expect(1, 3573, '\P{Is_Script_Extensions=-Sinhala}', "");
Expect(0, 3573, '\P{^Is_Script_Extensions=-Sinhala}', "");
Error('\p{Is_Scx=:=	Sinh}');
Error('\P{Is_Scx=:=	Sinh}');
Expect(1, 3572, '\p{Is_Scx=sinh}', "");
Expect(0, 3572, '\p{^Is_Scx=sinh}', "");
Expect(0, 3572, '\P{Is_Scx=sinh}', "");
Expect(1, 3572, '\P{^Is_Scx=sinh}', "");
Expect(0, 3573, '\p{Is_Scx=sinh}', "");
Expect(1, 3573, '\p{^Is_Scx=sinh}', "");
Expect(1, 3573, '\P{Is_Scx=sinh}', "");
Expect(0, 3573, '\P{^Is_Scx=sinh}', "");
Expect(1, 3572, '\p{Is_Scx=_SINH}', "");
Expect(0, 3572, '\p{^Is_Scx=_SINH}', "");
Expect(0, 3572, '\P{Is_Scx=_SINH}', "");
Expect(1, 3572, '\P{^Is_Scx=_SINH}', "");
Expect(0, 3573, '\p{Is_Scx=_SINH}', "");
Expect(1, 3573, '\p{^Is_Scx=_SINH}', "");
Expect(1, 3573, '\P{Is_Scx=_SINH}', "");
Expect(0, 3573, '\P{^Is_Scx=_SINH}', "");
Error('\p{Script_Extensions= :=sora_sompeng}');
Error('\P{Script_Extensions= :=sora_sompeng}');
Expect(1, 69881, '\p{Script_Extensions=sorasompeng}', "");
Expect(0, 69881, '\p{^Script_Extensions=sorasompeng}', "");
Expect(0, 69881, '\P{Script_Extensions=sorasompeng}', "");
Expect(1, 69881, '\P{^Script_Extensions=sorasompeng}', "");
Expect(0, 69882, '\p{Script_Extensions=sorasompeng}', "");
Expect(1, 69882, '\p{^Script_Extensions=sorasompeng}', "");
Expect(1, 69882, '\P{Script_Extensions=sorasompeng}', "");
Expect(0, 69882, '\P{^Script_Extensions=sorasompeng}', "");
Expect(1, 69881, '\p{Script_Extensions=	_sora_Sompeng}', "");
Expect(0, 69881, '\p{^Script_Extensions=	_sora_Sompeng}', "");
Expect(0, 69881, '\P{Script_Extensions=	_sora_Sompeng}', "");
Expect(1, 69881, '\P{^Script_Extensions=	_sora_Sompeng}', "");
Expect(0, 69882, '\p{Script_Extensions=	_sora_Sompeng}', "");
Expect(1, 69882, '\p{^Script_Extensions=	_sora_Sompeng}', "");
Expect(1, 69882, '\P{Script_Extensions=	_sora_Sompeng}', "");
Expect(0, 69882, '\P{^Script_Extensions=	_sora_Sompeng}', "");
Error('\p{Scx::=__SORA}');
Error('\P{Scx::=__SORA}');
Expect(1, 69881, '\p{Scx=sora}', "");
Expect(0, 69881, '\p{^Scx=sora}', "");
Expect(0, 69881, '\P{Scx=sora}', "");
Expect(1, 69881, '\P{^Scx=sora}', "");
Expect(0, 69882, '\p{Scx=sora}', "");
Expect(1, 69882, '\p{^Scx=sora}', "");
Expect(1, 69882, '\P{Scx=sora}', "");
Expect(0, 69882, '\P{^Scx=sora}', "");
Expect(1, 69881, '\p{Scx= sora}', "");
Expect(0, 69881, '\p{^Scx= sora}', "");
Expect(0, 69881, '\P{Scx= sora}', "");
Expect(1, 69881, '\P{^Scx= sora}', "");
Expect(0, 69882, '\p{Scx= sora}', "");
Expect(1, 69882, '\p{^Scx= sora}', "");
Expect(1, 69882, '\P{Scx= sora}', "");
Expect(0, 69882, '\P{^Scx= sora}', "");
Error('\p{Is_Script_Extensions:	/a/Sora_Sompeng}');
Error('\P{Is_Script_Extensions:	/a/Sora_Sompeng}');
Expect(1, 69881, '\p{Is_Script_Extensions=sorasompeng}', "");
Expect(0, 69881, '\p{^Is_Script_Extensions=sorasompeng}', "");
Expect(0, 69881, '\P{Is_Script_Extensions=sorasompeng}', "");
Expect(1, 69881, '\P{^Is_Script_Extensions=sorasompeng}', "");
Expect(0, 69882, '\p{Is_Script_Extensions=sorasompeng}', "");
Expect(1, 69882, '\p{^Is_Script_Extensions=sorasompeng}', "");
Expect(1, 69882, '\P{Is_Script_Extensions=sorasompeng}', "");
Expect(0, 69882, '\P{^Is_Script_Extensions=sorasompeng}', "");
Expect(1, 69881, '\p{Is_Script_Extensions=_	sora_SOMPENG}', "");
Expect(0, 69881, '\p{^Is_Script_Extensions=_	sora_SOMPENG}', "");
Expect(0, 69881, '\P{Is_Script_Extensions=_	sora_SOMPENG}', "");
Expect(1, 69881, '\P{^Is_Script_Extensions=_	sora_SOMPENG}', "");
Expect(0, 69882, '\p{Is_Script_Extensions=_	sora_SOMPENG}', "");
Expect(1, 69882, '\p{^Is_Script_Extensions=_	sora_SOMPENG}', "");
Expect(1, 69882, '\P{Is_Script_Extensions=_	sora_SOMPENG}', "");
Expect(0, 69882, '\P{^Is_Script_Extensions=_	sora_SOMPENG}', "");
Error('\p{Is_Scx=- Sora:=}');
Error('\P{Is_Scx=- Sora:=}');
Expect(1, 69881, '\p{Is_Scx=sora}', "");
Expect(0, 69881, '\p{^Is_Scx=sora}', "");
Expect(0, 69881, '\P{Is_Scx=sora}', "");
Expect(1, 69881, '\P{^Is_Scx=sora}', "");
Expect(0, 69882, '\p{Is_Scx=sora}', "");
Expect(1, 69882, '\p{^Is_Scx=sora}', "");
Expect(1, 69882, '\P{Is_Scx=sora}', "");
Expect(0, 69882, '\P{^Is_Scx=sora}', "");
Expect(1, 69881, '\p{Is_Scx=Sora}', "");
Expect(0, 69881, '\p{^Is_Scx=Sora}', "");
Expect(0, 69881, '\P{Is_Scx=Sora}', "");
Expect(1, 69881, '\P{^Is_Scx=Sora}', "");
Expect(0, 69882, '\p{Is_Scx=Sora}', "");
Expect(1, 69882, '\p{^Is_Scx=Sora}', "");
Expect(1, 69882, '\P{Is_Scx=Sora}', "");
Expect(0, 69882, '\P{^Is_Scx=Sora}', "");
Error('\p{Script_Extensions=	/a/SUNDANESE}');
Error('\P{Script_Extensions=	/a/SUNDANESE}');
Expect(1, 7367, '\p{Script_Extensions=sundanese}', "");
Expect(0, 7367, '\p{^Script_Extensions=sundanese}', "");
Expect(0, 7367, '\P{Script_Extensions=sundanese}', "");
Expect(1, 7367, '\P{^Script_Extensions=sundanese}', "");
Expect(0, 7368, '\p{Script_Extensions=sundanese}', "");
Expect(1, 7368, '\p{^Script_Extensions=sundanese}', "");
Expect(1, 7368, '\P{Script_Extensions=sundanese}', "");
Expect(0, 7368, '\P{^Script_Extensions=sundanese}', "");
Expect(1, 7367, '\p{Script_Extensions=	 SUNDANESE}', "");
Expect(0, 7367, '\p{^Script_Extensions=	 SUNDANESE}', "");
Expect(0, 7367, '\P{Script_Extensions=	 SUNDANESE}', "");
Expect(1, 7367, '\P{^Script_Extensions=	 SUNDANESE}', "");
Expect(0, 7368, '\p{Script_Extensions=	 SUNDANESE}', "");
Expect(1, 7368, '\p{^Script_Extensions=	 SUNDANESE}', "");
Expect(1, 7368, '\P{Script_Extensions=	 SUNDANESE}', "");
Expect(0, 7368, '\P{^Script_Extensions=	 SUNDANESE}', "");
Error('\p{Scx=	-Sund/a/}');
Error('\P{Scx=	-Sund/a/}');
Expect(1, 7367, '\p{Scx=sund}', "");
Expect(0, 7367, '\p{^Scx=sund}', "");
Expect(0, 7367, '\P{Scx=sund}', "");
Expect(1, 7367, '\P{^Scx=sund}', "");
Expect(0, 7368, '\p{Scx=sund}', "");
Expect(1, 7368, '\p{^Scx=sund}', "");
Expect(1, 7368, '\P{Scx=sund}', "");
Expect(0, 7368, '\P{^Scx=sund}', "");
Expect(1, 7367, '\p{Scx=	 Sund}', "");
Expect(0, 7367, '\p{^Scx=	 Sund}', "");
Expect(0, 7367, '\P{Scx=	 Sund}', "");
Expect(1, 7367, '\P{^Scx=	 Sund}', "");
Expect(0, 7368, '\p{Scx=	 Sund}', "");
Expect(1, 7368, '\p{^Scx=	 Sund}', "");
Expect(1, 7368, '\P{Scx=	 Sund}', "");
Expect(0, 7368, '\P{^Scx=	 Sund}', "");
Error('\p{Is_Script_Extensions=	Sundanese/a/}');
Error('\P{Is_Script_Extensions=	Sundanese/a/}');
Expect(1, 7367, '\p{Is_Script_Extensions=sundanese}', "");
Expect(0, 7367, '\p{^Is_Script_Extensions=sundanese}', "");
Expect(0, 7367, '\P{Is_Script_Extensions=sundanese}', "");
Expect(1, 7367, '\P{^Is_Script_Extensions=sundanese}', "");
Expect(0, 7368, '\p{Is_Script_Extensions=sundanese}', "");
Expect(1, 7368, '\p{^Is_Script_Extensions=sundanese}', "");
Expect(1, 7368, '\P{Is_Script_Extensions=sundanese}', "");
Expect(0, 7368, '\P{^Is_Script_Extensions=sundanese}', "");
Expect(1, 7367, '\p{Is_Script_Extensions: 	_sundanese}', "");
Expect(0, 7367, '\p{^Is_Script_Extensions: 	_sundanese}', "");
Expect(0, 7367, '\P{Is_Script_Extensions: 	_sundanese}', "");
Expect(1, 7367, '\P{^Is_Script_Extensions: 	_sundanese}', "");
Expect(0, 7368, '\p{Is_Script_Extensions: 	_sundanese}', "");
Expect(1, 7368, '\p{^Is_Script_Extensions: 	_sundanese}', "");
Expect(1, 7368, '\P{Is_Script_Extensions: 	_sundanese}', "");
Expect(0, 7368, '\P{^Is_Script_Extensions: 	_sundanese}', "");
Error('\p{Is_Scx=/a/Sund}');
Error('\P{Is_Scx=/a/Sund}');
Expect(1, 7367, '\p{Is_Scx=sund}', "");
Expect(0, 7367, '\p{^Is_Scx=sund}', "");
Expect(0, 7367, '\P{Is_Scx=sund}', "");
Expect(1, 7367, '\P{^Is_Scx=sund}', "");
Expect(0, 7368, '\p{Is_Scx=sund}', "");
Expect(1, 7368, '\p{^Is_Scx=sund}', "");
Expect(1, 7368, '\P{Is_Scx=sund}', "");
Expect(0, 7368, '\P{^Is_Scx=sund}', "");
Expect(1, 7367, '\p{Is_Scx=	 Sund}', "");
Expect(0, 7367, '\p{^Is_Scx=	 Sund}', "");
Expect(0, 7367, '\P{Is_Scx=	 Sund}', "");
Expect(1, 7367, '\P{^Is_Scx=	 Sund}', "");
Expect(0, 7368, '\p{Is_Scx=	 Sund}', "");
Expect(1, 7368, '\p{^Is_Scx=	 Sund}', "");
Expect(1, 7368, '\P{Is_Scx=	 Sund}', "");
Expect(0, 7368, '\P{^Is_Scx=	 Sund}', "");
Error('\p{Script_Extensions=/a/ syloti_Nagri}');
Error('\P{Script_Extensions=/a/ syloti_Nagri}');
Expect(1, 43051, '\p{Script_Extensions=sylotinagri}', "");
Expect(0, 43051, '\p{^Script_Extensions=sylotinagri}', "");
Expect(0, 43051, '\P{Script_Extensions=sylotinagri}', "");
Expect(1, 43051, '\P{^Script_Extensions=sylotinagri}', "");
Expect(0, 43052, '\p{Script_Extensions=sylotinagri}', "");
Expect(1, 43052, '\p{^Script_Extensions=sylotinagri}', "");
Expect(1, 43052, '\P{Script_Extensions=sylotinagri}', "");
Expect(0, 43052, '\P{^Script_Extensions=sylotinagri}', "");
Expect(1, 43051, '\p{Script_Extensions=	_syloti_NAGRI}', "");
Expect(0, 43051, '\p{^Script_Extensions=	_syloti_NAGRI}', "");
Expect(0, 43051, '\P{Script_Extensions=	_syloti_NAGRI}', "");
Expect(1, 43051, '\P{^Script_Extensions=	_syloti_NAGRI}', "");
Expect(0, 43052, '\p{Script_Extensions=	_syloti_NAGRI}', "");
Expect(1, 43052, '\p{^Script_Extensions=	_syloti_NAGRI}', "");
Expect(1, 43052, '\P{Script_Extensions=	_syloti_NAGRI}', "");
Expect(0, 43052, '\P{^Script_Extensions=	_syloti_NAGRI}', "");
Error('\p{Scx=:=		sylo}');
Error('\P{Scx=:=		sylo}');
Expect(1, 43051, '\p{Scx=sylo}', "");
Expect(0, 43051, '\p{^Scx=sylo}', "");
Expect(0, 43051, '\P{Scx=sylo}', "");
Expect(1, 43051, '\P{^Scx=sylo}', "");
Expect(0, 43052, '\p{Scx=sylo}', "");
Expect(1, 43052, '\p{^Scx=sylo}', "");
Expect(1, 43052, '\P{Scx=sylo}', "");
Expect(0, 43052, '\P{^Scx=sylo}', "");
Expect(1, 43051, '\p{Scx=	Sylo}', "");
Expect(0, 43051, '\p{^Scx=	Sylo}', "");
Expect(0, 43051, '\P{Scx=	Sylo}', "");
Expect(1, 43051, '\P{^Scx=	Sylo}', "");
Expect(0, 43052, '\p{Scx=	Sylo}', "");
Expect(1, 43052, '\p{^Scx=	Sylo}', "");
Expect(1, 43052, '\P{Scx=	Sylo}', "");
Expect(0, 43052, '\P{^Scx=	Sylo}', "");
Error('\p{Is_Script_Extensions=_/a/SYLOTI_Nagri}');
Error('\P{Is_Script_Extensions=_/a/SYLOTI_Nagri}');
Expect(1, 43051, '\p{Is_Script_Extensions=sylotinagri}', "");
Expect(0, 43051, '\p{^Is_Script_Extensions=sylotinagri}', "");
Expect(0, 43051, '\P{Is_Script_Extensions=sylotinagri}', "");
Expect(1, 43051, '\P{^Is_Script_Extensions=sylotinagri}', "");
Expect(0, 43052, '\p{Is_Script_Extensions=sylotinagri}', "");
Expect(1, 43052, '\p{^Is_Script_Extensions=sylotinagri}', "");
Expect(1, 43052, '\P{Is_Script_Extensions=sylotinagri}', "");
Expect(0, 43052, '\P{^Is_Script_Extensions=sylotinagri}', "");
Expect(1, 43051, '\p{Is_Script_Extensions= _Syloti_NAGRI}', "");
Expect(0, 43051, '\p{^Is_Script_Extensions= _Syloti_NAGRI}', "");
Expect(0, 43051, '\P{Is_Script_Extensions= _Syloti_NAGRI}', "");
Expect(1, 43051, '\P{^Is_Script_Extensions= _Syloti_NAGRI}', "");
Expect(0, 43052, '\p{Is_Script_Extensions= _Syloti_NAGRI}', "");
Expect(1, 43052, '\p{^Is_Script_Extensions= _Syloti_NAGRI}', "");
Expect(1, 43052, '\P{Is_Script_Extensions= _Syloti_NAGRI}', "");
Expect(0, 43052, '\P{^Is_Script_Extensions= _Syloti_NAGRI}', "");
Error('\p{Is_Scx=/a/SYLO}');
Error('\P{Is_Scx=/a/SYLO}');
Expect(1, 43051, '\p{Is_Scx=sylo}', "");
Expect(0, 43051, '\p{^Is_Scx=sylo}', "");
Expect(0, 43051, '\P{Is_Scx=sylo}', "");
Expect(1, 43051, '\P{^Is_Scx=sylo}', "");
Expect(0, 43052, '\p{Is_Scx=sylo}', "");
Expect(1, 43052, '\p{^Is_Scx=sylo}', "");
Expect(1, 43052, '\P{Is_Scx=sylo}', "");
Expect(0, 43052, '\P{^Is_Scx=sylo}', "");
Expect(1, 43051, '\p{Is_Scx: __Sylo}', "");
Expect(0, 43051, '\p{^Is_Scx: __Sylo}', "");
Expect(0, 43051, '\P{Is_Scx: __Sylo}', "");
Expect(1, 43051, '\P{^Is_Scx: __Sylo}', "");
Expect(0, 43052, '\p{Is_Scx: __Sylo}', "");
Expect(1, 43052, '\p{^Is_Scx: __Sylo}', "");
Expect(1, 43052, '\P{Is_Scx: __Sylo}', "");
Expect(0, 43052, '\P{^Is_Scx: __Sylo}', "");
Error('\p{Script_Extensions=-:=SYRIAC}');
Error('\P{Script_Extensions=-:=SYRIAC}');
Expect(1, 1871, '\p{Script_Extensions=syriac}', "");
Expect(0, 1871, '\p{^Script_Extensions=syriac}', "");
Expect(0, 1871, '\P{Script_Extensions=syriac}', "");
Expect(1, 1871, '\P{^Script_Extensions=syriac}', "");
Expect(0, 1872, '\p{Script_Extensions=syriac}', "");
Expect(1, 1872, '\p{^Script_Extensions=syriac}', "");
Expect(1, 1872, '\P{Script_Extensions=syriac}', "");
Expect(0, 1872, '\P{^Script_Extensions=syriac}', "");
Error('\p{Scx=:=  Syrc}');
Error('\P{Scx=:=  Syrc}');
Expect(1, 1871, '\p{Scx=syrc}', "");
Expect(0, 1871, '\p{^Scx=syrc}', "");
Expect(0, 1871, '\P{Scx=syrc}', "");
Expect(1, 1871, '\P{^Scx=syrc}', "");
Expect(0, 1872, '\p{Scx=syrc}', "");
Expect(1, 1872, '\p{^Scx=syrc}', "");
Expect(1, 1872, '\P{Scx=syrc}', "");
Expect(0, 1872, '\P{^Scx=syrc}', "");
Expect(1, 1871, '\p{Scx=_SYRC}', "");
Expect(0, 1871, '\p{^Scx=_SYRC}', "");
Expect(0, 1871, '\P{Scx=_SYRC}', "");
Expect(1, 1871, '\P{^Scx=_SYRC}', "");
Expect(0, 1872, '\p{Scx=_SYRC}', "");
Expect(1, 1872, '\p{^Scx=_SYRC}', "");
Expect(1, 1872, '\P{Scx=_SYRC}', "");
Expect(0, 1872, '\P{^Scx=_SYRC}', "");
Error('\p{Is_Script_Extensions=-_Syriac:=}');
Error('\P{Is_Script_Extensions=-_Syriac:=}');
Expect(1, 1871, '\p{Is_Script_Extensions=syriac}', "");
Expect(0, 1871, '\p{^Is_Script_Extensions=syriac}', "");
Expect(0, 1871, '\P{Is_Script_Extensions=syriac}', "");
Expect(1, 1871, '\P{^Is_Script_Extensions=syriac}', "");
Expect(0, 1872, '\p{Is_Script_Extensions=syriac}', "");
Expect(1, 1872, '\p{^Is_Script_Extensions=syriac}', "");
Expect(1, 1872, '\P{Is_Script_Extensions=syriac}', "");
Expect(0, 1872, '\P{^Is_Script_Extensions=syriac}', "");
Expect(1, 1871, '\p{Is_Script_Extensions=  syriac}', "");
Expect(0, 1871, '\p{^Is_Script_Extensions=  syriac}', "");
Expect(0, 1871, '\P{Is_Script_Extensions=  syriac}', "");
Expect(1, 1871, '\P{^Is_Script_Extensions=  syriac}', "");
Expect(0, 1872, '\p{Is_Script_Extensions=  syriac}', "");
Expect(1, 1872, '\p{^Is_Script_Extensions=  syriac}', "");
Expect(1, 1872, '\P{Is_Script_Extensions=  syriac}', "");
Expect(0, 1872, '\P{^Is_Script_Extensions=  syriac}', "");
Error('\p{Is_Scx=__Syrc/a/}');
Error('\P{Is_Scx=__Syrc/a/}');
Expect(1, 1871, '\p{Is_Scx=syrc}', "");
Expect(0, 1871, '\p{^Is_Scx=syrc}', "");
Expect(0, 1871, '\P{Is_Scx=syrc}', "");
Expect(1, 1871, '\P{^Is_Scx=syrc}', "");
Expect(0, 1872, '\p{Is_Scx=syrc}', "");
Expect(1, 1872, '\p{^Is_Scx=syrc}', "");
Expect(1, 1872, '\P{Is_Scx=syrc}', "");
Expect(0, 1872, '\P{^Is_Scx=syrc}', "");
Expect(1, 1871, '\p{Is_Scx=_syrc}', "");
Expect(0, 1871, '\p{^Is_Scx=_syrc}', "");
Expect(0, 1871, '\P{Is_Scx=_syrc}', "");
Expect(1, 1871, '\P{^Is_Scx=_syrc}', "");
Expect(0, 1872, '\p{Is_Scx=_syrc}', "");
Expect(1, 1872, '\p{^Is_Scx=_syrc}', "");
Expect(1, 1872, '\P{Is_Scx=_syrc}', "");
Expect(0, 1872, '\P{^Is_Scx=_syrc}', "");
Error('\p{Script_Extensions=	_TAGBANWA:=}');
Error('\P{Script_Extensions=	_TAGBANWA:=}');
Expect(1, 6003, '\p{Script_Extensions=tagbanwa}', "");
Expect(0, 6003, '\p{^Script_Extensions=tagbanwa}', "");
Expect(0, 6003, '\P{Script_Extensions=tagbanwa}', "");
Expect(1, 6003, '\P{^Script_Extensions=tagbanwa}', "");
Expect(0, 6004, '\p{Script_Extensions=tagbanwa}', "");
Expect(1, 6004, '\p{^Script_Extensions=tagbanwa}', "");
Expect(1, 6004, '\P{Script_Extensions=tagbanwa}', "");
Expect(0, 6004, '\P{^Script_Extensions=tagbanwa}', "");
Expect(1, 6003, '\p{Script_Extensions=	TAGBANWA}', "");
Expect(0, 6003, '\p{^Script_Extensions=	TAGBANWA}', "");
Expect(0, 6003, '\P{Script_Extensions=	TAGBANWA}', "");
Expect(1, 6003, '\P{^Script_Extensions=	TAGBANWA}', "");
Expect(0, 6004, '\p{Script_Extensions=	TAGBANWA}', "");
Expect(1, 6004, '\p{^Script_Extensions=	TAGBANWA}', "");
Expect(1, 6004, '\P{Script_Extensions=	TAGBANWA}', "");
Expect(0, 6004, '\P{^Script_Extensions=	TAGBANWA}', "");
Error('\p{Scx=:=_ Tagb}');
Error('\P{Scx=:=_ Tagb}');
Expect(1, 6003, '\p{Scx=tagb}', "");
Expect(0, 6003, '\p{^Scx=tagb}', "");
Expect(0, 6003, '\P{Scx=tagb}', "");
Expect(1, 6003, '\P{^Scx=tagb}', "");
Expect(0, 6004, '\p{Scx=tagb}', "");
Expect(1, 6004, '\p{^Scx=tagb}', "");
Expect(1, 6004, '\P{Scx=tagb}', "");
Expect(0, 6004, '\P{^Scx=tagb}', "");
Expect(1, 6003, '\p{Scx= _tagb}', "");
Expect(0, 6003, '\p{^Scx= _tagb}', "");
Expect(0, 6003, '\P{Scx= _tagb}', "");
Expect(1, 6003, '\P{^Scx= _tagb}', "");
Expect(0, 6004, '\p{Scx= _tagb}', "");
Expect(1, 6004, '\p{^Scx= _tagb}', "");
Expect(1, 6004, '\P{Scx= _tagb}', "");
Expect(0, 6004, '\P{^Scx= _tagb}', "");
Error('\p{Is_Script_Extensions=_/a/Tagbanwa}');
Error('\P{Is_Script_Extensions=_/a/Tagbanwa}');
Expect(1, 6003, '\p{Is_Script_Extensions=tagbanwa}', "");
Expect(0, 6003, '\p{^Is_Script_Extensions=tagbanwa}', "");
Expect(0, 6003, '\P{Is_Script_Extensions=tagbanwa}', "");
Expect(1, 6003, '\P{^Is_Script_Extensions=tagbanwa}', "");
Expect(0, 6004, '\p{Is_Script_Extensions=tagbanwa}', "");
Expect(1, 6004, '\p{^Is_Script_Extensions=tagbanwa}', "");
Expect(1, 6004, '\P{Is_Script_Extensions=tagbanwa}', "");
Expect(0, 6004, '\P{^Is_Script_Extensions=tagbanwa}', "");
Error('\p{Is_Scx=/a/-tagb}');
Error('\P{Is_Scx=/a/-tagb}');
Expect(1, 6003, '\p{Is_Scx:tagb}', "");
Expect(0, 6003, '\p{^Is_Scx:tagb}', "");
Expect(0, 6003, '\P{Is_Scx:tagb}', "");
Expect(1, 6003, '\P{^Is_Scx:tagb}', "");
Expect(0, 6004, '\p{Is_Scx:tagb}', "");
Expect(1, 6004, '\p{^Is_Scx:tagb}', "");
Expect(1, 6004, '\P{Is_Scx:tagb}', "");
Expect(0, 6004, '\P{^Is_Scx:tagb}', "");
Expect(1, 6003, '\p{Is_Scx:_Tagb}', "");
Expect(0, 6003, '\p{^Is_Scx:_Tagb}', "");
Expect(0, 6003, '\P{Is_Scx:_Tagb}', "");
Expect(1, 6003, '\P{^Is_Scx:_Tagb}', "");
Expect(0, 6004, '\p{Is_Scx:_Tagb}', "");
Expect(1, 6004, '\p{^Is_Scx:_Tagb}', "");
Expect(1, 6004, '\P{Is_Scx:_Tagb}', "");
Expect(0, 6004, '\P{^Is_Scx:_Tagb}', "");
Error('\p{Script_Extensions=_/a/Takri}');
Error('\P{Script_Extensions=_/a/Takri}');
Expect(1, 71369, '\p{Script_Extensions=takri}', "");
Expect(0, 71369, '\p{^Script_Extensions=takri}', "");
Expect(0, 71369, '\P{Script_Extensions=takri}', "");
Expect(1, 71369, '\P{^Script_Extensions=takri}', "");
Expect(0, 71370, '\p{Script_Extensions=takri}', "");
Expect(1, 71370, '\p{^Script_Extensions=takri}', "");
Expect(1, 71370, '\P{Script_Extensions=takri}', "");
Expect(0, 71370, '\P{^Script_Extensions=takri}', "");
Expect(1, 71369, '\p{Script_Extensions= 	takri}', "");
Expect(0, 71369, '\p{^Script_Extensions= 	takri}', "");
Expect(0, 71369, '\P{Script_Extensions= 	takri}', "");
Expect(1, 71369, '\P{^Script_Extensions= 	takri}', "");
Expect(0, 71370, '\p{Script_Extensions= 	takri}', "");
Expect(1, 71370, '\p{^Script_Extensions= 	takri}', "");
Expect(1, 71370, '\P{Script_Extensions= 	takri}', "");
Expect(0, 71370, '\P{^Script_Extensions= 	takri}', "");
Error('\p{Scx:/a/ TAKR}');
Error('\P{Scx:/a/ TAKR}');
Expect(1, 71369, '\p{Scx=takr}', "");
Expect(0, 71369, '\p{^Scx=takr}', "");
Expect(0, 71369, '\P{Scx=takr}', "");
Expect(1, 71369, '\P{^Scx=takr}', "");
Expect(0, 71370, '\p{Scx=takr}', "");
Expect(1, 71370, '\p{^Scx=takr}', "");
Expect(1, 71370, '\P{Scx=takr}', "");
Expect(0, 71370, '\P{^Scx=takr}', "");
Expect(1, 71369, '\p{Scx=	-Takr}', "");
Expect(0, 71369, '\p{^Scx=	-Takr}', "");
Expect(0, 71369, '\P{Scx=	-Takr}', "");
Expect(1, 71369, '\P{^Scx=	-Takr}', "");
Expect(0, 71370, '\p{Scx=	-Takr}', "");
Expect(1, 71370, '\p{^Scx=	-Takr}', "");
Expect(1, 71370, '\P{Scx=	-Takr}', "");
Expect(0, 71370, '\P{^Scx=	-Takr}', "");
Error('\p{Is_Script_Extensions=	/a/TAKRI}');
Error('\P{Is_Script_Extensions=	/a/TAKRI}');
Expect(1, 71369, '\p{Is_Script_Extensions=takri}', "");
Expect(0, 71369, '\p{^Is_Script_Extensions=takri}', "");
Expect(0, 71369, '\P{Is_Script_Extensions=takri}', "");
Expect(1, 71369, '\P{^Is_Script_Extensions=takri}', "");
Expect(0, 71370, '\p{Is_Script_Extensions=takri}', "");
Expect(1, 71370, '\p{^Is_Script_Extensions=takri}', "");
Expect(1, 71370, '\P{Is_Script_Extensions=takri}', "");
Expect(0, 71370, '\P{^Is_Script_Extensions=takri}', "");
Expect(1, 71369, '\p{Is_Script_Extensions=- Takri}', "");
Expect(0, 71369, '\p{^Is_Script_Extensions=- Takri}', "");
Expect(0, 71369, '\P{Is_Script_Extensions=- Takri}', "");
Expect(1, 71369, '\P{^Is_Script_Extensions=- Takri}', "");
Expect(0, 71370, '\p{Is_Script_Extensions=- Takri}', "");
Expect(1, 71370, '\p{^Is_Script_Extensions=- Takri}', "");
Expect(1, 71370, '\P{Is_Script_Extensions=- Takri}', "");
Expect(0, 71370, '\P{^Is_Script_Extensions=- Takri}', "");
Error('\p{Is_Scx=	:=Takr}');
Error('\P{Is_Scx=	:=Takr}');
Expect(1, 71369, '\p{Is_Scx=takr}', "");
Expect(0, 71369, '\p{^Is_Scx=takr}', "");
Expect(0, 71369, '\P{Is_Scx=takr}', "");
Expect(1, 71369, '\P{^Is_Scx=takr}', "");
Expect(0, 71370, '\p{Is_Scx=takr}', "");
Expect(1, 71370, '\p{^Is_Scx=takr}', "");
Expect(1, 71370, '\P{Is_Scx=takr}', "");
Expect(0, 71370, '\P{^Is_Scx=takr}', "");
Expect(1, 71369, '\p{Is_Scx= 	Takr}', "");
Expect(0, 71369, '\p{^Is_Scx= 	Takr}', "");
Expect(0, 71369, '\P{Is_Scx= 	Takr}', "");
Expect(1, 71369, '\P{^Is_Scx= 	Takr}', "");
Expect(0, 71370, '\p{Is_Scx= 	Takr}', "");
Expect(1, 71370, '\p{^Is_Scx= 	Takr}', "");
Expect(1, 71370, '\P{Is_Scx= 	Takr}', "");
Expect(0, 71370, '\P{^Is_Scx= 	Takr}', "");
Error('\p{Script_Extensions=/a/	 Tai_Le}');
Error('\P{Script_Extensions=/a/	 Tai_Le}');
Expect(1, 6516, '\p{Script_Extensions=taile}', "");
Expect(0, 6516, '\p{^Script_Extensions=taile}', "");
Expect(0, 6516, '\P{Script_Extensions=taile}', "");
Expect(1, 6516, '\P{^Script_Extensions=taile}', "");
Expect(0, 6517, '\p{Script_Extensions=taile}', "");
Expect(1, 6517, '\p{^Script_Extensions=taile}', "");
Expect(1, 6517, '\P{Script_Extensions=taile}', "");
Expect(0, 6517, '\P{^Script_Extensions=taile}', "");
Expect(1, 6516, '\p{Script_Extensions=_	Tai_Le}', "");
Expect(0, 6516, '\p{^Script_Extensions=_	Tai_Le}', "");
Expect(0, 6516, '\P{Script_Extensions=_	Tai_Le}', "");
Expect(1, 6516, '\P{^Script_Extensions=_	Tai_Le}', "");
Expect(0, 6517, '\p{Script_Extensions=_	Tai_Le}', "");
Expect(1, 6517, '\p{^Script_Extensions=_	Tai_Le}', "");
Expect(1, 6517, '\P{Script_Extensions=_	Tai_Le}', "");
Expect(0, 6517, '\P{^Script_Extensions=_	Tai_Le}', "");
Error('\p{Scx=/a/  Tale}');
Error('\P{Scx=/a/  Tale}');
Expect(1, 6516, '\p{Scx=tale}', "");
Expect(0, 6516, '\p{^Scx=tale}', "");
Expect(0, 6516, '\P{Scx=tale}', "");
Expect(1, 6516, '\P{^Scx=tale}', "");
Expect(0, 6517, '\p{Scx=tale}', "");
Expect(1, 6517, '\p{^Scx=tale}', "");
Expect(1, 6517, '\P{Scx=tale}', "");
Expect(0, 6517, '\P{^Scx=tale}', "");
Expect(1, 6516, '\p{Scx:	_ Tale}', "");
Expect(0, 6516, '\p{^Scx:	_ Tale}', "");
Expect(0, 6516, '\P{Scx:	_ Tale}', "");
Expect(1, 6516, '\P{^Scx:	_ Tale}', "");
Expect(0, 6517, '\p{Scx:	_ Tale}', "");
Expect(1, 6517, '\p{^Scx:	_ Tale}', "");
Expect(1, 6517, '\P{Scx:	_ Tale}', "");
Expect(0, 6517, '\P{^Scx:	_ Tale}', "");
Error('\p{Is_Script_Extensions=	Tai_le:=}');
Error('\P{Is_Script_Extensions=	Tai_le:=}');
Expect(1, 6516, '\p{Is_Script_Extensions:   taile}', "");
Expect(0, 6516, '\p{^Is_Script_Extensions:   taile}', "");
Expect(0, 6516, '\P{Is_Script_Extensions:   taile}', "");
Expect(1, 6516, '\P{^Is_Script_Extensions:   taile}', "");
Expect(0, 6517, '\p{Is_Script_Extensions:   taile}', "");
Expect(1, 6517, '\p{^Is_Script_Extensions:   taile}', "");
Expect(1, 6517, '\P{Is_Script_Extensions:   taile}', "");
Expect(0, 6517, '\P{^Is_Script_Extensions:   taile}', "");
Expect(1, 6516, '\p{Is_Script_Extensions= _TAI_Le}', "");
Expect(0, 6516, '\p{^Is_Script_Extensions= _TAI_Le}', "");
Expect(0, 6516, '\P{Is_Script_Extensions= _TAI_Le}', "");
Expect(1, 6516, '\P{^Is_Script_Extensions= _TAI_Le}', "");
Expect(0, 6517, '\p{Is_Script_Extensions= _TAI_Le}', "");
Expect(1, 6517, '\p{^Is_Script_Extensions= _TAI_Le}', "");
Expect(1, 6517, '\P{Is_Script_Extensions= _TAI_Le}', "");
Expect(0, 6517, '\P{^Is_Script_Extensions= _TAI_Le}', "");
Error('\p{Is_Scx=	-tale/a/}');
Error('\P{Is_Scx=	-tale/a/}');
Expect(1, 6516, '\p{Is_Scx=tale}', "");
Expect(0, 6516, '\p{^Is_Scx=tale}', "");
Expect(0, 6516, '\P{Is_Scx=tale}', "");
Expect(1, 6516, '\P{^Is_Scx=tale}', "");
Expect(0, 6517, '\p{Is_Scx=tale}', "");
Expect(1, 6517, '\p{^Is_Scx=tale}', "");
Expect(1, 6517, '\P{Is_Scx=tale}', "");
Expect(0, 6517, '\P{^Is_Scx=tale}', "");
Expect(1, 6516, '\p{Is_Scx=	TALE}', "");
Expect(0, 6516, '\p{^Is_Scx=	TALE}', "");
Expect(0, 6516, '\P{Is_Scx=	TALE}', "");
Expect(1, 6516, '\P{^Is_Scx=	TALE}', "");
Expect(0, 6517, '\p{Is_Scx=	TALE}', "");
Expect(1, 6517, '\p{^Is_Scx=	TALE}', "");
Expect(1, 6517, '\P{Is_Scx=	TALE}', "");
Expect(0, 6517, '\P{^Is_Scx=	TALE}', "");
Error('\p{Script_Extensions=/a/ New_Tai_LUE}');
Error('\P{Script_Extensions=/a/ New_Tai_LUE}');
Expect(1, 6623, '\p{Script_Extensions=newtailue}', "");
Expect(0, 6623, '\p{^Script_Extensions=newtailue}', "");
Expect(0, 6623, '\P{Script_Extensions=newtailue}', "");
Expect(1, 6623, '\P{^Script_Extensions=newtailue}', "");
Expect(0, 6624, '\p{Script_Extensions=newtailue}', "");
Expect(1, 6624, '\p{^Script_Extensions=newtailue}', "");
Expect(1, 6624, '\P{Script_Extensions=newtailue}', "");
Expect(0, 6624, '\P{^Script_Extensions=newtailue}', "");
Expect(1, 6623, '\p{Script_Extensions=_-New_TAI_Lue}', "");
Expect(0, 6623, '\p{^Script_Extensions=_-New_TAI_Lue}', "");
Expect(0, 6623, '\P{Script_Extensions=_-New_TAI_Lue}', "");
Expect(1, 6623, '\P{^Script_Extensions=_-New_TAI_Lue}', "");
Expect(0, 6624, '\p{Script_Extensions=_-New_TAI_Lue}', "");
Expect(1, 6624, '\p{^Script_Extensions=_-New_TAI_Lue}', "");
Expect(1, 6624, '\P{Script_Extensions=_-New_TAI_Lue}', "");
Expect(0, 6624, '\P{^Script_Extensions=_-New_TAI_Lue}', "");
Error('\p{Scx=	Talu/a/}');
Error('\P{Scx=	Talu/a/}');
Expect(1, 6623, '\p{Scx=talu}', "");
Expect(0, 6623, '\p{^Scx=talu}', "");
Expect(0, 6623, '\P{Scx=talu}', "");
Expect(1, 6623, '\P{^Scx=talu}', "");
Expect(0, 6624, '\p{Scx=talu}', "");
Expect(1, 6624, '\p{^Scx=talu}', "");
Expect(1, 6624, '\P{Scx=talu}', "");
Expect(0, 6624, '\P{^Scx=talu}', "");
Expect(1, 6623, '\p{Scx: Talu}', "");
Expect(0, 6623, '\p{^Scx: Talu}', "");
Expect(0, 6623, '\P{Scx: Talu}', "");
Expect(1, 6623, '\P{^Scx: Talu}', "");
Expect(0, 6624, '\p{Scx: Talu}', "");
Expect(1, 6624, '\p{^Scx: Talu}', "");
Expect(1, 6624, '\P{Scx: Talu}', "");
Expect(0, 6624, '\P{^Scx: Talu}', "");
Error('\p{Is_Script_Extensions=	_New_tai_LUE/a/}');
Error('\P{Is_Script_Extensions=	_New_tai_LUE/a/}');
Expect(1, 6623, '\p{Is_Script_Extensions=newtailue}', "");
Expect(0, 6623, '\p{^Is_Script_Extensions=newtailue}', "");
Expect(0, 6623, '\P{Is_Script_Extensions=newtailue}', "");
Expect(1, 6623, '\P{^Is_Script_Extensions=newtailue}', "");
Expect(0, 6624, '\p{Is_Script_Extensions=newtailue}', "");
Expect(1, 6624, '\p{^Is_Script_Extensions=newtailue}', "");
Expect(1, 6624, '\P{Is_Script_Extensions=newtailue}', "");
Expect(0, 6624, '\P{^Is_Script_Extensions=newtailue}', "");
Expect(1, 6623, '\p{Is_Script_Extensions=__New_tai_Lue}', "");
Expect(0, 6623, '\p{^Is_Script_Extensions=__New_tai_Lue}', "");
Expect(0, 6623, '\P{Is_Script_Extensions=__New_tai_Lue}', "");
Expect(1, 6623, '\P{^Is_Script_Extensions=__New_tai_Lue}', "");
Expect(0, 6624, '\p{Is_Script_Extensions=__New_tai_Lue}', "");
Expect(1, 6624, '\p{^Is_Script_Extensions=__New_tai_Lue}', "");
Expect(1, 6624, '\P{Is_Script_Extensions=__New_tai_Lue}', "");
Expect(0, 6624, '\P{^Is_Script_Extensions=__New_tai_Lue}', "");
Error('\p{Is_Scx=:= _Talu}');
Error('\P{Is_Scx=:= _Talu}');
Expect(1, 6623, '\p{Is_Scx:   talu}', "");
Expect(0, 6623, '\p{^Is_Scx:   talu}', "");
Expect(0, 6623, '\P{Is_Scx:   talu}', "");
Expect(1, 6623, '\P{^Is_Scx:   talu}', "");
Expect(0, 6624, '\p{Is_Scx:   talu}', "");
Expect(1, 6624, '\p{^Is_Scx:   talu}', "");
Expect(1, 6624, '\P{Is_Scx:   talu}', "");
Expect(0, 6624, '\P{^Is_Scx:   talu}', "");
Expect(1, 6623, '\p{Is_Scx=  TALU}', "");
Expect(0, 6623, '\p{^Is_Scx=  TALU}', "");
Expect(0, 6623, '\P{Is_Scx=  TALU}', "");
Expect(1, 6623, '\P{^Is_Scx=  TALU}', "");
Expect(0, 6624, '\p{Is_Scx=  TALU}', "");
Expect(1, 6624, '\p{^Is_Scx=  TALU}', "");
Expect(1, 6624, '\P{Is_Scx=  TALU}', "");
Expect(0, 6624, '\P{^Is_Scx=  TALU}', "");
Error('\p{Script_Extensions=/a/_	Tamil}');
Error('\P{Script_Extensions=/a/_	Tamil}');
Expect(1, 3066, '\p{Script_Extensions:tamil}', "");
Expect(0, 3066, '\p{^Script_Extensions:tamil}', "");
Expect(0, 3066, '\P{Script_Extensions:tamil}', "");
Expect(1, 3066, '\P{^Script_Extensions:tamil}', "");
Expect(0, 3067, '\p{Script_Extensions:tamil}', "");
Expect(1, 3067, '\p{^Script_Extensions:tamil}', "");
Expect(1, 3067, '\P{Script_Extensions:tamil}', "");
Expect(0, 3067, '\P{^Script_Extensions:tamil}', "");
Expect(1, 3066, '\p{Script_Extensions= 	Tamil}', "");
Expect(0, 3066, '\p{^Script_Extensions= 	Tamil}', "");
Expect(0, 3066, '\P{Script_Extensions= 	Tamil}', "");
Expect(1, 3066, '\P{^Script_Extensions= 	Tamil}', "");
Expect(0, 3067, '\p{Script_Extensions= 	Tamil}', "");
Expect(1, 3067, '\p{^Script_Extensions= 	Tamil}', "");
Expect(1, 3067, '\P{Script_Extensions= 	Tamil}', "");
Expect(0, 3067, '\P{^Script_Extensions= 	Tamil}', "");
Error('\p{Scx=_Taml:=}');
Error('\P{Scx=_Taml:=}');
Expect(1, 3066, '\p{Scx=taml}', "");
Expect(0, 3066, '\p{^Scx=taml}', "");
Expect(0, 3066, '\P{Scx=taml}', "");
Expect(1, 3066, '\P{^Scx=taml}', "");
Expect(0, 3067, '\p{Scx=taml}', "");
Expect(1, 3067, '\p{^Scx=taml}', "");
Expect(1, 3067, '\P{Scx=taml}', "");
Expect(0, 3067, '\P{^Scx=taml}', "");
Expect(1, 3066, '\p{Scx= _Taml}', "");
Expect(0, 3066, '\p{^Scx= _Taml}', "");
Expect(0, 3066, '\P{Scx= _Taml}', "");
Expect(1, 3066, '\P{^Scx= _Taml}', "");
Expect(0, 3067, '\p{Scx= _Taml}', "");
Expect(1, 3067, '\p{^Scx= _Taml}', "");
Expect(1, 3067, '\P{Scx= _Taml}', "");
Expect(0, 3067, '\P{^Scx= _Taml}', "");
Error('\p{Is_Script_Extensions=_	TAMIL:=}');
Error('\P{Is_Script_Extensions=_	TAMIL:=}');
Expect(1, 3066, '\p{Is_Script_Extensions=tamil}', "");
Expect(0, 3066, '\p{^Is_Script_Extensions=tamil}', "");
Expect(0, 3066, '\P{Is_Script_Extensions=tamil}', "");
Expect(1, 3066, '\P{^Is_Script_Extensions=tamil}', "");
Expect(0, 3067, '\p{Is_Script_Extensions=tamil}', "");
Expect(1, 3067, '\p{^Is_Script_Extensions=tamil}', "");
Expect(1, 3067, '\P{Is_Script_Extensions=tamil}', "");
Expect(0, 3067, '\P{^Is_Script_Extensions=tamil}', "");
Expect(1, 3066, '\p{Is_Script_Extensions=TAMIL}', "");
Expect(0, 3066, '\p{^Is_Script_Extensions=TAMIL}', "");
Expect(0, 3066, '\P{Is_Script_Extensions=TAMIL}', "");
Expect(1, 3066, '\P{^Is_Script_Extensions=TAMIL}', "");
Expect(0, 3067, '\p{Is_Script_Extensions=TAMIL}', "");
Expect(1, 3067, '\p{^Is_Script_Extensions=TAMIL}', "");
Expect(1, 3067, '\P{Is_Script_Extensions=TAMIL}', "");
Expect(0, 3067, '\P{^Is_Script_Extensions=TAMIL}', "");
Error('\p{Is_Scx=_	Taml:=}');
Error('\P{Is_Scx=_	Taml:=}');
Expect(1, 3066, '\p{Is_Scx=taml}', "");
Expect(0, 3066, '\p{^Is_Scx=taml}', "");
Expect(0, 3066, '\P{Is_Scx=taml}', "");
Expect(1, 3066, '\P{^Is_Scx=taml}', "");
Expect(0, 3067, '\p{Is_Scx=taml}', "");
Expect(1, 3067, '\p{^Is_Scx=taml}', "");
Expect(1, 3067, '\P{Is_Scx=taml}', "");
Expect(0, 3067, '\P{^Is_Scx=taml}', "");
Error('\p{Script_Extensions=_Tai_viet:=}');
Error('\P{Script_Extensions=_Tai_viet:=}');
Expect(1, 43743, '\p{Script_Extensions=taiviet}', "");
Expect(0, 43743, '\p{^Script_Extensions=taiviet}', "");
Expect(0, 43743, '\P{Script_Extensions=taiviet}', "");
Expect(1, 43743, '\P{^Script_Extensions=taiviet}', "");
Expect(0, 43744, '\p{Script_Extensions=taiviet}', "");
Expect(1, 43744, '\p{^Script_Extensions=taiviet}', "");
Expect(1, 43744, '\P{Script_Extensions=taiviet}', "");
Expect(0, 43744, '\P{^Script_Extensions=taiviet}', "");
Expect(1, 43743, '\p{Script_Extensions= 	Tai_viet}', "");
Expect(0, 43743, '\p{^Script_Extensions= 	Tai_viet}', "");
Expect(0, 43743, '\P{Script_Extensions= 	Tai_viet}', "");
Expect(1, 43743, '\P{^Script_Extensions= 	Tai_viet}', "");
Expect(0, 43744, '\p{Script_Extensions= 	Tai_viet}', "");
Expect(1, 43744, '\p{^Script_Extensions= 	Tai_viet}', "");
Expect(1, 43744, '\P{Script_Extensions= 	Tai_viet}', "");
Expect(0, 43744, '\P{^Script_Extensions= 	Tai_viet}', "");
Error('\p{Scx=/a/	Tavt}');
Error('\P{Scx=/a/	Tavt}');
Expect(1, 43743, '\p{Scx=tavt}', "");
Expect(0, 43743, '\p{^Scx=tavt}', "");
Expect(0, 43743, '\P{Scx=tavt}', "");
Expect(1, 43743, '\P{^Scx=tavt}', "");
Expect(0, 43744, '\p{Scx=tavt}', "");
Expect(1, 43744, '\p{^Scx=tavt}', "");
Expect(1, 43744, '\P{Scx=tavt}', "");
Expect(0, 43744, '\P{^Scx=tavt}', "");
Expect(1, 43743, '\p{Scx= 	tavt}', "");
Expect(0, 43743, '\p{^Scx= 	tavt}', "");
Expect(0, 43743, '\P{Scx= 	tavt}', "");
Expect(1, 43743, '\P{^Scx= 	tavt}', "");
Expect(0, 43744, '\p{Scx= 	tavt}', "");
Expect(1, 43744, '\p{^Scx= 	tavt}', "");
Expect(1, 43744, '\P{Scx= 	tavt}', "");
Expect(0, 43744, '\P{^Scx= 	tavt}', "");
Error('\p{Is_Script_Extensions=_TAI_viet/a/}');
Error('\P{Is_Script_Extensions=_TAI_viet/a/}');
Expect(1, 43743, '\p{Is_Script_Extensions=taiviet}', "");
Expect(0, 43743, '\p{^Is_Script_Extensions=taiviet}', "");
Expect(0, 43743, '\P{Is_Script_Extensions=taiviet}', "");
Expect(1, 43743, '\P{^Is_Script_Extensions=taiviet}', "");
Expect(0, 43744, '\p{Is_Script_Extensions=taiviet}', "");
Expect(1, 43744, '\p{^Is_Script_Extensions=taiviet}', "");
Expect(1, 43744, '\P{Is_Script_Extensions=taiviet}', "");
Expect(0, 43744, '\P{^Is_Script_Extensions=taiviet}', "");
Expect(1, 43743, '\p{Is_Script_Extensions=-Tai_Viet}', "");
Expect(0, 43743, '\p{^Is_Script_Extensions=-Tai_Viet}', "");
Expect(0, 43743, '\P{Is_Script_Extensions=-Tai_Viet}', "");
Expect(1, 43743, '\P{^Is_Script_Extensions=-Tai_Viet}', "");
Expect(0, 43744, '\p{Is_Script_Extensions=-Tai_Viet}', "");
Expect(1, 43744, '\p{^Is_Script_Extensions=-Tai_Viet}', "");
Expect(1, 43744, '\P{Is_Script_Extensions=-Tai_Viet}', "");
Expect(0, 43744, '\P{^Is_Script_Extensions=-Tai_Viet}', "");
Error('\p{Is_Scx=- Tavt:=}');
Error('\P{Is_Scx=- Tavt:=}');
Expect(1, 43743, '\p{Is_Scx:	tavt}', "");
Expect(0, 43743, '\p{^Is_Scx:	tavt}', "");
Expect(0, 43743, '\P{Is_Scx:	tavt}', "");
Expect(1, 43743, '\P{^Is_Scx:	tavt}', "");
Expect(0, 43744, '\p{Is_Scx:	tavt}', "");
Expect(1, 43744, '\p{^Is_Scx:	tavt}', "");
Expect(1, 43744, '\P{Is_Scx:	tavt}', "");
Expect(0, 43744, '\P{^Is_Scx:	tavt}', "");
Expect(1, 43743, '\p{Is_Scx=_tavt}', "");
Expect(0, 43743, '\p{^Is_Scx=_tavt}', "");
Expect(0, 43743, '\P{Is_Scx=_tavt}', "");
Expect(1, 43743, '\P{^Is_Scx=_tavt}', "");
Expect(0, 43744, '\p{Is_Scx=_tavt}', "");
Expect(1, 43744, '\p{^Is_Scx=_tavt}', "");
Expect(1, 43744, '\P{Is_Scx=_tavt}', "");
Expect(0, 43744, '\P{^Is_Scx=_tavt}', "");
Error('\p{Script_Extensions=:=	Telugu}');
Error('\P{Script_Extensions=:=	Telugu}');
Expect(1, 3199, '\p{Script_Extensions=telugu}', "");
Expect(0, 3199, '\p{^Script_Extensions=telugu}', "");
Expect(0, 3199, '\P{Script_Extensions=telugu}', "");
Expect(1, 3199, '\P{^Script_Extensions=telugu}', "");
Expect(0, 3200, '\p{Script_Extensions=telugu}', "");
Expect(1, 3200, '\p{^Script_Extensions=telugu}', "");
Expect(1, 3200, '\P{Script_Extensions=telugu}', "");
Expect(0, 3200, '\P{^Script_Extensions=telugu}', "");
Expect(1, 3199, '\p{Script_Extensions= 	TELUGU}', "");
Expect(0, 3199, '\p{^Script_Extensions= 	TELUGU}', "");
Expect(0, 3199, '\P{Script_Extensions= 	TELUGU}', "");
Expect(1, 3199, '\P{^Script_Extensions= 	TELUGU}', "");
Expect(0, 3200, '\p{Script_Extensions= 	TELUGU}', "");
Expect(1, 3200, '\p{^Script_Extensions= 	TELUGU}', "");
Expect(1, 3200, '\P{Script_Extensions= 	TELUGU}', "");
Expect(0, 3200, '\P{^Script_Extensions= 	TELUGU}', "");
Error('\p{Scx:	/a/ Telu}');
Error('\P{Scx:	/a/ Telu}');
Expect(1, 3199, '\p{Scx=telu}', "");
Expect(0, 3199, '\p{^Scx=telu}', "");
Expect(0, 3199, '\P{Scx=telu}', "");
Expect(1, 3199, '\P{^Scx=telu}', "");
Expect(0, 3200, '\p{Scx=telu}', "");
Expect(1, 3200, '\p{^Scx=telu}', "");
Expect(1, 3200, '\P{Scx=telu}', "");
Expect(0, 3200, '\P{^Scx=telu}', "");
Expect(1, 3199, '\p{Scx=	telu}', "");
Expect(0, 3199, '\p{^Scx=	telu}', "");
Expect(0, 3199, '\P{Scx=	telu}', "");
Expect(1, 3199, '\P{^Scx=	telu}', "");
Expect(0, 3200, '\p{Scx=	telu}', "");
Expect(1, 3200, '\p{^Scx=	telu}', "");
Expect(1, 3200, '\P{Scx=	telu}', "");
Expect(0, 3200, '\P{^Scx=	telu}', "");
Error('\p{Is_Script_Extensions=	-TELUGU:=}');
Error('\P{Is_Script_Extensions=	-TELUGU:=}');
Expect(1, 3199, '\p{Is_Script_Extensions=telugu}', "");
Expect(0, 3199, '\p{^Is_Script_Extensions=telugu}', "");
Expect(0, 3199, '\P{Is_Script_Extensions=telugu}', "");
Expect(1, 3199, '\P{^Is_Script_Extensions=telugu}', "");
Expect(0, 3200, '\p{Is_Script_Extensions=telugu}', "");
Expect(1, 3200, '\p{^Is_Script_Extensions=telugu}', "");
Expect(1, 3200, '\P{Is_Script_Extensions=telugu}', "");
Expect(0, 3200, '\P{^Is_Script_Extensions=telugu}', "");
Expect(1, 3199, '\p{Is_Script_Extensions=--telugu}', "");
Expect(0, 3199, '\p{^Is_Script_Extensions=--telugu}', "");
Expect(0, 3199, '\P{Is_Script_Extensions=--telugu}', "");
Expect(1, 3199, '\P{^Is_Script_Extensions=--telugu}', "");
Expect(0, 3200, '\p{Is_Script_Extensions=--telugu}', "");
Expect(1, 3200, '\p{^Is_Script_Extensions=--telugu}', "");
Expect(1, 3200, '\P{Is_Script_Extensions=--telugu}', "");
Expect(0, 3200, '\P{^Is_Script_Extensions=--telugu}', "");
Error('\p{Is_Scx=-:=Telu}');
Error('\P{Is_Scx=-:=Telu}');
Expect(1, 3199, '\p{Is_Scx=telu}', "");
Expect(0, 3199, '\p{^Is_Scx=telu}', "");
Expect(0, 3199, '\P{Is_Scx=telu}', "");
Expect(1, 3199, '\P{^Is_Scx=telu}', "");
Expect(0, 3200, '\p{Is_Scx=telu}', "");
Expect(1, 3200, '\p{^Is_Scx=telu}', "");
Expect(1, 3200, '\P{Is_Scx=telu}', "");
Expect(0, 3200, '\P{^Is_Scx=telu}', "");
Expect(1, 3199, '\p{Is_Scx:	-	telu}', "");
Expect(0, 3199, '\p{^Is_Scx:	-	telu}', "");
Expect(0, 3199, '\P{Is_Scx:	-	telu}', "");
Expect(1, 3199, '\P{^Is_Scx:	-	telu}', "");
Expect(0, 3200, '\p{Is_Scx:	-	telu}', "");
Expect(1, 3200, '\p{^Is_Scx:	-	telu}', "");
Expect(1, 3200, '\P{Is_Scx:	-	telu}', "");
Expect(0, 3200, '\P{^Is_Scx:	-	telu}', "");
Error('\p{Script_Extensions=/a/--tifinagh}');
Error('\P{Script_Extensions=/a/--tifinagh}');
Expect(1, 11647, '\p{Script_Extensions=tifinagh}', "");
Expect(0, 11647, '\p{^Script_Extensions=tifinagh}', "");
Expect(0, 11647, '\P{Script_Extensions=tifinagh}', "");
Expect(1, 11647, '\P{^Script_Extensions=tifinagh}', "");
Expect(0, 11648, '\p{Script_Extensions=tifinagh}', "");
Expect(1, 11648, '\p{^Script_Extensions=tifinagh}', "");
Expect(1, 11648, '\P{Script_Extensions=tifinagh}', "");
Expect(0, 11648, '\P{^Script_Extensions=tifinagh}', "");
Expect(1, 11647, '\p{Script_Extensions=_Tifinagh}', "");
Expect(0, 11647, '\p{^Script_Extensions=_Tifinagh}', "");
Expect(0, 11647, '\P{Script_Extensions=_Tifinagh}', "");
Expect(1, 11647, '\P{^Script_Extensions=_Tifinagh}', "");
Expect(0, 11648, '\p{Script_Extensions=_Tifinagh}', "");
Expect(1, 11648, '\p{^Script_Extensions=_Tifinagh}', "");
Expect(1, 11648, '\P{Script_Extensions=_Tifinagh}', "");
Expect(0, 11648, '\P{^Script_Extensions=_Tifinagh}', "");
Error('\p{Scx=:=	_Tfng}');
Error('\P{Scx=:=	_Tfng}');
Expect(1, 11647, '\p{Scx:   tfng}', "");
Expect(0, 11647, '\p{^Scx:   tfng}', "");
Expect(0, 11647, '\P{Scx:   tfng}', "");
Expect(1, 11647, '\P{^Scx:   tfng}', "");
Expect(0, 11648, '\p{Scx:   tfng}', "");
Expect(1, 11648, '\p{^Scx:   tfng}', "");
Expect(1, 11648, '\P{Scx:   tfng}', "");
Expect(0, 11648, '\P{^Scx:   tfng}', "");
Expect(1, 11647, '\p{Scx=- Tfng}', "");
Expect(0, 11647, '\p{^Scx=- Tfng}', "");
Expect(0, 11647, '\P{Scx=- Tfng}', "");
Expect(1, 11647, '\P{^Scx=- Tfng}', "");
Expect(0, 11648, '\p{Scx=- Tfng}', "");
Expect(1, 11648, '\p{^Scx=- Tfng}', "");
Expect(1, 11648, '\P{Scx=- Tfng}', "");
Expect(0, 11648, '\P{^Scx=- Tfng}', "");
Error('\p{Is_Script_Extensions=	Tifinagh/a/}');
Error('\P{Is_Script_Extensions=	Tifinagh/a/}');
Expect(1, 11647, '\p{Is_Script_Extensions=tifinagh}', "");
Expect(0, 11647, '\p{^Is_Script_Extensions=tifinagh}', "");
Expect(0, 11647, '\P{Is_Script_Extensions=tifinagh}', "");
Expect(1, 11647, '\P{^Is_Script_Extensions=tifinagh}', "");
Expect(0, 11648, '\p{Is_Script_Extensions=tifinagh}', "");
Expect(1, 11648, '\p{^Is_Script_Extensions=tifinagh}', "");
Expect(1, 11648, '\P{Is_Script_Extensions=tifinagh}', "");
Expect(0, 11648, '\P{^Is_Script_Extensions=tifinagh}', "");
Expect(1, 11647, '\p{Is_Script_Extensions=-	TIFINAGH}', "");
Expect(0, 11647, '\p{^Is_Script_Extensions=-	TIFINAGH}', "");
Expect(0, 11647, '\P{Is_Script_Extensions=-	TIFINAGH}', "");
Expect(1, 11647, '\P{^Is_Script_Extensions=-	TIFINAGH}', "");
Expect(0, 11648, '\p{Is_Script_Extensions=-	TIFINAGH}', "");
Expect(1, 11648, '\p{^Is_Script_Extensions=-	TIFINAGH}', "");
Expect(1, 11648, '\P{Is_Script_Extensions=-	TIFINAGH}', "");
Expect(0, 11648, '\P{^Is_Script_Extensions=-	TIFINAGH}', "");
Error('\p{Is_Scx=_:=Tfng}');
Error('\P{Is_Scx=_:=Tfng}');
Expect(1, 11647, '\p{Is_Scx=tfng}', "");
Expect(0, 11647, '\p{^Is_Scx=tfng}', "");
Expect(0, 11647, '\P{Is_Scx=tfng}', "");
Expect(1, 11647, '\P{^Is_Scx=tfng}', "");
Expect(0, 11648, '\p{Is_Scx=tfng}', "");
Expect(1, 11648, '\p{^Is_Scx=tfng}', "");
Expect(1, 11648, '\P{Is_Scx=tfng}', "");
Expect(0, 11648, '\P{^Is_Scx=tfng}', "");
Expect(1, 11647, '\p{Is_Scx=-TFNG}', "");
Expect(0, 11647, '\p{^Is_Scx=-TFNG}', "");
Expect(0, 11647, '\P{Is_Scx=-TFNG}', "");
Expect(1, 11647, '\P{^Is_Scx=-TFNG}', "");
Expect(0, 11648, '\p{Is_Scx=-TFNG}', "");
Expect(1, 11648, '\p{^Is_Scx=-TFNG}', "");
Expect(1, 11648, '\P{Is_Scx=-TFNG}', "");
Expect(0, 11648, '\P{^Is_Scx=-TFNG}', "");
Error('\p{Script_Extensions=_/a/TAGALOG}');
Error('\P{Script_Extensions=_/a/TAGALOG}');
Expect(1, 5942, '\p{Script_Extensions=tagalog}', "");
Expect(0, 5942, '\p{^Script_Extensions=tagalog}', "");
Expect(0, 5942, '\P{Script_Extensions=tagalog}', "");
Expect(1, 5942, '\P{^Script_Extensions=tagalog}', "");
Expect(0, 5943, '\p{Script_Extensions=tagalog}', "");
Expect(1, 5943, '\p{^Script_Extensions=tagalog}', "");
Expect(1, 5943, '\P{Script_Extensions=tagalog}', "");
Expect(0, 5943, '\P{^Script_Extensions=tagalog}', "");
Expect(1, 5942, '\p{Script_Extensions= Tagalog}', "");
Expect(0, 5942, '\p{^Script_Extensions= Tagalog}', "");
Expect(0, 5942, '\P{Script_Extensions= Tagalog}', "");
Expect(1, 5942, '\P{^Script_Extensions= Tagalog}', "");
Expect(0, 5943, '\p{Script_Extensions= Tagalog}', "");
Expect(1, 5943, '\p{^Script_Extensions= Tagalog}', "");
Expect(1, 5943, '\P{Script_Extensions= Tagalog}', "");
Expect(0, 5943, '\P{^Script_Extensions= Tagalog}', "");
Error('\p{Scx=:=		Tglg}');
Error('\P{Scx=:=		Tglg}');
Expect(1, 5942, '\p{Scx=tglg}', "");
Expect(0, 5942, '\p{^Scx=tglg}', "");
Expect(0, 5942, '\P{Scx=tglg}', "");
Expect(1, 5942, '\P{^Scx=tglg}', "");
Expect(0, 5943, '\p{Scx=tglg}', "");
Expect(1, 5943, '\p{^Scx=tglg}', "");
Expect(1, 5943, '\P{Scx=tglg}', "");
Expect(0, 5943, '\P{^Scx=tglg}', "");
Expect(1, 5942, '\p{Scx=-TGLG}', "");
Expect(0, 5942, '\p{^Scx=-TGLG}', "");
Expect(0, 5942, '\P{Scx=-TGLG}', "");
Expect(1, 5942, '\P{^Scx=-TGLG}', "");
Expect(0, 5943, '\p{Scx=-TGLG}', "");
Expect(1, 5943, '\p{^Scx=-TGLG}', "");
Expect(1, 5943, '\P{Scx=-TGLG}', "");
Expect(0, 5943, '\P{^Scx=-TGLG}', "");
Error('\p{Is_Script_Extensions=-TAGALOG/a/}');
Error('\P{Is_Script_Extensions=-TAGALOG/a/}');
Expect(1, 5942, '\p{Is_Script_Extensions=tagalog}', "");
Expect(0, 5942, '\p{^Is_Script_Extensions=tagalog}', "");
Expect(0, 5942, '\P{Is_Script_Extensions=tagalog}', "");
Expect(1, 5942, '\P{^Is_Script_Extensions=tagalog}', "");
Expect(0, 5943, '\p{Is_Script_Extensions=tagalog}', "");
Expect(1, 5943, '\p{^Is_Script_Extensions=tagalog}', "");
Expect(1, 5943, '\P{Is_Script_Extensions=tagalog}', "");
Expect(0, 5943, '\P{^Is_Script_Extensions=tagalog}', "");
Expect(1, 5942, '\p{Is_Script_Extensions: -	Tagalog}', "");
Expect(0, 5942, '\p{^Is_Script_Extensions: -	Tagalog}', "");
Expect(0, 5942, '\P{Is_Script_Extensions: -	Tagalog}', "");
Expect(1, 5942, '\P{^Is_Script_Extensions: -	Tagalog}', "");
Expect(0, 5943, '\p{Is_Script_Extensions: -	Tagalog}', "");
Expect(1, 5943, '\p{^Is_Script_Extensions: -	Tagalog}', "");
Expect(1, 5943, '\P{Is_Script_Extensions: -	Tagalog}', "");
Expect(0, 5943, '\P{^Is_Script_Extensions: -	Tagalog}', "");
Error('\p{Is_Scx:	_tglg:=}');
Error('\P{Is_Scx:	_tglg:=}');
Expect(1, 5942, '\p{Is_Scx=tglg}', "");
Expect(0, 5942, '\p{^Is_Scx=tglg}', "");
Expect(0, 5942, '\P{Is_Scx=tglg}', "");
Expect(1, 5942, '\P{^Is_Scx=tglg}', "");
Expect(0, 5943, '\p{Is_Scx=tglg}', "");
Expect(1, 5943, '\p{^Is_Scx=tglg}', "");
Expect(1, 5943, '\P{Is_Scx=tglg}', "");
Expect(0, 5943, '\P{^Is_Scx=tglg}', "");
Expect(1, 5942, '\p{Is_Scx:- Tglg}', "");
Expect(0, 5942, '\p{^Is_Scx:- Tglg}', "");
Expect(0, 5942, '\P{Is_Scx:- Tglg}', "");
Expect(1, 5942, '\P{^Is_Scx:- Tglg}', "");
Expect(0, 5943, '\p{Is_Scx:- Tglg}', "");
Expect(1, 5943, '\p{^Is_Scx:- Tglg}', "");
Expect(1, 5943, '\P{Is_Scx:- Tglg}', "");
Expect(0, 5943, '\P{^Is_Scx:- Tglg}', "");
Error('\p{Script_Extensions=:=  Thaana}');
Error('\P{Script_Extensions=:=  Thaana}');
Expect(1, 65021, '\p{Script_Extensions=thaana}', "");
Expect(0, 65021, '\p{^Script_Extensions=thaana}', "");
Expect(0, 65021, '\P{Script_Extensions=thaana}', "");
Expect(1, 65021, '\P{^Script_Extensions=thaana}', "");
Expect(0, 65022, '\p{Script_Extensions=thaana}', "");
Expect(1, 65022, '\p{^Script_Extensions=thaana}', "");
Expect(1, 65022, '\P{Script_Extensions=thaana}', "");
Expect(0, 65022, '\P{^Script_Extensions=thaana}', "");
Expect(1, 65021, '\p{Script_Extensions= THAANA}', "");
Expect(0, 65021, '\p{^Script_Extensions= THAANA}', "");
Expect(0, 65021, '\P{Script_Extensions= THAANA}', "");
Expect(1, 65021, '\P{^Script_Extensions= THAANA}', "");
Expect(0, 65022, '\p{Script_Extensions= THAANA}', "");
Expect(1, 65022, '\p{^Script_Extensions= THAANA}', "");
Expect(1, 65022, '\P{Script_Extensions= THAANA}', "");
Expect(0, 65022, '\P{^Script_Extensions= THAANA}', "");
Error('\p{Scx=- Thaa/a/}');
Error('\P{Scx=- Thaa/a/}');
Expect(1, 65021, '\p{Scx=thaa}', "");
Expect(0, 65021, '\p{^Scx=thaa}', "");
Expect(0, 65021, '\P{Scx=thaa}', "");
Expect(1, 65021, '\P{^Scx=thaa}', "");
Expect(0, 65022, '\p{Scx=thaa}', "");
Expect(1, 65022, '\p{^Scx=thaa}', "");
Expect(1, 65022, '\P{Scx=thaa}', "");
Expect(0, 65022, '\P{^Scx=thaa}', "");
Expect(1, 65021, '\p{Scx= Thaa}', "");
Expect(0, 65021, '\p{^Scx= Thaa}', "");
Expect(0, 65021, '\P{Scx= Thaa}', "");
Expect(1, 65021, '\P{^Scx= Thaa}', "");
Expect(0, 65022, '\p{Scx= Thaa}', "");
Expect(1, 65022, '\p{^Scx= Thaa}', "");
Expect(1, 65022, '\P{Scx= Thaa}', "");
Expect(0, 65022, '\P{^Scx= Thaa}', "");
Error('\p{Is_Script_Extensions=/a/__thaana}');
Error('\P{Is_Script_Extensions=/a/__thaana}');
Expect(1, 65021, '\p{Is_Script_Extensions=thaana}', "");
Expect(0, 65021, '\p{^Is_Script_Extensions=thaana}', "");
Expect(0, 65021, '\P{Is_Script_Extensions=thaana}', "");
Expect(1, 65021, '\P{^Is_Script_Extensions=thaana}', "");
Expect(0, 65022, '\p{Is_Script_Extensions=thaana}', "");
Expect(1, 65022, '\p{^Is_Script_Extensions=thaana}', "");
Expect(1, 65022, '\P{Is_Script_Extensions=thaana}', "");
Expect(0, 65022, '\P{^Is_Script_Extensions=thaana}', "");
Expect(1, 65021, '\p{Is_Script_Extensions=	Thaana}', "");
Expect(0, 65021, '\p{^Is_Script_Extensions=	Thaana}', "");
Expect(0, 65021, '\P{Is_Script_Extensions=	Thaana}', "");
Expect(1, 65021, '\P{^Is_Script_Extensions=	Thaana}', "");
Expect(0, 65022, '\p{Is_Script_Extensions=	Thaana}', "");
Expect(1, 65022, '\p{^Is_Script_Extensions=	Thaana}', "");
Expect(1, 65022, '\P{Is_Script_Extensions=	Thaana}', "");
Expect(0, 65022, '\P{^Is_Script_Extensions=	Thaana}', "");
Error('\p{Is_Scx= Thaa/a/}');
Error('\P{Is_Scx= Thaa/a/}');
Expect(1, 65021, '\p{Is_Scx:	thaa}', "");
Expect(0, 65021, '\p{^Is_Scx:	thaa}', "");
Expect(0, 65021, '\P{Is_Scx:	thaa}', "");
Expect(1, 65021, '\P{^Is_Scx:	thaa}', "");
Expect(0, 65022, '\p{Is_Scx:	thaa}', "");
Expect(1, 65022, '\p{^Is_Scx:	thaa}', "");
Expect(1, 65022, '\P{Is_Scx:	thaa}', "");
Expect(0, 65022, '\P{^Is_Scx:	thaa}', "");
Expect(1, 65021, '\p{Is_Scx=_	Thaa}', "");
Expect(0, 65021, '\p{^Is_Scx=_	Thaa}', "");
Expect(0, 65021, '\P{Is_Scx=_	Thaa}', "");
Expect(1, 65021, '\P{^Is_Scx=_	Thaa}', "");
Expect(0, 65022, '\p{Is_Scx=_	Thaa}', "");
Expect(1, 65022, '\p{^Is_Scx=_	Thaa}', "");
Expect(1, 65022, '\P{Is_Scx=_	Thaa}', "");
Expect(0, 65022, '\P{^Is_Scx=_	Thaa}', "");
Error('\p{Script_Extensions=_:=THAI}');
Error('\P{Script_Extensions=_:=THAI}');
Expect(1, 3675, '\p{Script_Extensions=thai}', "");
Expect(0, 3675, '\p{^Script_Extensions=thai}', "");
Expect(0, 3675, '\P{Script_Extensions=thai}', "");
Expect(1, 3675, '\P{^Script_Extensions=thai}', "");
Expect(0, 3676, '\p{Script_Extensions=thai}', "");
Expect(1, 3676, '\p{^Script_Extensions=thai}', "");
Expect(1, 3676, '\P{Script_Extensions=thai}', "");
Expect(0, 3676, '\P{^Script_Extensions=thai}', "");
Expect(1, 3675, '\p{Script_Extensions=	_thai}', "");
Expect(0, 3675, '\p{^Script_Extensions=	_thai}', "");
Expect(0, 3675, '\P{Script_Extensions=	_thai}', "");
Expect(1, 3675, '\P{^Script_Extensions=	_thai}', "");
Expect(0, 3676, '\p{Script_Extensions=	_thai}', "");
Expect(1, 3676, '\p{^Script_Extensions=	_thai}', "");
Expect(1, 3676, '\P{Script_Extensions=	_thai}', "");
Expect(0, 3676, '\P{^Script_Extensions=	_thai}', "");
Error('\p{Scx=Thai/a/}');
Error('\P{Scx=Thai/a/}');
Expect(1, 3675, '\p{Scx=thai}', "");
Expect(0, 3675, '\p{^Scx=thai}', "");
Expect(0, 3675, '\P{Scx=thai}', "");
Expect(1, 3675, '\P{^Scx=thai}', "");
Expect(0, 3676, '\p{Scx=thai}', "");
Expect(1, 3676, '\p{^Scx=thai}', "");
Expect(1, 3676, '\P{Scx=thai}', "");
Expect(0, 3676, '\P{^Scx=thai}', "");
Expect(1, 3675, '\p{Scx=-_THAI}', "");
Expect(0, 3675, '\p{^Scx=-_THAI}', "");
Expect(0, 3675, '\P{Scx=-_THAI}', "");
Expect(1, 3675, '\P{^Scx=-_THAI}', "");
Expect(0, 3676, '\p{Scx=-_THAI}', "");
Expect(1, 3676, '\p{^Scx=-_THAI}', "");
Expect(1, 3676, '\P{Scx=-_THAI}', "");
Expect(0, 3676, '\P{^Scx=-_THAI}', "");
Error('\p{Is_Script_Extensions::=-Thai}');
Error('\P{Is_Script_Extensions::=-Thai}');
Expect(1, 3675, '\p{Is_Script_Extensions=thai}', "");
Expect(0, 3675, '\p{^Is_Script_Extensions=thai}', "");
Expect(0, 3675, '\P{Is_Script_Extensions=thai}', "");
Expect(1, 3675, '\P{^Is_Script_Extensions=thai}', "");
Expect(0, 3676, '\p{Is_Script_Extensions=thai}', "");
Expect(1, 3676, '\p{^Is_Script_Extensions=thai}', "");
Expect(1, 3676, '\P{Is_Script_Extensions=thai}', "");
Expect(0, 3676, '\P{^Is_Script_Extensions=thai}', "");
Expect(1, 3675, '\p{Is_Script_Extensions=	_THAI}', "");
Expect(0, 3675, '\p{^Is_Script_Extensions=	_THAI}', "");
Expect(0, 3675, '\P{Is_Script_Extensions=	_THAI}', "");
Expect(1, 3675, '\P{^Is_Script_Extensions=	_THAI}', "");
Expect(0, 3676, '\p{Is_Script_Extensions=	_THAI}', "");
Expect(1, 3676, '\p{^Is_Script_Extensions=	_THAI}', "");
Expect(1, 3676, '\P{Is_Script_Extensions=	_THAI}', "");
Expect(0, 3676, '\P{^Is_Script_Extensions=	_THAI}', "");
Error('\p{Is_Scx=/a/__THAI}');
Error('\P{Is_Scx=/a/__THAI}');
Expect(1, 3675, '\p{Is_Scx=thai}', "");
Expect(0, 3675, '\p{^Is_Scx=thai}', "");
Expect(0, 3675, '\P{Is_Scx=thai}', "");
Expect(1, 3675, '\P{^Is_Scx=thai}', "");
Expect(0, 3676, '\p{Is_Scx=thai}', "");
Expect(1, 3676, '\p{^Is_Scx=thai}', "");
Expect(1, 3676, '\P{Is_Scx=thai}', "");
Expect(0, 3676, '\P{^Is_Scx=thai}', "");
Expect(1, 3675, '\p{Is_Scx=-	THAI}', "");
Expect(0, 3675, '\p{^Is_Scx=-	THAI}', "");
Expect(0, 3675, '\P{Is_Scx=-	THAI}', "");
Expect(1, 3675, '\P{^Is_Scx=-	THAI}', "");
Expect(0, 3676, '\p{Is_Scx=-	THAI}', "");
Expect(1, 3676, '\p{^Is_Scx=-	THAI}', "");
Expect(1, 3676, '\P{Is_Scx=-	THAI}', "");
Expect(0, 3676, '\P{^Is_Scx=-	THAI}', "");
Error('\p{Script_Extensions=/a/	-Tibetan}');
Error('\P{Script_Extensions=/a/	-Tibetan}');
Expect(1, 4058, '\p{Script_Extensions=tibetan}', "");
Expect(0, 4058, '\p{^Script_Extensions=tibetan}', "");
Expect(0, 4058, '\P{Script_Extensions=tibetan}', "");
Expect(1, 4058, '\P{^Script_Extensions=tibetan}', "");
Expect(0, 4059, '\p{Script_Extensions=tibetan}', "");
Expect(1, 4059, '\p{^Script_Extensions=tibetan}', "");
Expect(1, 4059, '\P{Script_Extensions=tibetan}', "");
Expect(0, 4059, '\P{^Script_Extensions=tibetan}', "");
Expect(1, 4058, '\p{Script_Extensions=_-TIBETAN}', "");
Expect(0, 4058, '\p{^Script_Extensions=_-TIBETAN}', "");
Expect(0, 4058, '\P{Script_Extensions=_-TIBETAN}', "");
Expect(1, 4058, '\P{^Script_Extensions=_-TIBETAN}', "");
Expect(0, 4059, '\p{Script_Extensions=_-TIBETAN}', "");
Expect(1, 4059, '\p{^Script_Extensions=_-TIBETAN}', "");
Expect(1, 4059, '\P{Script_Extensions=_-TIBETAN}', "");
Expect(0, 4059, '\P{^Script_Extensions=_-TIBETAN}', "");
Error('\p{Scx:    -Tibt/a/}');
Error('\P{Scx:    -Tibt/a/}');
Expect(1, 4058, '\p{Scx=tibt}', "");
Expect(0, 4058, '\p{^Scx=tibt}', "");
Expect(0, 4058, '\P{Scx=tibt}', "");
Expect(1, 4058, '\P{^Scx=tibt}', "");
Expect(0, 4059, '\p{Scx=tibt}', "");
Expect(1, 4059, '\p{^Scx=tibt}', "");
Expect(1, 4059, '\P{Scx=tibt}', "");
Expect(0, 4059, '\P{^Scx=tibt}', "");
Expect(1, 4058, '\p{Scx= TIBT}', "");
Expect(0, 4058, '\p{^Scx= TIBT}', "");
Expect(0, 4058, '\P{Scx= TIBT}', "");
Expect(1, 4058, '\P{^Scx= TIBT}', "");
Expect(0, 4059, '\p{Scx= TIBT}', "");
Expect(1, 4059, '\p{^Scx= TIBT}', "");
Expect(1, 4059, '\P{Scx= TIBT}', "");
Expect(0, 4059, '\P{^Scx= TIBT}', "");
Error('\p{Is_Script_Extensions=:=TIBETAN}');
Error('\P{Is_Script_Extensions=:=TIBETAN}');
Expect(1, 4058, '\p{Is_Script_Extensions=tibetan}', "");
Expect(0, 4058, '\p{^Is_Script_Extensions=tibetan}', "");
Expect(0, 4058, '\P{Is_Script_Extensions=tibetan}', "");
Expect(1, 4058, '\P{^Is_Script_Extensions=tibetan}', "");
Expect(0, 4059, '\p{Is_Script_Extensions=tibetan}', "");
Expect(1, 4059, '\p{^Is_Script_Extensions=tibetan}', "");
Expect(1, 4059, '\P{Is_Script_Extensions=tibetan}', "");
Expect(0, 4059, '\P{^Is_Script_Extensions=tibetan}', "");
Expect(1, 4058, '\p{Is_Script_Extensions=	Tibetan}', "");
Expect(0, 4058, '\p{^Is_Script_Extensions=	Tibetan}', "");
Expect(0, 4058, '\P{Is_Script_Extensions=	Tibetan}', "");
Expect(1, 4058, '\P{^Is_Script_Extensions=	Tibetan}', "");
Expect(0, 4059, '\p{Is_Script_Extensions=	Tibetan}', "");
Expect(1, 4059, '\p{^Is_Script_Extensions=	Tibetan}', "");
Expect(1, 4059, '\P{Is_Script_Extensions=	Tibetan}', "");
Expect(0, 4059, '\P{^Is_Script_Extensions=	Tibetan}', "");
Error('\p{Is_Scx=/a/Tibt}');
Error('\P{Is_Scx=/a/Tibt}');
Expect(1, 4058, '\p{Is_Scx=tibt}', "");
Expect(0, 4058, '\p{^Is_Scx=tibt}', "");
Expect(0, 4058, '\P{Is_Scx=tibt}', "");
Expect(1, 4058, '\P{^Is_Scx=tibt}', "");
Expect(0, 4059, '\p{Is_Scx=tibt}', "");
Expect(1, 4059, '\p{^Is_Scx=tibt}', "");
Expect(1, 4059, '\P{Is_Scx=tibt}', "");
Expect(0, 4059, '\P{^Is_Scx=tibt}', "");
Expect(1, 4058, '\p{Is_Scx=- Tibt}', "");
Expect(0, 4058, '\p{^Is_Scx=- Tibt}', "");
Expect(0, 4058, '\P{Is_Scx=- Tibt}', "");
Expect(1, 4058, '\P{^Is_Scx=- Tibt}', "");
Expect(0, 4059, '\p{Is_Scx=- Tibt}', "");
Expect(1, 4059, '\p{^Is_Scx=- Tibt}', "");
Expect(1, 4059, '\P{Is_Scx=- Tibt}', "");
Expect(0, 4059, '\P{^Is_Scx=- Tibt}', "");
Error('\p{Script_Extensions=:=_	Ugaritic}');
Error('\P{Script_Extensions=:=_	Ugaritic}');
Expect(1, 66463, '\p{Script_Extensions=ugaritic}', "");
Expect(0, 66463, '\p{^Script_Extensions=ugaritic}', "");
Expect(0, 66463, '\P{Script_Extensions=ugaritic}', "");
Expect(1, 66463, '\P{^Script_Extensions=ugaritic}', "");
Expect(0, 66464, '\p{Script_Extensions=ugaritic}', "");
Expect(1, 66464, '\p{^Script_Extensions=ugaritic}', "");
Expect(1, 66464, '\P{Script_Extensions=ugaritic}', "");
Expect(0, 66464, '\P{^Script_Extensions=ugaritic}', "");
Expect(1, 66463, '\p{Script_Extensions=_-Ugaritic}', "");
Expect(0, 66463, '\p{^Script_Extensions=_-Ugaritic}', "");
Expect(0, 66463, '\P{Script_Extensions=_-Ugaritic}', "");
Expect(1, 66463, '\P{^Script_Extensions=_-Ugaritic}', "");
Expect(0, 66464, '\p{Script_Extensions=_-Ugaritic}', "");
Expect(1, 66464, '\p{^Script_Extensions=_-Ugaritic}', "");
Expect(1, 66464, '\P{Script_Extensions=_-Ugaritic}', "");
Expect(0, 66464, '\P{^Script_Extensions=_-Ugaritic}', "");
Error('\p{Scx=/a/__ugar}');
Error('\P{Scx=/a/__ugar}');
Expect(1, 66463, '\p{Scx: ugar}', "");
Expect(0, 66463, '\p{^Scx: ugar}', "");
Expect(0, 66463, '\P{Scx: ugar}', "");
Expect(1, 66463, '\P{^Scx: ugar}', "");
Expect(0, 66464, '\p{Scx: ugar}', "");
Expect(1, 66464, '\p{^Scx: ugar}', "");
Expect(1, 66464, '\P{Scx: ugar}', "");
Expect(0, 66464, '\P{^Scx: ugar}', "");
Expect(1, 66463, '\p{Scx= -UGAR}', "");
Expect(0, 66463, '\p{^Scx= -UGAR}', "");
Expect(0, 66463, '\P{Scx= -UGAR}', "");
Expect(1, 66463, '\P{^Scx= -UGAR}', "");
Expect(0, 66464, '\p{Scx= -UGAR}', "");
Expect(1, 66464, '\p{^Scx= -UGAR}', "");
Expect(1, 66464, '\P{Scx= -UGAR}', "");
Expect(0, 66464, '\P{^Scx= -UGAR}', "");
Error('\p{Is_Script_Extensions:-Ugaritic:=}');
Error('\P{Is_Script_Extensions:-Ugaritic:=}');
Expect(1, 66463, '\p{Is_Script_Extensions=ugaritic}', "");
Expect(0, 66463, '\p{^Is_Script_Extensions=ugaritic}', "");
Expect(0, 66463, '\P{Is_Script_Extensions=ugaritic}', "");
Expect(1, 66463, '\P{^Is_Script_Extensions=ugaritic}', "");
Expect(0, 66464, '\p{Is_Script_Extensions=ugaritic}', "");
Expect(1, 66464, '\p{^Is_Script_Extensions=ugaritic}', "");
Expect(1, 66464, '\P{Is_Script_Extensions=ugaritic}', "");
Expect(0, 66464, '\P{^Is_Script_Extensions=ugaritic}', "");
Error('\p{Is_Scx:    Ugar/a/}');
Error('\P{Is_Scx:    Ugar/a/}');
Expect(1, 66463, '\p{Is_Scx=ugar}', "");
Expect(0, 66463, '\p{^Is_Scx=ugar}', "");
Expect(0, 66463, '\P{Is_Scx=ugar}', "");
Expect(1, 66463, '\P{^Is_Scx=ugar}', "");
Expect(0, 66464, '\p{Is_Scx=ugar}', "");
Expect(1, 66464, '\p{^Is_Scx=ugar}', "");
Expect(1, 66464, '\P{Is_Scx=ugar}', "");
Expect(0, 66464, '\P{^Is_Scx=ugar}', "");
Expect(1, 66463, '\p{Is_Scx=	Ugar}', "");
Expect(0, 66463, '\p{^Is_Scx=	Ugar}', "");
Expect(0, 66463, '\P{Is_Scx=	Ugar}', "");
Expect(1, 66463, '\P{^Is_Scx=	Ugar}', "");
Expect(0, 66464, '\p{Is_Scx=	Ugar}', "");
Expect(1, 66464, '\p{^Is_Scx=	Ugar}', "");
Expect(1, 66464, '\P{Is_Scx=	Ugar}', "");
Expect(0, 66464, '\P{^Is_Scx=	Ugar}', "");
Error('\p{Script_Extensions=vai/a/}');
Error('\P{Script_Extensions=vai/a/}');
Expect(1, 42539, '\p{Script_Extensions=vai}', "");
Expect(0, 42539, '\p{^Script_Extensions=vai}', "");
Expect(0, 42539, '\P{Script_Extensions=vai}', "");
Expect(1, 42539, '\P{^Script_Extensions=vai}', "");
Expect(0, 42540, '\p{Script_Extensions=vai}', "");
Expect(1, 42540, '\p{^Script_Extensions=vai}', "");
Expect(1, 42540, '\P{Script_Extensions=vai}', "");
Expect(0, 42540, '\P{^Script_Extensions=vai}', "");
Expect(1, 42539, '\p{Script_Extensions=	 Vai}', "");
Expect(0, 42539, '\p{^Script_Extensions=	 Vai}', "");
Expect(0, 42539, '\P{Script_Extensions=	 Vai}', "");
Expect(1, 42539, '\P{^Script_Extensions=	 Vai}', "");
Expect(0, 42540, '\p{Script_Extensions=	 Vai}', "");
Expect(1, 42540, '\p{^Script_Extensions=	 Vai}', "");
Expect(1, 42540, '\P{Script_Extensions=	 Vai}', "");
Expect(0, 42540, '\P{^Script_Extensions=	 Vai}', "");
Error('\p{Scx=/a/	-Vaii}');
Error('\P{Scx=/a/	-Vaii}');
Expect(1, 42539, '\p{Scx=vaii}', "");
Expect(0, 42539, '\p{^Scx=vaii}', "");
Expect(0, 42539, '\P{Scx=vaii}', "");
Expect(1, 42539, '\P{^Scx=vaii}', "");
Expect(0, 42540, '\p{Scx=vaii}', "");
Expect(1, 42540, '\p{^Scx=vaii}', "");
Expect(1, 42540, '\P{Scx=vaii}', "");
Expect(0, 42540, '\P{^Scx=vaii}', "");
Expect(1, 42539, '\p{Scx= -vaii}', "");
Expect(0, 42539, '\p{^Scx= -vaii}', "");
Expect(0, 42539, '\P{Scx= -vaii}', "");
Expect(1, 42539, '\P{^Scx= -vaii}', "");
Expect(0, 42540, '\p{Scx= -vaii}', "");
Expect(1, 42540, '\p{^Scx= -vaii}', "");
Expect(1, 42540, '\P{Scx= -vaii}', "");
Expect(0, 42540, '\P{^Scx= -vaii}', "");
Error('\p{Is_Script_Extensions=/a/ 	Vai}');
Error('\P{Is_Script_Extensions=/a/ 	Vai}');
Expect(1, 42539, '\p{Is_Script_Extensions=vai}', "");
Expect(0, 42539, '\p{^Is_Script_Extensions=vai}', "");
Expect(0, 42539, '\P{Is_Script_Extensions=vai}', "");
Expect(1, 42539, '\P{^Is_Script_Extensions=vai}', "");
Expect(0, 42540, '\p{Is_Script_Extensions=vai}', "");
Expect(1, 42540, '\p{^Is_Script_Extensions=vai}', "");
Expect(1, 42540, '\P{Is_Script_Extensions=vai}', "");
Expect(0, 42540, '\P{^Is_Script_Extensions=vai}', "");
Expect(1, 42539, '\p{Is_Script_Extensions= Vai}', "");
Expect(0, 42539, '\p{^Is_Script_Extensions= Vai}', "");
Expect(0, 42539, '\P{Is_Script_Extensions= Vai}', "");
Expect(1, 42539, '\P{^Is_Script_Extensions= Vai}', "");
Expect(0, 42540, '\p{Is_Script_Extensions= Vai}', "");
Expect(1, 42540, '\p{^Is_Script_Extensions= Vai}', "");
Expect(1, 42540, '\P{Is_Script_Extensions= Vai}', "");
Expect(0, 42540, '\P{^Is_Script_Extensions= Vai}', "");
Error('\p{Is_Scx: --vaii:=}');
Error('\P{Is_Scx: --vaii:=}');
Expect(1, 42539, '\p{Is_Scx=vaii}', "");
Expect(0, 42539, '\p{^Is_Scx=vaii}', "");
Expect(0, 42539, '\P{Is_Scx=vaii}', "");
Expect(1, 42539, '\P{^Is_Scx=vaii}', "");
Expect(0, 42540, '\p{Is_Scx=vaii}', "");
Expect(1, 42540, '\p{^Is_Scx=vaii}', "");
Expect(1, 42540, '\P{Is_Scx=vaii}', "");
Expect(0, 42540, '\P{^Is_Scx=vaii}', "");
Expect(1, 42539, '\p{Is_Scx=-_vaii}', "");
Expect(0, 42539, '\p{^Is_Scx=-_vaii}', "");
Expect(0, 42539, '\P{Is_Scx=-_vaii}', "");
Expect(1, 42539, '\P{^Is_Scx=-_vaii}', "");
Expect(0, 42540, '\p{Is_Scx=-_vaii}', "");
Expect(1, 42540, '\p{^Is_Scx=-_vaii}', "");
Expect(1, 42540, '\P{Is_Scx=-_vaii}', "");
Expect(0, 42540, '\P{^Is_Scx=-_vaii}', "");
Error('\p{Script_Extensions=_/a/Old_Persian}');
Error('\P{Script_Extensions=_/a/Old_Persian}');
Expect(1, 66517, '\p{Script_Extensions=oldpersian}', "");
Expect(0, 66517, '\p{^Script_Extensions=oldpersian}', "");
Expect(0, 66517, '\P{Script_Extensions=oldpersian}', "");
Expect(1, 66517, '\P{^Script_Extensions=oldpersian}', "");
Expect(0, 66518, '\p{Script_Extensions=oldpersian}', "");
Expect(1, 66518, '\p{^Script_Extensions=oldpersian}', "");
Expect(1, 66518, '\P{Script_Extensions=oldpersian}', "");
Expect(0, 66518, '\P{^Script_Extensions=oldpersian}', "");
Expect(1, 66517, '\p{Script_Extensions=_	OLD_persian}', "");
Expect(0, 66517, '\p{^Script_Extensions=_	OLD_persian}', "");
Expect(0, 66517, '\P{Script_Extensions=_	OLD_persian}', "");
Expect(1, 66517, '\P{^Script_Extensions=_	OLD_persian}', "");
Expect(0, 66518, '\p{Script_Extensions=_	OLD_persian}', "");
Expect(1, 66518, '\p{^Script_Extensions=_	OLD_persian}', "");
Expect(1, 66518, '\P{Script_Extensions=_	OLD_persian}', "");
Expect(0, 66518, '\P{^Script_Extensions=_	OLD_persian}', "");
Error('\p{Scx=XPEO/a/}');
Error('\P{Scx=XPEO/a/}');
Expect(1, 66517, '\p{Scx=xpeo}', "");
Expect(0, 66517, '\p{^Scx=xpeo}', "");
Expect(0, 66517, '\P{Scx=xpeo}', "");
Expect(1, 66517, '\P{^Scx=xpeo}', "");
Expect(0, 66518, '\p{Scx=xpeo}', "");
Expect(1, 66518, '\p{^Scx=xpeo}', "");
Expect(1, 66518, '\P{Scx=xpeo}', "");
Expect(0, 66518, '\P{^Scx=xpeo}', "");
Expect(1, 66517, '\p{Scx= Xpeo}', "");
Expect(0, 66517, '\p{^Scx= Xpeo}', "");
Expect(0, 66517, '\P{Scx= Xpeo}', "");
Expect(1, 66517, '\P{^Scx= Xpeo}', "");
Expect(0, 66518, '\p{Scx= Xpeo}', "");
Expect(1, 66518, '\p{^Scx= Xpeo}', "");
Expect(1, 66518, '\P{Scx= Xpeo}', "");
Expect(0, 66518, '\P{^Scx= Xpeo}', "");
Error('\p{Is_Script_Extensions=/a/	Old_persian}');
Error('\P{Is_Script_Extensions=/a/	Old_persian}');
Expect(1, 66517, '\p{Is_Script_Extensions=oldpersian}', "");
Expect(0, 66517, '\p{^Is_Script_Extensions=oldpersian}', "");
Expect(0, 66517, '\P{Is_Script_Extensions=oldpersian}', "");
Expect(1, 66517, '\P{^Is_Script_Extensions=oldpersian}', "");
Expect(0, 66518, '\p{Is_Script_Extensions=oldpersian}', "");
Expect(1, 66518, '\p{^Is_Script_Extensions=oldpersian}', "");
Expect(1, 66518, '\P{Is_Script_Extensions=oldpersian}', "");
Expect(0, 66518, '\P{^Is_Script_Extensions=oldpersian}', "");
Expect(1, 66517, '\p{Is_Script_Extensions=__Old_Persian}', "");
Expect(0, 66517, '\p{^Is_Script_Extensions=__Old_Persian}', "");
Expect(0, 66517, '\P{Is_Script_Extensions=__Old_Persian}', "");
Expect(1, 66517, '\P{^Is_Script_Extensions=__Old_Persian}', "");
Expect(0, 66518, '\p{Is_Script_Extensions=__Old_Persian}', "");
Expect(1, 66518, '\p{^Is_Script_Extensions=__Old_Persian}', "");
Expect(1, 66518, '\P{Is_Script_Extensions=__Old_Persian}', "");
Expect(0, 66518, '\P{^Is_Script_Extensions=__Old_Persian}', "");
Error('\p{Is_Scx=/a/Xpeo}');
Error('\P{Is_Scx=/a/Xpeo}');
Expect(1, 66517, '\p{Is_Scx=xpeo}', "");
Expect(0, 66517, '\p{^Is_Scx=xpeo}', "");
Expect(0, 66517, '\P{Is_Scx=xpeo}', "");
Expect(1, 66517, '\P{^Is_Scx=xpeo}', "");
Expect(0, 66518, '\p{Is_Scx=xpeo}', "");
Expect(1, 66518, '\p{^Is_Scx=xpeo}', "");
Expect(1, 66518, '\P{Is_Scx=xpeo}', "");
Expect(0, 66518, '\P{^Is_Scx=xpeo}', "");
Expect(1, 66517, '\p{Is_Scx=	Xpeo}', "");
Expect(0, 66517, '\p{^Is_Scx=	Xpeo}', "");
Expect(0, 66517, '\P{Is_Scx=	Xpeo}', "");
Expect(1, 66517, '\P{^Is_Scx=	Xpeo}', "");
Expect(0, 66518, '\p{Is_Scx=	Xpeo}', "");
Expect(1, 66518, '\p{^Is_Scx=	Xpeo}', "");
Expect(1, 66518, '\P{Is_Scx=	Xpeo}', "");
Expect(0, 66518, '\P{^Is_Scx=	Xpeo}', "");
Error('\p{Script_Extensions=-	CUNEIFORM:=}');
Error('\P{Script_Extensions=-	CUNEIFORM:=}');
Expect(1, 74867, '\p{Script_Extensions=cuneiform}', "");
Expect(0, 74867, '\p{^Script_Extensions=cuneiform}', "");
Expect(0, 74867, '\P{Script_Extensions=cuneiform}', "");
Expect(1, 74867, '\P{^Script_Extensions=cuneiform}', "");
Expect(0, 74868, '\p{Script_Extensions=cuneiform}', "");
Expect(1, 74868, '\p{^Script_Extensions=cuneiform}', "");
Expect(1, 74868, '\P{Script_Extensions=cuneiform}', "");
Expect(0, 74868, '\P{^Script_Extensions=cuneiform}', "");
Expect(1, 74867, '\p{Script_Extensions=-Cuneiform}', "");
Expect(0, 74867, '\p{^Script_Extensions=-Cuneiform}', "");
Expect(0, 74867, '\P{Script_Extensions=-Cuneiform}', "");
Expect(1, 74867, '\P{^Script_Extensions=-Cuneiform}', "");
Expect(0, 74868, '\p{Script_Extensions=-Cuneiform}', "");
Expect(1, 74868, '\p{^Script_Extensions=-Cuneiform}', "");
Expect(1, 74868, '\P{Script_Extensions=-Cuneiform}', "");
Expect(0, 74868, '\P{^Script_Extensions=-Cuneiform}', "");
Error('\p{Scx= _XSUX:=}');
Error('\P{Scx= _XSUX:=}');
Expect(1, 74867, '\p{Scx=xsux}', "");
Expect(0, 74867, '\p{^Scx=xsux}', "");
Expect(0, 74867, '\P{Scx=xsux}', "");
Expect(1, 74867, '\P{^Scx=xsux}', "");
Expect(0, 74868, '\p{Scx=xsux}', "");
Expect(1, 74868, '\p{^Scx=xsux}', "");
Expect(1, 74868, '\P{Scx=xsux}', "");
Expect(0, 74868, '\P{^Scx=xsux}', "");
Expect(1, 74867, '\p{Scx=_ Xsux}', "");
Expect(0, 74867, '\p{^Scx=_ Xsux}', "");
Expect(0, 74867, '\P{Scx=_ Xsux}', "");
Expect(1, 74867, '\P{^Scx=_ Xsux}', "");
Expect(0, 74868, '\p{Scx=_ Xsux}', "");
Expect(1, 74868, '\p{^Scx=_ Xsux}', "");
Expect(1, 74868, '\P{Scx=_ Xsux}', "");
Expect(0, 74868, '\P{^Scx=_ Xsux}', "");
Error('\p{Is_Script_Extensions=	:=CUNEIFORM}');
Error('\P{Is_Script_Extensions=	:=CUNEIFORM}');
Expect(1, 74867, '\p{Is_Script_Extensions: cuneiform}', "");
Expect(0, 74867, '\p{^Is_Script_Extensions: cuneiform}', "");
Expect(0, 74867, '\P{Is_Script_Extensions: cuneiform}', "");
Expect(1, 74867, '\P{^Is_Script_Extensions: cuneiform}', "");
Expect(0, 74868, '\p{Is_Script_Extensions: cuneiform}', "");
Expect(1, 74868, '\p{^Is_Script_Extensions: cuneiform}', "");
Expect(1, 74868, '\P{Is_Script_Extensions: cuneiform}', "");
Expect(0, 74868, '\P{^Is_Script_Extensions: cuneiform}', "");
Expect(1, 74867, '\p{Is_Script_Extensions:    Cuneiform}', "");
Expect(0, 74867, '\p{^Is_Script_Extensions:    Cuneiform}', "");
Expect(0, 74867, '\P{Is_Script_Extensions:    Cuneiform}', "");
Expect(1, 74867, '\P{^Is_Script_Extensions:    Cuneiform}', "");
Expect(0, 74868, '\p{Is_Script_Extensions:    Cuneiform}', "");
Expect(1, 74868, '\p{^Is_Script_Extensions:    Cuneiform}', "");
Expect(1, 74868, '\P{Is_Script_Extensions:    Cuneiform}', "");
Expect(0, 74868, '\P{^Is_Script_Extensions:    Cuneiform}', "");
Error('\p{Is_Scx=  XSUX/a/}');
Error('\P{Is_Scx=  XSUX/a/}');
Expect(1, 74867, '\p{Is_Scx=xsux}', "");
Expect(0, 74867, '\p{^Is_Scx=xsux}', "");
Expect(0, 74867, '\P{Is_Scx=xsux}', "");
Expect(1, 74867, '\P{^Is_Scx=xsux}', "");
Expect(0, 74868, '\p{Is_Scx=xsux}', "");
Expect(1, 74868, '\p{^Is_Scx=xsux}', "");
Expect(1, 74868, '\P{Is_Scx=xsux}', "");
Expect(0, 74868, '\P{^Is_Scx=xsux}', "");
Expect(1, 74867, '\p{Is_Scx=_Xsux}', "");
Expect(0, 74867, '\p{^Is_Scx=_Xsux}', "");
Expect(0, 74867, '\P{Is_Scx=_Xsux}', "");
Expect(1, 74867, '\P{^Is_Scx=_Xsux}', "");
Expect(0, 74868, '\p{Is_Scx=_Xsux}', "");
Expect(1, 74868, '\p{^Is_Scx=_Xsux}', "");
Expect(1, 74868, '\P{Is_Scx=_Xsux}', "");
Expect(0, 74868, '\P{^Is_Scx=_Xsux}', "");
Error('\p{Script_Extensions=_/a/Yi}');
Error('\P{Script_Extensions=_/a/Yi}');
Expect(1, 65381, '\p{Script_Extensions=yi}', "");
Expect(0, 65381, '\p{^Script_Extensions=yi}', "");
Expect(0, 65381, '\P{Script_Extensions=yi}', "");
Expect(1, 65381, '\P{^Script_Extensions=yi}', "");
Expect(0, 65382, '\p{Script_Extensions=yi}', "");
Expect(1, 65382, '\p{^Script_Extensions=yi}', "");
Expect(1, 65382, '\P{Script_Extensions=yi}', "");
Expect(0, 65382, '\P{^Script_Extensions=yi}', "");
Expect(1, 65381, '\p{Script_Extensions=-	Yi}', "");
Expect(0, 65381, '\p{^Script_Extensions=-	Yi}', "");
Expect(0, 65381, '\P{Script_Extensions=-	Yi}', "");
Expect(1, 65381, '\P{^Script_Extensions=-	Yi}', "");
Expect(0, 65382, '\p{Script_Extensions=-	Yi}', "");
Expect(1, 65382, '\p{^Script_Extensions=-	Yi}', "");
Expect(1, 65382, '\P{Script_Extensions=-	Yi}', "");
Expect(0, 65382, '\P{^Script_Extensions=-	Yi}', "");
Error('\p{Scx=/a/_	YIII}');
Error('\P{Scx=/a/_	YIII}');
Expect(1, 65381, '\p{Scx=yiii}', "");
Expect(0, 65381, '\p{^Scx=yiii}', "");
Expect(0, 65381, '\P{Scx=yiii}', "");
Expect(1, 65381, '\P{^Scx=yiii}', "");
Expect(0, 65382, '\p{Scx=yiii}', "");
Expect(1, 65382, '\p{^Scx=yiii}', "");
Expect(1, 65382, '\P{Scx=yiii}', "");
Expect(0, 65382, '\P{^Scx=yiii}', "");
Expect(1, 65381, '\p{Scx=- YIII}', "");
Expect(0, 65381, '\p{^Scx=- YIII}', "");
Expect(0, 65381, '\P{Scx=- YIII}', "");
Expect(1, 65381, '\P{^Scx=- YIII}', "");
Expect(0, 65382, '\p{Scx=- YIII}', "");
Expect(1, 65382, '\p{^Scx=- YIII}', "");
Expect(1, 65382, '\P{Scx=- YIII}', "");
Expect(0, 65382, '\P{^Scx=- YIII}', "");
Error('\p{Is_Script_Extensions=/a/YI}');
Error('\P{Is_Script_Extensions=/a/YI}');
Expect(1, 65381, '\p{Is_Script_Extensions=yi}', "");
Expect(0, 65381, '\p{^Is_Script_Extensions=yi}', "");
Expect(0, 65381, '\P{Is_Script_Extensions=yi}', "");
Expect(1, 65381, '\P{^Is_Script_Extensions=yi}', "");
Expect(0, 65382, '\p{Is_Script_Extensions=yi}', "");
Expect(1, 65382, '\p{^Is_Script_Extensions=yi}', "");
Expect(1, 65382, '\P{Is_Script_Extensions=yi}', "");
Expect(0, 65382, '\P{^Is_Script_Extensions=yi}', "");
Expect(1, 65381, '\p{Is_Script_Extensions=_YI}', "");
Expect(0, 65381, '\p{^Is_Script_Extensions=_YI}', "");
Expect(0, 65381, '\P{Is_Script_Extensions=_YI}', "");
Expect(1, 65381, '\P{^Is_Script_Extensions=_YI}', "");
Expect(0, 65382, '\p{Is_Script_Extensions=_YI}', "");
Expect(1, 65382, '\p{^Is_Script_Extensions=_YI}', "");
Expect(1, 65382, '\P{Is_Script_Extensions=_YI}', "");
Expect(0, 65382, '\P{^Is_Script_Extensions=_YI}', "");
Error('\p{Is_Scx=	/a/Yiii}');
Error('\P{Is_Scx=	/a/Yiii}');
Expect(1, 65381, '\p{Is_Scx=yiii}', "");
Expect(0, 65381, '\p{^Is_Scx=yiii}', "");
Expect(0, 65381, '\P{Is_Scx=yiii}', "");
Expect(1, 65381, '\P{^Is_Scx=yiii}', "");
Expect(0, 65382, '\p{Is_Scx=yiii}', "");
Expect(1, 65382, '\p{^Is_Scx=yiii}', "");
Expect(1, 65382, '\P{Is_Scx=yiii}', "");
Expect(0, 65382, '\P{^Is_Scx=yiii}', "");
Expect(1, 65381, '\p{Is_Scx=-	yiii}', "");
Expect(0, 65381, '\p{^Is_Scx=-	yiii}', "");
Expect(0, 65381, '\P{Is_Scx=-	yiii}', "");
Expect(1, 65381, '\P{^Is_Scx=-	yiii}', "");
Expect(0, 65382, '\p{Is_Scx=-	yiii}', "");
Expect(1, 65382, '\p{^Is_Scx=-	yiii}', "");
Expect(1, 65382, '\P{Is_Scx=-	yiii}', "");
Expect(0, 65382, '\P{^Is_Scx=-	yiii}', "");
Error('\p{Script_Extensions:	:=Inherited}');
Error('\P{Script_Extensions:	:=Inherited}');
Expect(1, 917999, '\p{Script_Extensions=inherited}', "");
Expect(0, 917999, '\p{^Script_Extensions=inherited}', "");
Expect(0, 917999, '\P{Script_Extensions=inherited}', "");
Expect(1, 917999, '\P{^Script_Extensions=inherited}', "");
Expect(0, 918000, '\p{Script_Extensions=inherited}', "");
Expect(1, 918000, '\p{^Script_Extensions=inherited}', "");
Expect(1, 918000, '\P{Script_Extensions=inherited}', "");
Expect(0, 918000, '\P{^Script_Extensions=inherited}', "");
Expect(1, 917999, '\p{Script_Extensions:_ inherited}', "");
Expect(0, 917999, '\p{^Script_Extensions:_ inherited}', "");
Expect(0, 917999, '\P{Script_Extensions:_ inherited}', "");
Expect(1, 917999, '\P{^Script_Extensions:_ inherited}', "");
Expect(0, 918000, '\p{Script_Extensions:_ inherited}', "");
Expect(1, 918000, '\p{^Script_Extensions:_ inherited}', "");
Expect(1, 918000, '\P{Script_Extensions:_ inherited}', "");
Expect(0, 918000, '\P{^Script_Extensions:_ inherited}', "");
Error('\p{Scx:--zinh:=}');
Error('\P{Scx:--zinh:=}');
Expect(1, 917999, '\p{Scx: zinh}', "");
Expect(0, 917999, '\p{^Scx: zinh}', "");
Expect(0, 917999, '\P{Scx: zinh}', "");
Expect(1, 917999, '\P{^Scx: zinh}', "");
Expect(0, 918000, '\p{Scx: zinh}', "");
Expect(1, 918000, '\p{^Scx: zinh}', "");
Expect(1, 918000, '\P{Scx: zinh}', "");
Expect(0, 918000, '\P{^Scx: zinh}', "");
Expect(1, 917999, '\p{Scx=  zinh}', "");
Expect(0, 917999, '\p{^Scx=  zinh}', "");
Expect(0, 917999, '\P{Scx=  zinh}', "");
Expect(1, 917999, '\P{^Scx=  zinh}', "");
Expect(0, 918000, '\p{Scx=  zinh}', "");
Expect(1, 918000, '\p{^Scx=  zinh}', "");
Expect(1, 918000, '\P{Scx=  zinh}', "");
Expect(0, 918000, '\P{^Scx=  zinh}', "");
Error('\p{Is_Script_Extensions=/a/_QAAI}');
Error('\P{Is_Script_Extensions=/a/_QAAI}');
Expect(1, 917999, '\p{Is_Script_Extensions=qaai}', "");
Expect(0, 917999, '\p{^Is_Script_Extensions=qaai}', "");
Expect(0, 917999, '\P{Is_Script_Extensions=qaai}', "");
Expect(1, 917999, '\P{^Is_Script_Extensions=qaai}', "");
Expect(0, 918000, '\p{Is_Script_Extensions=qaai}', "");
Expect(1, 918000, '\p{^Is_Script_Extensions=qaai}', "");
Expect(1, 918000, '\P{Is_Script_Extensions=qaai}', "");
Expect(0, 918000, '\P{^Is_Script_Extensions=qaai}', "");
Expect(1, 917999, '\p{Is_Script_Extensions=	_qaai}', "");
Expect(0, 917999, '\p{^Is_Script_Extensions=	_qaai}', "");
Expect(0, 917999, '\P{Is_Script_Extensions=	_qaai}', "");
Expect(1, 917999, '\P{^Is_Script_Extensions=	_qaai}', "");
Expect(0, 918000, '\p{Is_Script_Extensions=	_qaai}', "");
Expect(1, 918000, '\p{^Is_Script_Extensions=	_qaai}', "");
Expect(1, 918000, '\P{Is_Script_Extensions=	_qaai}', "");
Expect(0, 918000, '\P{^Is_Script_Extensions=	_qaai}', "");
Error('\p{Is_Scx=/a/INHERITED}');
Error('\P{Is_Scx=/a/INHERITED}');
Expect(1, 917999, '\p{Is_Scx=inherited}', "");
Expect(0, 917999, '\p{^Is_Scx=inherited}', "");
Expect(0, 917999, '\P{Is_Scx=inherited}', "");
Expect(1, 917999, '\P{^Is_Scx=inherited}', "");
Expect(0, 918000, '\p{Is_Scx=inherited}', "");
Expect(1, 918000, '\p{^Is_Scx=inherited}', "");
Expect(1, 918000, '\P{Is_Scx=inherited}', "");
Expect(0, 918000, '\P{^Is_Scx=inherited}', "");
Expect(1, 917999, '\p{Is_Scx=-INHERITED}', "");
Expect(0, 917999, '\p{^Is_Scx=-INHERITED}', "");
Expect(0, 917999, '\P{Is_Scx=-INHERITED}', "");
Expect(1, 917999, '\P{^Is_Scx=-INHERITED}', "");
Expect(0, 918000, '\p{Is_Scx=-INHERITED}', "");
Expect(1, 918000, '\p{^Is_Scx=-INHERITED}', "");
Expect(1, 918000, '\P{Is_Scx=-INHERITED}', "");
Expect(0, 918000, '\P{^Is_Scx=-INHERITED}', "");
Error('\p{Script_Extensions=	 Common:=}');
Error('\P{Script_Extensions=	 Common:=}');
Expect(1, 917631, '\p{Script_Extensions=common}', "");
Expect(0, 917631, '\p{^Script_Extensions=common}', "");
Expect(0, 917631, '\P{Script_Extensions=common}', "");
Expect(1, 917631, '\P{^Script_Extensions=common}', "");
Expect(0, 917632, '\p{Script_Extensions=common}', "");
Expect(1, 917632, '\p{^Script_Extensions=common}', "");
Expect(1, 917632, '\P{Script_Extensions=common}', "");
Expect(0, 917632, '\P{^Script_Extensions=common}', "");
Expect(1, 917631, '\p{Script_Extensions:	 common}', "");
Expect(0, 917631, '\p{^Script_Extensions:	 common}', "");
Expect(0, 917631, '\P{Script_Extensions:	 common}', "");
Expect(1, 917631, '\P{^Script_Extensions:	 common}', "");
Expect(0, 917632, '\p{Script_Extensions:	 common}', "");
Expect(1, 917632, '\p{^Script_Extensions:	 common}', "");
Expect(1, 917632, '\P{Script_Extensions:	 common}', "");
Expect(0, 917632, '\P{^Script_Extensions:	 common}', "");
Error('\p{Scx=- Zyyy/a/}');
Error('\P{Scx=- Zyyy/a/}');
Expect(1, 917631, '\p{Scx=zyyy}', "");
Expect(0, 917631, '\p{^Scx=zyyy}', "");
Expect(0, 917631, '\P{Scx=zyyy}', "");
Expect(1, 917631, '\P{^Scx=zyyy}', "");
Expect(0, 917632, '\p{Scx=zyyy}', "");
Expect(1, 917632, '\p{^Scx=zyyy}', "");
Expect(1, 917632, '\P{Scx=zyyy}', "");
Expect(0, 917632, '\P{^Scx=zyyy}', "");
Expect(1, 917631, '\p{Scx=ZYYY}', "");
Expect(0, 917631, '\p{^Scx=ZYYY}', "");
Expect(0, 917631, '\P{Scx=ZYYY}', "");
Expect(1, 917631, '\P{^Scx=ZYYY}', "");
Expect(0, 917632, '\p{Scx=ZYYY}', "");
Expect(1, 917632, '\p{^Scx=ZYYY}', "");
Expect(1, 917632, '\P{Scx=ZYYY}', "");
Expect(0, 917632, '\P{^Scx=ZYYY}', "");
Error('\p{Is_Script_Extensions:	 Common:=}');
Error('\P{Is_Script_Extensions:	 Common:=}');
Expect(1, 917631, '\p{Is_Script_Extensions=common}', "");
Expect(0, 917631, '\p{^Is_Script_Extensions=common}', "");
Expect(0, 917631, '\P{Is_Script_Extensions=common}', "");
Expect(1, 917631, '\P{^Is_Script_Extensions=common}', "");
Expect(0, 917632, '\p{Is_Script_Extensions=common}', "");
Expect(1, 917632, '\p{^Is_Script_Extensions=common}', "");
Expect(1, 917632, '\P{Is_Script_Extensions=common}', "");
Expect(0, 917632, '\P{^Is_Script_Extensions=common}', "");
Expect(1, 917631, '\p{Is_Script_Extensions=-common}', "");
Expect(0, 917631, '\p{^Is_Script_Extensions=-common}', "");
Expect(0, 917631, '\P{Is_Script_Extensions=-common}', "");
Expect(1, 917631, '\P{^Is_Script_Extensions=-common}', "");
Expect(0, 917632, '\p{Is_Script_Extensions=-common}', "");
Expect(1, 917632, '\p{^Is_Script_Extensions=-common}', "");
Expect(1, 917632, '\P{Is_Script_Extensions=-common}', "");
Expect(0, 917632, '\P{^Is_Script_Extensions=-common}', "");
Error('\p{Is_Scx:   :=-_Zyyy}');
Error('\P{Is_Scx:   :=-_Zyyy}');
Expect(1, 917631, '\p{Is_Scx=zyyy}', "");
Expect(0, 917631, '\p{^Is_Scx=zyyy}', "");
Expect(0, 917631, '\P{Is_Scx=zyyy}', "");
Expect(1, 917631, '\P{^Is_Scx=zyyy}', "");
Expect(0, 917632, '\p{Is_Scx=zyyy}', "");
Expect(1, 917632, '\p{^Is_Scx=zyyy}', "");
Expect(1, 917632, '\P{Is_Scx=zyyy}', "");
Expect(0, 917632, '\P{^Is_Scx=zyyy}', "");
Expect(1, 917631, '\p{Is_Scx=	Zyyy}', "");
Expect(0, 917631, '\p{^Is_Scx=	Zyyy}', "");
Expect(0, 917631, '\P{Is_Scx=	Zyyy}', "");
Expect(1, 917631, '\P{^Is_Scx=	Zyyy}', "");
Expect(0, 917632, '\p{Is_Scx=	Zyyy}', "");
Expect(1, 917632, '\p{^Is_Scx=	Zyyy}', "");
Expect(1, 917632, '\P{Is_Scx=	Zyyy}', "");
Expect(0, 917632, '\P{^Is_Scx=	Zyyy}', "");
Error('\p{Script_Extensions= :=Unknown}');
Error('\P{Script_Extensions= :=Unknown}');
Expect(1, 918000, '\p{Script_Extensions=unknown}', "");
Expect(0, 918000, '\p{^Script_Extensions=unknown}', "");
Expect(0, 918000, '\P{Script_Extensions=unknown}', "");
Expect(1, 918000, '\P{^Script_Extensions=unknown}', "");
Expect(0, 917999, '\p{Script_Extensions=unknown}', "");
Expect(1, 917999, '\p{^Script_Extensions=unknown}', "");
Expect(1, 917999, '\P{Script_Extensions=unknown}', "");
Expect(0, 917999, '\P{^Script_Extensions=unknown}', "");
Expect(1, 918000, '\p{Script_Extensions:   	_Unknown}', "");
Expect(0, 918000, '\p{^Script_Extensions:   	_Unknown}', "");
Expect(0, 918000, '\P{Script_Extensions:   	_Unknown}', "");
Expect(1, 918000, '\P{^Script_Extensions:   	_Unknown}', "");
Expect(0, 917999, '\p{Script_Extensions:   	_Unknown}', "");
Expect(1, 917999, '\p{^Script_Extensions:   	_Unknown}', "");
Expect(1, 917999, '\P{Script_Extensions:   	_Unknown}', "");
Expect(0, 917999, '\P{^Script_Extensions:   	_Unknown}', "");
Error('\p{Scx: :=  Zzzz}');
Error('\P{Scx: :=  Zzzz}');
Expect(1, 918000, '\p{Scx=zzzz}', "");
Expect(0, 918000, '\p{^Scx=zzzz}', "");
Expect(0, 918000, '\P{Scx=zzzz}', "");
Expect(1, 918000, '\P{^Scx=zzzz}', "");
Expect(0, 917999, '\p{Scx=zzzz}', "");
Expect(1, 917999, '\p{^Scx=zzzz}', "");
Expect(1, 917999, '\P{Scx=zzzz}', "");
Expect(0, 917999, '\P{^Scx=zzzz}', "");
Expect(1, 918000, '\p{Scx=	 Zzzz}', "");
Expect(0, 918000, '\p{^Scx=	 Zzzz}', "");
Expect(0, 918000, '\P{Scx=	 Zzzz}', "");
Expect(1, 918000, '\P{^Scx=	 Zzzz}', "");
Expect(0, 917999, '\p{Scx=	 Zzzz}', "");
Expect(1, 917999, '\p{^Scx=	 Zzzz}', "");
Expect(1, 917999, '\P{Scx=	 Zzzz}', "");
Expect(0, 917999, '\P{^Scx=	 Zzzz}', "");
Error('\p{Is_Script_Extensions=/a/--UNKNOWN}');
Error('\P{Is_Script_Extensions=/a/--UNKNOWN}');
Expect(1, 918000, '\p{Is_Script_Extensions=unknown}', "");
Expect(0, 918000, '\p{^Is_Script_Extensions=unknown}', "");
Expect(0, 918000, '\P{Is_Script_Extensions=unknown}', "");
Expect(1, 918000, '\P{^Is_Script_Extensions=unknown}', "");
Expect(0, 917999, '\p{Is_Script_Extensions=unknown}', "");
Expect(1, 917999, '\p{^Is_Script_Extensions=unknown}', "");
Expect(1, 917999, '\P{Is_Script_Extensions=unknown}', "");
Expect(0, 917999, '\P{^Is_Script_Extensions=unknown}', "");
Expect(1, 918000, '\p{Is_Script_Extensions=-Unknown}', "");
Expect(0, 918000, '\p{^Is_Script_Extensions=-Unknown}', "");
Expect(0, 918000, '\P{Is_Script_Extensions=-Unknown}', "");
Expect(1, 918000, '\P{^Is_Script_Extensions=-Unknown}', "");
Expect(0, 917999, '\p{Is_Script_Extensions=-Unknown}', "");
Expect(1, 917999, '\p{^Is_Script_Extensions=-Unknown}', "");
Expect(1, 917999, '\P{Is_Script_Extensions=-Unknown}', "");
Expect(0, 917999, '\P{^Is_Script_Extensions=-Unknown}', "");
Error('\p{Is_Scx=- zzzz/a/}');
Error('\P{Is_Scx=- zzzz/a/}');
Expect(1, 918000, '\p{Is_Scx=zzzz}', "");
Expect(0, 918000, '\p{^Is_Scx=zzzz}', "");
Expect(0, 918000, '\P{Is_Scx=zzzz}', "");
Expect(1, 918000, '\P{^Is_Scx=zzzz}', "");
Expect(0, 917999, '\p{Is_Scx=zzzz}', "");
Expect(1, 917999, '\p{^Is_Scx=zzzz}', "");
Expect(1, 917999, '\P{Is_Scx=zzzz}', "");
Expect(0, 917999, '\P{^Is_Scx=zzzz}', "");
Expect(1, 918000, '\p{Is_Scx=	ZZZZ}', "");
Expect(0, 918000, '\p{^Is_Scx=	ZZZZ}', "");
Expect(0, 918000, '\P{Is_Scx=	ZZZZ}', "");
Expect(1, 918000, '\P{^Is_Scx=	ZZZZ}', "");
Expect(0, 917999, '\p{Is_Scx=	ZZZZ}', "");
Expect(1, 917999, '\p{^Is_Scx=	ZZZZ}', "");
Expect(1, 917999, '\P{Is_Scx=	ZZZZ}', "");
Expect(0, 917999, '\P{^Is_Scx=	ZZZZ}', "");
Test_X('÷ 0020 ÷ 0020 ÷');
Test_X('÷ 0020 × 0308 ÷ 0020 ÷');
Test_X('÷ 0020 ÷ 000D ÷');
Test_X('÷ 0020 × 0308 ÷ 000D ÷');
Test_X('÷ 0020 ÷ 000A ÷');
Test_X('÷ 0020 × 0308 ÷ 000A ÷');
Test_X('÷ 0020 ÷ 0001 ÷');
Test_X('÷ 0020 × 0308 ÷ 0001 ÷');
Test_X('÷ 0020 × 0300 ÷');
Test_X('÷ 0020 × 0308 × 0300 ÷');
Test_X('÷ 0020 × 0903 ÷');
Test_X('÷ 0020 × 0308 × 0903 ÷');
Test_X('÷ 0020 ÷ 1100 ÷');
Test_X('÷ 0020 × 0308 ÷ 1100 ÷');
Test_X('÷ 0020 ÷ 1160 ÷');
Test_X('÷ 0020 × 0308 ÷ 1160 ÷');
Test_X('÷ 0020 ÷ 11A8 ÷');
Test_X('÷ 0020 × 0308 ÷ 11A8 ÷');
Test_X('÷ 0020 ÷ AC00 ÷');
Test_X('÷ 0020 × 0308 ÷ AC00 ÷');
Test_X('÷ 0020 ÷ AC01 ÷');
Test_X('÷ 0020 × 0308 ÷ AC01 ÷');
Test_X('÷ 0020 ÷ 1F1E6 ÷');
Test_X('÷ 0020 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ 0020 ÷ 0378 ÷');
Test_X('÷ 0020 × 0308 ÷ 0378 ÷');
Test_X('÷ 0020 ÷ D800 ÷');
Test_X('÷ 0020 × 0308 ÷ D800 ÷');
Test_X('÷ 000D ÷ 0020 ÷');
Test_X('÷ 000D ÷ 0308 ÷ 0020 ÷');
Test_X('÷ 000D ÷ 000D ÷');
Test_X('÷ 000D ÷ 0308 ÷ 000D ÷');
Test_X('÷ 000D × 000A ÷');
Test_X('÷ 000D ÷ 0308 ÷ 000A ÷');
Test_X('÷ 000D ÷ 0001 ÷');
Test_X('÷ 000D ÷ 0308 ÷ 0001 ÷');
Test_X('÷ 000D ÷ 0300 ÷');
Test_X('÷ 000D ÷ 0308 × 0300 ÷');
Test_X('÷ 000D ÷ 0903 ÷');
Test_X('÷ 000D ÷ 0308 × 0903 ÷');
Test_X('÷ 000D ÷ 1100 ÷');
Test_X('÷ 000D ÷ 0308 ÷ 1100 ÷');
Test_X('÷ 000D ÷ 1160 ÷');
Test_X('÷ 000D ÷ 0308 ÷ 1160 ÷');
Test_X('÷ 000D ÷ 11A8 ÷');
Test_X('÷ 000D ÷ 0308 ÷ 11A8 ÷');
Test_X('÷ 000D ÷ AC00 ÷');
Test_X('÷ 000D ÷ 0308 ÷ AC00 ÷');
Test_X('÷ 000D ÷ AC01 ÷');
Test_X('÷ 000D ÷ 0308 ÷ AC01 ÷');
Test_X('÷ 000D ÷ 1F1E6 ÷');
Test_X('÷ 000D ÷ 0308 ÷ 1F1E6 ÷');
Test_X('÷ 000D ÷ 0378 ÷');
Test_X('÷ 000D ÷ 0308 ÷ 0378 ÷');
Test_X('÷ 000D ÷ D800 ÷');
Test_X('÷ 000D ÷ 0308 ÷ D800 ÷');
Test_X('÷ 000A ÷ 0020 ÷');
Test_X('÷ 000A ÷ 0308 ÷ 0020 ÷');
Test_X('÷ 000A ÷ 000D ÷');
Test_X('÷ 000A ÷ 0308 ÷ 000D ÷');
Test_X('÷ 000A ÷ 000A ÷');
Test_X('÷ 000A ÷ 0308 ÷ 000A ÷');
Test_X('÷ 000A ÷ 0001 ÷');
Test_X('÷ 000A ÷ 0308 ÷ 0001 ÷');
Test_X('÷ 000A ÷ 0300 ÷');
Test_X('÷ 000A ÷ 0308 × 0300 ÷');
Test_X('÷ 000A ÷ 0903 ÷');
Test_X('÷ 000A ÷ 0308 × 0903 ÷');
Test_X('÷ 000A ÷ 1100 ÷');
Test_X('÷ 000A ÷ 0308 ÷ 1100 ÷');
Test_X('÷ 000A ÷ 1160 ÷');
Test_X('÷ 000A ÷ 0308 ÷ 1160 ÷');
Test_X('÷ 000A ÷ 11A8 ÷');
Test_X('÷ 000A ÷ 0308 ÷ 11A8 ÷');
Test_X('÷ 000A ÷ AC00 ÷');
Test_X('÷ 000A ÷ 0308 ÷ AC00 ÷');
Test_X('÷ 000A ÷ AC01 ÷');
Test_X('÷ 000A ÷ 0308 ÷ AC01 ÷');
Test_X('÷ 000A ÷ 1F1E6 ÷');
Test_X('÷ 000A ÷ 0308 ÷ 1F1E6 ÷');
Test_X('÷ 000A ÷ 0378 ÷');
Test_X('÷ 000A ÷ 0308 ÷ 0378 ÷');
Test_X('÷ 000A ÷ D800 ÷');
Test_X('÷ 000A ÷ 0308 ÷ D800 ÷');
Test_X('÷ 0001 ÷ 0020 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 0020 ÷');
Test_X('÷ 0001 ÷ 000D ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 000D ÷');
Test_X('÷ 0001 ÷ 000A ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 000A ÷');
Test_X('÷ 0001 ÷ 0001 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 0001 ÷');
Test_X('÷ 0001 ÷ 0300 ÷');
Test_X('÷ 0001 ÷ 0308 × 0300 ÷');
Test_X('÷ 0001 ÷ 0903 ÷');
Test_X('÷ 0001 ÷ 0308 × 0903 ÷');
Test_X('÷ 0001 ÷ 1100 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 1100 ÷');
Test_X('÷ 0001 ÷ 1160 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 1160 ÷');
Test_X('÷ 0001 ÷ 11A8 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 11A8 ÷');
Test_X('÷ 0001 ÷ AC00 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ AC00 ÷');
Test_X('÷ 0001 ÷ AC01 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ AC01 ÷');
Test_X('÷ 0001 ÷ 1F1E6 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 1F1E6 ÷');
Test_X('÷ 0001 ÷ 0378 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 0378 ÷');
Test_X('÷ 0001 ÷ D800 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ D800 ÷');
Test_X('÷ 0300 ÷ 0020 ÷');
Test_X('÷ 0300 × 0308 ÷ 0020 ÷');
Test_X('÷ 0300 ÷ 000D ÷');
Test_X('÷ 0300 × 0308 ÷ 000D ÷');
Test_X('÷ 0300 ÷ 000A ÷');
Test_X('÷ 0300 × 0308 ÷ 000A ÷');
Test_X('÷ 0300 ÷ 0001 ÷');
Test_X('÷ 0300 × 0308 ÷ 0001 ÷');
Test_X('÷ 0300 × 0300 ÷');
Test_X('÷ 0300 × 0308 × 0300 ÷');
Test_X('÷ 0300 × 0903 ÷');
Test_X('÷ 0300 × 0308 × 0903 ÷');
Test_X('÷ 0300 ÷ 1100 ÷');
Test_X('÷ 0300 × 0308 ÷ 1100 ÷');
Test_X('÷ 0300 ÷ 1160 ÷');
Test_X('÷ 0300 × 0308 ÷ 1160 ÷');
Test_X('÷ 0300 ÷ 11A8 ÷');
Test_X('÷ 0300 × 0308 ÷ 11A8 ÷');
Test_X('÷ 0300 ÷ AC00 ÷');
Test_X('÷ 0300 × 0308 ÷ AC00 ÷');
Test_X('÷ 0300 ÷ AC01 ÷');
Test_X('÷ 0300 × 0308 ÷ AC01 ÷');
Test_X('÷ 0300 ÷ 1F1E6 ÷');
Test_X('÷ 0300 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ 0300 ÷ 0378 ÷');
Test_X('÷ 0300 × 0308 ÷ 0378 ÷');
Test_X('÷ 0300 ÷ D800 ÷');
Test_X('÷ 0300 × 0308 ÷ D800 ÷');
Test_X('÷ 0903 ÷ 0020 ÷');
Test_X('÷ 0903 × 0308 ÷ 0020 ÷');
Test_X('÷ 0903 ÷ 000D ÷');
Test_X('÷ 0903 × 0308 ÷ 000D ÷');
Test_X('÷ 0903 ÷ 000A ÷');
Test_X('÷ 0903 × 0308 ÷ 000A ÷');
Test_X('÷ 0903 ÷ 0001 ÷');
Test_X('÷ 0903 × 0308 ÷ 0001 ÷');
Test_X('÷ 0903 × 0300 ÷');
Test_X('÷ 0903 × 0308 × 0300 ÷');
Test_X('÷ 0903 × 0903 ÷');
Test_X('÷ 0903 × 0308 × 0903 ÷');
Test_X('÷ 0903 ÷ 1100 ÷');
Test_X('÷ 0903 × 0308 ÷ 1100 ÷');
Test_X('÷ 0903 ÷ 1160 ÷');
Test_X('÷ 0903 × 0308 ÷ 1160 ÷');
Test_X('÷ 0903 ÷ 11A8 ÷');
Test_X('÷ 0903 × 0308 ÷ 11A8 ÷');
Test_X('÷ 0903 ÷ AC00 ÷');
Test_X('÷ 0903 × 0308 ÷ AC00 ÷');
Test_X('÷ 0903 ÷ AC01 ÷');
Test_X('÷ 0903 × 0308 ÷ AC01 ÷');
Test_X('÷ 0903 ÷ 1F1E6 ÷');
Test_X('÷ 0903 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ 0903 ÷ 0378 ÷');
Test_X('÷ 0903 × 0308 ÷ 0378 ÷');
Test_X('÷ 0903 ÷ D800 ÷');
Test_X('÷ 0903 × 0308 ÷ D800 ÷');
Test_X('÷ 1100 ÷ 0020 ÷');
Test_X('÷ 1100 × 0308 ÷ 0020 ÷');
Test_X('÷ 1100 ÷ 000D ÷');
Test_X('÷ 1100 × 0308 ÷ 000D ÷');
Test_X('÷ 1100 ÷ 000A ÷');
Test_X('÷ 1100 × 0308 ÷ 000A ÷');
Test_X('÷ 1100 ÷ 0001 ÷');
Test_X('÷ 1100 × 0308 ÷ 0001 ÷');
Test_X('÷ 1100 × 0300 ÷');
Test_X('÷ 1100 × 0308 × 0300 ÷');
Test_X('÷ 1100 × 0903 ÷');
Test_X('÷ 1100 × 0308 × 0903 ÷');
Test_X('÷ 1100 × 1100 ÷');
Test_X('÷ 1100 × 0308 ÷ 1100 ÷');
Test_X('÷ 1100 × 1160 ÷');
Test_X('÷ 1100 × 0308 ÷ 1160 ÷');
Test_X('÷ 1100 ÷ 11A8 ÷');
Test_X('÷ 1100 × 0308 ÷ 11A8 ÷');
Test_X('÷ 1100 × AC00 ÷');
Test_X('÷ 1100 × 0308 ÷ AC00 ÷');
Test_X('÷ 1100 × AC01 ÷');
Test_X('÷ 1100 × 0308 ÷ AC01 ÷');
Test_X('÷ 1100 ÷ 1F1E6 ÷');
Test_X('÷ 1100 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ 1100 ÷ 0378 ÷');
Test_X('÷ 1100 × 0308 ÷ 0378 ÷');
Test_X('÷ 1100 ÷ D800 ÷');
Test_X('÷ 1100 × 0308 ÷ D800 ÷');
Test_X('÷ 1160 ÷ 0020 ÷');
Test_X('÷ 1160 × 0308 ÷ 0020 ÷');
Test_X('÷ 1160 ÷ 000D ÷');
Test_X('÷ 1160 × 0308 ÷ 000D ÷');
Test_X('÷ 1160 ÷ 000A ÷');
Test_X('÷ 1160 × 0308 ÷ 000A ÷');
Test_X('÷ 1160 ÷ 0001 ÷');
Test_X('÷ 1160 × 0308 ÷ 0001 ÷');
Test_X('÷ 1160 × 0300 ÷');
Test_X('÷ 1160 × 0308 × 0300 ÷');
Test_X('÷ 1160 × 0903 ÷');
Test_X('÷ 1160 × 0308 × 0903 ÷');
Test_X('÷ 1160 ÷ 1100 ÷');
Test_X('÷ 1160 × 0308 ÷ 1100 ÷');
Test_X('÷ 1160 × 1160 ÷');
Test_X('÷ 1160 × 0308 ÷ 1160 ÷');
Test_X('÷ 1160 × 11A8 ÷');
Test_X('÷ 1160 × 0308 ÷ 11A8 ÷');
Test_X('÷ 1160 ÷ AC00 ÷');
Test_X('÷ 1160 × 0308 ÷ AC00 ÷');
Test_X('÷ 1160 ÷ AC01 ÷');
Test_X('÷ 1160 × 0308 ÷ AC01 ÷');
Test_X('÷ 1160 ÷ 1F1E6 ÷');
Test_X('÷ 1160 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ 1160 ÷ 0378 ÷');
Test_X('÷ 1160 × 0308 ÷ 0378 ÷');
Test_X('÷ 1160 ÷ D800 ÷');
Test_X('÷ 1160 × 0308 ÷ D800 ÷');
Test_X('÷ 11A8 ÷ 0020 ÷');
Test_X('÷ 11A8 × 0308 ÷ 0020 ÷');
Test_X('÷ 11A8 ÷ 000D ÷');
Test_X('÷ 11A8 × 0308 ÷ 000D ÷');
Test_X('÷ 11A8 ÷ 000A ÷');
Test_X('÷ 11A8 × 0308 ÷ 000A ÷');
Test_X('÷ 11A8 ÷ 0001 ÷');
Test_X('÷ 11A8 × 0308 ÷ 0001 ÷');
Test_X('÷ 11A8 × 0300 ÷');
Test_X('÷ 11A8 × 0308 × 0300 ÷');
Test_X('÷ 11A8 × 0903 ÷');
Test_X('÷ 11A8 × 0308 × 0903 ÷');
Test_X('÷ 11A8 ÷ 1100 ÷');
Test_X('÷ 11A8 × 0308 ÷ 1100 ÷');
Test_X('÷ 11A8 ÷ 1160 ÷');
Test_X('÷ 11A8 × 0308 ÷ 1160 ÷');
Test_X('÷ 11A8 × 11A8 ÷');
Test_X('÷ 11A8 × 0308 ÷ 11A8 ÷');
Test_X('÷ 11A8 ÷ AC00 ÷');
Test_X('÷ 11A8 × 0308 ÷ AC00 ÷');
Test_X('÷ 11A8 ÷ AC01 ÷');
Test_X('÷ 11A8 × 0308 ÷ AC01 ÷');
Test_X('÷ 11A8 ÷ 1F1E6 ÷');
Test_X('÷ 11A8 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ 11A8 ÷ 0378 ÷');
Test_X('÷ 11A8 × 0308 ÷ 0378 ÷');
Test_X('÷ 11A8 ÷ D800 ÷');
Test_X('÷ 11A8 × 0308 ÷ D800 ÷');
Test_X('÷ AC00 ÷ 0020 ÷');
Test_X('÷ AC00 × 0308 ÷ 0020 ÷');
Test_X('÷ AC00 ÷ 000D ÷');
Test_X('÷ AC00 × 0308 ÷ 000D ÷');
Test_X('÷ AC00 ÷ 000A ÷');
Test_X('÷ AC00 × 0308 ÷ 000A ÷');
Test_X('÷ AC00 ÷ 0001 ÷');
Test_X('÷ AC00 × 0308 ÷ 0001 ÷');
Test_X('÷ AC00 × 0300 ÷');
Test_X('÷ AC00 × 0308 × 0300 ÷');
Test_X('÷ AC00 × 0903 ÷');
Test_X('÷ AC00 × 0308 × 0903 ÷');
Test_X('÷ AC00 ÷ 1100 ÷');
Test_X('÷ AC00 × 0308 ÷ 1100 ÷');
Test_X('÷ AC00 × 1160 ÷');
Test_X('÷ AC00 × 0308 ÷ 1160 ÷');
Test_X('÷ AC00 × 11A8 ÷');
Test_X('÷ AC00 × 0308 ÷ 11A8 ÷');
Test_X('÷ AC00 ÷ AC00 ÷');
Test_X('÷ AC00 × 0308 ÷ AC00 ÷');
Test_X('÷ AC00 ÷ AC01 ÷');
Test_X('÷ AC00 × 0308 ÷ AC01 ÷');
Test_X('÷ AC00 ÷ 1F1E6 ÷');
Test_X('÷ AC00 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ AC00 ÷ 0378 ÷');
Test_X('÷ AC00 × 0308 ÷ 0378 ÷');
Test_X('÷ AC00 ÷ D800 ÷');
Test_X('÷ AC00 × 0308 ÷ D800 ÷');
Test_X('÷ AC01 ÷ 0020 ÷');
Test_X('÷ AC01 × 0308 ÷ 0020 ÷');
Test_X('÷ AC01 ÷ 000D ÷');
Test_X('÷ AC01 × 0308 ÷ 000D ÷');
Test_X('÷ AC01 ÷ 000A ÷');
Test_X('÷ AC01 × 0308 ÷ 000A ÷');
Test_X('÷ AC01 ÷ 0001 ÷');
Test_X('÷ AC01 × 0308 ÷ 0001 ÷');
Test_X('÷ AC01 × 0300 ÷');
Test_X('÷ AC01 × 0308 × 0300 ÷');
Test_X('÷ AC01 × 0903 ÷');
Test_X('÷ AC01 × 0308 × 0903 ÷');
Test_X('÷ AC01 ÷ 1100 ÷');
Test_X('÷ AC01 × 0308 ÷ 1100 ÷');
Test_X('÷ AC01 ÷ 1160 ÷');
Test_X('÷ AC01 × 0308 ÷ 1160 ÷');
Test_X('÷ AC01 × 11A8 ÷');
Test_X('÷ AC01 × 0308 ÷ 11A8 ÷');
Test_X('÷ AC01 ÷ AC00 ÷');
Test_X('÷ AC01 × 0308 ÷ AC00 ÷');
Test_X('÷ AC01 ÷ AC01 ÷');
Test_X('÷ AC01 × 0308 ÷ AC01 ÷');
Test_X('÷ AC01 ÷ 1F1E6 ÷');
Test_X('÷ AC01 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ AC01 ÷ 0378 ÷');
Test_X('÷ AC01 × 0308 ÷ 0378 ÷');
Test_X('÷ AC01 ÷ D800 ÷');
Test_X('÷ AC01 × 0308 ÷ D800 ÷');
Test_X('÷ 1F1E6 ÷ 0020 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 0020 ÷');
Test_X('÷ 1F1E6 ÷ 000D ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 000D ÷');
Test_X('÷ 1F1E6 ÷ 000A ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 000A ÷');
Test_X('÷ 1F1E6 ÷ 0001 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 0001 ÷');
Test_X('÷ 1F1E6 × 0300 ÷');
Test_X('÷ 1F1E6 × 0308 × 0300 ÷');
Test_X('÷ 1F1E6 × 0903 ÷');
Test_X('÷ 1F1E6 × 0308 × 0903 ÷');
Test_X('÷ 1F1E6 ÷ 1100 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 1100 ÷');
Test_X('÷ 1F1E6 ÷ 1160 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 1160 ÷');
Test_X('÷ 1F1E6 ÷ 11A8 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 11A8 ÷');
Test_X('÷ 1F1E6 ÷ AC00 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ AC00 ÷');
Test_X('÷ 1F1E6 ÷ AC01 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ AC01 ÷');
Test_X('÷ 1F1E6 × 1F1E6 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ 1F1E6 ÷ 0378 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 0378 ÷');
Test_X('÷ 1F1E6 ÷ D800 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ D800 ÷');
Test_X('÷ 0378 ÷ 0020 ÷');
Test_X('÷ 0378 × 0308 ÷ 0020 ÷');
Test_X('÷ 0378 ÷ 000D ÷');
Test_X('÷ 0378 × 0308 ÷ 000D ÷');
Test_X('÷ 0378 ÷ 000A ÷');
Test_X('÷ 0378 × 0308 ÷ 000A ÷');
Test_X('÷ 0378 ÷ 0001 ÷');
Test_X('÷ 0378 × 0308 ÷ 0001 ÷');
Test_X('÷ 0378 × 0300 ÷');
Test_X('÷ 0378 × 0308 × 0300 ÷');
Test_X('÷ 0378 × 0903 ÷');
Test_X('÷ 0378 × 0308 × 0903 ÷');
Test_X('÷ 0378 ÷ 1100 ÷');
Test_X('÷ 0378 × 0308 ÷ 1100 ÷');
Test_X('÷ 0378 ÷ 1160 ÷');
Test_X('÷ 0378 × 0308 ÷ 1160 ÷');
Test_X('÷ 0378 ÷ 11A8 ÷');
Test_X('÷ 0378 × 0308 ÷ 11A8 ÷');
Test_X('÷ 0378 ÷ AC00 ÷');
Test_X('÷ 0378 × 0308 ÷ AC00 ÷');
Test_X('÷ 0378 ÷ AC01 ÷');
Test_X('÷ 0378 × 0308 ÷ AC01 ÷');
Test_X('÷ 0378 ÷ 1F1E6 ÷');
Test_X('÷ 0378 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ 0378 ÷ 0378 ÷');
Test_X('÷ 0378 × 0308 ÷ 0378 ÷');
Test_X('÷ 0378 ÷ D800 ÷');
Test_X('÷ 0378 × 0308 ÷ D800 ÷');
Test_X('÷ D800 ÷ 0020 ÷');
Test_X('÷ D800 ÷ 0308 ÷ 0020 ÷');
Test_X('÷ D800 ÷ 000D ÷');
Test_X('÷ D800 ÷ 0308 ÷ 000D ÷');
Test_X('÷ D800 ÷ 000A ÷');
Test_X('÷ D800 ÷ 0308 ÷ 000A ÷');
Test_X('÷ D800 ÷ 0001 ÷');
Test_X('÷ D800 ÷ 0308 ÷ 0001 ÷');
Test_X('÷ D800 ÷ 0300 ÷');
Test_X('÷ D800 ÷ 0308 × 0300 ÷');
Test_X('÷ D800 ÷ 0903 ÷');
Test_X('÷ D800 ÷ 0308 × 0903 ÷');
Test_X('÷ D800 ÷ 1100 ÷');
Test_X('÷ D800 ÷ 0308 ÷ 1100 ÷');
Test_X('÷ D800 ÷ 1160 ÷');
Test_X('÷ D800 ÷ 0308 ÷ 1160 ÷');
Test_X('÷ D800 ÷ 11A8 ÷');
Test_X('÷ D800 ÷ 0308 ÷ 11A8 ÷');
Test_X('÷ D800 ÷ AC00 ÷');
Test_X('÷ D800 ÷ 0308 ÷ AC00 ÷');
Test_X('÷ D800 ÷ AC01 ÷');
Test_X('÷ D800 ÷ 0308 ÷ AC01 ÷');
Test_X('÷ D800 ÷ 1F1E6 ÷');
Test_X('÷ D800 ÷ 0308 ÷ 1F1E6 ÷');
Test_X('÷ D800 ÷ 0378 ÷');
Test_X('÷ D800 ÷ 0308 ÷ 0378 ÷');
Test_X('÷ D800 ÷ D800 ÷');
Test_X('÷ D800 ÷ 0308 ÷ D800 ÷');
Test_X('÷ 0061 ÷ 1F1E6 ÷ 0062 ÷');
Test_X('÷ 1F1F7 × 1F1FA ÷');
Test_X('÷ 1F1F7 × 1F1FA × 1F1F8 ÷');
Test_X('÷ 1F1F7 × 1F1FA × 1F1F8 × 1F1EA ÷');
Test_X('÷ 1F1F7 × 1F1FA ÷ 200B ÷ 1F1F8 × 1F1EA ÷');
Test_X('÷ 1F1E6 × 1F1E7 × 1F1E8 ÷');
Test_X('÷ 1F1E6 × 200D ÷ 1F1E7 × 1F1E8 ÷');
Test_X('÷ 1F1E6 × 1F1E7 × 200D ÷ 1F1E8 ÷');
Test_X('÷ 0020 × 200D ÷ 0646 ÷');
Test_X('÷ 0646 × 200D ÷ 0020 ÷');
Finished();
